senticnet = {}
senticnet['32_teeth'] = [0.965, 0.775, 0, 0.968, '#joyful', '#admirable', 0.903, 'snot', 'good_taste', 'mouth_part', 'gum', 'near_mouth']
senticnet['a_little'] = [-0.99, 0, 0, -0.709, '#sad', '#disgusting', -0.566, 'least', 'little', 'small_amount', 'shortage', 'scarce']
senticnet['a_little_hungry'] = [0.757, 0, 0, 0, '#joyful', '#joyful', 0.252, 'get_full', 'hunger_go_away', 'feel_full', 'hunger', 'full']
senticnet['a_lot'] = [0.277, 0.161, 0, 0.337, '#joyful', '#admirable', 0.258, 'many', 'plenty', 'big_amount', 'abundant', 'good_number']
senticnet['a_lot_of_books'] = [0, 0.076, 0, 0.066, '#interesting', '#admirable', 0.047, 'library', 'old_testament', 'cook_book', 'magazine', 'librarian']
senticnet['a_lot_of_energy'] = [0, 0, 0, 0.766, '#admirable', '#admirable', 0.255, 'effort', 'determination', 'discipline', 'good_condition', 'stamina']
senticnet['a_lot_of_fat'] = [0, 0, 0.801, -0.702, '#angry', '#disgusting', -0.501, 'overweight', 'obese', 'gross', 'roly-poly', 'heavy']
senticnet['a_lot_of_flowers'] = [0.027, 0.093, 0.025, 0.071, '#interesting', '#admirable', 0.055, 'flower', 'love', 'show_love', 'rose', 'give_flower']
senticnet['a_lot_of_food'] = [0.043, -0.055, 0, 0, '#joyful', '#surprising', 0.033, 'apple_pie', 'lasagna', 'jelly', 'frozen_food', 'cottage_cheese']
senticnet['a_lot_of_fun'] = [0.814, 0, 0, 0.856, '#joyful', '#admirable', 0.557, 'radical', 'enjoyable', 'just_fun', 'good_mental_health', 'fun_play']
senticnet['a_lot_of_information'] = [0, 0.219, -0.05, 0.144, '#interesting', '#admirable', 0.104, 'information', 'like_price', 'amount_charge', 'amount', 'item_worth']
senticnet['a_lot_of_money'] = [0, 0.131, 0, 0, '#interesting', '#interesting', 0.044, 'money_bank', 'bring_wallet', 'much_money', 'wealthy', 'down_payment']
senticnet['a_lot_of_noise'] = [0, 0, 0.896, -0.962, '#angry', '#disgusting', -0.619, 'back_pain', 'dog_bark', 'sprain_ankle', 'backache', 'broken_leg']
senticnet['a_lot_of_people'] = [0.08, -0.028, 0, 0, '#joyful', '#surprising', 0.036, 'big_group', 'multitude', 'bunch_person', 'group_of_people', 'several_people']
senticnet['a_lot_of_practice'] = [0.808, 0, 0, 0.943, '#joyful', '#admirable', 0.584, 'elastic', 'flexibility', 'take_lesson', 'coordination', 'air_tank']
senticnet['a_lot_of_sex'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'prosper', 'sexual_intercourse', 'warm_fuzzy_feeling', 'woman', 'give_birth_child']
senticnet['a_lot_of_space'] = [0.84, 0.852, 0, 0, '#joyful', '#interesting', 0.564, 'room', 'space', 'capacity', 'house', 'universe']
senticnet['a_lot_of_stress'] = [-0.184, -0.016, -0.104, -0.163, '#sad', '#disgusting', -0.145, 'get_grade', 'failure', 'flunk', 'stress', 'worry']
senticnet['a_lot_of_study'] = [0, 0, 0.905, -0.997, '#angry', '#disgusting', -0.634, 'study_lot', 'stress', 'worry', 'study_material', 'anxiety']
senticnet['a_lot_of_time'] = [0.918, 0.988, 0, 0, '#joyful', '#interesting', 0.635, 'learn_program_language', 'write_code', 'learn_program', 'debug', 'learn_computer_language']
senticnet['a_lot_of_work'] = [0.93, 0.894, 0, 0, '#joyful', '#interesting', 0.608, 'work', 'produce_value', 'prepare_event', 'accomplish', 'finish_work']
senticnet['aah'] = [0, 0, 0.747, -0.892, '#angry', '#disgusting', -0.546, 'shout', 'cry', 'gee', 'ooh', 'cry_out']
senticnet['abandon'] = [-0.99, 0, 0, -0.709, '#sad', '#disgusting', -0.566, 'leave_alone', 'smelly_foot', 'unattractive', 'lose_team', 'leave_out']
senticnet['abandoned'] = [0, 0, -0.981, -0.921, '#scared', '#disgusting', -0.634, 'give_up', 'forsake', 'desolate', 'derelict', 'deserted']
senticnet['abandoned_person'] = [-0.676, 0, 0.838, -0.86, '#angry', '#disgusting', -0.791, 'unsuccessful_person', 'loser', 'unfortunate', 'desperate', 'orphan']
senticnet['abandonment'] = [-0.73, 0, -0.938, 0, '#sad', '#scared', -0.556, 'need_break', 'need_to_rest', 'leg_tire', 'catch_breath', 'weary']
senticnet['abase'] = [-0.871, 0, -0.702, 0, '#sad', '#scared', -0.524, 'mortify', 'embarrassed', 'self-hatred', 'self-disgust', 'humiliated']
senticnet['abash'] = [-0.927, 0, 0.71, 0, '#sad', '#angry', -0.546, 'awkward', 'unenviable', 'embarrassingly', 'embarrassing', 'sheepish']
senticnet['abashed'] = [-0.97, 0, 0.731, 0, '#sad', '#angry', -0.567, 'chagrined', 'embarrassingly', 'abash', 'awkward', 'unenviable']
senticnet['abashment'] = [-0.796, 0, 0.743, 0, '#sad', '#angry', -0.513, 'bashfulness', 'humility', 'timidity', 'abash', 'reservation']
senticnet['abate'] = [-0.927, 0, 0.757, -0.905, '#sad', '#disgusting', -0.863, 'let_up', 'far', 'slack_off', 'die_away', 'die']
senticnet['abatement'] = [0, 0, 0.955, -0.984, '#angry', '#disgusting', -0.646, 'defervescence', 'subsidence', 'break', 'decline', 'remittal']
senticnet['abbreviate'] = [-0.046, 0.127, -0.121, 0.223, '#interesting', '#admirable', 0.061, 'shorten', 'abridge', 'curtail', 'cut_short', 'shortcut']
senticnet['abc'] = [0.03, -0.009, 0, 0.089, '#joyful', '#admirable', 0.043, 'grammar', 'alphabet', 'letter', 'language', 'noun']
senticnet['abdicate'] = [-0.783, 0, 0.801, -0.87, '#angry', '#disgusting', -0.818, 'resign', 'renounce', 'step_down', 'vacate', 'leave_office']
senticnet['abdomen'] = [0.902, 0.772, 0, 0, '#joyful', '#interesting', 0.558, 'body', 'two_ears', 'dog_pet', 'living_thing', 'midsection']
senticnet['abdominal_pregnancy'] = [-0.752, 0, 0.715, -0.725, '#sad', '#disgusting', -0.731, 'ectopic_gestation', 'ovarian_pregnancy', 'tubal_pregnancy', 'disease', 'pain']
senticnet['abdominoplasty'] = [0.96, -0.839, 0, 0.566, '#joyful', '#surprising', 0.788, 'lift', 'phalloplasty', 'plastic_surgery', 'tummy_tuck', 'autoplasty']
senticnet['abduction'] = [0, 0, -0.903, -0.976, '#scared', '#disgusting', -0.626, 'reaper', 'intolerance', 'danger', 'illiteracy', 'kidnap']
senticnet['abductor'] = [0.934, -0.62, 0, 0.79, '#joyful', '#admirable', 0.781, 'voluntary_muscle', 'deltoid', 'pterygoid_muscle', 'skeletal_muscle', 'muscle']
senticnet['abductor_muscle'] = [0.934, -0.62, 0, 0.79, '#joyful', '#admirable', 0.781, 'voluntary_muscle', 'deltoid', 'muscle', 'abductor', 'skeletal_muscle']
senticnet['aberrance'] = [-0.859, 0, 0.936, -0.807, '#sad', '#angry', -0.867, 'abnormalcy', 'abnormality', 'deflection', 'warp', 'chromosomal_aberration']
senticnet['aberrancy'] = [-0.555, 0, 0.911, -0.987, '#angry', '#disgusting', -0.818, 'abnormalcy', 'abnormality', 'deflection', 'warp', 'chromosomal_aberration']
senticnet['aberrant'] = [-0.881, 0, 0.882, -0.586, '#sad', '#angry', -0.783, 'mortal', 'behemoth', 'colossus', 'unusual_person', 'giant']
senticnet['abhor'] = [-0.063, 0.183, 0.651, -0.642, '#angry', '#disgusting', -0.391, 'abhorrence', 'abomination', 'detestation', 'execration', 'loathing']
senticnet['abhorrence'] = [-0.063, 0.183, 0.651, -0.642, '#angry', '#disgusting', -0.391, 'abomination', 'detestation', 'execration', 'loathing', 'odium']
senticnet['abhorrent'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repulsive', 'repugnant', 'detestably', 'abominably', 'odiously']
senticnet['abidance'] = [0.614, -0.953, 0, 0.768, '#surprising', '#admirable', 0.778, 'keeping', 'formality', 'honoring', 'line', 'observance']
senticnet['abide'] = [0.038, 0, 0, 0.097, '#joyful', '#admirable', 0.045, 'rule', 'decision', 'follow', 'discipline', 'acceptance']
senticnet['abide_by'] = [0.731, -0.592, 0, 0.634, '#joyful', '#admirable', 0.652, 'accommodate', 'obey', 'conform_to', 'toe_line', 'oblige']
senticnet['abience'] = [-0.846, 0, 0.762, 0, '#sad', '#angry', -0.536, 'motive', 'need', 'spur', 'impulse', 'adience']
senticnet['ability'] = [0, 0.273, -0.162, 0.277, '#interesting', '#admirable', 0.129, 'skill', 'competence', 'talent', 'expert', 'possible']
senticnet['ability_communicate'] = [0, 0.87, 0, 0.736, '#interesting', '#admirable', 0.535, 'convey_information', 'know_language', 'fact_straight', 'know_talk', 'use_language']
senticnet['ability_hear'] = [0.708, 0, 0, 0, '#joyful', '#joyful', 0.236, 'use_ear', 'ear_activity', 'hear', 'audible', 'hear_sound']
senticnet['ability_read'] = [0.727, 0, 0, 0.856, '#joyful', '#admirable', 0.528, 'eyes', 'information', 'choose_book', 'good_book', 'hold_book']
senticnet['ability_see'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'wear_glass', 'recognize', 'open_eye', 'turn_on_tv', 'regard']
senticnet['abject'] = [-0.773, 0, 0, -0.802, '#sad', '#disgusting', -0.525, 'resignedly', 'unhopeful', 'abjectly', 'resignation', 'reconcile']
senticnet['abjection'] = [-0.566, 0, 0.512, -0.506, '#sad', '#angry', -0.528, 'depth', 'humiliation', 'degeneration', 'decadence', 'decadency']
senticnet['abjectly'] = [-0.961, 0, 0, -0.995, '#sad', '#disgusting', -0.652, 'resignedly', 'abject', 'unhopeful', 'resignation', 'reconcile']
senticnet['abjure'] = [-0.97, 0, 0.616, -0.589, '#sad', '#angry', -0.725, 'repudiate', 'recant', 'forswear', 'deny', 'reject']
senticnet['ablate'] = [-0.909, 0, 0, -0.966, '#sad', '#disgusting', -0.625, 'wear_out', 'wear_off', 'melt', 'vaporize', 'wear_thin']
senticnet['ablaze'] = [0.641, -0.733, 0, 0.798, '#surprising', '#admirable', 0.724, 'lighted', 'aflame', 'afire', 'aflare', 'alight']
senticnet['able'] = [0.982, -0.67, 0, 0.682, '#joyful', '#admirable', 0.778, 'workmanlike', 'effective', 'efficient', 'competent', 'capcompetent']
senticnet['able_eat'] = [0.728, 0.921, 0, 0, '#joyful', '#interesting', 0.55, 'munch', 'satisfy_appetite', 'nourishment', 'replenish_energy', 'sustenance']
senticnet['able_hear'] = [0.96, -0.907, 0, 0, '#joyful', '#surprising', 0.622, 'go_rock_concert', 'attend_concert', 'sensibility', 'audible', 'turn_radio']
senticnet['able_read'] = [0.972, 0.895, 0, 0.727, '#joyful', '#interesting', 0.865, 'good_sense_of_humor', 'good_eyesight', 'taken_seriously', 'complement', 'much_need']
senticnet['able_run'] = [0.731, 0.729, 0, 0.866, '#joyful', '#admirable', 0.775, 'stand_behind', 'start_move', 'conform', 'stand', 'go_end']
senticnet['able_see'] = [0.071, 0.111, 0, 0.078, '#interesting', '#admirable', 0.087, 'make_popcorn', 'rend_video', 'wear_glass', 'watch_good_movie', 'rend_movie']
senticnet['able_use'] = [0.84, 0.813, 0, 0.915, '#joyful', '#admirable', 0.856, 'increase_income', 'transact_business', 'resolve_dispute', 'active', 'promote_business']
senticnet['abnegate'] = [-0.887, 0, 0.938, -0.995, '#angry', '#disgusting', -0.94, 'check', 'hold', 'hold_in', 'moderate', 'control']
senticnet['abnormal'] = [-0.583, 0, 0.814, -0.54, '#sad', '#angry', -0.646, 'atypical', 'irregular', 'vicarious', 'supernormal', 'subnormal']
senticnet['abnormalcy'] = [-0.859, 0, 0.936, -0.807, '#sad', '#angry', -0.867, 'aberrance', 'abnormality', 'deflection', 'warp', 'chromosomal_aberration']
senticnet['abnormality'] = [-0.859, 0, 0.936, -0.807, '#sad', '#angry', -0.867, 'abnormalcy', 'aberrance', 'deflection', 'warp', 'chromosomal_aberration']
senticnet['abolish'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'clean', 'clear_away', 'discharge', 'remove', 'cut_out']
senticnet['abominable_snowman'] = [0, 0, 0.808, -0.779, '#angry', '#disgusting', -0.529, 'monster', 'wild_man', 'orang_pendek', 'yeti', 'abominable']
senticnet['abominably'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repulsive', 'repugnant', 'detestably', 'odiously', 'detestable']
senticnet['abominate'] = [-0.063, 0.183, 0.651, -0.642, '#angry', '#disgusting', -0.391, 'abhorrence', 'abomination', 'detestation', 'execration', 'loathing']
senticnet['abomination'] = [-0.063, 0.183, 0.651, -0.642, '#angry', '#disgusting', -0.391, 'abhorrence', 'detestation', 'execration', 'loathing', 'odium']
senticnet['abominator'] = [0, 0, 0.778, -0.997, '#angry', '#disgusting', -0.592, 'hater', 'loather', 'fear', 'anglophobe', 'horror']
senticnet['aboriginal'] = [0.066, 0.12, -0.104, 0.121, '#interesting', '#admirable', 0.068, 'form_government', 'kingdom', 'united_country', 'political_entity', 'native_australia']
senticnet['abortion'] = [-0.955, 0, -0.986, 0, '#sad', '#scared', -0.647, 'death', 'feticide', 'sickness', 'miscarriage', 'spontaneous_abortion']
senticnet['abortive'] = [-0.705, 0, 0.919, -0.732, '#angry', '#disgusting', -0.785, 'childless', 'unsuccessful', 'acarpous', 'unfruitful', 'stillborn']
senticnet['abortus'] = [-0.947, 0, 0, -0.85, '#sad', '#disgusting', -0.599, 'teras', 'spontaneous_abortion', 'miscarriage', 'fetus', 'vertebrate']
senticnet['above'] = [0.75, 0, 0, 0.971, '#joyful', '#admirable', 0.574, 'high', 'superior', 'aloft', 'above_all', 'atop']
senticnet['above_earth'] = [0, 0.09, 0, 0.066, '#interesting', '#admirable', 0.052, 'massive', 'universe', 'light', 'limitless', 'outer_space']
senticnet['above_leg'] = [0.023, 0.085, -0.045, 0.088, '#interesting', '#admirable', 0.05, 'thigh', 'femur', 'joint', 'hip', 'knee']
senticnet['abrade'] = [-0.992, 0, 0.869, -0.604, '#sad', '#angry', -0.822, 'excoriate', 'chafe', 'rasp', 'wear_away', 'wear_off']
senticnet['abraded'] = [0, 0, 0.862, -0.768, '#angry', '#disgusting', -0.543, 'scour', 'abrase', 'rub_off', 'corrade', 'rub_down']
senticnet['abrasion'] = [-0.101, 0, -0.056, -0.099, '#sad', '#disgusting', -0.085, 'gash', 'painful_injury', 'cut_skin', 'injury', 'laceration']
senticnet['abrasive'] = [-0.061, 0, 0, -0.037, '#sad', '#disgusting', -0.033, 'friction', 'lack_of_water', 'dirt', 'sand', 'ground_material']
senticnet['abridge'] = [0.718, 0.977, 0, 0, '#joyful', '#interesting', 0.565, 'immobilize', 'abstract', 'curtail', 'digest', 'concentrate']
senticnet['abridgement'] = [0, 0.175, 0.084, 0.133, '#interesting', '#admirable', 0.075, 'brief', 'recap', 'summary', 'resume', 'report']
senticnet['abroad'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'overseas', 'another_country', 'study_abroad', 'elsewhere', 'live_abroad']
senticnet['abrupt'] = [-0.732, 0, 0.865, -0.878, '#angry', '#disgusting', -0.825, 'rude', 'surprise', 'jeer', 'sudden', 'jolt']
senticnet['abruptness'] = [-0.566, 0, 0.828, -0.689, '#angry', '#disgusting', -0.694, 'hastiness', 'precipitateness', 'precipitousness', 'precipitance', 'precipitancy']
senticnet['abscessed'] = [-0.657, 0, 0.995, -0.625, '#sad', '#angry', -0.759, 'dirty', 'putrefactive', 'putrefacient', 'infected', 'contaminative']
senticnet['absence'] = [-0.561, 0, -0.493, -0.093, '#sad', '#scared', -0.382, 'lack', 'poor', 'poverty', 'emptiness', 'hunger']
senticnet['absence_of_communication'] = [-0.957, 0, 0.549, -0.993, '#sad', '#disgusting', -0.833, 'bad_connection', 'bad_communication', 'internet_problem', 'bad_reception', 'underground']
senticnet['absence_of_danger'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'safety', 'absence_of_risk', 'guarded', 'secure', 'defended']
senticnet['absence_of_light'] = [-0.809, 0, -0.931, 0, '#sad', '#scared', -0.58, 'lack_light', 'depression', 'anguish', 'feel_sorry', 'dark']
senticnet['absence_of_risk'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'safety', 'absence_of_danger', 'guarded', 'secure', 'defended']
senticnet['absence_seizure'] = [-0.782, 0, 0, -0.826, '#sad', '#disgusting', -0.536, 'attack', 'raptus', 'epileptic_seizure', 'absence', 'ictus']
senticnet['absent'] = [-0.87, 0, 0.884, 0, '#sad', '#angry', -0.585, 'skip_class', 'skip_work', 'gone', 'avoid_work', 'lazy']
senticnet['absentee'] = [-0.514, 0, 0.63, -0.842, '#angry', '#disgusting', -0.662, 'hooky_player', 'truant', 'defaulter', 'exile', 'expatriate']
senticnet['absolute'] = [0.295, 0.239, 0.049, 0.346, '#joyful', '#admirable', 0.277, 'full', 'never_end', 'infinite', 'total', 'unending']
senticnet['absolute_alcohol'] = [0, 0, 0.722, -0.9, '#angry', '#disgusting', -0.541, 'ethyl_alcohol', 'spirits_of_wine', 'absolute_vodka', 'fermentation_alcohol', 'grain_alcohol']
senticnet['absolute_pitch'] = [0.785, -0.995, 0, 0.981, '#surprising', '#admirable', 0.92, 'ear', 'audition', 'perfect_pitch', 'modality', 'sense_modality']
senticnet['absolutely'] = [0.77, 0, 0, 0.996, '#joyful', '#admirable', 0.589, 'bind_agreement', 'need_money', 'completely', 'earn_wage', 'truly']
senticnet['absolution'] = [0.901, 0, 0, 0.916, '#joyful', '#admirable', 0.606, 'get_away', 'bread', 'glory', 'counsel', 'vow']
senticnet['absolutism'] = [-0.837, 0, 0.858, -0.795, '#sad', '#angry', -0.83, 'dominance', 'ascendance', 'autocracy', 'ascendancy', 'tirant']
senticnet['absolved'] = [0.913, -0.745, 0, 0.703, '#joyful', '#surprising', 0.787, 'guiltless', 'exculpated', 'exonerated', 'vindicated', 'clear']
senticnet['absolvitory'] = [0.579, -0.541, 0, 0.784, '#joyful', '#admirable', 0.635, 'forgiving', 'vindicatory', 'exculpatory', 'exonerative', 'extenuating']
senticnet['absorb'] = [0.869, -0.598, 0, 0.66, '#joyful', '#admirable', 0.709, 'assimilate', 'take_up', 'reabsorb', 'resorb', 'imbibe']
senticnet['absorb_information'] = [0.757, 0.896, 0, 0.538, '#joyful', '#interesting', 0.73, 'ask_expert', 'remember_fact', 'remember_information', 'research', 'seek_info']
senticnet['absorb_moisture'] = [0, 0.799, 0, 0, '#interesting', '#interesting', 0.266, 'iron_shirt', 'sit_on_beach', 'dry_clothes', 'iron_clothes', 'shine_shoes']
senticnet['absorb_water'] = [0, 0.184, -0.051, 0.179, '#interesting', '#admirable', 0.104, 'hygroscope', 'hold_water', 'antiquate', 'molecule', 'tangent']
senticnet['absorbing'] = [0.566, -0.912, 0, 0.599, '#surprising', '#admirable', 0.692, 'intriguing', 'interesting', 'engrossing', 'fascinating', 'gripping']
senticnet['absorption'] = [0.633, -0.968, 0, 0.612, '#joyful', '#surprising', 0.738, 'particularism', 'centering', 'concentration', 'engrossment', 'immersion']
senticnet['abstemious'] = [0.555, -0.914, 0, 0.601, '#surprising', '#admirable', 0.69, 'ascetic', 'ascetical', 'spartan', 'austere', 'abstinent']
senticnet['abstemiousness'] = [-0.741, 0, 0.585, -0.583, '#sad', '#angry', -0.636, 'lack_of_quality', 'meagreness', 'poorness', 'scantiness', 'scantness']
senticnet['abstinence'] = [-0.998, 0, 0.893, -0.703, '#sad', '#angry', -0.865, 'use_condom', 'prevent_conception', 'restrain', 'prevent', 'stop']
senticnet['abstinent'] = [0.555, -0.914, 0, 0.601, '#surprising', '#admirable', 0.69, 'ascetic', 'ascetical', 'spartan', 'austere', 'abstemious']
senticnet['abstract'] = [0, 0.309, -0.105, 0.266, '#interesting', '#admirable', 0.157, 'subjective', 'abstract_concept', 'choice', 'again_and_again', 'imaginary']
senticnet['abstract_concept'] = [0, 0, 0, 0.745, '#admirable', '#admirable', 0.248, 'choice', 'thoughtful', 'abstract', 'certainty', 'forethought']
senticnet['abstract_think'] = [0, 0.733, 0, 0.979, '#interesting', '#admirable', 0.571, 'new_think', 'brain_function', 'make_right_decision', 'brainstorm', 'think']
senticnet['abstract_thought'] = [0.725, -0.76, 0, 0.51, '#joyful', '#surprising', 0.665, 'ratiocination', 'logical_argument', 'line_of_reasoning', 'thinking', 'thought']
senticnet['abstraction'] = [0.144, 0.291, -0.075, 0.296, '#interesting', '#admirable', 0.219, 'descriptive_term', 'reliable', 'social_creature', 'imaginary', 'sentient']
senticnet['absurd'] = [0, 0, 0.911, -0.867, '#angry', '#disgusting', -0.593, 'illogical', 'nonrational', 'preposterous', 'ridiculous', 'ludicrous']
senticnet['absurdity'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'nonsense', 'meaninglessness', 'bunk', 'nonsensicality', 'hokum']
senticnet['abundance'] = [0, 0.184, -0.051, 0.179, '#interesting', '#admirable', 0.104, 'rich', 'a_lot', 'abundant', 'fat', 'plentiful']
senticnet['abundant'] = [-0.083, 0.168, -0.069, 0.189, '#interesting', '#admirable', 0.068, 'abundance', 'a_lot', 'rich', 'plenty', 'plentiful']
senticnet['abuse'] = [-0.25, -0.033, -0.157, -0.287, '#sad', '#disgusting', -0.22, 'feel_stressed', 'parking_ticket', 'without_money', 'mock', 'reprimand']
senticnet['abut'] = [0, 0, -0.898, -0.961, '#scared', '#disgusting', -0.62, 'march', 'butt', 'edge', 'border', 'adjoin']
senticnet['abysmal'] = [-0.808, 0, 0.761, -0.705, '#sad', '#angry', -0.758, 'illimitable', 'limitless', 'measureless', 'unmeasured', 'immeasurable']
senticnet['academic_administrator'] = [0.695, -0.856, 0, 0.501, '#joyful', '#surprising', 0.684, 'executive', 'executive_director', 'chief', 'administrator', 'professor']
senticnet['academic_requirement'] = [0.695, -0.856, 0, 0.501, '#joyful', '#surprising', 0.684, 'essential_condition', 'sine_qua_non', 'responsibility', 'precondition', 'prerequisite']
senticnet['academy'] = [0.739, 0.825, 0, 0.782, '#interesting', '#admirable', 0.782, 'school_session', 'freshman', 'lesson', 'university', 'undergraduate']
senticnet['acarophobia'] = [-0.57, 0, 0.814, -0.936, '#angry', '#disgusting', -0.773, 'phobia', 'zoophobia', 'fear', 'arachnophobia', 'cynophobia']
senticnet['acarpous'] = [-0.705, 0, 0.919, -0.732, '#angry', '#disgusting', -0.785, 'childless', 'unsuccessful', 'unfruitful', 'abortive', 'stillborn']
senticnet['accelerator'] = [0.562, -0.777, 0, 0.962, '#surprising', '#admirable', 0.767, 'console', 'instrument', 'scientific_instrument', 'particle_scientific_instrument', 'atom_smasher']
senticnet['accent'] = [0.982, -0.701, 0, 0.527, '#joyful', '#surprising', 0.737, 'sound', 'lilt', 'enounce', 'round', 'sibilate']
senticnet['accept'] = [0.972, 0, 0, 0.894, '#joyful', '#admirable', 0.622, 'bring', 'receive', 'allow', 'come', 'permission']
senticnet['accept_challenge'] = [0.887, 0, 0, 0, '#joyful', '#joyful', 0.296, 'fun', 'difficult_play', 'enjoy_sport', 'compete', 'competition']
senticnet['acceptability'] = [-0.997, 0, 0.878, -0.957, '#sad', '#disgusting', -0.944, 'adequacy', 'adequateness', 'satisfactoriness', 'acceptableness', 'quality']
senticnet['acceptable'] = [0.258, 0.357, -0.088, 0.351, '#interesting', '#admirable', 0.293, 'satisfaction', 'sufficient', 'serenity', 'feel_ok', 'tolerable']
senticnet['acceptableness'] = [-0.997, 0, 0.878, -0.957, '#sad', '#disgusting', -0.944, 'adequacy', 'adequateness', 'acceptability', 'satisfactoriness', 'quality']
senticnet['acceptance'] = [0, 0, 0, 0.3, '#admirable', '#admirable', 0.1, 'approval', 'given', 'suggest', 'kindness', 'limit_time']
senticnet['acceptation'] = [0.577, -0.77, 0, 0.517, '#joyful', '#surprising', 0.621, 'admiration', 'appreciation', 'reward', 'blessing', 'support']
senticnet['accepted'] = [0.683, -0.553, 0, 0.552, '#joyful', '#surprising', 0.596, 'acknowledged', 'recognized', 'declarable', 'given', 'putative']
senticnet['access'] = [0.825, 0, 0, 0.703, '#joyful', '#admirable', 0.509, 'pay_toll', 'get_fast', 'drive', 'fast_travel', 'drive_quickly']
senticnet['access_computer'] = [0, 0.85, 0, 0.847, '#interesting', '#admirable', 0.566, 'learn_program_language', 'learn_computer_language', 'turn_computer_on', 'write_code', 'a_lot_of_time']
senticnet['access_internet'] = [0.827, 0.732, 0, 0.769, '#joyful', '#admirable', 0.776, 'process_data', 'process_information', 'surf_internet', 'increase_efficiency', 'send_email']
senticnet['accessary'] = [0.9, -0.742, 0, 0.721, '#joyful', '#surprising', 0.788, 'supportive', 'demonstrative_of', 'encouraging', 'certificatory', 'supporting']
senticnet['accessible'] = [0.859, -0.81, 0, 0.615, '#joyful', '#surprising', 0.761, 'get_table', 'approachable', 'reachable', 'handy', 'ready_to_hand']
senticnet['accessorial'] = [-0.819, 0, 0.987, -0.641, '#sad', '#angry', -0.816, 'nonessential', 'accidental', 'incidental', 'unessential', 'adscititious']
senticnet['accessorize_outfit'] = [0.152, 0.114, -0.103, 0.21, '#joyful', '#admirable', 0.124, 'decoration', 'adornment', 'look_nice', 'decorate', 'nice']
senticnet['accessory'] = [0, 0.075, 0.028, 0.173, '#interesting', '#admirable', 0.073, 'worn', 'adornment', 'protective_cover', 'hang_hanger', 'stylish']
senticnet['accident'] = [0, 0, -0.792, -0.718, '#scared', '#disgusting', -0.503, 'automobile_accident', 'hit_car', 'crash_tree', 'use_brake', 'crash_car']
senticnet['accident_game'] = [-0.931, 0, 0.945, -0.932, '#angry', '#disgusting', -0.936, 'break_mirror', 'break_window_shop', 'accident', 'break_window', 'break_door']
senticnet['accident_happen'] = [0, 0, -0.811, -0.832, '#scared', '#disgusting', -0.548, 'get_stuck_traffic', 'traffic_congestion', 'piss_off', 'overwhelm', 'work_much']
senticnet['accidental'] = [-0.819, 0, 0.987, -0.641, '#sad', '#angry', -0.816, 'nonessential', 'unessential', 'incidental', 'accessorial', 'adscititious']
senticnet['acclaim'] = [0.853, 0.828, 0, 0.98, '#joyful', '#admirable', 0.887, 'endorse', 'recommend', 'stimulate_mind', 'acculturation', 'support']
senticnet['acclaimed'] = [0, 0.845, 0, 0.787, '#interesting', '#admirable', 0.544, 'praise', 'hail', 'herald', 'applaud', 'clap']
senticnet['acclamation'] = [0.985, 0, 0, 0.711, '#joyful', '#admirable', 0.565, 'favorite', 'crowd', 'encore', 'bunch', 'large_crowd']
senticnet['accolade'] = [0.232, 0.178, -0.172, 0.223, '#joyful', '#admirable', 0.154, 'fame', 'alms', 'find_money', 'better_life', 'small_detail']
senticnet['accommodate'] = [0.62, -0.917, 0, 0.766, '#surprising', '#admirable', 0.768, 'meet', 'satisfy', 'fulfill', 'conform_to', 'please']
senticnet['accommodation'] = [0, 0.119, 0, 0.095, '#interesting', '#admirable', 0.071, 'building', 'government', 'govern_city', 'government_building', 'large_building']
senticnet['accomplice'] = [0, 0, -0.863, -0.752, '#scared', '#disgusting', -0.538, 'crime', 'murder', 'fellow_conspirator', 'partner_in_crime', 'offence']
senticnet['accomplish'] = [0.907, 0, 0, 0.79, '#joyful', '#admirable', 0.566, 'get_job_done', 'task', 'hard_work', 'job', 'find_job']
senticnet['accomplish_goal'] = [0.228, 0.185, -0.076, 0.308, '#joyful', '#admirable', 0.215, 'reach_goal', 'nice_place_to_live', 'better_life', 'make_difference', 'self_esteem']
senticnet['accomplish_mission'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'victory', 'win_war', 'win_battle', 'score_goal', 'gain_ground']
senticnet['accomplish_task'] = [0.532, 0.657, -0.257, 0.268, '#joyful', '#interesting', 0.4, 'score_goal', 'explain_idea', 'ego_boost', 'solve', 'win_game']
senticnet['accomplished'] = [0, 0, 0, 0.819, '#admirable', '#admirable', 0.273, 'complete_task', 'finished', 'concluded', 'complete_job', 'completed']
senticnet['accomplishment'] = [0.122, 0, 0, 0.107, '#joyful', '#admirable', 0.076, 'extreme_elation', 'stardom', 'cramp', 'win', 'sense_accomplishment']
senticnet['accord'] = [0.824, 0, 0, 0, '#joyful', '#joyful', 0.275, 'pact', 'ode', 'harmony', 'chord', 'agreement']
senticnet['accordant'] = [0.509, -0.626, 0, 0.786, '#surprising', '#admirable', 0.64, 'agreeable', 'consentaneous', 'consentient', 'unanimous', 'according']
senticnet['according'] = [0.509, -0.626, 0, 0.786, '#surprising', '#admirable', 0.64, 'agreeable', 'consentaneous', 'consentient', 'unanimous', 'accordant']
senticnet['accost'] = [0.505, -0.732, 0, 0.743, '#surprising', '#admirable', 0.66, 'come_up', 'recognize', 'greet', 'approach', 'come']
senticnet['account'] = [0, 0.259, 0, 0.055, '#interesting', '#admirable', 0.105, 'dividend', 'piggy_bank', 'banker', 'bank_loan', 'billfold']
senticnet['account_book'] = [0.041, 0.119, 0.017, 0, '#joyful', '#interesting', 0.048, 'tab', 'bank', 'general_ledger', 'cash', 'savings']
senticnet['account_department'] = [0.026, 0.082, 0, 0, '#joyful', '#interesting', 0.036, 'accountant_office', 'deposit', 'financial', 'bank_loan', 'checkbook']
senticnet['account_payable'] = [-0.915, 0, 0.65, -0.594, '#sad', '#angry', -0.72, 'indebtedness', 'payable', 'limited_liability', 'debt', 'arrears']
senticnet['account_term'] = [-0.028, 0.307, -0.07, 0.179, '#interesting', '#admirable', 0.129, 'money_due', 'money_loss', 'amount_owe', 'money_payment', 'money_owe']
senticnet['accountant'] = [-0.075, 0.228, 0.019, 0.089, '#interesting', '#admirable', 0.074, 'football_coach', 'little_child', 'bookkeeper', 'visitor', 'child']
senticnet['accountant_office'] = [0.026, 0.082, 0, 0, '#joyful', '#interesting', 0.036, 'account_department', 'office', 'stationery_store', 'shirt_pocket', 'desk_drawer']
senticnet['accounting'] = [0.671, -0.574, 0, 0.879, '#joyful', '#admirable', 0.708, 'bank_statement', 'bill', 'account', 'invoice', 'financial_statement']
senticnet['accouterment'] = [-0.741, 0, 0.722, -0.562, '#sad', '#angry', -0.675, 'trapping', 'furnishing', 'wear', 'wearable', 'belt']
senticnet['accoutrement'] = [-0.899, 0, 0.795, -0.64, '#sad', '#angry', -0.778, 'trapping', 'furnishing', 'wear', 'wearable', 'belt']
senticnet['accredited'] = [-0.784, 0, 0.657, -0.868, '#sad', '#disgusting', -0.77, 'commissioned', 'authorized', 'licensed', 'licenced', 'approved']
senticnet['accretion'] = [0.942, -0.798, 0, 0.901, '#joyful', '#admirable', 0.88, 'backup', 'buildup', 'deposition', 'deposit', 'increase']
senticnet['acculturation'] = [0.868, 0.99, 0, 0, '#joyful', '#interesting', 0.619, 'enjoy_story', 'cultural_experience', 'stimulate_mind', 'get_news', 'escape_reality']
senticnet['accumulate'] = [0.02, 0.131, -0.081, 0.279, '#interesting', '#admirable', 0.116, 'save_up', 'retrieve', 'obtain', 'savings', 'bring_together']
senticnet['accumulate_knowledge'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'get_smart', 'gain_new_knowledge', 'increase_knowledge', 'learn_history', 'comprehend']
senticnet['accumulate_stress'] = [-0.983, 0, 0.058, -0.921, '#sad', '#disgusting', -0.654, 'traffic_jam', 'crowd', 'stress', 'crowd_city', 'bad_service']
senticnet['accumulation'] = [0.553, -0.8, 0, 0.908, '#surprising', '#admirable', 0.754, 'strong_suit', 'collection', 'aggregation', 'long_suit', 'assemblage']
senticnet['accuracy'] = [0.043, 0.067, 0.012, 0, '#joyful', '#interesting', 0.033, 'accurate', 'time', 'time_loop', 'period', 'time_description']
senticnet['accurate'] = [0.043, 0.067, 0.012, 0, '#joyful', '#interesting', 0.033, 'accuracy', 'time', 'time_loop', 'period', 'time_description']
senticnet['accurse'] = [-0.655, 0, 0.754, -0.937, '#angry', '#disgusting', -0.782, 'anathemize', 'pick_apart', 'execrate', 'criticize', 'deplore']
senticnet['accusation'] = [-0.708, 0, 0.874, -0.75, '#angry', '#disgusting', -0.777, 'blame', 'incrimination', 'inculpation', 'complaint', 'imprecation']
senticnet['accusative'] = [-0.827, 0, 0.81, -0.617, '#sad', '#angry', -0.751, 'oblique', 'genitive', 'genitive_case', 'possessive', 'possessive_case']
senticnet['accusatory'] = [-0.953, 0, 0.771, -0.677, '#sad', '#angry', -0.8, 'condemnatory', 'condemning', 'inculpative', 'accusing', 'accusive']
senticnet['accuse'] = [-0.068, 0, -0.099, -0.188, '#scared', '#disgusting', -0.118, 'accuse_person', 'become_lawyer', 'wear_robe', 'examine_evidence', 'consider_evidence']
senticnet['accuse_person'] = [-0.068, 0, -0.099, -0.188, '#scared', '#disgusting', -0.118, 'accuse', 'become_lawyer', 'liar', 'incriminate', 'blame']
senticnet['accuser'] = [-0.068, 0, -0.099, -0.188, '#scared', '#disgusting', -0.118, 'fault', 'fall_down', 'sore_knee', 'breafast', 'miss_ball']
senticnet['accusing'] = [-0.953, 0, 0.771, -0.677, '#sad', '#angry', -0.8, 'condemnatory', 'condemning', 'accusatory', 'inculpative', 'accusive']
senticnet['accusive'] = [-0.953, 0, 0.771, -0.677, '#sad', '#angry', -0.8, 'condemnatory', 'condemning', 'accusatory', 'accusing', 'inculpative']
senticnet['ace'] = [-0.049, 0.11, -0.057, 0.172, '#interesting', '#admirable', 0.059, 'heavy_paper', 'hard_paper', 'poker_hand', 'paper_square', 'gamble_game']
senticnet['acerbity'] = [-0.991, 0, 0.744, -0.74, '#sad', '#angry', -0.825, 'acidity', 'vinegariness', 'vinegarishness', 'tartness', 'taste_property']
senticnet['acetabulum'] = [0.681, -0.632, 0, 0.647, '#joyful', '#admirable', 0.653, 'hip_socket', 'tooth_socket', 'alveolus', 'socket', 'cotyloid_cavity']
senticnet['acetaminophen'] = [-0.985, 0, 0.601, -0.695, '#sad', '#disgusting', -0.76, 'hydromorphone_hydrochloride', 'hydromorphone', 'pain_pill', 'codeine', 'medicine']
senticnet['acetify'] = [-0.707, 0, 0.518, -0.514, '#sad', '#angry', -0.58, 'bitter', 'modify', 'acidulate', 'acidify', 'change_taste']
senticnet['acetone'] = [0.843, -0.958, 0, 0.648, '#joyful', '#surprising', 0.816, 'medium', 'dissolvent', 'propanone', 'dimethyl_ketone', 'chlorobenzene']
senticnet['ache'] = [-0.767, 0, -0.743, -0.716, '#sad', '#scared', -0.742, 'ouch', 'cut_skin', 'excruciate', 'dislocation', 'hurt']
senticnet['achene'] = [0, 0.141, 0.01, 0.115, '#interesting', '#admirable', 0.082, 'fruit', 'rind', 'funiculus', 'seed', 'pip']
senticnet['achievability'] = [-0.968, 0, 0.603, -0.915, '#sad', '#disgusting', -0.829, 'potential', 'potency', 'conceivableness', 'conceivability', 'possibleness']
senticnet['achievable'] = [0.036, 0.232, -0.057, 0.192, '#interesting', '#admirable', 0.134, 'money_spend', 'look_price', 'purchase', 'establish_credit', 'pay_debt']
senticnet['achieve'] = [0.981, 0.855, 0, 0.884, '#joyful', '#admirable', 0.907, 'attain_goal', 'permission', 'obtain', 'achieve_goal', 'take']
senticnet['achieve_goal'] = [0, 0.083, 0, 0.148, '#interesting', '#admirable', 0.077, 'mission_accomplished', 'maintenance', 'clean_often', 'vacuum_carpet', 'achievement']
senticnet['achievement'] = [0.177, 0.308, -0.065, 0.329, '#interesting', '#admirable', 0.25, 'good_work', 'benefit', 'positive_reinforcement', 'set_goal', 'accomplishment']
senticnet['achiever'] = [0.701, -0.596, 0, 0.908, '#joyful', '#admirable', 0.735, 'great', 'highflier', 'highflyer', 'natural', 'mortal']
senticnet['aching'] = [-0.74, 0, 0.872, -0.616, '#sad', '#angry', -0.743, 'hurting', 'bellyache', 'pain', 'headache', 'toothache']
senticnet['achromasia'] = [-0.665, 0, 0.782, -0.529, '#sad', '#angry', -0.659, 'lividness', 'pallidness', 'pallor', 'wanness', 'complexion']
senticnet['achromatic'] = [-0.7, 0, 0.617, -0.523, '#sad', '#angry', -0.613, 'silvery', 'blackish', 'bluish_black', 'hueless', 'pitchy']
senticnet['achromatic_color'] = [-0.749, 0, 0.876, -0.595, '#sad', '#angry', -0.74, 'inkiness', 'blackness', 'black', 'white', 'grayness']
senticnet['acid'] = [0.071, 0, -0.085, -0.09, '#scared', '#disgusting', -0.035, 'gunk', 'rotten_food', 'sour_cream', 'glass_of_milk', 'lemon_juice']
senticnet['acid_indigestion'] = [0, 0, -0.885, -0.765, '#scared', '#disgusting', -0.55, 'choke', 'become_full', 'get_full', 'burp', 'sickness']
senticnet['acidify'] = [-0.707, 0, 0.518, -0.514, '#sad', '#angry', -0.58, 'bitter', 'modify', 'acidulate', 'change_taste', 'acetify']
senticnet['acidity'] = [-0.991, 0, 0.744, -0.74, '#sad', '#angry', -0.825, 'acerbity', 'vinegariness', 'vinegarishness', 'tartness', 'taste_property']
senticnet['acidophil'] = [0.905, -0.659, 0, 0.851, '#joyful', '#admirable', 0.805, 'gonococcus', 'bacteria', 'bacteriae', 'probiotic', 'probiotic_bacterium']
senticnet['acidophile'] = [0.905, -0.659, 0, 0.851, '#joyful', '#admirable', 0.805, 'gonococcus', 'acidophil', 'bacteria', 'probiotic', 'probiotic_bacterium']
senticnet['acidophilus'] = [-0.998, 0, 0.987, -0.965, '#sad', '#angry', -0.983, 'lactobacillus', 'probiotic', 'probiotic_bacterium', 'probiotic_microflora', 'probiotic_flora']
senticnet['acidulate'] = [-0.707, 0, 0.518, -0.514, '#sad', '#angry', -0.58, 'bitter', 'modify', 'change_taste', 'acidify', 'acetify']
senticnet['acidulousness'] = [-0.78, 0, 0.969, -0.785, '#angry', '#disgusting', -0.845, 'acidity', 'sourness', 'taste', 'taste_sensation', 'gustatory_sensation']
senticnet['acknowledge'] = [-0.109, 0.242, -0.072, 0.165, '#interesting', '#admirable', 0.075, 'figure_out', 'polarize', 'reach_conclusion', 'think_process', 'arrive_conclusion']
senticnet['acknowledgeable'] = [0.935, -0.958, 0, 0.949, '#surprising', '#admirable', 0.947, 'identifiable', 'specifiable', 'recognizable', 'diagnosable', 'classifiable']
senticnet['acknowledged'] = [0.683, -0.553, 0, 0.552, '#joyful', '#surprising', 0.596, 'accepted', 'recognized', 'declarable', 'given', 'putative']
senticnet['acknowledgment'] = [0.98, 0.857, 0, 0.966, '#joyful', '#admirable', 0.934, 'sincere', 'brownie_point', 'positive_reinforcement', 'acceptance', 'mutual_understand']
senticnet['acne'] = [-0.983, 0, 0.969, -0.955, '#sad', '#angry', -0.969, 'ill_health', 'terminal_illness', 'physical_pain', 'trauma', 'car_wreck']
senticnet['acne_medication'] = [-0.745, 0, 0, -0.735, '#sad', '#disgusting', -0.493, 'skin_condition', 'adolescent', 'pimples', 'medical_treatment', 'prescription']
senticnet['acned'] = [-0.85, 0, 0.804, -0.855, '#sad', '#disgusting', -0.836, 'scarred', 'flyblown', 'marred', 'blemished', 'pimpled']
senticnet['acolyte'] = [-0.677, 0, 0.994, -0.503, '#sad', '#angry', -0.725, 'altar_boy', 'reverend', 'thurifer', 'clergyman', 'man_of_cloth']
senticnet['acorn_squash'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'squash', 'winter_squash', 'hubbard_squash', 'turban_squash', 'winter_squash_plant']
senticnet['acoustic_aphasia'] = [-0.82, 0, 0.953, -0.878, '#angry', '#disgusting', -0.884, 'auditory_aphasia', 'aphasia', 'word_deafness', 'nominal_aphasia', 'anomic_aphasia']
senticnet['acoustic_power'] = [0.695, -0.856, 0, 0.501, '#joyful', '#surprising', 0.684, 'sound_power', 'light_intensity', 'intensity', 'sound_pressure_level', 'threshold_level']
senticnet['acquaint'] = [0.649, -0.619, 0, 0.723, '#joyful', '#admirable', 0.664, 'bring_out', 'present', 'reintroduce', 'introduce', 'inform']
senticnet['acquire'] = [-0.048, 0.18, -0.094, 0.247, '#interesting', '#admirable', 0.095, 'obtain', 'satisfy_need', 'business_transaction', 'get_stuff', 'return_goods']
senticnet['acquire_goods'] = [0, 0.078, 0, 0.099, '#interesting', '#admirable', 0.059, 'exchange_money', 'buy_sell', 'sell', 'make_rich', 'sell_goods']
senticnet['acquire_information'] = [0.383, 0.246, -0.108, 0.256, '#joyful', '#admirable', 0.259, 'hear_opinion', 'information', 'stare', 'obtain', 'acquire']
senticnet['acquire_knowledge'] = [0.719, 0.757, 0, 0, '#joyful', '#interesting', 0.492, 'get_knowledge', 'gain_knowledge', 'increase_knowledge', 'expand_knowledge', 'become_intelligent']
senticnet['acquire_wealth'] = [0.881, 0.737, 0, 0.851, '#joyful', '#admirable', 0.823, 'financial_security', 'take_vacation', 'accomplish', 'human_race_survive', 'positive_reinforcement']
senticnet['acquirement'] = [0.967, -0.699, 0, 0.52, '#joyful', '#surprising', 0.729, 'marksmanship', 'oarsmanship', 'seamanship', 'swordsmanship', 'numeracy']
senticnet['acquisition'] = [0.679, -0.757, 0, 0.658, '#joyful', '#surprising', 0.698, 'moneymaking', 'heritage', 'purchase', 'assumption', 'restitution']
senticnet['acquisitiveness'] = [-0.5, 0, 0.939, -0.835, '#angry', '#disgusting', -0.758, 'avarice', 'covetousness', 'possessiveness', 'desire', 'greed']
senticnet['acquit'] = [0.799, -0.888, 0, 0.883, '#surprising', '#admirable', 0.857, 'pronounce', 'purge', 'whitewash', 'vindicate', 'label']
senticnet['acre'] = [0, 0.096, 0.009, 0.077, '#interesting', '#admirable', 0.055, 'acreage', 'cow_home', 'big_land', 'crop_place', 'large_land']
senticnet['acreage'] = [0, 0.122, 0, 0.123, '#interesting', '#admirable', 0.082, 'acre', 'cow_home', 'crop_place', 'big_land', 'animal_house']
senticnet['acrid'] = [-0.977, 0, -0.86, 0, '#sad', '#scared', -0.612, 'acid', 'pungent', 'acerb', 'acerbic', 'bitter']
senticnet['acridity'] = [-0.687, 0, 0.994, -0.549, '#sad', '#angry', -0.743, 'disagreeableness', 'acridness', 'unpleasantness', 'unpalatability', 'unpalatableness']
senticnet['acridness'] = [-0.687, 0, 0.994, -0.549, '#sad', '#angry', -0.743, 'acridity', 'disagreeableness', 'unpleasantness', 'unpalatability', 'unpalatableness']
senticnet['acrobat'] = [0.754, 0, 0, 0.861, '#joyful', '#admirable', 0.538, 'clown', 'juggler', 'swing', 'halloween', 'dare']
senticnet['acrobatic_feat'] = [-0.687, 0, 0.545, -0.688, '#sad', '#disgusting', -0.64, 'stunt', 'tumble', 'split', 'walkover', 'backbend']
senticnet['acrobatic_stunt'] = [-0.819, 0, 0.618, -0.564, '#sad', '#angry', -0.667, 'stunt', 'tumble', 'split', 'walkover', 'backbend']
senticnet['acromegalic'] = [-0.737, 0, 0.904, -0.531, '#sad', '#angry', -0.724, 'unshapely', 'shapeless', 'lumpy', 'deformed', 'malformed']
senticnet['act'] = [0.754, 0, 0, 0.861, '#joyful', '#admirable', 0.538, 'act_part', 'part_of_play', 'play_part', 'part_of_movie', 'role_play']
senticnet['act_bored'] = [-0.92, 0, 0, -0.906, '#sad', '#disgusting', -0.609, 'check_time', 'think_dog', 'finish_test', 'watch_other_person', 'master_skill']
senticnet['act_foolish'] = [-0.893, 0, 0.797, -0.958, '#sad', '#disgusting', -0.883, 'amount_nothing', 'lower_standard', 'box_ear', 'become_depressed', 'see_sky']
senticnet['act_out'] = [-0.127, 0, 0, -0.09, '#sad', '#disgusting', -0.072, 'listen_story', 'voice_opinion', 'promise_good', 'keep_word', 'state_obvious']
senticnet['act_part'] = [0, 0.981, 0, 0.775, '#interesting', '#admirable', 0.585, 'act', 'portray', 'part_of_play', 'imitate', 'play_part']
senticnet['act_play'] = [0.861, 0.928, 0, 0, '#joyful', '#interesting', 0.596, 'perform', 'go_stage', 'pretend', 'play_violin', 'play_guitar']
senticnet['act_quickly'] = [-0.092, 0.104, 0, 0.099, '#interesting', '#admirable', 0.037, 'use_leg', 'take_step', 'wear_running_shoes', 'wear_good_shoes', 'run_slowly']
senticnet['act_silly'] = [0.814, 0, 0, 0, '#joyful', '#joyful', 0.271, 'experience_joy', 'lift_spirit', 'plan_party', 'think_funny', 'sense_joy']
senticnet['act_smart'] = [0.814, 0, 0, 0, '#joyful', '#joyful', 0.271, 'smart', 'come_to_conclusion', 'focus_attention', 'find_answer', 'solve_mystery']
senticnet['act_stupid'] = [0, 0, 0.792, -0.733, '#angry', '#disgusting', -0.508, 'become_drunk', 'slur_word', 'disorientation', 'forgetfulness', 'hangover']
senticnet['act_up'] = [-0.161, 0, -0.091, -0.037, '#sad', '#scared', -0.096, 'throw_fit', 'watch_d', 'battle_illness', 'sun_oneself', 'honor_parent']
senticnet['act_wisely'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'president', 'teacher', 'respect', 'old_man', 'monk']
senticnet['acting'] = [0.916, 0.821, 0, 0, '#joyful', '#interesting', 0.579, 'good_imagination', 'rehearse', 'role_play', 'star_movie', 'become_actor']
senticnet['acting_out'] = [0.565, -0.792, 0, 0.959, '#surprising', '#admirable', 0.772, 'manifestation', 'cry', 'reflection', 'ebullition', 'explosion']
senticnet['actinic_dermatitis'] = [-0.726, 0, 0.778, -0.98, '#angry', '#disgusting', -0.828, 'dermatitis', 'hypericism', 'diaper_rash', 'diaper_dermatitis', 'seborrheic_dermatitis']
senticnet['actinotherapy'] = [0.789, -0.817, 0, 0.591, '#joyful', '#surprising', 0.732, 'radiotherapy', 'radiation_therapy', 'radiation', 'phototherapy', 'irradiation']
senticnet['action'] = [0, 0.73, 0, 0.922, '#interesting', '#admirable', 0.551, 'motion', 'manoeuvre', 'cause_change', 'movement', 'forceful']
senticnet['action_at_law'] = [0.804, -0.993, 0, 0.507, '#joyful', '#surprising', 0.768, 'antitrust_case', 'civil_action', 'counterclaim', 'custody_case', 'lis_pendens']
senticnet['action_figure'] = [0, -0.985, 0, 0.795, '#surprising', '#admirable', 0.593, 'toy_car', 'toy_soldier', 'beanie_baby', 'toy_marble', 'toy_ball']
senticnet['action_movie'] = [0, 0.951, 0, 0, '#interesting', '#interesting', 0.317, 'part_of_history', 'movie_genre', 'genre', 'fictional', 'horror_movie']
senticnet['activate'] = [0.724, 0.806, 0, 0, '#joyful', '#interesting', 0.51, 'initiate', 'trigger_off', 'get_going', 'do_it_yourself', 'operate']
senticnet['activated'] = [0.766, -0.875, 0, 0.666, '#joyful', '#surprising', 0.769, 'oxidizable', 'unstable', 'labile', 'reactive', 'excited']
senticnet['activating'] = [0.547, -0.692, 0, 0.52, '#joyful', '#surprising', 0.586, 'vivification', 'invigoration', 'activity', 'animation', 'electrification']
senticnet['activation_energy'] = [0.695, -0.856, 0, 0.501, '#joyful', '#surprising', 0.684, 'alternative_energy', 'energy', 'energy_of_activation', 'atomic_energy', 'nuclear_energy']
senticnet['active'] = [-0.035, 0.106, 0, 0.125, '#interesting', '#admirable', 0.065, 'push_up', 'healthy_activity', 'use_muscle', 'move_body', 'stamina']
senticnet['activeness'] = [0.681, -0.935, 0, 0.78, '#surprising', '#admirable', 0.799, 'behavior', 'state', 'play', 'agency', 'busyness']
senticnet['activewear'] = [-0.76, 0, 0.58, -0.507, '#sad', '#angry', -0.616, 'attire', 'garb', 'dress', 'gym_suit', 'running_suit']
senticnet['activist'] = [0.77, 0, 0, 0.96, '#joyful', '#admirable', 0.577, 'picket_sign', 'everyone_know', 'several_people', 'well_known', 'favorite']
senticnet['activity'] = [0, 0.099, -0.061, 0.231, '#interesting', '#admirable', 0.09, 'action', 'game_action', 'business', 'take_action', 'active']
senticnet['actor'] = [0, 0.909, 0, 0.958, '#interesting', '#admirable', 0.622, 'director', 'shooting_movie', 'director_chair', 'important_person', 'movie']
senticnet['actress'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'movie_star', 'actor', 'entertainer', 'performer', 'preview']
senticnet['actual'] = [0.032, 0.205, -0.118, 0.294, '#interesting', '#admirable', 0.138, 'electrical_unit', 'relevant', 'contemporary', 'particular', 'up_date']
senticnet['actual_eviction'] = [-0.873, 0, 0.765, -0.828, '#sad', '#disgusting', -0.822, 'due_process', 'due_process_of_law', 'ouster', 'retaliatory_eviction', 'dispossession']
senticnet['actus_reus'] = [-0.635, 0, 0.728, -0.588, '#sad', '#angry', -0.65, 'misconduct', 'inroad', 'wrongdoing', 'wrongful_conduct', 'usurpation']
senticnet['acuity'] = [0.959, -0.976, 0, 0.633, '#joyful', '#surprising', 0.856, 'oxyopia', 'sight', 'top', 'vision', 'visual_sense']
senticnet['acute_gastritis'] = [-0.959, 0, 0.729, -0.989, '#sad', '#disgusting', -0.892, 'chronic_gastritis', 'rubor', 'redness', 'gastritis', 'inflammation']
senticnet['acute_glossitis'] = [-0.638, 0, 0.961, -0.705, '#angry', '#disgusting', -0.768, 'glossitis', 'glossodynia_exfoliativa', 'rubor', 'redness', 'inflammation']
senticnet['acute_kidney_failure'] = [-0.603, 0, 0.544, -0.539, '#sad', '#angry', -0.562, 'acute_renal_failure', 'kidney_failure', 'chronic_renal_failure', 'chronic_kidney_failure', 'nephrosis']
senticnet['acute_renal_failure'] = [-0.603, 0, 0.544, -0.539, '#sad', '#angry', -0.562, 'kidney_failure', 'acute_kidney_failure', 'chronic_renal_failure', 'chronic_kidney_failure', 'nephrosis']
senticnet['acute_triangle'] = [0.763, -0.612, 0, 0.777, '#joyful', '#admirable', 0.717, 'triangle', 'wedge_shape', 'cuneus', 'wedge', 'oblique_triangle']
senticnet['adagio'] = [0.54, -0.575, 0, 0.678, '#surprising', '#admirable', 0.598, 'musical_composition', 'opus', 'composition', 'piece', 'piece_of_music']
senticnet['adam_and_eve'] = [0.783, 0.708, 0, 0, '#joyful', '#interesting', 0.497, 'eden', 'first_man', 'first_woman', 'religious', 'bible']
senticnet['adam_apple'] = [0, 0.102, 0, 0, '#interesting', '#interesting', 0.034, 'two_arms', 'belly_button', 'two_ears', 'five_fingers_hand', 'human']
senticnet['adamance'] = [-0.975, 0, 0.549, -0.978, '#sad', '#disgusting', -0.834, 'firmness', 'resolve', 'resoluteness', 'firmness_of_purpose', 'resolution']
senticnet['adamant'] = [-0.806, 0, 0.507, -0.763, '#sad', '#disgusting', -0.692, 'inflexible', 'inexorable', 'intransigent', 'ironclad', 'brassbound']
senticnet['adapt'] = [-0.038, 0.086, 0, 0.114, '#interesting', '#admirable', 0.054, 'deduce', 'figure_out', 'arrive_conclusion', 'come_conclusion', 'come_up_new_idea']
senticnet['adaptability'] = [0.873, -0.943, 0, 0.74, '#joyful', '#surprising', 0.852, 'ability', 'flexibility', 'flexibleness', 'pliancy', 'pliantness']
senticnet['add'] = [0, 0.145, 0.056, 0.197, '#interesting', '#admirable', 0.095, 'subtraction', 'equal', 'mathematical_operation', 'math_action', 'factor']
senticnet['add_flavor'] = [0.04, 0, 0, 0.067, '#joyful', '#admirable', 0.036, 'cook', 'food', 'taste', 'ingredient', 'tongue']
senticnet['add_knowledge'] = [0.757, 0, 0, 0, '#joyful', '#joyful', 0.252, 'become_smart', 'learn', 'increase_knowledge', 'gain_knowledge', 'great_understand']
senticnet['add_number'] = [0, 0.951, 0, 0, '#interesting', '#interesting', 0.317, 'enter_data_computer', 'train_open_mind', 'write_computer_program', 'add_two_numbers_together', 'calculation']
senticnet['add_number_together'] = [0, 0.27, 0.014, 0.133, '#interesting', '#admirable', 0.13, 'add_two_numbers_together', 'learn_add', 'get_total', 'get_answer', 'sharpen_pencil']
senticnet['add_on'] = [0.846, -0.765, 0, 0.688, '#joyful', '#surprising', 0.766, 'further', 'promote', 'encourage', 'boost', 'advance']
senticnet['add_spice'] = [0, -0.01, 0.014, -0.102, '#angry', '#disgusting', -0.035, 'burp', 'prepare_ingredient', 'say_grace', 'measure_ingredient', 'swallow_food']
senticnet['add_sugar'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'sugar', 'drink_tea', 'drink_coffee', 'cake', 'sweet']
senticnet['add_two_numbers'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'delight_audience', 'amuse_child', 'bounce_up_down', 'go_game', 'play_on_grass']
senticnet['add_two_numbers_together'] = [0.973, 0.937, 0, 0, '#joyful', '#interesting', 0.637, 'get_sum', 'get_total', 'find_total', 'add_number_together', 'find_number']
senticnet['add_up_column_number'] = [0, 0.083, 0.039, 0.074, '#interesting', '#admirable', 0.039, 'compute_sum', 'add_up_number', 'calculate_quickly', 'program_computer', 'write_program']
senticnet['add_up_number'] = [0.04, 0, 0, 0.067, '#joyful', '#admirable', 0.036, 'compute_sum', 'add_up_column_number', 'calculate_quickly', 'program_computer', 'write_program']
senticnet['added_value'] = [0, 0.197, 0.056, 0.177, '#interesting', '#admirable', 0.106, 'advance_career', 'total', 'four_quarters', 'root_evil', 'total_number']
senticnet['adder'] = [-0.96, 0, 0.865, -0.753, '#sad', '#angry', -0.859, 'gaboon_viper', 'ophidian', 'serpent', 'snake', 'viper']
senticnet['addict'] = [-0.921, -0.815, 0.972, 0, '#sad', '#angry', -0.359, 'health_problem', 'overpay', 'ill_health', 'diabetes', 'terrify']
senticnet['addicted'] = [-0.752, 0.288, -0.434, -0.058, '#sad', '#scared', -0.319, 'obsession', 'obsessed_love', 'addiction', 'stalker', 'weird']
senticnet['addicted_computer_games'] = [-0.969, 0, 0.172, -0.997, '#sad', '#disgusting', -0.713, 'nerd', 'wear_glasses', 'geek', 'big_glasses', 'computer_lover']
senticnet['addiction'] = [-0.766, 0, 0, -0.95, '#sad', '#disgusting', -0.572, 'smoke', 'drug', 'embarrassment', 'cigarette', 'disappointment']
senticnet['addictive'] = [-0.774, 0, 0.776, -0.8, '#angry', '#disgusting', -0.783, 'just_fun', 'profitable', 'dangerous_drive', 'taboo', 'competitive']
senticnet['addition'] = [-0.034, 0.214, 0.043, 0.209, '#interesting', '#admirable', 0.115, 'add', 'sum', 'list_number', 'multiplication', 'arithmetic']
senticnet['addle'] = [-0.569, 0, 0.738, -0.615, '#angry', '#disgusting', -0.641, 'mix_up', 'muddle', 'puddle', 'assemble', 'piece']
senticnet['addlehead'] = [-0.997, 0, 0.804, -0.523, '#sad', '#angry', -0.775, 'misfit', 'birdbrain', 'ape', 'loon', 'mortal']
senticnet['address'] = [0.038, 0, 0, 0.097, '#joyful', '#admirable', 0.045, 'place', 'wigwam', 'abide', 'post', 'property']
senticnet['address_book'] = [0.038, 0, 0, 0.097, '#joyful', '#admirable', 0.045, 'blank_check', 'glue_stick', 'post-it_note', 'ball_point_pen', 'paper_clip']
senticnet['address_envelope'] = [-0.127, 0, 0, -0.068, '#sad', '#disgusting', -0.065, 'put_envelope', 'make_note', 'store_pen', 'make_mark_paper', 'write_word']
senticnet['address_label'] = [0.058, -0.049, 0, 0, '#joyful', '#surprising', 0.036, 'letter_slot', 'envelope', 'pamphlet', 'mailman', 'postage_stamp']
senticnet['adenoma'] = [-0.704, 0, 0.639, -0.56, '#sad', '#angry', -0.634, 'fibroma', 'benign_tumor', 'chondroma', 'enchondroma', 'myoma']
senticnet['adenosine'] = [0, 0.9, 0, 0.719, '#interesting', '#admirable', 0.54, 'biochemistry', 'water', 'make_up_water', 'large_body', 'water_spill']
senticnet['adenosis'] = [-0.533, 0, 0.667, -0.556, '#angry', '#disgusting', -0.585, 'exophthalmic_goiter', 'glandular_disease', 'gland_disease', 'glandular_disorder', 'thyrotoxicosis']
senticnet['adenozine'] = [0, 0.799, 0, 0.72, '#interesting', '#admirable', 0.506, 'water', 'make_up_water', 'large_body', 'water_spill', 'cover_water']
senticnet['adept'] = [0, 0.933, 0, 0.768, '#interesting', '#admirable', 0.567, 'virtuoso', 'genius', 'expert', 'proficient', 'skillful']
senticnet['adeptness'] = [0.703, -0.8, 0, 0.691, '#joyful', '#surprising', 0.731, 'skillfulness', 'touch', 'dexterity', 'manual_dexterity', 'sleight']
senticnet['adequacy'] = [-0.997, 0, 0.878, -0.957, '#sad', '#disgusting', -0.944, 'satisfactoriness', 'adequateness', 'acceptability', 'acceptableness', 'quality']
senticnet['adequate'] = [0.889, -0.904, 0, 0.559, '#joyful', '#surprising', 0.784, 'competent', 'up_to', 'adequate_to', 'equal_to', 'capable']
senticnet['adequate_to'] = [0.889, -0.904, 0, 0.559, '#joyful', '#surprising', 0.784, 'competent', 'up_to', 'adequate', 'equal_to', 'capable']
senticnet['adequateness'] = [-0.997, 0, 0.878, -0.957, '#sad', '#disgusting', -0.944, 'adequacy', 'satisfactoriness', 'acceptability', 'acceptableness', 'quality']
senticnet['adhere'] = [0.105, -0.178, 0.057, 0.079, '#joyful', '#surprising', 0.102, 'stick', 'adhesive', 'follow', 'believe_in', 'glue']
senticnet['adhesion_contract'] = [0.865, -0.844, 0, 0.915, '#joyful', '#admirable', 0.875, 'grant', 'sale_in_gross', 'contract_of_hazard', 'contract', 'contract_of_adhesion']
senticnet['adhesive'] = [0, 0, 0.778, -0.832, '#angry', '#disgusting', -0.537, 'sticky_substance', 'gummy', 'insert', 'viscous', 'sticky']
senticnet['adhesive_bandage'] = [-0.919, 0, 0, -0.884, '#sad', '#disgusting', -0.601, 'bandage', 'painkiller', 'gauze', 'aspirin', 'contraceptive_device']
senticnet['adiabatic_process'] = [-0.643, 0, 0.938, -0.521, '#sad', '#angry', -0.701, 'extinction', 'thermodynamic_process', 'hardening', 'decay', 'absorption']
senticnet['adience'] = [-0.637, 0, 0.677, -0.948, '#angry', '#disgusting', -0.754, 'motive', 'need', 'motivation', 'abience', 'impulse']
senticnet['adipic_acid'] = [-0.652, 0, 0.935, -0.968, '#angry', '#disgusting', -0.852, 'acid', 'hexanedioic_acid', 'carboxylic_acid', 'succinic_acid', 'valeric_acid']
senticnet['adjoin'] = [-0.748, 0, 0.627, -0.589, '#sad', '#angry', -0.655, 'touch', 'contact', 'meet', 'neighbor', 'butt_against']
senticnet['adjust'] = [0.033, 0.234, -0.084, 0.274, '#interesting', '#admirable', 0.152, 'change', 'transform', 'modifier', 'precise', 'versatile']
senticnet['adjust_clothes'] = [-0.091, 0, 0, -0.063, '#sad', '#disgusting', -0.051, 'plan_day', 'get_stick_traffic', 'rush_work', 'out_car', 'meet_old_friend']
senticnet['adjust_seat'] = [0, 0.098, 0, 0.107, '#interesting', '#admirable', 0.068, 'check_mirror', 'fasten_seatbelt', 'turn_engine', 'change_gear', 'put_key_ignition']
senticnet['adjust_volume'] = [0, 0, 0.831, -0.903, '#angry', '#disgusting', -0.578, 'sound_level', 'speakers', 'noisy', 'making_a_lot_of_noise', 'hear_song']
senticnet['adjust_water_temperature'] = [-0.091, 0, 0, 0, '#sad', '#sad', -0.03, 'water_garden', 'water_lawn', 'heater', 'shower', 'cook']
senticnet['adjustable'] = [0.102, 0.078, 0, 0.087, '#joyful', '#admirable', 0.089, 'gold', 'platinum', 'iron_ore', 'silver', 'magnetic']
senticnet['adjustable_wrench'] = [0, 0.098, 0, 0.107, '#interesting', '#admirable', 0.068, 'power_drill', 'air_pump', 'drill_bite', 'type_of_machine', 'drill']
senticnet['adjusted'] = [-0.623, 0, 0.657, -0.955, '#angry', '#disgusting', -0.745, 'paraphrastic', 'altered', 'changed', 'emended', 'edited']
senticnet['adjustment'] = [0.735, -0.714, 0, 0.566, '#joyful', '#surprising', 0.672, 'improvement', 'betterment', 'habituation', 'domestication', 'shakedown']
senticnet['administrable'] = [0.5, -0.9, 0, 0.525, '#surprising', '#admirable', 0.642, 'manageable', 'controllable', 'governable', 'steerable', 'dirigible']
senticnet['administration'] = [0.039, 0.145, 0, 0.142, '#interesting', '#admirable', 0.109, 'hierarchy', 'position', 'order', 'march_rear', 'rule']
senticnet['administrative_district'] = [0.858, -0.891, 0, 0.719, '#joyful', '#surprising', 0.823, 'mandatory', 'district', 'administrative_division', 'territorial_division', 'borderland']
senticnet['administrative_division'] = [0.858, -0.891, 0, 0.719, '#joyful', '#surprising', 0.823, 'mandatory', 'administrative_district', 'district', 'territorial_division', 'borderland']
senticnet['administrator'] = [-0.801, 0, 0.522, -0.83, '#sad', '#disgusting', -0.718, 'head', 'executive', 'executive_director', 'chief', 'academic_administrator']
senticnet['admirable'] = [0.575, 0.636, -0.268, 0.318, '#joyful', '#interesting', 0.42, 'laudably', 'admirably', 'praiseworthily', 'commendable', 'look_up_to']
senticnet['admirably'] = [0.575, 0.636, -0.268, 0.318, '#joyful', '#interesting', 0.42, 'laudably', 'praiseworthily', 'commendable', 'look_up_to', 'admirable']
senticnet['admiral'] = [0.688, -0.908, 0, 0.877, '#surprising', '#admirable', 0.824, 'fleet_flag_officer', 'rear_flag_officer', 'flag_officer', 'full_flag_officer', 'vice_flag_officer']
senticnet['admiration'] = [0, 0, 0, 1, '#admirable', '#admirable', 0.333, 'awe', 'dazed', 'stun', 'stunned', 'stupefied']
senticnet['admire'] = [0, 0, 0, 0.705, '#admirable', '#admirable', 0.235, 'positive', 'confidence', 'sympathetic', 'regard', 'fellow_feeling']
senticnet['admired'] = [0.59, -0.815, 0, 0.571, '#joyful', '#surprising', 0.659, 'preferred', 'wanted', 'loved', 'darling', 'precious']
senticnet['admirer'] = [0.814, -0.508, 0, 0.622, '#joyful', '#admirable', 0.648, 'friend', 'champion', 'supporter', 'protagonist', 'endorser']
senticnet['admission'] = [0, 0.175, -0.13, 0.204, '#interesting', '#admirable', 0.083, 'door', 'control_access', 'gate', 'corridor', 'let_in']
senticnet['admit'] = [0, 0, 0, 0.852, '#admirable', '#admirable', 0.284, 'aye', 'allow', 'promise', 'cope', 'accept']
senticnet['admonishing'] = [-0.74, 0, 0.982, -0.819, '#angry', '#disgusting', -0.847, 'inauspicious', 'unfavorable', 'reproachful', 'reproving', 'untoward']
senticnet['admonishment'] = [0.609, -0.686, 0, 0.951, '#surprising', '#admirable', 0.749, 'rebuke', 'reproof', 'reproval', 'reprehension', 'reprimand']
senticnet['admonitory'] = [0, 0, -0.853, -0.928, '#scared', '#disgusting', -0.594, 'reproachful', 'admonishing', 'exemplary', 'warning', 'cautionary']
senticnet['adobe'] = [0.962, -0.703, 0, 0.522, '#joyful', '#surprising', 0.729, 'brick', 'stack_brick', 'clinker', 'clinker_brick', 'firebrick']
senticnet['adobe_brick'] = [0.962, -0.703, 0, 0.522, '#joyful', '#surprising', 0.729, 'adobe', 'brick', 'clinker', 'clinker_brick', 'firebrick']
senticnet['adolescence'] = [0, 0.788, 0, 0.86, '#interesting', '#admirable', 0.549, 'child', 'enjoy_time', 'youth', 'smile_child', 'open_mind']
senticnet['adolescent'] = [0.029, 0.076, 0, 0, '#joyful', '#interesting', 0.035, 'youngster', 'teenager', 'junior', 'lad', 'maturity']
senticnet['adopt'] = [0.788, 0.739, 0, 0, '#joyful', '#interesting', 0.509, 'foster_kid', 'daughter', 'relation', 'sister', 'cousin']
senticnet['adopt_child'] = [0.793, 0, 0, 0.845, '#joyful', '#admirable', 0.546, 'mommy', 'father_child', 'mother_child', 'kinship', 'father_son']
senticnet['adorable'] = [0.936, -0.815, 0, 0.83, '#joyful', '#admirable', 0.86, 'cherubic', 'lovely', 'lovable', 'endearing', 'angelic']
senticnet['adorably'] = [0.494, 0.673, -0.269, 0.25, '#joyful', '#interesting', 0.383, 'loving', 'lovingly', 'fondly', 'endearingly', 'devotedness']
senticnet['adoration'] = [0.732, 0.868, 0, 0.762, '#interesting', '#admirable', 0.787, 'confident', 'fondness', 'kindly', 'benevolent', 'charitable']
senticnet['adore'] = [0.703, 0, 0, 0.854, '#joyful', '#admirable', 0.519, 'beloved', 'show_support', 'find_woman', 'show_empathy', 'love_oneself']
senticnet['adoring'] = [0.524, 0.681, -0.278, 0.281, '#joyful', '#interesting', 0.403, 'worshipful', 'devotedness', 'devoted', 'amorousness', 'amorous']
senticnet['adorn'] = [0.053, -0.013, -0.052, 0.121, '#joyful', '#admirable', 0.045, 'coat', 'winter_clothes', 'stylish', 'outerwear', 'protective_cover']
senticnet['adorned'] = [0.613, -0.532, 0, 0.932, '#joyful', '#admirable', 0.692, 'buttony', 'ruffled', 'fringed', 'tessellated', 'mounted']
senticnet['adornment'] = [0.059, 0, 0, 0.161, '#joyful', '#admirable', 0.073, 'accessory', 'make_gold', 'piece_of_jewelry', 'gold', 'jewel']
senticnet['adrenal_cortical_steroid'] = [-0.763, 0, 0.681, -0.578, '#sad', '#angry', -0.674, 'corticosteroid', 'corticoid', 'spironolactone', 'antihypertensive', 'antihypertensive_drug']
senticnet['adrenalin'] = [0.672, -0.552, 0, 0.992, '#joyful', '#admirable', 0.739, 'pressor', 'hormone', 'endocrine', 'internal_secretion', 'catecholamine']
senticnet['adrenaline'] = [0.958, -0.724, 0, 0.72, '#joyful', '#surprising', 0.801, 'pressor', 'hormone', 'endocrine', 'internal_secretion', 'catecholamine']
senticnet['adrenergic'] = [0.887, -0.9, 0, 0.852, '#joyful', '#surprising', 0.88, 'pressor', 'phenylephrine', 'phenylpropanolamine', 'vasoconstrictor', 'vasoconstrictive']
senticnet['adrenergic_drug'] = [0.601, -0.667, 0, 0.827, '#surprising', '#admirable', 0.698, 'pressor', 'phenylephrine', 'phenylpropanolamine', 'vasoconstrictor', 'vasoconstrictive']
senticnet['adrenocorticotrophic'] = [0.95, -0.951, 0, 0.769, '#joyful', '#surprising', 0.89, 'adrenocorticotropic', 'stimulative', 'stimulant', 'stimulating', 'excitant']
senticnet['adrenocorticotropic'] = [0.95, -0.951, 0, 0.769, '#joyful', '#surprising', 0.89, 'stimulative', 'adrenocorticotrophic', 'stimulant', 'stimulating', 'excitant']
senticnet['adrift'] = [-0.997, 0, 0.658, -0.736, '#sad', '#disgusting', -0.797, 'purposeless', 'afloat', 'aimless', 'directionless', 'planless']
senticnet['adroit'] = [0.738, -0.965, 0, 0.727, '#joyful', '#surprising', 0.81, 'ingenious', 'clever', 'cunning', 'clean', 'neat']
senticnet['adroitness'] = [0.966, -0.879, 0, 0.78, '#joyful', '#surprising', 0.875, 'skillfulness', 'touch', 'dexterity', 'manual_dexterity', 'sleight']
senticnet['ads'] = [0.08, 0.153, -0.125, 0.224, '#interesting', '#admirable', 0.111, 'advertisment', 'informative', 'introduction', 'media', 'ephemeral']
senticnet['adscititious'] = [-0.732, 0, 0.899, -0.765, '#angry', '#disgusting', -0.799, 'extraneous', 'alien', 'adventitious', 'foreign', 'extrinsic']
senticnet['adulate'] = [-0.106, 0, -0.053, -0.24, '#sad', '#disgusting', -0.133, 'blandish', 'suck_up', 'toady', 'bootlick', 'kowtow']
senticnet['adult'] = [0.72, 0, 0, 0.879, '#joyful', '#admirable', 0.533, 'friendship', 'friend', 'companion', 'rely_on_other_person', 'fully_developed']
senticnet['adult_drink'] = [-0.27, 0, -0.293, 0, '#sad', '#scared', -0.188, 'drink_alcohol', 'alcoholic_drink', 'alcoholic_beverage', 'strong_drink', 'booze']
senticnet['adulterate'] = [-0.897, 0, 0.89, -0.775, '#sad', '#angry', -0.854, 'doctor', 'doctor_up', 'corrupt', 'spoil', 'sophisticate']
senticnet['adulteration'] = [0, 0, 0.894, -0.744, '#angry', '#disgusting', -0.546, 'debasement', 'dirtiness', 'pollution', 'taint', 'impureness']
senticnet['adulterer'] = [-0.544, 0, 0.691, -0.966, '#angry', '#disgusting', -0.734, 'slut', 'trollop', 'libertine', 'adulteress', 'fornicatress']
senticnet['adulteress'] = [-0.544, 0, 0.691, -0.966, '#angry', '#disgusting', -0.734, 'slut', 'trollop', 'libertine', 'adulterer', 'fornicatress']
senticnet['adultery'] = [-0.27, 0, -0.293, 0, '#sad', '#scared', -0.188, 'marriage', 'marry', 'care', 'affair', 'precaution']
senticnet['advance'] = [-0.072, 0.227, -0.131, 0.203, '#interesting', '#admirable', 0.076, 'progress', 'lunge', 'go_forth', 'meander', 'go_ahead']
senticnet['advance_battle'] = [0.972, 0.986, 0, 0, '#joyful', '#interesting', 0.653, 'join_army', 'fight_war', 'fight_enemy', 'wage_war', 'storm_fortress']
senticnet['advance_career'] = [0, 0.197, 0.056, 0.177, '#interesting', '#admirable', 0.106, 'added_value', 'total', 'four_quarters', 'root_evil', 'total_number']
senticnet['advance_civilization'] = [0, 0.08, 0, 0.117, '#interesting', '#admirable', 0.066, 'stand_still', 'go_home', 'pull_out', 'stretch_out', 'civilization']
senticnet['advance_knowledge'] = [0.044, 0.297, -0.253, 0.281, '#interesting', '#admirable', 0.123, 'knowledge', 'trivia', 'gain_insight', 'seek_answer', 'understand']
senticnet['advance_next_level'] = [0.706, 0, 0, 0.712, '#joyful', '#admirable', 0.473, 'get_grade', 'succeed', 'pass_grade', 'relaxation', 'graduate_school']
senticnet['advanced'] = [0.795, 0.866, 0, 0, '#joyful', '#interesting', 0.554, 'progress', 'innovative', 'modern', 'sophisticated', 'ripe']
senticnet['advancement'] = [0.856, 0, 0, 0.963, '#joyful', '#admirable', 0.606, 'progress', 'get_better_job', 'further_career', 'graduate_school', 'get_diploma']
senticnet['advantage'] = [0.733, 0.991, 0, 0.843, '#interesting', '#admirable', 0.856, 'improvement', 'gain', 'return', 'receive', 'contribution']
senticnet['advantageous'] = [0.53, -0.559, 0, 0.912, '#surprising', '#admirable', 0.667, 'beneficial', 'positive', 'good', 'plus', 'discriminatory']
senticnet['advantageousness'] = [0.854, -0.794, 0, 0.977, '#joyful', '#admirable', 0.875, 'profitableness', 'favorableness', 'favourableness', 'auspiciousness', 'positivity']
senticnet['adventitious'] = [-0.732, 0, 0.899, -0.765, '#angry', '#disgusting', -0.799, 'extraneous', 'alien', 'extrinsic', 'foreign', 'adscititious']
senticnet['adventure'] = [0, -0.779, 0, 0.761, '#surprising', '#admirable', 0.513, 'quest', 'stunt', 'illusion', 'journey', 'activity']
senticnet['adventurer'] = [0.703, 0.913, 0, 0.701, '#joyful', '#interesting', 0.772, 'discovery', 'egalitarian', 'pioneer', 'correspondent', 'humankind']
senticnet['adventuresome'] = [0.706, -0.87, 0, 0.968, '#surprising', '#admirable', 0.848, 'audacious', 'swaggering', 'daring', 'venturesome', 'venturous']
senticnet['adventurism'] = [0.828, -0.675, 0, 0.811, '#joyful', '#admirable', 0.771, 'foolhardiness', 'brashness', 'thoughtlessness', 'desperation', 'unthoughtfulness']
senticnet['adventurous'] = [0.626, -0.787, 0, 0.611, '#joyful', '#surprising', 0.675, 'audacious', 'swaggering', 'daring', 'venturesome', 'venturous']
senticnet['adversative'] = [-0.668, 0, 0.502, -0.796, '#sad', '#disgusting', -0.655, 'disjunctive', 'oppositive', 'contrastive', 'alternative', 'separative']
senticnet['adversity'] = [-0.165, 0.131, -0.283, 0, '#sad', '#scared', -0.106, 'danger', 'jeopardy', 'problem', 'impend_danger', 'intolerance']
senticnet['advert'] = [-0.978, 0, 0.692, -0.641, '#sad', '#angry', -0.77, 'name', 'bring_up', 'mention', 'drag_up', 'cite']
senticnet['advertise_company'] = [0.856, 0, 0, 0.963, '#joyful', '#admirable', 0.606, 'advertise_product', 'media', 'advertise_panel', 'money', 'company']
senticnet['advertise_panel'] = [0.087, 0.08, 0.013, 0, '#joyful', '#interesting', 0.051, 'advertise_company', 'billboard', 'underground_map', 'neighborhood_map', 'restaurant_entrance']
senticnet['advertise_product'] = [0.866, 0, 0, 0, '#joyful', '#joyful', 0.289, 'report_crime', 'page_through_book', 'check_mail', 'find_book_library', 'receive_email']
senticnet['advertisement'] = [0.956, 0.713, 0, 0, '#joyful', '#interesting', 0.556, 'marketing', 'sales', 'announcement', 'billboard', 'promotion']
senticnet['advertisment'] = [-0.023, 0, -0.101, 0, '#sad', '#scared', -0.041, 'ads', 'boring', 'bother', 'stop_watch', 'annoying']
senticnet['advice'] = [0.986, 0, 0, 0.862, '#joyful', '#admirable', 0.616, 'plea', 'charity', 'agreement', 'contribution', 'offer']
senticnet['advise'] = [-0.032, 0.315, -0.169, 0.261, '#interesting', '#admirable', 0.125, 'tell_everyone', 'choice', 'explanation', 'identify', 'help_find']
senticnet['advisory'] = [0.795, -0.977, 0, 0.679, '#joyful', '#surprising', 0.817, 'informatory', 'consultative', 'consultatory', 'consultive', 'revealing']
senticnet['advocate'] = [0.677, -0.529, 0, 0.714, '#joyful', '#admirable', 0.64, 'economic_libertarian', 'civil_libertarian', 'libertarian', 'advocator', 'proponent']
senticnet['advocator'] = [0.677, -0.529, 0, 0.714, '#joyful', '#admirable', 0.64, 'economic_libertarian', 'civil_libertarian', 'advocate', 'libertarian', 'proponent']
senticnet['aeonian'] = [-0.954, 0, 0.808, -0.613, '#sad', '#angry', -0.792, 'everlasting', 'standing', 'imperishable', 'enduring', 'lasting']
senticnet['aerial'] = [0.16, 0.067, 0, 0.083, '#joyful', '#admirable', 0.103, 'antenna', 'sensory', 'arthropods', 'insect', 'connection']
senticnet['aerial_bomb'] = [0, 0, -0.902, -0.846, '#scared', '#disgusting', -0.583, 'grenade', 'weapon', 'bomb', 'cannon', 'machine_gun']
senticnet['aerobic_exercise'] = [0, 0.08, 0, 0.117, '#interesting', '#admirable', 0.066, 'exercise', 'healthy_exercise', 'good_environment', 'make_strong', 'want_exercise']
senticnet['aeroplane'] = [-0.048, 0.105, -0.061, 0.115, '#interesting', '#admirable', 0.037, 'airplane', 'pilot', 'air_traffic', 'sky', 'jet']
senticnet['aesthesia'] = [0.638, -0.996, 0, 0.631, '#joyful', '#surprising', 0.755, 'awareness', 'ego', 'state_of_mind', 'conscious', 'consciousness']
senticnet['aesthesis'] = [-0.586, 0, 0.568, -0.973, '#sad', '#disgusting', -0.709, 'masking', 'taste', 'threshold', 'perception', 'limen']
senticnet['aesthetic'] = [0.737, -0.854, 0, 0.623, '#joyful', '#surprising', 0.738, 'understated', 'esthetic', 'tasteful', 'artistic', 'unostentatious']
senticnet['aesthetical'] = [0.596, -0.64, 0, 0.945, '#surprising', '#admirable', 0.727, 'cosmetic', 'painterly', 'sensuous', 'artistic', 'enhancive']
senticnet['aesthetics'] = [0.074, 0.138, 0, 0.104, '#interesting', '#admirable', 0.105, 'make_furniture', 'please_eye', 'reflect_light', 'yellow_orange', 'decorative']
senticnet['afar'] = [-0.853, 0, 0, -0.734, '#sad', '#disgusting', -0.529, 'long_distance', 'compass_direction', 'distance', 'away', 'long_distance_relationship']
senticnet['affability'] = [0.593, -0.658, 0, 0.711, '#surprising', '#admirable', 0.654, 'sweetness_and_light', 'condescension', 'condescendingness', 'mellowness', 'friendliness']
senticnet['affableness'] = [0.747, -0.971, 0, 0.917, '#surprising', '#admirable', 0.878, 'sweetness_and_light', 'condescension', 'condescendingness', 'mellowness', 'friendliness']
senticnet['affair'] = [-0.777, 0, 0.965, 0, '#sad', '#angry', -0.581, 'intrigue', 'love_affair', 'divorce', 'betrayal', 'adultery']
senticnet['affaire'] = [0.692, -0.992, 0, 0.614, '#joyful', '#surprising', 0.766, 'intimacy', 'sexual_relationship', 'liaison', 'affair', 'involvement']
senticnet['affect'] = [0.884, 0, 0, 0.811, '#joyful', '#admirable', 0.565, 'attachment', 'fond_regard', 'anticipation', 'protectiveness', 'love']
senticnet['affected'] = [0, 0, 0.891, -0.836, '#angry', '#disgusting', -0.576, 'pretended', 'feigned', 'false', 'fake', 'sham']
senticnet['affectedness'] = [-0.562, 0, 0.757, -0.991, '#angry', '#disgusting', -0.77, 'unnaturalness', 'airs', 'pose', 'coyness', 'demureness']
senticnet['affection'] = [0.826, 0.945, 0, 0.796, '#joyful', '#interesting', 0.856, 'wonderful_feeling', 'gratitude', 'like', 'admire', 'desire']
senticnet['affectional'] = [0.461, 0.674, -0.262, 0.247, '#joyful', '#interesting', 0.373, 'affect', 'warmness', 'philia', 'affective', 'emotive']
senticnet['affectionate'] = [0.851, 0, 0, 0.886, '#joyful', '#admirable', 0.579, 'devoted', 'fond', 'warm', 'caring', 'tenderness']
senticnet['affectionateness'] = [0.461, 0.674, -0.262, 0.247, '#joyful', '#interesting', 0.373, 'warmness', 'philia', 'affectional', 'affective', 'emotive']
senticnet['affective'] = [0.461, 0.674, -0.262, 0.247, '#joyful', '#interesting', 0.373, 'affectionateness', 'warmness', 'philia', 'affectional', 'emotive']
senticnet['affective_disorder'] = [-0.618, 0, 0.934, -0.628, '#angry', '#disgusting', -0.727, 'manic_disorder', 'bipolar_disorder', 'manic_depression', 'manic_depressive_illness', 'depression']
senticnet['affinity'] = [0.784, 0, 0, 0.974, '#joyful', '#admirable', 0.586, 'resemblance', 'mutual_resemblance', 'alikeness', 'likeness', 'similitude']
senticnet['affirm'] = [0.854, -0.703, 0, 0.912, '#joyful', '#admirable', 0.823, 'shew', 'verify', 'back', 'prove', 'demonstrate']
senticnet['affirmation'] = [0.731, 0, 0, 0.96, '#joyful', '#admirable', 0.564, 'ask', 'inquiry', 'plea', 'suggest', 'question_start']
senticnet['affirmative'] = [0.585, 0.652, -0.268, 0.313, '#joyful', '#interesting', 0.427, 'approbative', 'approve', 'approbatory', 'plausive', 'approved']
senticnet['affirmativeness'] = [0.604, -0.576, 0, 0.935, '#joyful', '#admirable', 0.705, 'agreeability', 'deference', 'compliance', 'disposition', 'complaisance']
senticnet['affixed'] = [0.993, -0.893, 0, 0.891, '#joyful', '#surprising', 0.926, 'mounted', 'appendant', 'basifixed', 'glued', 'pasted']
senticnet['afflict'] = [-0.743, 0, 0.622, -0.867, '#sad', '#disgusting', -0.744, 'tribulate', 'upset', 'grieve', 'disconcert', 'aggrieve']
senticnet['affliction'] = [-0.912, 0, 0.921, -0.733, '#sad', '#angry', -0.855, 'crown_of_thorns', 'adversity', 'hardship', 'hard_knocks', 'cross']
senticnet['afford'] = [-0.041, 0.292, -0.106, 0.173, '#interesting', '#admirable', 0.106, 'owe', 'debit', 'payment', 'expense', 'severance']
senticnet['affray'] = [-0.818, 0, 0.52, -0.875, '#sad', '#disgusting', -0.738, 'batrachomyomachia', 'wrangle', 'dustup', 'quarrel', 'row']
senticnet['affright'] = [-0.954, 0, -0.729, 0, '#sad', '#scared', -0.561, 'frightened', 'scared', 'daunt', 'scare_off', 'frighten_off']
senticnet['affront'] = [-0.927, 0, 0.699, -0.936, '#sad', '#disgusting', -0.854, 'discourtesy', 'offense', 'outrage', 'scandalization', 'indignity']
senticnet['aficionado'] = [0.703, -0.513, 0, 0.811, '#joyful', '#admirable', 0.676, 'enthusiast', 'partizan', 'partisan', 'rooter', 'railbird']
senticnet['afire'] = [0.641, -0.733, 0, 0.798, '#surprising', '#admirable', 0.724, 'ablaze', 'aflame', 'lighted', 'aflare', 'alight']
senticnet['aflame'] = [0.641, -0.733, 0, 0.798, '#surprising', '#admirable', 0.724, 'ablaze', 'lighted', 'afire', 'aflare', 'alight']
senticnet['aflare'] = [0.641, -0.733, 0, 0.798, '#surprising', '#admirable', 0.724, 'ablaze', 'aflame', 'afire', 'lighted', 'alight']
senticnet['afloat'] = [-0.997, 0, 0.658, -0.736, '#sad', '#disgusting', -0.797, 'adrift', 'purposeless', 'aimless', 'directionless', 'planless']
senticnet['afoot'] = [0.535, -0.586, 0, 0.748, '#surprising', '#admirable', 0.623, 'kinetic', 'restless', 'moving', 'ahorse', 'ahorseback']
senticnet['afraid'] = [-0.446, 0.311, 0.049, -0.398, '#sad', '#disgusting', -0.194, 'horrific', 'hysteria', 'anxious', 'desperate', 'discouraged']
senticnet['afraid_death'] = [-0.853, 0, 0, -0.734, '#sad', '#disgusting', -0.529, 'uneducated', 'superlative', 'high_quality', 'precision', 'solitary']
senticnet['afraid_of'] = [-0.932, 0, 0.096, -0.929, '#sad', '#disgusting', -0.652, 'fear', 'afraid', 'danger', 'threat', 'dangerous']
senticnet['after_dinner'] = [0.046, 0.201, -0.053, 0.115, '#interesting', '#admirable', 0.103, 'money_term', 'serve_hot', 'pay_monthly', 'must_pay', 'monetary_amount']
senticnet['after_exercise'] = [0.125, 0.097, 0, 0.152, '#joyful', '#admirable', 0.125, 'good_shape', 'rest_tire', 'elongate', 'plenty_rest', 'physical_condition']
senticnet['after_fire'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'destroyed_home', 'destroyed_city', 'burned_thing', 'mess', 'count_damage']
senticnet['after_lunch'] = [0.767, 0.732, 0, 0, '#joyful', '#interesting', 0.5, 'form_of_food', 'japanese_food', 'food_item', 'raw_fish', 'food']
senticnet['after_meal'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'teeth_whitening', 'brush_tooth', 'clean_mouth', 'clean_teeth', 'dentist']
senticnet['after_school'] = [0.053, -0.12, 0.015, -0.036, '#joyful', '#surprising', 0.041, 'student_place', 'learning_place', 'school_session', 'campus', 'professor']
senticnet['after_shower'] = [0, 0.877, 0, 0, '#interesting', '#interesting', 0.292, 'cleaned', 'reinvigorated', 'shower', 'feel_refreshed', 'relax_time']
senticnet['after_sundown'] = [-0.119, 0, -0.059, 0, '#sad', '#scared', -0.059, 'dim', 'absence_of_light', 'dark_color', 'dark', 'without_light']
senticnet['after_taste'] = [0.16, 0, 0.039, 0.121, '#joyful', '#admirable', 0.081, 'taste_bitter', 'sweetness', 'sweet', 'sweet_food', 'sweet_taste']
senticnet['afterimage'] = [-0.768, 0, 0.629, -0.718, '#sad', '#disgusting', -0.705, 'memory_picture', 'memory_image', 'aftersensation', 'image', 'mental_image']
senticnet['afternoon'] = [0.02, 0.067, 0, 0, '#joyful', '#interesting', 0.029, 'sunrise', 'begin_day', 'bright_sky', 'sunny', 'part_of_day']
senticnet['aftersensation'] = [-0.768, 0, 0.629, -0.718, '#sad', '#disgusting', -0.705, 'memory_picture', 'afterimage', 'memory_image', 'image', 'mental_image']
senticnet['aftertaste'] = [0.112, 0, 0, 0.141, '#joyful', '#admirable', 0.084, 'sweet', 'sweet_food', 'bake_good', 'round_pastry', 'eatable']
senticnet['again_and_again'] = [0, 0.338, -0.162, 0.355, '#interesting', '#admirable', 0.177, 'redo', 'inclusion', 'repeatedly', 'never_stop', 'repeat']
senticnet['against'] = [0, 0, 0.986, -0.842, '#angry', '#disgusting', -0.609, 'uprise', 'quarrel', 'opposition', 'riot', 'dispute']
senticnet['against_law'] = [-0.285, 0.214, -0.351, 0.206, '#sad', '#scared', -0.072, 'felony', 'dishonest', 'bad_action', 'bad_behavior', 'deception']
senticnet['against_rules'] = [-0.761, 0, 0.824, -0.868, '#angry', '#disgusting', -0.818, 'mulishness', 'unruliness', 'fractiousness', 'willfulness', 'intractability']
senticnet['agamic'] = [-0.686, 0, 0.779, -0.863, '#angry', '#disgusting', -0.776, 'asexual', 'agamous', 'agamogenetic', 'parthenogenetic', 'apomictic']
senticnet['agamogenetic'] = [-0.686, 0, 0.779, -0.863, '#angry', '#disgusting', -0.776, 'agamic', 'agamous', 'asexual', 'parthenogenetic', 'apomictic']
senticnet['agamous'] = [-0.686, 0, 0.779, -0.863, '#angry', '#disgusting', -0.776, 'agamic', 'asexual', 'agamogenetic', 'parthenogenetic', 'apomictic']
senticnet['agape'] = [0.807, -0.92, 0, 0.796, '#joyful', '#surprising', 0.841, 'religious_ritual', 'confirmation', 'libation', 'rite', 'service']
senticnet['age'] = [0.074, -0.06, 0, 0, '#joyful', '#surprising', 0.045, 'years', 'annual', 'elderly', 'teen', 'time']
senticnet['age_gracefully'] = [0, -0.738, 0, 0.957, '#surprising', '#admirable', 0.565, 'looking_old', 'aging', 'looking_good', 'accepting_changes', 'cosmetic_surgery']
senticnet['age_prematurely'] = [-0.951, 0, 0.924, -0.937, '#sad', '#disgusting', -0.937, 'cause_mental_illness', 'catch_fire', 'smoke_cigarette', 'light_cigar', 'light_pipe']
senticnet['age_skin'] = [-0.068, 0, -0.08, -0.081, '#scared', '#disgusting', -0.076, 'dry_wet_clothes', 'make_drunk', 'grow_plant', 'warm_hand', 'burn_trash']
senticnet['age_well'] = [0.909, 0.983, 0, 0, '#joyful', '#interesting', 0.631, 'old', 'elderly', 'ripped', 'matured', 'mentality']
senticnet['aged'] = [0.789, -0.58, 0, 0.715, '#joyful', '#admirable', 0.695, 'desiccated', 'preserved', 'lyophilized', 'cured', 'candied']
senticnet['agelessness'] = [-0.834, 0, 0.696, -0.989, '#sad', '#disgusting', -0.84, 'unalterability', 'immutability', 'changelessness', 'unchangeability', 'unchangeableness']
senticnet['agency'] = [0.065, 0.235, -0.112, 0.184, '#interesting', '#admirable', 0.124, 'association', 'egalitarian_society', 'union', 'team_up', 'social_group']
senticnet['agenda'] = [0.055, -0.017, 0, 0.106, '#joyful', '#admirable', 0.059, 'attendee', 'pencil_pen', 'learn_write', 'find_paper', 'paper_plane']
senticnet['agent'] = [0.962, -0.898, 0, 0.855, '#joyful', '#surprising', 0.905, 'infectious_agent', 'infective_agent', 'satisfier', 'quickener', 'invigorator']
senticnet['agglomerate'] = [-0.77, 0, 0.588, -0.801, '#sad', '#disgusting', -0.72, 'heap', 'funeral_pyre', 'piles', 'mound', 'cumulation']
senticnet['agglomeration'] = [-0.635, 0, 0.862, -0.523, '#sad', '#angry', -0.673, 'knot', 'swad', 'tuft', 'tussock', 'bunch']
senticnet['aggrandize'] = [0.54, -0.976, 0, 0.569, '#surprising', '#admirable', 0.695, 'overstate', 'hyperbolize', 'glorify', 'exaggerate', 'overdraw']
senticnet['aggravate'] = [-0.121, 0.069, 0.703, -0.673, '#angry', '#disgusting', -0.476, 'exacerbate', 'provoked', 'aggravated', 'exasperation', 'displeased']
senticnet['aggravated'] = [-0.121, 0.069, 0.703, -0.673, '#angry', '#disgusting', -0.476, 'aggravate', 'exacerbate', 'provoked', 'exasperation', 'displeased']
senticnet['aggravating'] = [0.652, -0.649, 0, 0.953, '#joyful', '#admirable', 0.751, 'heightening', 'thickening', 'intensifying', 'exacerbating', 'deepening']
senticnet['aggravation'] = [-0.139, 0, 0.703, -0.727, '#angry', '#disgusting', -0.523, 'offend', 'frustrate', 'disgust', 'bedevil', 'frustrating']
senticnet['aggregation'] = [0.553, -0.8, 0, 0.908, '#surprising', '#admirable', 0.754, 'strong_suit', 'collection', 'long_suit', 'accumulation', 'assemblage']
senticnet['aggress'] = [-0.754, 0, 0.886, -0.726, '#sad', '#angry', -0.789, 'harass', 'move', 'check', 'fork', 'pin']
senticnet['aggression'] = [-0.062, 0.128, 0.707, -0.677, '#angry', '#disgusting', -0.439, 'aggressive', 'hostility', 'malice', 'animosity', 'offensive']
senticnet['aggressive'] = [0, 0, -0.859, -0.936, '#scared', '#disgusting', -0.598, 'anger', 'animosity', 'hostility', 'malice', 'grudge']
senticnet['aggressiveness'] = [-0.715, 0, 0.871, 0, '#sad', '#angry', -0.529, 'offensive', 'despise', 'maleficence', 'rage', 'malefic']
senticnet['aggrieve'] = [-0.894, 0.161, -0.613, 0.053, '#sad', '#scared', -0.431, 'heartrending', 'heartbreaking', 'grievous', 'grievously', 'brokenheartedness']
senticnet['aggroup'] = [0.867, -0.846, 0, 0.876, '#joyful', '#admirable', 0.863, 'meet', 'team', 'team_up', 'embed', 'gang']
senticnet['agile'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'find_balance', 'avoid_fall', 'skip_rope', 'avoid_failure', 'good_balance']
senticnet['agility'] = [-0.046, 0.109, -0.061, 0.121, '#interesting', '#admirable', 0.041, 'use_leg', 'walk_quickly', 'run_slowly', 'find_ball', 'take_step']
senticnet['agitate'] = [-0.988, 0, -0.875, 0, '#sad', '#scared', -0.621, 'foment', 'agitated', 'tumult', 'stir_up', 'earnestness']
senticnet['agitated'] = [-0.871, 0.79, 0, -0.951, '#sad', '#disgusting', -0.344, 'agitate', 'foment', 'tumult', 'stir_up', 'earnestness']
senticnet['agitation'] = [-0.712, 0, 0.928, -0.741, '#angry', '#disgusting', -0.794, 'set_off', 'shake_up', 'stir_up', 'instigate', 'inflame']
senticnet['agnosia'] = [-0.738, 0, 0.955, -0.547, '#sad', '#angry', -0.747, 'visual_agnosia', 'auditory_agnosia', 'brain_disorder', 'encephalopathy', 'brain_disease']
senticnet['agnostic'] = [0.55, -0.981, 0, 0.794, '#surprising', '#admirable', 0.775, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['agonizing'] = [-0.795, 0, 0.903, 0, '#sad', '#angry', -0.566, 'excruciating', 'harrowing', 'torturing', 'worry', 'fret']
senticnet['agony'] = [-0.858, 0, 0.791, -0.788, '#sad', '#angry', -0.812, 'suffer', 'pain', 'inflict_pain', 'ouch', 'trauma']
senticnet['agree'] = [0.723, 0, 0, 0.98, '#joyful', '#admirable', 0.568, 'reach_tentative_agreement', 'thank', 'comfort_friend', 'forgive', 'take_oath']
senticnet['agree_disagree'] = [0.905, 0.779, 0, 0, '#joyful', '#interesting', 0.561, 'welcome_friend', 'captain_boat', 'gather_berry', 'hang_picture_on_wall', 'laugh_oneself']
senticnet['agreeability'] = [0.604, -0.576, 0, 0.935, '#joyful', '#admirable', 0.705, 'affirmativeness', 'deference', 'compliance', 'disposition', 'complaisance']
senticnet['agreeable'] = [0.509, -0.626, 0, 0.786, '#surprising', '#admirable', 0.64, 'accordant', 'consentaneous', 'consentient', 'unanimous', 'according']
senticnet['agreed_upon'] = [0.858, -0.891, 0, 0.719, '#joyful', '#surprising', 0.823, 'sign_contract', 'agreement', 'arrangement', 'promise', 'agreed']
senticnet['agreement'] = [0.808, 0, 0, 0.943, '#joyful', '#admirable', 0.584, 'offer', 'pact', 'business_agreement', 'cope', 'ask_politely']
senticnet['agricultural'] = [0, 0.094, 0.02, 0.09, '#interesting', '#admirable', 0.055, 'cultivation', 'plant_food', 'grow_food', 'grow_stuff', 'farm_vegetable']
senticnet['agricultural_product'] = [0, 0.073, 0.052, 0.082, '#interesting', '#admirable', 0.034, 'grown_field', 'farm_food', 'edible_plant', 'grown_food', 'farm_plant']
senticnet['agriculture'] = [0, 0.08, 0.012, 0.067, '#interesting', '#admirable', 0.045, 'raise_animal', 'grow_food', 'grow_crop', 'plant_crop', 'grow_stuff']
senticnet['agromania'] = [-0.898, 0, 0.987, -0.904, '#angry', '#disgusting', -0.93, 'logorrhea', 'logomania', 'cacoethes', 'pyromania', 'necrophilia']
senticnet['ahead'] = [0.844, 0, 0, 0, '#joyful', '#joyful', 0.281, 'straight', 'late_time', 'preparedness', 'past_present', 'wait']
senticnet['ahorse'] = [0.535, -0.586, 0, 0.748, '#surprising', '#admirable', 0.623, 'kinetic', 'restless', 'afoot', 'moving', 'movingback']
senticnet['ahorseback'] = [0.535, -0.586, 0, 0.748, '#surprising', '#admirable', 0.623, 'kinetic', 'restless', 'afoot', 'ahorse', 'moving']
senticnet['aid'] = [0.751, 0, 0, 0.716, '#joyful', '#admirable', 0.489, 'assistance', 'emergency', 'look_after', 'sleep_disorder', 'care']
senticnet['aide'] = [0, 0, 0, 0.876, '#admirable', '#admirable', 0.292, 'good_manner', 'courteous', 'good_behavior', 'handle_carefully', 'politeness']
senticnet['aids'] = [-0.989, 0, 0.942, -0.9, '#sad', '#angry', -0.944, 'disease', 'immunodeficiency', 'immunological_disorder', 'die', 'hiv']
senticnet['ail'] = [-0.732, 0, 0.865, -0.878, '#angry', '#disgusting', -0.825, 'ill', 'sickness', 'illness', 'malady', 'polio']
senticnet['ailment'] = [-0.185, 0.071, -0.17, -0.176, '#sad', '#disgusting', -0.153, 'malady', 'polio', 'illness', 'sickness', 'medical_problem']
senticnet['aim'] = [0.717, 0.935, 0, 0, '#joyful', '#interesting', 0.551, 'intention', 'point_weapon', 'life_goal', 'objective', 'target']
senticnet['aimless'] = [-0.997, 0, 0.658, -0.736, '#sad', '#disgusting', -0.797, 'adrift', 'afloat', 'purposeless', 'directionless', 'planless']
senticnet['air'] = [0.909, 0.983, 0, 0, '#joyful', '#interesting', 0.631, 'oxygen', 'breathable', 'atmosphere', 'hydrogen', 'inhale_air']
senticnet['air_attack'] = [0.954, -0.87, 0, 0.583, '#joyful', '#surprising', 0.802, 'penetration', 'air_raid', 'foray', 'swoop', 'incursion']
senticnet['air_breath'] = [0.882, -0.722, 0, 0, '#joyful', '#surprising', 0.535, 'atmosphere', 'fresh_air', 'oxygen', 'lung', 'breathe']
senticnet['air_breathe'] = [0, 0.966, 0, 0.952, '#interesting', '#admirable', 0.639, 'atmosphere', 'bird_fly', 'thunder_storm', 'lung', 'breathe']
senticnet['air_bubble'] = [0.954, -0.87, 0, 0.583, '#joyful', '#surprising', 0.802, 'bubble', 'foam', 'froth', 'soap_bubble', 'globule']
senticnet['air_conditioner'] = [0.046, -0.03, 0, 0, '#joyful', '#surprising', 0.025, 'cold', 'electricity', 'circulate_air', 'blow_air', 'breeze']
senticnet['air_density'] = [0.728, 0.977, 0, 0.939, '#interesting', '#admirable', 0.881, 'air_pressure', 'altitude', 'air', 'heavy_air', 'density']
senticnet['air_grievance'] = [-0.848, 0, 0.969, -0.85, '#angry', '#disgusting', -0.889, 'sail_around_world', 'hurry_work', 'arm_oneself', 'storm_out_room', 'speak_english']
senticnet['air_marshal'] = [0.74, -0.539, 0, 0.641, '#joyful', '#admirable', 0.64, 'marshal', 'sky_marshal', 'lawman', 'law_officer', 'peace_officer']
senticnet['air_movement'] = [0.116, 0.129, -0.058, 0.053, '#joyful', '#interesting', 0.08, 'move_air', 'circulate_air', 'blown', 'blow_air', 'windy']
senticnet['air_out'] = [0.74, -0.539, 0, 0.641, '#joyful', '#admirable', 0.64, 'regenerate', 'freshen', 'air', 'renew', 'vent']
senticnet['air_pollution'] = [-0.706, 0, 0, -0.9, '#sad', '#disgusting', -0.535, 'lung_cancer', 'pollution', 'pollute_air', 'speeding_ticket', 'bright_flash']
senticnet['air_pressure'] = [0.728, 0.977, 0, 0.939, '#interesting', '#admirable', 0.881, 'pressure', 'altitude', 'air_density', 'heavy_air', 'air']
senticnet['air_pump'] = [0.116, 0.129, -0.058, 0.053, '#joyful', '#interesting', 0.08, 'power_drill', 'adjustable_wrench', 'drill_bite', 'type_of_machine', 'drill']
senticnet['air_raid'] = [0.954, -0.87, 0, 0.583, '#joyful', '#surprising', 0.802, 'penetration', 'foray', 'air_attack', 'swoop', 'incursion']
senticnet['air_tank'] = [-0.045, 0.118, -0.069, 0.102, '#interesting', '#admirable', 0.035, 'a_lot_of_practice', 'race_hare', 'live_old', 'hide_shell', 'grasp']
senticnet['air_ticket'] = [0.105, 0.226, -0.083, 0.176, '#interesting', '#admirable', 0.141, 'hand_luggage', 'passenger_ticket', 'travel', 'plane_ticket', 'first_class_airplane_seat']
senticnet['air_traffic'] = [-0.987, 0, 0.989, -0.933, '#sad', '#angry', -0.97, 'flight_accident', 'dangerous', 'danger', 'traffic', 'traffic_jam']
senticnet['air_traffic_controller'] = [0, -0.076, 0, 0.081, '#surprising', '#admirable', 0.052, 'wing', 'most_birds', 'vulture', 'bird', 'pigeon']
senticnet['air_vent'] = [0, -0.01, 0, 0.069, '#surprising', '#admirable', 0.026, 'ventilation', 'move_air', 'fan', 'spin', 'circulate_air']
senticnet['aircraft'] = [0.627, 0.61, -0.24, 0.234, '#joyful', '#interesting', 0.41, 'helicopter', 'plane', 'airplane', 'aeroplane', 'airliner']
senticnet['aircraft_carrier'] = [-0.045, 0.092, 0, 0.062, '#interesting', '#admirable', 0.036, 'hangar', 'blimp', 'hot_air_balloon', 'war_museum', 'spaceship']
senticnet['aircraft_roadway'] = [0.745, 0.898, 0, 0, '#joyful', '#interesting', 0.548, 'highway', 'taxiway', 'runway', 'flight_terminal', 'ticket_counter']
senticnet['airfield'] = [-0.975, 0, 0.737, -0.979, '#sad', '#disgusting', -0.897, 'flare_path', 'airstrip', 'landing_field', 'flying_field', 'field']
senticnet['airheaded'] = [-0.799, 0, 0.904, -0.652, '#sad', '#angry', -0.785, 'dizzy', 'giddy', 'idle', 'frivolous', 'featherbrained']
senticnet['airline'] = [0, -0.01, 0, 0.069, '#surprising', '#admirable', 0.026, 'airport_terminal', 'airport', 'baggage_compartment', 'aircraft', 'airliner']
senticnet['airline_seat'] = [0.721, -0.952, 0, 0, '#joyful', '#surprising', 0.558, 'sofa_bed', 'small_seat', 'beanbag_chair', 'hide-a-bed_sofa', 'chair']
senticnet['airliner'] = [0, -0.01, 0, 0.069, '#surprising', '#admirable', 0.026, 'airport_terminal', 'airport', 'baggage_compartment', 'aircraft', 'airline']
senticnet['airmanship'] = [0.607, -0.997, 0, 0.847, '#surprising', '#admirable', 0.817, 'eristic', 'puppetry', 'homiletics', 'aviation', 'artistry']
senticnet['airplane'] = [0.821, 0, 0, 0.802, '#joyful', '#admirable', 0.541, 'aeroplane', 'plane', 'transportation', 'back_airplane', 'aircraft']
senticnet['airplane_engine'] = [0, 0.986, 0, 0.988, '#interesting', '#admirable', 0.658, 'engine', 'hatchet', 'angle_grinder', 'knife', 'cannonball']
senticnet['airplane_seat'] = [0.835, -0.747, 0, 0, '#joyful', '#surprising', 0.527, 'coach_seat', 'small_seat', 'train_seat', 'sofa_bed', 'first_class_train_seat']
senticnet['airport'] = [0, 0.147, 0, 0.099, '#interesting', '#admirable', 0.082, 'train_station', 'railway_station', 'subway', 'airport_terminal', 'depot']
senticnet['airport_terminal'] = [0, 0.147, 0, 0.099, '#interesting', '#admirable', 0.082, 'airliner', 'airport', 'baggage_compartment', 'aircraft', 'cable_car']
senticnet['airs'] = [-0.562, 0, 0.757, -0.991, '#angry', '#disgusting', -0.77, 'unnaturalness', 'affectedness', 'pose', 'coyness', 'demureness']
senticnet['airstrip'] = [-0.975, 0, 0.737, -0.979, '#sad', '#disgusting', -0.897, 'flare_path', 'airfield', 'landing_field', 'flying_field', 'field']
senticnet['airy'] = [0.116, 0.129, -0.058, 0.053, '#joyful', '#interesting', 0.08, 'blown', 'weather_element', 'move_air', 'unseen', 'breezy']
senticnet['aisle'] = [0.029, 0.087, 0.065, 0.137, '#interesting', '#admirable', 0.063, 'archway', 'arch', 'mat', 'passageway', 'walkway']
senticnet['alarm'] = [0, 0, -0.775, -0.855, '#scared', '#disgusting', -0.543, 'alarmed', 'horrify', 'fear', 'appall', 'scary']
senticnet['alarm_clock_ring'] = [-0.024, 0.093, -0.068, 0.079, '#interesting', '#admirable', 0.027, 'turn_off_alarm', 'start_new_day', 'get_out_of_bed', 'work_oneself', 'hard_work']
senticnet['alarmed'] = [-0.879, 0, -0.771, 0, '#sad', '#scared', -0.55, 'scared', 'horrify', 'appall', 'timidness', 'bashfully']
senticnet['alarming'] = [-0.524, 0, 0.71, -0.942, '#angry', '#disgusting', -0.725, 'atrocious', 'horrific', 'menacing', 'minacious', 'minatory']
senticnet['albinism'] = [-0.917, 0, 0.961, -0.556, '#sad', '#angry', -0.811, 'hypopigmentation', 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder']
senticnet['album_collection'] = [0.74, -0.539, 0, 0.641, '#joyful', '#admirable', 0.64, 'hobby', 'collection', 'butterfly_collection', 'insect_collection', 'coin_collection']
senticnet['alchemist'] = [0, 0.795, 0, 0.796, '#interesting', '#admirable', 0.53, 'servant', 'art_of_transmuting_metal', 'stone', 'alchemy', 'philosopher']
senticnet['alcohol'] = [0.11, -0.013, 0, 0, '#joyful', '#surprising', 0.041, 'drink_alcohol', 'adult_drink', 'alcoholic_drink', 'cocktail', 'booze']
senticnet['alcohol_abuse'] = [-0.514, 0, 0.97, -0.626, '#angry', '#disgusting', -0.703, 'abuse', 'misuse', 'drug_abuse', 'alcoholic_abuse', 'alcoholism_abuse']
senticnet['alcoholic'] = [-0.884, 0, 0, -0.705, '#sad', '#disgusting', -0.53, 'drunkard', 'drunk_person', 'whisky', 'beer', 'alcohol']
senticnet['alcoholic_abuse'] = [-0.514, 0, 0.97, -0.626, '#angry', '#disgusting', -0.703, 'abuse', 'misuse', 'alcohol_abuse', 'drug_abuse', 'alcoholism_abuse']
senticnet['alcoholic_beverage'] = [0, 0, 0, -0.912, '#disgusting', '#disgusting', -0.304, 'alcoholic_drink', 'get_drunk', 'ferment_beverage', 'adult_drink', 'booze']
senticnet['alcoholic_dementia'] = [-0.947, 0, 0.821, -0.756, '#sad', '#angry', -0.841, 'presenile_dementia', 'insanity', 'senile_dementia', 'senile_psychosis', 'dementedness']
senticnet['alcoholic_drink'] = [0, 0.948, 0, 0, '#interesting', '#interesting', 0.316, 'alcoholic_beverage', 'drink_alcohol', 'adult_drink', 'beer', 'cocktail']
senticnet['alcoholism'] = [-0.799, 0, 0, -0.811, '#sad', '#disgusting', -0.537, 'become_intoxicated', 'use_party', 'party', 'bee_sting', 'lose_control']
senticnet['alcoholism_abuse'] = [-0.514, 0, 0.97, -0.626, '#angry', '#disgusting', -0.703, 'abuse', 'misuse', 'alcohol_abuse', 'alcoholic_abuse', 'drug_abuse']
senticnet['aldose'] = [-0.528, 0, 0.681, -0.768, '#angry', '#disgusting', -0.659, 'triose', 'tetrose', 'pentose', 'hexose', 'simple_sugar']
senticnet['ale'] = [0.819, -0.813, 0, 0, '#joyful', '#surprising', 0.544, 'scotch', 'bourbon', 'vodka', 'brandy', 'whiskey']
senticnet['alert'] = [-0.799, 0, 0, -0.811, '#sad', '#disgusting', -0.537, 'alarm', 'disquiet', 'confuse', 'panic', 'dread']
senticnet['alga'] = [-0.659, 0, 0.523, -0.739, '#sad', '#disgusting', -0.64, 'confervoid_algae', 'seaweed', 'golden_algae', 'diatom', 'brown_algae']
senticnet['algae'] = [-0.632, 0, 0.812, -0.82, '#angry', '#disgusting', -0.755, 'confervoid_algae', 'seaweed', 'golden_algae', 'diatom', 'brown_algae']
senticnet['algebra'] = [0, 0.71, 0, 0.907, '#interesting', '#admirable', 0.539, 'calculus', 'math', 'mathematics', 'math_equation', 'mathematical_function']
senticnet['alias'] = [0.056, 0.183, -0.126, 0.188, '#interesting', '#admirable', 0.1, 'kingdom', 'royal', 'monarchy', 'throne', 'noble']
senticnet['alibi'] = [-0.105, 0, 0, -0.167, '#sad', '#disgusting', -0.091, 'choose_victim', 'murder_weapon', 'plan_attack', 'shoot_person', 'shoot']
senticnet['alien'] = [-0.038, 0.118, 0.472, -0.469, '#angry', '#disgusting', -0.287, 'detached', 'set-apart', 'separated', 'isolated', 'sickening']
senticnet['alienage'] = [-0.864, 0, 0.941, -0.622, '#sad', '#angry', -0.809, 'foreignness', 'alienism', 'exoticism', 'exoticness', 'exotism']
senticnet['alienate'] = [-0.106, 0.176, 0.629, -0.642, '#angry', '#disgusting', -0.4, 'alienated', 'alienation', 'disaffection', 'estrange', 'disoriented']
senticnet['alienated'] = [-0.106, 0.176, 0.629, -0.642, '#angry', '#disgusting', -0.4, 'alienation', 'disaffection', 'estrange', 'alienate', 'disoriented']
senticnet['alienation'] = [-0.106, 0.176, 0.629, -0.642, '#angry', '#disgusting', -0.4, 'alienated', 'disaffection', 'estrange', 'alienate', 'disoriented']
senticnet['alienism'] = [-0.864, 0, 0.941, -0.622, '#sad', '#angry', -0.809, 'alienage', 'foreignness', 'exoticism', 'exoticness', 'exotism']
senticnet['alight'] = [0.641, -0.733, 0, 0.798, '#surprising', '#admirable', 0.724, 'ablaze', 'aflame', 'afire', 'aflare', 'lighted']
senticnet['align'] = [-0.756, 0, 0.514, -0.672, '#sad', '#disgusting', -0.647, 'realign', 'realine', 'focus', 'true', 'address']
senticnet['alike'] = [0, 0.213, -0.073, 0.308, '#interesting', '#admirable', 0.149, 'same', 'identical', 'similar', 'compare', 'comparison']
senticnet['alikeness'] = [-0.894, 0, 0.58, -0.723, '#sad', '#disgusting', -0.732, 'resemblance', 'comparison', 'equivalence', 'reflection', 'spitting_image']
senticnet['alimentary'] = [0.656, -0.731, 0, 0.736, '#surprising', '#admirable', 0.708, 'good_for_you', 'salubrious', 'healthy', 'solid', 'wholesome']
senticnet['alimentary_canal'] = [0.74, -0.539, 0, 0.641, '#joyful', '#admirable', 0.64, 'enteron', 'alimentary_tract', 'digestive_tube', 'digestive_tract', 'gastrointestinal_tract']
senticnet['alimentary_tract'] = [0.74, -0.539, 0, 0.641, '#joyful', '#admirable', 0.64, 'alimentary_canal', 'enteron', 'digestive_tube', 'digestive_tract', 'gastrointestinal_tract']
senticnet['alimony'] = [-0.847, 0, -0.756, 0, '#sad', '#scared', -0.534, 'allowance', 'provision', 'divorce', 'bill', 'due']
senticnet['alive'] = [0.027, 0.132, -0.06, 0.182, '#interesting', '#admirable', 0.094, 'life_form', 'live_object', 'poisonous_human', 'live_organism', 'live_creature']
senticnet['aliyah'] = [0.682, -0.705, 0, 0.98, '#surprising', '#admirable', 0.789, 'prize', 'seal_of_approval', 'honorable_mention', 'laurels', 'cachet']
senticnet['alkali_poisoning'] = [-0.72, 0, 0.884, -0.758, '#angry', '#disgusting', -0.787, 'ergotism', 'paraquat_poisoning', 'poisoning', 'caffeinism', 'caffeine_intoxication']
senticnet['alkaline'] = [0.045, 0, 0, 0.051, '#joyful', '#admirable', 0.032, 'science', 'battery', 'chemistry', 'ph_level', 'chemical']
senticnet['alkalizer'] = [-0.533, 0, 0.954, -0.541, '#angry', '#disgusting', -0.676, 'antacid', 'histamine_blocker', 'gastric_antacid', 'ranitidine', 'antiacid']
senticnet['alky'] = [0.556, -0.791, 0, 0.755, '#surprising', '#admirable', 0.701, 'lush', 'alcoholic', 'rummy', 'dipsomaniac', 'boozer']
senticnet['all'] = [0, -0.861, 0, 0.994, '#surprising', '#admirable', 0.618, 'whole', 'entire', 'complete', 'total', 'altogether']
senticnet['all_important'] = [0.86, -0.857, 0, 0.864, '#joyful', '#admirable', 0.86, 'of_import', 'of_essence', 'outstanding', 'master', 'chief']
senticnet['all_of_it'] = [0.038, 0.204, 0, 0.258, '#interesting', '#admirable', 0.167, 'totality', 'full', 'total', 'entire', 'complete']
senticnet['all_right'] = [0.065, 0.351, -0.173, 0.395, '#interesting', '#admirable', 0.213, 'let', 'suggest', 'plea', 'given', 'permission']
senticnet['allay'] = [0.615, 0.643, -0.247, 0.29, '#joyful', '#interesting', 0.434, 'relieve', 'easiness', 'pacifically', 'peaceable', 'repose']
senticnet['allayer'] = [0.81, -0.693, 0, 0.741, '#joyful', '#admirable', 0.748, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['allegation'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'grievance', 'accusation', 'plaint', 'lodgment', 'accuse']
senticnet['alleged'] = [0.843, -0.935, 0, 0.952, '#surprising', '#admirable', 0.91, 'asserted', 'avowed', 'professed', 'declared', 'announced']
senticnet['allegory'] = [0.844, -0.572, 0, 0.576, '#joyful', '#admirable', 0.664, 'blue_ribbon', 'cordon_bleu', 'badge', 'stripe', 'merit_badge']
senticnet['allergic_reaction'] = [-0.063, 0.183, 0.651, -0.642, '#angry', '#disgusting', -0.391, 'runny_nose', 'chew', 'pierce', 'mastication', 'put_mouth']
senticnet['allergic_rhinitis'] = [-0.606, 0, 0.931, -0.922, '#angry', '#disgusting', -0.82, 'rhinitis', 'coryza', 'hay_fever', 'pollinosis', 'hypersensitivity_reaction']
senticnet['allergy'] = [-0.961, 0, 0.848, -0.824, '#sad', '#angry', -0.878, 'sneeze', 'sign_sickness', 'runny_nose', 'flu', 'common_cold']
senticnet['allergy_symptom'] = [-0.943, 0, 0.891, -0.939, '#sad', '#disgusting', -0.924, 'allergy', 'symptom', 'need_cure', 'sick', 'cause_allergy']
senticnet['alleviate'] = [0.676, -0.706, 0, 0.8, '#surprising', '#admirable', 0.727, 'better', 'soothe', 'improve', 'alleviate_pain', 'meliorate']
senticnet['alleviate_boredom'] = [0.738, 0.961, 0, 0, '#joyful', '#interesting', 0.566, 'amusement', 'entertainment', 'fun', 'play', 'games']
senticnet['alleviate_pain'] = [0.676, -0.706, 0, 0.8, '#surprising', '#admirable', 0.727, 'better', 'soothe', 'improve', 'alleviate', 'meliorate']
senticnet['alleviated'] = [-0.793, 0, 0.817, -0.538, '#sad', '#angry', -0.716, 'mitigated', 'eased', 'relieved', 'lessened', 'quenched']
senticnet['alleviative'] = [0.761, -0.751, 0, 0.77, '#joyful', '#admirable', 0.761, 'analgesic', 'analgetic', 'anodyne', 'weakening', 'moderating']
senticnet['alley'] = [0.749, 0, 0, 0, '#joyful', '#joyful', 0.25, 'dark', 'road', 'street', 'direction', 'alleyway']
senticnet['alleyway'] = [0.749, 0, 0, 0, '#joyful', '#joyful', 0.25, 'dark', 'road', 'street', 'direction', 'alley']
senticnet['alligator'] = [0, 0, -0.071, 0, '#scared', '#scared', -0.024, 'reptile', 'animal', 'predator', 'meat_eater', 'river']
senticnet['allocation'] = [0.732, -0.833, 0, 0.566, '#joyful', '#surprising', 0.71, 'share', 'reallocation', 'quota', 'portion', 'part']
senticnet['allomerism'] = [-0.836, 0, 0.546, -0.88, '#sad', '#disgusting', -0.754, 'difference', 'variation', 'deviation', 'divergence', 'departure']
senticnet['allot'] = [0.519, -0.991, 0, 0.741, '#surprising', '#admirable', 0.75, 'earmark', 'appropriate', 'set_aside', 'reserve', 'reserve_table']
senticnet['allotment'] = [0, 0.108, 0.029, 0.09, '#interesting', '#admirable', 0.056, 'quantity', 'amount', 'rate', 'a_lot', 'pound']
senticnet['allow'] = [0, 0, 0, 0.964, '#admirable', '#admirable', 0.321, 'let', 'permission', 'accept', 'come', 'continue']
senticnet['allowance'] = [0.924, 0.968, 0, 0.876, '#joyful', '#interesting', 0.923, 'live_simply', 'help_out', 'really_want', 'accolade', 'generous']
senticnet['alloy'] = [0.04, 0, 0.017, 0.056, '#joyful', '#admirable', 0.026, 'platinum', 'silver', 'mixed_metal', 'titanium', 'heavy_element']
senticnet['alloy_cast_iron'] = [0.706, -0.941, 0, 0.622, '#joyful', '#surprising', 0.756, 'alloy_iron', 'cast_iron', 'pot_metal', 'iron', 'atomic_number_26']
senticnet['alloy_iron'] = [0.706, -0.941, 0, 0.622, '#joyful', '#surprising', 0.756, 'cast_iron', 'alloy_cast_iron', 'pot_metal', 'iron', 'atomic_number_26']
senticnet['alloyed'] = [-0.818, 0, 0.668, -0.873, '#sad', '#disgusting', -0.786, 'dirty', 'dingy', 'muddied', 'impure', 'adulterate']
senticnet['allure'] = [0.817, -0.626, 0, 0.62, '#joyful', '#surprising', 0.688, 'quality', 'fascination', 'attractivenessment', 'attractiveness', 'temptingness']
senticnet['allurement'] = [0.817, -0.626, 0, 0.62, '#joyful', '#surprising', 0.688, 'quality', 'fascination', 'attractiveness', 'allure', 'temptingness']
senticnet['alluring'] = [0.969, -0.848, 0, 0.837, '#joyful', '#surprising', 0.885, 'seductive', 'enticing', 'tempting', 'beguiling', 'corrupting']
senticnet['allusiveness'] = [-0.629, 0, 0.69, -0.765, '#angry', '#disgusting', -0.695, 'deviousness', 'mediacy', 'mediateness', 'characteristic', 'indirectness']
senticnet['alluviation'] = [0.614, -0.956, 0, 0.584, '#joyful', '#surprising', 0.718, 'mother_lode', 'champion_lode', 'deposit', 'sedimentation', 'lode']
senticnet['ally'] = [0.716, -0.51, 0, 0.647, '#joyful', '#admirable', 0.624, 'state', 'nation', 'country', 'land', 'commonwealth']
senticnet['almighty'] = [0.064, 0.225, -0.091, 0.232, '#interesting', '#admirable', 0.143, 'lord', 'baron', 'omniscient', 'nobility', 'deity']
senticnet['almond'] = [0.128, 0, 0, 0.092, '#joyful', '#admirable', 0.073, 'face_feature', 'near_nose', 'facial', 'facial_part', 'socket']
senticnet['almost_always'] = [-0.046, 0, -0.116, 0, '#sad', '#scared', -0.054, 'book', 'many_books', 'book_genre', 'saga', 'book_poetry']
senticnet['almost_complete'] = [0.445, 0.37, -0.142, 0.483, '#joyful', '#admirable', 0.385, 'near_completion', 'near', 'mission_accomplished', 'sufficient', 'absolute']
senticnet['almost_fall'] = [0, 0, -0.903, 0, '#scared', '#scared', -0.301, 'lose_foot', 'skid', 'stumble', 'reach_high_shelf', 'trip']
senticnet['almost_finish'] = [-0.987, 0, 0.989, -0.933, '#sad', '#angry', -0.97, 'run_out_of_time', 'run_out_of_money', 'lack_of_food', 'run_out', 'low_battery']
senticnet['almost_there'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'destination', 'near_destination', 'goal', 'return_home', 'reach_home']
senticnet['alms'] = [0.053, 0.248, -0.185, 0.258, '#interesting', '#admirable', 0.125, 'slogan', 'find_money', 'wealthy', 'much_money', 'donation']
senticnet['aloe'] = [0.722, -0.606, 0, 0.596, '#joyful', '#surprising', 0.641, 'medicament', 'medicinal_drug', 'medication', 'cathartic', 'bitter_cathartic']
senticnet['alone'] = [-0.81, 0, -0.901, 0, '#sad', '#scared', -0.57, 'lonely', 'feel_lonely', 'entire', 'body_type', 'live_in_mountains']
senticnet['alone_long_time'] = [-0.921, 0, 0.779, -0.704, '#sad', '#angry', -0.801, 'loneliness', 'disappointment', 'stupidity', 'feel_lonely', 'act_stupid']
senticnet['aloneness'] = [-0.58, 0, 0.925, -0.632, '#angry', '#disgusting', -0.712, 'ill_nature', 'disagreeableness', 'unfriendliness', 'bloodthirstiness', 'disposition']
senticnet['along_beach'] = [-0.065, 0.07, 0.03, 0.138, '#interesting', '#admirable', 0.038, 'depth', 'salty', 'vast', 'oceanside', 'full_water']
senticnet['aloofness'] = [-0.93, 0, 0, -0.726, '#sad', '#disgusting', -0.552, 'withdrawal', 'detachment', 'indifferently', 'indifferent', 'apathetic']
senticnet['alp'] = [0, 0.069, 0, 0.065, '#interesting', '#admirable', 0.045, 'canyon', 'high_mountain', 'rocky_area', 'ski_resort', 'high_place']
senticnet['alpaca'] = [-0.535, 0, 0.751, -0.971, '#angry', '#disgusting', -0.752, 'guanaco', 'domestic_llama', 'llama', 'artiodactyl', 'artiodactyl_mammal']
senticnet['alpha'] = [0.053, 0.248, -0.185, 0.258, '#interesting', '#admirable', 0.125, 'first', 'dominant_role', 'alpha_male', 'master', 'in_charge']
senticnet['alpha_male'] = [0, 0, -0.122, 0, '#scared', '#scared', -0.041, 'male', 'male_person', 'masculine', 'man_child', 'boy']
senticnet['alpha_radiation'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'ionizing_radiation', 'alpha_ray', 'beta_radiation', 'beta_ray', 'electron_radiation']
senticnet['alpha_ray'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'alpha_radiation', 'ionizing_radiation', 'beta_radiation', 'beta_ray', 'electron_radiation']
senticnet['alpha_test'] = [0.928, -0.879, 0, 0.679, '#joyful', '#surprising', 0.829, 'field_trial', 'field_test', 'test', 'beta_test', 'road_test']
senticnet['alphabet'] = [0, 0.985, 0, 0.981, '#interesting', '#admirable', 0.655, 'part_of_speech', 'word', 'ideograph', 'vowel', 'news_story']
senticnet['alphabet_soup'] = [-0.625, 0, 0.988, -0.591, '#sad', '#angry', -0.735, 'motley', 'mixture', 'variety', 'assortment', 'mixed_bag']
senticnet['alpine_milk_vetch'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'wild_licorice', 'wild_liquorice', 'milk_vetch', 'purple_milk_vetch', 'woody_plant']
senticnet['altar'] = [0.027, 0.24, 0, 0.226, '#interesting', '#admirable', 0.164, 'chapel', 'confessional', 'christianity', 'lectern', 'temple']
senticnet['altar_boy'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'acolyte', 'reverend', 'thurifer', 'clergyman', 'man_of_cloth']
senticnet['alter'] = [-0.039, 0.224, 0, 0.221, '#interesting', '#admirable', 0.135, 'small_coin', 'small_money', 'money_coin', 'american_coin', 'change']
senticnet['alter_state_consciousness'] = [0, 0, -0.826, -0.983, '#scared', '#disgusting', -0.603, 'change_mind', 'think_sex', 'invigorate', 'hallucinate', 'loss_of_consciousness']
senticnet['alterable'] = [0.623, -0.566, 0, 0.974, '#joyful', '#admirable', 0.721, 'commutable', 'convertible', 'translatable', 'transformable', 'transmutable']
senticnet['alteration'] = [0.772, -0.923, 0, 0.524, '#joyful', '#surprising', 0.74, 'change', 'modification', 'disembarrassment', 'breath_of_fresh_air', 'easing']
senticnet['altercate'] = [0.915, -0.847, 0, 0.778, '#joyful', '#surprising', 0.847, 'fall_out', 'debate', 'wrangle', 'spat', 'brawl']
senticnet['altercation'] = [-0.601, 0, 0.777, -0.51, '#sad', '#angry', -0.629, 'batrachomyomachia', 'wrangle', 'dustup', 'quarrel', 'row']
senticnet['altered'] = [-0.623, 0, 0.657, -0.955, '#angry', '#disgusting', -0.745, 'paraphrastic', 'adjusted', 'changed', 'emended', 'edited']
senticnet['alternate'] = [0, 0.945, 0, 0.723, '#interesting', '#admirable', 0.556, 'alternative', 'substitute', 'replacement', 'another', 'every_second']
senticnet['alternative'] = [0.02, 0.277, -0.119, 0.336, '#interesting', '#admirable', 0.171, 'different', 'similar', 'substitute', 'other_person', 'exception']
senticnet['alternative_energy'] = [-0.791, 0, 0.997, -0.687, '#sad', '#angry', -0.825, 'energy', 'solar_energy', 'solar_power', 'wind_generation', 'wind_power']
senticnet['altitude'] = [0.023, 0.113, 0.053, 0.153, '#interesting', '#admirable', 0.079, 'high', 'high_land', 'incline_plane', 'top', 'diagonal']
senticnet['alto'] = [0.034, 0, 0.01, 0.087, '#joyful', '#admirable', 0.037, 'music', 'voice', 'bell', 'singing', 'highest_pitch']
senticnet['altogether'] = [-0.947, 0, 0.991, -0.656, '#sad', '#angry', -0.865, 'birthday_suit', 'raw', 'nakedness', 'nude', 'undress']
senticnet['altruistic'] = [0.075, 0.252, -0.147, 0.186, '#interesting', '#admirable', 0.122, 'tall_play_basketball', 'niceness', 'magnanimous', 'kindness', 'type_of_bear']
senticnet['aluminium'] = [0.057, 0, 0.012, 0.08, '#joyful', '#admirable', 0.042, 'rust', 'foil', 'tin', 'thin_metal', 'magnet']
senticnet['aluminium_foil'] = [0.716, -0.791, 0, 0.543, '#joyful', '#surprising', 0.683, 'chaff', 'wrap', 'foil', 'tin_foil', 'gold_foil']
senticnet['alveolus'] = [0.681, -0.632, 0, 0.647, '#joyful', '#admirable', 0.653, 'hip_socket', 'tooth_socket', 'socket', 'acetabulum', 'cotyloid_cavity']
senticnet['always_read'] = [-0.041, 0.226, -0.143, 0.255, '#interesting', '#admirable', 0.099, 'like_read', 'plot', 'personality_trait', 'animate', 'play_role']
senticnet['amalgamate'] = [0, 0, -0.832, -0.845, '#scared', '#disgusting', -0.559, 'mingle', 'coalesced', 'commix', 'mix', 'unify']
senticnet['amass'] = [-0.593, 0, 0.604, -0.951, '#angry', '#disgusting', -0.716, 'pile_up', 'roll_up', 'collect', 'accumulate', 'run_up']
senticnet['amateur'] = [-0.982, 0, 0.937, -0.689, '#sad', '#angry', -0.869, 'sciolist', 'dabbler', 'mortal', 'dilettante', 'bird_watcher']
senticnet['amateurishness'] = [0.983, -0.637, 0, 0.697, '#joyful', '#admirable', 0.772, 'unskillfulness', 'inability', 'ineptness', 'clumsiness', 'awkwardness']
senticnet['amative'] = [0.531, 0.673, -0.276, 0.275, '#joyful', '#interesting', 0.401, 'amorous', 'amorousness', 'amatory', 'enamoredness', 'puppy_love']
senticnet['amativeness'] = [0.982, -0.72, 0, 0.615, '#joyful', '#surprising', 0.772, 'sexual_desire', 'concupiscence', 'physical_attraction', 'prurience', 'pruriency']
senticnet['amatory'] = [0.531, 0.673, -0.276, 0.275, '#joyful', '#interesting', 0.401, 'amorous', 'amorousness', 'enamoredness', 'amative', 'puppy_love']
senticnet['amaze'] = [0, -0.735, 0, 0, '#surprising', '#surprising', 0.245, 'fantastic', 'grand', 'pose', 'marvel', 'wonderful']
senticnet['amaze_friend'] = [-0.052, -0.197, -0.179, 0.219, '#surprising', '#admirable', 0.062, 'amuse_child', 'entertain_child', 'add_two_numbers', 'delight_child', 'make_child_laugh']
senticnet['amazed'] = [0.045, -0.662, 0, 0.363, '#surprising', '#admirable', 0.357, 'astounded', 'astonished', 'astound', 'surprise', 'amazing']
senticnet['amazement'] = [0, -1, 0, 0, '#surprising', '#surprising', 0.333, 'astonishment', 'awe', 'marvel', 'perplex', 'amaze']
senticnet['amazing'] = [0.045, -0.662, 0, 0.363, '#surprising', '#admirable', 0.357, 'astounded', 'astonished', 'astound', 'surprise', 'amazed']
senticnet['amazingly'] = [0.045, -0.664, 0, 0.363, '#surprising', '#admirable', 0.357, 'astonishingly', 'surprised', 'surprising', 'surprisedly', 'surprisingly']
senticnet['amazon'] = [-0.687, 0, 0.947, -0.839, '#angry', '#disgusting', -0.824, 'popinjay', 'poll', 'bird', 'lovebird', 'parrot']
senticnet['ambassador'] = [0.029, 0.157, -0.074, 0.12, '#interesting', '#admirable', 0.077, 'supervisor', 'management', 'master', 'president', 'despot']
senticnet['ambidextrous'] = [0, 0, -0.901, -0.703, '#scared', '#disgusting', -0.535, 'duplicitous', 'deceitful', 'double-dealing', 'janus-faced', 'two-handed']
senticnet['ambiguity'] = [0, 0, 0.801, -0.933, '#angry', '#disgusting', -0.578, 'amphibology', 'amphiboly', 'parisology', 'ambivalence', 'equivocation']
senticnet['ambition'] = [0.053, 0.207, -0.073, 0.165, '#interesting', '#admirable', 0.117, 'motivation', 'go_job', 'reinforce', 'resume', 'effort']
senticnet['ambitious'] = [0.913, -0.833, 0, 0.739, '#joyful', '#surprising', 0.828, 'pushful', 'pushy', 'aspirant', 'aspiring', 'wishful']
senticnet['ambiversion'] = [-0.648, 0, 0.574, -0.89, '#sad', '#disgusting', -0.704, 'gregariousness', 'sociability', 'openness', 'nakedness', 'extraversion']
senticnet['ambulance'] = [0, 0, -0.131, -0.149, '#scared', '#disgusting', -0.093, 'dentist_office', 'hospital', 'doctor_office', 'emergency_ward', 'prosthesis']
senticnet['ambulant_plague'] = [-0.861, 0, 0.825, -0.544, '#sad', '#angry', -0.743, 'pestis', 'plague', 'pestilence', 'pest', 'bubonic_plague']
senticnet['ambush'] = [0.02, 0.162, 0, 0.062, '#interesting', '#admirable', 0.081, 'catch', 'trap', 'bait_trap', 'lure', 'decoy']
senticnet['amebic_dysentery'] = [-0.892, 0, 0.702, -0.671, '#sad', '#angry', -0.755, 'dysentery', 'amoebic_dysentery', 'shigellosis', 'bacillary_dysentery', 'infectious_disease']
senticnet['amelia'] = [-0.579, 0, 0.888, -0.883, '#angry', '#disgusting', -0.783, 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder', 'congenital_abnormality']
senticnet['ameliorating'] = [0.618, -0.604, 0, 0.747, '#joyful', '#admirable', 0.656, 'corrective', 'remedial', 'bettering', 'ameliorative', 'amelioratory']
senticnet['ameliorative'] = [0.618, -0.604, 0, 0.747, '#joyful', '#admirable', 0.656, 'corrective', 'remedial', 'ameliorating', 'bettering', 'amelioratory']
senticnet['amelioratory'] = [0.618, -0.604, 0, 0.747, '#joyful', '#admirable', 0.656, 'corrective', 'remedial', 'ameliorating', 'ameliorative', 'bettering']
senticnet['amenability'] = [0.637, -0.911, 0, 0.757, '#surprising', '#admirable', 0.768, 'manageability', 'manageableness', 'docility', 'obedience', 'tractability']
senticnet['amenable'] = [0.933, -0.755, 0, 0.89, '#joyful', '#admirable', 0.859, 'susceptible', 'tractable', 'pliable', 'capable', 'vulnerable']
senticnet['amend'] = [0.881, -0.869, 0, 0.688, '#joyful', '#surprising', 0.813, 'better', 'improve', 'make_look_better', 'meliorate', 'enrich']
senticnet['amendable'] = [0.779, -0.882, 0, 0.521, '#joyful', '#surprising', 0.727, 'corrigible', 'correctable', 'improvable', 'reformable', 'redeemable']
senticnet['amendment'] = [0, 0.173, -0.067, 0.126, '#interesting', '#admirable', 0.077, 'democracy', 'empire', 'realm', 'unite', 'international']
senticnet['amends'] = [-0.759, 0, 0.805, -0.709, '#sad', '#angry', -0.758, 'atonement', 'expiation', 'punitive_damage', 'exemplary_damages', 'compensation']
senticnet['amentia'] = [-0.602, 0, 0.827, -0.762, '#angry', '#disgusting', -0.73, 'slowness', 'mental_retardation', 'backwardness', 'subnormality', 'retardation']
senticnet['american'] = [0, 0.195, 0, 0.097, '#interesting', '#admirable', 0.097, 'combination', 'teller', 'money_place', 'money_storage', 'money_hold']
senticnet['american_coin'] = [0.98, 0.945, 0, 0, '#joyful', '#interesting', 0.642, 'small_coin', 'monetary_unit', 'currency_unit', 'form_of_money', 'small_currency']
senticnet['american_express'] = [0.965, 0.845, 0, 0, '#joyful', '#interesting', 0.603, 'credit_card', 'profit', 'mastercard', 'audit', 'back_to_black']
senticnet['american_flag'] = [0.076, 0.067, 0, 0.056, '#joyful', '#interesting', 0.066, 'rubble', 'ground', 'ground_material', 'abrasive', 'asphalt']
senticnet['american_forest'] = [0.03, 0.068, -0.061, 0.062, '#interesting', '#admirable', 0.033, 'pacific_northwest', 'thermal', 'treetop', 'animals', 'zoo']
senticnet['american_money'] = [0, 0.112, 0.071, 0.089, '#interesting', '#admirable', 0.043, 'currency_unit', 'american_coin', 'money_unit', 'form_of_money', 'dollar_change']
senticnet['american_sport'] = [0, -0.081, 0, 0.075, '#surprising', '#admirable', 0.052, 'popular_sport_america', 'popular_game', 'rough_sport', 'team_sport', 'type_of_sport']
senticnet['amethyst'] = [0.037, 0.073, 0.027, 0.072, '#interesting', '#admirable', 0.052, 'sapphire', 'birth_stone', 'turquoise', 'gemstone', 'precious_stone']
senticnet['amiability'] = [0.544, -0.712, 0, 0.727, '#surprising', '#admirable', 0.661, 'jolity', 'jolliness', 'joviality', 'humor', 'temper']
senticnet['amiable'] = [0.206, 0.151, -0.165, 0.169, '#joyful', '#admirable', 0.12, 'know_other', 'charisma', 'sexual_attraction', 'start_conversation', 'enjoy_company']
senticnet['amiableness'] = [0.657, -0.56, 0, 0.749, '#joyful', '#admirable', 0.655, 'sweetness_and_light', 'condescension', 'condescendingness', 'mellowness', 'friendliness']
senticnet['amicability'] = [0.608, 0.647, -0.266, 0.325, '#joyful', '#interesting', 0.438, 'amicably', 'amicable', 'amicableness', 'brotherly', 'brother_like']
senticnet['amicable'] = [0.608, 0.647, -0.266, 0.325, '#joyful', '#interesting', 0.438, 'amicably', 'amicableness', 'amicability', 'brotherly', 'brother_like']
senticnet['amicableness'] = [0.608, 0.647, -0.266, 0.325, '#joyful', '#interesting', 0.438, 'amicably', 'amicable', 'amicability', 'brotherly', 'brother_like']
senticnet['amicably'] = [0.608, 0.647, -0.266, 0.325, '#joyful', '#interesting', 0.438, 'amicable', 'amicableness', 'amicability', 'brotherly', 'brother_like']
senticnet['amiss'] = [-0.732, 0, 0.787, -0.662, '#sad', '#angry', -0.727, 'wrong', 'haywire', 'bad', 'out_of_whack', 'malfunctioning']
senticnet['ammonification'] = [0.789, -0.925, 0, 0.964, '#surprising', '#admirable', 0.893, 'permeation', 'carbonation', 'impregnation', 'saturation', 'diffusion']
senticnet['ammunition'] = [0, 0, -0.731, -0.746, '#scared', '#disgusting', -0.492, 'automatic', 'firearm', 'gun', 'weapon', 'projectile']
senticnet['amnesia'] = [-0.969, 0, 0.907, -0.959, '#sad', '#disgusting', -0.945, 'brain_damage', 'loss_ofawareness', 'concussion', 'unconscious', 'death']
senticnet['amnesty'] = [0.73, -0.569, 0, 0.621, '#joyful', '#admirable', 0.64, 'exemption', 'unsusceptibility', 'diplomatic_immunity', 'indemnity', 'impunity']
senticnet['amoeba'] = [0, 0.065, 0.021, 0.052, '#interesting', '#admirable', 0.032, 'microscopic', 'tiny_organism', 'microbe', 'heron', 'single_celled']
senticnet['amoebic_dysentery'] = [-0.892, 0, 0.702, -0.671, '#sad', '#angry', -0.755, 'amebic_dysentery', 'dysentery', 'shigellosis', 'bacillary_dysentery', 'infectious_disease']
senticnet['amok'] = [-0.072, 0.192, 0.634, -0.635, '#angry', '#disgusting', -0.383, 'murderously', 'amuck', 'murderousness', 'misocainea', 'misogyny']
senticnet['amoralism'] = [0.95, -0.772, 0, 0.578, '#joyful', '#surprising', 0.767, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['amorous'] = [0.531, 0.673, -0.276, 0.275, '#joyful', '#interesting', 0.401, 'amorousness', 'amatory', 'enamoredness', 'amative', 'puppy_love']
senticnet['amorousness'] = [0.531, 0.673, -0.276, 0.275, '#joyful', '#interesting', 0.401, 'amorous', 'amatory', 'enamoredness', 'amative', 'puppy_love']
senticnet['amorphous'] = [-0.646, 0, 0.557, -0.739, '#sad', '#disgusting', -0.647, 'formless', 'unformed', 'shapeless', 'unshaped', 'unshapen']
senticnet['amount'] = [0, 0.236, 0.031, 0.158, '#interesting', '#admirable', 0.121, 'quantity', 'rate', 'item_worth', 'all_of_it', 'amount_charge']
senticnet['amount_charge'] = [0, 0.266, 0, 0.141, '#interesting', '#admirable', 0.136, 'money_term', 'item_worth', 'like_price', 'sticker', 'like_cost']
senticnet['amount_due'] = [-0.048, 0.268, 0, 0.158, '#interesting', '#admirable', 0.126, 'item_value', 'payment_amount', 'amount_pay', 'value_amount', 'amount_money']
senticnet['amount_money'] = [-0.026, 0.254, 0, 0.147, '#interesting', '#admirable', 0.125, 'value_amount', 'amount_pay', 'item_value', 'sticker', 'amount_due']
senticnet['amount_nothing'] = [-0.122, -0.006, -0.143, 0.061, '#sad', '#scared', -0.066, 'feel_heat', 'fly_around', 'close_together', 'act_foolish', 'smoke_joint']
senticnet['amount_owe'] = [-0.063, 0.288, -0.095, 0.171, '#interesting', '#admirable', 0.1, 'money_owe', 'money_due', 'account_term', 'money_payment', 'money_loss']
senticnet['amount_pay'] = [-0.041, 0.263, 0, 0.159, '#interesting', '#admirable', 0.127, 'amount_due', 'amount_money', 'item_value', 'value_amount', 'tag']
senticnet['amount_water'] = [0, 0.72, 0, 0.767, '#interesting', '#admirable', 0.496, 'liquid_unit', 'liquid_measure', 'small_size', 'liquid_measurement', 'small_amount']
senticnet['amour'] = [0.982, 0.851, 0, 0.902, '#joyful', '#admirable', 0.912, 'passion', 'beloved', 'human_emotion', 'wonderful_feeling', 'pleasant_emotion']
senticnet['amour_propre'] = [0.469, 0.661, -0.249, 0.23, '#joyful', '#interesting', 0.37, 'self-love', 'conceit', 'self-pride', 'egotism', 'self-importance']
senticnet['ampere'] = [0, 0.961, 0, 0.879, '#interesting', '#admirable', 0.613, 'electricity', 'electrical_unit', 'voltage', 'relevant', 'contemporary']
senticnet['amphibian'] = [0, 0, 0.073, 0, '#angry', '#angry', -0.024, 'cold-blooded', 'reptile', 'scaly', 'frog', 'aquatic']
senticnet['amphibology'] = [0.633, -0.67, 0, 0.776, '#surprising', '#admirable', 0.693, 'double_entendre', 'loophole', 'ambiguity', 'amphiboly', 'parisology']
senticnet['amphiboly'] = [0.633, -0.67, 0, 0.776, '#surprising', '#admirable', 0.693, 'double_entendre', 'loophole', 'amphibology', 'ambiguity', 'parisology']
senticnet['amphipod'] = [0.96, -0.772, 0, 0.929, '#joyful', '#admirable', 0.887, 'whale_louse', 'beach_flea', 'sand_hopper', 'sandhopper', 'sand_flea']
senticnet['amphiprostylar'] = [-0.659, 0, 0.878, -0.868, '#angry', '#disgusting', -0.802, 'amphistylar', 'apteral', 'amphiprostyle', 'porticoed', 'prostyle']
senticnet['amphiprostyle'] = [-0.659, 0, 0.878, -0.868, '#angry', '#disgusting', -0.802, 'amphistylar', 'amphiprostylar', 'apteral', 'porticoed', 'prostyle']
senticnet['amphisbaena'] = [-0.651, 0, 0.505, -0.919, '#sad', '#disgusting', -0.692, 'hellhound', 'mythical_being', 'dragon', 'roc', 'mythical_monster']
senticnet['amphistylar'] = [-0.659, 0, 0.878, -0.868, '#angry', '#disgusting', -0.802, 'apteral', 'amphiprostylar', 'amphiprostyle', 'porticoed', 'prostyle']
senticnet['amphitheater'] = [0.136, -0.056, -0.046, -0.03, '#joyful', '#surprising', 0.039, 'theater_hall', 'rehearse_room', 'theater_box', 'sound_control_room', 'soundstage']
senticnet['ample'] = [0, 0.931, 0, 0.793, '#interesting', '#admirable', 0.575, 'copious', 'plenteous', 'plentiful', 'rich', 'sizable']
senticnet['amplifier'] = [0.056, -0.019, 0.036, 0.073, '#joyful', '#admirable', 0.037, 'loud_sound', 'stereo', 'tuner', 'speaker', 'steam_engine']
senticnet['amplify'] = [-0.765, 0, 0.86, -0.667, '#sad', '#angry', -0.764, 'screw_up', 'fan', 'enhance', 'deepen', 'heat_up']
senticnet['amplitude'] = [0.023, 0.096, 0.021, 0.175, '#interesting', '#admirable', 0.091, 'frequency', 'ounce', 'echo', 'volume', 'loudness']
senticnet['amplitude_level'] = [-0.756, 0, 0.589, -0.719, '#sad', '#disgusting', -0.688, 'lowness', 'grind', 'immoderation', 'immoderateness', 'degree']
senticnet['ampulla'] = [0.619, -0.834, 0, 0.912, '#surprising', '#admirable', 0.788, 'hipflask', 'pocket_flask', 'flask', 'canteen', 'vacuum_flask']
senticnet['amuck'] = [-0.072, 0.192, 0.634, -0.635, '#angry', '#disgusting', -0.383, 'murderously', 'amok', 'murderousness', 'misocainea', 'misogyny']
senticnet['amuse'] = [0.933, 0.85, 0, 0.966, '#joyful', '#admirable', 0.916, 'amusement', 'enjoyment', 'make_laugh', 'funny', 'give_pleasure']
senticnet['amuse_child'] = [0.987, 0, 0, 0.868, '#joyful', '#admirable', 0.618, 'bounce_up_down', 'entertain_child', 'play_catch', 'add_two_numbers', 'play_fun']
senticnet['amuse_oneself'] = [0.959, 0, 0, 0.929, '#joyful', '#admirable', 0.629, 'celebrate_holiday', 'get_reaction', 'make_gift', 'give_pleasure', 'amuse']
senticnet['amusement'] = [0.969, 0.817, 0, 0.828, '#joyful', '#admirable', 0.871, 'amuse', 'recreation', 'keep_child_occupy', 'enjoyment', 'pleasure']
senticnet['amusement_park'] = [0.056, -0.019, 0.036, 0.073, '#joyful', '#admirable', 0.037, 'thrill_ride', 'have_fun', 'drag_race', 'enjoyment', 'roller_coaster']
senticnet['amusement_ride'] = [0.114, 0, -0.058, 0.114, '#joyful', '#admirable', 0.057, 'enjoy', 'ferris_wheel', 'merry_go_round', 'roller-coaster', 'carnival_ride']
senticnet['amyloid_plaque'] = [-0.81, 0, 0.741, -0.763, '#sad', '#disgusting', -0.771, 'spot', 'plaque', 'dentist', 'arterial_plaque', 'dental_plaque']
senticnet['amyotrophia'] = [-0.869, 0, 0.738, -0.93, '#sad', '#disgusting', -0.846, 'wasting_away', 'amyotrophy', 'tabes', 'kraurosis', 'symptom']
senticnet['amyotrophy'] = [-0.869, 0, 0.738, -0.93, '#sad', '#disgusting', -0.846, 'amyotrophia', 'wasting_away', 'tabes', 'kraurosis', 'symptom']
senticnet['anagnost'] = [0.546, -0.768, 0, 0.74, '#surprising', '#admirable', 0.685, 'exorcist', 'deacon', 'acolyte', 'holy_order', 'doorkeeper']
senticnet['anagram'] = [0, 0.84, 0, 0.786, '#interesting', '#admirable', 0.542, 'foot_motion', 'foot_action', 'foot_movement', 'stride', 'pace']
senticnet['analgesic'] = [0.969, 0.817, 0, 0.828, '#joyful', '#admirable', 0.871, 'ibuprofen', 'painkiller', 'medicine', 'pain_reliever', 'phenobarbital']
senticnet['analgetic'] = [0.761, -0.751, 0, 0.77, '#joyful', '#admirable', 0.761, 'analgesic', 'moderating', 'anodyne', 'weakening', 'alleviative']
senticnet['analphabet'] = [-0.901, 0, 0.76, -0.871, '#sad', '#disgusting', -0.844, 'illiterate', 'illiterateic', 'functional_illiterate', 'ignoramus', 'know_nothing']
senticnet['analphabetic'] = [-0.901, 0, 0.76, -0.871, '#sad', '#disgusting', -0.844, 'analphabet', 'illiterate', 'functional_illiterate', 'ignoramus', 'know_nothing']
senticnet['analphabetism'] = [-0.784, 0, 0.707, -0.868, '#sad', '#disgusting', -0.786, 'mental_block', 'uncreativeness', 'stupidity', 'illiteracy', 'inability']
senticnet['analysis'] = [0, 0.78, 0, 0.734, '#interesting', '#admirable', 0.505, 'investigation', 'come_up_new_idea', 'reach_conclusion', 'study_fact', 'come_up_idea']
senticnet['analyst'] = [0.711, 0, 0, 0, '#joyful', '#joyful', 0.237, 'chemist', 'expert', 'scientist', 'esaminatore', 'physicist']
senticnet['analyze'] = [0, -0.092, 0, 0.08, '#surprising', '#admirable', 0.057, 'examine', 'look_detail', 'observe', 'determine_truth', 'find_truth']
senticnet['analyze_book'] = [0, 0.848, 0, 0.971, '#interesting', '#admirable', 0.606, 'review', 'book', 'read_book', 'write_review', 'review_book']
senticnet['anamnesis'] = [0.685, -0.896, 0, 0.609, '#joyful', '#surprising', 0.73, 'mental_faculty', 'faculty', 'module', 'remembrance', 'retentiveness']
senticnet['anarchic'] = [-0.891, 0, 0.678, -0.62, '#sad', '#angry', -0.73, 'undisciplined', 'uncontrolled', 'uncontrolledal', 'irrepressible', 'uncontrollable']
senticnet['anarchical'] = [-0.891, 0, 0.678, -0.62, '#sad', '#angry', -0.73, 'undisciplined', 'anarchic', 'uncontrolled', 'irrepressible', 'uncontrollable']
senticnet['anarchism'] = [-0.819, -0.715, 0.843, -0.726, '#sad', '#angry', -0.558, 'lack_of_rules', 'fascism', 'despot', 'tyrant', 'nazism']
senticnet['anarchy'] = [-0.868, 0, 0.859, -0.918, '#sad', '#disgusting', -0.882, 'mess', 'family_activity', 'work_together', 'roller_coaster', 'watch_comedy']
senticnet['anathemize'] = [-0.836, 0, 0.555, -0.642, '#sad', '#disgusting', -0.678, 'call_down', 'stir', 'call_forth', 'conjure', 'bring_up']
senticnet['anatomy'] = [0, 0.078, 0, 0.096, '#interesting', '#admirable', 0.058, 'animal', 'study_of_structure', 'body_organ', 'analysis', 'human_organ']
senticnet['anchoritic'] = [-0.948, 0, 0.779, -0.858, '#sad', '#disgusting', -0.862, 'eremitic', 'eremitical', 'cloistered', 'unworldly', 'hermitic']
senticnet['ancient'] = [0, 0.078, 0, 0.096, '#interesting', '#admirable', 0.058, 'ancient_rome', 'past', 'age', 'ancient_artifact', 'century']
senticnet['ancient_artifact'] = [0.086, -0.107, 0.064, 0, '#joyful', '#surprising', 0.043, 'art_piece', 'lifetime', 'museum', 'vintage', 'collectibles']
senticnet['ancient_rome'] = [-0.038, 0.092, 0.07, 0.1, '#interesting', '#admirable', 0.028, 'gladiator', 'civilization', 'church_build', 'coliseum', 'every_town']
senticnet['anemone'] = [0, 0.068, -0.065, 0.081, '#interesting', '#admirable', 0.028, 'flower', 'windflower', 'leaves', 'plant', 'bright_petals']
senticnet['anergy'] = [-0.65, 0, 0.744, -0.802, '#angry', '#disgusting', -0.732, 'upset', 'disorder', 'immunodeficiency', 'immunological_disorder', 'immunosuppression']
senticnet['anesthesia'] = [-0.651, 0, 0.824, -0.869, '#angry', '#disgusting', -0.781, 'put_to_sleep', 'operation', 'general_anesthesia', 'surgery', 'local_anesthesia']
senticnet['anesthetic'] = [-0.612, 0, 0.572, -0.839, '#sad', '#disgusting', -0.674, 'numb', 'benumbed', 'insensible', 'emotionless', 'asleep']
senticnet['anfractuous'] = [-0.93, 0, 0.861, -0.504, '#sad', '#angry', -0.765, 'knotty', 'contorted', 'writhed', 'writhen', 'crooked']
senticnet['angel'] = [0.99, 0, 0, 0.982, '#joyful', '#admirable', 0.657, 'god', 'spiritual', 'saint', 'prayer', 'dogma']
senticnet['angelic'] = [0.936, -0.815, 0, 0.83, '#joyful', '#admirable', 0.86, 'cherubic', 'lovely', 'adorable', 'endearing', 'lovable']
senticnet['anger'] = [-0.339, -0.14, 0.217, -0.584, '#sad', '#disgusting', -0.333, 'angry', 'hear_bad_news', 'mad', 'frustration', 'hate']
senticnet['angered'] = [-0.137, 0.145, 0.624, -0.638, '#angry', '#disgusting', -0.418, 'enraged', 'furious', 'infuriated', 'maddened', 'indignantly']
senticnet['angina'] = [-0.756, 0, 0.84, -0.633, '#sad', '#angry', -0.743, 'inflammatory_disease', 'gastroenteritis', 'stomach_flu', 'intestinal_flu', 'pelvic_inflammatory_disease']
senticnet['angioedema'] = [-0.998, 0, 0.605, -0.764, '#sad', '#disgusting', -0.789, 'dropsy', 'atrophedema', 'giant_hives', 'periodic_edema', 'lymphedema']
senticnet['angioplasty'] = [-0.502, 0, 0.596, -0.766, '#angry', '#disgusting', -0.621, 'operation', 'surgery', 'surgical_operation', 'surgical_procedure', 'surgical_process']
senticnet['angle'] = [0, 0.917, 0, 0.929, '#interesting', '#admirable', 0.615, 'incline_plane', 'mountain_side', 'facet', 'apex', 'height']
senticnet['angle_grinder'] = [0, 0, -0.732, -0.935, '#scared', '#disgusting', -0.556, 'hatchet', 'sword', 'knife', 'nuclear_bomb', 'atomic_bomb']
senticnet['angler'] = [0.073, -0.022, 0, 0, '#joyful', '#surprising', 0.032, 'fisherman', 'informal_rod', 'archaic_fisher', 'rare_piscator', 'fishing_line']
senticnet['anglophobe'] = [-0.559, 0, 0.689, -0.806, '#angry', '#disgusting', -0.685, 'abominator', 'loather', 'mortal', 'hater', 'person']
senticnet['angrily'] = [-0.161, 0.179, 0.568, -0.612, '#angry', '#disgusting', -0.387, 'choler', 'ire', 'see_red', 'dander', 'hackles']
senticnet['angry'] = [0, 0, 0.869, 0, '#angry', '#angry', -0.29, 'anger', 'hate', 'mad', 'hatred', 'resentment']
senticnet['angry_behavior'] = [-0.103, -0.049, 0, -0.147, '#sad', '#disgusting', -0.067, 'adjust_seat', 'road_rage', 'fasten_seatbelt', 'traffic_jam', 'skid_mark']
senticnet['angry_emotion'] = [0, 0, 0.959, 0, '#angry', '#angry', -0.32, 'arrogance', 'dislike', 'psychosis', 'anger', 'hurt_feeling']
senticnet['angry_man'] = [-0.944, 0, 0.129, -0.971, '#sad', '#disgusting', -0.681, 'trouble', 'anger', 'fury', 'rage', 'fight']
senticnet['angry_mob'] = [-0.211, 0.078, -0.146, -0.117, '#sad', '#scared', -0.132, 'picket', 'rally', 'against', 'protest', 'riot']
senticnet['angry_person'] = [0, -0.005, -0.048, -0.155, '#scared', '#disgusting', -0.066, 'victim', 'news_reporter', 'fire_weapon', 'use_weapon', 'use_gun']
senticnet['angst'] = [-0.878, 0, 0.924, -0.966, '#angry', '#disgusting', -0.923, 'embarrassment', 'consternation', 'humility', 'hysteria', 'nervousness']
senticnet['anguish'] = [-0.585, 0, -0.391, -0.182, '#sad', '#scared', -0.386, 'feeling_guilt', 'feel_bad', 'bad_feeling', 'death_love', 'get_fired']
senticnet['anguished'] = [0, 0, 0.704, -0.735, '#angry', '#disgusting', -0.48, 'pain', 'hurt', 'tormented', 'tortured', 'rage']
senticnet['angular_shape'] = [0.601, -0.879, 0, 0.5, '#joyful', '#surprising', 0.66, 'fold', 'crease', 'plication', 'crimp', 'flexure']
senticnet['angularity'] = [0.957, -0.749, 0, 0.987, '#joyful', '#admirable', 0.898, 'fold', 'crease', 'plication', 'crimp', 'flexure']
senticnet['angulation'] = [0.592, -0.913, 0, 0.61, '#surprising', '#admirable', 0.705, 'folding', 'change_of_shape', 'narrowing', 'elongation', 'fold']
senticnet['animal'] = [0, -0.101, 0, 0, '#surprising', '#surprising', 0.034, 'mammal', 'cage', 'reptile', 'wildlife', 'zoo']
senticnet['animal_dwell'] = [-0.968, 0, 0.995, 0, '#sad', '#angry', -0.654, 'animal_house', 'animal_home', 'animal_live', 'acreage', 'animal_place']
senticnet['animal_eat'] = [0, 0.105, 0.015, 0.068, '#interesting', '#admirable', 0.053, 'make_meal', 'able_eat', 'bait_trap', 'eat_rice', 'provide_food']
senticnet['animal_enclosure'] = [0, 0.073, 0.025, 0.131, '#interesting', '#admirable', 0.06, 'animal_place', 'animal_home', 'animal_house', 'homestead', 'crop_place']
senticnet['animal_fancier'] = [-0.615, 0, 0.606, -0.539, '#sad', '#angry', -0.587, 'enthusiast', 'cat_fancier', 'horseman', 'horse_fancier', 'fancier']
senticnet['animal_flesh'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'veal', 'beef', 'food_group', 'cereal', 'curry']
senticnet['animal_fur'] = [0, 0, 0.07, 0, '#angry', '#angry', -0.023, 'animal_hair', 'animal_skin', 'dog_fur', 'fluffy_animal', 'furry']
senticnet['animal_furry'] = [-0.036, 0.11, 0, 0.177, '#interesting', '#admirable', 0.084, 'domestic_pet', 'cute', 'woolly_animal', 'hairy', 'fuzzy_animal']
senticnet['animal_group'] = [-0.851, 0, 0.683, -0.84, '#sad', '#disgusting', -0.791, 'pack', 'strain', 'biological_group', 'brood', 'litter']
senticnet['animal_hair'] = [0, -0.101, 0, 0, '#surprising', '#surprising', 0.034, 'animal_fur', 'animal_skin', 'dog_fur', 'fluffy_animal', 'furry']
senticnet['animal_hide'] = [-0.104, -0.032, 0.057, -0.052, '#sad', '#angry', -0.06, 'animal_skin', 'striped', 'animal_pelt', 'animal_fur', 'waterproof']
senticnet['animal_home'] = [0, 0.076, 0.024, 0.137, '#interesting', '#admirable', 0.063, 'kennel', 'hive', 'lair', 'habitat', 'beehive']
senticnet['animal_house'] = [0, 0.076, 0.024, 0.137, '#interesting', '#admirable', 0.063, 'animal_dwell', 'animal_home', 'animal_place', 'cow_home', 'homestead']
senticnet['animal_instinct'] = [0, 0, -0.998, -0.768, '#scared', '#disgusting', -0.589, 'animal_behavior', 'fixed_pattern_of_behavior', 'overeact', 'instinct', 'impulse']
senticnet['animal_live'] = [0, 0.088, 0, 0.088, '#interesting', '#admirable', 0.059, 'animal_house', 'animal_place', 'animal_dwell', 'animal_home', 'cow_home']
senticnet['animal_order'] = [-0.927, 0, 0.64, -0.529, '#sad', '#angry', -0.699, 'perching_bird', 'percher', 'thyreophoran', 'marginocephalian', 'euronithopod']
senticnet['animal_part'] = [0, -0.01, 0.041, -0.065, '#angry', '#disgusting', -0.032, 'claws', 'paw', 'long_tail', 'sharp_tooth', 'fang']
senticnet['animal_pelt'] = [-0.104, -0.032, 0.057, -0.052, '#sad', '#angry', -0.06, 'animal_skin', 'striped', 'animal_hide', 'animal_fur', 'endangered']
senticnet['animal_person'] = [0, 0.773, 0, 0.844, '#interesting', '#admirable', 0.539, 'responsibility', 'obligation', 'ask_nicely', 'help_person', 'meet_need']
senticnet['animal_place'] = [0, 0.1, 0.023, 0.122, '#interesting', '#admirable', 0.066, 'cow_home', 'crop_place', 'raise_animal', 'field_crop', 'animal_house']
senticnet['animal_plant'] = [0.054, 0, 0, 0.056, '#joyful', '#admirable', 0.037, 'plant_animal', 'fauna', 'live_organism', 'flora', 'grow_place']
senticnet['animal_product'] = [0.754, 0, 0, 0.729, '#joyful', '#admirable', 0.494, 'food', 'biodegradable', 'pet', 'organic', 'toys']
senticnet['animal_shelter'] = [0.749, 0, 0, 0, '#joyful', '#joyful', 0.25, 'warm_bed', 'alleyway', 'doghouse', 'veterinarian_office', 'cage']
senticnet['animal_skin'] = [-0.026, 0, 0.05, 0, '#sad', '#angry', -0.025, 'animal_fur', 'animal_hide', 'waterproof', 'animal_pelt', 'striped']
senticnet['animal_sound'] = [0.029, 0, 0, 0.112, '#joyful', '#admirable', 0.047, 'sound', 'noise', 'decibel', 'loudness', 'audio']
senticnet['animal_type'] = [0.052, 0.119, 0, 0.141, '#interesting', '#admirable', 0.104, 'neigh', 'domestic_animal', 'rover', 'wild_animal', 'mammary_gland']
senticnet['animalism'] = [-0.776, 0, 0.809, -0.898, '#angry', '#disgusting', -0.828, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['animals'] = [0.03, 0.068, -0.061, 0.062, '#interesting', '#admirable', 0.033, 'pacific_northwest', 'thermal', 'treetop', 'american_forest', 'zoo']
senticnet['animate'] = [0.056, 0.165, -0.118, 0.228, '#interesting', '#admirable', 0.11, 'always_read', 'bold', 'option', 'activity', 'game_action']
senticnet['animate_being'] = [-0.975, 0, 0.677, -0.955, '#sad', '#disgusting', -0.869, 'stunt', 'game', 'mutant', 'invertebrate', 'varmint']
senticnet['animated'] = [0.689, -0.544, 0, 0.511, '#joyful', '#surprising', 0.581, 'lively', 'enlivened', 'spirited', 'reanimated', 'vital']
senticnet['animated_cartoon'] = [0.789, -0.518, 0, 0.947, '#joyful', '#admirable', 0.751, 'flick', 'cartoon', 'short_subject', 'toon', 'newsreel']
senticnet['animating'] = [0.843, -0.818, 0, 0.624, '#joyful', '#surprising', 0.762, 'exhilarating', 'invigorating', 'enlivening', 'refreshing', 'restorative']
senticnet['animation'] = [0.935, -0.858, 0, 0, '#joyful', '#surprising', 0.598, 'liveliness', 'excitement', 'art_form', 'art', 'film']
senticnet['anime'] = [0.743, 0, 0, 0.999, '#joyful', '#admirable', 0.581, 'manga', 'cartoon', 'japanese_animation', 'movie', 'film']
senticnet['animosity'] = [-0.989, 0, 0.871, -0.976, '#sad', '#disgusting', -0.945, 'grudge', 'hostility', 'loathe', 'bitterness', 'aggressive']
senticnet['animus'] = [0, 0.146, 0.723, -0.665, '#angry', '#disgusting', -0.414, 'bad_blood', 'belligerently', 'hostilely', 'aggressiveness', 'antagonism']
senticnet['anisette'] = [0.693, -0.945, 0, 0.713, '#surprising', '#admirable', 0.784, 'cordial', 'maraschino', 'ratafia', 'pastis', 'ratafee']
senticnet['ankle'] = [-0.037, -0.027, 0.065, -0.029, '#sad', '#angry', -0.035, 'leg', 'toe', 'hold_canvas', 'foot', 'heel']
senticnet['ankle_bracelet'] = [0.789, -0.518, 0, 0.947, '#joyful', '#admirable', 0.751, 'jewelry', 'jewellery', 'anklet', 'bangle', 'armilla']
senticnet['anklet'] = [-0.869, 0, 0.831, -0.795, '#sad', '#angry', -0.832, 'jewelry', 'jewellery', 'bangle', 'ankle_bracelet', 'armilla']
senticnet['annals'] = [0, 0.105, 0, 0.084, '#interesting', '#admirable', 0.063, 'archive', 'print_medium', 'quiet_place', 'written', 'media']
senticnet['annelid'] = [-0.716, 0, 0.605, -0.623, '#sad', '#disgusting', -0.648, 'medicinal_leech', 'horseleech', 'leech', 'leech_worm', 'segmented_worm']
senticnet['annelid_worm'] = [-0.103, -0.049, 0, -0.147, '#sad', '#disgusting', -0.067, 'medicinal_leech', 'horseleech', 'annelid', 'leech', 'segmented_worm']
senticnet['annex'] = [0, 0.31, -0.257, 0.286, '#interesting', '#admirable', 0.113, 'appoint', 'contribution', 'demand', 'elect', 'receive']
senticnet['annihilating'] = [0.518, -0.635, 0, 0.529, '#surprising', '#admirable', 0.561, 'disrespectful', 'undeferential', 'devastating', 'insolent', 'undutiful']
senticnet['annihilation'] = [-0.982, 0, 0.516, -0.908, '#sad', '#disgusting', -0.802, 'devastation', 'atomization', 'pulverization', 'vaporization', 'destruction']
senticnet['anniversary'] = [0.124, -0.195, -0.124, 0.063, '#joyful', '#surprising', 0.086, 'birthday', 'occasion', 'new_baby', 'holiday', 'cake_candle']
senticnet['anniversary_gift'] = [0.796, -0.847, 0, 0, '#joyful', '#surprising', 0.548, 'birthday_gift', 'christmas_present', 'gift', 'gamble_game', 'greeting']
senticnet['announced'] = [0.843, -0.935, 0, 0.952, '#surprising', '#admirable', 0.91, 'asserted', 'avowed', 'professed', 'alleged', 'declared']
senticnet['announcement'] = [0, 0.81, 0, 0.852, '#interesting', '#admirable', 0.554, 'remark', 'message', 'reply', 'word', 'sender']
senticnet['annoy'] = [0, 0, 0.784, 0, '#angry', '#angry', -0.261, 'annoyance', 'irritate', 'bother', 'fury', 'bothersome']
senticnet['annoy_bug'] = [-0.915, 0, 0.563, -0.931, '#sad', '#disgusting', -0.803, 'flea', 'bug', 'disturb', 'fly', 'insect']
senticnet['annoy_mom'] = [0, -0.055, 0.087, -0.11, '#angry', '#disgusting', -0.047, 'play_orchestra', 'play_tune', 'make_musical_sound', 'play_music', 'perform_of_music']
senticnet['annoy_neighbor'] = [0, 0, 0.762, 0, '#angry', '#angry', -0.254, 'create_music', 'make_music', 'play_music', 'produce_musical_sound', 'perform_of_music']
senticnet['annoy_other_person'] = [-0.106, 0, 0, -0.072, '#sad', '#disgusting', -0.059, 'forget_name', 'wave_arm', 'voice_opinion', 'reply_question', 'receive_email']
senticnet['annoy_person'] = [-0.906, 0, 0.877, -0.911, '#sad', '#disgusting', -0.898, 'talk_too_much', 'bored_person', 'tired_person', 'boring_movie', 'boring_show']
senticnet['annoy_sound'] = [-0.177, -0.049, 0.035, -0.081, '#sad', '#disgusting', -0.081, 'bad_music', 'squeak', 'high_music_note', 'bang', 'loud']
senticnet['annoy_your_dad'] = [-0.997, 0, 0.216, -0.921, '#sad', '#disgusting', -0.711, 'make_noise', 'talk_too_much', 'annoy', 'annoy_your_mom', 'talk_loud']
senticnet['annoy_your_mom'] = [-0.997, 0, 0.216, -0.921, '#sad', '#disgusting', -0.711, 'make_noise', 'talk_too_much', 'annoy', 'annoy_your_dad', 'talk_loud']
senticnet['annoyance'] = [0, 0, 0.3, 0, '#angry', '#angry', -0.1, 'irritate', 'offend', 'bother', 'bothersome', 'aggravation']
senticnet['annoyed'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['annoying'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'vexatious', 'teasing']
senticnet['annoying_bug'] = [-0.029, -0.037, 0.165, -0.121, '#angry', '#disgusting', -0.093, 'nuisance_insect', 'parasite', 'small_fly', 'fly_away', 'small_insect']
senticnet['annoying_sound'] = [-0.957, 0, 0.549, -0.993, '#sad', '#disgusting', -0.833, 'bad_music', 'stress', 'noise', 'rowdy', 'loud']
senticnet['annual'] = [0, 0, 0, 0.7, '#admirable', '#admirable', 0.233, 'yearly_celebration', 'year', 'twelve_months', 'age', 'centennial']
senticnet['annual_celebration'] = [0.164, -0.087, -0.062, 0, '#joyful', '#surprising', 0.063, 'party_time', 'yearly_celebration', 'special_day', 'celebrate', 'new_baby']
senticnet['annul'] = [-0.654, 0, 0.561, -0.58, '#sad', '#disgusting', -0.598, 'stet', 'set_aside', 'break', 'cancel', 'strike_down']
senticnet['anodyne'] = [0.761, -0.751, 0, 0.77, '#joyful', '#admirable', 0.761, 'analgesic', 'analgetic', 'moderating', 'weakening', 'alleviative']
senticnet['anomalopteryx'] = [-0.681, 0, 0.956, -0.909, '#angry', '#disgusting', -0.849, 'giant_moa', 'moa', 'ratite', 'ratite_bird', 'flightless_bird']
senticnet['anomaly'] = [-0.686, 0, 0.946, -0.628, '#sad', '#angry', -0.753, 'abnormality', 'abnormalcy', 'birth_defect', 'congenital_anomaly', 'congenital_defect']
senticnet['anomic'] = [-0.106, 0.176, 0.629, -0.642, '#angry', '#disgusting', -0.4, 'alienated', 'alienation', 'disaffection', 'estrange', 'alienate']
senticnet['anomic_aphasia'] = [-0.82, 0, 0.953, -0.878, '#angry', '#disgusting', -0.884, 'auditory_aphasia', 'acoustic_aphasia', 'word_deafness', 'nominal_aphasia', 'aphasia']
senticnet['anorgasmia'] = [-0.756, 0, 0.504, -0.772, '#sad', '#disgusting', -0.677, 'astasia', 'disablement', 'hearing_impairment', 'hearing_disorder', 'bow_legs']
senticnet['another_activity'] = [0.047, 0, 0, 0.171, '#joyful', '#admirable', 0.073, 'human_motion', 'human_movement', 'water_activity', 'athletic_activity', 'sport_activity']
senticnet['another_house'] = [0.032, 0.158, -0.085, 0.248, '#interesting', '#admirable', 0.118, 'residence', 'live_area', 'domestic_dwell', 'live_quarter', 'dwell_place']
senticnet['another_name'] = [0, 0.066, -0.058, 0.095, '#interesting', '#admirable', 0.034, 'interjection', 'like_car', 'red_cross', 'traffic_cop', 'gas_electric']
senticnet['another_person'] = [0.099, 0.167, -0.059, 0.165, '#interesting', '#admirable', 0.124, 'handshake', 'know_language', 'use_language', 'talk_another_person', 'find_another_person']
senticnet['another_place'] = [0.04, 0.144, -0.074, 0.122, '#interesting', '#admirable', 0.077, 'taxi_cab', 'abroad', 'foreign_country', 'transit', 'elsewhere']
senticnet['another_planet'] = [0, 0.965, 0, 0.804, '#interesting', '#admirable', 0.59, 'mars', 'far_away', 'discover_universe', 'astrology', 'alien']
senticnet['answer'] = [0, 0.88, 0, 0.855, '#interesting', '#admirable', 0.578, 'question', 'question_answering', 'inquiry', 'query', 'reply']
senticnet['answer_back'] = [-0.067, 0.073, -0.07, 0.197, '#interesting', '#admirable', 0.044, 'retort', 'response', 'write_back', 'question_answer', 'interrogation']
senticnet['answer_phone'] = [0, 0.995, 0, 0.807, '#interesting', '#admirable', 0.601, 'talk_telephone', 'call_mom', 'call', 'answer_telephone', 'call_friend_phone']
senticnet['answer_question'] = [0.929, 0.861, 0, 0.862, '#joyful', '#admirable', 0.884, 'communicate_other_person', 'transfer_knowledge', 'understand_better', 'supply_answer', 'commit_to_memory']
senticnet['answer_telephone'] = [0, 0.85, 0, 0.933, '#interesting', '#admirable', 0.594, 'learn_listen', 'answer_phone', 'receive_letter', 'call_mom', 'receive_phone_call']
senticnet['ant'] = [0, -0.073, 0.116, -0.121, '#angry', '#disgusting', -0.055, 'gypsy_moth', 'mole_cricket', 'japanese_beetle', 'cucumber_beetle', 'ladybug']
senticnet['ant_hill'] = [0.034, 0.111, -0.094, 0.148, '#interesting', '#admirable', 0.066, 'up_mountain', 'hike_trail', 'tress', 'fallen_leaf', 'grass']
senticnet['antacid'] = [-0.533, 0, 0.954, -0.541, '#angry', '#disgusting', -0.676, 'ranitidine', 'histamine_blocker', 'gastric_ranitidine', 'alkalizer', 'antiacid']
senticnet['antagonism'] = [0, 0.151, 0.717, -0.663, '#angry', '#disgusting', -0.41, 'class_feeling', 'belligerently', 'hostilely', 'aggressiveness', 'bad_blood']
senticnet['antagonist'] = [-0.755, 0, 0.907, 0, '#sad', '#angry', -0.554, 'argue', 'rival', 'disagreement', 'opposition', 'anti']
senticnet['antagonize'] = [-0.929, 0, 0.905, -0.746, '#sad', '#angry', -0.86, 'nettle', 'bother', 'devil', 'chafe', 'rag']
senticnet['antenna'] = [0.16, 0.067, 0, 0.083, '#joyful', '#admirable', 0.103, 'aerial', 'sensory', 'arthropods', 'insect', 'connection']
senticnet['anterior_jugular_vein'] = [0.614, -0.89, 0, 0.51, '#joyful', '#surprising', 0.671, 'jugular', 'external_jugular_vein', 'internal_jugular_vein', 'vein', 'vena']
senticnet['anthrax'] = [-0.871, 0, 0.936, -0.985, '#angry', '#disgusting', -0.931, 'diabetes', 'chicken_pox', 'out_work', 'schizophrenia', 'ill_health']
senticnet['anthropoid'] = [-0.939, 0, 0.508, -0.582, '#sad', '#disgusting', -0.676, 'inhuman', 'bloodless', 'apelike', 'nonhuman', 'nonhumanal']
senticnet['anthropoidal'] = [-0.939, 0, 0.508, -0.582, '#sad', '#disgusting', -0.676, 'inhuman', 'bloodless', 'apelike', 'anthropoid', 'nonhuman']
senticnet['anthropophagite'] = [-0.73, 0, 0.734, -0.786, '#angry', '#disgusting', -0.75, 'primitive', 'headhunter', 'cannibal', 'anthropophagus', 'barbarian']
senticnet['anthropophagus'] = [-0.73, 0, 0.734, -0.786, '#angry', '#disgusting', -0.75, 'primitive', 'headhunter', 'cannibal', 'barbarian', 'anthropophagite']
senticnet['anthroposophy'] = [0.661, -0.666, 0, 0.685, '#surprising', '#admirable', 0.671, 'ethical_code', 'theosophy', 'system_of_rules', 'logic', 'method']
senticnet['anti'] = [-0.126, 0.115, -0.064, -0.119, '#sad', '#disgusting', -0.065, 'opposition', 'fight_against', 'rival', 'uprise', 'go_against']
senticnet['antiacid'] = [-0.533, 0, 0.954, -0.541, '#angry', '#disgusting', -0.676, 'antacid', 'histamine_blocker', 'gastric_antacid', 'alkalizer', 'ranitidine']
senticnet['antianxiety_drug'] = [-0.866, 0, 0.646, -0.888, '#sad', '#disgusting', -0.8, 'minor_tranquilizer', 'put_to_sleep', 'tranquilizer', 'anxiolytic', 'anxiolytic_drug']
senticnet['antibacterial'] = [0.768, -0.631, 0, 0.717, '#joyful', '#admirable', 0.705, 'antibiotic_drug', 'medication', 'kill_germ', 'antibiotic', 'bacitracin']
senticnet['antibiotic'] = [-0.973, 0, -0.7, 0, '#sad', '#scared', -0.558, 'medicine', 'analgesic', 'ibuprofen', 'painkiller', 'pain_reliever']
senticnet['antibiotic_drug'] = [0.768, -0.631, 0, 0.717, '#joyful', '#admirable', 0.705, 'antibacterial', 'medication', 'kill_germ', 'antibiotic', 'bacitracin']
senticnet['antiblack'] = [0.779, -0.821, 0, 0.66, '#joyful', '#surprising', 0.753, 'homophobic', 'loaded', 'racist', 'jaundiced', 'discriminatory']
senticnet['antic'] = [0.9, -0.802, 0, 0.568, '#joyful', '#surprising', 0.757, 'joke', 'dirty_trick', 'prank', 'trick', 'caper']
senticnet['anticipant'] = [0, 0.779, 0, 0.993, '#interesting', '#admirable', 0.591, 'expectant', 'expectantly', 'anticipative', 'fevered', 'hectic']
senticnet['anticipate'] = [0, 0.988, 0, 0.733, '#interesting', '#admirable', 0.574, 'hopeful', 'hopefully', 'look_forward', 'probable', 'optimism']
senticnet['anticipation'] = [0, 0.6, 0, 0, '#interesting', '#interesting', 0.2, 'adoration', 'fondness', 'enthusiasm', 'optimism', 'affect']
senticnet['anticipative'] = [0, 0.745, 0, 0.89, '#interesting', '#admirable', 0.545, 'expectant', 'expectantly', 'anticipant', 'fevered', 'hectic']
senticnet['anticipator'] = [-0.985, 0, 0.599, -0.932, '#sad', '#disgusting', -0.839, 'diviner', 'intellect', 'anticipant', 'intellectual', 'illusionist']
senticnet['anticipatory_breach'] = [-0.106, 0, -0.053, -0.24, '#sad', '#disgusting', -0.133, 'breach_of_warranty', 'breach_of_trust', 'partial_breach', 'breach_of_contract', 'constructive_breach']
senticnet['antidote'] = [-0.601, 0, 0.544, -0.628, '#sad', '#disgusting', -0.591, 'remedy', 'cure', 'therapeutic', 'curative', 'atropine']
senticnet['antifeminism'] = [-0.684, 0, 0.949, -0.63, '#sad', '#angry', -0.754, 'chauvinism', 'male_chauvinism', 'sexism', 'sexual_discrimination', 'discrimination']
senticnet['antifungal'] = [0.932, -0.56, 0, 0.617, '#joyful', '#admirable', 0.703, 'lamisil', 'lamisil_agent', 'fungicide', 'antimycotic', 'antimycotic_agent']
senticnet['antifungal_agent'] = [0.932, -0.56, 0, 0.617, '#joyful', '#admirable', 0.703, 'antifungal', 'lamisil', 'fungicide', 'antimycotic', 'antimycotic_agent']
senticnet['antihypertensive'] = [-0.763, 0, 0.681, -0.578, '#sad', '#angry', -0.674, 'corticosteroid', 'corticoid', 'adrenal_cortical_steroid', 'spironolactone', 'spironolactone_drug']
senticnet['antihypertensive_drug'] = [-0.763, 0, 0.681, -0.578, '#sad', '#angry', -0.674, 'corticosteroid', 'corticoid', 'adrenal_cortical_steroid', 'antihypertensive', 'spironolactone']
senticnet['antimycotic'] = [0.932, -0.56, 0, 0.617, '#joyful', '#admirable', 0.703, 'antifungal', 'antifungal_agent', 'fungicide', 'lamisil', 'lamisil_agent']
senticnet['antimycotic_agent'] = [0.932, -0.56, 0, 0.617, '#joyful', '#admirable', 0.703, 'antifungal', 'antifungal_agent', 'fungicide', 'antimycotic', 'lamisil']
senticnet['antinomy'] = [-0.569, 0, 0.593, -0.595, '#angry', '#disgusting', -0.586, 'contradiction_in_terms', 'paradox', 'falsehood', 'falsity', 'untruth']
senticnet['antioxidant'] = [-0.028, 0, 0.052, 0, '#sad', '#angry', -0.027, 'exercise', 'exercise_regularly', 'physical_exercise', 'moderation', 'drink_plenty_water']
senticnet['antipathy'] = [-0.127, 0.193, 0.593, -0.627, '#angry', '#disgusting', -0.385, 'distaste', 'aversion', 'disapproval', 'disapprove', 'disapproving']
senticnet['antiquate'] = [-0.022, -0.051, 0.084, -0.166, '#angry', '#disgusting', -0.074, 'stifle', 'forgotten', 'old', 'touch_ground', 'seldom']
senticnet['antique'] = [0.07, 0.177, 0.028, 0.133, '#interesting', '#admirable', 0.117, 'worth', 'shilling', 'merit', 'monetary_value', 'value']
senticnet['antique_store'] = [0, 0.093, 0, 0.066, '#interesting', '#admirable', 0.053, 'gallery_open', 'museum', 'art_show', 'collectibles', 'vintage']
senticnet['antisemitism'] = [-0.721, 0, -0.825, -0.841, '#scared', '#disgusting', -0.796, 'racism', 'intolerant', 'xenophobic', 'racist', 'nazism']
senticnet['antisocial'] = [0, 0, 0.896, -0.962, '#angry', '#disgusting', -0.619, 'personality_disorder', 'sociopathic', 'psychopathic_personality', 'disturbance', 'schizoid']
senticnet['antitrust_case'] = [0.804, -0.993, 0, 0.507, '#joyful', '#surprising', 0.768, 'action_at_law', 'civil_action', 'counterclaim', 'custody_case', 'lis_pendens']
senticnet['antiviral'] = [-0.818, 0, 0.767, -0.936, '#sad', '#disgusting', -0.84, 'protease_inhibitor', 'indinavir', 'nelfinavir', 'ritonavir', 'saquinavir']
senticnet['antler'] = [0.063, 0.089, 0.036, 0.146, '#interesting', '#admirable', 0.087, 'horn', 'jew_harp', 'brass_instrument', 'trumpet', 'crash_cymbal']
senticnet['antler_moth'] = [-0.103, -0.049, 0, -0.147, '#sad', '#disgusting', -0.067, 'armyworm', 'cerapteryx_graminis', 'noctuid', 'heliothis_moth', 'moth']
senticnet['antsy'] = [-0.867, 0, -0.812, 0, '#sad', '#scared', -0.56, 'fretful', 'fidgetiness', 'fidgety', 'stewing', 'impatiently']
senticnet['anus'] = [0, 0, 0, -0.081, '#disgusting', '#disgusting', -0.027, 'bowel', 'scrotum', 'shoulder', 'liver', 'waist']
senticnet['anxiety'] = [-0.788, 0, -1.0, 0, '#sad', '#scared', -0.596, 'panic', 'confusion', 'fear', 'worry', 'nervousness']
senticnet['anxiety_disorder'] = [-0.823, 0, -0.72, 0, '#sad', '#scared', -0.514, 'illiteracy', 'schizophrenia', 'censorship', 'ill_health', 'big_monster']
senticnet['anxiety_hysteria'] = [-0.552, 0, 0.736, -0.714, '#angry', '#disgusting', -0.667, 'neurosis', 'neuroticism', 'psychoneurosis', 'hysterocatalepsy', 'hysterical_neurosis']
senticnet['anxiolytic'] = [-0.866, 0, 0.646, -0.888, '#sad', '#disgusting', -0.8, 'minor_tranquilizer', 'put_to_sleep', 'antianxiety_drug', 'tranquilizer', 'tranquilizer_drug']
senticnet['anxiolytic_drug'] = [-0.866, 0, 0.646, -0.888, '#sad', '#disgusting', -0.8, 'minor_tranquilizer', 'put_to_sleep', 'antianxiety_drug', 'anxiolytic', 'tranquilizer']
senticnet['anxious'] = [-0.878, 0, -0.919, 0, '#sad', '#scared', -0.599, 'hysteria', 'concerned', 'distressfully', 'perturbing', 'disturbing']
senticnet['anxiously'] = [-0.723, 0, -0.778, 0, '#sad', '#scared', -0.5, 'uneasily', 'apprehensively', 'apprehensive', 'worried', 'solicitousness']
senticnet['anxiousness'] = [-0.774, 0, -0.989, 0, '#sad', '#scared', -0.588, 'worried', 'solicitous', 'solicitously', 'solicitude', 'solicitousness']
senticnet['anybody'] = [-0.444, -0.154, 0, -0.364, '#sad', '#disgusting', -0.218, 'nothing', 'zero', 'nonsense', 'nobody', 'none']
senticnet['anything'] = [-0.444, -0.154, 0, -0.364, '#sad', '#disgusting', -0.218, 'nothing', 'none', 'zero', 'nobody', 'nonsense']
senticnet['aortic_stenosis'] = [-0.815, 0, 0.684, -0.813, '#sad', '#disgusting', -0.771, 'rhinostenosis', 'enterostenosis', 'laryngostenosis', 'stenosis', 'mitral_stenosis']
senticnet['apart'] = [-0.182, 0, -0.104, 0, '#sad', '#scared', -0.095, 'tear_apart', 'time_out', 'painful_injury', 'break_apart', 'rest_time']
senticnet['apartment'] = [0, -0.069, 0, 0, '#surprising', '#surprising', 0.023, 'rooms', 'home', 'furnitures', 'kitchen', 'flats']
senticnet['apartment_house'] = [0, 0.973, 0, 0.818, '#interesting', '#admirable', 0.597, 'capitol', 'government_building', 'house', 'white_house', 'government']
senticnet['apatetic_coloration'] = [0.62, -0.598, 0, 0.967, '#joyful', '#admirable', 0.728, 'aposematic_coloration', 'warning_coloration', 'protective_coloration', 'cryptic_coloration', 'coloration']
senticnet['apathetic'] = [-0.849, 0, -0.829, 0, '#sad', '#scared', -0.559, 'unconcern', 'feeling_no_interestunconcerned', 'unconcernedly', 'apathetically', 'indifferently']
senticnet['apathetically'] = [-0.709, 0, 0, -0.927, '#sad', '#disgusting', -0.545, 'impassiveness', 'impassivity', 'emotionlessness', 'unemotionality', 'stolidity']
senticnet['apathy'] = [-0.79, 0, 0.759, -0.703, '#sad', '#angry', -0.751, 'emotionlessness', 'impassivity', 'impassiveness', 'phlegm', 'stolidity']
senticnet['ape'] = [-0.627, 0, 0.667, -0.853, '#angry', '#disgusting', -0.716, 'copycat', 'emulator', 'epigonr', 'imitator', 'epigon']
senticnet['apelike'] = [-0.5, 0, 0.97, -0.521, '#angry', '#disgusting', -0.664, 'simulated', 'apish', 'parrotlike', 'imitative', 'mimic']
senticnet['aper'] = [-0.676, 0, 0.759, -0.805, '#angry', '#disgusting', -0.747, 'epigone', 'epigon', 'parrot', 'mortal', 'person']
senticnet['aperient'] = [-0.501, 0, 0.582, -0.573, '#angry', '#disgusting', -0.552, 'purgative', 'cathartic', 'physic', 'laxative', 'phenolphthalein']
senticnet['aperitif'] = [0.032, 0.075, 0, 0, '#joyful', '#interesting', 0.036, 'alcohol', 'stimulate_appetite', 'beverage', 'adult_drink', 'bartender']
senticnet['aperture'] = [-0.03, 0.079, 0, 0.142, '#interesting', '#admirable', 0.064, 'build_open', 'use_farm', 'house_open', 'open', 'home_entrance']
senticnet['apex'] = [0.062, 0.1, 0.074, 0.117, '#interesting', '#admirable', 0.068, 'angle', 'semicircle', 'facet', 'edge', 'altitude']
senticnet['aphakia'] = [-0.793, 0, 0.927, -0.956, '#angry', '#disgusting', -0.892, 'disability', 'disablement', 'vision_defect', 'color_blindness', 'color_vision_deficiency']
senticnet['aphakic'] = [-0.638, 0, 0.625, -0.989, '#sad', '#disgusting', -0.751, 'visually_impaired_person', 'blind_person', 'myope', 'mortal', 'hyperope']
senticnet['aphasia'] = [-0.82, 0, 0.953, -0.878, '#angry', '#disgusting', -0.884, 'auditory_aphasia', 'acoustic_aphasia', 'word_deafness', 'nominal_aphasia', 'anomic_aphasia']
senticnet['aphasic'] = [-0.567, 0, 0.509, -0.832, '#sad', '#disgusting', -0.636, 'inarticulate', 'aphonic', 'speechless', 'unarticulated', 'dumb']
senticnet['aphonic'] = [-0.567, 0, 0.509, -0.832, '#sad', '#disgusting', -0.636, 'aphasic', 'inarticulate', 'speechless', 'unarticulated', 'dumb']
senticnet['aphrodisia'] = [0.718, -0.726, 0, 0.952, '#surprising', '#admirable', 0.799, 'love', 'concupiscence', 'lecherousness', 'lustfulness', 'amorousness']
senticnet['aphrodisiac'] = [0.884, 0.804, 0, 0, '#joyful', '#interesting', 0.563, 'stimulant', 'sexual_desire', 'melodic_noise', 'loud', 'lol']
senticnet['apish'] = [-0.5, 0, 0.97, -0.521, '#angry', '#disgusting', -0.664, 'simulated', 'imitative', 'parrotlike', 'apelike', 'mimic']
senticnet['apnea'] = [-0.036, -0.035, -0.073, -0.072, '#scared', '#disgusting', -0.049, 'eat_poison', 'commit_suicide', 'drug_addiction', 'drunk_drive', 'jump_off_cliff']
senticnet['apocalypse'] = [-0.968, 0, 0.501, -0.596, '#sad', '#disgusting', -0.688, 'calamity', 'catastrophe', 'tragedy', 'disaster', 'cataclysm']
senticnet['apocalyptic'] = [-0.955, 0, 0.739, -0.599, '#sad', '#angry', -0.764, 'foreboding', 'precursory', 'premonitory', 'prophetic', 'prophetical']
senticnet['apocalyptical'] = [-0.955, 0, 0.739, -0.599, '#sad', '#angry', -0.764, 'foreboding', 'precursory', 'premonitory', 'apocalyptic', 'prophetic']
senticnet['apologize'] = [-0.984, 0, -0.872, 0, '#sad', '#scared', -0.619, 'emotion', 'regret', 'forgiveness', 'pardon', 'beg']
senticnet['apology'] = [0.875, 0, 0, 0.802, '#joyful', '#admirable', 0.559, 'polite', 'care', 'ask_for_forgiveness', 'forgive', 'take_care']
senticnet['apomictic'] = [-0.686, 0, 0.779, -0.863, '#angry', '#disgusting', -0.776, 'agamic', 'agamous', 'agamogenetic', 'parthenogenetic', 'asexual']
senticnet['apomixis'] = [-0.778, 0, 0.764, -0.548, '#sad', '#angry', -0.697, 'pullulation', 'asexual_reproduction', 'blastogenesis', 'budding', 'fission']
senticnet['apomorphine'] = [0.627, -0.72, 0, 0.974, '#surprising', '#admirable', 0.774, 'analgesic', 'morphia', 'anodyne', 'painkiller', 'pain_pill']
senticnet['aposematic_coloration'] = [0.62, -0.598, 0, 0.967, '#joyful', '#admirable', 0.728, 'protective_coloration', 'warning_coloration', 'apatetic_coloration', 'cryptic_coloration', 'coloration']
senticnet['apostate'] = [-0.669, 0, 0.709, -0.881, '#angry', '#disgusting', -0.753, 'untrue', 'unfaithful', 'treacherous', 'perfidious', 'punic']
senticnet['apotheosis'] = [0.84, -0.561, 0, 0.561, '#joyful', '#surprising', 0.654, 'jimdandy', 'jimhickey', 'crackerjack', 'class_act', 'humdinger']
senticnet['appal'] = [-0.917, 0, -0.778, 0, '#sad', '#scared', -0.565, 'horrify', 'horror', 'horrifying', 'atrocious', 'horrifyingly']
senticnet['appall'] = [-0.727, 0, -0.796, 0, '#sad', '#scared', -0.508, 'horrify', 'horror', 'horrifying', 'atrocious', 'horrifyingly']
senticnet['appanage'] = [0.639, -0.979, 0, 0.648, '#surprising', '#admirable', 0.755, 'benefit', 'fringe_benefit', 'provision', 'gratuity', 'tip']
senticnet['apparel'] = [0.032, 0.075, 0, 0, '#joyful', '#interesting', 0.036, 'nightgown', 'garment', 'clothes', 'dress', 'shirt']
senticnet['apparent_motion'] = [-0.947, 0, 0.866, -0.912, '#sad', '#disgusting', -0.908, 'movement', 'optical_illusion', 'motion', 'apparent_movement', 'mirage']
senticnet['apparent_movement'] = [-0.947, 0, 0.866, -0.912, '#sad', '#disgusting', -0.908, 'movement', 'apparent_motion', 'motion', 'optical_illusion', 'mirage']
senticnet['appeal'] = [0, 0.793, 0, 0.784, '#interesting', '#admirable', 0.526, 'witness', 'new_law', 'make_judgment', 'court_action', 'contact_lawyer']
senticnet['appear'] = [0, 0.948, 0, 0.831, '#interesting', '#admirable', 0.593, 'come', 'heap', 'arrive', 'accept', 'tow']
senticnet['appear_beautiful'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'hot_girl', 'good_looking', 'good_appearance', 'beauty', 'enjoy_view']
senticnet['appear_dumb'] = [0, 0, 0.87, -0.874, '#angry', '#disgusting', -0.581, 'mess_up', 'dumb', 'mess', 'goof', 'bungle']
senticnet['appear_smart'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'smart', 'intelligent', 'smart_person', 'become_better', 'wisdom']
senticnet['appear_suddenly'] = [-0.105, 0, -0.098, 0.067, '#sad', '#scared', -0.045, 'corner_well', 'gain_speed', 'travel_road', 'go_fast', 'drive_down_street']
senticnet['appearance'] = [0.769, 0, 0, 0, '#joyful', '#joyful', 0.256, 'look', 'glimpse', 'ship_part', 'quick_look', 'vision']
senticnet['appease'] = [0.683, -0.704, 0, 0.527, '#joyful', '#surprising', 0.638, 'tranquilize', 'tranquillize', 'calm_down', 'quieten', 'calm']
senticnet['appeasing'] = [-0.606, 0, 0.694, -0.651, '#angry', '#disgusting', -0.65, 'conciliative', 'placating', 'placative', 'placatory', 'pacific']
senticnet['appellative'] = [0.904, -0.588, 0, 0.736, '#joyful', '#admirable', 0.743, 'naming', 'denotative', 'designative', 'extensional', 'referent']
senticnet['appendage'] = [0, 0.103, 0, 0.111, '#interesting', '#admirable', 0.071, 'body_extremity', 'projection', 'limb', 'organ', 'tailpiece']
senticnet['appendant'] = [0.993, -0.893, 0, 0.891, '#joyful', '#surprising', 0.926, 'mounted', 'affixed', 'basifixed', 'glued', 'pasted']
senticnet['appetence'] = [-0.872, 0, 0.919, -0.899, '#angry', '#disgusting', -0.897, 'appetite', 'appetency', 'craving', 'addiction', 'desire']
senticnet['appetency'] = [-0.872, 0, 0.919, -0.899, '#angry', '#disgusting', -0.897, 'appetite', 'craving', 'appetence', 'addiction', 'desire']
senticnet['appetent'] = [0.919, -0.717, 0, 0.569, '#joyful', '#surprising', 0.735, 'desirous', 'avid', 'thirsty', 'devouring', 'envious']
senticnet['appetite'] = [0.769, 0, 0, 0, '#joyful', '#joyful', 0.256, 'make_breakfast', 'enjoy_meal', 'put_food_into_mouth', 'prepare_meal', 'prepare_breakfast']
senticnet['appetizer'] = [0.062, 0, 0.027, 0.055, '#joyful', '#admirable', 0.03, 'porridge', 'meal', 'broth', 'hamburger', 'hearty']
senticnet['appetizingness'] = [-0.797, 0, 0.992, -0.884, '#angry', '#disgusting', -0.891, 'flavorsomeness', 'flavoursomeness', 'savoriness', 'succulence', 'succulency']
senticnet['applaud'] = [0.354, -0.231, -0.051, 0, '#joyful', '#surprising', 0.178, 'happiness', 'emotional_reaction', 'appreciation', 'clap', 'hypnotic_effect']
senticnet['applause'] = [0.973, 0, 0, 0.878, '#joyful', '#admirable', 0.617, 'entertain_other_person', 'perform_on_stage', 'enjoy_show', 'giggle', 'clap']
senticnet['apple'] = [0, 0.085, 0, 0.146, '#interesting', '#admirable', 0.077, 'adam_and_eve', 'garden', 'fruit', 'tree', 'outdoor']
senticnet['apple_juice'] = [0.087, -0.003, 0, 0, '#joyful', '#surprising', 0.03, 'juice', 'soft_drink', 'orange_juice', 'ice_tea', 'cider']
senticnet['apple_pie'] = [0.079, -0.065, 0, 0, '#joyful', '#surprising', 0.048, 'ice_cream', 'a_lot_of_food', 'pumpkin_pie', 'muffin', 'cupcake']
senticnet['apple_polisher'] = [-0.558, 0, 0.588, -0.65, '#angry', '#disgusting', -0.599, 'crawler', 'bootlicker', 'fawner', 'web', 'groveler']
senticnet['apple_rust'] = [-0.512, 0, 0.781, -0.851, '#angry', '#disgusting', -0.715, 'flax_rust', 'flax_rust_fungus', 'blister_rust', 'rust_fungus', 'fungus']
senticnet['apple_tree'] = [0, 0.081, 0.03, 0.126, '#interesting', '#admirable', 0.059, 'plant', 'tree', 'fruit', 'apple', 'red']
senticnet['appliance_store'] = [0.101, 0.099, 0, 0.169, '#joyful', '#admirable', 0.123, 'family_home', 'apartment', 'renovation', 'kitchen', 'electronics']
senticnet['application'] = [0, 0, 0, 0.075, '#admirable', '#admirable', 0.025, 'job_application', 'resume', 'respond', 'questionnaire', 'help_understand']
senticnet['applique'] = [0.548, -0.611, 0, 0.556, '#surprising', '#admirable', 0.572, 'patchwork', 'darn', 'mend', 'stitch', 'stitchery']
senticnet['apply'] = [0, 0.196, -0.131, 0.192, '#interesting', '#admirable', 0.086, 'employ', 'attempt', 'resume', 'labor', 'police_work']
senticnet['appoint'] = [0, 0.932, 0, 0.769, '#interesting', '#admirable', 0.567, 'annex', 'elect', 'demand', 'vote', 'duty']
senticnet['appointment'] = [0, 0.75, 0, 0.984, '#interesting', '#admirable', 0.578, 'instance', 'year', 'rendezvous', 'years', 'yesterday']
senticnet['appointment_book'] = [0, 0.094, 0, 0, '#interesting', '#interesting', 0.031, 'highlighter_pen', 'notepad', 'memo_pad', 'pocket_notebook', 'address_label']
senticnet['appraise'] = [0.853, 0.895, 0, 0, '#joyful', '#interesting', 0.583, 'upgrade', 'deflate', 'performance', 'evaluate', 'assess']
senticnet['appreciate'] = [0.819, 0, 0, 0.816, '#joyful', '#admirable', 0.545, 'self_satisfaction', 'enjoy_oneself', 'good_feeling', 'happiness', 'desire_entertain']
senticnet['appreciate_art'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'get_informed', 'learn_news', 'get_news', 'view_art', 'stimulate_mind']
senticnet['appreciate_music'] = [0.806, 0.776, 0, 0.761, '#joyful', '#interesting', 0.781, 'entertain_others', 'music_lover', 'relieve_boredom', 'like_music', 'entertain_audience']
senticnet['appreciated'] = [0.632, -0.612, 0, 0.732, '#joyful', '#admirable', 0.659, 'understood', 'apprehended', 'comprehended', 'interpreted', 'taken']
senticnet['appreciation'] = [0.906, 0.719, 0, 0.962, '#joyful', '#admirable', 0.862, 'new_idea', 'improve_performance', 'insight', 'increase_intelligence', 'inspiration']
senticnet['appreciatively'] = [0.468, 0.661, -0.252, 0.231, '#joyful', '#interesting', 0.369, 'gratefully', 'gratefulness', 'appreciativeness', 'thankfulness', 'unfearing']
senticnet['appreciativeness'] = [0.488, 0.661, -0.256, 0.244, '#joyful', '#interesting', 0.379, 'thankfulness', 'gratefulness', 'unafraid', 'intrepidly', 'audacious']
senticnet['appreciator'] = [0.753, -0.641, 0, 0.606, '#joyful', '#surprising', 0.667, 'enthusiast', 'enophile', 'lover', 'person', 'individual']
senticnet['apprehend'] = [0.951, -0.806, 0, 0.501, '#joyful', '#surprising', 0.753, 'understand', 'twig', 'digest', 'tumble', 'intuit']
senticnet['apprehended'] = [0.632, -0.612, 0, 0.732, '#joyful', '#admirable', 0.659, 'appreciated', 'understood', 'comprehended', 'interpreted', 'taken']
senticnet['apprehension'] = [0, 0, -0.3, 0, '#scared', '#scared', -0.1, 'apprehensiveness', 'shuddery', 'shivery', 'chilling', 'timidity']
senticnet['apprehensive'] = [-0.944, 0, -0.716, 0, '#sad', '#scared', -0.553, 'uneasily', 'anxiouslyly', 'anxiously', 'worried', 'solicitousness']
senticnet['apprehensively'] = [-0.937, 0, -0.941, 0, '#sad', '#scared', -0.626, 'anxiously', 'uneasily', 'apprehensive', 'worried', 'solicitousness']
senticnet['apprehensiveness'] = [-0.747, 0, 0.966, -0.807, '#angry', '#disgusting', -0.84, 'fear', 'fearfulness', 'foreboding', 'presentiment', 'boding']
senticnet['apprentice'] = [0.134, 0.1, -0.112, 0.246, '#joyful', '#admirable', 0.123, 'hard_worker', 'pupil', 'student', 'serious_student', 'much_information']
senticnet['approach'] = [0, 0.828, 0, 0.896, '#interesting', '#admirable', 0.575, 'quick_look', 'dealing_with_situation', 'solution', 'proposal', 'proceed']
senticnet['approachable'] = [0.859, -0.81, 0, 0.615, '#joyful', '#surprising', 0.761, 'get_table', 'accessible', 'reachable', 'handy', 'ready_to_hand']
senticnet['approbative'] = [0.585, 0.652, -0.268, 0.313, '#joyful', '#interesting', 0.427, 'affirmative', 'approve', 'approbatory', 'plausive', 'approved']
senticnet['approbatory'] = [0.585, 0.652, -0.268, 0.313, '#joyful', '#interesting', 0.427, 'affirmative', 'approbative', 'approve', 'plausive', 'approved']
senticnet['appropriate'] = [0.519, -0.991, 0, 0.741, '#surprising', '#admirable', 0.75, 'earmark', 'allot', 'set_aside', 'reserve', 'reserve_table']
senticnet['appropriateness'] = [0.541, -0.594, 0, 0.527, '#joyful', '#surprising', 0.554, 'fitness', 'quality', 'fittingness', 'convenience', 'suitability']
senticnet['approval'] = [0.934, 0.773, 0, 0.743, '#joyful', '#interesting', 0.817, 'confidence', 'adoration', 'sympathetic', 'esteem', 'confident']
senticnet['approve'] = [0.585, 0.652, -0.268, 0.313, '#joyful', '#interesting', 0.427, 'affirmative', 'approbative', 'approbatory', 'plausive', 'approved']
senticnet['approved'] = [0.585, 0.652, -0.268, 0.313, '#joyful', '#interesting', 0.427, 'affirmative', 'approbative', 'approve', 'approbatory', 'plausive']
senticnet['approving'] = [0.585, 0.652, -0.268, 0.313, '#joyful', '#interesting', 0.427, 'affirmative', 'approbative', 'approve', 'approbatory', 'plausive']
senticnet['approximate'] = [-0.715, 0, 0.8, -0.693, '#sad', '#angry', -0.736, 'approximative', 'rough', 'inexact', 'loose', 'odd']
senticnet['approximation'] = [-0.53, 0, 0.543, -0.992, '#angry', '#disgusting', -0.688, 'underestimation', 'underrating', 'underreckoning', 'dead_reckoning', 'underestimate']
senticnet['approximative'] = [-0.715, 0, 0.8, -0.693, '#sad', '#angry', -0.736, 'inexact', 'rough', 'approximate', 'loose', 'odd']
senticnet['apricot'] = [0, 0.102, 0.016, 0.076, '#interesting', '#admirable', 0.054, 'cherry', 'tomato', 'plum', 'cranberry', 'pineapple']
senticnet['apt'] = [0.819, 0.914, 0, 0, '#joyful', '#interesting', 0.578, 'appropriate', 'suitable', 'proper', 'liable', 'likely']
senticnet['apteral'] = [-0.659, 0, 0.878, -0.868, '#angry', '#disgusting', -0.802, 'amphistylar', 'amphiprostylar', 'amphiprostyle', 'porticoed', 'prostyle']
senticnet['aptitude'] = [0, 0, 0, 1, '#admirable', '#admirable', 0.333, 'admiration', 'trust', 'stun', 'stunned', 'good_emotion']
senticnet['aqua'] = [0.847, 0.759, 0, 0, '#joyful', '#interesting', 0.535, 'blue', 'water', 'bird_pet', 'indigo', 'cyan']
senticnet['aquarium'] = [0.078, -0.034, -0.046, 0.105, '#joyful', '#admirable', 0.057, 'ocean', 'underwater', 'pacific_ocean', 'sea', 'ocean_wave']
senticnet['aquatic'] = [0, 0, 0.073, 0, '#angry', '#angry', -0.024, 'cold-blooded', 'reptile', 'scaly', 'frog', 'amphibian']
senticnet['aquatic_life'] = [0.053, 0.073, -0.065, 0.104, '#interesting', '#admirable', 0.055, 'coral', 'small_fish', 'horizon', 'ocean', 'waves']
senticnet['aquatic_plant'] = [0.62, -0.598, 0, 0.967, '#joyful', '#admirable', 0.728, 'water_carpet', 'water_mat', 'golden_saxifrage', 'water_plant', 'hydrophyte']
senticnet['arachnid'] = [0, -0.042, 0.082, -0.073, '#angry', '#disgusting', -0.038, 'arthropod', 'social_insect', 'vermin', 'insect', 'fly_insect']
senticnet['arachnophobia'] = [-0.57, 0, 0.814, -0.936, '#angry', '#disgusting', -0.773, 'phobia', 'acarophobia', 'fear', 'zoophobia', 'cynophobia']
senticnet['arbiter'] = [0.026, 0.115, 0, 0.087, '#interesting', '#admirable', 0.076, 'negotiator', 'juror', 'judge_jury', 'gavel', 'judge']
senticnet['arbitrator'] = [0, 0.146, 0, 0.077, '#interesting', '#admirable', 0.074, 'negotiator', 'judge_jury', 'arbiter', 'decide_guilt', 'become_judge']
senticnet['arboreal'] = [0, 0, -0.756, -0.88, '#scared', '#disgusting', -0.545, 'tree-living', 'dendroidal', 'arborous', 'arboriform', 'arborary']
senticnet['arboretum'] = [0.026, 0, 0, 0.073, '#joyful', '#admirable', 0.033, 'state_park', 'park', 'meadow', 'grass', 'backyard']
senticnet['arc'] = [0.052, 0.086, 0.052, 0.224, '#interesting', '#admirable', 0.103, 'curve', 'octagon', 'spiral', 'no_corner', 'no_edge']
senticnet['arch'] = [0.029, 0.087, 0.065, 0.137, '#interesting', '#admirable', 0.063, 'archway', 'aisle', 'mat', 'passageway', 'right_angle']
senticnet['archaic'] = [-0.996, 0, 0, -0.817, '#sad', '#disgusting', -0.604, 'primal', 'beforehand', 'archaean', 'previous', 'untimely']
senticnet['archaic_fisher'] = [0.073, -0.022, 0, 0, '#joyful', '#surprising', 0.032, 'fisherman', 'informal_rod', 'angler', 'rare_piscator', 'fishing_line']
senticnet['archeological_remains'] = [0.62, -0.598, 0, 0.967, '#joyful', '#admirable', 0.728, 'collectible', 'fossil', 'object', 'remains', 'physical_object']
senticnet['archeologist'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'learn_history', 'gain_new_knowledge', 'accumulate_knowledge', 'well_test', 'learn_new_word']
senticnet['archeology'] = [-0.03, 0, -0.056, 0, '#sad', '#scared', -0.029, 'keep_fresh', 'appetizer', 'piece_of_meat', 'porridge', 'food']
senticnet['archery'] = [0, -0.079, 0.091, -0.198, '#angry', '#disgusting', -0.07, 'projectile', 'use_hunt', 'weapon', 'ammunition', 'firearm']
senticnet['architect'] = [0, 0.857, 0, 0.751, '#interesting', '#admirable', 0.536, 'building', 'vocation', 'finish_school', 'engineer', 'reporter']
senticnet['architect_office'] = [0, 0.821, 0, 0.738, '#interesting', '#admirable', 0.52, 'math_book', 'science_lab', 'math_class', 'band_room', 'bluegrass_band']
senticnet['architectural_structure'] = [0, 0.779, 0, 0.937, '#interesting', '#admirable', 0.572, 'large_build', 'build', 'home_build', 'architect', 'build_support']
senticnet['architectural_style'] = [0.578, -0.957, 0, 0.979, '#surprising', '#admirable', 0.838, 'perpendicular', 'perpendicular_style', 'gothic_architecture', 'style_of_architecture', 'type_of_architecture']
senticnet['architecture'] = [0, 0.108, 0, 0.175, '#interesting', '#admirable', 0.094, 'build_structure', 'city_area', 'small_building', 'building', 'manufacture_plant']
senticnet['archive'] = [0, 0.105, 0, 0.084, '#interesting', '#admirable', 0.063, 'annals', 'print_medium', 'quiet_place', 'written', 'media']
senticnet['archway'] = [0.029, 0.087, 0.065, 0.137, '#interesting', '#admirable', 0.063, 'aisle', 'arch', 'mat', 'passageway', 'walkway']
senticnet['arctic'] = [0, 0, 0.701, -0.824, '#angry', '#disgusting', -0.508, 'north_pole', 'cold_weather', 'snow', 'ice', 'cold']
senticnet['arctic_fox'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'polar_bear', 'baji', 'white_animal', 'white_rabbit', 'fuzzy_animal']
senticnet['ardor'] = [0.547, 0.664, -0.267, 0.28, '#joyful', '#interesting', 0.408, 'passion', 'thirstily', 'eagerness', 'avidity', 'avidness']
senticnet['arduous'] = [-0.825, 0, 0.58, -0.539, '#sad', '#angry', -0.648, 'tiring', 'wearing', 'wearying', 'hard', 'effortful']
senticnet['arduousness'] = [-0.646, 0, 0.928, -0.703, '#angry', '#disgusting', -0.759, 'difficulty', 'effortfulness', 'strenuousness', 'laboriousness', 'operoseness']
senticnet['area'] = [0.031, 0.117, 0.025, 0.133, '#interesting', '#admirable', 0.085, 'region', 'area_land', 'place', 'location', 'zone']
senticnet['area_land'] = [0, 0.093, 0.052, 0.127, '#interesting', '#admirable', 0.056, 'land_measurement', 'area', 'house_land', 'house_place', 'acreage']
senticnet['arena'] = [0.026, -0.036, 0, 0.091, '#surprising', '#admirable', 0.051, 'stadium', 'auditorium', 'television_station', 'music_hall', 'movie_theater']
senticnet['argal'] = [-0.799, 0, 0.667, -0.668, '#sad', '#disgusting', -0.711, 'wild_sheepi', 'wild_sheep', 'urial', 'white_sheep', 'mountain_sheep']
senticnet['argali'] = [-0.799, 0, 0.667, -0.668, '#sad', '#disgusting', -0.711, 'wild_sheep', 'argal', 'urial', 'white_sheep', 'mountain_sheep']
senticnet['argonon'] = [-0.871, 0, 0.949, -0.809, '#sad', '#angry', -0.876, 'chemical_element', 'element', 'noble_gas', 'inert_gas', 'atomic_number_54']
senticnet['arguable'] = [-0.856, 0, 0.749, -0.998, '#sad', '#disgusting', -0.868, 'controversial', 'contentious', 'disputable', 'disputed', 'polemic']
senticnet['argue'] = [-0.785, 0, 0.845, -0.812, '#angry', '#disgusting', -0.814, 'disagreement', 'antagonist', 'make_enemy', 'uprise', 'argument']
senticnet['argufy'] = [0.851, -0.745, 0, 0.836, '#joyful', '#admirable', 0.811, 'fall_out', 'debate', 'wrangle', 'spat', 'brawl']
senticnet['arguing'] = [0.957, -0.788, 0, 0.658, '#joyful', '#surprising', 0.801, 'firestorm', 'dispute', 'fight', 'conflict', 'polemic']
senticnet['argument'] = [-0.803, 0, 0.936, -0.711, '#sad', '#angry', -0.817, 'become_angry', 'disagreement', 'hurt_feeling', 'argue', 'angry_emotion']
senticnet['argumentation'] = [-0.69, 0, 0.697, -0.609, '#sad', '#angry', -0.665, 'casuistry', 'argument', 'logical_argument', 'line_of_reasoning', 'line']
senticnet['argumentative'] = [0, 0, 0.866, -0.733, '#angry', '#disgusting', -0.533, 'contentious', 'disputatious', 'disputative', 'eristic', 'eristical']
senticnet['aridness'] = [-0.738, 0, 0.931, -0.821, '#angry', '#disgusting', -0.83, 'dryness', 'thirstiness', 'xerostomia', 'dry_mouth', 'sereness']
senticnet['arise'] = [0, 0.135, -0.087, 0.123, '#interesting', '#admirable', 0.057, 'rise', 'lift', 'store_garage', 'go_upstairs', 'reflect_water']
senticnet['aristocracy'] = [0.976, -0.5, 0, 0.853, '#joyful', '#admirable', 0.776, 'knighthood', 'elite', 'elite_group', 'noblesse', 'peerage']
senticnet['aristocrat'] = [0.076, 0.096, -0.089, 0.167, '#interesting', '#admirable', 0.083, 'royal_person', 'royal_title', 'noble', 'regal', 'royalty']
senticnet['arithmetic'] = [0.076, 0.096, -0.089, 0.167, '#interesting', '#admirable', 0.083, 'statistic', 'mathematical_function', 'calculation', 'list_number', 'calculate']
senticnet['arm'] = [0, 0, -0.066, -0.071, '#scared', '#disgusting', -0.046, 'elbow', 'bandit', 'wrist', 'five_fingers', 'bendable']
senticnet['arm_around_neck'] = [0.177, 0.083, 0, 0.166, '#joyful', '#admirable', 0.142, 'keep_clothes_clean', 'soft_skin', 'make_pretty', 'cover_table', 'clean_cloth']
senticnet['arm_atomic_bomb'] = [-0.82, 0, 0.839, -0.724, '#sad', '#angry', -0.794, 'even_odds', 'hunt_game', 'commit_genocide', 'kill_other_person', 'corner_prey']
senticnet['arm_bomb'] = [-0.938, 0, 0.352, -0.936, '#sad', '#disgusting', -0.742, 'bomb', 'war', 'weapon', 'soldier', 'gun']
senticnet['arm_force'] = [0, 0.762, 0, 0.715, '#interesting', '#admirable', 0.492, 'military', 'attacker', 'army', 'soldier_group', 'samurai']
senticnet['arm_man'] = [0, 0, 0.762, -0.82, '#angry', '#disgusting', -0.527, 'steal', 'commit_crime', 'storm_fortress', 'even_odds', 'go_after']
senticnet['arm_movement'] = [0, 0.098, -0.047, 0.265, '#interesting', '#admirable', 0.105, 'hand_gesture', 'water_motion', 'hand_motion', 'water_action', 'water_relate']
senticnet['arm_oneself'] = [-0.05, 0, 0, -0.192, '#sad', '#disgusting', -0.081, 'declare_war', 'fight_man', 'prepare_army', 'armory', 'civil_war']
senticnet['arm_part'] = [0, 0, 0, 0.07, '#admirable', '#admirable', 0.023, 'body_member', 'body_extremity', 'body_appendage', 'appendage', 'above_leg']
senticnet['arm_weapon'] = [-0.967, 0, 0.761, -0.962, '#sad', '#disgusting', -0.897, 'notice_problem', 'smoke_joint', 'shovel_snow', 'war', 'fly_around']
senticnet['armchair'] = [0.875, 0.845, 0, 0, '#joyful', '#interesting', 0.573, 'sofa_bed', 'club_chair', 'sofa_hide_bed', 'chair', 'rock_chair']
senticnet['armed_forces'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'military', 'military_reserve', 'armed_services', 'military_machine', 'war_machine']
senticnet['armed_services'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'military', 'armed_forces', 'military_reserve', 'military_machine', 'war_machine']
senticnet['armet'] = [-0.595, 0, 0.887, -0.715, '#angry', '#disgusting', -0.732, 'helmet', 'basinet', 'casque', 'heaume', 'morion']
senticnet['armilla'] = [-0.869, 0, 0.831, -0.795, '#sad', '#angry', -0.832, 'jewelry', 'jewellery', 'anklet', 'ankle_bracelet', 'bangle']
senticnet['armoire'] = [0, 0.092, 0.016, 0.074, '#interesting', '#admirable', 0.05, 'beach_towel', 'pillowcase', 'bed_sheet', 'duvet_cover', 'comforter']
senticnet['armor'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'coat', 'suit', 'leather', 'sweater', 'belt']
senticnet['armored'] = [-0.897, 0, 0.945, -0.894, '#sad', '#angry', -0.912, 'bulletproof', 'mailed', 'lightly_armored', 'lightly_armoured', 'scaled']
senticnet['armored_car'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'tank', 'tank_destroyer', 'armored_vehicle', 'armoured_car', 'armored_personnel_carrier']
senticnet['armored_personnel_carrier'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'tank', 'tank_destroyer', 'armored_car', 'armoured_car', 'armored_vehicle']
senticnet['armored_vehicle'] = [-0.716, 0, 0.585, -0.514, '#sad', '#angry', -0.605, 'tank', 'tank_destroyer', 'armored_car', 'armoured_car', 'armored_personnel_carrier']
senticnet['armory'] = [0.766, -0.799, 0, 0, '#joyful', '#surprising', 0.522, 'harpoon', 'gulf', 'lake', 'river', 'bay']
senticnet['armoured_car'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'tank', 'tank_destroyer', 'armored_car', 'armored_vehicle', 'armored_personnel_carrier']
senticnet['armoured_vehicle'] = [-0.562, 0, 0.714, -0.895, '#angry', '#disgusting', -0.724, 'tank', 'tank_destroyer', 'armored_car', 'armoured_car', 'armored_personnel_carrier']
senticnet['army'] = [-0.041, 0, -0.072, -0.169, '#scared', '#disgusting', -0.094, 'infantry', 'attacker', 'soldier', 'military', 'samurai']
senticnet['army_boss'] = [0, 0.121, 0, 0.068, '#interesting', '#admirable', 0.063, 'rank', 'military_rank', 'military_order', 'general', 'sergeant']
senticnet['army_leader'] = [0.023, 0.079, 0, 0, '#joyful', '#interesting', 0.034, 'army_officer', 'army_rank', 'high_rank', 'military_position', 'army_boss']
senticnet['army_man'] = [0, 0, -0.075, -0.031, '#scared', '#disgusting', -0.035, 'army_person', 'fighter', 'police_man', 'warrior', 'sergent']
senticnet['army_navy'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'army_rank', 'army_leader', 'navy_rank', 'navy', 'navy_leader']
senticnet['army_officer'] = [0.028, 0.081, 0, 0, '#joyful', '#interesting', 0.036, 'military_position', 'army_rank', 'military_officer', 'military_rank', 'high_rank']
senticnet['army_person'] = [0, 0.878, 0, 0.925, '#interesting', '#admirable', 0.601, 'soldier', 'fighter', 'military', 'sergent', 'warrior']
senticnet['army_position'] = [0, 0.09, 0, 0, '#interesting', '#interesting', 0.03, 'military_position', 'military_rank', 'high_rank', 'army_rank', 'army_boss']
senticnet['army_rank'] = [0, 0.07, 0, 0, '#interesting', '#interesting', 0.023, 'army_leader', 'military_rank', 'high_rank', 'military_position', 'army_officer']
senticnet['army_title'] = [0.031, 0.079, 0, 0, '#joyful', '#interesting', 0.037, 'police_rank', 'military_rank', 'head_guy', 'army_boss', 'high_rank']
senticnet['army_unit'] = [0.031, 0.079, 0, 0, '#joyful', '#interesting', 0.037, 'military_force', 'attacker', 'soldier_group', 'army', 'military']
senticnet['armyworm'] = [-0.534, 0, 0.8, -0.619, '#angry', '#disgusting', -0.651, 'noctuid', 'underwing', 'antler_moth', 'heliothis_moth', 'moth']
senticnet['aroma'] = [0.958, 0, 0, 0.924, '#joyful', '#admirable', 0.627, 'odor', 'fragrance', 'scent', 'smell_good', 'good_smell']
senticnet['around'] = [0.049, 0.167, -0.053, 0.295, '#interesting', '#admirable', 0.153, 'four_sides', 'surround', 'six_sides', 'neighborhood', 'dolby_surround']
senticnet['around_corner'] = [0, 0.121, 0, 0.178, '#interesting', '#admirable', 0.1, 'rotate', 'change_direction', 'ninety_degree', 'left_right', 'rotate_movement']
senticnet['around_earth'] = [0, 0.819, 0, 0.833, '#interesting', '#admirable', 0.551, 'heavenly_body', 'star_planet', 'celestial_body', 'limitless', 'nothingness']
senticnet['arousal'] = [0.971, 0.751, 0, 0.896, '#joyful', '#admirable', 0.873, 'new_friendship', 'foreplay', 'warm_fuzzy_feeling', 'become_aroused', 'erection']
senticnet['arouse'] = [0.722, -0.764, 0, 0.946, '#surprising', '#admirable', 0.811, 'ask_for', 'elicit', 'enkindle', 'kindle', 'evoke']
senticnet['arraign'] = [-0.708, 0, 0.905, -0.84, '#angry', '#disgusting', -0.818, 'reproach', 'upbraid', 'criminate', 'charge', 'accuse']
senticnet['arrange'] = [0.703, 0.83, 0, 0.756, '#interesting', '#admirable', 0.763, 'neat_tidy', 'sort', 'orderly', 'organize', 'neatness']
senticnet['arrange_hair'] = [-0.025, 0, 0.068, 0, '#sad', '#angry', -0.031, 'make_hair_look_nice', 'comb_hair', 'fix_hair', 'groom_hair', 'style_hair']
senticnet['arrange_meet'] = [0, 0, 0, 0.077, '#admirable', '#admirable', 0.026, 'date', 'catch_up', 'contact_friend', 'chat', 'call_phone']
senticnet['arranged'] = [-0.906, 0, 0.533, -0.934, '#sad', '#disgusting', -0.791, 'incorporated', 'organized', 'configured', 'corporate', 'reorganized']
senticnet['arrangement'] = [0.995, 0.73, 0, 0.746, '#joyful', '#admirable', 0.824, 'get_rid', 'hand_out', 'business_transaction', 'arrange', 'develop']
senticnet['array'] = [0.757, -0.635, 0, 0.501, '#joyful', '#surprising', 0.631, 'panoply', 'row', 'table', 'tabular_array', 'matrix']
senticnet['arrayed'] = [-0.533, 0, 0.937, -0.802, '#angry', '#disgusting', -0.757, 'gowned', 'petticoated', 'surpliced', 'clad', 'caparisoned']
senticnet['arrears'] = [0.628, -0.607, 0, 0.532, '#joyful', '#surprising', 0.589, 'account_payable', 'payable', 'limited_liability', 'debt', 'indebtedness']
senticnet['arrest'] = [-0.759, 0, 0.892, -0.929, '#angry', '#disgusting', -0.86, 'send_to_jail', 'go_jail', 'put_in_jail', 'injustice', 'go_to_prison']
senticnet['arrest_criminal'] = [0.973, 0.734, 0, 0.897, '#joyful', '#admirable', 0.868, 'settle_argument', 'make_judgment', 'judge_person', 'go_court', 'tell_truth']
senticnet['arrest_police'] = [-0.258, -0.042, -0.206, -0.207, '#sad', '#disgusting', -0.21, 'feel_anger', 'get_arrested', 'die', 'call_help', 'end_life']
senticnet['arresting'] = [0.972, 0.943, 0, 0, '#joyful', '#interesting', 0.638, 'impressive', 'nail', 'nab', 'pick_up', 'apprehend']
senticnet['arrhythmia'] = [-0.83, 0, 0.987, -0.504, '#sad', '#angry', -0.774, 'heart_block', 'atrioventricular_block', 'bradycardia', 'ventricular_fibrillation', 'tachycardia']
senticnet['arrhythmic'] = [-0.569, 0, 0.849, -0.618, '#angry', '#disgusting', -0.679, 'convulsive', 'unsteady', 'jerky', 'spasmodic', 'spastic']
senticnet['arrival'] = [0.056, 0.123, -0.074, 0.263, '#interesting', '#admirable', 0.123, 'arrive', 'come', 'steady', 'tow', 'permission']
senticnet['arrive'] = [0, 0.149, -0.132, 0.258, '#interesting', '#admirable', 0.092, 'come', 'haul', 'continue', 'reach', 'tow']
senticnet['arrive_conclusion'] = [0, 0.834, 0, 0.801, '#interesting', '#admirable', 0.545, 'resolve_problem', 'figure_out', 'come_conclusion', 'study_fact', 'come_up_idea']
senticnet['arrive_destination'] = [0.032, 0.261, -0.157, 0.198, '#interesting', '#admirable', 0.111, 'stop_red_light', 'run_out_gas', 'use_gas', 'shift_gear', 'win_race']
senticnet['arrive_early'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'love_another_person', 'wet_lip', 'change_diaper', 'care_deeply', 'feel_love']
senticnet['arrive_home'] = [0.47, 0.419, -0.318, 0.367, '#joyful', '#interesting', 0.313, 'date_woman', 'marry_man', 'service_car', 'dig_grave', 'bicycle_across_town']
senticnet['arrive_late'] = [-0.081, -0.026, 0, -0.092, '#sad', '#disgusting', -0.049, 'travel_quickly', 'press_accelerator', 'traffic_accident', 'get_lose', 'get_plane']
senticnet['arrive_mail'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'letter', 'postman', 'stamp', 'letterhead', 'envelope']
senticnet['arrive_somewhere'] = [0.798, 0.754, 0, 0.779, '#joyful', '#admirable', 0.777, 'reach_destination', 'see_neighbor', 'travel', 'satisfaction', 'arrive_home']
senticnet['arrive_time'] = [0.809, 0, 0, 0, '#joyful', '#joyful', 0.27, 'think_future', 'gather_berry', 'hang_picture_on_wall', 'see_star_night', 'bug_person']
senticnet['arrive_work'] = [0.879, 0.839, 0, 0.868, '#joyful', '#admirable', 0.862, 'dress_oneself', 'finish_task', 'plan_retirement', 'floss_tooth', 'erase_blackboard']
senticnet['arriviste'] = [-0.745, 0, 0.786, -0.967, '#angry', '#disgusting', -0.833, 'junior', 'unpleasant_person', 'disagreeable_person', 'climber', 'social_climber']
senticnet['arrogance'] = [-0.798, 0, 0.911, -0.941, '#angry', '#disgusting', -0.883, 'angry_emotion', 'feel_hurt', 'severe_pain', 'hurt_feeling', 'prejudice']
senticnet['arrogator'] = [-0.611, 0, 0.953, -0.618, '#angry', '#disgusting', -0.727, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['arrow'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'bayonet', 'spear', 'shotgun', 'bullet', 'hydrogen_bomb']
senticnet['arsenal'] = [-0.048, 0, -0.094, -0.194, '#scared', '#disgusting', -0.112, 'war', 'gun_store', 'holster', 'gun_shop', 'big_fight']
senticnet['arsenic'] = [0, 0, -0.973, 0, '#scared', '#scared', -0.324, 'iodine', 'lithium', 'uranium', 'element', 'manganese']
senticnet['arson'] = [-0.141, 0, -0.214, -0.078, '#sad', '#scared', -0.144, 'heat_light', 'burn_down_house', 'set_on_fire', 'rapid_oxidation', 'flame']
senticnet['arsonist'] = [0.057, 0, -0.074, -0.078, '#scared', '#disgusting', -0.032, 'huge_fire', 'fire', 'rapid_oxidation', 'heat_light', 'flame']
senticnet['art'] = [0.057, 0.101, 0, 0.158, '#interesting', '#admirable', 0.105, 'artwork', 'picture', 'wall_decoration', 'painting', 'wall_hang']
senticnet['art_craft'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'sculptor', 'carving', 'art', 'craft', 'wood_product']
senticnet['art_creation'] = [0.041, 0.115, 0, 0.197, '#interesting', '#admirable', 0.118, 'form_of_art', 'wall_decoration', 'creative_activity', 'art_form', 'artistic']
senticnet['art_critic'] = [0.811, -0.63, 0, 0.959, '#joyful', '#admirable', 0.8, 'drama_critic', 'theater_critic', 'professional', 'critic', 'literary_critic']
senticnet['art_form'] = [0.131, 0, 0, 0.191, '#joyful', '#admirable', 0.107, 'form_of_art', 'art_creation', 'creative_activity', 'art', 'craft']
senticnet['art_gallery'] = [-0.025, 0, -0.049, -0.031, '#scared', '#disgusting', -0.035, 'studio', 'art_piece', 'visual_communication', 'artist', 'museum']
senticnet['art_lover'] = [0.93, 0.734, 0, 0.958, '#joyful', '#admirable', 0.874, 'museum', 'artist', 'oil_paint', 'visual', 'artistic']
senticnet['art_object'] = [0.03, 0.084, 0, 0.077, '#interesting', '#admirable', 0.064, 'sculpture', 'painting', 'art', 'artwork', 'oil_paint']
senticnet['art_piece'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'art', 'gem', 'museum', 'artist', 'jewel']
senticnet['art_show'] = [0, 0.093, 0, 0.066, '#interesting', '#admirable', 0.053, 'gallery_open', 'museum', 'antique_store', 'laundromat', 'studio']
senticnet['art_supply'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'use_brush', 'wall_cover', 'cover_wall', 'brush', 'two-dimensional']
senticnet['artefact'] = [0.099, -0.073, -0.081, 0.195, '#joyful', '#admirable', 0.095, 'art', 'exhibit', 'craft', 'fine_art', 'artwork']
senticnet['arterial_plaque'] = [-0.81, 0, 0.741, -0.763, '#sad', '#disgusting', -0.771, 'spot', 'amyloid_plaque', 'dentist', 'plaque', 'dental_plaque']
senticnet['arteritis'] = [-0.853, 0, 0.657, -0.868, '#sad', '#disgusting', -0.793, 'pulseless_disease', 'temporal_arteritis', 'rubor', 'redness', 'polyarteritis']
senticnet['artery'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'skeletal_system', 'vein', 'main_artery', 'groin', 'bone']
senticnet['artfulness'] = [-0.837, 0, 0.802, -0.521, '#sad', '#angry', -0.72, 'dishonesty', 'deceitfulness', 'craftiness', 'guile', 'disingenuousness']
senticnet['arthritis'] = [-0.7, 0, 0.77, -0.754, '#angry', '#disgusting', -0.741, 'keep_rhythm', 'dog_bark', 'sore_knee', 'fatigue', 'sense_rhythm']
senticnet['arthropod'] = [0, -0.042, 0.082, -0.073, '#angry', '#disgusting', -0.038, 'arachnid', 'social_insect', 'vermin', 'insect', 'fly_insect']
senticnet['arthropods'] = [0.16, 0.067, 0, 0.083, '#joyful', '#admirable', 0.103, 'aerial', 'sensory', 'antenna', 'insect', 'connection']
senticnet['artic'] = [-0.04, 0, 0, -0.05, '#sad', '#disgusting', -0.03, 'bad_luck', 'tundra', 'damn', 'mammal_family', 'bad_mood']
senticnet['article'] = [0, 0.827, 0, 0.903, '#interesting', '#admirable', 0.577, 'riddle', 'obituary', 'editorial', 'news_story', 'mystery']
senticnet['article_clothes'] = [0, -0.89, 0, 0.936, '#surprising', '#admirable', 0.609, 'make_shirt', 'make_clothes', 'cloth', 'make_cloth', 'apparel']
senticnet['article_of_clothing'] = [0, -0.843, 0, 0.943, '#surprising', '#admirable', 0.595, 'wear', 'wearable', 'clothing', 'leisure_wear', 'vesture']
senticnet['articulate'] = [0, 0, -0.74, -0.769, '#scared', '#disgusting', -0.503, 'word', 'joint', 'formulate', 'give_voice', 'phrase']
senticnet['articulation'] = [-0.671, 0, 0.97, -0.64, '#sad', '#angry', -0.76, 'joint', 'node', 'connexion', 'join', 'juncture']
senticnet['artificer'] = [0.633, -0.502, 0, 0.59, '#joyful', '#admirable', 0.575, 'craftsman', 'manicurist', 'artisan', 'journeyman', 'beautician']
senticnet['artificial'] = [-0.7, 0, 0.77, -0.754, '#angry', '#disgusting', -0.741, 'fake', 'unnatural', 'man_made', 'artificial_sea', 'artificial_taste']
senticnet['artificial_arm'] = [0.776, 0.863, 0, 0, '#joyful', '#interesting', 0.546, 'x-ray_machine', 'prosthesis', 'ambulance', 'syringe', 'latex_glove']
senticnet['artificial_intelligence'] = [0, 0.081, 0.031, 0.119, '#interesting', '#admirable', 0.056, 'weak_acid', 'financial_security', 'acquire_wealth', 'much_need', 'spice_life']
senticnet['artificial_leg'] = [0.956, 0.95, 0, 0, '#joyful', '#interesting', 0.635, 'tree_trunk', 'plank', 'wooden_leg', 'hardwood', 'tree_wood']
senticnet['artificial_respiration'] = [-0.578, 0, 0.737, -0.851, '#angry', '#disgusting', -0.722, 'emergency_procedure', 'emergency', 'external_respiration', 'respiration', 'ventilation']
senticnet['artificial_sea'] = [-0.7, 0, 0.77, -0.754, '#angry', '#disgusting', -0.741, 'fake', 'unnatural', 'man_made', 'artificial', 'artificial_taste']
senticnet['artificial_taste'] = [-0.7, 0, 0.77, -0.754, '#angry', '#disgusting', -0.741, 'fake', 'unnatural', 'man_made', 'artificial_sea', 'artificial']
senticnet['artificiality'] = [-0.562, 0, 0.505, -0.953, '#sad', '#disgusting', -0.673, 'unnaturalness', 'pretence', 'pretension', 'staginess', 'theatricality']
senticnet['artillery'] = [-0.935, 0, 0, -0.758, '#sad', '#disgusting', -0.564, 'atomic_bomb', 'weapon_war', 'gun', 'pistol', 'hydrogen_bomb']
senticnet['artiodactyl'] = [-0.535, 0, 0.751, -0.971, '#angry', '#disgusting', -0.752, 'guanaco', 'domestic_llama', 'alpaca', 'llama', 'llama_mammal']
senticnet['artiodactyl_mammal'] = [0.752, 0.87, 0, 0, '#joyful', '#interesting', 0.541, 'guanaco', 'domestic_llama', 'alpaca', 'artiodactyl', 'llama']
senticnet['artisan'] = [0.633, -0.502, 0, 0.59, '#joyful', '#admirable', 0.575, 'craftsman', 'manicurist', 'beautician', 'journeyman', 'artificer']
senticnet['artist'] = [0.041, 0.112, 0, 0.077, '#interesting', '#admirable', 0.077, 'oil_paint', 'artist_tool', 'painter', 'oil_painting', 'painting']
senticnet['artist_tool'] = [0.041, 0.112, 0, 0.077, '#interesting', '#admirable', 0.077, 'oil_paint', 'artist', 'brush', 'palette', 'canvas']
senticnet['artistic'] = [0.032, 0.076, 0.015, 0.068, '#interesting', '#admirable', 0.054, 'like_paint', 'create_image', 'wall_hang', 'wall_decoration', 'art_creation']
senticnet['artistic_creation'] = [0.528, -0.606, 0, 0.724, '#surprising', '#admirable', 0.619, 'gastronomy', 'arts_and_crafts', 'carving', 'decoupage', 'ceramics']
senticnet['artistic_expression'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'creative_expression', 'pastime', 'self_expression', 'date_activity', 'make_beautiful']
senticnet['artistic_production'] = [0.654, -0.502, 0, 0.564, '#joyful', '#admirable', 0.573, 'gastronomy', 'arts_and_crafts', 'carving', 'decoupage', 'ceramics']
senticnet['artistry'] = [0.607, -0.997, 0, 0.847, '#surprising', '#admirable', 0.817, 'eristic', 'puppetry', 'homiletics', 'aviation', 'airmanship']
senticnet['artless'] = [0, 0, 0.957, -0.857, '#angry', '#disgusting', -0.605, 'ingenuous', 'gullible', 'naive', 'childlike', 'guileless']
senticnet['artlessness'] = [-0.613, 0, 0.599, -0.571, '#sad', '#angry', -0.594, 'simple_mindedness', 'simpleness', 'ingenuousness', 'naiveness', 'simplicity']
senticnet['arts_and_crafts'] = [0.528, -0.606, 0, 0.724, '#surprising', '#admirable', 0.619, 'gastronomy', 'artistic_creation', 'carving', 'decoupage', 'ceramics']
senticnet['artwork'] = [0.047, 0, 0, 0.055, '#joyful', '#admirable', 0.034, 'painting', 'sculpture', 'oil_painting', 'tapestry', 'mural']
senticnet['arytenoid'] = [-0.536, 0, 0.982, -0.671, '#angry', '#disgusting', -0.73, 'meniscus', 'semilunar_cartilage', 'fibrocartilage', 'hyaline_cartilage', 'gristle']
senticnet['asarabacca'] = [-0.524, 0, 0.527, -0.782, '#angry', '#disgusting', -0.611, 'herb', 'black_snakeroot', 'heartleaf', 'wild_ginger', 'herbaceous_plant']
senticnet['asbestos'] = [-0.035, 0, 0, -0.045, '#sad', '#disgusting', -0.027, 'cotton', 'silk', 'wool', 'cotton_boll', 'velvet']
senticnet['ascend'] = [0, 0.144, -0.052, 0.156, '#interesting', '#admirable', 0.083, 'go_up', 'move_upward', 'move_up', 'move_upwards', 'go_high']
senticnet['ascendance'] = [-0.837, 0, 0.858, -0.795, '#sad', '#angry', -0.83, 'dominance', 'absolutism', 'autocracy', 'ascendancy', 'tirant']
senticnet['ascendancy'] = [-0.837, 0, 0.858, -0.795, '#sad', '#angry', -0.83, 'dominance', 'ascendance', 'autocracy', 'absolutism', 'tirant']
senticnet['ascetic'] = [0.555, -0.914, 0, 0.601, '#surprising', '#admirable', 0.69, 'abstemious', 'abstemiousal', 'spartan', 'austere', 'abstinent']
senticnet['ascetical'] = [0.555, -0.914, 0, 0.601, '#surprising', '#admirable', 0.69, 'ascetic', 'abstemious', 'spartan', 'austere', 'abstinent']
senticnet['asceticism'] = [0.853, -0.958, 0, 0.605, '#joyful', '#surprising', 0.805, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['ascribable'] = [0.511, -0.597, 0, 0.576, '#surprising', '#admirable', 0.561, 'due', 'traceable', 'attributable', 'imputable', 'referable']
senticnet['asepsis'] = [0.617, -0.592, 0, 0.805, '#joyful', '#admirable', 0.671, 'sanitation', 'hygiene', 'sterility', 'sanitary_condition', 'sanitariness']
senticnet['asexual'] = [-0.686, 0, 0.779, -0.863, '#angry', '#disgusting', -0.776, 'agamic', 'agamous', 'agamogenetic', 'parthenogenetic', 'apomictic']
senticnet['asexual_reproduction'] = [-0.778, 0, 0.764, -0.548, '#sad', '#angry', -0.697, 'pullulation', 'apomixis', 'blastogenesis', 'budding', 'fission']
senticnet['ash'] = [0.037, 0, -0.055, -0.053, '#scared', '#disgusting', -0.024, 'soot', 'flame', 'cinder', 'combustion', 'flue']
senticnet['ashamed'] = [-0.748, 0, 0, -0.823, '#sad', '#disgusting', -0.524, 'disgraceful', 'shameful', 'shame', 'inglorious', 'dishonored']
senticnet['ashes'] = [-0.909, 0, -0.833, 0, '#sad', '#scared', -0.581, 'burn_heat', 'really_hot', 'hot', 'fire_burn', 'flame']
senticnet['asian'] = [0.026, 0.08, 0.043, 0.064, '#interesting', '#admirable', 0.042, 'eat_rice', 'white_brown', 'starchy_food', 'indian_food', 'staple_food']
senticnet['asininity'] = [0.702, -0.527, 0, 0.981, '#joyful', '#admirable', 0.737, 'injudiciousness', 'foolishness', 'silliness', 'fatuity', 'fatuousness']
senticnet['ask'] = [0.731, 0, 0, 0.96, '#joyful', '#admirable', 0.564, 'affirmation', 'inquiry', 'plea', 'suggest', 'question_start']
senticnet['ask_a_lot_of_question'] = [-0.134, 0, 0, -0.035, '#sad', '#disgusting', -0.056, 'want_buy', 'determine_need', 'search_item', 'discuss_friend', 'come_warranty']
senticnet['ask_expert'] = [0.026, 0.08, 0.043, 0.064, '#interesting', '#admirable', 0.042, 'absorb_information', 'remember_information', 'read_book_subject', 'use_telescope', 'use_search_engine']
senticnet['ask_for'] = [0.722, -0.764, 0, 0.946, '#surprising', '#admirable', 0.811, 'arouse', 'elicit', 'enkindle', 'kindle', 'evoke']
senticnet['ask_for_forgiveness'] = [0.875, 0, 0, 0.802, '#joyful', '#admirable', 0.559, 'polite', 'care', 'apology', 'forgive', 'take_care']
senticnet['ask_for_it'] = [-0.979, 0, 0.988, -0.504, '#sad', '#angry', -0.824, 'persevere', 'hang_in', 'persist', 'hang_on', 'hold_on']
senticnet['ask_for_lift'] = [0.763, 0, 0, 0.803, '#joyful', '#admirable', 0.522, 'hitchhike', 'take_walk', 'take_bus', 'go_to_another_place', 'take_metro']
senticnet['ask_for_trouble'] = [-0.862, 0, 0.565, -0.767, '#sad', '#disgusting', -0.731, 'persevere', 'hang_in', 'persist', 'hang_on', 'hold_on']
senticnet['ask_help'] = [0, 0.147, -0.055, 0.107, '#interesting', '#admirable', 0.066, 'become_frustrated', 'put_bid', 'introspection', 'make_comparison', 'keep_word']
senticnet['ask_information'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'job', 'settle', 'ask_person', 'work', 'dig_ground']
senticnet['ask_many_questions'] = [0, 0, 0.783, -0.706, '#angry', '#disgusting', -0.496, 'ask_question', 'investigate_fact', 'think_through', 'recognize_pattern', 'form_opinion']
senticnet['ask_menu'] = [0.021, 0.093, -0.069, 0.119, '#interesting', '#admirable', 0.055, 'use_restroom', 'order_dinner', 'read_menu', 'order_french_fries', 'talk_companion']
senticnet['ask_money'] = [-0.825, 0, 0, 0, '#sad', '#sad', -0.275, 'moolah', 'plan_advance', 'bind_agreement', 'money_credit', 'bring_wallet']
senticnet['ask_name'] = [0.021, 0.093, -0.069, 0.119, '#interesting', '#admirable', 0.055, 'say_hello', 'end_conversation', 'introduce_oneself', 'make_eye_contact', 'say_hi']
senticnet['ask_nicely'] = [0, 0.726, 0, 0.953, '#interesting', '#admirable', 0.56, 'question_ask', 'ask_politely', 'resume', 'obligation', 'animal_person']
senticnet['ask_permission'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'kind_request', 'cup_hand', 'tear_paper', 'laugh_clown', 'love_pet']
senticnet['ask_person'] = [0, 0.109, -0.055, 0.122, '#interesting', '#admirable', 0.059, 'job', 'settle', 'ask_information', 'work', 'dig_ground']
senticnet['ask_politely'] = [0.028, 0.254, -0.185, 0.319, '#interesting', '#admirable', 0.139, 'ask_nicely', 'obligation', 'meet_need', 'try', 'negotiate_contract']
senticnet['ask_price'] = [-0.065, 0.228, 0, 0.137, '#interesting', '#admirable', 0.1, 'item_value', 'value_amount', 'amount_due', 'price_item', 'item_worth']
senticnet['ask_question'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'research_subject', 'ask_many_questions', 'think_logically', 'investigate_fact', 'share_opinion']
senticnet['ask_to_leave'] = [0, 0, 0.87, -0.874, '#angry', '#disgusting', -0.581, 'go_away', 'leave_job', 'drive_out', 'chase_away', 'drive_away']
senticnet['asker'] = [-0.623, 0, 0.632, -0.783, '#angry', '#disgusting', -0.679, 'inquirer', 'enquirer', 'questioner', 'querier', 'inquisitor']
senticnet['asleep'] = [0.982, -0.991, 0, 0, '#joyful', '#surprising', 0.658, 'lie_back', 'feel_little_tired', 'nap', 'laze', 'take_nap']
senticnet['asocial'] = [-0.981, 0, 0.582, -0.561, '#sad', '#angry', -0.708, 'unsocial', 'antisocial', 'lonely', 'withdrawn', 'solitary']
senticnet['aspartame'] = [0.53, -0.64, 0, 0.934, '#surprising', '#admirable', 0.701, 'sweetener', 'honey', 'saccharin', 'sugar', 'refined_sugar']
senticnet['aspect'] = [0, 0.164, -0.051, 0.2, '#interesting', '#admirable', 0.104, 'perspective', 'scenic', 'quick_look', 'vista', 'viewfinder']
senticnet['asperger_syndrome'] = [-0.912, 0, 0.508, -0.897, '#sad', '#disgusting', -0.772, 'mental_disorder', 'mental_disturbance', 'psychological_disorder', 'folie', 'disturbance']
senticnet['asperity'] = [0.529, -0.755, 0, 0.578, '#surprising', '#admirable', 0.621, 'sternness', 'grimness', 'rigor', 'hardship', 'rigorousness']
senticnet['asperse'] = [-0.837, 0, 0, -0.806, '#sad', '#disgusting', -0.548, 'assassinate', 'charge', 'accuse', 'malign', 'libel']
senticnet['asphalt'] = [0.076, 0.067, 0, 0.056, '#joyful', '#interesting', 0.066, 'rubble', 'ground', 'ground_material', 'abrasive', 'american_flag']
senticnet['aspheric'] = [0.969, -0.542, 0, 0.806, '#joyful', '#admirable', 0.772, 'rounded', 'roundedal', 'prolate', 'auriform', 'crescent']
senticnet['aspherical'] = [0.969, -0.542, 0, 0.806, '#joyful', '#admirable', 0.772, 'aspheric', 'rounded', 'prolate', 'auriform', 'crescent']
senticnet['asphyxiating'] = [-0.534, 0, 0.886, -0.918, '#angry', '#disgusting', -0.779, 'dyspneic', 'dyspnoeic', 'dyspneal', 'dyspnoeal', 'breathless']
senticnet['aspic'] = [0.708, -0.934, 0, 0.764, '#surprising', '#admirable', 0.802, 'dainty', 'delicacy', 'treat', 'gelatin_dessert', 'jelly']
senticnet['aspirant'] = [0.913, -0.833, 0, 0.739, '#joyful', '#surprising', 0.828, 'pushful', 'pushy', 'ambitious', 'aspiring', 'wishful']
senticnet['aspirin'] = [-0.073, -0.038, -0.053, -0.25, '#sad', '#disgusting', -0.113, 'painkiller', 'ibuprofen', 'gauze', 'palliative', 'phenobarbital']
senticnet['aspiring'] = [0.913, -0.833, 0, 0.739, '#joyful', '#surprising', 0.828, 'pushful', 'pushy', 'aspirant', 'ambitious', 'wishful']
senticnet['ass'] = [-0.025, 0, 0, -0.054, '#sad', '#disgusting', -0.026, 'butt', 'foreign_country', 'menagerie', 'way', 'out_door']
senticnet['assail'] = [-0.632, 0, 0.796, -0.776, '#angry', '#disgusting', -0.735, 'blindside', 'profane', 'assault', 'savage', 'violate']
senticnet['assassin'] = [-0.982, 0, 0.078, -0.919, '#sad', '#disgusting', -0.66, 'escape', 'prisoner', 'killer', 'murderer', 'from_prison']
senticnet['assassin_bug'] = [-0.773, 0, 0.576, -0.922, '#sad', '#disgusting', -0.757, 'insect', 'firebug', 'water_bug', 'heteropterous_insect', 'reduviid']
senticnet['assassinate'] = [0, 0, 0.965, -0.79, '#angry', '#disgusting', -0.585, 'asperse', 'charge', 'accuse', 'malign', 'libel']
senticnet['assassination'] = [-0.801, 0, 0.555, -0.832, '#sad', '#disgusting', -0.729, 'calumniation', 'traducement', 'hatchet_job', 'defamation', 'calumny']
senticnet['assault'] = [-0.069, -0.024, -0.089, -0.197, '#scared', '#disgusting', -0.11, 'siege', 'violence', 'bloodshed', 'battle', 'use_military']
senticnet['assay'] = [0.747, -0.581, 0, 0.92, '#joyful', '#admirable', 0.749, 'diagnostic_assay', 'biopsy', 'cloze_procedure', 'cloze_test', 'fecal_occult_test']
senticnet['assemblage'] = [0.553, -0.8, 0, 0.908, '#surprising', '#admirable', 0.754, 'strong_suit', 'collection', 'aggregation', 'accumulation', 'long_suit']
senticnet['assemble'] = [0.048, 0.092, -0.089, 0.216, '#interesting', '#admirable', 0.089, 'gather', 'group', 'organization', 'clique', 'collection']
senticnet['assembly'] = [0.055, 0.072, -0.067, 0.094, '#interesting', '#admirable', 0.051, 'big_group', 'large_group', 'bunch_person', 'large_number', 'clique']
senticnet['assembly_line'] = [0, 0.109, -0.062, 0.132, '#interesting', '#admirable', 0.06, 'make_goods', 'make_product', 'factory_output', 'manufacture_plant', 'manufacture']
senticnet['assent'] = [-0.025, 0.241, -0.176, 0.351, '#interesting', '#admirable', 0.13, 'upward_movement', 'raise_up', 'bring_up', 'move_upward', 'go_up']
senticnet['assert'] = [0.098, 0.165, -0.134, 0.284, '#interesting', '#admirable', 0.138, 'like_jail', 'live_forever', 'live_ocean', 'like_play', 'proclamation']
senticnet['assert_oneself'] = [0.759, -0.767, 0, 0.878, '#surprising', '#admirable', 0.801, 'remember_oneself', 'move', 'walk', 'comport', 'act']
senticnet['asserted'] = [0.843, -0.935, 0, 0.952, '#surprising', '#admirable', 0.91, 'declared', 'avowed', 'professed', 'alleged', 'announced']
senticnet['assertion'] = [0.784, -0.666, 0, 0.554, '#joyful', '#surprising', 0.668, 'testimony', 'claim', 'charge', 'contention', 'accusation']
senticnet['assertiveness'] = [0.936, 0.757, 0, 0.927, '#joyful', '#admirable', 0.873, 'attitude', 'better', 'trait', 'blue_ribbon', 'exclamation']
senticnet['assess'] = [0.051, 0, 0, 0.072, '#joyful', '#admirable', 0.041, 'evaluate', 'wish_entertain', 'enjoyment', 'film_critic', 'entertainment']
senticnet['asset'] = [0.045, 0.207, -0.082, 0.191, '#interesting', '#admirable', 0.12, 'house_location', 'house_land', 'address', 'quality', 'house_place']
senticnet['assets'] = [0.522, -0.88, 0, 0.965, '#surprising', '#admirable', 0.789, 'overage', 'crown_jewel', 'security', 'capital', 'hole_card']
senticnet['asseverate'] = [0.565, -0.738, 0, 0.542, '#joyful', '#surprising', 0.615, 'say', 'aver', 'predicate', 'insist', 'take_firm_stand']
senticnet['asseveration'] = [0.686, -0.826, 0, 0.741, '#surprising', '#admirable', 0.751, 'testimony', 'claim', 'charge', 'contention', 'accusation']
senticnet['asshole'] = [0, 0, -0.135, 0, '#scared', '#scared', -0.045, 'womb', 'anus', 'sister_house', 'gone_moon', 'land_moon']
senticnet['assibilation'] = [0.524, -0.751, 0, 0.932, '#surprising', '#admirable', 0.736, 'accent', 'pronunciation', 'sibilation', 'mispronunciation', 'homophony']
senticnet['assiduity'] = [0.927, -0.922, 0, 0.76, '#joyful', '#surprising', 0.87, 'diligence', 'industriousness', 'singleness', 'intentness', 'engrossment']
senticnet['assiduousness'] = [0.91, -0.513, 0, 0.829, '#joyful', '#admirable', 0.751, 'diligence', 'industriousness', 'singleness', 'intentness', 'engrossment']
senticnet['assign'] = [0, 0, 0, 0.752, '#admirable', '#admirable', 0.251, 'nominate', 'lawyer', 'supreme_court', 'edict', 'take_court']
senticnet['assignment'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'school_work', 'learn_tool', 'text_book', 'homework', 'textbook']
senticnet['assimilate'] = [0.869, -0.598, 0, 0.66, '#joyful', '#admirable', 0.709, 'absorb', 'take_up', 'reabsorb', 'resorb', 'imbibe']
senticnet['assist'] = [0.735, 0.759, 0, 0.706, '#joyful', '#interesting', 0.733, 'permission', 'let', 'take', 'make_right', 'go_ahead']
senticnet['assistance'] = [0.779, 0.836, 0, 0.747, '#joyful', '#interesting', 0.787, 'good_karma', 'care', 'aid', 'precaution', 'type_of_bear']
senticnet['assistant'] = [0.02, 0.171, -0.101, 0.167, '#interesting', '#admirable', 0.086, 'office_job', 'helper', 'free_slave', 'laborer', 'meet_need']
senticnet['associability'] = [0.515, -0.544, 0, 0.579, '#surprising', '#admirable', 0.546, 'executability', 'ability', 'capability', 'associableness', 'strength']
senticnet['associableness'] = [0.515, -0.544, 0, 0.579, '#surprising', '#admirable', 0.546, 'executability', 'ability', 'associability', 'capability', 'strength']
senticnet['associate'] = [0.102, -0.05, 0, 0, '#joyful', '#surprising', 0.051, 'adjust_volume', 'tap_toe', 'enter_contest', 'tap_foot', 'dance_well']
senticnet['association'] = [0.044, 0.209, -0.13, 0.15, '#interesting', '#admirable', 0.091, 'organization', 'committee', 'agency', 'egalitarian_society', 'business_group']
senticnet['assoil'] = [0.576, -0.873, 0, 0.764, '#surprising', '#admirable', 0.738, 'pronounce', 'purge', 'whitewash', 'vindicate', 'label']
senticnet['assorted'] = [-0.826, 0, 0.756, -0.516, '#sad', '#angry', -0.699, 'inhomogeneous', 'nonuniform', 'heterogeneous', 'sundry', 'mixed']
senticnet['assortment'] = [0, 0.094, 0, 0, '#interesting', '#interesting', 0.031, 'color', 'painting', 'primary_color', 'bright_color', 'secondary_color']
senticnet['assuage'] = [0.618, -0.69, 0, 0.597, '#joyful', '#surprising', 0.635, 'tranquilize', 'tranquillize', 'calm_down', 'quieten', 'calm']
senticnet['assuasive'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'quieten', 'soothing', 'calmly', 'tranquility', 'tranquilize']
senticnet['assume'] = [0.863, -0.947, 0, 0.986, '#surprising', '#admirable', 0.932, 'postulate', 'posit', 'presuppose', 'presume', 'take_for_granted']
senticnet['assumption'] = [0.057, 0.322, -0.189, 0.377, '#interesting', '#admirable', 0.189, 'idol', 'axiom', 'principle', 'almighty', 'supreme']
senticnet['assurance'] = [0.036, 0.292, 0, 0.337, '#interesting', '#admirable', 0.222, 'importance', 'quality', 'total', 'excellence', 'frivolity']
senticnet['assure'] = [0.52, 0.666, -0.261, 0.269, '#joyful', '#interesting', 0.398, 'reassuring', 'reassured', 'reassuringly', 'reassure', 'likeable']
senticnet['assured'] = [0.847, 0, 0, 0.71, '#joyful', '#admirable', 0.519, 'guarantee', 'ensure', 'insure', 'ascertain', 'promise']
senticnet['astasia'] = [-0.756, 0, 0.504, -0.772, '#sad', '#disgusting', -0.677, 'disablement', 'anorgasmia', 'hearing_impairment', 'hearing_disorder', 'bow_legs']
senticnet['asternal'] = [-0.653, 0, 0.944, -0.87, '#angry', '#disgusting', -0.822, 'unconnected', 'isolated', 'separate', 'unattached', 'separated']
senticnet['asthenia'] = [-0.834, 0, 0.874, -0.716, '#sad', '#angry', -0.808, 'infirmity', 'frailty', 'debility', 'frailness', 'valetudinarianism']
senticnet['asthenopia'] = [-0.732, 0, 0.596, -0.773, '#sad', '#disgusting', -0.7, 'exhaustion', 'loss_of_strength', 'logginess', 'eyestrain', 'weariness']
senticnet['astheny'] = [-0.715, 0, 0.81, -0.718, '#angry', '#disgusting', -0.748, 'infirmity', 'frailty', 'debility', 'frailness', 'valetudinarianism']
senticnet['asthma'] = [-0.097, -0.049, -0.048, -0.158, '#sad', '#disgusting', -0.085, 'spider', 'back_pain', 'house_look_better', 'tidiness', 'barf']
senticnet['asthma_attack'] = [-0.966, 0, 0.751, -0.981, '#sad', '#disgusting', -0.899, 'breathing_problem', 'asthma', 'ill', 'sick', 'sickness']
senticnet['asthmatic'] = [-0.864, 0, 0.827, -0.87, '#sad', '#disgusting', -0.854, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['astonish'] = [0.045, -0.662, 0, 0.363, '#surprising', '#admirable', 0.357, 'surprise', 'astonished', 'astound', 'amazement', 'amazed']
senticnet['astonished'] = [0.045, -0.662, 0, 0.363, '#surprising', '#admirable', 0.357, 'surprise', 'astound', 'astonish', 'amazed', 'amazing']
senticnet['astonishing'] = [0.044, -0.662, 0, 0.362, '#surprising', '#admirable', 0.356, 'staggering', 'astounding', 'stupefying', 'astound', 'astonish']
senticnet['astonishingly'] = [0.045, -0.664, 0, 0.363, '#surprising', '#admirable', 0.357, 'amazingly', 'surprised', 'surprising', 'surprisedly', 'surprisingly']
senticnet['astonishment'] = [0.728, 0.77, 0, 0.854, '#interesting', '#admirable', 0.784, 'amazement', 'awe', 'wonder', 'marvel', 'amaze']
senticnet['astound'] = [0.045, -0.662, 0, 0.363, '#surprising', '#admirable', 0.357, 'astonishment', 'astonished', 'surprise', 'amazed', 'astonish']
senticnet['astounded'] = [0.045, -0.662, 0, 0.363, '#surprising', '#admirable', 0.357, 'astonished', 'astound', 'surprise', 'amazed', 'amazing']
senticnet['astounding'] = [0.044, -0.662, 0, 0.362, '#surprising', '#admirable', 0.356, 'staggering', 'stupefying', 'astonishing', 'bewilder', 'flabbergasted']
senticnet['astrakhan'] = [-0.582, 0, 0.517, -0.593, '#sad', '#disgusting', -0.564, 'fox', 'mink', 'seal', 'pelt', 'bearskin']
senticnet['astringence'] = [-0.93, 0, 0.537, -0.572, '#sad', '#disgusting', -0.68, 'taste', 'taste_sensation', 'gustatory_sensation', 'taste_perception', 'gustatory_perception']
senticnet['astringency'] = [-0.825, 0, 0.901, -0.656, '#sad', '#angry', -0.794, 'taste', 'taste_sensation', 'gustatory_sensation', 'taste_perception', 'gustatory_perception']
senticnet['astrology'] = [0.022, 0, 0.011, 0.07, '#joyful', '#admirable', 0.027, 'creationism', 'post_notice', 'mail_delivery', 'message_board', 'artificial']
senticnet['astuteness'] = [0.784, -0.595, 0, 0.846, '#joyful', '#admirable', 0.742, 'foxiness', 'slyness', 'wiliness', 'craftiness', 'cunning']
senticnet['asylum'] = [-0.654, 0, 0.514, -0.696, '#sad', '#disgusting', -0.621, 'booby_hatch', 'mental_hospital', 'psychiatric_hospital', 'mental_institution', 'mental_home']
senticnet['asymmetry'] = [-0.596, 0, 0.672, -0.831, '#angry', '#disgusting', -0.7, 'geometrical_irregularity', 'radial_asymmetry', 'lopsidedness', 'skewness', 'irregularity']
senticnet['at_loss'] = [-0.833, 0, 0.925, -0.994, '#angry', '#disgusting', -0.917, 'perplexed', 'nonplused', 'confused', 'puzzled', 'bewildered']
senticnet['at_variance'] = [-0.935, 0, 0.515, -0.786, '#sad', '#disgusting', -0.745, 'discrepant', 'discordant', 'dissentious', 'divisive', 'factious']
senticnet['at_your_service'] = [0.958, 0, 0, 0.968, '#joyful', '#admirable', 0.642, 'kind', 'nice', 'respectful', 'humble', 'red_carpet']
senticnet['ataraxia'] = [0.503, -0.828, 0, 0.681, '#surprising', '#admirable', 0.671, 'tranquility', 'serenity', 'repose', 'placidity', 'quiet']
senticnet['ataraxis'] = [0.621, 0.648, -0.252, 0.296, '#joyful', '#interesting', 0.438, 'pacifically', 'sereneness', 'tranquility', 'harmony', 'peace']
senticnet['atheist'] = [0, 0.736, 0, 0.836, '#interesting', '#admirable', 0.524, 'non-believer', 'doubter', 'agnostic', 'freethinker', 'sceptic']
senticnet['athlete'] = [0.888, 0.814, 0, 0, '#joyful', '#interesting', 0.567, 'strength', 'strong', 'manly', 'physical_strength', 'muscle']
senticnet['athlete_foot'] = [-0.964, 0, 0.694, -0.623, '#sad', '#angry', -0.76, 'fungal_infection', 'mycosis', 'kerion', 'tinea_pedis', 'ringworm']
senticnet['athletic'] = [0.897, 0.732, 0, 0, '#joyful', '#interesting', 0.543, 'fun_exercise', 'keep_fit', 'recreational', 'get_physically_fit', 'fit_person']
senticnet['athletic_activity'] = [0.032, 0, 0.024, 0.176, '#joyful', '#admirable', 0.061, 'healthy_activity', 'human_motion', 'water_activity', 'good_body', 'athletic']
senticnet['athletic_event'] = [0.836, -0.913, 0, 0, '#joyful', '#surprising', 0.583, 'sport_play', 'excite_game', 'sport', 'rough_game', 'verbosity']
senticnet['athletic_game'] = [0.7, -0.798, 0, 0.873, '#surprising', '#admirable', 0.79, 'sport', 'game', 'ice_hockey', 'hockey', 'hockey_game']
senticnet['athletic_training'] = [0.767, -0.81, 0, 0.714, '#joyful', '#surprising', 0.764, 'practice', 'activity', 'discipline', 'grooming', 'drill']
senticnet['athletic_wear'] = [-0.944, 0, 0.639, -0.757, '#sad', '#disgusting', -0.78, 'attire', 'garb', 'dress', 'gym_suit', 'running_suit']
senticnet['athleticism'] = [-0.709, 0, 0.703, -0.534, '#sad', '#angry', -0.649, 'vigor', 'strenuosity', 'forcefulness', 'force', 'strength']
senticnet['athletics'] = [0, -0.713, 0, 0.93, '#surprising', '#admirable', 0.548, 'olympic_event', 'train_hard', 'shape', 'form_of_exercise', 'good_shape']
senticnet['atlantic_ocean'] = [0, 0.087, 0, 0.071, '#interesting', '#admirable', 0.053, 'pond', 'lake', 'pacific_ocean', 'small_lake', 'mere']
senticnet['atmosphere'] = [0.909, 0.983, 0, 0, '#joyful', '#interesting', 0.631, 'oxygen', 'breathable', 'air', 'hydrogen', 'inhale_air']
senticnet['atmospheric_phenomenon'] = [-0.028, 0, 0, -0.081, '#sad', '#disgusting', -0.036, 'hurricane', 'natural_disaster', 'flood', 'weather_element', 'tropical_storm']
senticnet['atom'] = [0.026, 0.069, 0, 0, '#joyful', '#interesting', 0.032, 'cell', 'fuse', 'nucleus', 'human_body', 'rash']
senticnet['atom_smasher'] = [0.562, -0.777, 0, 0.962, '#surprising', '#admirable', 0.767, 'console', 'instrument', 'accelerator', 'particle_accelerator', 'scientific_instrument']
senticnet['atomic_bomb'] = [0, 0, -0.957, -0.875, '#scared', '#disgusting', -0.611, 'pistol', 'gun', 'hydrogen_bomb', 'handgun', 'revolver']
senticnet['atomic_energy'] = [-0.909, 0, 0.748, -0.904, '#sad', '#disgusting', -0.854, 'alternative_energy', 'activation_energy', 'energy_of_activation', 'energy', 'nuclear_energy']
senticnet['atomic_number_1'] = [-0.575, 0, 0.954, -0.806, '#angry', '#disgusting', -0.778, 'nonmetal', 'transactinide', 'hydrogen', 'chemical_element', 'xenon']
senticnet['atomic_number_26'] = [0.706, -0.941, 0, 0.622, '#joyful', '#surprising', 0.756, 'alloy_iron', 'alloy_cast_iron', 'pot_metal', 'iron', 'cast_iron']
senticnet['atomic_number_54'] = [-0.871, 0, 0.949, -0.809, '#sad', '#angry', -0.876, 'chemical_element', 'element', 'noble_gas', 'inert_gas', 'argonon']
senticnet['atomic_number_79'] = [-0.624, 0, 0.504, -0.798, '#sad', '#disgusting', -0.642, 'green_gold', 'pure_gold', 'gold_dust', 'guinea_gold', 'noble_metal']
senticnet['atomization'] = [-0.982, 0, 0.516, -0.908, '#sad', '#disgusting', -0.802, 'devastation', 'annihilation', 'pulverization', 'vaporization', 'destruction']
senticnet['atonement'] = [-0.822, 0, 0.672, -0.546, '#sad', '#angry', -0.68, 'amends', 'damages', 'indemnification', 'redress', 'restitution']
senticnet['atrioventricular_block'] = [-0.83, 0, 0.987, -0.504, '#sad', '#angry', -0.774, 'heart_block', 'arrhythmia', 'bradycardia', 'ventricular_fibrillation', 'tachycardia']
senticnet['atrium'] = [-0.027, -0.004, 0.022, -0.036, '#sad', '#disgusting', -0.027, 'fancy_house', 'outside_house', 'front_house', 'abide', 'many_homes']
senticnet['atrocious'] = [-0.871, 0, -0.755, 0, '#sad', '#scared', -0.542, 'horrifying', 'dreadfully', 'horrifyingly', 'horrified', 'horribly']
senticnet['atrociousness'] = [-0.99, 0, 0.947, -0.883, '#sad', '#angry', -0.94, 'inhumanity', 'barbarousness', 'heinousness', 'atrocity', 'barbarity']
senticnet['atrocity'] = [-0.875, 0, 0.932, -0.6, '#sad', '#angry', -0.802, 'inhuman_treatment', 'maltreatment', 'abuse', 'inhumanity', 'impalement']
senticnet['atrophedema'] = [-0.998, 0, 0.605, -0.764, '#sad', '#disgusting', -0.789, 'angioedema', 'dropsy', 'giant_hives', 'periodic_edema', 'lymphedema']
senticnet['atrophy'] = [-0.78, 0, 0.764, -0.886, '#sad', '#disgusting', -0.81, 'withering', 'downfall', 'weakening', 'fading', 'attenuation']
senticnet['atropine'] = [-0.601, 0, 0.544, -0.628, '#sad', '#disgusting', -0.591, 'remedy', 'cure', 'therapeutic', 'curative', 'antidote']
senticnet['attach'] = [0.02, 0.093, 0, 0.223, '#interesting', '#admirable', 0.112, 'extremity', 'extension', 'human_appendage', 'enclose', 'body_limb']
senticnet['attached'] = [-0.792, 0, -0.834, 0, '#sad', '#scared', -0.542, 'bind', 'tie', 'affiliated', 'connected', 'committed']
senticnet['attachment'] = [0.884, 0, 0, 0.811, '#joyful', '#admirable', 0.565, 'affect', 'fond_regard', 'protective', 'fondness', 'protectiveness']
senticnet['attack'] = [-0.108, 0, -0.11, -0.201, '#scared', '#disgusting', -0.14, 'siege', 'conflict', 'enemy', 'fight', 'bloodshed']
senticnet['attack_enemy'] = [-0.177, 0, -0.159, -0.218, '#sad', '#disgusting', -0.185, 'war', 'invade', 'casualty', 'ready_troop', 'cause_death']
senticnet['attacker'] = [-0.025, 0, -0.069, -0.121, '#scared', '#disgusting', -0.072, 'army', 'military', 'infantry', 'samurai', 'soldier']
senticnet['attain'] = [0.706, 0.798, 0, 0, '#joyful', '#interesting', 0.501, 'gain', 'reach', 'make', 'bottom_out', 'secure']
senticnet['attain_goal'] = [0.772, 0.719, 0, 0.988, '#joyful', '#admirable', 0.826, 'achieve', 'sate', 'good_fortune', 'taken_seriously', 'wedding_vow']
senticnet['attainment'] = [0.798, -0.542, 0, 0.552, '#joyful', '#admirable', 0.631, 'acquirement', 'skill', 'accomplishment', 'acquisition', 'horsemanship']
senticnet['attempt'] = [0, 0, 0, 0.898, '#admirable', '#admirable', 0.299, 'make_effort', 'try', 'ask_nicely', 'resume', 'ask_politely']
senticnet['attempt_bribe'] = [0, 0, 0, -0.875, '#disgusting', '#disgusting', -0.292, 'get_away_crime', 'commit_murder', 'steal', 'commit_perjury', 'hurt_else']
senticnet['attempt_fly'] = [0.042, 0.088, 0, 0, '#joyful', '#interesting', 0.043, 'jump_over_obstacle', 'chick', 'aircraft', 'pilot', 'wings']
senticnet['attend'] = [0, 0.12, -0.057, 0.204, '#interesting', '#admirable', 0.089, 'help', 'like_see', 'perceive', 'ear_work', 'ship_part']
senticnet['attend_class'] = [0.798, 0.754, 0, 0.779, '#joyful', '#admirable', 0.777, 'learn_science', 'take_course', 'study_subject', 'learn_subject', 'memorize']
senticnet['attend_concert'] = [0.172, 0.236, -0.135, 0.287, '#interesting', '#admirable', 0.187, 'watch_play', 'entertainment', 'cheering', 'applause', 'popcorn']
senticnet['attend_conference'] = [0.875, 0, 0, 0.802, '#joyful', '#admirable', 0.559, 'meeting', 'attend_meeting', 'attend_event', 'exchange_opinion', 'exchange_information']
senticnet['attend_event'] = [0.875, 0, 0, 0.802, '#joyful', '#admirable', 0.559, 'meeting', 'attend_conference', 'attend_meeting', 'exchange_opinion', 'exchange_information']
senticnet['attend_meeting'] = [0.875, 0, 0, 0.802, '#joyful', '#admirable', 0.559, 'meeting', 'attend_conference', 'attend_event', 'exchange_opinion', 'exchange_information']
senticnet['attend_opus'] = [0, 0, 0, -0.072, '#disgusting', '#disgusting', -0.024, 'go_movie', 'watch_musician_perform', 'go_concert', 'go_opus', 'turn_stereo']
senticnet['attend_rock_concert'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'hear_sing', 'see_band', 'see_beautiful_girl', 'hear_crowd_go_mad', 'go_stage']
senticnet['attendance'] = [0.723, 0, 0, 0.762, '#joyful', '#admirable', 0.495, 'presence', 'feel_important', 'existence', 'feel_satisfied', 'feel_presence']
senticnet['attendant'] = [0, 0.903, 0, 0.841, '#interesting', '#admirable', 0.581, 'personnel', 'employee', 'manager', 'servant', 'helper']
senticnet['attendee'] = [0.055, -0.017, 0, 0.106, '#joyful', '#admirable', 0.059, 'agenda', 'pencil_pen', 'learn_write', 'find_paper', 'paper_plane']
senticnet['attention'] = [0, 1, 0, 0, '#interesting', '#interesting', 0.333, 'interest', 'interesting', 'mood', 'strong_emotion', 'emotion']
senticnet['attentive'] = [0, -0.919, 0, 0.915, '#surprising', '#admirable', 0.611, 'express_feeling', 'ask_name', 'end_conversation', 'empathy', 'mutual_understand']
senticnet['attenuation'] = [-0.78, 0, 0.764, -0.886, '#sad', '#disgusting', -0.81, 'withering', 'downfall', 'atrophy', 'fading', 'weakening']
senticnet['attest'] = [0.749, -0.796, 0, 0.768, '#surprising', '#admirable', 0.771, 'prove', 'show', 'condemn', 'authenticate', 'reflect']
senticnet['attested'] = [-0.642, 0, 0.852, -0.803, '#angry', '#disgusting', -0.766, 'unquestionable', 'documented', 'veritable', 'echt', 'authenticated']
senticnet['attic'] = [-0.056, -0.047, 0.017, -0.056, '#sad', '#disgusting', -0.027, 'shoe_shop', 'shoe_store', 'hamper', 'obstruct', 'closet']
senticnet['attire'] = [-0.684, 0, 0.947, -0.951, '#angry', '#disgusting', -0.861, 'finery', 'sportswear', 'athletic_wear', 'activewear', 'costume']
senticnet['attitude'] = [0.197, 0.374, -0.275, 0.384, '#interesting', '#admirable', 0.227, 'thoughtful', 'certainty', 'similarity', 'yearn', 'prefer']
senticnet['attorney'] = [0, 0.146, -0.053, 0.077, '#interesting', '#admirable', 0.057, 'lawyer', 'negotiator', 'arbiter', 'judge_jury', 'decide_guilt']
senticnet['attract'] = [0.92, -0.883, 0, 0.695, '#joyful', '#surprising', 0.833, 'get', 'catch', 'arrest', 'tug', 'retract']
senticnet['attract_attention'] = [0.734, 0, 0, 0.708, '#joyful', '#admirable', 0.481, 'give_hug', 'know_other', 'take_movie', 'find_partner', 'shake_hand']
senticnet['attract_dog'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'dog_food', 'toy', 'lure', 'treats', 'whistle']
senticnet['attract_mate'] = [0.166, -0.052, 0.044, -0.046, '#joyful', '#surprising', 0.043, 'impress_girl', 'relieve_stress', 'enjoy_outdoors', 'social_bond', 'become_popular']
senticnet['attract_opposite_sex'] = [0.879, 0.91, 0, 0, '#joyful', '#interesting', 0.596, 'entertain_other_person', 'become_better', 'sing_dance', 'great_joy', 'listen']
senticnet['attraction'] = [0.908, 0.971, 0, 0, '#joyful', '#interesting', 0.626, 'care_deeply', 'love_another_person', 'love_oneself', 'show_empathy', 'find_woman']
senticnet['attractive'] = [0.111, 0.121, -0.096, 0.246, '#interesting', '#admirable', 0.127, 'nice_look', 'lovely', 'good_look', 'gorgeous', 'nice']
senticnet['attractiveness'] = [0.817, -0.626, 0, 0.62, '#joyful', '#surprising', 0.688, 'quality', 'fascination', 'allurement', 'allure', 'temptingness']
senticnet['attributable'] = [0.511, -0.597, 0, 0.576, '#surprising', '#admirable', 0.561, 'due', 'traceable', 'ascribable', 'imputable', 'referable']
senticnet['attrition'] = [-0.891, 0.168, -0.609, 0.05, '#sad', '#scared', -0.427, 'remorsefully', 'contritely', 'contrition', 'contriteness', 'ruefully']
senticnet['atypical'] = [-0.583, 0, 0.814, -0.54, '#sad', '#angry', -0.646, 'abnormal', 'irregular', 'vicarious', 'supernormal', 'subnormal']
senticnet['au_pair'] = [0.875, 0, 0, 0.802, '#joyful', '#admirable', 0.559, 'foreigner', 'exile', 'deportee', 'gringo', 'import']
senticnet['auction'] = [0, 0.827, 0, 0.84, '#interesting', '#admirable', 0.556, 'some_place', 'baby_sitter', 'babysitter', 'another_planet', 'death_row']
senticnet['audacious'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'intrepidly', 'hardy', 'fearlessness', 'fearlessly', 'unafraid']
senticnet['audaciousness'] = [0.775, -0.978, 0, 0.731, '#joyful', '#surprising', 0.828, 'daredevilry', 'daredeviltry', 'temerity', 'audacity', 'boldness']
senticnet['audacity'] = [0.775, -0.978, 0, 0.731, '#joyful', '#surprising', 0.828, 'daredevilry', 'daredeviltry', 'temerity', 'boldness', 'audaciousness']
senticnet['audibility'] = [0.685, -0.912, 0, 0.566, '#joyful', '#surprising', 0.721, 'perceptibility', 'audibleness', 'visibleness', 'visibility', 'physical_property']
senticnet['audible'] = [0.778, 0, 0, 0.706, '#joyful', '#admirable', 0.495, 'loud_soft', 'vocalization', 'mouth_noise', 'human_sound', 'human_noise']
senticnet['audibleness'] = [0.685, -0.912, 0, 0.566, '#joyful', '#surprising', 0.721, 'audibility', 'perceptibility', 'visibleness', 'visibility', 'physical_property']
senticnet['audience'] = [0.725, 0, 0, 0.86, '#joyful', '#admirable', 0.528, 'public', 'crowd', 'entertain_crowd', 'committee', 'large_crowd']
senticnet['audio'] = [0.055, 0, 0.03, 0.136, '#joyful', '#admirable', 0.054, 'loud_soft', 'decibel', 'loudness', 'sound', 'melodic_noise']
senticnet['audit'] = [0.947, 0.836, 0, 0, '#joyful', '#interesting', 0.594, 'credit_card', 'profit', 'mastercard', 'american_express', 'back_to_black']
senticnet['audition'] = [0.785, -0.995, 0, 0.981, '#surprising', '#admirable', 0.92, 'ear', 'absolute_pitch', 'perfect_pitch', 'modality', 'sense_modality']
senticnet['auditor'] = [-0.832, 0, 0.665, -0.512, '#sad', '#angry', -0.67, 'percipient', 'eavesdropper', 'perceiver', 'observer', 'beholder']
senticnet['auditorium'] = [0.744, -0.754, 0, 0, '#joyful', '#surprising', 0.499, 'theater', 'lecture_theater', 'tv_studio', 'movie_theater', 'opus']
senticnet['auditory_agnosia'] = [-0.738, 0, 0.955, -0.547, '#sad', '#angry', -0.747, 'visual_agnosia', 'agnosia', 'brain_disorder', 'encephalopathy', 'brain_disease']
senticnet['auditory_aphasia'] = [-0.82, 0, 0.953, -0.878, '#angry', '#disgusting', -0.884, 'aphasia', 'acoustic_aphasia', 'word_deafness', 'nominal_aphasia', 'anomic_aphasia']
senticnet['augment'] = [0, 0.262, -0.122, 0.399, '#interesting', '#admirable', 0.18, 'grow_large', 'proceed', 'increase', 'inclusion', 'plus']
senticnet['augur'] = [0.686, -0.514, 0, 0.829, '#joyful', '#admirable', 0.676, 'diviner', 'oracle', 'auspex', 'prophetess', 'sibyl']
senticnet['aunt'] = [0.02, 0.209, -0.148, 0.202, '#interesting', '#admirable', 0.094, 'familiar', 'mum', 'familiarity_uncle', 'care_giver', 'familiarity']
senticnet['aunt_uncle'] = [0.98, 0.786, 0, 0, '#joyful', '#interesting', 0.589, 'brother_sister', 'relative', 'relate_person', 'female_sibling', 'mom_dad']
senticnet['aureole'] = [0.931, -0.825, 0, 0.709, '#joyful', '#surprising', 0.822, 'light', 'radiance', 'corona', 'visible_light', 'visible_radiation']
senticnet['auriform'] = [0.969, -0.542, 0, 0.806, '#joyful', '#admirable', 0.772, 'aspheric', 'aspherical', 'prolate', 'rounded', 'crescent']
senticnet['auspex'] = [0.686, -0.514, 0, 0.829, '#joyful', '#admirable', 0.676, 'diviner', 'augur', 'oracle', 'prophetess', 'sibyl']
senticnet['auspicate'] = [0.636, -0.541, 0, 0.673, '#joyful', '#admirable', 0.617, 'foreshow', 'signal', 'threaten', 'bespeak', 'betoken']
senticnet['auspice'] = [0.851, -0.657, 0, 0.66, '#joyful', '#admirable', 0.723, 'omen', 'portent', 'presage', 'prognostic', 'prognostication']
senticnet['auspicious'] = [0.997, -0.655, 0, 0.569, '#joyful', '#surprising', 0.74, 'fortunate', 'rosy', 'promising', 'bright', 'hopeful']
senticnet['auspiciousness'] = [0.854, -0.794, 0, 0.977, '#joyful', '#admirable', 0.875, 'profitableness', 'favorableness', 'favourableness', 'advantageousness', 'positivity']
senticnet['austere'] = [0, 0, 0.722, -0.808, '#angry', '#disgusting', -0.51, 'spartan', 'abstemious', 'abstinent', 'strict', 'severe']
senticnet['australian_magpie'] = [-0.845, 0, 0.655, -0.851, '#sad', '#disgusting', -0.784, 'piping_crow', 'butcherbird', 'currawong', 'bell_magpie', 'oscine']
senticnet['authenticate'] = [0.749, -0.796, 0, 0.768, '#surprising', '#admirable', 0.771, 'prove', 'show', 'condemn', 'attest', 'reflect']
senticnet['authenticated'] = [-0.642, 0, 0.852, -0.803, '#angry', '#disgusting', -0.766, 'unquestionable', 'documented', 'veritable', 'attested', 'echt']
senticnet['authenticity'] = [0.726, -0.824, 0, 0.966, '#surprising', '#admirable', 0.839, 'real_thing', 'real_stuff', 'credibility', 'credibleness', 'believability']
senticnet['authoring_language'] = [-0.849, 0, 0.689, -0.907, '#sad', '#disgusting', -0.815, 'software', 'software_program', 'computer_software', 'software_system', 'software_package']
senticnet['authoritarian'] = [-0.551, 0, 0.931, -0.74, '#angry', '#disgusting', -0.741, 'totalitarian', 'undemocratic', 'dictatorial', 'despotic', 'monarchal']
senticnet['authoritative'] = [0.923, -0.546, 0, 0.633, '#joyful', '#admirable', 0.701, 'important', 'prestigious', 'powerful', 'influential', 'potent']
senticnet['authority'] = [0.954, 0.996, 0, 0.781, '#joyful', '#interesting', 0.91, 'officer', 'command', 'policeman', 'military_order', 'supervisor']
senticnet['authorized'] = [-0.784, 0, 0.657, -0.868, '#sad', '#disgusting', -0.77, 'commissioned', 'accredited', 'licensed', 'licenced', 'approved']
senticnet['auto'] = [-0.512, 0, 0.552, -0.659, '#angry', '#disgusting', -0.574, 'car', 'gas_guzzler', 'gas_guzzlermobile', 'machine', 'motorcar']
senticnet['auto_mechanic'] = [0, 0, 0, 0.882, '#admirable', '#admirable', 0.294, 'lubricant', 'oil', 'fuel', 'motor', 'car_gas']
senticnet['autobahn'] = [0.869, -0.586, 0, 0.824, '#joyful', '#admirable', 0.76, 'expressway', 'freeway', 'motorway', 'state_highway', 'throughway']
senticnet['autocracy'] = [-0.837, 0, 0.858, -0.795, '#sad', '#angry', -0.83, 'dominance', 'ascendance', 'absolutism', 'ascendancy', 'tirant']
senticnet['autocrat'] = [-0.685, 0, 0.597, -0.848, '#sad', '#disgusting', -0.71, 'dominance', 'tyrant', 'despot', 'despotism', 'dictator']
senticnet['autograph'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'discuss', 'communication', 'communicate_person', 'talk_another_person', 'discussion']
senticnet['autoimmune_disease'] = [-0.759, 0, 0.515, -0.93, '#sad', '#disgusting', -0.735, 'sclerosis', 'induration', 'degenerative_disorder', 'disseminated_sclerosis', 'autoimmune_disorder']
senticnet['autoimmune_disorder'] = [-0.759, 0, 0.515, -0.93, '#sad', '#disgusting', -0.735, 'sclerosis', 'induration', 'degenerative_disorder', 'autoimmune_disease', 'disseminated_sclerosis']
senticnet['automatic'] = [0.721, -0.883, 0, 0, '#joyful', '#surprising', 0.535, 'eletronic', 'robotic', 'pistol', 'firearm', 'shoot_weapon']
senticnet['automatic_car'] = [0.027, 0, 0.026, 0.073, '#joyful', '#admirable', 0.025, 'large_automobile', 'expensive_car', 'limousine', 'means_of_transport', 'roulotte']
senticnet['automobile'] = [-0.041, -0.163, 0, 0.056, '#surprising', '#admirable', 0.059, 'car_part', 'under_car', 'car_wheel', 'wheel', 'car']
senticnet['automobile_accident'] = [-0.926, 0, -0.937, 0, '#sad', '#scared', -0.621, 'serious_accident', 'accident', 'hit_car', 'loss_ofawareness', 'bang_head']
senticnet['autoplasty'] = [0.96, -0.839, 0, 0.566, '#joyful', '#surprising', 0.788, 'lift', 'phalloplasty', 'abdominoplasty', 'tummy_tuck', 'plastic_surgery']
senticnet['autostrada'] = [0.579, -0.891, 0, 0.878, '#surprising', '#admirable', 0.783, 'autobahn', 'expressway', 'turnpike', 'toll_road', 'highway']
senticnet['autumn'] = [0, -0.031, -0.105, -0.073, '#scared', '#disgusting', -0.049, 'avalanche', 'winter', 'skier', 'snow_fall', 'volcano']
senticnet['autumn_leaf'] = [-0.899, 0, 0, -0.985, '#sad', '#disgusting', -0.628, 'tropical_fish', 'wood_duck', 'disney', 'pink_flower', 'beau']
senticnet['autumn_sneezeweed'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'herb', 'sneezeweed', 'orange_sneezeweed', 'owlclaws', 'rosilla']
senticnet['avail'] = [0.951, -0.96, 0, 0.707, '#joyful', '#surprising', 0.873, 'helpfulness', 'help', 'usefulness', 'utility', 'service']
senticnet['availability'] = [0.781, 0.956, 0, 0.839, '#interesting', '#admirable', 0.859, 'ornament', 'centennial', 'present', 'card', 'lifetime']
senticnet['available'] = [-0.059, 0.161, -0.126, 0.181, '#interesting', '#admirable', 0.052, 'usable', 'redo', 'timeliness', 'question_starter', 'replay']
senticnet['avalanche'] = [0, -0.031, -0.105, -0.073, '#scared', '#disgusting', -0.049, 'autumn', 'winter', 'skier', 'snow_fall', 'volcano']
senticnet['avarice'] = [-0.5, 0, 0.939, -0.835, '#angry', '#disgusting', -0.758, 'greed', 'covetousness', 'possessiveness', 'desire', 'acquisitiveness']
senticnet['avaricious'] = [0.098, 0.084, 0.819, -0.682, '#angry', '#disgusting', -0.44, 'grasp', 'covet', 'covetousness', 'prehensile', 'grabby']
senticnet['avenue'] = [0, 0, 0.033, -0.045, '#angry', '#disgusting', -0.026, 'boulevard', 'lane', 'thoroughfare', 'intersection', 'curb']
senticnet['aver'] = [0.565, -0.738, 0, 0.542, '#joyful', '#surprising', 0.615, 'say', 'asseverate', 'predicate', 'insist', 'take_firm_stand']
senticnet['average'] = [0.031, 0.125, 0.081, 0.138, '#interesting', '#admirable', 0.071, 'equal', 'add', 'tally', 'multiplication', 'mathematical_operation']
senticnet['average_out'] = [-0.529, 0, 0.821, -0.651, '#angry', '#disgusting', -0.667, 'work_out', 'reckon', 'calculate', 'cipher', 'cypher']
senticnet['averageness'] = [0.798, -0.517, 0, 0.519, '#joyful', '#admirable', 0.611, 'normalcy', 'commonness', 'expectedness', 'typicality', 'condition']
senticnet['averment'] = [0.976, -0.685, 0, 0.672, '#joyful', '#surprising', 0.778, 'testimony', 'claim', 'charge', 'contention', 'accusation']
senticnet['aversion'] = [-0.127, 0.193, 0.593, -0.627, '#angry', '#disgusting', -0.385, 'distaste', 'antipathy', 'disapproval', 'disapprove', 'disapproving']
senticnet['aversion_therapy'] = [0.542, -0.63, 0, 0.912, '#surprising', '#admirable', 0.695, 'implosion_therapy', 'flooding', 'reciprocal_inhibition', 'behavior_modification', 'desensitization_technique']
senticnet['averting'] = [0.649, -0.858, 0, 0.947, '#surprising', '#admirable', 0.818, 'rejection', 'escape', 'near_thing', 'aversion', 'avoidance']
senticnet['avian'] = [0.05, -0.016, 0, 0.058, '#joyful', '#admirable', 0.041, 'wing_insect', 'flap_wing', 'aviation', 'wing_animal', 'wing_creature']
senticnet['avian_influenza'] = [-0.963, 0, 0.43, -0.903, '#sad', '#disgusting', -0.765, 'disease', 'doctor', 'sickness', 'illness', 'sick']
senticnet['aviation'] = [0.05, -0.016, 0, 0.058, '#joyful', '#admirable', 0.041, 'wing_insect', 'flap_wing', 'avian', 'wing_animal', 'wing_creature']
senticnet['aviator'] = [0.946, 0, 0, 0.77, '#joyful', '#admirable', 0.572, 'shade', 'drive_quickly', 'drive', 'drive_somewhere', 'fast_travel']
senticnet['avid'] = [0.75, 0, 0, 0.966, '#joyful', '#admirable', 0.572, 'thirst', 'eagerly', 'eagerness', 'avidity', 'avidness']
senticnet['avidity'] = [-0.875, 0, -0.717, -0.961, '#sad', '#disgusting', -0.851, 'avid', 'eagerly', 'eagerness', 'thirstily', 'avidness']
senticnet['avidness'] = [-0.884, 0.175, -0.599, 0, '#sad', '#scared', -0.436, 'keenness', 'eagerly', 'eagerness', 'avidity', 'thirstily']
senticnet['avitaminosis'] = [-0.712, 0, 0.74, -0.506, '#sad', '#angry', -0.653, 'kwashiorkor', 'marasmus', 'malnutrition', 'hypovitaminosis', 'deficiency_disease']
senticnet['avoid'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'avoid_conversation', 'avoid_person', 'prevent', 'avoid_fight', 'refrain_from']
senticnet['avoid_accident'] = [0.039, 0.152, 0, 0.157, '#interesting', '#admirable', 0.116, 'keep_safe', 'drive_safely', 'avoid_problem', 'just_in_time', 'good_break']
senticnet['avoid_bankruptcy'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'success', 'avoid_failure', 'triumph', 'avoid_fall', 'achievement']
senticnet['avoid_commitment'] = [-0.998, 0, 0.893, -0.703, '#sad', '#angry', -0.865, 'skip_class', 'absent', 'avoid_work', 'laziness', 'avoid_responsibility']
senticnet['avoid_conflict'] = [0.932, 0.787, 0, 0, '#joyful', '#interesting', 0.573, 'learn_patience', 'discuss', 'understand_each_other', 'conformist_attitude', 'seek_clarification']
senticnet['avoid_conversation'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'avoid', 'avoid_person', 'prevent', 'escape', 'refrain_from']
senticnet['avoid_crash'] = [0.722, 0.865, 0, 0.748, '#interesting', '#admirable', 0.778, 'safety', 'traffic_light', 'slow_speed', 'safety_belt', 'car']
senticnet['avoid_detention'] = [0, -0.04, 0, 0.244, '#surprising', '#admirable', 0.095, 'behave', 'good_citizen', 'make_up_story', 'follow_rule', 'think']
senticnet['avoid_failure'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'success', 'avoid_bankruptcy', 'triumph', 'avoid_fall', 'achievement']
senticnet['avoid_fall'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'find_balance', 'agile', 'skip_rope', 'avoid_failure', 'good_balance']
senticnet['avoid_fight'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'avoid_conversation', 'avoid_person', 'prevent', 'escape', 'refrain_from']
senticnet['avoid_food'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'ill', 'ill_person', 'sickness', 'sick', 'fast_day']
senticnet['avoid_injury'] = [0.29, 0, 0.028, 0.143, '#joyful', '#admirable', 0.135, 'safe', 'live_healthy_life', 'live_well', 'stimulation', 'live_long_happy_life']
senticnet['avoid_pain'] = [-0.87, 0, -0.959, 0, '#sad', '#scared', -0.61, 'medicine', 'get_cured', 'kill_specific_group', 'cure', 'illeness']
senticnet['avoid_person'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'avoid_conversation', 'avoid', 'prevent', 'rudeness', 'refrain_from']
senticnet['avoid_pregnancy'] = [0, 0, 0, 0.752, '#admirable', '#admirable', 0.251, 'prevent_pregnancy', 'contraception', 'safe_sex', 'sex', 'sexual_excitement']
senticnet['avoid_problem'] = [0.039, 0.152, 0, 0.157, '#interesting', '#admirable', 0.116, 'keep_safe', 'drive_safely', 'avoid_accident', 'just_in_time', 'good_break']
senticnet['avoid_responsibility'] = [-0.773, 0, 0.877, -0.947, '#angry', '#disgusting', -0.866, 'avoid_work', 'lazy', 'reject_involvement', 'skip_class', 'skip_assignment']
senticnet['avoid_work'] = [-0.998, 0, 0.893, -0.703, '#sad', '#angry', -0.865, 'skip_class', 'absent', 'avoid_commitment', 'laziness', 'avoid_responsibility']
senticnet['avoidance'] = [0, 0, 0.717, -0.888, '#angry', '#disgusting', -0.535, 'rejection', 'escape', 'near_thing', 'aversion', 'averting']
senticnet['avow'] = [0.813, -0.625, 0, 0.513, '#joyful', '#surprising', 0.65, 'hold', 'attest', 'assure', 'claim', 'take']
senticnet['avowed'] = [0.843, -0.935, 0, 0.952, '#surprising', '#admirable', 0.91, 'asserted', 'declared', 'professed', 'alleged', 'announced']
senticnet['await'] = [-0.867, 0, 0.609, -0.5, '#sad', '#angry', -0.659, 'look_forward', 'look_to', 'look_for', 'hang_on', 'expect']
senticnet['awake'] = [0, 0.08, 0, 0.179, '#interesting', '#admirable', 0.086, 'wake_up_morning', 'up_early', 'get_up_early', 'gather_energy_tomorrow', 'sit_chair']
senticnet['awaken'] = [0.023, 0.212, -0.132, 0.172, '#interesting', '#admirable', 0.092, 'step_up', 'levitate', 'rise_up', 'come_up', 'raise_up']
senticnet['award'] = [0.797, 0.887, 0, 0.965, '#interesting', '#admirable', 0.883, 'merit', 'excel', 'importance', 'bonus', 'prize']
senticnet['award_winner'] = [0, 0.066, 0, 0.093, '#interesting', '#admirable', 0.053, 'forge', 'recognition', 'medal', 'plaque', 'winner']
senticnet['aware'] = [0, -0.764, 0, 0.79, '#surprising', '#admirable', 0.518, 'alert', 'familiar', 'alive', 'conscious', 'awake']
senticnet['awareness'] = [0.098, 0.165, -0.134, 0.284, '#interesting', '#admirable', 0.138, 'see_different', 'eye_strain', 'know', 'learn', 'insight']
senticnet['away'] = [-0.853, 0, 0, -0.734, '#sad', '#disgusting', -0.529, 'long_distance', 'compass_direction', 'distance', 'afar', 'long_distance_relationship']
senticnet['away_crime'] = [0, 0, 0, -0.875, '#disgusting', '#disgusting', -0.292, 'commit_perjury', 'obstruct_justice', 'get_away_crime', 'hurt_else', 'destroy_enemy']
senticnet['awe'] = [0.867, 0, 0, 0.963, '#joyful', '#admirable', 0.61, 'wonder', 'wonderment', 'amazement', 'astonishment', 'respect']
senticnet['awed'] = [0.044, -0.659, 0, 0.364, '#surprising', '#admirable', 0.356, 'awestricken', 'awestruck', 'wondrous', 'wondrously', 'terrific']
senticnet['aweless'] = [0.615, -0.572, 0, 0.502, '#joyful', '#surprising', 0.563, 'irreverent', 'awless', 'disrespectful', 'sacrilegious', 'blasphemous']
senticnet['awesome'] = [0.784, 0.764, 0, 0.79, '#joyful', '#admirable', 0.779, 'most_good', 'high_quality', 'better_good', 'really_good', 'well_done']
senticnet['awestricken'] = [0.044, -0.659, 0, 0.364, '#surprising', '#admirable', 0.356, 'awestruck', 'awed', 'wondrous', 'wondrously', 'terrific']
senticnet['awestruck'] = [0.044, -0.659, 0, 0.364, '#surprising', '#admirable', 0.356, 'awestricken', 'awed', 'wondrous', 'wondrously', 'terrific']
senticnet['awful'] = [-0.082, 0.202, 0.615, -0.627, '#angry', '#disgusting', -0.374, 'terrible', 'awful_mistake', 'ugly', 'disgusting', 'bad']
senticnet['awful_event'] = [-0.923, 0, 0.095, -0.91, '#sad', '#disgusting', -0.643, 'mess', 'distressingly_bad', 'terrible_crime', 'bad_influence', 'terrible_loss']
senticnet['awful_mistake'] = [-0.082, 0.202, 0.615, -0.627, '#angry', '#disgusting', -0.374, 'terrible', 'awful', 'mess', 'problem', 'mistake']
senticnet['awfully'] = [-0.794, 0, 0, -0.735, '#sad', '#disgusting', -0.51, 'horrifying', 'atrocious', 'dreadfully', 'horrifyingly', 'horrified']
senticnet['awing'] = [0.562, -0.698, 0, 0.883, '#surprising', '#admirable', 0.714, 'majestic', 'formidable', 'awesome', 'impressive', 'brilliant']
senticnet['awkward'] = [-0.97, 0, 0, -0.948, '#sad', '#disgusting', -0.639, 'abash', 'unenviable', 'embarrassingly', 'embarrassing', 'sheepish']
senticnet['awkwardness'] = [-0.647, 0, 0.625, -0.882, '#sad', '#disgusting', -0.718, 'difficulty', 'troublesomeness', 'flea_bite', 'difficultness', 'cumbersomeness']
senticnet['awless'] = [0.615, -0.572, 0, 0.502, '#joyful', '#surprising', 0.563, 'aweless', 'irreverent', 'disrespectful', 'sacrilegious', 'blasphemous']
senticnet['axe'] = [-0.913, 0, 0, -0.716, '#sad', '#disgusting', -0.543, 'knife', 'hatchet', 'cut_tool', 'dagger', 'saw']
senticnet['axiom'] = [0, 0.274, -0.066, 0.282, '#interesting', '#admirable', 0.163, 'principle', 'tenet', 'govern', 'confirmation', 'supreme']
senticnet['axle'] = [0.041, -0.087, 0, 0.056, '#surprising', '#admirable', 0.061, 'engine', 'wheel', 'motor', 'steer_wheel', 'two_wheels']
senticnet['aye'] = [0.919, 0, 0, 0.703, '#joyful', '#admirable', 0.541, 'admit', 'propose', 'cope', 'contribution', 'promise']
senticnet['ayrshire'] = [0.546, -0.969, 0, 0.533, '#joyful', '#surprising', 0.683, 'dairy_cattle', 'dairy_cow', 'milch_cow', 'milk_cow', 'milcher']
senticnet['babassu'] = [0.635, -0.847, 0, 0.85, '#surprising', '#admirable', 0.777, 'oil_palm', 'feather_palm', 'palm', 'coco_de_macao', 'wax_palm']
senticnet['babassu_palm'] = [0.635, -0.847, 0, 0.85, '#surprising', '#admirable', 0.777, 'oil_palm', 'babassu', 'feather_palm', 'coco_de_macao', 'wax_palm']
senticnet['babble'] = [-0.614, 0, 0.738, -0.803, '#angry', '#disgusting', -0.718, 'babbling', 'double_talk', 'mumbo_jumbo', 'gibber', 'lallation']
senticnet['babbling'] = [-0.614, 0, 0.738, -0.803, '#angry', '#disgusting', -0.718, 'gibber', 'double_talk', 'mumbo_jumbo', 'babble', 'lallation']
senticnet['babe_ruth'] = [0.048, 0, 0, 0.092, '#joyful', '#admirable', 0.047, 'find_other_player', 'know_how_play_baseball', 'step_up_plate', 'contest', 'game_chess']
senticnet['babinski'] = [0.89, -0.821, 0, 0.776, '#joyful', '#surprising', 0.829, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['babinski_reflex'] = [0.68, -0.824, 0, 0.574, '#joyful', '#surprising', 0.693, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['babinski_sign'] = [0.722, -0.87, 0, 0.696, '#joyful', '#surprising', 0.763, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['baby'] = [0, 0, 0, 0.939, '#admirable', '#admirable', 0.313, 'large_family', 'small_child', 'youth', 'quiet_baby', 'deliver_baby']
senticnet['baby_action'] = [0.97, 0, 0, 0, '#joyful', '#joyful', 0.323, 'eye_tear', 'reaction', 'shed_tear', 'bawl', 'body_action']
senticnet['baby_bird'] = [0, -0.06, 0.022, 0.054, '#surprising', '#admirable', 0.031, 'chick', 'wild_bird', 'hatch', 'lay_egg', 'bird_home']
senticnet['baby_born'] = [0.032, 0.261, -0.157, 0.198, '#interesting', '#admirable', 0.111, 'carry_baby', 'ejaculate', 'herpes', 'cum', 'change_diaper']
senticnet['baby_cat'] = [0.959, 0, 0, 0.929, '#joyful', '#admirable', 0.629, 'small_cat', 'cute', 'pet', 'small_animal', 'curious_animal']
senticnet['baby_chicken'] = [0.053, 0.091, 0, 0.152, '#interesting', '#admirable', 0.099, 'inside_egg', 'hen_baby', 'oval_shape', 'lay_egg', 'hatch']
senticnet['baby_cow'] = [0, -0.021, 0, 0.06, '#surprising', '#admirable', 0.027, 'male_cow', 'donkey', 'little_horse', 'hoof_animal', 'animal']
senticnet['baby_cry'] = [-0.966, 0, 0.915, 0, '#sad', '#angry', -0.627, 'hear_sound', 'disturb', 'field_question', 'listen_news', 'mess_up']
senticnet['baby_deer'] = [0, -0.101, 0, 0, '#surprising', '#surprising', 0.034, 'mammal', 'type_of_animal', 'animal', 'sea_mammal', 'water_mammal']
senticnet['baby_dog'] = [0.144, 0.134, -0.045, 0.238, '#joyful', '#admirable', 0.157, 'puppy', 'vulnerable', 'need_care', 'young_animal', 'newborn']
senticnet['baby_flower'] = [0.088, 0, 0, 0.072, '#joyful', '#admirable', 0.053, 'wee', 'poppy', 'yellow_flower', 'rose', 'green_plant']
senticnet['baby_need'] = [-0.037, 0, 0.049, 0, '#sad', '#angry', -0.029, 'need_care', 'baby_dog', 'most_dogs', 'young_animal', 'dog']
senticnet['baby_sitter'] = [0, 0.827, 0, 0.84, '#interesting', '#admirable', 0.556, 'take_care', 'baby', 'free_time', 'children_in_safe_hands', 'free_night']
senticnet['babysit'] = [0.705, 0.953, 0, 0, '#joyful', '#interesting', 0.553, 'part_of_family', 'father_child', 'take_out_trash', 'mother_child', 'relationship']
senticnet['babysitter'] = [0, 0.827, 0, 0.84, '#interesting', '#admirable', 0.556, 'some_place', 'baby_sitter', 'auction', 'another_planet', 'death_row']
senticnet['bachata'] = [0.764, -0.526, 0, 0.866, '#joyful', '#admirable', 0.719, 'tap_dancing', 'tap_dance', 'hoofing', 'dance', 'salsa']
senticnet['bachelor_degree'] = [0.032, 0, 0, 0.053, '#joyful', '#admirable', 0.028, 'place_learn', 'educational_institution', 'educational_facility', 'educational_place', 'student_study']
senticnet['bachelor_party'] = [0.702, -0.862, 0, 0, '#joyful', '#surprising', 0.521, 'special_event', 'type', 'birthday_party', 'event', 'event_type']
senticnet['bacillary_dysentery'] = [-0.892, 0, 0.702, -0.671, '#sad', '#angry', -0.755, 'amebic_dysentery', 'amoebic_dysentery', 'shigellosis', 'dysentery', 'infectious_disease']
senticnet['bacitracin'] = [0.768, -0.631, 0, 0.717, '#joyful', '#admirable', 0.705, 'antibacterial', 'medication', 'kill_germ', 'antibiotic', 'antibiotic_drug']
senticnet['back'] = [0.854, -0.703, 0, 0.912, '#joyful', '#admirable', 0.823, 'shew', 'verify', 'affirm', 'prove', 'demonstrate']
senticnet['back_airplane'] = [0, 0.281, 0, 0.206, '#interesting', '#admirable', 0.162, 'plane', 'airplane', 'type_of_car', 'bus', 'airliner']
senticnet['back_bone'] = [0, 0.991, 0, 0.804, '#interesting', '#admirable', 0.598, 'pillar', 'sustain', 'solid_basis', 'structure', 'help_people']
senticnet['back_door'] = [0.844, 0, 0, 0, '#joyful', '#joyful', 0.281, 'back_yard', 'exit', 'door', 'door_knob', 'home']
senticnet['back_forth'] = [0.059, 0.132, -0.128, 0.272, '#interesting', '#admirable', 0.112, 'hand_movement', 'hand_action', 'hand_gesture', 'vibrate', 'hand_motion']
senticnet['back_house'] = [0.844, 0, 0, 0, '#joyful', '#joyful', 0.281, 'outside_house', 'garden', 'yard', 'backyard', 'outdoor']
senticnet['back_off'] = [0, 0, 0, -0.079, '#disgusting', '#disgusting', -0.026, 'go_away', 'ask_to_leave', 'anger', 'chase', 'hold_onto']
senticnet['back_pain'] = [0, 0, -0.798, -0.94, '#scared', '#disgusting', -0.579, 'sore_back', 'backache', 'dog_bark', 'broken_leg', 'become_exhausted']
senticnet['back_pocket'] = [0, 0.092, 0, 0, '#interesting', '#interesting', 0.031, 'man_pocket', 'pant_pocket', 'pocket', 'purse', 'clothes_washer']
senticnet['back_seat'] = [-0.814, 0, 0.864, 0, '#sad', '#angry', -0.559, 'emergency_brake', 'air_vent', 'brake_pedal', 'fan_belt', 'exhaust_pipe']
senticnet['back_sofa'] = [-0.023, 0, 0, -0.058, '#sad', '#disgusting', -0.027, 'sock_drawer', 'under_carpet', 'closet', 'under_closet', 'under_bed']
senticnet['back_to_black'] = [0.869, 0.871, 0, 0, '#joyful', '#interesting', 0.58, 'credit_card', 'profit', 'mastercard', 'audit', 'american_express']
senticnet['back_up'] = [0.635, 0.639, -0.243, 0.291, '#joyful', '#interesting', 0.441, 'heal', 'put_back', 'restore', 'restore_energy', 'fill_up']
senticnet['back_yard'] = [0, 0.092, 0, 0, '#interesting', '#interesting', 0.031, 'outside_house', 'behind_house', 'yard', 'backyard', 'back_house']
senticnet['backache'] = [0, 0, -0.861, -0.951, '#scared', '#disgusting', -0.604, 'back_pain', 'sore_back', 'feel_tired', 'a_lot_of_noise', 'dog_bark']
senticnet['backbend'] = [-0.687, 0, 0.545, -0.688, '#sad', '#disgusting', -0.64, 'stunt', 'tumble', 'split', 'walkover', 'acrobatic_feat']
senticnet['backbone'] = [0.147, 0.126, -0.096, 0.314, '#joyful', '#admirable', 0.164, 'bone', 'nipple', 'leave_leg', 'thigh', 'scrotum']
senticnet['backchat'] = [-0.853, 0, 0.855, -0.878, '#angry', '#disgusting', -0.862, 'banter', 'raillery', 'repartee', 'wit', 'humor']
senticnet['backdrop'] = [0, 0.117, -0.077, 0.094, '#interesting', '#admirable', 0.045, 'stage_door', 'balcony', 'curtain', 'stage_border', 'row_seat']
senticnet['backfire'] = [0.774, -0.916, 0, 0.95, '#surprising', '#admirable', 0.88, 'big_bang', 'fragmentation', 'discharge', 'blowup', 'blast']
senticnet['backgammon'] = [0, -0.07, -0.047, 0.063, '#surprising', '#admirable', 0.029, 'yo-yo', 'playroom', 'game', 'board_game', 'play_game']
senticnet['backpack'] = [0.042, -0.056, 0, 0, '#joyful', '#surprising', 0.033, 'drink_coffee', 'backpacker', 'internet_cafe', 'coffee_house', 'hostel']
senticnet['backpacker'] = [0.042, -0.056, 0, 0, '#joyful', '#surprising', 0.033, 'drink_coffee', 'backpack', 'internet_cafe', 'coffee_house', 'hostel']
senticnet['backseat'] = [-0.579, 0, 0.53, -0.639, '#sad', '#disgusting', -0.583, 'low_status', 'lowness', 'inferiority', 'lowliness', 'subordinateness']
senticnet['backseat_driver'] = [-0.641, 0, 0.71, -0.953, '#angry', '#disgusting', -0.768, 'buttinsky', 'unwelcome_person', 'killjoy', 'meddler', 'busybody']
senticnet['backside'] = [-0.112, 0.184, -0.131, 0.157, '#interesting', '#admirable', 0.033, 'rear', 'go_backwards', 'rear_end', 'flipside', 'exception']
senticnet['backstroke'] = [0.703, 0.836, 0, 0, '#joyful', '#interesting', 0.513, 'swim', 'water_activity', 'movement_of_water', 'water_sport', 'swiming_pool']
senticnet['backtalk'] = [-0.958, 0, 0.941, -0.577, '#sad', '#angry', -0.825, 'reply', 'response', 'sass', 'sassing', 'comeback']
senticnet['backup'] = [0, 0.716, 0, 0.741, '#interesting', '#admirable', 0.486, 'make_musical_sound', 'play_orchestra', 'make_noise', 'play_music', 'make_drawing']
senticnet['backup_man'] = [-0.573, 0, 0.932, -0.504, '#sad', '#angry', -0.67, 'backup', 'substitute', 'reliever', 'relief', 'stunt_man']
senticnet['backward'] = [-0.801, 0, 0, -0.778, '#sad', '#disgusting', -0.526, 'reverse', 'retrograde', 'retral', 'primitive', 'benighted']
senticnet['backwardness'] = [-0.654, 0, 0.691, -0.547, '#sad', '#angry', -0.631, 'moronity', 'mental_deficiency', 'imbecility', 'stupidity', 'mental_defectiveness']
senticnet['backwards'] = [0.035, 0.115, 0, 0.209, '#interesting', '#admirable', 0.12, 'dance_move', 'anagram', 'pace', 'tread', 'foot_action']
senticnet['backyard'] = [0.844, 0, 0, 0, '#joyful', '#joyful', 0.281, 'outside_house', 'garden', 'yard', 'back_house', 'outdoor']
senticnet['bacon'] = [0.648, -0.539, 0, 0.94, '#joyful', '#admirable', 0.709, 'bacon_strip', 'flitch', 'side_of_bacon', 'gammon', 'cut_of_pork']
senticnet['bacon_strip'] = [0.648, -0.539, 0, 0.94, '#joyful', '#admirable', 0.709, 'bacon', 'flitch', 'side_of_bacon', 'gammon', 'cut_of_pork']
senticnet['bacteria'] = [0.905, -0.659, 0, 0.851, '#joyful', '#admirable', 0.805, 'gonococcus', 'acidophil', 'acidophile', 'probiotic', 'probiotic_bacterium']
senticnet['bacteria_order'] = [0.888, -0.815, 0, 0.617, '#joyful', '#surprising', 0.773, 'ordering', 'word_order', 'genetic_code', 'genome', 'series']
senticnet['bacterium'] = [-0.846, 0, 0, -0.727, '#sad', '#disgusting', -0.524, 'earthworm', 'microorganism', 'germ', 'bug', 'cutworm']
senticnet['bad'] = [-0.755, 0.154, -0.643, 0.142, '#sad', '#scared', -0.367, 'evil', 'awful', 'bad_person', 'smell_bad', 'harmful_human']
senticnet['bad_action'] = [-0.768, 0, 0.85, -0.778, '#angry', '#disgusting', -0.799, 'violent_action', 'bad_behavior', 'consequence', 'judge_decision', 'badness']
senticnet['bad_air'] = [-0.999, 0, 0.056, -0.982, '#sad', '#disgusting', -0.679, 'smoke', 'cigarette', 'tobacco', 'pollution', 'cigar']
senticnet['bad_behavior'] = [-0.458, 0.154, -0.392, 0.094, '#sad', '#scared', -0.201, 'bad_choice', 'wrongdoing', 'misbehavior', 'wrong', 'retribution']
senticnet['bad_blood'] = [0, 0.146, 0.723, -0.665, '#angry', '#disgusting', -0.414, 'animus', 'belligerently', 'hostilely', 'aggressiveness', 'antagonism']
senticnet['bad_boy'] = [-0.196, 0, -0.12, 0, '#sad', '#scared', -0.105, 'bad_child', 'misbehavior', 'bad_kid', 'bad_action', 'difficulty']
senticnet['bad_breath'] = [0, 0, 0.933, -0.965, '#angry', '#disgusting', -0.633, 'worm_intestine', 'fur_keep_warm', 'unpleasant-smelling', 'halitosis', 'asthama']
senticnet['bad_camera'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'slow', 'long_focus', 'focus_time', 'long_focus_time', 'low_quality_photo']
senticnet['bad_character'] = [-0.941, 0, 0.105, -0.967, '#sad', '#disgusting', -0.671, 'bad_person', 'bad', 'evil_man', 'evil_eye', 'bad_action']
senticnet['bad_child'] = [-0.2, 0.081, -0.127, 0, '#sad', '#scared', -0.082, 'bad_boy', 'misbehavior', 'bad_action', 'badness', 'difficulty']
senticnet['bad_choice'] = [-0.951, 0, 0.42, -0.916, '#sad', '#disgusting', -0.762, 'mistake', 'bad', 'error', 'danger', 'trouble']
senticnet['bad_citizen'] = [-0.82, 0, 0.953, -0.878, '#angry', '#disgusting', -0.884, 'steal', 'rob', 'leave_without_pay', 'shoplift', 'robbery']
senticnet['bad_climate'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'storm', 'heavy_rain', 'rain', 'snow', 'become_sick']
senticnet['bad_communication'] = [-0.919, 0, 0.833, -0.945, '#sad', '#disgusting', -0.899, 'curse_word', 'bad_word', 'rude', 'rude_man', 'curse']
senticnet['bad_company'] = [-0.947, 0, 0.622, -0.912, '#sad', '#disgusting', -0.827, 'bad_team', 'terrorist_group', 'terrorist_corporation', 'terrorism', 'bad_guy']
senticnet['bad_connection'] = [-0.096, -0.036, 0.061, 0, '#sad', '#angry', -0.04, 'bad_reception', 'wifi', 'internet', 'phone_call', 'underground']
senticnet['bad_couple'] = [-0.975, 0, 0.893, -0.993, '#sad', '#disgusting', -0.954, 'heart_broken', 'wrong_person', 'fake_love', 'bad_person', 'bad_marriage']
senticnet['bad_credit'] = [-0.175, 0.095, 0, -0.163, '#sad', '#disgusting', -0.081, 'bank', 'piggy_bank', 'checkbook', 'government_agreement', 'wallet']
senticnet['bad_customer'] = [-0.927, 0, 0.784, -0.912, '#sad', '#disgusting', -0.874, 'rude_man', 'disloyal', 'make_noise', 'bad_communication', 'buy_cheaper']
senticnet['bad_dream'] = [-0.976, 0, 0.502, -0.971, '#sad', '#disgusting', -0.816, 'nightmare', 'eat_too_much', 'stress', 'anxiety', 'bad_rest']
senticnet['bad_drug'] = [-0.182, -0.078, 0, -0.203, '#sad', '#disgusting', -0.102, 'water_spill', 'water', 'atmosphere', 'cool_water', 'obtain_water']
senticnet['bad_egg'] = [-0.931, 0, 0.238, -0.904, '#sad', '#disgusting', -0.691, 'expired', 'poisoning', 'bad_taste', 'spoil', 'expired_food']
senticnet['bad_experience'] = [0, 0, -0.737, 0, '#scared', '#scared', -0.246, 'bad_haircut', 'further_knowledge', 'join_navy', 'explain_problem', 'live_castle']
senticnet['bad_eyesight'] = [-0.139, 0, 0.013, -0.081, '#sad', '#disgusting', -0.078, 'blind', 'dig_tunnel', 'underground_animal', 'big_mouse', 'small_rodent']
senticnet['bad_fairy'] = [-0.678, 0, 0.752, -0.898, '#angry', '#disgusting', -0.776, 'evil_spirit', 'fiend', 'demon', 'devil', 'daimon']
senticnet['bad_feeling'] = [-0.839, 0, 0, 0, '#sad', '#sad', -0.28, 'feel_stressed', 'complication', 'anguish', 'death_love', 'screw_up']
senticnet['bad_flatmate'] = [-0.932, 0, 0.578, -0.906, '#sad', '#disgusting', -0.805, 'lazy', 'slack_off', 'careless', 'terrible', 'slack']
senticnet['bad_food'] = [0, 0, -0.84, 0, '#scared', '#scared', -0.28, 'bad_karma', 'spoil_food', 'anxiety_disorder', 'anthrax', 'tape_machine_room']
senticnet['bad_grade'] = [-0.3, -0.031, -0.096, -0.056, '#sad', '#scared', -0.14, 'loss', 'flunk', 'lose_memory', 'loose', 'lose_war']
senticnet['bad_guy'] = [0, 0, 0.913, -0.983, '#angry', '#disgusting', -0.632, 'opposition', 'rival', 'conflict', 'uprise', 'foe']
senticnet['bad_habit'] = [0, 0, -0.073, 0, '#scared', '#scared', -0.024, 'vapor', 'gaseous', 'haze', 'smoke', 'smog']
senticnet['bad_hair_day'] = [-0.49, -0.142, -0.082, -0.374, '#sad', '#disgusting', -0.268, 'brain_tumor', 'lyme_disease', 'bad_luck', 'flab', 'suffer_fool']
senticnet['bad_haircut'] = [-0.913, 0, 0.869, -0.765, '#sad', '#angry', -0.849, 'talk_hairdresser', 'hair_get_short', 'hair_become_short', 'keep_hair_short', 'hair_wash']
senticnet['bad_hat'] = [-0.651, 0, 0.716, -0.942, '#angry', '#disgusting', -0.77, 'disturber', 'provoker', 'inciter', 'instigant', 'hellhound']
senticnet['bad_health'] = [-0.381, 0.108, -0.389, 0.072, '#sad', '#scared', -0.197, 'unhealthy', 'dangerous_health', 'hazardous_health', 'harmful_human', 'inherit']
senticnet['bad_influence'] = [-0.923, 0, 0.095, -0.91, '#sad', '#disgusting', -0.643, 'mess', 'trouble', 'bad_company', 'wrong_person', 'awful_event']
senticnet['bad_injury'] = [-0.703, 0, 0, -0.995, '#sad', '#disgusting', -0.566, 'minor_injury', 'get_injured', 'injure', 'accident', 'become_exhausted']
senticnet['bad_karma'] = [-0.39, -0.115, -0.177, -0.307, '#sad', '#disgusting', -0.253, 'physical_pain', 'screw_up', 'bad_feeling', 'schizophrenia', 'disrespect']
senticnet['bad_kid'] = [-0.799, 0, 0.977, 0, '#sad', '#angry', -0.592, 'bad_child', 'bad_boy', 'calamity', 'badness', 'bad_action']
senticnet['bad_knee'] = [-0.168, -0.067, -0.066, -0.264, '#sad', '#disgusting', -0.144, 'broken_bone', 'poke_pin', 'bruise', 'physical_pain', 'earache']
senticnet['bad_liar'] = [-0.245, 0.086, -0.17, 0, '#sad', '#scared', -0.11, 'correct_mistake', 'face_music', 'wait_forever', 'keep_promise', 'state_obvious']
senticnet['bad_luck'] = [-0.438, -0.145, -0.066, -0.333, '#sad', '#disgusting', -0.231, 'brain_tumor', 'lyme_disease', 'cause_suffer', 'lose_team', 'bad_hair_day']
senticnet['bad_man'] = [-0.82, 0, 0.953, -0.878, '#angry', '#disgusting', -0.884, 'lifeboat', 'mast', 'pirate', 'keel', 'yacht']
senticnet['bad_manner'] = [-0.06, 0, 0, -0.166, '#sad', '#disgusting', -0.075, 'inferno', 'big_problem', 'smoke_pipe', 'combustion', 'fire_product']
senticnet['bad_manners'] = [0, 0, 0, -0.765, '#disgusting', '#disgusting', -0.255, 'burp', 'rude', 'fart', 'shame', 'get_angry']
senticnet['bad_marriage'] = [-0.975, 0, 0.893, -0.993, '#sad', '#disgusting', -0.954, 'heart_broken', 'wrong_person', 'fake_love', 'bad_person', 'bad_couple']
senticnet['bad_meal'] = [-0.927, 0, 0.784, -0.912, '#sad', '#disgusting', -0.874, 'eat_fast_food', 'eat_snack', 'eat_unhealthy_food', 'eat_expired_food', 'eat_quickly']
senticnet['bad_memory'] = [-0.957, 0, 0.549, -0.993, '#sad', '#disgusting', -0.833, 'lose_track_of_time', 'memory_loss', 'lose_consciousness', 'sickness', 'become_old']
senticnet['bad_mood'] = [-0.055, -0.009, 0.086, -0.184, '#angry', '#disgusting', -0.105, 'playful_mood', 'rain_forest', 'sadness', 'hole_ground', 'feel_down']
senticnet['bad_music'] = [-0.957, 0, 0.549, -0.993, '#sad', '#disgusting', -0.833, 'annoying_sound', 'stress', 'noise', 'rowdy', 'loud']
senticnet['bad_news'] = [-0.886, 0, -0.783, 0, '#sad', '#scared', -0.556, 'calamity', 'big_monster', 'set_fire', 'sick', 'anxiety_disorder']
senticnet['bad_nightmare'] = [0, 0, -0.905, 0, '#scared', '#scared', -0.302, 'comfortable_position', 'asleep', 'take_nap', 'lie_back', 'miss_work']
senticnet['bad_odor'] = [-0.031, 0.152, -0.107, 0.188, '#interesting', '#admirable', 0.067, 'mouth_action', 'smelly', 'five_senses', 'human_sense', 'exhalation']
senticnet['bad_omen'] = [0, 0, -0.995, 0, '#scared', '#scared', -0.332, 'morality', 'worse', 'inherit', 'hazardous', 'badness']
senticnet['bad_organization'] = [-0.947, 0, 0.622, -0.912, '#sad', '#disgusting', -0.827, 'terrorist_organization', 'terrorist_group', 'bad_company', 'terrorism', 'terrorist_corporation']
senticnet['bad_person'] = [-0.099, 0, -0.091, -0.095, '#sad', '#disgusting', -0.095, 'felon', 'freak', 'busy_person', 'delusional', 'good_man']
senticnet['bad_pillow'] = [-0.92, 0, 0.022, -0.97, '#sad', '#disgusting', -0.637, 'problem', 'headache', 'sick', 'sickness', 'ill']
senticnet['bad_quality'] = [-0.061, 0, 0, -0.037, '#sad', '#disgusting', -0.033, 'poor', 'bad', 'dirt', 'terrible', 'easy_to_break']
senticnet['bad_reception'] = [-0.957, 0, 0.549, -0.993, '#sad', '#disgusting', -0.833, 'bad_connection', 'bad_communication', 'internet_problem', 'absence_of_communication', 'underground']
senticnet['bad_rest'] = [-0.976, 0, 0.502, -0.971, '#sad', '#disgusting', -0.816, 'nightmare', 'eat_too_much', 'stress', 'anxiety', 'jet_lag']
senticnet['bad_service'] = [-0.983, 0, 0.058, -0.921, '#sad', '#disgusting', -0.654, 'bad_staff', 'cheap_hotel', 'cheap_restaurant', 'unfriendly_staff', 'long_waiting_time']
senticnet['bad_situation'] = [0, 0, -0.942, -0.922, '#scared', '#disgusting', -0.621, 'difficulty', 'dilemma', 'odds', 'misplace', 'sadness']
senticnet['bad_smell'] = [0, 0, 0.83, -0.939, '#angry', '#disgusting', -0.59, 'nasty', 'smelly', 'dirty_sock', 'stinky', 'durian']
senticnet['bad_staff'] = [-0.983, 0, 0.058, -0.921, '#sad', '#disgusting', -0.654, 'bad_service', 'cheap_hotel', 'cheap_restaurant', 'unfriendly_staff', 'long_waiting_time']
senticnet['bad_student'] = [-0.118, 0.19, 0.604, -0.63, '#angry', '#disgusting', -0.387, 'disinclination', 'disinclined', 'indispose', 'unfriendly', 'inimical']
senticnet['bad_surprise'] = [-0.732, 0, 0.865, -0.878, '#angry', '#disgusting', -0.825, 'jeer', 'shout', 'abrupt', 'rude', 'mocking']
senticnet['bad_taste'] = [0, 0, 0, -0.817, '#disgusting', '#disgusting', -0.272, 'snot', '32_teeth', 'mouth_part', 'volume_control', 'near_mouth']
senticnet['bad_team'] = [-0.947, 0, 0.622, -0.912, '#sad', '#disgusting', -0.827, 'bad_company', 'terrorist_group', 'terrorist_corporation', 'terrorism', 'bad_guy']
senticnet['bad_temper'] = [-0.139, 0.151, 0.613, -0.627, '#angry', '#disgusting', -0.409, 'ill_temper', 'umbrage', 'offense', 'outraged', 'indignant']
senticnet['bad_tempered'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'cranky', 'nervous', 'neurasthenic', 'irritable', 'testy']
senticnet['bad_thing'] = [-0.91, 0, 0.296, -0.997, '#sad', '#disgusting', -0.734, 'bad', 'trouble', 'danger', 'punishment', 'bad_feeling']
senticnet['bad_time'] = [-0.392, 0, -0.327, 0, '#sad', '#scared', -0.24, 'deliberate', 'unwanted_outcome', 'say_eureka', 'look_fact', 'rational']
senticnet['bad_vision'] = [-0.321, -0.197, 0.049, -0.496, '#sad', '#disgusting', -0.223, 'lay_off', 'poor_eyesight', 'migraine', 'forget_everything', 'cross_eye']
senticnet['bad_weather'] = [-0.984, 0, 0.96, -0.923, '#sad', '#angry', -0.956, 'thunderstorm', 'storm', 'gale', 'heavy_rain', 'hurricane']
senticnet['bad_word'] = [0, 0, 0.764, -0.707, '#angry', '#disgusting', -0.49, 'bigot', 'intolerance', 'censorship', 'kidnap', 'insane']
senticnet['bad_writing'] = [-0.986, 0, 0, -0.704, '#sad', '#disgusting', -0.563, 'mistake', 'error', 'grammar_mistake', 'poor_english', 'misspell']
senticnet['baddie'] = [-0.829, 0, 0.958, -0.557, '#sad', '#angry', -0.781, 'character', 'role', 'theatrical_role', 'part', 'persona']
senticnet['badge'] = [0.844, -0.572, 0, 0.576, '#joyful', '#admirable', 0.664, 'blue_ribbon', 'cordon_bleu', 'allegory', 'stripe', 'merit_badge']
senticnet['badger_skunk'] = [-0.547, 0, 0.768, -0.503, '#sad', '#angry', -0.606, 'striped_skunk', 'hooded_skunk', 'hognosed_skunk', 'polecat', 'rooter_skunk']
senticnet['badness'] = [-0.393, 0.149, -0.166, 0.062, '#sad', '#scared', -0.116, 'bad_action', 'bad_behavior', 'negative', 'inherit', 'cant']
senticnet['baffle'] = [-0.393, 0.149, -0.166, 0.062, '#sad', '#scared', -0.116, 'block', 'confuse', 'confound', 'frustrate', 'impede']
senticnet['bafflement'] = [-0.506, 0, 0.85, -0.828, '#angry', '#disgusting', -0.728, 'confusion', 'disarray', 'mental_confusion', 'confusedness', 'muddiness']
senticnet['bag'] = [0, -0.023, 0, 0.051, '#surprising', '#admirable', 0.025, 'cardboard_box', 'box', 'package', 'box_cereal', 'bin']
senticnet['bagel'] = [0.041, -0.071, 0.034, 0, '#joyful', '#surprising', 0.026, 'butter', 'mayonaise', 'pie', 'noodle', 'muffin']
senticnet['baggage'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'hand_luggage', 'luggage', 'passenger_ticket', 'ticket_counter', 'baggage_trunk']
senticnet['baggage_compartment'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'train_station', 'government_office', 'cable_car', 'sport_stadium', 'terminal']
senticnet['baggage_trunk'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'hand_luggage', 'luggage', 'passenger_ticket', 'ticket_counter', 'travel']
senticnet['bagle'] = [-0.819, 0, 0.9, 0, '#sad', '#angry', -0.573, 'separation', 'divide', 'division', 'slash', 'split']
senticnet['bagnio'] = [0.754, -0.823, 0, 0.947, '#surprising', '#admirable', 0.841, 'whorehouse', 'brothel', 'bordello', 'massage_parlor', 'house_of_prostitution']
senticnet['bail'] = [-0.08, 0.277, -0.159, 0.168, '#interesting', '#admirable', 0.069, 'bequest', 'excise', 'bribe', 'afford', 'owe']
senticnet['bail_out'] = [-0.126, 0, 0, -0.036, '#sad', '#disgusting', -0.054, 'escape', 'escape_situation', 'cancel_meeting', 'absent', 'cancel_appointment']
senticnet['bail_water'] = [-0.035, 0.146, -0.087, 0.208, '#interesting', '#admirable', 0.077, 'sail_ocean', 'hold_flower', 'carry_book', 'carry_liquid', 'hold_stuff']
senticnet['bailable'] = [0.866, -0.528, 0, 0.529, '#joyful', '#admirable', 0.641, 'worthy', 'desirable', 'suitable', 'eligible', 'entitled']
senticnet['bait'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'fishing_rod', 'fishing', 'patience', 'fish_lake', 'catch_fish']
senticnet['bait_trap'] = [0.02, 0.162, 0, 0.062, '#interesting', '#admirable', 0.081, 'catch', 'trap', 'ambush', 'lure', 'decoy']
senticnet['baji'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'polar_bear', 'white_animal', 'arctic_fox', 'white_rabbit', 'fuzzy_animal']
senticnet['bake'] = [0.032, -0.068, 0, 0, '#joyful', '#surprising', 0.033, 'prepare_food', 'food', 'make_flour', 'bake_bread', 'bread']
senticnet['bake_bean'] = [0.098, 0.103, -0.062, 0.134, '#interesting', '#admirable', 0.091, 'like_food', 'bake_cake', 'foodstuff', 'pop', 'eat_food']
senticnet['bake_bread'] = [0.032, -0.068, 0, 0, '#joyful', '#surprising', 0.033, 'prepare_food', 'food', 'make_flour', 'bake', 'bread']
senticnet['bake_cake'] = [0.791, -0.838, 0, 0, '#joyful', '#surprising', 0.543, 'make_bread', 'cook_dinner', 'cook_meal', 'cook_curry', 'follow_recipe']
senticnet['bake_cookie'] = [0.825, -0.76, 0, 0, '#joyful', '#surprising', 0.528, 'make_flour', 'bake_bread', 'bake_food', 'bake', 'pot_roast']
senticnet['bake_food'] = [0.036, -0.06, 0.037, 0.05, '#surprising', '#admirable', 0.036, 'bake', 'make_grain', 'make_flour', 'pot_roast', 'eaten']
senticnet['bake_good'] = [0.077, -0.017, 0.024, 0.095, '#joyful', '#admirable', 0.055, 'bake_product', 'bakery_item', 'bake_treat', 'round_pastry', 'sweet_food']
senticnet['bake_goods'] = [0.069, -0.039, 0.025, 0.089, '#joyful', '#admirable', 0.057, 'bakery_item', 'bake_good', 'round_pastry', 'bake_treat', 'bake_product']
senticnet['bake_oven'] = [0.061, -0.049, 0, 0, '#joyful', '#surprising', 0.037, 'heat_element', 'stick_butter', 'find_recipe', 'grill', 'food_bake']
senticnet['bake_pan'] = [0.044, 0.08, 0, -0.03, '#joyful', '#interesting', 0.031, 'cook', 'festival', 'dinner', 'restaurant', 'food']
senticnet['bake_product'] = [0.07, -0.014, 0.026, 0.108, '#joyful', '#admirable', 0.055, 'bake_good', 'sweet_food', 'eatable', 'bakery_item', 'morning_food']
senticnet['bake_treat'] = [0.076, -0.005, 0.019, 0.102, '#joyful', '#admirable', 0.055, 'bakery_item', 'bake_good', 'round_pastry', 'bake_goods', 'bake_product']
senticnet['baker'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'cook_meat', 'cook_hamburger', 'cook_food', 'brown_meat', 'eat_outdoors']
senticnet['bakery'] = [0, -0.023, 0, 0.07, '#surprising', '#admirable', 0.031, 'pastry', 'christmas_stock', 'breadbox', 'sundae', 'freezer']
senticnet['bakery_item'] = [0.07, -0.015, 0.03, 0.119, '#joyful', '#admirable', 0.058, 'bake_treat', 'bake_good', 'bake_goods', 'round_pastry', 'bake_product']
senticnet['balance'] = [0, 0.125, 0.074, 0.097, '#interesting', '#admirable', 0.049, 'weigh', 'measurement_device', 'proportion', 'measure_pound', 'weight_measurement']
senticnet['balance_check_account'] = [-0.064, 0.151, 0, 0.075, '#interesting', '#admirable', 0.054, 'need_money', 'much_money', 'earn_wage', 'need_make_money', 'take_out_loan']
senticnet['balance_checkbook'] = [0, 0.951, 0, 0.7, '#interesting', '#admirable', 0.55, 'complete_job', 'explain_idea', 'count_money', 'balance_check_account', 'borrow_money']
senticnet['balanced'] = [0.814, -0.658, 0, 0.782, '#joyful', '#admirable', 0.751, 'harmonious', 'stable', 'symmetrical', 'counterbalanced', 'proportionate']
senticnet['balcony'] = [0, 0.117, -0.077, 0.094, '#interesting', '#admirable', 0.045, 'stage_border', 'row_seat', 'stage_entrance', 'theater_seat', 'theater_box']
senticnet['balcony_rail'] = [0.26, 0, 0, 0.089, '#joyful', '#admirable', 0.116, 'mosh_pit', 'movie_theater_seat', 'row_seat', 'usher', 'sticky_floor']
senticnet['balcony_seat'] = [0, 0.117, -0.077, 0.094, '#interesting', '#admirable', 0.045, 'stage_entrance', 'sticky_floor', 'row_seat', 'theater_box', 'thespian']
senticnet['bald'] = [-0.051, -0.004, -0.074, -0.05, '#sad', '#scared', -0.057, 'vulnerable', 'many_children', 'nostalgic', 'newborn', 'baby_dog']
senticnet['bald_eagle'] = [0, 0.081, 0.03, 0.126, '#interesting', '#admirable', 0.059, 'bird', 'old', 'predator', 'featherless', 'prey']
senticnet['bald_head'] = [-0.291, -0.009, 0, -0.162, '#sad', '#disgusting', -0.148, 'ridiculous', 'fall_head', 'death_penalty', 'car_wreck', 'terminal_illness']
senticnet['balderdash'] = [0.732, -0.646, 0, 0.728, '#joyful', '#admirable', 0.702, 'nonsense', 'meaninglessness', 'bunk', 'nonsensicality', 'hokum']
senticnet['balding'] = [-0.587, 0, 0.66, -0.8, '#angry', '#disgusting', -0.682, 'bald', 'depilous', 'glabrescent', 'glabrous', 'hairless']
senticnet['baleful'] = [-0.634, 0, 0.674, -0.756, '#angry', '#disgusting', -0.688, 'baneful', 'evil', 'maleficent', 'malevolent', 'malign']
senticnet['balk'] = [-0.717, 0, 0.932, -0.505, '#sad', '#angry', -0.718, 'refuse', 'subvert', 'decline', 'disobey', 'baulk']
senticnet['balking'] = [-0.998, 0, 0.754, -0.503, '#sad', '#angry', -0.752, 'unmalleable', 'stubborn', 'refractory', 'uncontrollable', 'intractable']
senticnet['ball'] = [0.787, 0.899, 0, 0, '#joyful', '#interesting', 0.562, 'ball_bounce', 'bounce', 'football_bounce', 'soccer', 'basketball_bounce']
senticnet['ball_and_chain'] = [-0.291, -0.009, 0, -0.162, '#sad', '#disgusting', -0.148, 'bother', 'nuisance', 'trouble', 'problem', 'boring_person']
senticnet['ball_bounce'] = [0.787, 0.878, 0, 0, '#joyful', '#interesting', 0.555, 'ball', 'bounce', 'football', 'soccer', 'basketball']
senticnet['ball_boy'] = [0.575, -0.622, 0, 0.596, '#surprising', '#admirable', 0.598, 'altar_boy', 'cub', 'boy', 'bat_boy', 'lad']
senticnet['ball_game'] = [0.054, -0.073, 0.019, 0, '#joyful', '#surprising', 0.036, 'sport_game', 'sport_play', 'sport', 'fun_game', 'team_sport']
senticnet['ball_over'] = [-0.569, 0, 0.897, -0.651, '#angry', '#disgusting', -0.706, 'shock', 'floor', 'galvanize', 'blow_out_of_water', 'take_aback']
senticnet['ball_player'] = [0.98, 0, 0, 0.936, '#joyful', '#admirable', 0.639, 'team', 'sports', 'player', 'competition', 'teamwork']
senticnet['ball_point_pen'] = [0.022, -0.057, 0.079, -0.116, '#angry', '#disgusting', -0.039, 'stationery', 'ink', 'paper', 'refill', 'notes']
senticnet['ball_shape'] = [0, 0.827, 0, 0.753, '#interesting', '#admirable', 0.527, 'circle_shape', 'fill_with_sand', 'round_shape', 'seen_night_sky', 'round']
senticnet['ball_sport'] = [0, -0.083, 0.022, 0.067, '#surprising', '#admirable', 0.043, 'team_sport', 'rough_sport', 'popular_sport_america', 'rough_game', 'type_of_sport']
senticnet['ball_up'] = [-0.786, 0, 0.915, -0.99, '#angry', '#disgusting', -0.897, 'bodge', 'botch_up', 'flub', 'go_wrong', 'bollix']
senticnet['ballerina'] = [0.15, -0.005, 0, 0.08, '#joyful', '#admirable', 0.078, 'dance_move', 'prom', 'ballet', 'dance', 'salsa']
senticnet['ballet'] = [0.12, -0.061, 0, 0, '#joyful', '#surprising', 0.06, 'ballroom', 'perform_art', 'nightclub', 'ballerina', 'venue']
senticnet['ballon'] = [0.089, -0.18, 0.037, -0.061, '#joyful', '#surprising', 0.057, 'balloon', 'luna_park', 'fielder', 'kite', 'blimp']
senticnet['balloon'] = [0.069, -0.277, 0, -0.038, '#joyful', '#surprising', 0.103, 'yo-yo', 'ball', 'helium_balloon', 'toy_soldier', 'basketball']
senticnet['ballot'] = [-0.034, 0.242, -0.125, 0.226, '#interesting', '#admirable', 0.103, 'elect', 'vote', 'presidential', 'democratic_process', 'nominate']
senticnet['balloting'] = [0.611, -0.829, 0, 0.737, '#surprising', '#admirable', 0.726, 'choice', 'option', 'veto', 'multiple_voting', 'block_vote']
senticnet['ballpark'] = [0.025, 0.246, 0, 0.226, '#interesting', '#admirable', 0.166, 'game', 'disneyland', 'sport_event', 'hockey_game', 'hockey_rink']
senticnet['ballpoint_pen'] = [-0.06, 0.103, 0, 0.073, '#interesting', '#admirable', 0.039, 'memo_pad', 'intern', 'pocket_size_notebook', 'stamp_pad', 'graphite_pencil']
senticnet['ballroom'] = [0.068, -0.03, 0, 0, '#joyful', '#surprising', 0.033, 'ballet', 'nightclub', 'venue', 'disco', 'concert']
senticnet['ballroom_dance'] = [0.893, 0, 0, 0, '#joyful', '#joyful', 0.298, 'relate_music', 'done_person', 'like', 'dancer', 'old_dance']
senticnet['balm'] = [-0.644, 0, 0.941, -0.923, '#angry', '#disgusting', -0.836, 'unction', 'salve', 'ointment', 'unguent', 'carron_oil']
senticnet['bamboo_curtain'] = [-0.765, 0, 0.692, -0.845, '#sad', '#disgusting', -0.767, 'iron_curtain', 'ideological_barrier', 'color_bar', 'color_line', 'barrier']
senticnet['banal'] = [-0.811, 0, 0, -0.777, '#sad', '#disgusting', -0.529, 'dull', 'ordinary', 'unoriginal', 'murky', 'lack_originality']
senticnet['banality'] = [0.524, -0.641, 0, 0.675, '#surprising', '#admirable', 0.613, 'truth', 'platitude', 'cliche', 'truism', 'commonplace']
senticnet['banana'] = [0, 0.066, -0.058, 0.089, '#interesting', '#admirable', 0.032, 'pineapple', 'kale', 'raisin', 'pickle', 'tomato']
senticnet['banana_bread'] = [0.644, -0.946, 0, 0.729, '#surprising', '#admirable', 0.773, 'gem', 'quick_bread', 'date_bread', 'nut_bread', 'oatcake']
senticnet['band'] = [0.023, 0.303, -0.087, 0.261, '#interesting', '#admirable', 0.167, 'high_school_choral', 'drum_set', 'choral', 'string_quartet', 'school_choral']
senticnet['band_play'] = [0.937, 0, 0, 0, '#joyful', '#joyful', 0.312, 'music', 'classical', 'composer', 'songwriter', 'rock_band']
senticnet['band_room'] = [0, 0.844, 0, 0.825, '#interesting', '#admirable', 0.556, 'string_quartet', 'music_store', 'musical_instrument_store', 'music_shop', 'high_school_band']
senticnet['band_together'] = [0.098, 0.254, -0.166, 0.297, '#interesting', '#admirable', 0.161, 'make_right', 'again_and_again', 'similar', 'commence', 'proposition']
senticnet['bandage'] = [-0.063, -0.03, 0, -0.172, '#sad', '#disgusting', -0.068, 'seam', 'needle_thread', 'sew_term', 'stitch', 'medical_kit']
senticnet['banded_water_snake'] = [-0.514, 0, 0.625, -0.984, '#angry', '#disgusting', -0.708, 'common_water_snake', 'water_snake', 'water_moccasin', 'grass_snake', 'ring_snake']
senticnet['bandit'] = [0, 0, -0.066, -0.071, '#scared', '#disgusting', -0.046, 'elbow', 'arm', 'wrist', 'five_fingers', 'bendable']
senticnet['bandwagon_effect'] = [0.894, -0.517, 0, 0.813, '#joyful', '#admirable', 0.741, 'issue', 'effect', 'consequence', 'outcome', 'result']
senticnet['baneful'] = [-0.634, 0, 0.674, -0.756, '#angry', '#disgusting', -0.688, 'maleficent', 'evil', 'baleful', 'malevolent', 'malign']
senticnet['bang'] = [0.444, 0.367, -0.111, 0.188, '#joyful', '#interesting', 0.296, 'strike', 'soothe', 'quiet', 'squeak', 'annoy_sound']
senticnet['bang_gavel'] = [-0.915, 0, -0.748, 0, '#sad', '#scared', -0.554, 'serve_jury', 'verdict', 'register_vote', 'close_case', 'convict_criminal']
senticnet['bang_head'] = [-0.258, -0.092, -0.091, -0.277, '#sad', '#disgusting', -0.178, 'loss_ofawareness', 'serious_accident', 'broken_limb', 'concussion', 'brain_damage']
senticnet['bang_head_against_wall'] = [0, 0, -0.975, -0.922, '#scared', '#disgusting', -0.632, 'feel_guilty', 'anguish', 'feeling_guilt', 'end_relationship', 'feel_anger']
senticnet['bangle'] = [-0.869, 0, 0.831, -0.795, '#sad', '#angry', -0.832, 'jewelry', 'jewellery', 'anklet', 'ankle_bracelet', 'armilla']
senticnet['banish'] = [-0.812, 0, 0.775, 0, '#sad', '#angry', -0.529, 'move', 'displace', 'fire', 'chase_away', 'ostracise']
senticnet['bank'] = [0.031, 0.176, 0, 0, '#joyful', '#interesting', 0.069, 'government_agreement', 'bank_vault', 'wallet', 'safe', 'coffer']
senticnet['bank_account'] = [0, 0.192, 0, 0.052, '#interesting', '#admirable', 0.081, 'bank_vault', 'wallet', 'billfold', 'hold_change', 'bank']
senticnet['bank_loan'] = [0, 0.33, -0.063, 0.107, '#interesting', '#admirable', 0.125, 'bank_money', 'vault', 'account', 'checkbook', 'dividend']
senticnet['bank_machine'] = [0, 0.845, 0, 0.791, '#interesting', '#admirable', 0.545, 'bank_vault', 'wallet', 'bank', 'credit_card_wallet', 'billfold']
senticnet['bank_money'] = [0, 0.304, -0.075, 0.102, '#interesting', '#admirable', 0.11, 'bank_loan', 'store_money', 'check_account', 'savings_account', 'require_signature']
senticnet['bank_statement'] = [0.671, -0.574, 0, 0.879, '#joyful', '#admirable', 0.708, 'financial_statement', 'bill', 'account', 'invoice', 'accounting']
senticnet['bank_vault'] = [0.031, 0.171, 0, 0, '#joyful', '#interesting', 0.067, 'bank_account', 'bank', 'wallet', 'safe', 'government_agreement']
senticnet['banker'] = [0, 0.747, 0, 0.814, '#interesting', '#admirable', 0.52, 'money', 'treasurer', 'account', 'dividend', 'piggy_bank']
senticnet['banknote'] = [0.828, 0.779, 0, 0, '#joyful', '#interesting', 0.536, 'dollar_bill', 'franc', 'euro', 'dollar', 'cent']
senticnet['bankrupt'] = [-0.949, 0, 0.551, -0.984, '#sad', '#disgusting', -0.828, 'unfortunate', 'insolvent', 'underdog', 'nonstarter', 'dud']
senticnet['bankruptcy'] = [0, 0, 0.884, -0.897, '#angry', '#disgusting', -0.594, 'go_broke', 'receive_change', 'run_out_money', 'compare_price', 'incur_debt']
senticnet['banner'] = [0.041, 0.077, 0, 0, '#joyful', '#interesting', 0.039, 'post_notice', 'emblem', 'placard', 'car_path', 'asphalt']
senticnet['banquet'] = [0.128, -0.041, 0, 0, '#joyful', '#surprising', 0.056, 'buffet', 'rave', 'auction', 'limbo', 'loose_end']
senticnet['banter'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'witty_remark', 'cross_talking', 'swordplay', 'wordplay', 'jester']
senticnet['bar'] = [0.754, -0.994, 0, 0, '#joyful', '#surprising', 0.583, 'liquor_store', 'tavern', 'pub', 'internet_site', 'club']
senticnet['bar_service'] = [0.743, -0.814, 0, 0, '#joyful', '#surprising', 0.519, 'porter', 'beverage_service', 'luggage_trolley', 'concierge', 'minibar']
senticnet['bar_stool'] = [0.909, -0.982, 0, 0, '#joyful', '#surprising', 0.63, 'alcohol', 'bar', 'high_chair', 'beer_mug', 'minibar']
senticnet['barb'] = [0, 0, 0, 0.071, '#admirable', '#admirable', 0.024, 'two_horses', 'horse', 'mule', 'buddhist', 'ride_horse']
senticnet['barbarian'] = [-0.73, 0, 0.734, -0.786, '#angry', '#disgusting', -0.75, 'primitive', 'headhunter', 'cannibal', 'anthropophagus', 'anthropophagite']
senticnet['barbarity'] = [-0.99, 0, 0.947, -0.883, '#sad', '#angry', -0.94, 'atrociousness', 'barbarousness', 'heinousness', 'atrocity', 'inhumanity']
senticnet['barbarous'] = [-0.52, 0, 0.896, -0.763, '#angry', '#disgusting', -0.726, 'noncivilized', 'primitive', 'savage', 'wild', 'preliterate']
senticnet['barbarousness'] = [-0.99, 0, 0.947, -0.883, '#sad', '#angry', -0.94, 'atrociousness', 'inhumanity', 'heinousness', 'atrocity', 'barbarity']
senticnet['barbate'] = [-0.945, 0, 0.84, -0.917, '#sad', '#disgusting', -0.901, 'bearded', 'unshaved', 'bewhiskered', 'whiskered', 'whiskery']
senticnet['barbecue'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'grill', 'red_meat', 'cook_grill', 'cook', 'grilled_vegetables']
senticnet['barber_comb'] = [0, 0.979, 0, 0.749, '#interesting', '#admirable', 0.576, 'hair_roller', 'hairdresser_chair', 'hair_accessory', 'sculpt_gel', 'barrette']
senticnet['barber_shop'] = [0.976, 0, 0, 0.889, '#joyful', '#admirable', 0.622, 'barbershop', 'beauty_salon', 'hair_salon', 'salon', 'hairdressing_salon']
senticnet['barbershop'] = [-0.024, 0.122, 0, 0.137, '#interesting', '#admirable', 0.078, 'barber_shop', 'beauty_salon', 'hair_salon', 'salon', 'hairdressing_salon']
senticnet['barbershop_quartet'] = [0.552, -0.61, 0, 0.588, '#surprising', '#admirable', 0.583, 'quartette', 'string_quartet', 'string_quartette', 'musical_organization', 'musical_group']
senticnet['barbie_doll'] = [0.039, -0.082, 0, 0.098, '#surprising', '#admirable', 0.073, 'slinky', 'toy', 'yo-yo', 'action_figure', 'stuff_animal']
senticnet['bard'] = [0.836, -0.602, 0, 0.845, '#joyful', '#admirable', 0.761, 'poetess', 'poet', 'elegist', 'odist', 'poet_laureate']
senticnet['bare'] = [-0.752, 0, 0.869, -0.737, '#sad', '#angry', -0.786, 'spare', 'unembellished', 'unornamented', 'unadorned', 'plain']
senticnet['bare_bones'] = [0.645, -0.766, 0, 0.961, '#surprising', '#admirable', 0.791, 'content', 'quintessence', 'stuff', 'essence', 'hypostasis']
senticnet['barefaced'] = [-0.695, 0, 0.857, -0.921, '#angry', '#disgusting', -0.824, 'bald', 'raw', 'overt', 'visible', 'naked']
senticnet['barehanded'] = [-0.574, 0, 0.654, -0.986, '#angry', '#disgusting', -0.738, 'defenseless', 'defenceless', 'unarmed', 'clean', 'weaponless']
senticnet['bareness'] = [-0.934, 0, 0.508, -0.848, '#sad', '#disgusting', -0.763, 'nakedness', 'cloud', 'bleakness', 'desolation', 'glumness']
senticnet['barf'] = [-0.265, -0.077, -0.066, -0.283, '#sad', '#disgusting', -0.179, 'go_insane', 'punch_face', 'ice_cream_melt', 'bang_head', 'suffer_fool']
senticnet['bargain'] = [-0.032, 0.306, -0.074, 0.241, '#interesting', '#admirable', 0.147, 'sale', 'good_buy', 'cheap_price', 'good_price', 'business_deal']
senticnet['barge'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'push', 'ram', 'shove_around', 'bang', 'jostle']
senticnet['barge_in'] = [-0.928, 0, 0.722, -0.555, '#sad', '#angry', -0.735, 'block', 'disrupt', 'jam', 'interject', 'throw_in']
senticnet['bark'] = [-0.958, 0, 0.892, -0.777, '#sad', '#angry', -0.876, 'cork', 'cassia_bark', 'canella', 'canella_bark', 'white_cinnamon']
senticnet['barn'] = [0.034, 0, 0, 0.064, '#joyful', '#admirable', 0.033, 'barn_field', 'graze_field', 'field', 'stable', 'farmyard']
senticnet['barn_animal'] = [0.053, 0.094, 0, 0.136, '#interesting', '#admirable', 0.094, 'farm', 'domesticate', 'stand_field', 'sheep', 'cow']
senticnet['barn_field'] = [0.034, 0, 0, 0.064, '#joyful', '#admirable', 0.033, 'barn', 'graze_field', 'field', 'stable', 'farmyard']
senticnet['barnacle'] = [0, 0, -0.069, 0, '#scared', '#scared', -0.023, 'mussel', 'fish', 'urchin', 'scuba_diver', 'seal']
senticnet['barndoor'] = [-0.585, 0, 0.715, -0.597, '#angry', '#disgusting', -0.632, 'fly', 'overlap', 'flap', 'coattail', 'codpiece']
senticnet['barnyard_animal'] = [0.041, 0, 0, 0.058, '#joyful', '#admirable', 0.033, 'farm', 'domesticate', 'stand_field', 'sheep', 'cow']
senticnet['baron'] = [0.066, 0.163, -0.062, 0.163, '#interesting', '#admirable', 0.11, 'lord', 'royal_title', 'almighty', 'duchess', 'omniscient']
senticnet['barony'] = [0.975, -0.789, 0, 0.969, '#joyful', '#admirable', 0.911, 'demesne', 'estate', 'land', 'landed_estate', 'acre']
senticnet['barrack'] = [0.627, 0.61, -0.24, 0.234, '#joyful', '#interesting', 0.41, 'pacifically', 'peaceably', 'peace-loving', 'peaceable', 'peace_of_mind']
senticnet['barrage'] = [0, 0, -0.858, -0.913, '#scared', '#disgusting', -0.59, 'onslaught', 'battery', 'shelling', 'bombardment', 'outpouring']
senticnet['barren'] = [-0.98, 0, 0.441, -0.962, '#sad', '#disgusting', -0.794, 'desert_land', 'infertile', 'sand', 'barren_land', 'desert']
senticnet['barren_land'] = [-0.98, 0, 0.441, -0.962, '#sad', '#disgusting', -0.794, 'desert_land', 'infertile', 'sand', 'barren', 'desert']
senticnet['barrenness'] = [-0.738, 0, 0.634, -0.856, '#sad', '#disgusting', -0.743, 'cacogenesis', 'impotence', 'impotency', 'infertility', 'dysgenesis']
senticnet['barrette'] = [0, 0.729, 0, 0.808, '#interesting', '#admirable', 0.512, 'sculpt_gel', 'haircut_scissor', 'hair_dryer', 'bobby_pin', 'hair_gel']
senticnet['barrier'] = [-0.939, 0, -0.998, -0.928, '#sad', '#scared', -0.955, 'language_barrier', 'shut', 'shut_down', 'close_down', 'obstacle']
senticnet['barroom'] = [-0.814, 0, 0.553, -0.928, '#sad', '#disgusting', -0.765, 'bar', 'sawdust_saloon', 'saloon', 'ginmill', 'taproom']
senticnet['bart'] = [0.159, -0.071, 0.024, 0, '#joyful', '#surprising', 0.069, 'club', 'metal_stick', 'hangout', 'organize_group', 'staff']
senticnet['bartender'] = [0.792, 0, 0, 0.82, '#joyful', '#admirable', 0.537, 'drunkard', 'drunk_person', 'whisky', 'beer', 'alcoholic']
senticnet['barter'] = [-0.05, 0.215, -0.089, 0.293, '#interesting', '#admirable', 0.123, 'swap', 'give_take', 'exchange_goods', 'transaction', 'increase_money']
senticnet['base'] = [0, 0.089, 0, 0, '#interesting', '#interesting', 0.03, 'ground', 'basement', 'baseboard', 'foundation', 'basis']
senticnet['baseball'] = [0, 0, 0, -0.108, '#disgusting', '#disgusting', -0.036, 'team', 'baseball_team', 'type_of_sport', 'sport', 'team_up']
senticnet['baseball_bat'] = [0.092, -0.091, 0, 0, '#joyful', '#surprising', 0.061, 'sport', 'pitch', 'home_ground', 'match', 'collectible']
senticnet['baseball_diamond'] = [0.048, 0.077, 0, -0.031, '#joyful', '#interesting', 0.031, 'soccer_field', 'outhouse', 'memorial', 'baseball_field', 'city_park']
senticnet['baseball_field'] = [0.048, 0.077, 0, -0.031, '#joyful', '#interesting', 0.031, 'soccer_field', 'outhouse', 'memorial', 'baseball_diamond', 'city_park']
senticnet['baseball_team'] = [0, 0, 0, -0.108, '#disgusting', '#disgusting', -0.036, 'team', 'baseball', 'type_of_sport', 'sport', 'team_up']
senticnet['baseboard'] = [0, 0.089, 0, 0, '#interesting', '#interesting', 0.03, 'ground', 'basement', 'base', 'foundation', 'basis']
senticnet['baseless'] = [-0.974, 0, 0.59, -0.93, '#sad', '#disgusting', -0.831, 'idle', 'unsupported', 'groundless', 'unfounded', 'unwarranted']
senticnet['basement'] = [0, 0.089, 0, 0, '#interesting', '#interesting', 0.03, 'ground', 'base', 'baseboard', 'foundation', 'basis']
senticnet['bash'] = [0.12, -0.192, 0, -0.096, '#joyful', '#surprising', 0.072, 'social_gathering', 'meet_up', 'radical', 'gathering', 'get_together']
senticnet['bashfully'] = [0.892, 0.936, 0, 0, '#joyful', '#interesting', 0.609, 'timorousness', 'timidness', 'timidity', 'shyly', 'timidly']
senticnet['bashfulness'] = [-0.969, 0, 0, -0.84, '#sad', '#disgusting', -0.603, 'abashment', 'self-consciousness', 'uncomfortableness', 'self-conscious', 'mortification']
senticnet['basic'] = [0, 0.148, 0, 0.148, '#interesting', '#admirable', 0.099, 'status', 'basic_need', 'mandatory', 'fundamental', 'classification']
senticnet['basic_food'] = [0.847, 0, 0, 0.817, '#joyful', '#admirable', 0.555, 'starchy_food', 'staple_food', 'whole_grain', 'crust', 'yeast']
senticnet['basic_human_need'] = [0.127, 0.069, 0.029, 0.16, '#joyful', '#admirable', 0.109, 'bourgeois', 'construct', 'set_down', 'make', 'build_process']
senticnet['basic_need'] = [0, 0.148, 0, 0.148, '#interesting', '#admirable', 0.099, 'status', 'basic', 'mandatory', 'eat', 'classification']
senticnet['basic_unit'] = [0, 0.804, 0, 0.95, '#interesting', '#admirable', 0.585, 'microscopic', 'small_unit', 'small_object', 'tiny_organism', 'unit']
senticnet['basifixed'] = [0.993, -0.893, 0, 0.891, '#joyful', '#surprising', 0.926, 'mounted', 'appendant', 'affixed', 'glued', 'pasted']
senticnet['basinet'] = [-0.595, 0, 0.887, -0.715, '#angry', '#disgusting', -0.732, 'armet', 'helmet', 'casque', 'heaume', 'morion']
senticnet['basis'] = [0, 0.089, 0, 0, '#interesting', '#interesting', 0.03, 'ground', 'basement', 'baseboard', 'foundation', 'base']
senticnet['basket_hilt'] = [-0.903, 0, 0.874, 0, '#sad', '#angry', -0.592, 'hold', 'grip', 'hilt', 'handle', 'handgrip']
senticnet['basket_laundry'] = [0.041, 0.086, 0.016, 0, '#joyful', '#interesting', 0.037, 'sort_clothes', 'laundry', 'clean_clothes', 'dirty_clothes', 'washing_machine']
senticnet['basket_oak'] = [-0.818, 0, 0.747, 0, '#sad', '#angry', -0.522, 'swamp_chestnut_oak', 'chinquapin_oak', 'chinkapin_oak', 'yellow_chestnut_oak', 'chestnut_oak']
senticnet['basketball'] = [0.967, -0.995, 0, 0, '#joyful', '#surprising', 0.654, 'yo-yo', 'ball', 'tennis_ball', 'sport_ball', 'ping_pong_paddle']
senticnet['basketball_court'] = [0.041, 0.086, 0.016, 0, '#joyful', '#interesting', 0.037, 'team', 'play_sport', 'game', 'exercise', 'match']
senticnet['basketball_game'] = [0.041, 0.086, 0.016, 0, '#joyful', '#interesting', 0.037, 'teamwork', 'team', 'game', 'defender', 'score']
senticnet['basketball_hoop'] = [-0.029, 0.075, 0, 0.059, '#interesting', '#admirable', 0.035, 'gather_team', 'form_team', 'buy_ball', 'suit_up', 'hoop']
senticnet['basketball_team'] = [0.035, 0.155, 0, 0, '#joyful', '#interesting', 0.063, 'basketball_court', 'basketball_game', 'basketball', 'ball', 'sport']
senticnet['bass'] = [0.049, 0.167, -0.053, 0.295, '#interesting', '#admirable', 0.153, 'four_sides', 'sound_system', 'dolby_surround', 'movie', 'surround']
senticnet['bastard'] = [-0.357, -0.135, -0.056, -0.384, '#sad', '#disgusting', -0.221, 'dick', 'idiot', 'asshole', 'fuck', 'motherfucker']
senticnet['bastille'] = [0.977, -0.556, 0, 0.679, '#joyful', '#admirable', 0.737, 'lockup', 'holding_cell', 'workhouse', 'gaol', 'hoosegow']
senticnet['bat_boy'] = [0.575, -0.622, 0, 0.596, '#surprising', '#admirable', 0.598, 'altar_boy', 'cub', 'ball_boy', 'boy', 'lad']
senticnet['bath'] = [0.042, -0.056, 0, 0, '#joyful', '#surprising', 0.033, 'toilet', 'bathroom_drawerroom', 'beauty_parlor', 'hotel_bathroom_drawerroom', 'bathroom_drawer']
senticnet['bath_robe'] = [0.758, 0, 0, 0.903, '#joyful', '#admirable', 0.554, 'washroom', 'bathroom', 'toilet', 'hotel_bathroom', 'bathroom_drawer']
senticnet['bath_shower'] = [0.041, 0.086, 0.016, 0, '#joyful', '#interesting', 0.037, 'separate_shower', 'shower_head', 'shampoo_conditioner', 'plunger', 'tub']
senticnet['bath_toy'] = [0, -0.106, 0, 0, '#surprising', '#surprising', 0.035, 'toy', 'rubber_duck', 'toy_soldier', 'action_figure', 'old_game']
senticnet['bathe'] = [-0.604, 0, 0.992, -0.948, '#angry', '#disgusting', -0.848, 'wash', 'lather', 'floss', 'decontaminate', 'cleanse']
senticnet['bathing'] = [0.785, 0, 0, 0.841, '#joyful', '#admirable', 0.542, 'clean_oneself', 'wash_up', 'wash_oneself', 'wash_body', 'clean_self']
senticnet['bathroom'] = [0, -0.106, 0, 0, '#surprising', '#surprising', 0.035, 'washroom', 'bath_robe', 'toilet', 'hotel_bathroom', 'bathroom_drawer']
senticnet['bathroom_cabinet'] = [0, 0.785, 0, 0.786, '#interesting', '#admirable', 0.524, 'hotel_bathroom', 'medicine_cabinet', 'first-aid_kit', 'towel', 'toothbrush']
senticnet['bathroom_drawer'] = [0.042, -0.056, 0, 0, '#joyful', '#surprising', 0.033, 'toilet', 'bathroom', 'beauty_parlor', 'hotel_bathroom', 'bath']
senticnet['bathroom_floor'] = [-0.043, 0.066, 0, 0.149, '#interesting', '#admirable', 0.057, 'first_aid_kit', 'floor', 'restroom', 'floorboard', 'fish_tackle']
senticnet['bathroom_wall'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'tiles', 'hair', 'design', 'water_resistance', 'algae']
senticnet['batman'] = [0.036, 0.127, 0.019, 0.225, '#interesting', '#admirable', 0.123, 'bird', 'sing_bird', 'hatch', 'vulture', 'only_bird']
senticnet['baton'] = [-0.914, 0, 0.931, -0.724, '#sad', '#angry', -0.856, 'hit_with_baton', 'get_hurt', 'whip', 'arrow', 'hurt']
senticnet['batrachomyomachia'] = [-0.818, 0, 0.52, -0.875, '#sad', '#disgusting', -0.738, 'affray', 'wrangle', 'dustup', 'quarrel', 'row']
senticnet['batter'] = [0.092, -0.091, 0, 0, '#joyful', '#surprising', 0.061, 'birthday_present', 'babe_ruth', 'baseball_bat', 'treat', 'collectible']
senticnet['battered'] = [-0.753, 0, 0.68, -0.599, '#sad', '#angry', -0.677, 'damaged', 'bedraggled', 'hurt', 'derelict', 'dilapidated']
senticnet['battery'] = [0.045, 0, 0, 0.051, '#joyful', '#admirable', 0.032, 'science', 'alkaline', 'chemistry', 'ph_level', 'chemical']
senticnet['battle'] = [-0.053, 0, -0.084, -0.196, '#scared', '#disgusting', -0.111, 'siege', 'big_fight', 'war', 'declare_war', 'combat']
senticnet['battle_cancer'] = [-0.781, 0, -0.933, 0, '#sad', '#scared', -0.571, 'lower_standard', 'kill_oneself', 'hang_picture_on_wall', 'gather_berry', 'wave_flag']
senticnet['battle_disease'] = [-0.988, 0, -0.886, 0, '#sad', '#scared', -0.625, 'fear_death', 'condition', 'infection', 'battle_cancer', 'health']
senticnet['battle_dress'] = [-0.798, 0, 0.599, -0.938, '#sad', '#disgusting', -0.778, 'uniform', 'military_uniform', 'dress_uniform', 'fatigues', 'khakis']
senticnet['battle_fatigue'] = [-0.754, 0, 0.87, -0.514, '#sad', '#angry', -0.713, 'posttraumatic_stress_disorder', 'combat_fatigue', 'combat_neurosis', 'shell_shock', 'anxiety_disorder']
senticnet['battle_illness'] = [-0.133, 0, -0.067, 0, '#sad', '#scared', -0.067, 'throw_fit', 'watch_d', 'sun_oneself', 'laugh_clown', 'honor_parent']
senticnet['battlefield'] = [-0.027, 0.067, -0.117, -0.198, '#scared', '#disgusting', -0.092, 'war_museum', 'underworld', 'police_station', 'prisoner_war_camp', 'war_zone']
senticnet['battler'] = [0.833, -0.974, 0, 0.91, '#surprising', '#admirable', 0.906, 'combatant', 'fencer', 'belligerent', 'fighter', 'scrapper']
senticnet['battleship'] = [0, 0, 0, -0.072, '#disgusting', '#disgusting', -0.024, 'submarine', 'lifeboat', 'titanic', 'large_ship', 'canoe']
senticnet['baulk'] = [-0.717, 0, 0.932, -0.505, '#sad', '#angry', -0.718, 'refuse', 'subvert', 'decline', 'balk', 'disobey']
senticnet['bawd'] = [-0.917, 0, 0.974, -0.612, '#sad', '#angry', -0.834, 'slattern', 'camp_follower', 'call_girl', 'comfort_woman', 'ianfu']
senticnet['bawl'] = [-0.221, 0, -0.2, 0, '#sad', '#scared', -0.14, 'weep', 'sob', 'shed_tear', 'wail', 'eye_tear']
senticnet['bawl_out'] = [-0.99, 0, 0.545, -0.555, '#sad', '#disgusting', -0.697, 'castigate', 'tell_off', 'brush_down', 'chasten', 'objurgate']
senticnet['bawling_out'] = [-0.641, 0, 0.859, -0.601, '#sad', '#angry', -0.7, 'reprimand', 'rebuke', 'reproof', 'reproval', 'reprehension']
senticnet['bay'] = [0.939, -0.877, 0, 0, '#joyful', '#surprising', 0.605, 'estuary', 'harpoon', 'gulf', 'lake', 'river']
senticnet['bay_window'] = [0.046, -0.03, 0, 0, '#joyful', '#surprising', 0.025, 'breeze', 'sea_view', 'natural_air', 'seashore', 'sand']
senticnet['bayonet'] = [0, 0, -0.717, -0.785, '#scared', '#disgusting', -0.501, 'shotgun', 'knife', 'stab', 'hydrogen_bomb', 'dangerous_weapon']
senticnet['bazaar'] = [0, 0.113, 0.041, 0.058, '#interesting', '#admirable', 0.043, 'corner_shop', 'general_store', 'many_shops', 'large_supermarket', 'goods']
senticnet['beach'] = [0.03, 0.117, 0, 0.084, '#interesting', '#admirable', 0.077, 'ocean_beach', 'waterfront', 'ocean', 'coast', 'sea']
senticnet['beach_bag'] = [0, 0.092, 0.016, 0.074, '#interesting', '#admirable', 0.05, 'walmart', 'drugstore', 'own_bathroom', 'pharmacy', 'car_trunk']
senticnet['beach_ball'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'volleyball', 'game', 'sun', 'sand', 'fun']
senticnet['beach_flea'] = [0.845, 0, 0, 0.999, '#joyful', '#admirable', 0.615, 'whale_louse', 'amphipod', 'sand_hopper', 'sandhopper', 'sand_flea']
senticnet['beach_house'] = [0.844, 0, 0, 0, '#joyful', '#joyful', 0.281, 'front_build', 'television_station', 'football_stadium', 'football_game', 'back_door']
senticnet['beach_towel'] = [0, 0.092, 0.016, 0.074, '#interesting', '#admirable', 0.05, 'armoire', 'pillowcase', 'bed_sheet', 'duvet_cover', 'comforter']
senticnet['beach_waggon'] = [0, 0.929, 0, 0.935, '#interesting', '#admirable', 0.621, 'beach_wagon', 'station_wagon', 'wagon', 'estate_car', 'shooting_brake']
senticnet['beach_wagon'] = [0, 0.815, 0, 0.932, '#interesting', '#admirable', 0.582, 'shooting_brake', 'station_wagon', 'wagon', 'estate_car', 'beach_waggon']
senticnet['beachcomber'] = [-0.943, 0, 0.839, -0.539, '#sad', '#angry', -0.774, 'hobo', 'tramp', 'drifter', 'bum', 'sundowner']
senticnet['bead'] = [0, 0.171, -0.056, 0.102, '#interesting', '#admirable', 0.072, 'bed', 'mattress', 'linen_cupboard', 'bed_cover', 'seduce']
senticnet['beak'] = [0, 0.105, 0, 0, '#interesting', '#interesting', 0.035, 'big_eye', 'many_feathers', 'predator', 'bird', 'eagle']
senticnet['beaker'] = [0.026, 0.067, 0, 0, '#joyful', '#interesting', 0.031, 'vial', 'glass_container', 'bottle', 'drink_holder', 'flask']
senticnet['beam'] = [0.926, 0.988, 0, 0, '#joyful', '#interesting', 0.638, 'cork', 'rod', 'nest_table', 'wand', 'i-beam']
senticnet['beam_of_light'] = [0.575, -0.622, 0, 0.596, '#surprising', '#admirable', 0.598, 'beam', 'sunbeam', 'light_beam', 'ray', 'ray_of_light']
senticnet['beaming'] = [0.635, 0.639, -0.243, 0.291, '#joyful', '#interesting', 0.441, 'gladsomeness', 'gladfulness', 'gladness', 'gladsome', 'gladden']
senticnet['bean'] = [-0.705, 0, 0.606, -0.723, '#sad', '#disgusting', -0.678, 'common_bean', 'soya', 'goa_bean', 'mung_bean', 'mung']
senticnet['beanbag'] = [0, -0.068, 0, 0, '#surprising', '#surprising', 0.023, 'collectible', 'teddy_bear', 'paper_airplane', 'barbie_doll', 'beanie_baby']
senticnet['beanbag_chair'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'soft', 'small_seat', 'relax', 'beans', 'chair']
senticnet['beanie_baby'] = [0.983, -0.966, 0, 0, '#joyful', '#surprising', 0.65, 'action_figure', 'toy_car', 'toy_ball', 'toy_soldier', 'yo-yo']
senticnet['beans'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'soft', 'small_seat', 'relax', 'beanbag_chair', 'chair']
senticnet['bear'] = [0.835, -0.948, 0, 0.537, '#joyful', '#surprising', 0.773, 'fluster', 'hold', 'assert', 'deport', 'move']
senticnet['bear_claw'] = [0, 0.774, 0, 0.812, '#interesting', '#admirable', 0.529, 'cross_bun', 'hot_cross_bun', 'bear_paw', 'coffee_roll', 'bun']
senticnet['bear_in_mind'] = [0.541, -0.868, 0, 0.85, '#surprising', '#admirable', 0.753, 'qualify', 'think_of', 'mind', 'keep_note', 'characterize']
senticnet['bear_on'] = [0.874, -0.616, 0, 0.845, '#joyful', '#admirable', 0.778, 'matter_to', 'interest', 'hold', 'go_for', 'regard']
senticnet['bear_out'] = [0.853, -0.972, 0, 0.855, '#surprising', '#admirable', 0.893, 'check', 'match', 'correspond', 'jibe', 'tally']
senticnet['bear_paw'] = [0, 0.788, 0, 0.788, '#interesting', '#admirable', 0.525, 'cross_bun', 'hot_cross_bun', 'coffee_roll', 'bear_claw', 'bun']
senticnet['bear_up'] = [-0.993, 0, 0.871, -0.559, '#sad', '#angry', -0.808, 'endure', 'brook', 'tolerate', 'stomach', 'abide']
senticnet['bear_upon'] = [0.976, -0.807, 0, 0.557, '#joyful', '#surprising', 0.78, 'color', 'treat', 'strike_blow', 'expose', 'influence']
senticnet['bearable'] = [0.525, -0.799, 0, 0.593, '#surprising', '#admirable', 0.639, 'tolerant', 'resistant', 'tolerable', 'endurable', 'sufferable']
senticnet['beard'] = [-0.103, 0, -0.053, -0.112, '#sad', '#disgusting', -0.089, 'jaw', 'cheek', 'dimple', 'forehead', 'pimple']
senticnet['beard_cut'] = [0.575, -0.622, 0, 0.596, '#surprising', '#admirable', 0.598, 'go_barber', 'visit_barber', 'go_barber_shop', 'go_hair_salon', 'haircut']
senticnet['bearded'] = [-0.945, 0, 0.84, -0.917, '#sad', '#disgusting', -0.901, 'unshaved', 'barbate', 'bewhiskered', 'whiskered', 'whiskery']
senticnet['bearer'] = [-0.989, 0, 0.664, -0.524, '#sad', '#angry', -0.726, 'unfortunate', 'unfortunate_person', 'weeper', 'pallgriever', 'griever']
senticnet['bearskin'] = [-0.588, 0, 0.632, -0.638, '#angry', '#disgusting', -0.619, 'skimmer', 'trilby', 'chapeau', 'busby', 'shako']
senticnet['beast'] = [0.03, 0.068, -0.044, 0.093, '#interesting', '#admirable', 0.049, 'critter', 'equine', 'live_creature', 'furry_creature', 'domesticate_animal']
senticnet['beat'] = [0.062, -0.604, 0, 0.289, '#surprising', '#admirable', 0.318, 'perplex', 'amaze', 'marvel', 'pose', 'grand']
senticnet['beat_box'] = [0.853, -0.821, 0, 0, '#joyful', '#surprising', 0.558, 'sound_control_room', 'microphone_boom', 'mouth', 'speaker', 'beats']
senticnet['beat_egg'] = [0.938, -0.796, 0, 0, '#joyful', '#surprising', 0.578, 'scrumble_egg', 'heat_meal', 'pan', 'breakfast', 'food']
senticnet['beat_enemy'] = [0, 0.827, 0, 0.84, '#interesting', '#admirable', 0.556, 'win_war', 'win_battle', 'kill_enemy', 'become_strong', 'become_best']
senticnet['beat_generation'] = [0.52, -0.911, 0, 0.65, '#surprising', '#admirable', 0.694, 'flower_people', 'hippies', 'hipsters', 'youth_subculture', 'beats']
senticnet['beat_off'] = [0, 0.724, 0, 0.929, '#interesting', '#admirable', 0.551, 'beat', 'defeat', 'punch', 'fight', 'masturbation']
senticnet['beat_opponent'] = [0.816, 0.756, 0, 0.747, '#joyful', '#interesting', 0.773, 'teamwork', 'fight', 'win_hand', 'defeat', 'winner']
senticnet['beat_out'] = [0.595, -0.5, 0, 0.712, '#joyful', '#admirable', 0.602, 'master', 'walk_over', 'checkmate', 'outfight', 'screw']
senticnet['beat_person'] = [-0.917, 0, 0.513, -0.932, '#sad', '#disgusting', -0.787, 'cause_someone_embarrassment', 'cause_bleeding', 'cut_finger', 'kill_person', 'cause_strong_pain']
senticnet['beat_to_bleeding'] = [-0.973, 0, 0.676, -0.963, '#sad', '#disgusting', -0.871, 'commit_crime', 'criminal', 'kill_person', 'deceive', 'torture']
senticnet['beat_up'] = [-0.948, 0, 0, -0.992, '#sad', '#disgusting', -0.647, 'lose_battle', 'confrontation', 'fight', 'victory_defeat', 'military_action']
senticnet['beat_violently'] = [-0.973, 0, 0.676, -0.963, '#sad', '#disgusting', -0.871, 'violent', 'beat', 'thrash', 'merciless', 'thief']
senticnet['beatable'] = [0.702, -0.944, 0, 0.582, '#joyful', '#surprising', 0.743, 'conquerable', 'vanquishable', 'vincible', 'subduable', 'subjugable']
senticnet['beaten'] = [0, 0, -0.758, 0, '#scared', '#scared', -0.253, 'lose_war', 'loss', 'lose_battle', 'military_action', 'defeat']
senticnet['beatify'] = [0.645, 0.637, -0.239, 0.299, '#joyful', '#interesting', 0.447, 'gladdened', 'stimulating', 'tickle_pink', 'inebriate', 'exalt']
senticnet['beatles_song'] = [0.029, 0.189, -0.099, 0.306, '#interesting', '#admirable', 0.142, 'woolly_animal', 'goofy', 'big_person', 'descriptive_term', 'song']
senticnet['beats'] = [0.746, -1.0, 0, 0, '#joyful', '#surprising', 0.582, 'sound_control_room', 'microphone_boom', 'mouth', 'speaker', 'beat_box']
senticnet['beau'] = [0.706, 0, 0, 0.756, '#joyful', '#admirable', 0.487, 'dandy', 'male_admirer', 'boyfriend', 'rich', 'young_man']
senticnet['beaut'] = [0.986, -0.609, 0, 0.568, '#joyful', '#surprising', 0.721, 'exemplar', 'ideal', 'exemplary', 'pattern', 'pacesetter']
senticnet['beautician'] = [0.633, -0.502, 0, 0.59, '#joyful', '#admirable', 0.575, 'craftsman', 'manicurist', 'artisan', 'journeyman', 'artificer']
senticnet['beautification'] = [0.944, -0.603, 0, 0.756, '#joyful', '#admirable', 0.768, 'makeover', 'beauty_treatment', 'manicure', 'pedicure', 'facial']
senticnet['beautiful'] = [0.091, 0.121, 0, 0.229, '#interesting', '#admirable', 0.147, 'pretty', 'delicate', 'elegant', 'big', 'fair']
senticnet['beautiful_car'] = [0.992, 0.728, 0, 0.834, '#joyful', '#admirable', 0.851, 'famous_brand', 'car', 'high_class', 'expensive_car', 'limousine']
senticnet['beautiful_creature'] = [0.816, 0.756, 0, 0.747, '#joyful', '#interesting', 0.773, 'attractive', 'become_extinct', 'exotic', 'nocturnal', 'unique_animal']
senticnet['beautiful_dangerous'] = [-0.09, 0, -0.147, 0, '#sad', '#scared', -0.079, 'destructive', 'violent', 'dangerous_health', 'illegal', 'dangerous']
senticnet['beautiful_day'] = [0.984, 0.789, 0, 0, '#joyful', '#interesting', 0.591, 'attract_opposite_sex', 'have_fun', 'popularity', 'feel_pleasure', 'humor']
senticnet['beautiful_girl'] = [0.902, 0.995, 0, 0, '#joyful', '#interesting', 0.632, 'hot_babe', 'hen_baby', 'slang_woman', 'hen_child', 'bird']
senticnet['beautiful_look'] = [0.062, 0.076, 0.054, 0.171, '#interesting', '#admirable', 0.085, 'pretty', 'tall', 'large', 'really_big', 'high_land']
senticnet['beautiful_music'] = [0.994, 0.924, 0, 0.926, '#joyful', '#admirable', 0.948, 'stressful_situation', 'chamber_music', 'store_photo', 'music', 'part_of_band']
senticnet['beautiful_place'] = [0.089, 0, 0, 0.13, '#joyful', '#admirable', 0.073, 'metropolis', 'county', 'good_view', 'complex_structure', 'populate_area']
senticnet['beautiful_scenery'] = [0.877, 0.832, 0, 0.791, '#joyful', '#interesting', 0.833, 'enjoy_scenery', 'beautiful_view', 'enjoy_nature', 'relax', 'tourist_attraction']
senticnet['beautiful_smile'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'teeth_whitening', 'smile', 'clean_teeth', 'white_tooth', 'dentist']
senticnet['beautiful_sunset'] = [0.865, 0, 0, 0.984, '#joyful', '#admirable', 0.616, 'place_somewhere', 'gas_stove', 'attain_goal', 'sate', 'taken_seriously']
senticnet['beautiful_view'] = [0.877, 0.832, 0, 0.791, '#joyful', '#interesting', 0.833, 'enjoy_scenery', 'beautiful_scenery', 'enjoy_nature', 'relax', 'tourist_attraction']
senticnet['beautiful_well_useful'] = [-0.046, 0.12, -0.078, 0.199, '#interesting', '#admirable', 0.065, 'brown', 'driven_person', 'graceful', 'majestic', 'opaque']
senticnet['beautiful_woman'] = [0, 0.098, 0, 0.107, '#interesting', '#admirable', 0.068, 'interjection', 'pretty_girl', 'policy', 'traffic_cop', 'adjust_seat']
senticnet['beautify'] = [0.903, -0.615, 0, 0.736, '#joyful', '#admirable', 0.751, 'suit', 'better', 'improve', 'make_look_better', 'meliorate']
senticnet['beauty'] = [0.868, 0.99, 0, 0, '#joyful', '#interesting', 0.619, 'pretty', 'nice_look', 'gorgeous', 'please_eye', 'good_look']
senticnet['beauty_parlor'] = [0.816, 0.756, 0, 0.747, '#joyful', '#interesting', 0.773, 'beauty_shop', 'lady_hair', 'barber_shop', 'hair_salon', 'beauty_salon']
senticnet['beauty_salon'] = [-0.024, 0.122, 0, 0.137, '#interesting', '#admirable', 0.078, 'barber_shop', 'salon', 'barbershop', 'hair_salon', 'beauty_shop']
senticnet['beauty_section'] = [0.541, -0.868, 0, 0.85, '#surprising', '#admirable', 0.753, 'book', 'gossip', 'book_magazine', 'fashion', 'visual_communication']
senticnet['beauty_shop'] = [-0.024, 0.122, 0, 0.137, '#interesting', '#admirable', 0.078, 'beauty_parlor', 'lady_hair', 'body_lotion', 'beauty_salon', 'make_up']
senticnet['beauty_treatment'] = [0.944, -0.603, 0, 0.756, '#joyful', '#admirable', 0.768, 'makeover', 'beautification', 'manicure', 'pedicure', 'facial']
senticnet['beauty_world'] = [0.962, -0.811, 0, 0, '#joyful', '#surprising', 0.591, 'know_result', 'carpal_tunnel_syndrome', 'become_excited', 'informative', 'want_join']
senticnet['beaver'] = [0, 0.95, 0, 0.765, '#interesting', '#admirable', 0.572, 'monkey', 'marmoset', 'lemur', 'fiance', 'koala']
senticnet['beaver_board'] = [0.514, -0.979, 0, 0.899, '#surprising', '#admirable', 0.797, 'board', 'dry_wall', 'fiberboard', 'furniture', 'particle_board']
senticnet['becharm'] = [0.521, -0.552, 0, 0.657, '#surprising', '#admirable', 0.577, 'bewitch', 'enchant', 'jinx', 'hex', 'witch']
senticnet['beckon'] = [0, 0.098, -0.049, 0.25, '#interesting', '#admirable', 0.1, 'verbal', 'say', 'orate', 'verbalize', 'communicate']
senticnet['become_actor'] = [0.932, 0.85, 0, 0, '#joyful', '#interesting', 0.594, 'good_imagination', 'rehearse', 'role_play', 'star_movie', 'acting']
senticnet['become_addicted'] = [0.596, 0.233, -0.14, 0.106, '#joyful', '#interesting', 0.265, 'joy', 'happiness', 'happy', 'satisfaction', 'good_feeling']
senticnet['become_adult'] = [-0.141, 0, -0.083, -0.06, '#sad', '#scared', -0.095, 'wear_silly_hat', 'trade_baseball_card', 'follow_mother', 'roll_ball', 'promise_good']
senticnet['become_angry'] = [-0.192, -0.093, 0, -0.369, '#sad', '#disgusting', -0.156, 'feel_hurt', 'hurt_feeling', 'feel_sad', 'lose_mind', 'feel_stupid']
senticnet['become_aroused'] = [0.888, 0.803, 0, 0, '#joyful', '#interesting', 0.564, 'evoke_feeling', 'wake_up', 'excite_someone_sexually', 'love_back', 'love_oneself']
senticnet['become_artist'] = [0.963, 0, 0, 0.929, '#joyful', '#admirable', 0.631, 'star_movie', 'famous', 'movie', 'tv_show', 'actor']
senticnet['become_aware'] = [0, 0.933, 0, 0.953, '#interesting', '#admirable', 0.629, 'figure_out', 'gather_fact', 'cognition', 'arrive_conclusion', 'revelation']
senticnet['become_beautiful'] = [0.793, 0.811, 0, 0.908, '#interesting', '#admirable', 0.837, 'make_new_friend', 'embellish', 'make_beautiful', 'make_new', 'adorn']
senticnet['become_best'] = [0, 0.827, 0, 0.84, '#interesting', '#admirable', 0.556, 'win_war', 'win_battle', 'beat_enemy', 'become_strong', 'kill_enemy']
senticnet['become_better'] = [0.879, 0.91, 0, 0, '#joyful', '#interesting', 0.596, 'build_strength', 'feel_better_oneself', 'strengthen_muscle', 'improvement', 'increase_energy']
senticnet['become_better_person'] = [0.791, 0.892, 0, 0.966, '#interesting', '#admirable', 0.883, 'help_others', 'keep_work', 'increase_intelligence', 'sense_satisfaction', 'develop_talent']
senticnet['become_bigger'] = [0.642, -0.585, 0, 0.751, '#joyful', '#admirable', 0.659, 'change', 'become_better', 'change_aspect', 'look_better', 'metamorphosis']
senticnet['become_blessed'] = [0.963, 0.606, 0, 0.955, '#joyful', '#admirable', 0.841, 'become_enlighten', 'become_informed', 'investigate_fact', 'make_happy', 'learn_new_fact']
senticnet['become_blind'] = [-0.994, -0.757, -0.901, 0, '#sad', '#scared', -0.379, 'lose_team', 'disrespect', 'cause_suffer', 'brain_tumor', 'lyme_disease']
senticnet['become_bored'] = [-0.959, 0, 0, -0.983, '#sad', '#disgusting', -0.647, 'lack_of_interest', 'boredom', 'extreme_boredom', 'get_bored', 'kill_brain_cell']
senticnet['become_clean'] = [0, 0.716, 0, 0.741, '#interesting', '#admirable', 0.486, 'clean_clothes', 'get_clean', 'take_shower', 'clean_body', 'wash_clothes']
senticnet['become_cleaner'] = [0, 0, 0, 0.07, '#admirable', '#admirable', 0.023, 'remove_dirt', 'shower', 'clean_skin', 'clothes_clean', 'feel_clean']
senticnet['become_cold'] = [-0.728, 0, 0, -0.777, '#sad', '#disgusting', -0.502, 'get_cold', 'wet_clothes', 'cold_bed', 'cold_food', 'cold_body']
senticnet['become_cultured'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'learn_culture', 'broaden_horizon', 'expand_knowledge', 'find_out_world', 'learn_other_culture']
senticnet['become_dad'] = [0.939, -0.894, 0, 0, '#joyful', '#surprising', 0.611, 'name_child', 'name', 'baby', 'child', 'name_baby']
senticnet['become_depressed'] = [-0.827, 0, -0.968, 0, '#sad', '#scared', -0.598, 'act_foolish', 'lower_standard', 'trade_stock', 'plan_retirement', 'smell_smoke']
senticnet['become_dirty'] = [-0.066, 0, 0, -0.052, '#sad', '#disgusting', -0.039, 'sweat', 'sports', 'fall_mud', 'exercise', 'dirty']
senticnet['become_distracted'] = [-0.702, 0, 0.811, 0, '#sad', '#angry', -0.504, 'unable_to_focus', 'preoccupied', 'inattentive', 'brain_storm', 'new_idea']
senticnet['become_doctor'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'graduate', 'doctor', 'important_person', 'become_judge', 'study']
senticnet['become_drunk'] = [0, 0, 0.715, -0.764, '#angry', '#disgusting', -0.493, 'act_stupid', 'drunkenness', 'get_wasted', 'hangover', 'intoxication']
senticnet['become_dull'] = [-0.078, 0, -0.048, 0, '#sad', '#scared', -0.042, 'lack_interest', 'lack_brightness', 'boring', 'tedious', 'dark']
senticnet['become_educated'] = [0.851, 0.514, 0, 0.53, '#joyful', '#admirable', 0.632, 'get_degree', 'learn_information', 'better_grade', 'learn', 'become_intelligent']
senticnet['become_engineer'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'prove_learn', 'get_qualification', 'want_pass_class', 'prove_knowledge', 'complete_course']
senticnet['become_enlighten'] = [0.884, -0.916, 0, 0.576, '#joyful', '#surprising', 0.792, 'learn_new_fact', 'better_understand', 'become_informed', 'learn_much', 'increase_knowledge']
senticnet['become_excited'] = [0.887, -0.847, 0, 0, '#joyful', '#surprising', 0.578, 'laughter', 'laugh', 'happiness', 'want_join', 'become_happy']
senticnet['become_exhausted'] = [-0.727, 0, 0, -0.78, '#sad', '#disgusting', -0.502, 'increased_heart_rate', 'very_tired', 'sore_muscle', 'breathlessness', 'pull_muscle']
senticnet['become_expert'] = [0.822, 0.894, 0, 0.855, '#interesting', '#admirable', 0.857, 'gain_insight', 'teach_others', 'trivia', 'understand', 'forget_else']
senticnet['become_extinct'] = [-0.095, 0, -0.07, 0, '#sad', '#scared', -0.055, 'biped', 'die', 'fly_animal', 'nocturnal', 'wing_animal']
senticnet['become_famous'] = [0.912, 0, 0, 0.974, '#joyful', '#admirable', 0.629, 'occupy_mind', 'ego_boost', 'get_excited', 'spread_idea', 'show_off']
senticnet['become_fat'] = [0, 0, 0.931, -0.749, '#angry', '#disgusting', -0.56, 'overweight', 'chubby', 'large', 'heavy', 'get_fat']
senticnet['become_fatigued'] = [-0.098, -0.041, 0.013, -0.118, '#sad', '#disgusting', -0.063, 'exhaustion', 'muscle_ache', 'breathlessness', 'become_tired', 'leg_cramp']
senticnet['become_fit'] = [0.071, 0, 0, 0, '#joyful', '#joyful', 0.024, 'build_muscle', 'improve_health', 'stay_shape', 'exercise', 'good_health']
senticnet['become_friend'] = [0, 0, 0, 0.848, '#admirable', '#admirable', 0.283, 'eye_contact', 'start_conversation', 'say_hello', 'talk_another_person', 'share_feeling']
senticnet['become_frustrated'] = [-0.809, 0, 0.703, 0, '#sad', '#angry', -0.504, 'think_past', 'introspection', 'keep_work', 'reflect', 'keep_word']
senticnet['become_full'] = [0.043, -0.003, -0.058, -0.132, '#scared', '#disgusting', -0.048, 'indigestion', 'hungry', 'get_full', 'heartburn', 'stomach_ache']
senticnet['become_gigantic'] = [0.057, 0, 0.012, 0.08, '#joyful', '#admirable', 0.042, 'see_better', 'glasses', 'magnify', 'magnifier', 'contact_lens']
senticnet['become_happy'] = [0.746, 0.809, 0, 0, '#joyful', '#interesting', 0.518, 'feel_happy', 'laugh', 'laughter', 'good_feeling', 'become_excited']
senticnet['become_healthy'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'increase_metabolism', 'big_muscle', 'feel_fit', 'diet', 'weight_loss']
senticnet['become_hungry'] = [0, 0, 0.883, -0.767, '#angry', '#disgusting', -0.55, 'hangry', 'a_little_hungry', 'become_little_hungry', 'angry', 'need_food']
senticnet['become_ill'] = [-0.928, -0.735, -0.939, 0, '#sad', '#scared', -0.377, 'constipation', 'catch_mumps', 'drink_much_alcohol', 'become_sick', 'forgetfulness']
senticnet['become_impatient'] = [0, 0, 0.882, 0, '#angry', '#angry', -0.294, 'get_front', 'get_sore_foot', 'learn_patience', 'think_dog', 'get_ticket']
senticnet['become_inebriated'] = [0.229, 0.127, 0, 0, '#joyful', '#interesting', 0.119, 'get_excited', 'eat_breakfast_in_bed', 'inebriate', 'eat_like_pig', 'eat_quickly']
senticnet['become_informed'] = [0.822, 0.894, 0, 0.855, '#interesting', '#admirable', 0.857, 'learn_current_event', 'enlightenment', 'eye_strain', 'gain_knowledge', 'become_enlighten']
senticnet['become_intelligent'] = [0.945, 0.996, 0, 0.737, '#joyful', '#interesting', 0.893, 'gain_knowledge', 'increase_knowledge', 'get_knowledge', 'become_smart', 'expand_mind']
senticnet['become_intoxicated'] = [-0.95, 0, -0.736, -0.736, '#sad', '#scared', -0.807, 'alcoholism', 'hold_beer', 'greet_guest', 'intoxication', 'social_occasion']
senticnet['become_judge'] = [0, 0.118, 0, 0, '#interesting', '#interesting', 0.039, 'determine_guilt_innocence', 'negotiator', 'juror', 'become_lawyer', 'decide_guilt']
senticnet['become_knowledgeable'] = [0.757, 0, 0, 0, '#joyful', '#joyful', 0.252, 'gain_knowledge', 'learn', 'expert', 'increase_knowledge', 'add_knowledge']
senticnet['become_known'] = [0, 0, 0, 0.861, '#admirable', '#admirable', 0.287, 'come_out', 'debut', 'become_famous', 'vip', 'admit']
senticnet['become_lawyer'] = [0, 0.959, 0, 0.839, '#interesting', '#admirable', 0.599, 'become_judge', 'consider_evidence', 'examine_evidence', 'determine_guilt_innocence', 'call_witness']
senticnet['become_liquid'] = [0.093, 0.204, -0.088, 0.254, '#interesting', '#admirable', 0.154, 'change_shape', 'blend', 'circumstance', 'ice_crystal', 'ice_rain']
senticnet['become_little_hungry'] = [0.964, 0, 0, 0, '#joyful', '#joyful', 0.321, 'weight_gain', 'impress_girlfriend', 'eat_pizza', 'eat', 'satisfy_crave']
senticnet['become_man'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'fancy_girl', 'date_girl', 'wedge_door', 'kiss_girl', 'make_compost']
senticnet['become_mom'] = [0.1, 0.216, -0.185, 0.22, '#interesting', '#admirable', 0.117, 'maternity', 'birth', 'maternity_ward', 'hospital', 'have_baby']
senticnet['become_nurse'] = [0, 0.812, 0, 0.98, '#interesting', '#admirable', 0.597, 'pass_exam', 'medical_school', 'become_doctor', 'go_to_school', 'study_medicine']
senticnet['become_obsolete'] = [0, 0, 0.894, -0.825, '#angry', '#disgusting', -0.573, 'get_old', 'old_software', 'unglam', 'old_technology', 'overrated']
senticnet['become_old'] = [0, 0, 0, -0.847, '#disgusting', '#disgusting', -0.282, 'get_old', 'grow_older', 'old', 'lose_energy', 'lose_health']
senticnet['become_parent'] = [-0.062, 0.2, -0.1, 0.168, '#interesting', '#admirable', 0.069, 'orphan', 'take_child', 'offspring', 'progeny', 'much_child']
senticnet['become_physically_fit'] = [0, 0, 0, 0.968, '#admirable', '#admirable', 0.323, 'increase_stamina', 'sweat_lot', 'get_strong', 'wear_out_shoes', 'exercise_dog']
senticnet['become_politician'] = [0, 0.732, 0, 0.908, '#interesting', '#admirable', 0.547, 'find_another_person', 'help_understand', 'disagree', 'know_better', 'investigation']
senticnet['become_poor'] = [-0.303, -0.073, -0.045, -0.241, '#sad', '#disgusting', -0.172, 'wage_slavery', 'overspend', 'pay_fine', 'go_bankrupt', 'bounce_check']
senticnet['become_popular'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'get_to_know_person', 'get_sex', 'make_laugh', 'social_bond', 'give_pleasure']
senticnet['become_pregnant'] = [0.97, 0.729, 0, 0.946, '#joyful', '#admirable', 0.882, 'make_baby', 'give_birth_child', 'sexual_intercourse', 'find_partner', 'make_love']
senticnet['become_red'] = [-0.964, 0, 0, -0.715, '#sad', '#disgusting', -0.56, 'embarrass_oneself', 'uncomfortable_situation', 'bad_experience', 'shy', 'provocative_discussion']
senticnet['become_relaxed'] = [0.846, 0.976, 0, 0.766, '#joyful', '#interesting', 0.863, 'feel_relaxed', 'relax_muscle', 'stress_reduction', 'stress_relief', 'relax']
senticnet['become_rich'] = [0.832, 0, 0, 0, '#joyful', '#joyful', 0.277, 'gain_wealth', 'make_money', 'earn_money', 'become_wealthy', 'entrepreneur']
senticnet['become_rude'] = [-0.969, 0, 0.525, -0.959, '#sad', '#disgusting', -0.818, 'angry', 'get_angry', 'rude', 'shout', 'anger']
senticnet['become_sad'] = [-0.993, 0, 0.673, -0.928, '#sad', '#disgusting', -0.865, 'sadness', 'boredom', 'miss_someone', 'lose_job', 'lose_money']
senticnet['become_scientist'] = [0, -0.786, 0, 0.98, '#surprising', '#admirable', 0.589, 'want_learn_new', 'become_intelligent', 'learn_new', 'enroll_class', 'add_knowledge']
senticnet['become_sick'] = [0, -0.734, -0.778, -0.806, '#scared', '#disgusting', -0.283, 'suffer_fool', 'punch_face', 'std', 'toothache', 'go_insane']
senticnet['become_small'] = [-0.996, 0, 0.327, -0.913, '#sad', '#disgusting', -0.745, 'shrink', 'clothes_shrink', 'shrinkage', 'remove_stain', 'fight_fire']
senticnet['become_smart'] = [0, 0, 0, 0.879, '#admirable', '#admirable', 0.293, 'gain_knowledge', 'increase_knowledge', 'add_knowledge', 'learn_information', 'learn']
senticnet['become_stressed'] = [0, 0, 0, -0.773, '#disgusting', '#disgusting', -0.258, 'stress', 'want_pass_class', 'fail', 'complete_course', 'lose_qualification']
senticnet['become_strong'] = [0.879, 0.884, 0, 0.979, '#interesting', '#admirable', 0.914, 'live_healthy_lifestyle', 'long_life', 'exercise', 'feel_fit', 'stay_shape']
senticnet['become_tired'] = [-0.814, 0, 0, -0.878, '#sad', '#disgusting', -0.564, 'fatigue', 'tiredness', 'exhaustion', 'heavy_breathe', 'sore_foot']
senticnet['become_unconscious'] = [-0.049, -0.035, -0.062, -0.163, '#scared', '#disgusting', -0.08, 'stop_move', 'hit_oneself_head', 'twitch', 'loss_of_consciousness', 'lose_consciousness']
senticnet['become_wage-slave'] = [-0.796, 0, 0, -0.717, '#sad', '#disgusting', -0.504, 'employment', 'workaholic', 'arduous', 'work', 'salary']
senticnet['become_wealthy'] = [0.986, 0, 0, 0, '#joyful', '#joyful', 0.329, 'become_rich', 'gain_wealth', 'buy_land', 'need_job', 'need_make_money']
senticnet['become_wet'] = [0, 0, 0.883, -0.767, '#angry', '#disgusting', -0.55, 'shower', 'rain', 'wash_away_dirt', 'wet_clothes', 'run_out_soap']
senticnet['become_wind'] = [0, 0, -0.922, -0.919, '#scared', '#disgusting', -0.614, 'get_out_breath', 'run_out_breath', 'breathlessness', 'breaheavily', 'shin_splint']
senticnet['become_wise'] = [0, 0.943, 0, 0, '#interesting', '#interesting', 0.314, 'enlightenment', 'smartness', 'curious', 'intelligent', 'comprehend']
senticnet['become_younger'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'feel_rejuvenated', 'feel_fresher', 'feel_more_lively', 'recover', 'feel_regenerate']
senticnet['bed'] = [0, 0.171, -0.056, 0.102, '#interesting', '#admirable', 0.072, 'bead', 'mattress', 'linen_cupboard', 'bead_cover', 'seduce']
senticnet['bed_bug'] = [0, -0.074, 0.137, -0.124, '#angry', '#disgusting', -0.062, 'gnat', 'mite', 'small_fly', 'flea', 'fly_away']
senticnet['bed_check'] = [0.84, -0.979, 0, 0.713, '#joyful', '#surprising', 0.844, 'proof', 'substantiation', 'crosscheck', 'parity_check', 'redundancy_check']
senticnet['bed_cover'] = [0.049, 0, 0, 0.052, '#joyful', '#admirable', 0.034, 'sleep_under', 'bed', 'berth', 'cover_furniture', 'mattress']
senticnet['bed_covering'] = [0.883, -0.912, 0, 0.991, '#surprising', '#admirable', 0.929, 'spread', 'bedspread', 'bedcover', 'bed_cover', 'quilted_bedspread']
senticnet['bed_sheet'] = [0, 0.943, 0, 0, '#interesting', '#interesting', 0.314, 'duvet_cover', 'pillow', 'comforter', 'pillowcase', 'blanket']
senticnet['bed_sleep'] = [0.299, 0.126, 0, 0.207, '#joyful', '#admirable', 0.211, 'inactivity', 'count_sheep', 'shut_eye', 'rest_night', 'lay_down']
senticnet['bed_time'] = [0.1, 0.085, 0, 0.093, '#joyful', '#admirable', 0.093, 'narrative', 'bedtime', 'fable', 'long_story', 'saga']
senticnet['bed_time_story'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'literature', 'book_story', 'fairy_tale', 'fiction', 'childhood']
senticnet['bed_wetter'] = [-0.531, 0, 0.508, -0.748, '#sad', '#disgusting', -0.596, 'bedwetter', 'pisser', 'mortal', 'wetter', 'person']
senticnet['bedamn'] = [-0.715, 0, 0.792, -0.952, '#angry', '#disgusting', -0.82, 'call_down', 'stir', 'call_forth', 'conjure', 'bring_up']
senticnet['bedaze'] = [0, 0, 0.911, -0.707, '#angry', '#disgusting', -0.539, 'confuse', 'fulgurant', 'eye-popping', 'fulgurous', 'dazzling']
senticnet['bedbug'] = [0, 0, -0.941, -0.904, '#scared', '#disgusting', -0.615, 'eight_legs', 'dog_hair', 'parasite', 'dog_fur', 'bite_dog']
senticnet['bedcover'] = [0.883, -0.912, 0, 0.991, '#surprising', '#admirable', 0.929, 'spread', 'bedspread', 'quilted_bedspread', 'bed_cover', 'bed_covering']
senticnet['bedevil'] = [-0.132, 0.071, 0.694, -0.674, '#angry', '#disgusting', -0.476, 'crucify', 'dun', 'frustrating', 'aggravate', 'exasperation']
senticnet['bedizen'] = [-0.997, 0, 0.687, -0.864, '#sad', '#disgusting', -0.849, 'ornament', 'grace', 'decorate', 'adorn', 'embellish']
senticnet['bedraggle'] = [-0.809, 0, 0.962, -0.553, '#sad', '#angry', -0.775, 'sop', 'douse', 'dowse', 'drench', 'soak']
senticnet['bedraggled'] = [-0.753, 0, 0.68, -0.599, '#sad', '#angry', -0.677, 'battered', 'damaged', 'hurt', 'derelict', 'dilapidated']
senticnet['bedrock'] = [0, 0, 0, 0.882, '#admirable', '#admirable', 0.294, 'fossil', 'oil', 'dark_liquid', 'smithsonian_institution', 'inert_gas']
senticnet['bedsheet'] = [0.024, 0, 0, 0.074, '#joyful', '#admirable', 0.033, 'sheet', 'cover', 'quilt', 'comforter', 'modesty']
senticnet['bedspread'] = [0, 0.141, -0.065, 0.215, '#interesting', '#admirable', 0.097, 'concealment', 'front_page', 'conceal', 'lid', 'surround']
senticnet['bedtime'] = [0.1, 0.085, 0, 0.093, '#joyful', '#admirable', 0.093, 'narrative', 'bed_time', 'fable', 'long_story', 'saga']
senticnet['bedwetter'] = [-0.531, 0, 0.508, -0.748, '#sad', '#disgusting', -0.596, 'pisser', 'bed_wetter', 'mortal', 'wetter', 'person']
senticnet['bee'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'fly_animal', 'insect', 'mosquito', 'bug', 'fly_insect']
senticnet['bee_hive'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'windsor', 'lair', 'habitat', 'grassy_field', 'pet_store']
senticnet['bee_home'] = [0.028, 0, 0.027, 0.101, '#joyful', '#admirable', 0.034, 'animal_dwell', 'mew', 'live_place', 'dwell_place', 'place_to_live']
senticnet['bee_house'] = [-0.08, 0.232, 0, 0.099, '#interesting', '#admirable', 0.084, 'bee_product', 'gooey', 'red_skin', 'really_hot', 'crispy']
senticnet['bee_product'] = [0.072, 0.065, -0.068, 0.144, '#joyful', '#admirable', 0.071, 'gooey', 'paraffin', 'slick', 'goo', 'fuel_source']
senticnet['bee_sting'] = [0, 0, -0.734, -0.819, '#scared', '#disgusting', -0.518, 'flab', 'bad_hair_day', 'lose_friend', 'alcoholism', 'brain_tumor']
senticnet['beef'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'veal', 'animal_flesh', 'food_group', 'cereal', 'curry']
senticnet['beefeater'] = [-0.993, 0, 0.877, -0.777, '#sad', '#angry', -0.882, 'yeoman', 'outrider', 'yeoman_of_guard', 'bodyguard', 'defender']
senticnet['beehive'] = [0, 0.076, 0.024, 0.137, '#interesting', '#admirable', 0.063, 'kennel', 'hive', 'lair', 'habitat', 'animal_home']
senticnet['beep'] = [-0.035, -0.043, 0.055, -0.052, '#angry', '#disgusting', -0.033, 'make_noise', 'strum', 'make_sound', 'backup', 'compose_music']
senticnet['beer'] = [0.855, -0.817, 0, 0, '#joyful', '#surprising', 0.557, 'whisky', 'brand_name', 'alcohol', 'vodka', 'wine']
senticnet['beer_container'] = [0.03, 0, 0.022, 0.062, '#joyful', '#admirable', 0.023, 'large_cup', 'hold_drink', 'cool_drink', 'store_ice_cream', 'drink_holder']
senticnet['beer_mug'] = [0.872, 0.793, 0, 0, '#joyful', '#interesting', 0.555, 'liquor_glass', 'flask', 'beer', 'refill', 'bartender']
senticnet['beetle'] = [0, -0.075, 0.08, -0.086, '#angry', '#disgusting', -0.03, 'cutworm', 'gypsy_moth', 'mole_cricket', 'japanese_beetle', 'scorpion']
senticnet['befit'] = [0.565, -0.946, 0, 0.798, '#surprising', '#admirable', 0.77, 'check', 'match', 'correspond', 'jibe', 'tally']
senticnet['before_fall'] = [-0.049, -0.02, 0.062, -0.1, '#angry', '#disgusting', -0.064, 'skid', 'fall_down', 'lose_balance', 'slippery', 'stumble']
senticnet['before_meal'] = [0.127, 0.264, 0, 0.234, '#interesting', '#admirable', 0.208, 'liquid_food', 'vital', 'hot_liquid', 'broth', 'hearty']
senticnet['before_night'] = [-0.049, -0.02, 0.062, -0.1, '#angry', '#disgusting', -0.064, 'darkness', 'dark', 'bleak', 'moon_star', 'cold_day']
senticnet['befouled'] = [-0.717, 0, 0.839, -0.762, '#angry', '#disgusting', -0.773, 'draggled', 'soiled', 'filthy', 'nasty', 'scummy']
senticnet['befoulment'] = [0.764, -0.619, 0, 0.878, '#joyful', '#admirable', 0.754, 'feculence', 'dirtiness', 'defilement', 'dinginess', 'dinge']
senticnet['befuddle'] = [-0.873, 0, 0.787, -0.717, '#sad', '#angry', -0.792, 'demoralize', 'pose', 'disorient', 'disorientate', 'amaze']
senticnet['befuddlement'] = [-0.781, 0, 0.582, -0.633, '#sad', '#disgusting', -0.665, 'confusion', 'disarray', 'mental_confusion', 'confusedness', 'muddiness']
senticnet['beg'] = [0, 0, 0.705, -0.987, '#angry', '#disgusting', -0.564, 'bring', 'prevent', 'accept', 'ask_politely', 'take']
senticnet['beggarly'] = [-0.919, 0, 0.598, -0.522, '#sad', '#angry', -0.68, 'parsimonious', 'penurious', 'scrimy', 'stingy', 'chintzy']
senticnet['beggary'] = [-0.733, 0, 0.872, -0.978, '#angry', '#disgusting', -0.861, 'poverty', 'impoverishment', 'poorness', 'indigence', 'mendicancy']
senticnet['begging'] = [-0.76, 0, 0, -0.763, '#sad', '#disgusting', -0.508, 'appeal', 'prayer', 'beggary', 'solicitation', 'implore']
senticnet['begin'] = [0, 0.256, -0.157, 0.31, '#interesting', '#admirable', 0.136, 'commence', 'omega', 'finish_complete', 'conclusion', 'end']
senticnet['begin_day'] = [0.02, 0.067, 0, 0, '#joyful', '#interesting', 0.029, 'sunrise', 'light_in_sky', 'dawn', 'daylight', 'sun']
senticnet['begin_end'] = [0, 0.069, 0.009, 0.173, '#interesting', '#admirable', 0.078, 'start_end', 'omega', 'infinite', 'plot', 'always_read']
senticnet['begin_pro'] = [0.038, 0.259, 0, 0.195, '#interesting', '#admirable', 0.164, 'money_maker', 'business_term', 'savings_account', 'save', 'check_account']
senticnet['begin_work'] = [0.229, 0.127, 0, 0, '#joyful', '#interesting', 0.119, 'return_work', 'start_project', 'work_box_office', 'write_program', 'go_work']
senticnet['beginner'] = [-0.954, 0, 0.735, -0.842, '#sad', '#disgusting', -0.844, 'novice', 'cub', 'tyro', 'tiro', 'initiate']
senticnet['beginning'] = [0.836, -0.832, 0, 0.511, '#joyful', '#surprising', 0.726, 'issue', 'start', 'casus_belli', 'emergence', 'egress']
senticnet['begrime'] = [-0.971, 0, 0.922, -0.533, '#sad', '#angry', -0.809, 'muddy_up', 'muck_up', 'foul', 'blemish', 'smear']
senticnet['begrudge'] = [0.067, 0.104, 0.791, -0.679, '#angry', '#disgusting', -0.433, 'enviousness', 'enviably', 'grudging', 'enviable', 'sulkiness']
senticnet['beguile'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['beguiled'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['beguiler'] = [0.962, -0.675, 0, 0.954, '#joyful', '#admirable', 0.864, 'mountebank', 'charlatan', 'obscurantist', 'sandbagger', 'gouger']
senticnet['beguiling'] = [0.969, -0.848, 0, 0.837, '#joyful', '#surprising', 0.885, 'alluring', 'enticing', 'tempting', 'seductive', 'corrupting']
senticnet['behave'] = [0, 0.715, 0, 0.772, '#interesting', '#admirable', 0.496, 'act', 'emote', 'do_something', 'imitate', 'stage_play']
senticnet['behavior'] = [0, 0.815, 0, 0.735, '#interesting', '#admirable', 0.517, 'way_of_acting', 'good_etiquette', 'manners', 'niceness', 'good_behavior']
senticnet['behavior_modification'] = [0.542, -0.63, 0, 0.912, '#surprising', '#admirable', 0.695, 'implosion_therapy', 'flooding', 'reciprocal_inhibition', 'aversion_therapy', 'desensitization_technique']
senticnet['behavior_therapy'] = [0.677, -0.694, 0, 0.562, '#joyful', '#surprising', 0.644, 'implosion_therapy', 'flooding', 'reciprocal_inhibition', 'aversion_therapy', 'desensitization_technique']
senticnet['behead'] = [0, 0, -0.966, -0.912, '#scared', '#disgusting', -0.626, 'kill', 'french_revolution', 'kill_other_person', 'seek_revenge', 'murder']
senticnet['behemoth'] = [-0.881, 0, 0.882, -0.586, '#sad', '#angry', -0.783, 'mortal', 'unusual_person', 'colossus', 'aberrant', 'giant']
senticnet['behind_house'] = [0.885, -0.874, 0, 0, '#joyful', '#surprising', 0.586, 'outside_house', 'back_yard', 'yard', 'backyard', 'back_house']
senticnet['beholder'] = [-0.832, 0, 0.665, -0.512, '#sad', '#angry', -0.67, 'percipient', 'eavesdropper', 'perceiver', 'observer', 'auditor']
senticnet['beijing'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'newyork', 'london', 'big_city', 'rome', 'tokyo']
senticnet['belch'] = [0, 0, -0.802, -0.809, '#scared', '#disgusting', -0.537, 'acid_indigestion', 'burp', 'gurk', 'hunger_go_away', 'choke']
senticnet['beldam'] = [0.52, -0.773, 0, 0.921, '#surprising', '#admirable', 0.738, 'oldster', 'old_person', 'senior_citizen', 'golden_ager', 'old_woman']
senticnet['beleaguer'] = [-0.642, 0, 0.881, -0.82, '#angry', '#disgusting', -0.781, 'torment', 'bedevil', 'rag', 'dun', 'crucify']
senticnet['belie'] = [-0.593, 0, 0.537, -0.532, '#sad', '#angry', -0.554, 'murder', 'mutilate', 'mangle', 'misrepresent', 'falsify']
senticnet['belief'] = [0.086, 0.471, -0.126, 0.411, '#interesting', '#admirable', 0.281, 'faith', 'dogma', 'belief_god', 'spiritual', 'religious']
senticnet['belief_god'] = [-0.025, 0.347, -0.123, 0.305, '#interesting', '#admirable', 0.168, 'faith', 'religious_purpose', 'spiritual', 'religious', 'belief']
senticnet['belief_system'] = [0, 0.356, -0.079, 0.327, '#interesting', '#admirable', 0.201, 'belief_god', 'religious_action', 'faith', 'belief', 'sect']
senticnet['believability'] = [0.726, -0.824, 0, 0.966, '#surprising', '#admirable', 0.839, 'real_thing', 'real_stuff', 'credibility', 'credibleness', 'authenticity']
senticnet['believe'] = [0.06, 0.422, -0.177, 0.41, '#interesting', '#admirable', 0.238, 'faith', 'enter_contract', 'belief', 'belief_god', 'religious_belief']
senticnet['believe_god'] = [-0.036, 0.284, -0.112, 0.211, '#interesting', '#admirable', 0.116, 'plan_wedding', 'trust_god', 'kneel', 'belief_god', 'wish']
senticnet['believe_in'] = [0.105, -0.178, 0.057, 0.079, '#joyful', '#surprising', 0.102, 'trust', 'believe', 'pray', 'religion', 'church']
senticnet['believer'] = [0, 0.231, -0.064, 0.216, '#interesting', '#admirable', 0.128, 'true_believer', 'worshiper', 'cleric', 'religious_person', 'vicar']
senticnet['belittle'] = [-0.822, 0, 0.835, -0.675, '#sad', '#angry', -0.777, 'disparage', 'depreciate', 'deflate', 'puncture', 'pick_at']
senticnet['bell'] = [0.034, 0, 0.01, 0.087, '#joyful', '#admirable', 0.037, 'chime', 'bell_noise', 'alto', 'piano', 'ring_loudly']
senticnet['bell_cat'] = [-0.052, 0.072, 0.012, 0.066, '#interesting', '#admirable', 0.025, 'pet', 'leash', 'animal', 'dog_tag', 'fur']
senticnet['bell_magpie'] = [0, 0.749, 0, 0.729, '#interesting', '#admirable', 0.493, 'bird', 'piping_crow', 'butcherbird', 'currawong', 'australian_magpie']
senticnet['bell_noise'] = [0.02, 0, 0, 0.123, '#joyful', '#admirable', 0.048, 'bell_sound', 'clang', 'chime', 'jingle', 'piece_of_jewelry']
senticnet['bell_ring'] = [0.768, 0, 0, 0.881, '#joyful', '#admirable', 0.55, 'something_familiar', 'remember', 'amplitude', 'step', 'rung']
senticnet['bell_sound'] = [0.034, 0, 0, 0.19, '#joyful', '#admirable', 0.075, 'piece_of_jewelry', 'ring', 'wedding_band', 'engagement', 'make_gold']
senticnet['bell_tower'] = [0, 0.199, 0.036, 0.199, '#interesting', '#admirable', 0.121, 'temple', 'catholic_church', 'church', 'cathedral', 'chapel']
senticnet['belle'] = [0.748, 0, 0, 0.987, '#joyful', '#admirable', 0.578, 'pretty', 'gorgeous', 'nice_look', 'beautiful', 'sophisticated']
senticnet['bellicoseness'] = [-0.507, 0, 0.817, -0.593, '#angry', '#disgusting', -0.639, 'disagreeableness', 'truculence', 'truculency', 'bellicosity', 'pugnacity']
senticnet['bellicosity'] = [-0.507, 0, 0.817, -0.593, '#angry', '#disgusting', -0.639, 'disagreeableness', 'truculence', 'truculency', 'pugnacity', 'bellicoseness']
senticnet['belligerence'] = [0, 0.139, 0.736, -0.668, '#angry', '#disgusting', -0.422, 'belligerent', 'belligerency', 'bad_blood', 'animus', 'warpath']
senticnet['belligerency'] = [0, 0.139, 0.736, -0.668, '#angry', '#disgusting', -0.422, 'belligerent', 'belligerence', 'bad_blood', 'animus', 'warpath']
senticnet['belligerent'] = [0, 0.139, 0.736, -0.668, '#angry', '#disgusting', -0.422, 'belligerence', 'belligerency', 'bad_blood', 'animus', 'warpath']
senticnet['belligerently'] = [0, 0.149, 0.719, -0.664, '#angry', '#disgusting', -0.411, 'hostilely', 'antagonism', 'class_feeling', 'aggressiveness', 'animus']
senticnet['belly'] = [0, 0, 0, 0.968, '#admirable', '#admirable', 0.323, 'digestive_system', 'nervous_system', 'human_body', 'stomach', 'tummy']
senticnet['belly_button'] = [0, 0.102, 0, 0, '#interesting', '#interesting', 0.034, 'two_arms', 'adam_apple', 'two_ears', 'five_fingers_hand', 'liver']
senticnet['belly_out'] = [-0.763, 0, 0.656, -0.726, '#sad', '#disgusting', -0.715, 'tumefy', 'swell_up', 'tumesce', 'intumesce', 'swell']
senticnet['bellyache'] = [-0.74, 0, 0.872, -0.616, '#sad', '#angry', -0.743, 'hurting', 'aching', 'pain', 'headache', 'toothache']
senticnet['belong'] = [0.064, 0.2, -0.19, 0.292, '#interesting', '#admirable', 0.122, 'ownership', 'possessive', 'possess', 'possession', 'own']
senticnet['belong_club'] = [0, 0.086, -0.069, 0.12, '#interesting', '#admirable', 0.046, 'miss_bus', 'study_library', 'borrow_book_from_library', 'learn_new_idea', 'point_out']
senticnet['belong_person'] = [0, 0.221, -0.13, 0.249, '#interesting', '#admirable', 0.113, 'belong', 'possessive', 'part_of_group', 'bring_together', 'inclusion']
senticnet['belonging'] = [0.632, 0.645, -0.24, 0.295, '#joyful', '#interesting', 0.444, 'elated', 'gleeful', 'gladden', 'gladsome', 'gladness']
senticnet['belongings'] = [0.057, 0.141, -0.064, 0.162, '#interesting', '#admirable', 0.099, 'madonna', 'singer', 'personal_item', 'guarantee', 'stuff']
senticnet['beloved'] = [0.743, 0, 0, 0.996, '#joyful', '#admirable', 0.58, 'lust', 'passion', 'love', 'love_another_person', 'wonderful_feeling']
senticnet['below_belt'] = [-0.745, 0, 0.934, -0.859, '#angry', '#disgusting', -0.846, 'dirty', 'unjust', 'foul', 'cheating', 'raw']
senticnet['below_neck'] = [0, 0.072, 0, 0.064, '#interesting', '#admirable', 0.045, 'physique', 'leg_arm', 'anatomy', 'human_part', 'hand_foot']
senticnet['belt'] = [0, 0.072, 0, 0.064, '#interesting', '#admirable', 0.045, 'zipper', 'pant', 'trousers', 'cowboy_boot', 'accessory']
senticnet['bemire'] = [-0.976, 0, 0.873, -0.669, '#sad', '#angry', -0.839, 'muddy_up', 'muck_up', 'foul', 'blemish', 'smear']
senticnet['bemoan'] = [-0.906, 0, 0.725, -0.861, '#sad', '#disgusting', -0.831, 'quetch', 'kvetch', 'complain', 'sound_off', 'plain']
senticnet['bemock'] = [-0.555, 0, 0.947, -0.775, '#angry', '#disgusting', -0.759, 'blackguard', 'deride', 'twit', 'tease', 'razz']
senticnet['bemuse'] = [-0.959, 0, 0.683, -0.575, '#sad', '#angry', -0.739, 'upset', 'disconcert', 'discompose', 'discomfit', 'untune']
senticnet['bemusement'] = [-0.846, 0, 0.855, -0.715, '#sad', '#angry', -0.805, 'confusion', 'disarray', 'mental_confusion', 'confusedness', 'muddiness']
senticnet['bench'] = [0.033, -0.039, 0, 0, '#joyful', '#surprising', 0.024, 'chair', 'coach_seat', 'couch', 'stool', 'seat']
senticnet['bench_press'] = [0.642, -0.585, 0, 0.751, '#joyful', '#admirable', 0.659, 'jerk', 'snatch', 'military_press', 'clean', 'weightlift']
senticnet['bench_sit'] = [0, -0.122, 0, 0, '#surprising', '#surprising', 0.041, 'rest', 'wooden_chair', 'park', 'garden', 'outdoor']
senticnet['bend'] = [0, 0, 0, 0.078, '#admirable', '#admirable', 0.026, 'rotate', 'turn_around', 'change_direction', 'revolve', 'rotate_movement']
senticnet['bend_knee'] = [0, 0, -0.951, -0.783, '#scared', '#disgusting', -0.578, 'knee_bend', 'submit', 'bend_over', 'find_chair', 'keep_balance']
senticnet['bend_leg'] = [0, 0, 0.921, -0.966, '#angry', '#disgusting', -0.629, 'walk_upon', 'stand_upon', 'stand', 'keep_foot_warm', 'lower_body']
senticnet['bend_over'] = [-0.086, -0.027, 0.042, -0.117, '#sad', '#disgusting', -0.073, 'stop_walk', 'bend_knee', 'coordination', 'manual_dexterity', 'break_half']
senticnet['bend_spear'] = [-0.935, 0, 0.794, -0.991, '#sad', '#disgusting', -0.907, 'break', 'smash', 'damage', 'fracture', 'ruin']
senticnet['bendability'] = [-0.549, 0, 0.909, -0.973, '#angry', '#disgusting', -0.81, 'suppleness', 'pliancy', 'pliantness', 'flexibility', 'flexibleness']
senticnet['bendable'] = [0, 0, -0.066, -0.071, '#scared', '#disgusting', -0.046, 'elbow', 'arm', 'wrist', 'five_fingers', 'bandit']
senticnet['benediction'] = [0.638, -0.838, 0, 0.852, '#surprising', '#admirable', 0.776, 'blessing', 'grace', 'commination', 'orison', 'supplication']
senticnet['benefic'] = [0.578, 0.672, -0.286, 0.305, '#joyful', '#interesting', 0.423, 'beneficence', 'beneficent', 'beneficed', 'beneficially', 'kindly']
senticnet['beneficed'] = [0.578, 0.672, -0.286, 0.305, '#joyful', '#interesting', 0.423, 'beneficence', 'beneficent', 'benefic', 'beneficially', 'kindly']
senticnet['beneficence'] = [0.578, 0.672, -0.286, 0.305, '#joyful', '#interesting', 0.423, 'beneficent', 'beneficed', 'benefic', 'beneficially', 'kindly']
senticnet['beneficent'] = [0.578, 0.672, -0.286, 0.305, '#joyful', '#interesting', 0.423, 'beneficence', 'beneficed', 'benefic', 'beneficially', 'kindly']
senticnet['beneficial'] = [0.53, -0.559, 0, 0.912, '#surprising', '#admirable', 0.667, 'advantageous', 'positive', 'good', 'plus', 'discriminatory']
senticnet['beneficially'] = [0.578, 0.672, -0.286, 0.305, '#joyful', '#interesting', 0.423, 'beneficence', 'beneficent', 'beneficed', 'benefic', 'kindly']
senticnet['beneficiary'] = [0.955, 0, 0, 0.759, '#joyful', '#admirable', 0.571, 'devisee', 'legatee', 'recipient', 'receiver', 'pensioner']
senticnet['benefit'] = [0.085, 0.365, -0.201, 0.362, '#interesting', '#admirable', 0.204, 'bonus', 'monetary_gain', 'financial_gain', 'return', 'given']
senticnet['benevolence'] = [0.547, 0.674, -0.281, 0.286, '#joyful', '#interesting', 0.409, 'benevolently', 'amorous', 'amative', 'enamoredness', 'amorousness']
senticnet['benevolent'] = [0.552, 0.681, -0.294, 0.297, '#joyful', '#interesting', 0.412, 'charitable', 'good-hearted', 'large-hearted', 'openhearted', 'kindly']
senticnet['benevolently'] = [0.547, 0.674, -0.281, 0.286, '#joyful', '#interesting', 0.409, 'benevolence', 'amorous', 'amative', 'enamoredness', 'amorousness']
senticnet['benight'] = [0.627, -0.651, 0, 0.968, '#surprising', '#admirable', 0.749, 'overwhelm', 'overpower', 'sweep_over', 'whelm', 'overcome']
senticnet['benign_tumor'] = [-0.704, 0, 0.639, -0.56, '#sad', '#angry', -0.634, 'fibroma', 'adenoma', 'chondroma', 'enchondroma', 'myoma']
senticnet['bent'] = [-0.83, 0, 0, -0.713, '#sad', '#disgusting', -0.514, 'limp', 'crooked', 'inclined', 'droopy', 'arciform']
senticnet['benumb'] = [-0.585, 0, 0.703, -0.868, '#angry', '#disgusting', -0.719, 'numb', 'desensitize', 'modify', 'deaf', 'bedaze']
senticnet['benumbed'] = [-0.612, 0, 0.572, -0.839, '#sad', '#disgusting', -0.674, 'numb', 'insensible', 'anesthetic', 'emotionless', 'asleep']
senticnet['bequest'] = [-0.061, 0.247, -0.201, 0.205, '#interesting', '#admirable', 0.063, 'bail', 'excise', 'bribe', 'divorce_money', 'return']
senticnet['berate'] = [-0.907, 0, 0.841, -0.651, '#sad', '#angry', -0.8, 'castigate', 'tell_off', 'brush_down', 'chasten', 'objurgate']
senticnet['berating'] = [-0.864, 0, 0.953, -0.965, '#angry', '#disgusting', -0.927, 'reprimand', 'rebuke', 'reproof', 'reproval', 'reprehension']
senticnet['bereave'] = [-0.986, 0, 0.654, -0.847, '#sad', '#disgusting', -0.829, 'deprive', 'expropriate', 'disarm', 'unclothe', 'take']
senticnet['bereaved'] = [-0.884, 0.175, -0.599, 0, '#sad', '#scared', -0.436, 'grief-stricken', 'sorrowing', 'bereft', 'grieving', 'mourning']
senticnet['bereaved_person'] = [-0.69, 0, 0.94, -0.617, '#sad', '#angry', -0.749, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['bereavement'] = [0, 0, -0.922, -0.988, '#scared', '#disgusting', -0.637, 'loss', 'deprivation', 'dispossession', 'privation', 'demise']
senticnet['bereft'] = [-0.884, 0.175, -0.599, 0, '#sad', '#scared', -0.436, 'bereaved', 'grief-stricken', 'sorrowing', 'grieving', 'mourning']
senticnet['berry'] = [0.779, -0.76, 0, 0, '#joyful', '#surprising', 0.513, 'juicy_fruit', 'fruit', 'prune', 'fig', 'sweet_fruit']
senticnet['berth'] = [0.049, 0, 0, 0.052, '#joyful', '#admirable', 0.034, 'sleep_under', 'bed', 'bed_cover', 'cover_furniture', 'mattress']
senticnet['beseem'] = [0.59, -0.545, 0, 0.766, '#joyful', '#admirable', 0.634, 'check', 'match', 'correspond', 'jibe', 'tally']
senticnet['beset'] = [-0.593, 0.162, 0.221, -0.503, '#sad', '#disgusting', -0.385, 'annoy', 'harass', 'provoke', 'poke', 'chivvy']
senticnet['beshrew'] = [-0.724, 0, 0.847, -0.976, '#angry', '#disgusting', -0.849, 'call_down', 'stir', 'call_forth', 'conjure', 'bring_up']
senticnet['beside'] = [0.071, 0.127, 0, 0.197, '#interesting', '#admirable', 0.132, 'place_work', 'workplace', 'office', 'work', 'hang_wall']
senticnet['besiege'] = [-0.78, 0, 0.725, -0.953, '#sad', '#disgusting', -0.819, 'assail', 'blockade', 'seal_off', 'ebb', 'attack']
senticnet['besmirch'] = [-0.856, 0, 0, -0.863, '#sad', '#disgusting', -0.573, 'charge', 'accuse', 'malign', 'libel', 'slander']
senticnet['besot'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'nonplus', 'baffle', 'stupefy', 'dumbfound', 'stupefaction']
senticnet['bespeak'] = [0.636, -0.541, 0, 0.673, '#joyful', '#admirable', 0.617, 'foreshow', 'signal', 'threaten', 'auspicate', 'betoken']
senticnet['best'] = [0.135, 0.225, -0.124, 0.432, '#interesting', '#admirable', 0.223, 'excellent', 'goodness', 'well_done', 'great', 'good_quality']
senticnet['best_ever'] = [0.106, -0.053, 0, 0.437, '#joyful', '#admirable', 0.199, 'high_quality', 'really_good', 'well_done', 'high_standard', 'most_good']
senticnet['best_friend'] = [0.727, 0, 0, 0.705, '#joyful', '#admirable', 0.477, 'loyal', 'household_animal', 'house_pet', 'good_pet', 'home_animal']
senticnet['best_life'] = [0.924, 0, 0, 0, '#joyful', '#joyful', 0.308, 'knowledgeable', 'live_ripe_old_age', 'complement', 'develop_talent', 'live_well']
senticnet['best_moment'] = [0.642, -0.585, 0, 0.751, '#joyful', '#admirable', 0.659, 'highlight', 'sport_highlight', 'football_highlight', 'television_news', 'put_in_evidence']
senticnet['best_opponent'] = [-0.133, 0, -0.094, -0.121, '#sad', '#disgusting', -0.116, 'die_in_war', 'hit', 'dribble', 'even_score', 'experience_fear']
senticnet['bestow'] = [-0.531, 0, 0.612, -0.796, '#angry', '#disgusting', -0.646, 'impart', 'lend', 'contribute', 'add', 'throw_in']
senticnet['bestower'] = [0.883, -0.664, 0, 0.732, '#joyful', '#admirable', 0.76, 'giver', 'donor', 'presenter', 'subsidizer', 'conferrer']
senticnet['bet'] = [0, 0, -0.79, -0.818, '#scared', '#disgusting', -0.536, 'gamble', 'casino', 'hazard', 'poker_chip', 'risk']
senticnet['beta_radiation'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'alpha_radiation', 'alpha_ray', 'ionizing_radiation', 'beta_ray', 'electron_radiation']
senticnet['beta_ray'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'alpha_radiation', 'alpha_ray', 'beta_radiation', 'ionizing_radiation', 'electron_radiation']
senticnet['beta_test'] = [0.928, -0.879, 0, 0.679, '#joyful', '#surprising', 0.829, 'field_trial', 'field_test', 'alpha_test', 'test', 'road_test']
senticnet['betoken'] = [0.636, -0.541, 0, 0.673, '#joyful', '#admirable', 0.617, 'foreshow', 'signal', 'threaten', 'bespeak', 'auspicate']
senticnet['betray'] = [-0.501, -0.185, 0.038, -0.348, '#sad', '#disgusting', -0.234, 'leave_out', 'unattractive', 'cause_suffer', 'loathing', 'lose_team']
senticnet['betrayal'] = [-0.222, 0.154, -0.248, 0, '#sad', '#scared', -0.105, 'abduction', 'kidnap', 'sell_out', 'sleepless_night', 'sin']
senticnet['betrayer'] = [-0.672, 0, 0.546, -0.633, '#sad', '#disgusting', -0.617, 'fink', 'snitch', 'snitcher', 'sneak', 'stoolpigeon']
senticnet['better'] = [0.979, 0, 0, 0.982, '#joyful', '#admirable', 0.654, 'improve', 'tall_play_basketball', 'reliable', 'best', 'good_quality']
senticnet['better_cardiovascular_health'] = [0.698, -0.547, 0, 0.995, '#joyful', '#admirable', 0.747, 'fitter', 'increased_heart_rate', 'increase_stamina', 'weight_loss', 'get_strong']
senticnet['better_cold'] = [0.121, 0.113, -0.046, 0.114, '#joyful', '#admirable', 0.101, 'gulp', 'potable_liquid', 'sip', 'liquid_beverage', 'ingest']
senticnet['better_good'] = [0.123, -0.338, -0.049, 0.493, '#surprising', '#admirable', 0.302, 'most_good', 'really_good', 'high_quality', 'exceptional', 'wonderful']
senticnet['better_grade'] = [0.769, 0, 0, 0, '#joyful', '#joyful', 0.256, 'become_educated', 'learn', 'learn_information', 'desire_education', 'get_smart']
senticnet['better_half'] = [0.905, -0.515, 0, 0.913, '#joyful', '#admirable', 0.778, 'spouse', 'partner', 'married_person', 'mate', 'helpmate']
senticnet['better_health'] = [0.769, 0, 0, 0, '#joyful', '#joyful', 0.256, 'health', 'become_strong', 'feel_better', 'sporty_person', 'increase_muscle_mass']
senticnet['better_job'] = [0.957, 0, 0, 0, '#joyful', '#joyful', 0.319, 'earn_degree', 'graduate_school', 'get_better_job', 'good_job', 'personal_improvement']
senticnet['better_life'] = [0.808, 0, 0, 0.975, '#joyful', '#admirable', 0.594, 'happiness', 'accomplish_goal', 'self_esteem', 'make_world_better_place', 'help_others']
senticnet['better_off'] = [0.943, -0.582, 0, 0.694, '#joyful', '#admirable', 0.74, 'fortunate', 'happy', 'lucky', 'well', 'felicitous']
senticnet['better_oneself'] = [0, 0.991, 0, 0.804, '#interesting', '#admirable', 0.598, 'feel_better', 'improve', 'glad', 'nice', 'feel_good']
senticnet['better_others'] = [0.786, 0.955, 0, 0, '#joyful', '#interesting', 0.58, 'medical', 'medical_person', 'trustworthy', 'doctor_patient', 'treat_illness']
senticnet['better_person'] = [0.235, 0.271, -0.181, 0.199, '#joyful', '#interesting', 0.175, 'demand', 'pleasant_emotion', 'good_feeling', 'human_emotion', 'end_argument']
senticnet['better_price'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'save_money', 'good_customer', 'buy_cheaper', 'sales', 'on_sale']
senticnet['better_shape'] = [0.981, 0.955, 0, 0.709, '#joyful', '#interesting', 0.882, 'shape_up', 'fit', 'healthy', 'exercise', 'go_to_gym']
senticnet['better_understand'] = [0.932, 0.774, 0, 0.798, '#joyful', '#admirable', 0.835, 'learn_new_fact', 'learn', 'learn_much', 'know_subject', 'become_enlighten']
senticnet['better_world'] = [0.561, 0.575, 0, 0.763, '#interesting', '#admirable', 0.633, 'go_green', 'nice_environment', 'live', 'religious_experience', 'good_health']
senticnet['bettering'] = [0.618, -0.604, 0, 0.747, '#joyful', '#admirable', 0.656, 'corrective', 'remedial', 'ameliorating', 'ameliorative', 'amelioratory']
senticnet['betterment'] = [-0.028, 0.276, -0.21, 0.302, '#interesting', '#admirable', 0.113, 'improvement', 'permission', 'make_better', 'let', 'allow']
senticnet['bettor'] = [-0.786, 0, 0.944, -0.511, '#sad', '#angry', -0.747, 'loser', 'speculator', 'mortal', 'better', 'gambler']
senticnet['beverage'] = [0.951, -0.97, 0, 0.639, '#joyful', '#surprising', 0.853, 'smoothie', 'drinking_water', 'nutrient', 'milk', 'refresher']
senticnet['beverage_service'] = [0.797, -0.782, 0, 0, '#joyful', '#surprising', 0.526, 'waiter', 'bar_service', 'lounge', 'concierge', 'minibar']
senticnet['bewail'] = [-0.76, 0, 0.998, -0.637, '#sad', '#angry', -0.798, 'quetch', 'kvetch', 'complain', 'sound_off', 'plain']
senticnet['beware'] = [0, 0, -0.787, -0.921, '#scared', '#disgusting', -0.569, 'watch_out', 'keep_one_eyes_peeled', 'keep_one_eyes_skinned', 'keep_one_eyes_open', 'aware']
senticnet['bewhiskered'] = [-0.945, 0, 0.84, -0.917, '#sad', '#disgusting', -0.901, 'bearded', 'barbate', 'unshaved', 'whiskered', 'whiskery']
senticnet['bewilder'] = [-0.501, -0.185, 0.038, -0.348, '#sad', '#disgusting', -0.234, 'confuse', 'perplex', 'stupefy', 'dumbfound', 'baffle']
senticnet['bewildered'] = [-0.833, 0, 0.925, -0.994, '#angry', '#disgusting', -0.917, 'at_loss', 'nonplused', 'confused', 'puzzled', 'perplexed']
senticnet['bewilderment'] = [-0.501, -0.185, 0.038, -0.348, '#sad', '#disgusting', -0.234, 'crucifix', 'religion', 'world_religion', 'religious_icon', 'faith']
senticnet['bewitch'] = [0.972, 0, 0, 0.729, '#joyful', '#admirable', 0.567, 'captivated', 'charmed', 'captivate', 'enthrallment', 'enchantment']
senticnet['bewitched'] = [0.998, -0.75, 0, 0.695, '#joyful', '#surprising', 0.814, 'enchanted', 'ensorcelled', 'fascinated', 'hypnotized', 'mesmerized']
senticnet['bewitching'] = [0.724, 0, 0, 0.961, '#joyful', '#admirable', 0.562, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['bewray'] = [-0.962, 0, 0.69, -0.844, '#sad', '#disgusting', -0.832, 'bring_out', 'break', 'let_out', 'expose', 'unwrap']
senticnet['beyond_doubt'] = [-0.718, 0, 0.785, -0.558, '#sad', '#angry', -0.687, 'unimpeachable', 'acknowledged', 'for_sure', 'mathematical', 'unquestionable']
senticnet['bezoar_goat'] = [0, 0.891, 0, 0.987, '#interesting', '#admirable', 0.626, 'wild_goat', 'pasang', 'markhor', 'goat', 'ibex']
senticnet['bhang'] = [-0.946, 0, 0.517, -0.757, '#sad', '#disgusting', -0.74, 'narcotic', 'soft_drug', 'cannabis', 'marijuana', 'marihuana']
senticnet['bias'] = [-0.79, 0, 0.627, -0.816, '#sad', '#disgusting', -0.744, 'taboo', 'tabu', 'tendentiousness', 'irrational_hostility', 'experimenter_bias']
senticnet['biased'] = [0, 0, 0.933, -0.764, '#angry', '#disgusting', -0.566, 'punish_crime', 'go_trial', 'find_guilty', 'arrest', 'send_to_jail']
senticnet['bible'] = [0, 0.187, 0, 0.211, '#interesting', '#admirable', 0.133, 'philosophy', 'holy', 'gospel', 'prayer', 'confessional']
senticnet['bible_story'] = [0.87, 0.953, 0, 0, '#joyful', '#interesting', 0.608, 'bible', 'popular_hobby', 'big_boat', 'song_lyric', 'religion']
senticnet['bicker'] = [-0.833, 0, 0.714, -0.723, '#sad', '#disgusting', -0.757, 'wrangle', 'dustup', 'quarrel', 'row', 'word']
senticnet['bickering'] = [-0.837, 0, 0.735, -0.777, '#sad', '#disgusting', -0.783, 'wrangle', 'dustup', 'quarrel', 'row', 'word']
senticnet['bicycle'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'exercise', 'keep_fit', 'healthy_life', 'sport', 'bicycle_riding']
senticnet['bicycle_across_town'] = [0.954, 0.919, 0, 0, '#joyful', '#interesting', 0.624, 'cycle', 'pedal_cycle', 'bike', 'transportation', 'city']
senticnet['bicycle_area'] = [0.038, 0, 0.01, 0.059, '#joyful', '#admirable', 0.029, 'traffic_rule', 'develop_city', 'control_road', 'red_light', 'yellow_line']
senticnet['bicycle_part'] = [0.069, 0.072, 0, 0.124, '#interesting', '#admirable', 0.088, 'door_opener', 'broomstick', 'carry_suitcase', 'threshold', 'slam']
senticnet['bicycle_riding'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'exercise', 'keep_fit', 'healthy_life', 'sport', 'bicycle']
senticnet['bicycle_school'] = [-0.165, 0, -0.057, -0.065, '#sad', '#disgusting', -0.096, 'roll_ball', 'laugh_clown', 'thank_parent', 'throw_fit', 'watch_d']
senticnet['bicycle_shop'] = [0, -0.025, 0.038, -0.079, '#angry', '#disgusting', -0.031, 'bicycle', 'repair_shop', 'yellow_line', 'big_road', 'schoolyard']
senticnet['bicycle_storage_area'] = [0, -0.075, 0, 0, '#surprising', '#surprising', 0.025, 'garage', 'storeroom', 'trunks', 'motor_oil', 'bicycle']
senticnet['bicycle_store'] = [-0.072, 0, 0, 0, '#sad', '#sad', -0.024, 'enter_door', 'grunt', 'open', 'hang_door', 'control_access']
senticnet['bicycle_tire'] = [0, -0.075, 0, 0, '#surprising', '#surprising', 0.025, 'gyroscope', 'air_pump', 'ball_bounce', 'motor_oil', 'tire']
senticnet['bicycle_work'] = [-0.106, 0, 0, -0.049, '#sad', '#disgusting', -0.052, 'hurry_work', 'carry_briefcase', 'mine_gold', 'sail_around_world', 'voice_concern']
senticnet['bicyle'] = [0.128, -0.111, 0, -0.057, '#joyful', '#surprising', 0.061, 'chesterfield', 'stool', 'tape_machine_room', 'chair', 'tripod_dolly']
senticnet['bid'] = [0.735, 0, 0, 0.972, '#joyful', '#admirable', 0.569, 'receive', 'price', 'limit_time', 'offer', 'return']
senticnet['biff'] = [-0.94, 0, 0.863, -0.984, '#sad', '#disgusting', -0.929, 'poke', 'clout', 'lick', 'punch', 'knockout_punch']
senticnet['bifoliate'] = [-0.508, 0, 0.573, -0.893, '#angry', '#disgusting', -0.658, 'petallike', 'bowery', 'foliolate', 'unifoliate', 'leafy']
senticnet['big'] = [0.037, 0.09, 0.049, 0.223, '#interesting', '#admirable', 0.1, 'large', 'huge', 'great', 'really_big', 'tall']
senticnet['big_animal'] = [0.029, 0, 0.018, 0.059, '#joyful', '#admirable', 0.023, 'domestic_animal', 'wild_animal', 'hoof_mammal', 'large_mammal', 'animal']
senticnet['big_bang'] = [0.763, 0, 0, 0.719, '#joyful', '#admirable', 0.494, 'hypothesis', 'test_hypothesis', 'theory', 'prove_theory', 'experiment']
senticnet['big_blue'] = [0, 0.856, 0, 0.812, '#interesting', '#admirable', 0.556, 'vast', 'along_beach', 'near_beach', 'land_sea', 'full_water']
senticnet['big_boat'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'boat', 'large_boat', 'rowboat', 'ship', 'military_ship']
senticnet['big_breadbox'] = [0.809, -0.868, 0, 0, '#joyful', '#surprising', 0.559, 'home_made', 'bread', 'container', 'baked_goods', 'eat_bread']
senticnet['big_brother'] = [0, 0.269, -0.17, 0.182, '#interesting', '#admirable', 0.094, 'kinship', 'siblings', 'elder', 'family', 'best_friend']
senticnet['big_build'] = [0, 0.126, 0.032, 0.167, '#interesting', '#admirable', 0.087, 'edifice', 'storage_facility', 'manufacture_plant', 'make_stuff', 'storage_space']
senticnet['big_business'] = [0.769, 0.863, 0, 0, '#joyful', '#interesting', 0.544, 'large_business', 'business_organization', 'partnership', 'business_firm', 'company']
senticnet['big_car'] = [0.028, 0, 0.013, 0.061, '#joyful', '#admirable', 0.025, 'truck', 'vehicle', 'limousine', 'car', 'lorry']
senticnet['big_car_accident'] = [-0.921, 0, 0.833, -0.973, '#sad', '#disgusting', -0.909, 'accident', 'drive_fast', 'car_accident', 'miss_red_light', 'break_rule']
senticnet['big_cat'] = [0.028, 0, 0.013, 0.061, '#joyful', '#admirable', 0.025, 'cute_cat', 'domesticate_animal', 'cat', 'big_animal', 'big']
senticnet['big_cheese'] = [0.979, -0.692, 0, 0.576, '#joyful', '#surprising', 0.749, 'knocker', 'supremo', 'important_person', 'influential_person', 'personage']
senticnet['big_christmas_tree'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'holiday', 'jingles', 'tree', 'festive_season', 'christmas']
senticnet['big_city'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'newyork', 'london', 'beijing', 'rome', 'tokyo']
senticnet['big_city_life'] = [0, -0.011, 0.046, -0.052, '#angry', '#disgusting', -0.029, 'pressure', 'busy', 'system', 'fast_pace', 'subway']
senticnet['big_country'] = [0.039, 0, 0, 0.053, '#joyful', '#admirable', 0.031, 'china', 'democratic_country', 'free_country', 'unite', 'russia']
senticnet['big_deal'] = [-0.048, 0.198, -0.133, 0.185, '#interesting', '#admirable', 0.067, 'do_something', 'important_thing', 'factory_output', 'creation', 'make_happen']
senticnet['big_dog'] = [0.731, 0, 0, 0.843, '#joyful', '#admirable', 0.525, 'breed', 'domestic_pet', 'smart_dog', 'wild_wolf', 'fierce']
senticnet['big_enchilada'] = [0.571, -0.689, 0, 0.769, '#surprising', '#admirable', 0.676, 'knocker', 'supremo', 'important_person', 'influential_person', 'personage']
senticnet['big_event'] = [0.838, 0.75, 0, 0.708, '#joyful', '#interesting', 0.765, 'festival', 'party', 'banquet', 'marketplace', 'rock_concert']
senticnet['big_eye'] = [0, 0.105, 0, 0, '#interesting', '#interesting', 0.035, 'beak', 'many_feathers', 'predator', 'bird', 'eagle']
senticnet['big_fight'] = [-0.087, 0, -0.085, -0.179, '#sad', '#disgusting', -0.117, 'conflict', 'combat', 'battle', 'war', 'siege']
senticnet['big_fire'] = [-0.025, -0.012, -0.078, -0.124, '#scared', '#disgusting', -0.072, 'grow_yard', 'stain_clothes', 'burn', 'set_on_fire', 'chemical_process']
senticnet['big_fish'] = [-0.049, 0.184, -0.085, 0.172, '#interesting', '#admirable', 0.074, 'fish', 'animal', 'big_animal', 'big_cat', 'big']
senticnet['big_game'] = [-0.049, 0.184, -0.085, 0.172, '#interesting', '#admirable', 0.074, 'winner_loser', 'passive', 'competitive', 'fun', 'profitable']
senticnet['big_glasses'] = [-0.964, 0, 0, -0.715, '#sad', '#disgusting', -0.56, 'nerd', 'wear_glasses', 'computer_lover', 'geek', 'blind']
senticnet['big_group'] = [0.066, 0.069, 0, 0.086, '#interesting', '#admirable', 0.074, 'multitude', 'clique', 'several_people', 'large_group', 'group']
senticnet['big_gun'] = [-0.031, -0.016, 0, -0.163, '#sad', '#disgusting', -0.059, 'weapon', 'cannon', 'firearm', 'machine_gun', 'handgun']
senticnet['big_guy'] = [0.034, 0.066, 0, 0, '#joyful', '#interesting', 0.033, 'strong_person', 'strength', 'fearless', 'wrestler', 'body_building']
senticnet['big_hat'] = [0.038, 0.079, 0.03, 0.083, '#interesting', '#admirable', 0.057, 'hat', 'country_side', 'large_area', 'rural_area', 'farm_area']
senticnet['big_heavy'] = [0.026, 0.141, 0.031, 0.2, '#interesting', '#admirable', 0.112, 'really_big', 'large', 'big', 'huge', 'massive']
senticnet['big_home'] = [0.231, 0, 0, 0.109, '#joyful', '#admirable', 0.113, 'watch_comedy', 'dinner_party', 'opera', 'family_activity', 'anarchy']
senticnet['big_house'] = [0, 0.105, 0, 0.076, '#interesting', '#admirable', 0.06, 'palace', 'mansion', 'castle', 'bungalow', 'terrace']
senticnet['big_issue'] = [-0.972, 0, 0.7, -0.964, '#sad', '#disgusting', -0.879, 'issue', 'difficult', 'complicated', 'terrorist_attack', 'problem']
senticnet['big_lake'] = [-0.03, 0.085, 0, 0.127, '#interesting', '#admirable', 0.061, 'small_stream', 'riverside', 'reservoir', 'dam', 'oceanside']
senticnet['big_land'] = [0, 0.07, 0.018, 0.069, '#interesting', '#admirable', 0.04, 'large_land', 'country_area', 'land_area', 'large_area', 'land']
senticnet['big_meal'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'size_up', 'upsize', 'big_size', 'big', 'quantity']
senticnet['big_mistake'] = [-0.561, 0.156, -0.431, 0.122, '#sad', '#scared', -0.238, 'bad_behavior', 'hard_to_define', 'treatable', 'harmful_human', 'mock']
senticnet['big_money'] = [0.223, 0, 0.055, 0.157, '#joyful', '#admirable', 0.108, 'part_of_team', 'prove_oneself', 'athletic', 'increase_strength', 'keep_fit']
senticnet['big_monster'] = [-0.344, 0, -0.391, -0.096, '#sad', '#scared', -0.277, 'caution', 'unsafe', 'psychoneurosis', 'severe_pain', 'anxiety_disorder']
senticnet['big_monument'] = [0.034, 0.13, -0.083, 0.258, '#interesting', '#admirable', 0.113, 'tourism', 'nice_view', 'tourist_attraction', 'temple', 'sightsee']
senticnet['big_mouse'] = [-0.139, 0, 0.013, -0.081, '#sad', '#disgusting', -0.078, 'mouse', 'dig_tunnel', 'underground_animal', 'rat', 'small_rodent']
senticnet['big_mouth'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'piece_of_meat', 'flavorful', 'choose_eat', 'mouth', 'masticate']
senticnet['big_muscle'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'increase_metabolism', 'feel_fit', 'become_healthy', 'exercise', 'weight_lift']
senticnet['big_paycheck'] = [0.163, 0.142, 0.024, 0.184, '#joyful', '#admirable', 0.155, 'self_confidence', 'look_beautiful', 'take_out_loan', 'down_payment', 'much_money']
senticnet['big_person'] = [0, 0.073, 0.009, 0.122, '#interesting', '#admirable', 0.062, 'smart_animal', 'person', 'domestic_animal', 'human', 'large_breadbox']
senticnet['big_place'] = [0.034, 0.09, 0.021, 0.186, '#interesting', '#admirable', 0.096, 'location', 'place', 'area', 'big', 'tourist_attraction']
senticnet['big_problem'] = [-0.176, 0, -0.204, 0, '#sad', '#scared', -0.127, 'radiation', 'big_issue', 'problem', 'calamity', 'difficult_problem']
senticnet['big_rat'] = [-0.721, 0, -0.825, -0.841, '#scared', '#disgusting', -0.796, 'helpless', 'unwanted', 'rabies', 'small_cat', 'freckle']
senticnet['big_road'] = [0, -0.025, 0.038, -0.079, '#angry', '#disgusting', -0.031, 'expressway', 'repair_shop', 'yellow_line', 'car_workshop', 'schoolyard']
senticnet['big_rock'] = [0.057, 0.075, 0.039, 0.059, '#interesting', '#admirable', 0.051, 'summit', 'cliff', 'high_land', 'peak', 'mountain_side']
senticnet['big_shot'] = [0.925, -0.522, 0, 0.691, '#joyful', '#admirable', 0.713, 'knocker', 'supremo', 'important_person', 'influential_person', 'personage']
senticnet['big_size'] = [0, 0.14, 0.06, 0.237, '#interesting', '#admirable', 0.106, 'size_up', 'upsize', 'big_meal', 'big', 'quantity']
senticnet['big_stick'] = [0.134, -0.112, 0.066, 0.054, '#joyful', '#surprising', 0.078, 'wooden_stick', 'long_stick', 'tree_limb', 'tree_part', 'twig']
senticnet['big_tooth'] = [0, -0.01, 0.041, -0.065, '#angry', '#disgusting', -0.032, 'long_tooth', 'fang', 'tail', 'sharp_tooth', 'animal_part']
senticnet['big_tree'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'tree', 'evergreen_tree', 'christmas_tree', 'tree_item', 'christmas']
senticnet['big_wheel'] = [0.749, -0.973, 0, 0.992, '#surprising', '#admirable', 0.905, 'knocker', 'supremo', 'important_person', 'influential_person', 'personage']
senticnet['bigamy'] = [-0.875, 0, 0.524, -0.762, '#sad', '#disgusting', -0.72, 'marriage', 'matrimony', 'union', 'spousal_relationship', 'wedlock']
senticnet['bigger_than_usual'] = [-0.762, 0, 0.571, -0.847, '#sad', '#disgusting', -0.727, 'hypertrophy', 'giantism', 'disease', 'overgrowth', 'feel_pain']
senticnet['bigmouthed'] = [-0.925, 0, 0.876, -0.963, '#sad', '#disgusting', -0.921, 'indiscreet', 'blabby', 'blabbermouthed', 'talkative', 'imprudent']
senticnet['bigot'] = [-0.214, 0, -0.198, -0.189, '#sad', '#scared', -0.2, 'censorship', 'bad_word', 'kidnap', 'intolerance', 'hurt_other_person']
senticnet['bigotry'] = [0, 0, 0.854, -0.857, '#angry', '#disgusting', -0.57, 'fight_enemy', 'conquer_nation', 'destroy_enemy', 'genocide', 'wage_war']
senticnet['bike'] = [0.05, -0.043, 0, 0, '#joyful', '#surprising', 0.031, 'have_fun', 'motorcycle', 'roller_coaster', 'sports_car', 'scooter']
senticnet['bikini'] = [0.819, -0.782, 0, 0, '#joyful', '#surprising', 0.534, 'swimming_costume', 'storage_item', 'jeans', 'pair_of_pants', 'dirty_magazine']
senticnet['bikini_pants'] = [0.845, 0.962, 0, 0, '#joyful', '#interesting', 0.602, 'bikini', 'pants', 'underpants', 'bloomers', 'swimming_costume']
senticnet['bilge'] = [-0.549, 0, 0.845, -0.955, '#angry', '#disgusting', -0.783, 'face', 'base', 'underbelly', 'sole', 'underside']
senticnet['biliousness'] = [-0.598, 0, 0.911, -0.831, '#angry', '#disgusting', -0.78, 'querulousness', 'peevishness', 'pettishness', 'snappishness', 'surliness']
senticnet['bilk'] = [0, 0, -0.805, -0.749, '#scared', '#disgusting', -0.518, 'thwart', 'spoil', 'queer', 'foil', 'scotch']
senticnet['bill'] = [-0.033, 0.249, -0.065, 0.102, '#interesting', '#admirable', 0.084, 'yellowstone', 'invoice', 'expense', 'owe', 'mastercard']
senticnet['bill_pay'] = [-0.139, 0.251, -0.131, 0.146, '#interesting', '#admirable', 0.042, 'give_cash', 'owe_money', 'send_money', 'money_exchange', 'money']
senticnet['billboard'] = [0.704, 0.815, 0, 0, '#joyful', '#interesting', 0.506, 'advertisement', 'large_outdoor_board', 'motorway', 'expressway', 'train_track']
senticnet['billfold'] = [0, 0.149, 0, 0, '#interesting', '#interesting', 0.05, 'wallet', 'piggy_bank', 'coffer', 'bank_vault', 'credit_card_wallet']
senticnet['billiards'] = [-0.035, 0.085, -0.077, 0.114, '#interesting', '#admirable', 0.029, 'many_games', 'poker', 'form_of_gambling', 'card_game', 'backgammon']
senticnet['billingsgate'] = [-0.896, 0, 0.554, -0.713, '#sad', '#disgusting', -0.721, 'abuse', 'vilification', 'insult', 'revilement', 'contumely']
senticnet['billion'] = [0.787, -0.527, 0, 0.806, '#joyful', '#admirable', 0.707, 'gross', 'century', 'grand', 'million', 'large_integer']
senticnet['billowing'] = [0, 0, -0.898, -0.806, '#scared', '#disgusting', -0.568, 'heave', 'inflate', 'balloon', 'surge', 'wallow']
senticnet['bin'] = [0, -0.023, 0, 0.051, '#surprising', '#admirable', 0.025, 'cardboard_box', 'bag', 'package', 'box_cereal', 'box']
senticnet['binary_star'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'giant', 'variable', 'supernova', 'supergiant', 'star']
senticnet['bind'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'keep_paper_together', 'fasten', 'frighten_person', 'carry_paper', 'beatles_song']
senticnet['bind_agreement'] = [0, 0.104, -0.046, 0.092, '#interesting', '#admirable', 0.05, 'earn_money', 'need_earn_money', 'support_family', 'responsible', 'ask_money']
senticnet['bind_book'] = [-0.063, 0, 0.013, 0, '#sad', '#angry', -0.025, 'dry_hair', 'refrigerate', 'scrub_floor', 'remove_paint', 'mow_grass']
senticnet['bind_paper_together'] = [0.025, 0.083, 0, 0.06, '#interesting', '#admirable', 0.056, 'organize_document', 'carry_document', 'keep_paper_together', 'carry_paper', 'store_document']
senticnet['bind_together'] = [0.026, 0.078, 0, 0.214, '#interesting', '#admirable', 0.106, 'fasten_two_objects_together', 'hold_together', 'build_bridge', 'hold_object', 'tow']
senticnet['binge'] = [-0.702, 0, 0.704, -0.552, '#sad', '#angry', -0.653, 'whoopee', 'merrymaking', 'jollification', 'revel', 'riot']
senticnet['binoculars'] = [0, -0.028, 0.048, -0.058, '#angry', '#disgusting', -0.026, 'telescope', 'read_glass', 'eyeglass', 'camera', 'monocle']
senticnet['biodegradable'] = [0.085, 0, 0.035, 0.147, '#joyful', '#admirable', 0.066, 'soft', 'material_type', 'fabric_type', 'type_of_cloth', 'cloth_fabric']
senticnet['bioethics'] = [0.601, -0.846, 0, 0.872, '#surprising', '#admirable', 0.773, 'moral_philosophy', 'hedonism', 'philosophy', 'casuistry', 'eudemonism']
senticnet['biography'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'literature', 'bed_time_story', 'book_story', 'fiction', 'non_fiction']
senticnet['biohazard_suit'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'wear', 'protective_garment', 'coverall', 'shoulder_pad', 'wearable']
senticnet['biological_group'] = [-0.96, 0, 0.556, -0.872, '#sad', '#disgusting', -0.796, 'animal_group', 'group', 'genotype', 'clade', 'taxonomic_group']
senticnet['biological_machine'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'machine', 'social_creature', 'live_creature', 'live_object', 'alive']
senticnet['biology'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'college_major', 'geology', 'physic', 'chemistry', 'subject_school']
senticnet['biology_book'] = [0, -0.131, -0.053, 0.08, '#surprising', '#admirable', 0.053, 'science', 'school', 'student', 'study_material', 'study_of_life']
senticnet['bioluminescence'] = [-0.925, 0, 0.734, -0.51, '#sad', '#angry', -0.723, 'chemiluminescence', 'light', 'luminescence', 'visible_light', 'visible_radiation']
senticnet['biome'] = [-0.739, 0, 0.59, -0.893, '#sad', '#disgusting', -0.741, 'desert', 'grassland', 'forest', 'woodland', 'timberland']
senticnet['bionergy'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'tough', 'wild_plant', 'vitality', 'wild_flower', 'nature']
senticnet['biopsy'] = [0.747, -0.581, 0, 0.92, '#joyful', '#admirable', 0.749, 'assay', 'diagnostic_assay', 'cloze_procedure', 'cloze_test', 'fecal_occult_test']
senticnet['biped'] = [0.041, 0, 0, 0.058, '#joyful', '#admirable', 0.033, 'human', 'bird_animal', 'farm_bird', 'barnyard_animal', 'hen_baby']
senticnet['bipolar_disorder'] = [-0.975, 0, 0.793, -0.688, '#sad', '#angry', -0.819, 'affective_disorder', 'major_affective_disorder', 'emotional_disorder', 'emotional_disturbance', 'cyclothymia']
senticnet['birch'] = [0.043, -0.04, 0, 0, '#joyful', '#surprising', 0.028, 'willow', 'cedar', 'oak', 'elm', 'lumber']
senticnet['bird'] = [-0.541, 0, 0.811, -0.516, '#sad', '#angry', -0.623, 'bird_of_prey', 'raptor', 'raptorial_bird', 'parrot', 'cock']
senticnet['bird_animal'] = [0.041, 0, 0, 0.058, '#joyful', '#admirable', 0.033, 'feather', 'wings', 'farm_bird', 'barnyard_animal', 'hen_baby']
senticnet['bird_droppings'] = [0, -0.01, 0.041, -0.065, '#angry', '#disgusting', -0.032, 'bad_luck', 'nature', 'slate', 'feces', 'unhealthy']
senticnet['bird_fly'] = [0.753, 0.908, 0, 0, '#joyful', '#interesting', 0.554, 'atmosphere', 'wings', 'nest', 'feather', 'flight']
senticnet['bird_food'] = [0, 0, 0.064, -0.04, '#angry', '#disgusting', -0.035, 'calyx', 'funiculus', 'plant_product', 'fuzz', 'agricultural_product']
senticnet['bird_group'] = [0.048, 0.095, 0, 0.087, '#interesting', '#admirable', 0.077, 'bird', 'team_up', 'group_of_people', 'group', 'social_group']
senticnet['bird_home'] = [0, -0.06, 0.022, 0.054, '#surprising', '#admirable', 0.031, 'hold_egg', 'baby_bird', 'hatch', 'lay_egg', 'wild_bird']
senticnet['bird_mouth'] = [0, 0.105, 0, 0, '#interesting', '#interesting', 0.035, 'beak', 'many_feathers', 'big_eye', 'bird', 'eagle']
senticnet['bird_of_prey'] = [-0.81, 0, 0.913, -0.858, '#angry', '#disgusting', -0.86, 'bird', 'hawk', 'eagle', 'vulture', 'secretary_bird']
senticnet['bird_pet'] = [0.03, 0.085, 0, 0, '#joyful', '#interesting', 0.038, 'favorite_color', 'pet', 'different_color', 'pink', 'color_red']
senticnet['bird_prey'] = [-0.03, -0.029, 0.027, -0.109, '#sad', '#disgusting', -0.046, 'crow', 'eagle', 'hawk', 'raven', 'bird_type']
senticnet['bird_type'] = [-0.03, -0.029, 0.027, -0.109, '#sad', '#disgusting', -0.046, 'crow', 'dove', 'water_bird', 'bird_prey', 'raven']
senticnet['bird_watch'] = [0.885, 0, 0, 0, '#joyful', '#joyful', 0.295, 'catch_ball', 'swim_lake', 'experience_fear', 'field_ball', 'toss_ball']
senticnet['bird_watcher'] = [-0.982, 0, 0.937, -0.689, '#sad', '#angry', -0.869, 'ornithology', 'ornithologist', 'hobby', 'naturalist', 'amateur']
senticnet['birdbrain'] = [-0.997, 0, 0.804, -0.523, '#sad', '#angry', -0.775, 'addlehead', 'misfit', 'ape', 'loon', 'mortal']
senticnet['birth'] = [0.95, 0, 0, 0, '#joyful', '#joyful', 0.317, 'born', 'new_baby', 'birthday', 'thanksgiving', 'anniversary']
senticnet['birth_certificate'] = [0.931, -0.526, 0, 0.67, '#joyful', '#admirable', 0.709, 'document', 'certificate_of_incorporation', 'credential', 'diploma', 'sheepskin']
senticnet['birth_control'] = [-0.035, 0.066, -0.106, -0.088, '#scared', '#disgusting', -0.054, 'gland', 'cure_illness', 'trip_acid', 'sickness', 'determine_health']
senticnet['birth_control_pill'] = [0.799, 0.858, 0, 0, '#joyful', '#interesting', 0.552, 'contraceptive_device', 'condom', 'medicine', 'pillow_case', 'sex']
senticnet['birth_defect'] = [-0.917, 0, 0.961, -0.556, '#sad', '#angry', -0.811, 'hypopigmentation', 'albinism', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder']
senticnet['birth_stone'] = [0, 0.861, 0, 0.968, '#interesting', '#admirable', 0.61, 'sapphire', 'turquoise', 'amethyst', 'gemstone', 'precious_stone']
senticnet['birth_trauma'] = [-0.917, 0, 0.961, -0.556, '#sad', '#angry', -0.811, 'psychic_trauma', 'psychological_state', 'psychological_condition', 'mental_state', 'mental_condition']
senticnet['birthday'] = [0.863, 0, 0, 0.878, '#joyful', '#admirable', 0.58, 'christmas', 'occasion', 'new_baby', 'holiday', 'anniversary']
senticnet['birthday_cake'] = [0.875, 0, 0, 0, '#joyful', '#joyful', 0.292, 'cake_candle', 'occasion', 'festivity', 'birthday', 'special_day']
senticnet['birthday_candle'] = [0.73, 0, 0, 0, '#joyful', '#joyful', 0.243, 'birthday_treat', 'birthday_surprise', 'cover_ice', 'birthday_wedding', 'layer']
senticnet['birthday_card'] = [0.051, 0, 0, 0.072, '#joyful', '#admirable', 0.041, 'letter_slot', 'postcard', 'postage_stamp', 'birthday', 'graphical_representation']
senticnet['birthday_gift'] = [0.994, 0.93, 0, 0.789, '#joyful', '#interesting', 0.904, 'present', 'holiday', 'gift', 'surprise', 'birthday']
senticnet['birthday_party'] = [0.901, -0.901, 0, 0, '#joyful', '#surprising', 0.601, 'special_happen', 'special_moment', 'festivity', 'occasion', 'party']
senticnet['birthday_present'] = [0.989, 0.733, 0, 0.91, '#joyful', '#admirable', 0.877, 'batter', 'collectible', 'treat', 'cover_ice', 'round_pastry']
senticnet['birthday_suit'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'surprise', 'sexy', 'gift', 'nude', 'undress']
senticnet['birthday_surprise'] = [0.894, -0.732, 0, 0, '#joyful', '#surprising', 0.542, 'surprise', 'birthday_treat', 'cover_ice', 'round_pastry', 'bake_goods']
senticnet['birthday_treat'] = [0.942, -0.882, 0, 0, '#joyful', '#surprising', 0.608, 'birthday_surprise', 'surprise', 'cover_ice', 'round_pastry', 'bake_goods']
senticnet['birthday_wed'] = [0.128, -0.119, 0, 0.085, '#joyful', '#surprising', 0.111, 'birthday_surprise', 'birthday_treat', 'cover_ice', 'round_pastry', 'birthday']
senticnet['birthday_wedding'] = [0.73, 0, 0, 0, '#joyful', '#joyful', 0.243, 'birthday_treat', 'birthday_surprise', 'cover_ice', 'birthday_candle', 'layer']
senticnet['bis'] = [0, 0.173, 0.021, 0.223, '#interesting', '#admirable', 0.125, 'plus', 'twice', 'sequence', 'redo', 'one_more']
senticnet['biscuit'] = [0.023, -0.078, 0, 0, '#joyful', '#surprising', 0.034, 'pudding', 'cookie', 'chocolate', 'custard', 'bagel']
senticnet['bishop'] = [0.023, 0.218, 0, 0.223, '#interesting', '#admirable', 0.155, 'pastor', 'church_head', 'protestant', 'monk', 'minister']
senticnet['bit'] = [0.654, -0.571, 0, 0.898, '#joyful', '#admirable', 0.708, 'routine', 'showstopper', 'number', 'act', 'turn']
senticnet['bitchiness'] = [-0.945, 0, 0.897, -0.932, '#sad', '#disgusting', -0.925, 'cattiness', 'malevolency', 'spitefulness', 'cruelness', 'evil']
senticnet['bitchy'] = [-0.887, 0, 0.864, -0.725, '#sad', '#angry', -0.825, 'vixenish', 'venomous', 'malicious', 'catty', 'cattish']
senticnet['bite'] = [0, 0, 0.876, -0.7, '#angry', '#disgusting', -0.525, 'sting', 'tidbit', 'nip', 'tiny_amount', 'piece']
senticnet['bite_dog'] = [0, 0, -0.941, -0.904, '#scared', '#disgusting', -0.615, 'eight_legs', 'dog_hair', 'parasite', 'dog_fur', 'bedbug']
senticnet['bite_food'] = [0.854, 0.659, 0, 0.545, '#joyful', '#interesting', 0.686, 'teeth', 'obtain_food', 'find_restaurant', 'order_lunch', 'decide_eat']
senticnet['bite_nail'] = [-0.253, 0, -0.267, -0.122, '#sad', '#scared', -0.214, 'addiction', 'feel_sad', 'see_light', 'vomit', 'put_box']
senticnet['bite_tongue'] = [-0.159, -0.051, -0.083, -0.125, '#sad', '#disgusting', -0.105, 'tongue', 'choke', 'no_long_hungry', 'spill', 'digest']
senticnet['bitter'] = [-0.707, 0, 0.518, -0.514, '#sad', '#angry', -0.58, 'change_taste', 'modify', 'acidulate', 'acidify', 'acetify']
senticnet['bitter_aloe'] = [0.722, -0.606, 0, 0.596, '#joyful', '#surprising', 0.641, 'medicament', 'medicinal_drug', 'medication', 'aloe', 'cathartic']
senticnet['bitterness'] = [0, 0, 0, -0.875, '#disgusting', '#disgusting', -0.292, 'grievance', 'heartburning', 'enviable', 'grudging', 'enviably']
senticnet['bitumastic'] = [-0.944, 0, 0.569, -0.721, '#sad', '#disgusting', -0.745, 'coating', 'veneer', 'veneering', 'lacquer', 'seal']
senticnet['blabber'] = [-0.982, 0, 0.93, -0.506, '#sad', '#angry', -0.806, 'fink', 'snitch', 'snitcher', 'sneak', 'stoolpigeon']
senticnet['blabbermouth'] = [-0.804, 0, 0.56, -0.608, '#sad', '#disgusting', -0.657, 'gossip', 'gossiper', 'gossipmonger', 'talk_too_much', 'rumormonger']
senticnet['blabbermouthed'] = [-0.607, 0, 0.523, -0.959, '#sad', '#disgusting', -0.696, 'communicatory', 'expansive', 'heraldic', 'talkative', 'leaky']
senticnet['blabby'] = [-0.925, 0, 0.876, -0.963, '#sad', '#disgusting', -0.921, 'bigmouthed', 'indiscreet', 'blabbermouthed', 'talkative', 'imprudent']
senticnet['black'] = [-0.604, 0, 0.895, -0.541, '#sad', '#angry', -0.68, 'coal_black', 'jet_black', 'pitch_black', 'soot_black', 'achromatic_color']
senticnet['black_art'] = [-0.845, 0, 0.833, -0.663, '#sad', '#angry', -0.78, 'magic', 'thaumaturgy', 'enchantment', 'witchcraft', 'witchery']
senticnet['black_body'] = [0.566, -0.553, 0, 0.776, '#joyful', '#admirable', 0.632, 'whole', 'natural_object', 'blackbody', 'full_radiator', 'stone']
senticnet['black_bread'] = [0.52, -0.693, 0, 0.639, '#surprising', '#admirable', 0.617, 'rye_bread', 'pumpernickel', 'limpa', 'bread', 'breadstuff']
senticnet['black_dot'] = [-0.027, 0, 0.048, 0, '#sad', '#angry', -0.025, 'furry_creature', 'skin_impurity', 'big_mouse', 'underground_animal', 'small_rodent']
senticnet['black_dress'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'sexy', 'elegant', 'classy', 'slim', 'lady_like']
senticnet['black_eye'] = [0, 0, 0.974, -0.941, '#angry', '#disgusting', -0.638, 'broken_finger', 'schizophrenia', 'bloody_nose', 'complication', 'censorship']
senticnet['black_goo'] = [0.024, 0.073, 0, 0.101, '#interesting', '#admirable', 0.066, 'polish', 'black_liquid', 'greasy', 'slick', 'slippery']
senticnet['black_green'] = [-0.047, 0.079, 0, 0.073, '#interesting', '#admirable', 0.035, 'red_green', 'red_orange', 'spectrum', 'yellow_green', 'red_blue']
senticnet['black_gum'] = [-0.605, 0, 0.787, -0.909, '#angry', '#disgusting', -0.767, 'pain', 'tooth_disease', 'need_dentist', 'discomfort', 'ugly_smile']
senticnet['black_liquid'] = [-0.119, 0, -0.089, 0, '#sad', '#scared', -0.069, 'black_water', 'dirt', 'energy_source', 'dark_liquid', 'greasy']
senticnet['black_locust'] = [-0.856, 0, 0.5, -0.709, '#sad', '#disgusting', -0.688, 'courbaril', 'water_locust', 'swamp_locust', 'honey_locust', 'locust_tree']
senticnet['black_magic'] = [-0.728, 0, 0.759, -0.878, '#angry', '#disgusting', -0.788, 'magic', 'thaumaturgy', 'enchantment', 'witchcraft', 'witchery']
senticnet['black_mallee'] = [-0.605, 0, 0.787, -0.909, '#angry', '#disgusting', -0.767, 'white_mallee', 'congoo_mallee', 'mallee', 'black_sally', 'snake']
senticnet['black_pavement'] = [0, 0, 0.078, 0, '#angry', '#angry', -0.026, 'street_city', 'small_street', 'walkway', 'pave', 'dark_road']
senticnet['black_rockweed'] = [-0.896, 0, 0.556, -0.726, '#sad', '#disgusting', -0.726, 'fucus', 'bladderwrack', 'rockweed', 'bladder_fucus', 'tang']
senticnet['black_root_rot_fungus'] = [-0.872, 0, 0.723, -0.946, '#sad', '#disgusting', -0.847, 'potato_wart_fungus', 'bottom_rot_fungus', 'potato_fungus', 'fungus', 'sclerotinia']
senticnet['black_sally'] = [-0.605, 0, 0.787, -0.909, '#angry', '#disgusting', -0.767, 'white_mallee', 'congoo_mallee', 'black_mallee', 'mallee', 'black_gum']
senticnet['black_sheep'] = [-0.515, 0, 0.571, -0.593, '#angry', '#disgusting', -0.56, 'scapegrace', 'miscreant', 'degenerate', 'wretch', 'pervert']
senticnet['black_snakeroot'] = [-0.524, 0, 0.527, -0.782, '#angry', '#disgusting', -0.611, 'herb', 'fairy_candle', 'actaea_racemosa', 'black_bugbane', 'black_cohosh']
senticnet['black_stuff'] = [-0.74, 0, 0, -0.983, '#sad', '#disgusting', -0.574, 'ethnicity', 'paint_nail', 'black_teeth', 'burnt', 'racism']
senticnet['black_treacle'] = [-0.089, 0.106, 0, 0.125, '#interesting', '#admirable', 0.047, 'sugar', 'tracle', 'molasses', 'add_sugar', 'sugar_substitute']
senticnet['black_water'] = [-0.119, 0, -0.089, 0, '#sad', '#scared', -0.069, 'black_liquid', 'greasy', 'energy_source', 'dark_liquid', 'give_light']
senticnet['black_white'] = [0, 0.115, 0, 0.105, '#interesting', '#admirable', 0.073, 'yellow_green', 'pink', 'vintage', 'moo', 'beautiful_well_useful']
senticnet['blackball'] = [-0.687, 0, 0.923, -0.684, '#sad', '#angry', -0.765, 'negative', 'veto', 'refute', 'rebut', 'controvert']
senticnet['blackberry'] = [0, 0.772, 0, 0.952, '#interesting', '#admirable', 0.575, 'fruit', 'mobile_phone', 'drinkable', 'savory', 'eat_fruit']
senticnet['blackberry_bush'] = [-0.922, 0, 0.912, -0.942, '#sad', '#disgusting', -0.925, 'true_blackberry', 'sand_blackberry', 'dewberry', 'dewberry_bush', 'running_blackberry']
senticnet['blackbody'] = [0.566, -0.553, 0, 0.776, '#joyful', '#admirable', 0.632, 'whole', 'black_body', 'natural_object', 'full_radiator', 'stone']
senticnet['blackguard'] = [-0.555, 0, 0.947, -0.775, '#angry', '#disgusting', -0.759, 'bemock', 'deride', 'twit', 'tease', 'razz']
senticnet['blackish'] = [-0.7, 0, 0.617, -0.523, '#sad', '#angry', -0.613, 'silvery', 'achromatic', 'bluish_black', 'hueless', 'pitchy']
senticnet['blackjack'] = [0.818, 0.913, 0, 0.825, '#interesting', '#admirable', 0.852, 'greeting', 'magic_trick', 'pass_card', 'credit', 'play_magic_trick']
senticnet['blackmail'] = [0, 0, 0.968, -0.73, '#angry', '#disgusting', -0.566, 'illegal_activity', 'sell_out', 'go_bankrupt', 'deserve', 'penalty']
senticnet['blackness'] = [0, 0, -0.766, -0.906, '#scared', '#disgusting', -0.557, 'night', 'blackout', 'darkness', 'dark', 'obscure']
senticnet['blackout'] = [-0.429, 0, -0.214, -0.206, '#sad', '#scared', -0.283, 'blackness', 'darkness', 'dark', 'obscure', 'black']
senticnet['blacksmith'] = [0, 0.115, 0, 0.105, '#interesting', '#admirable', 0.073, 'farrier', 'miner', 'horseshoer', 'locksmith', 'smith']
senticnet['blackwash'] = [-0.56, 0, 0.889, -0.827, '#angry', '#disgusting', -0.759, 'calumniation', 'traducement', 'hatchet_job', 'defamation', 'calumny']
senticnet['bladder_fucus'] = [-0.896, 0, 0.556, -0.726, '#sad', '#disgusting', -0.726, 'fucus', 'bladderwrack', 'black_rockweed', 'rockweed', 'tang']
senticnet['bladder_full'] = [-0.044, 0, 0, -0.099, '#sad', '#disgusting', -0.048, 'urinate', 'go_toilet', 'go_potty', 'go_pee', 'pee']
senticnet['bladderwrack'] = [-0.896, 0, 0.556, -0.726, '#sad', '#disgusting', -0.726, 'fucus', 'rockweed', 'black_rockweed', 'bladder_fucus', 'tang']
senticnet['blade'] = [0, -0.028, 0.074, -0.095, '#angry', '#disgusting', -0.047, 'sharp_edge', 'without_space', 'knife_sharp', 'pin', 'machete']
senticnet['blade_geometry'] = [-0.04, 0.138, -0.085, 0.111, '#interesting', '#admirable', 0.041, 'geometry', 'craft', 'katana', 'blade', 'collect_item']
senticnet['blade_weapon'] = [-0.917, 0, 0.718, -0.941, '#sad', '#disgusting', -0.859, 'knife', 'blade', 'cut', 'sword', 'weapon']
senticnet['blame'] = [-0.429, 0, -0.214, -0.206, '#sad', '#scared', -0.283, 'injustice', 'put_in_jail', 'bad_feeling', 'complication', 'imprisonment']
senticnet['blameworthiness'] = [-0.985, 0, 0.657, -0.959, '#sad', '#disgusting', -0.867, 'impeachability', 'indictability', 'guiltiness', 'culpability', 'culpableness']
senticnet['bland'] = [0, 0, 0.981, -0.96, '#angry', '#disgusting', -0.647, 'uninteresting', 'no_emotion', 'boring', 'banal', 'tasteless']
senticnet['bland_diet'] = [-0.035, 0.146, -0.087, 0.208, '#interesting', '#admirable', 0.077, 'light_diet', 'soft_diet', 'spoon_food', 'diet', 'ulcer_diet']
senticnet['blandish'] = [-0.106, 0, -0.053, -0.24, '#sad', '#disgusting', -0.133, 'adulate', 'suck_up', 'toady', 'bootlick', 'kowtow']
senticnet['blank'] = [0, -0.997, 0, 0.856, '#surprising', '#admirable', 0.618, 'space', 'lacuna', 'dummy', 'clean', 'vacuous']
senticnet['blank_check'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'address_book', 'get_rich', 'ladle', 'swiss_army_knife', 'whisk']
senticnet['blank_space'] = [-0.982, 0, 0.959, -0.685, '#sad', '#angry', -0.875, 'expanse', 'margin', 'indentation', 'indention', 'indent']
senticnet['blank_stare'] = [-0.16, 0, -0.144, -0.092, '#sad', '#scared', -0.132, 'mind_boggle', 'illogical', 'emotional_response', 'epiphany', 'introspection']
senticnet['blanket'] = [0, 0.943, 0, 0, '#interesting', '#interesting', 0.314, 'duvet_cover', 'pillow', 'comforter', 'pillowcase', 'bed_sheet']
senticnet['blare'] = [-0.038, -0.05, 0.071, -0.07, '#angry', '#disgusting', -0.043, 'chamber_music', 'stressful_situation', 'make_sound', 'low_note', 'annoy_neighbor']
senticnet['blaring'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'noisy', 'noise_pollution', 'make_sound', 'shouting', 'loud']
senticnet['blasphemous'] = [0.615, -0.572, 0, 0.502, '#joyful', '#surprising', 0.563, 'aweless', 'awless', 'disrespectful', 'sacrilegious', 'irreverent']
senticnet['blast'] = [0, -0.055, -0.121, -0.126, '#scared', '#disgusting', -0.064, 'invade', 'combat', 'fight_against', 'use_military', 'lose_war']
senticnet['blastogenesis'] = [-0.778, 0, 0.764, -0.548, '#sad', '#angry', -0.697, 'pullulation', 'apomixis', 'asexual_reproduction', 'budding', 'fission']
senticnet['blatancy'] = [-0.516, 0, 0.607, -0.769, '#angry', '#disgusting', -0.631, 'offensiveness', 'odiousness', 'distastefulness', 'patency', 'obviousness']
senticnet['blatant'] = [0, 0, -0.826, -0.934, '#scared', '#disgusting', -0.587, 'clamant', 'strident', 'conspicuous', 'blazing', 'clamorous']
senticnet['blate'] = [0.691, -0.973, 0, 0.771, '#surprising', '#admirable', 0.812, 'squeal', 'let_loose', 'churr', 'honk', 'sibilate']
senticnet['bleacher'] = [0.994, -0.965, 0, 0, '#joyful', '#surprising', 0.653, 'hockey_fan', 'goalie', 'competitor', 'spectator', 'hockey_stick']
senticnet['bleaching_clay'] = [-0.71, 0, 0.704, -0.891, '#sad', '#disgusting', -0.768, 'soil', 'mire', 'dirt', 'mud', 'bleaching_earth']
senticnet['bleaching_earth'] = [-0.71, 0, 0.704, -0.891, '#sad', '#disgusting', -0.768, 'soil', 'mire', 'dirt', 'bleaching_clay', 'mud']
senticnet['bleak'] = [-0.049, -0.02, 0.062, -0.1, '#angry', '#disgusting', -0.064, 'darkness', 'dark', 'before_night', 'moon_star', 'cold_day']
senticnet['bleakness'] = [-0.934, 0, 0.508, -0.848, '#sad', '#disgusting', -0.763, 'nakedness', 'cloud', 'glumness', 'desolation', 'bareness']
senticnet['bleary'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'hazy', 'blur', 'blurry', 'blurred', 'foggy']
senticnet['bleb'] = [-0.784, 0, 0.855, -0.996, '#angry', '#disgusting', -0.878, 'blood_blister', 'pustule', 'water_blister', 'vesicle', 'cyst']
senticnet['bleed'] = [0, 0, -0.753, -0.749, '#scared', '#disgusting', -0.501, 'bloody', 'hurt', 'suffer', 'damage', 'physical_pain']
senticnet['bleeding'] = [-0.931, 0, 0.945, -0.932, '#angry', '#disgusting', -0.936, 'break_window', 'break_window_shop', 'accident', 'break_mirror', 'damage']
senticnet['blemish'] = [-0.222, -0.039, 0.026, -0.137, '#sad', '#disgusting', -0.115, 'burn_toast', 'bad_eyesight', 'water_bubble', 'dig_tunnel', 'vermin']
senticnet['blemished'] = [-0.85, 0, 0.804, -0.855, '#sad', '#disgusting', -0.836, 'scarred', 'flyblown', 'marred', 'acned', 'pimpled']
senticnet['blend'] = [0.13, 0.097, -0.077, 0.198, '#joyful', '#admirable', 0.116, 'jiggle', 'back_forth', 'vibrate', 'fuse', 'mixture']
senticnet['blender'] = [0.053, -0.067, 0, 0, '#joyful', '#surprising', 0.04, 'salad_shaker', 'store_shelf', 'kitchen_tool', 'pliers', 'ladle']
senticnet['blending'] = [-0.773, 0, 0.914, -0.501, '#sad', '#angry', -0.729, 'confluence', 'conflux', 'merging', 'homogenization', 'combination']
senticnet['blepharism'] = [-0.691, 0, 0.849, -0.717, '#angry', '#disgusting', -0.752, 'muscle_spasm', 'spasm', 'cramp', 'tic', 'twitch']
senticnet['blepharitis'] = [-0.998, 0, 0.964, -0.704, '#sad', '#angry', -0.889, 'inflammation', 'diverticulitis', 'epiglottitis', 'orchitis', 'prostatitis']
senticnet['blepharospasm'] = [-0.56, 0, 0.981, -0.676, '#angry', '#disgusting', -0.739, 'tenesmus', 'muscle_spasm', 'twitch', 'twitching', 'vellication']
senticnet['bless'] = [0.903, 0, 0, 0, '#joyful', '#joyful', 0.301, 'gospel', 'religion', 'prayer', 'faith', 'world_religion']
senticnet['blessing'] = [0.577, -0.77, 0, 0.517, '#joyful', '#surprising', 0.621, 'admiration', 'appreciation', 'reward', 'acceptation', 'support']
senticnet['blight'] = [-0.874, 0, 0.889, -0.621, '#sad', '#angry', -0.795, 'ruination', 'ruin', 'deterioration', 'devastation', 'impairment']
senticnet['blighted'] = [-0.622, 0, 0.863, -0.991, '#angry', '#disgusting', -0.825, 'spoilt', 'wrecked', 'impoverished', 'destroyed', 'extinguished']
senticnet['blighter'] = [-0.998, 0, 0.636, -0.808, '#sad', '#disgusting', -0.814, 'pest', 'dullard', 'bore', 'nudnick', 'cuss']
senticnet['blimp'] = [-0.045, 0.092, 0, 0.062, '#interesting', '#admirable', 0.036, 'hangar', 'aircraft_carrier', 'hot_air_balloon', 'war_museum', 'spaceship']
senticnet['blind'] = [-0.222, -0.039, 0.026, -0.137, '#sad', '#disgusting', -0.115, 'blind_man', 'blind_person', 'shade', 'need_help', 'shadow']
senticnet['blind_man'] = [-0.972, 0, 0.165, -0.935, '#sad', '#disgusting', -0.691, 'shade', 'need_help', 'blind', 'shadow', 'conceal']
senticnet['blind_person'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'walking_stick', 'sunglasses', 'disabled', 'poor_visual_perception', 'vision_loss']
senticnet['blind_snake'] = [-0.575, 0, 0.571, -0.975, '#sad', '#disgusting', -0.707, 'viper', 'elapid', 'elapid_snake', 'worm_snake', 'ophidian']
senticnet['blindfold'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'surprise', 'suspense', 'bandage', 'muffle', 'blindfolded']
senticnet['blindfolded'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'surprise', 'suspense', 'bandage', 'muffle', 'blindfold']
senticnet['blindness'] = [-0.131, -0.012, 0.014, -0.1, '#sad', '#disgusting', -0.078, 'big_tooth', 'fang', 'sharp_tooth', 'long_tail', 'blind']
senticnet['blindside'] = [-0.632, 0, 0.796, -0.776, '#angry', '#disgusting', -0.735, 'assail', 'profane', 'assault', 'savage', 'violate']
senticnet['blink'] = [-0.15, -0.008, 0, -0.101, '#sad', '#disgusting', -0.081, 'take_picture', 'try_understand', 'take_shit', 'point_out', 'check_mail']
senticnet['blink_eye'] = [0, 0.709, 0, 0, '#interesting', '#interesting', 0.236, 'eye_sense', 'sight', 'like_see', 'vision', 'eye_function']
senticnet['bliss'] = [0.732, 0, 0, 0.706, '#joyful', '#admirable', 0.479, 'pleasant_emotion', 'happy_emotion', 'happy_feeling', 'show_affection', 'good_emotion']
senticnet['blister'] = [-0.114, -0.086, 0.028, -0.188, '#sad', '#disgusting', -0.081, 'injury', 'contusion', 'broken_bone', 'leg_hurt', 'muscle_pain']
senticnet['blister_foot'] = [0, 0, -0.931, -0.781, '#scared', '#disgusting', -0.571, 'swelling', 'breahard', 'trip_fall', 'breafast', 'run_out_breath']
senticnet['blister_rust'] = [-0.512, 0, 0.781, -0.851, '#angry', '#disgusting', -0.715, 'flax_rust', 'flax_rust_fungus', 'rust_fungus', 'apple_rust', 'fungus']
senticnet['blistering_agent'] = [-0.903, 0, 0.529, -0.842, '#sad', '#disgusting', -0.758, 'nerve_gas', 'nerve_agent', 'mustard_gas', 'mustard_agent', 'poison_gas']
senticnet['blithely'] = [0.653, 0.635, -0.244, 0.294, '#joyful', '#interesting', 0.446, 'merrily', 'jubilantly', 'happily', 'mirthfully', 'gayly']
senticnet['blitheness'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerfully', 'cheerful', 'jolly_up', 'hearten', 'chirk_up']
senticnet['blither'] = [-0.875, 0, 0.838, -0.695, '#sad', '#angry', -0.803, 'prate', 'prattle', 'gibber', 'blabber', 'gabble']
senticnet['blizzard'] = [0, 0, -0.717, -0.904, '#scared', '#disgusting', -0.54, 'thunderstorm', 'snow_storm', 'storm', 'weather', 'rainy']
senticnet['bloat'] = [-0.735, 0, 0.94, -0.875, '#angry', '#disgusting', -0.85, 'edema', 'oedema', 'hydrops', 'dropsy', 'puffiness']
senticnet['bloated'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'fat', 'heavy_dinner', 'enlarged', 'expanded', 'bulging']
senticnet['block'] = [0, 0.857, 0, 0.77, '#interesting', '#admirable', 0.542, 'building', 'piece', 'cube', 'dice', 'ping_pong_paddle']
senticnet['block_flat'] = [0, 0.105, 0, 0.076, '#interesting', '#admirable', 0.06, 'house', 'mansion', 'high_rise_building', 'home', 'modern_home']
senticnet['block_light'] = [-0.951, 0, 0.485, -0.937, '#sad', '#disgusting', -0.791, 'shade', 'block', 'shadow', 'dark', 'blind']
senticnet['block_off'] = [-0.571, 0, 0.814, -0.805, '#angry', '#disgusting', -0.73, 'block', 'jam', 'close_up', 'obstruct', 'obturate']
senticnet['block_rain'] = [0.106, 0.162, 0.037, 0.32, '#interesting', '#admirable', 0.184, 'block_sun', 'waterproof_jacket', 'waterproof_boot', 'rain_equipment', 'umbrella']
senticnet['block_road'] = [0, 0, 0.74, -0.901, '#angry', '#disgusting', -0.547, 'roadblock', 'stop', 'block_sunlight', 'dark_area', 'cover_window']
senticnet['block_sun'] = [0, 0.071, 0, 0.078, '#interesting', '#admirable', 0.05, 'sun_cover', 'no_sun', 'cool_temperature', 'nice_day', 'overcast']
senticnet['block_sunlight'] = [0, -0.789, 0, 0.797, '#surprising', '#admirable', 0.529, 'sun_block', 'shadow', 'block_light', 'parasol', 'no_sun']
senticnet['block_up'] = [-0.794, 0, 0.925, -0.878, '#angry', '#disgusting', -0.866, 'block', 'jam', 'block_off', 'close', 'close_up']
senticnet['block_vote'] = [0.611, -0.829, 0, 0.737, '#surprising', '#admirable', 0.726, 'choice', 'option', 'veto', 'multiple_voting', 'balloting']
senticnet['blockade'] = [-0.78, 0, 0.725, -0.953, '#sad', '#disgusting', -0.819, 'assail', 'besiege', 'seal_off', 'ebb', 'attack']
senticnet['blocked'] = [-0.633, 0, 0.829, -0.794, '#angry', '#disgusting', -0.752, 'stuffiness', 'congestion', 'problem', 'traffic', 'stuck']
senticnet['blocked_artery'] = [-0.972, 0, 0.7, -0.964, '#sad', '#disgusting', -0.879, 'kill_person', 'fats', 'unhealthy_food', 'kill', 'cause_heart_disease']
senticnet['blockhead'] = [-0.911, 0, 0.723, -0.541, '#sad', '#angry', -0.725, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['blog'] = [0, 0.073, -0.059, 0.067, '#interesting', '#admirable', 0.027, 'forum', 'read_magazine', 'read_news', 'attend_meeting', 'read_book']
senticnet['bloke'] = [0, 0.914, 0, 0.901, '#interesting', '#admirable', 0.605, 'dude', 'male', 'male_person', 'man_child', 'boys']
senticnet['blonde'] = [0, 0.073, -0.059, 0.067, '#interesting', '#admirable', 0.027, 'hair_color', 'purple', 'violet', 'dark_light', 'hue']
senticnet['blood'] = [-0.041, -0.006, -0.045, -0.189, '#scared', '#disgusting', -0.09, 'skeletal_system', 'groin', 'artery', 'vein', 'body_hurt']
senticnet['blood_blister'] = [-0.784, 0, 0.855, -0.996, '#angry', '#disgusting', -0.878, 'bleb', 'pustule', 'water_blister', 'vesicle', 'cyst']
senticnet['blood_brotherhood'] = [0.589, -0.608, 0, 0.828, '#surprising', '#admirable', 0.675, 'trust', 'confidence', 'friendly_relationship', 'company', 'companionship']
senticnet['blood_disease'] = [-0.866, 0, 0.668, -0.543, '#sad', '#angry', -0.692, 'purpura', 'blood_disorder', 'disease', 'blood_problem', 'cancer']
senticnet['blood_disorder'] = [-0.866, 0, 0.668, -0.543, '#sad', '#angry', -0.692, 'blood_disease', 'purpura', 'disease', 'blood_problem', 'cancer']
senticnet['blood_eye'] = [-0.974, 0, 0.22, -0.912, '#sad', '#disgusting', -0.702, 'bad_person', 'evil_man', 'killer', 'murderer', 'evil_eye']
senticnet['blood_feud'] = [-0.866, 0, 0.668, -0.543, '#sad', '#angry', -0.692, 'conflict', 'struggle', 'battle', 'vendetta', 'feud']
senticnet['blood_fluke'] = [-0.866, 0, 0.668, -0.543, '#sad', '#angry', -0.692, 'flatworm', 'platyhelminth', 'liver_fluke', 'schistosome', 'trematode']
senticnet['blood_plasma'] = [0.611, -0.829, 0, 0.737, '#surprising', '#admirable', 0.726, 'plasma', 'cytoplasm', 'germplasm', 'nucleoplasm', 'protoplasm']
senticnet['blood_pressure'] = [-0.852, 0, -0.788, 0, '#sad', '#scared', -0.547, 'faint', 'low_blood_pressure', 'feel_sick', 'circulating_blood', 'heart']
senticnet['blood_problem'] = [-0.866, 0, 0.668, -0.543, '#sad', '#angry', -0.692, 'blood_disease', 'blood_disorder', 'disease', 'purpura', 'cancer']
senticnet['blood_test'] = [0, 0, -0.822, 0, '#scared', '#scared', -0.274, 'go_see_doctor', 'visit_doctor', 'see_doctor', 'go_doctor', 'eat_balance_diet']
senticnet['blood_type'] = [0.063, -0.038, 0, 0.121, '#joyful', '#admirable', 0.074, 'letter', 'sender', 'examine', 'card', 'blood']
senticnet['blood_typing'] = [0.818, -0.696, 0, 0.657, '#joyful', '#surprising', 0.724, 'medical_diagnosis', 'diagnosis', 'check_up', 'hospital', 'designation']
senticnet['blood_vessel'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'chest', 'artery', 'vein', 'internal_organ', 'under_head']
senticnet['bloodbath'] = [-0.671, 0, 0.938, -0.706, '#angry', '#disgusting', -0.772, 'massacre', 'mass_murder', 'carnage', 'slaughter', 'butchery']
senticnet['bloodhound'] = [0.059, 0.073, 0, 0, '#joyful', '#interesting', 0.044, 'chihuahua', 'dog', 'domesticate_dog', 'domesticate_animal', 'truffle_dog']
senticnet['bloodless'] = [-0.939, 0, 0.508, -0.582, '#sad', '#disgusting', -0.676, 'inhuman', 'nonhuman', 'apelike', 'anthropoid', 'anthropoidal']
senticnet['bloodletting'] = [-0.793, 0, 0.624, -0.614, '#sad', '#angry', -0.677, 'murder', 'slaying', 'bloodbath', 'bloodshed', 'carnage']
senticnet['bloodshed'] = [-0.976, 0, -0.936, -0.875, '#sad', '#scared', -0.929, 'siege', 'violence', 'fire_weapon', 'conflict', 'assault']
senticnet['bloodstain'] = [-0.518, 0, 0.937, -0.926, '#angry', '#disgusting', -0.794, 'discoloration', 'mud_stain', 'iron_mold', 'iron_mould', 'oil_stain']
senticnet['bloodstone'] = [-0.04, -0.021, 0.027, -0.031, '#sad', '#disgusting', -0.026, 'precious_metal', 'olympic_medal', 'shiny_metal', 'many_different_kinds', 'valuable_metal']
senticnet['bloodthirstiness'] = [-0.58, 0, 0.925, -0.632, '#angry', '#disgusting', -0.712, 'ill_nature', 'disagreeableness', 'unfriendliness', 'disposition', 'aloneness']
senticnet['bloody'] = [-0.193, 0, -0.14, -0.157, '#sad', '#disgusting', -0.163, 'hurtful', 'blood', 'gash', 'severe', 'suffer']
senticnet['bloody_nose'] = [0, 0, -0.875, -0.809, '#scared', '#disgusting', -0.561, 'broken_limb', 'fall_head', 'black_eye', 'car_wreck', 'hit_face']
senticnet['bloom'] = [0, 0.07, 0, 0.071, '#interesting', '#admirable', 0.047, 'tree_flower', 'blossom', 'perennial', 'poppy', 'greenery']
senticnet['bloomers'] = [-0.736, 0, 0.997, -0.862, '#angry', '#disgusting', -0.865, 'scanty', 'unmentionable', 'bikini_pants', 'underpants', 'pants']
senticnet['blooper'] = [-0.964, 0, 0.636, -0.673, '#sad', '#disgusting', -0.758, 'bobble', 'error', 'misstep', 'fumble', 'stumble']
senticnet['blossom'] = [0, 0.07, 0, 0.071, '#interesting', '#admirable', 0.047, 'tree_flower', 'bloom', 'perennial', 'poppy', 'greenery']
senticnet['blot'] = [-0.879, 0, 0.881, -0.731, '#sad', '#angry', -0.83, 'fingermark', 'blemish', 'mar', 'defect', 'blotch']
senticnet['blotch'] = [0.707, -0.527, 0, 0.634, '#joyful', '#admirable', 0.623, 'spot', 'smirch', 'daub', 'smudge', 'blot']
senticnet['blotter'] = [0.029, -0.033, 0.066, -0.086, '#angry', '#disgusting', -0.03, 'card_case', 'drawer', 'file_box', 'desk_tray', 'letter_scale']
senticnet['blouse'] = [0.1, -0.12, 0.05, -0.032, '#joyful', '#surprising', 0.046, 'fancy_dress', 'frill', 'fashion', 'dress', 'skirt']
senticnet['blow'] = [-0.106, 0, 0, 0, '#sad', '#sad', -0.035, 'fever', 'flu', 'blow_nose', 'cold', 'whine']
senticnet['blow_air'] = [0.116, 0.129, -0.058, 0.053, '#joyful', '#interesting', 0.08, 'move_air', 'circulate_air', 'blown', 'air_movement', 'weather_element']
senticnet['blow_away'] = [-0.105, 0, -0.052, 0, '#sad', '#scared', -0.052, 'shovel_snow', 'fly_around', 'smoke_joint', 'mine_gold', 'sit_floor']
senticnet['blow_candle'] = [0.167, -0.144, 0.015, 0.051, '#joyful', '#surprising', 0.116, 'party_time', 'special_occasion', 'birthday_surprise', 'birthday_treat', 'annual_celebration']
senticnet['blow_dryer'] = [0, 0.933, 0, 0.804, '#interesting', '#admirable', 0.579, 'wash_hair', 'hair_dryer', 'clipper', 'dry_hair', 'hair_gel']
senticnet['blow_horn'] = [-0.106, 0, 0, 0, '#sad', '#sad', -0.035, 'cast_shadow', 'cross_bridge', 'roll_downhill', 'weather_storm', 'box_ear']
senticnet['blow_nose'] = [-0.106, 0, 0, 0, '#sad', '#sad', -0.035, 'fever', 'flu', 'blow', 'cold', 'whine']
senticnet['blow_note'] = [-0.037, -0.074, 0.079, -0.124, '#angry', '#disgusting', -0.055, 'play_jazz', 'play_in_band', 'produce_musical_sound', 'play_tune', 'play_music']
senticnet['blow_off_steam'] = [0.863, -0.849, 0, 0, '#joyful', '#surprising', 0.571, 'win_loose', 'restore_energy', 'meet_new_friend', 'meet_others', 'feel_rejuvenated']
senticnet['blow_out'] = [0.75, 0.879, 0, 0, '#joyful', '#interesting', 0.543, 'light_pia_lot_of_light', 'create_light', 'burn_wood', 'burn_paper', 'heat_light']
senticnet['blow_out_candle'] = [0.891, -0.84, 0, 0, '#joyful', '#surprising', 0.577, 'surprise_friend', 'act_foolish', 'receive_gift', 'tear_paper', 'say_love']
senticnet['blow_out_match'] = [-0.083, 0, -0.088, -0.12, '#scared', '#disgusting', -0.097, 'touch_fire', 'excessive_heat', 'light_candle', 'burn_oneself', 'create_light']
senticnet['blow_out_of_water'] = [0.718, -0.882, 0, 0.83, '#surprising', '#admirable', 0.81, 'shock', 'floor', 'ball_over', 'galvanize', 'take_aback']
senticnet['blow_over'] = [-0.638, 0, 0.867, -0.57, '#sad', '#angry', -0.692, 'topple', 'flip', 'knock_down', 'fly_away', 'blow']
senticnet['blow_smoke'] = [-0.051, 0, -0.111, -0.047, '#sad', '#scared', -0.07, 'light_cigar', 'light_pipe', 'age_prematurely', 'catch_fire', 'cause_mental_illness']
senticnet['blow_thing_up'] = [-0.939, 0, 0.87, -0.979, '#sad', '#disgusting', -0.929, 'mine', 'bomb', 'weapon', 'gun', 'bullet']
senticnet['blow_up'] = [-0.083, -0.049, -0.097, -0.153, '#scared', '#disgusting', -0.095, 'shoot_target', 'target_practice', 'shoot_bullet', 'murder', 'destroy_home']
senticnet['blow_up_balloon'] = [-0.114, -0.01, -0.071, 0, '#sad', '#scared', -0.058, 'smoke_joint', 'sun_oneself', 'throw_fit', 'watch_d', 'shovel_snow']
senticnet['blower'] = [0.628, -0.967, 0, 0.682, '#surprising', '#admirable', 0.759, 'electric_fan', 'fan', 'exhaust_fan', 'punkah', 'device']
senticnet['blowfish'] = [-0.545, 0, 0.829, -0.725, '#angry', '#disgusting', -0.7, 'puffer', 'pufferfish', 'plectognath', 'triggerfish', 'filefish']
senticnet['blowhard'] = [0, 0, 0.765, -0.748, '#angry', '#disgusting', -0.504, 'boaster', 'braggart', 'vaunter', 'line-shooter', 'bragger']
senticnet['blowhole'] = [-0.935, 0, 0.607, -0.67, '#sad', '#disgusting', -0.737, 'spiracle', 'stigma', 'orifice', 'opening', 'porta']
senticnet['blowing'] = [0.783, -0.606, 0, 0.512, '#joyful', '#surprising', 0.634, 'refinement', 'processing', 'data_processing', 'development', 'developing']
senticnet['blowing_up'] = [-0.575, 0, 0.56, -0.875, '#sad', '#disgusting', -0.67, 'reprimand', 'rebuke', 'reproof', 'reproval', 'reprehension']
senticnet['blowjob'] = [0.305, 0.168, -0.103, 0.299, '#joyful', '#admirable', 0.223, 'diversity', 'prosper', 'desirable', 'a_lot_of_sex', 'cherish']
senticnet['blown'] = [-0.094, 0, 0, -0.102, '#sad', '#disgusting', -0.065, 'gape', 'blow', 'move_air', 'hurtful', 'gash']
senticnet['blown_up'] = [0, 0, -0.758, 0, '#scared', '#scared', -0.253, 'kill', 'defend_oneself', 'death_destruction', 'cause_death', 'make_war']
senticnet['blowup'] = [0.774, -0.916, 0, 0.95, '#surprising', '#admirable', 0.88, 'big_bang', 'fragmentation', 'discharge', 'backfire', 'blast']
senticnet['blubber'] = [-0.728, 0, 0.973, -0.579, '#sad', '#angry', -0.76, 'exogenous_obesity', 'corpulency', 'fat', 'embonpoint', 'stoutness']
senticnet['bludgeon'] = [0.12, -0.157, 0.032, 0.075, '#joyful', '#surprising', 0.107, 'get_attention', 'bart', 'knock', 'hook_up', 'waltz']
senticnet['blue'] = [-0.458, 0.081, -0.25, 0, '#sad', '#scared', -0.209, 'green_yellow', 'color', 'blue_green', 'cyan', 'purple']
senticnet['blue_blood'] = [0.064, 0.087, 0, 0.135, '#interesting', '#admirable', 0.095, 'kingly', 'king_queen', 'royalty', 'monarch', 'regal']
senticnet['blue_collar'] = [0, 0.108, 0, 0.127, '#interesting', '#admirable', 0.078, 'laborer', 'work_person', 'occupation', 'worker', 'land_owner']
senticnet['blue_color'] = [0, 0.108, 0, 0.127, '#interesting', '#admirable', 0.078, 'color', 'blue', 'blue_sky', 'sea', 'blue_green']
senticnet['blue_green'] = [0, 0.123, -0.067, 0.11, '#interesting', '#admirable', 0.055, 'visible', 'reflect_light', 'colorful', 'hue', 'tint']
senticnet['blue_joke'] = [0.949, -0.64, 0, 0.937, '#joyful', '#admirable', 0.842, 'joke', 'jape', 'jest', 'gag', 'laugh']
senticnet['blue_monday'] = [-0.849, 0.205, -0.484, -0.035, '#sad', '#scared', -0.388, 'depressed', 'sadness', 'bothering', 'feeling_low', 'feel_dejected']
senticnet['blue_ribbon'] = [0.064, 0.203, 0.014, 0.202, '#interesting', '#admirable', 0.152, 'compete', 'compete_against', 'score_home_run', 'play_baseball', 'play_hockey']
senticnet['blue_sky'] = [0.085, 0.071, 0.01, 0.085, '#joyful', '#admirable', 0.077, 'blue_color', 'munchkin', 'imaginary', 'crystal_clear', 'water_sky']
senticnet['blue_steel'] = [-0.809, 0, -0.972, 0, '#sad', '#scared', -0.594, 'shoe_horse', 'dig_grave', 'bicycle_across_town', 'mine_diamond', 'seed_lawn']
senticnet['blue_story'] = [0.641, -0.874, 0, 0.637, '#joyful', '#surprising', 0.717, 'joke', 'jape', 'jest', 'gag', 'laugh']
senticnet['blue_yellow'] = [-0.052, 0, 0.028, 0, '#sad', '#angry', -0.027, 'yellow_blue', 'hue', 'tint', 'red_blue', 'hue_tint']
senticnet['bluegrass_band'] = [-0.043, -0.04, -0.049, -0.046, '#scared', '#disgusting', -0.033, 'music_shop', 'music_store', 'musical_instrument_store', 'string_quartet', 'high_school_band']
senticnet['blueprint'] = [-0.037, 0.267, -0.052, 0.21, '#interesting', '#admirable', 0.129, 'plan', 'draw_blueprint', 'outline', 'forethought', 'create_form']
senticnet['blues'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'music', 'vapor', 'jazz', 'megrim', 'demoralization']
senticnet['bluetooth'] = [0, 0, 0, 0.072, '#admirable', '#admirable', 0.024, 'run_treadmill', 'complete_thesis', 'dwarf_planet', 'insure', 'ridgeback']
senticnet['bluff'] = [-0.813, 0, 0.595, -0.88, '#sad', '#disgusting', -0.763, 'deceit', 'deception', 'misrepresentation', 'pretext', 'dissembling']
senticnet['bluish_black'] = [-0.7, 0, 0.617, -0.523, '#sad', '#angry', -0.613, 'silvery', 'blackish', 'achromatic', 'hueless', 'pitchy']
senticnet['blunder'] = [-0.844, 0, 0.707, -0.758, '#sad', '#disgusting', -0.77, 'bobble', 'error', 'misstep', 'fumble', 'stumble']
senticnet['blunderer'] = [-0.773, 0, 0.503, -0.932, '#sad', '#disgusting', -0.736, 'butcher', 'fuckup', 'slouch', 'bungler', 'incompetent']
senticnet['blunt'] = [-0.043, -0.04, -0.049, -0.046, '#scared', '#disgusting', -0.033, 'blunted', 'dull', 'unsharpened', 'insensitive', 'edgeless']
senticnet['blunted'] = [-0.043, -0.04, -0.049, -0.046, '#scared', '#disgusting', -0.033, 'blunt', 'dull', 'unsharpened', 'insensitive', 'edgeless']
senticnet['blur'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'hazy', 'blurry', 'bleary', 'blurryred', 'foggy']
senticnet['blurred'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'hazy', 'blur', 'bleary', 'blurry', 'foggy']
senticnet['blurred_vision'] = [-0.722, 0, -0.894, 0, '#sad', '#scared', -0.539, 'unclear', 'dark', 'shadow', 'unseen', 'without_light']
senticnet['blurriness'] = [0.906, -0.601, 0, 0.653, '#joyful', '#admirable', 0.72, 'opaqueness', 'faintness', 'dimness', 'opacity', 'vagueness']
senticnet['blurry'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'hazy', 'blur', 'bleary', 'blurred', 'foggy']
senticnet['blush'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'embarrass', 'embarrassed', 'embarrassing', 'embarrassingly', 'embarassament']
senticnet['blushing'] = [-0.992, 0, 0.858, -0.597, '#sad', '#angry', -0.816, 'embarrassed', 'abashed', 'chagrined', 'discomposed', 'bothered']
senticnet['bluster'] = [0.957, -0.576, 0, 0.857, '#joyful', '#admirable', 0.797, 'gust', 'puff', 'sandblast', 'puff_of_air', 'whiff']
senticnet['blustery'] = [-0.91, 0, 0.521, -0.811, '#sad', '#disgusting', -0.747, 'bullying', 'peremptory', 'domineering', 'roughshod', 'cavalier']
senticnet['board'] = [0.935, 0.842, 0, 0, '#joyful', '#interesting', 0.592, 'plank', 'lumber', 'mahogany', 'hardwood', 'stump']
senticnet['board_airplane'] = [0.838, 0.936, 0, 0, '#joyful', '#interesting', 0.591, 'board_bus', 'travel', 'board_plane', 'travel_abroad', 'board_boat']
senticnet['board_boat'] = [0.838, 0.936, 0, 0, '#joyful', '#interesting', 0.591, 'travel', 'board_airplane', 'board_ship', 'board_plane', 'travel_abroad']
senticnet['board_bus'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'board_airplane', 'board_plane', 'board_boat', 'board_ship', 'travel_abroad']
senticnet['board_game'] = [0, -0.07, -0.047, 0.063, '#surprising', '#admirable', 0.029, 'yo-yo', 'playroom', 'game', 'backgammon', 'play_game']
senticnet['board_plane'] = [0.838, 0.936, 0, 0, '#joyful', '#interesting', 0.591, 'board_bus', 'travel', 'board_airplane', 'travel_abroad', 'board_boat']
senticnet['board_room'] = [0.053, 0.1, 0, 0, '#joyful', '#interesting', 0.051, 'registry_office', 'lodgings', 'telephone_booth', 'cubicle', 'reception_area']
senticnet['board_ship'] = [0.872, 0.966, 0, 0, '#joyful', '#interesting', 0.613, 'board_boat', 'visit_grandmother', 'market_product', 'bridge_difference', 'rush_job']
senticnet['board_subway_train'] = [-0.041, -0.016, 0, -0.092, '#sad', '#disgusting', -0.039, 'wait_train', 'public_transport', 'wait', 'find_end_line', 'travel']
senticnet['boardwalk'] = [-0.093, -0.028, 0, -0.09, '#sad', '#disgusting', -0.052, 'stupid_person', 'tourist', 'pass_exam', 'apple_tree', 'learn_fact']
senticnet['boast'] = [0.838, 0.936, 0, 0, '#joyful', '#interesting', 0.591, 'proud', 'glory', 'brag', 'vaunt', 'pride']
senticnet['boastfulness'] = [-0.845, 0, 0.969, -0.685, '#sad', '#angry', -0.833, 'posturing', 'swelled_head', 'egotism', 'conceitedness', 'vainglory']
senticnet['boat'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'big_boat', 'rowboat', 'large_boat', 'ship', 'sailboat']
senticnet['boat_deck'] = [0.831, -0.821, 0, 0.826, '#joyful', '#admirable', 0.826, 'deck', 'freeboard_deck', 'weather_deck', 'shelter_deck', 'upper_deck']
senticnet['boat_part'] = [0, 0.993, 0, 0.87, '#interesting', '#admirable', 0.621, 'propeller', 'hull', 'cleat', 'gunwale', 'stern']
senticnet['boat_type'] = [0, 0, 0, 0.135, '#admirable', '#admirable', 0.045, 'kayak', 'ferries', 'canoes', 'towboats', 'yachts']
senticnet['boatmanship'] = [0.764, -0.963, 0, 0.883, '#surprising', '#admirable', 0.87, 'seamanship', 'acquirement', 'skill', 'accomplishment', 'acquisition']
senticnet['bobble'] = [-0.964, 0, 0.636, -0.673, '#sad', '#disgusting', -0.758, 'blooper', 'error', 'misstep', 'fumble', 'stumble']
senticnet['bobby_pin'] = [0, -0.716, 0, 0.83, '#surprising', '#admirable', 0.515, 'barrette', 'hairpin', 'hair_dryer', 'hair_clip', 'curl_iron']
senticnet['bobcat'] = [-0.033, 0, -0.088, 0, '#sad', '#scared', -0.04, 'lion', 'leopard', 'mountain_lion', 'craven', 'wolf']
senticnet['bode'] = [0.527, -0.984, 0, 0.847, '#surprising', '#admirable', 0.786, 'auspicate', 'prefigure', 'foreshow', 'portend', 'prognosticate']
senticnet['bodge'] = [-0.786, 0, 0.915, -0.99, '#angry', '#disgusting', -0.897, 'go_wrong', 'botch_up', 'flub', 'ball_up', 'bollix']
senticnet['bodiless'] = [-0.53, 0, 0.637, -0.925, '#angry', '#disgusting', -0.697, 'discorporate', 'unembodied', 'disembodied', 'incorporeal', 'unbodied']
senticnet['bodily_cavity'] = [0.718, -0.882, 0, 0.83, '#surprising', '#admirable', 0.81, 'throat', 'pharynx', 'cavity', 'tubular_cavity', 'cavum']
senticnet['bodily_fluid'] = [0, 0, 0.025, -0.099, '#angry', '#disgusting', -0.041, 'body_fluid', 'artery', 'skeletal_system', 'cartilage', 'near_mouth']
senticnet['bodily_waste'] = [-0.041, -0.016, 0, -0.092, '#sad', '#disgusting', -0.039, 'sweat', 'feces', 'urine', 'dead_skin', 'shit']
senticnet['boding'] = [0.818, 0.856, 0, 0, '#joyful', '#interesting', 0.558, 'foreboding', 'premonition', 'presentiment', 'presage', 'timorous']
senticnet['body'] = [0.902, 0.772, 0, 0, '#joyful', '#interesting', 0.558, 'abdomen', 'two_ears', 'dog_pet', 'living_thing', 'fur']
senticnet['body_ache'] = [-0.16, 0, -0.147, -0.103, '#sad', '#scared', -0.137, 'pain', 'concern_health', 'soreness', 'injury', 'ouch']
senticnet['body_action'] = [-0.034, 0.094, -0.047, 0.142, '#interesting', '#admirable', 0.052, 'exhalation', 'body_reaction', 'mouth_action', 'bad_odor', 'push_wind']
senticnet['body_appendage'] = [0, 0.077, 0, 0.081, '#interesting', '#admirable', 0.053, 'limb', 'organ', 'tail', 'arm', 'legs']
senticnet['body_area'] = [0, 0.096, 0, 0.112, '#interesting', '#admirable', 0.069, 'body_organ', 'sensory_organ', 'body', 'sense_organ', 'human_part']
senticnet['body_armor'] = [0.939, -0.632, 0, 0.653, '#joyful', '#admirable', 0.741, 'vest', 'waistcoat', 'bulletproof_vest', 'suit_of_armor', 'coat_of_mail']
senticnet['body_building'] = [0.034, 0.066, 0, 0, '#joyful', '#interesting', 0.033, 'big_guy', 'strength', 'exercise', 'wrestler', 'strong_person']
senticnet['body_care'] = [0.903, 0.804, 0, 0, '#joyful', '#interesting', 0.569, 'hand_wash', 'hygiene', 'godliness', 'clean_agent', 'tv_drama']
senticnet['body_clean'] = [0, 0.133, 0, 0.206, '#interesting', '#admirable', 0.113, 'scrub', 'cleanse', 'use_soap', 'shower', 'clean_laundry']
senticnet['body_disease'] = [-0.365, -0.082, 0, -0.327, '#sad', '#disgusting', -0.203, 'disease', 'varicose_vein', 'need_cure', 'need_doctor', 'leg_pain']
senticnet['body_extremity'] = [0, 0.077, 0, 0.081, '#interesting', '#admirable', 0.053, 'body_member', 'body_appendage', 'body_limb', 'human_appendage', 'appendage']
senticnet['body_fluid'] = [0, 0.079, 0, 0, '#interesting', '#interesting', 0.026, 'bodily_fluid', 'near_mouth', 'mouth_part', 'artery', 'cartilage']
senticnet['body_heat'] = [-0.964, 0, 0, -0.715, '#sad', '#disgusting', -0.56, 'fever', 'sickness', 'sweat', 'heatiness', 'high_fever']
senticnet['body_hurt'] = [-0.964, 0, 0.895, -0.974, '#sad', '#disgusting', -0.944, 'accident', 'hurt', 'pain', 'injury', 'blood']
senticnet['body_language'] = [0, 0.199, -0.114, 0.317, '#interesting', '#admirable', 0.134, 'posture', 'gentleman', 'gesture', 'transmit_information', 'emotion']
senticnet['body_limb'] = [0.11, 0.209, 0, 0.238, '#interesting', '#admirable', 0.186, 'upper_hand', 'hand', 'human_appendage', 'arm_part', 'legs']
senticnet['body_lotion'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'beauty_parlor', 'lady_hair', 'beauty_shop', 'beauty_salon', 'make_up']
senticnet['body_member'] = [0, 0.077, 0, 0.081, '#interesting', '#admirable', 0.053, 'body_extremity', 'body_appendage', 'body_limb', 'human_appendage', 'appendage']
senticnet['body_movement'] = [0.044, 0.082, 0, 0.231, '#interesting', '#admirable', 0.119, 'fast_movement', 'move_action', 'vigorous_activity', 'human_movement', 'human_action']
senticnet['body_odor'] = [0, 0, 0, -0.836, '#disgusting', '#disgusting', -0.279, 'lose_team', 'lyme_disease', 'brain_tumor', 'bad_luck', 'cause_suffer']
senticnet['body_organ'] = [0, 0.068, 0, 0.097, '#interesting', '#admirable', 0.055, 'human_part', 'body_area', 'part_of_body', 'human_organ', 'sense_organ']
senticnet['body_part'] = [0.023, 0.085, -0.045, 0.088, '#interesting', '#admirable', 0.05, 'thigh', 'hip', 'joint', 'body_organ', 'knee']
senticnet['body_reaction'] = [-0.154, 0.117, -0.149, 0.083, '#sad', '#scared', -0.034, 'symptom', 'exhalation', 'physical_reaction', 'unpleasant', 'push_wind']
senticnet['body_system'] = [0.939, -0.632, 0, 0.653, '#joyful', '#admirable', 0.741, 'keep_alive', 'circulating_blood', 'body_working', 'blood_pressure', 'heart']
senticnet['body_tissue'] = [0, 0.073, 0, 0, '#interesting', '#interesting', 0.024, 'organ', 'organ_body', 'internal_organ', 'vital_organ', 'part_of_human_body']
senticnet['body_type'] = [0, 0.123, 0.051, 0.137, '#interesting', '#admirable', 0.07, 'shape', 'entire', 'human_mass', 'different_shape', 'human_part']
senticnet['body_working'] = [0.939, -0.632, 0, 0.653, '#joyful', '#admirable', 0.741, 'keep_alive', 'body_system', 'circulating_blood', 'blood_pressure', 'heart']
senticnet['bodybuilding'] = [0.072, 0.094, 0, 0.149, '#interesting', '#admirable', 0.105, 'go_to_gym', 'make_strong', 'do_exercise', 'aerobic_exercise', 'eat_healthy_food']
senticnet['bodyguard'] = [-0.993, 0, 0.877, -0.777, '#sad', '#angry', -0.882, 'yeoman', 'outrider', 'yeoman_of_guard', 'beefeater', 'defender']
senticnet['boffin'] = [0.846, -0.755, 0, 0.69, '#joyful', '#surprising', 0.764, 'experimenter', 'investigator', 'fieldworker', 'postdoc', 'post_doc']
senticnet['boggle'] = [-0.885, 0, 0.925, -0.556, '#sad', '#angry', -0.789, 'falter', 'waver', 'linger', 'hesitate', 'dwell_on']
senticnet['bohemian'] = [0.742, -0.965, 0, 0.58, '#joyful', '#surprising', 0.762, 'dissident', 'beat', 'recusant', 'maverick', 'enfant_terrible']
senticnet['boil'] = [0.054, -0.057, 0, 0.098, '#surprising', '#admirable', 0.07, 'magnetism', 'boom', 'physical_phenomenon', 'spray', 'vapor']
senticnet['boil_water'] = [0, 0.941, 0, 0.883, '#interesting', '#admirable', 0.608, 'bubble', 'steam', 'hot', 'coffee', 'tea']
senticnet['boilers_suit'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'protective_garment', 'boilersuit', 'coverall', 'overall', 'duster']
senticnet['boilersuit'] = [-0.675, 0, 0.688, -0.899, '#angry', '#disgusting', -0.754, 'protective_garment', 'coverall', 'boilers_suit', 'overall', 'duster']
senticnet['boiling'] = [-0.908, 0, 0.965, 0, '#sad', '#angry', -0.624, 'stewing', 'simmering', 'churn', 'moil', 'seethe']
senticnet['boisterous'] = [-0.642, 0, 0.941, -0.664, '#angry', '#disgusting', -0.749, 'rowdy', 'disorderly', 'unruly', 'rambunctious', 'robustious']
senticnet['bold'] = [0, 0.972, 0, 0.774, '#interesting', '#admirable', 0.582, 'courageous', 'brave', 'play_role', 'imitate', 'personality_trait']
senticnet['boldness'] = [0.775, -0.978, 0, 0.731, '#joyful', '#surprising', 0.828, 'daredevilry', 'daredeviltry', 'temerity', 'audacity', 'audaciousness']
senticnet['boll'] = [0.069, 0.112, 0, 0.167, '#interesting', '#admirable', 0.116, 'plant_material', 'clothes_material', 'natural_fiber', 'natural_fabric', 'fabric_type']
senticnet['bollix'] = [-0.786, 0, 0.915, -0.99, '#angry', '#disgusting', -0.897, 'bodge', 'botch_up', 'flub', 'ball_up', 'go_wrong']
senticnet['bolshy'] = [-0.964, 0, 0.858, -0.876, '#sad', '#disgusting', -0.899, 'contrarious', 'dogged', 'pertinacious', 'cantankerous', 'unregenerate']
senticnet['bolster'] = [0.846, -0.941, 0, 0.797, '#joyful', '#surprising', 0.861, 'strengthen', 'buttress', 'mine', 'line', 'reenforce']
senticnet['bomb'] = [0, -0.038, -0.044, -0.192, '#scared', '#disgusting', -0.066, 'nuclear_bomb', 'explosive', 'grenade', 'nuclear_weapon', 'aerial_bomb']
senticnet['bombast'] = [-0.544, 0, 0.7, -0.64, '#angry', '#disgusting', -0.628, 'flourish', 'rant', 'ornateness', 'fustian', 'claptrap']
senticnet['bomber'] = [-0.033, 0, -0.064, -0.184, '#scared', '#disgusting', -0.094, 'arsenal', 'war_zone', 'bomb', 'gun_shop', 'war']
senticnet['bombproof'] = [-0.589, 0, 0.509, -0.836, '#sad', '#disgusting', -0.645, 'burial_chamber', 'sepulcher', 'bunker', 'sepulture', 'chamber']
senticnet['bombshell'] = [0.54, -0.64, 0, 0.566, '#surprising', '#admirable', 0.582, 'pleaser', 'entertainer', 'mortal', 'busker', 'drawing_card']
senticnet['bond'] = [0.228, 0.123, -0.099, 0, '#joyful', '#interesting', 0.084, 'spend_time_with_child', 'social', 'friendship', 'companionship', 'get_close']
senticnet['bond_servant'] = [0.585, -0.698, 0, 0.909, '#surprising', '#admirable', 0.731, 'thrall', 'slave', 'bondman', 'bondsman', 'bondwoman']
senticnet['bonded_labor'] = [-0.365, -0.082, 0, -0.327, '#sad', '#disgusting', -0.203, 'thrall', 'servitude', 'serfdom', 'serfhood', 'vassalage']
senticnet['bonding'] = [0.988, -0.609, 0, 0.7, '#joyful', '#admirable', 0.766, 'indebtedness', 'personal_relation', 'obligation', 'relationship', 'human_relationship']
senticnet['bondman'] = [0.585, -0.698, 0, 0.909, '#surprising', '#admirable', 0.731, 'thrall', 'slave', 'bond_servant', 'bondsman', 'bondwoman']
senticnet['bondsman'] = [0.585, -0.698, 0, 0.909, '#surprising', '#admirable', 0.731, 'thrall', 'slave', 'bondman', 'bond_servant', 'bondwoman']
senticnet['bondwoman'] = [0.585, -0.698, 0, 0.909, '#surprising', '#admirable', 0.731, 'thrall', 'slave', 'bondman', 'bondsman', 'bond_servant']
senticnet['bone'] = [0.228, 0.123, -0.099, 0, '#joyful', '#interesting', 0.084, 'muscle', 'neck', 'shoulder', 'skeletal_system', 'bone_human']
senticnet['bone_chicken'] = [-0.084, 0, 0, -0.032, '#sad', '#disgusting', -0.039, 'salt_food', 'chicken', 'brown_hamburger', 'fry_chicken', 'make_tea']
senticnet['bone_contention'] = [-0.899, 0, -0.849, 0, '#sad', '#scared', -0.583, 'argument', 'disagreement', 'prejudice', 'opposition', 'insanity']
senticnet['bone_human'] = [0.228, 0.123, -0.099, 0, '#joyful', '#interesting', 0.084, 'muscle', 'neck', 'shoulder', 'skeletal_system', 'bone']
senticnet['bone_marrow'] = [0.73, -0.726, 0, 0.653, '#joyful', '#surprising', 0.703, 'red_marrow', 'red_bone_marrow', 'yellow_marrow', 'yellow_bone_marrow', 'connective_tissue']
senticnet['bonehead'] = [-0.682, 0, 0.533, -0.608, '#sad', '#disgusting', -0.608, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['boner'] = [-0.14, -0.009, -0.048, -0.099, '#sad', '#disgusting', -0.093, 'master_new_skill', 'sleep_bed', 'study_library', 'finish_test', 'borrow_book_from_library']
senticnet['bonfire'] = [0.1, 0, 0, 0, '#joyful', '#joyful', 0.033, 'burn_material', 'ash', 'stay_warm', 'oregano', 'campfire']
senticnet['bonheur'] = [0.611, 0.644, -0.239, 0.282, '#joyful', '#interesting', 0.433, 'gleeful', 'gladden', 'joyousness', 'joyfulness', 'gleefully']
senticnet['bonhomie'] = [0.702, -0.937, 0, 0.719, '#surprising', '#admirable', 0.786, 'sweetness_and_light', 'condescension', 'condescendingness', 'mellowness', 'friendliness']
senticnet['bonk'] = [0.702, -0.65, 0, 0.788, '#joyful', '#admirable', 0.713, 'have', 'pair', 'take', 'couple', 'fornicate']
senticnet['bonus'] = [0.785, 0, 0, 0, '#joyful', '#joyful', 0.262, 'monetary_gain', 'money_pay', 'financial_gain', 'earnings', 'compensation']
senticnet['bony'] = [0, 0, -0.767, -0.95, '#scared', '#disgusting', -0.572, 'cadaverous', 'gaunt', 'haggard', 'pinched', 'skeletal']
senticnet['bonzer'] = [0.728, -0.727, 0, 0.881, '#joyful', '#admirable', 0.779, 'howling', 'wonderful', 'wondrous', 'extraordinary', 'rattling']
senticnet['boo'] = [0, 0, -0.901, -0.864, '#scared', '#disgusting', -0.588, 'exclamation', 'thumb_down', 'complaint', 'bad', 'dislike']
senticnet['booby'] = [0.776, -0.53, 0, 0.728, '#joyful', '#admirable', 0.678, 'saphead', 'muggins', 'tomfool', 'fool', 'simpleton']
senticnet['booby_hatch'] = [-0.654, 0, 0.514, -0.696, '#sad', '#disgusting', -0.621, 'asylum', 'mental_hospital', 'psychiatric_hospital', 'mental_institution', 'mental_home']
senticnet['book'] = [-0.046, 0, -0.116, 0, '#sad', '#scared', -0.054, 'almost_always', 'many_almost_alwayss', 'almost_always_genre', 'saga', 'almost_always_poetry']
senticnet['book_appointment'] = [-0.099, 0, -0.087, -0.06, '#sad', '#scared', -0.082, 'close_together', 'feel_heat', 'book_reservation', 'wear_clothes', 'write_computer_program']
senticnet['book_bible'] = [0.031, 0.178, -0.102, 0.183, '#interesting', '#admirable', 0.097, 'omega', 'begin_end', 'first', 'issue', 'book']
senticnet['book_content'] = [0.044, 0, 0, 0.206, '#joyful', '#admirable', 0.083, 'begin_end', 'book', 'title_page', 'book_end', 'frontspiece']
senticnet['book_end'] = [0.044, 0, 0, 0.206, '#joyful', '#admirable', 0.083, 'cookbook', 'begin_end', 'good_book', 'novel', 'book']
senticnet['book_flight'] = [0, 0.882, 0, 0, '#interesting', '#interesting', 0.294, 'book_hotel_room', 'travel_by_airplane', 'board_boat', 'board_plane', 'board_airplane']
senticnet['book_genre'] = [-0.052, -0.197, -0.179, 0.219, '#surprising', '#admirable', 0.062, 'classic', 'novel', 'long_story', 'fiction', 'literature']
senticnet['book_holiday'] = [0.939, -0.632, 0, 0.653, '#joyful', '#admirable', 0.741, 'buy_new_car', 'buy_ice_cream', 'happiness', 'book_flight', 'buy_happiness']
senticnet['book_hotel'] = [0, 0.084, 0, 0, '#interesting', '#interesting', 0.028, 'reservation', 'online_booking', 'staycation', 'rate', 'currency']
senticnet['book_hotel_room'] = [0, 0.788, 0, 0.787, '#interesting', '#admirable', 0.525, 'book_flight', 'look_around', 'board_boat', 'decide_to_go_first', 'go_town']
senticnet['book_library'] = [0, 0.846, 0, 0.798, '#interesting', '#admirable', 0.548, 'vocabulary', 'read_material', 'book_genre', 'many_words', 'definition']
senticnet['book_magazine'] = [-0.056, 0.084, 0, 0.062, '#interesting', '#admirable', 0.03, 'book', 'gossip', 'beauty_section', 'fashion', 'visual_communication']
senticnet['book_newspaper'] = [0.067, 0.153, -0.054, 0.111, '#interesting', '#admirable', 0.092, 'many_pages', 'record_event', 'pen_and_paper', 'world_event', 'current_event']
senticnet['book_office'] = [0.077, 0.073, 0.013, -0.028, '#joyful', '#interesting', 0.036, 'registry_office', 'radio_studio', 'book', 'conference_auditorium', 'mezzanine']
senticnet['book_page'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'book_paper', 'book_content', 'readable', 'book_write', 'print_medium']
senticnet['book_paper'] = [0.026, 0, 0, 0.084, '#joyful', '#admirable', 0.037, 'write_material', 'thin_wood', 'book', 'paper', 'book_content']
senticnet['book_part'] = [0.053, 0, 0.025, 0.118, '#joyful', '#admirable', 0.049, 'paper_square', 'book', 'part_of_book', 'book_end', 'flat_thin']
senticnet['book_poetry'] = [0, 0.748, 0, 0.867, '#interesting', '#admirable', 0.538, 'book_genre', 'book_library', 'vocabulary', 'translation', 'thesaurus']
senticnet['book_read'] = [0.725, 0, 0, 0, '#joyful', '#joyful', 0.242, 'buy_book', 'open_book', 'choose_book', 'find_book', 'book_subject']
senticnet['book_relate'] = [0.762, 0.746, 0, 0, '#joyful', '#interesting', 0.503, 'book', 'store_knowledge', 'find_book', 'use_book', 'bookmark']
senticnet['book_reservation'] = [-0.102, 0, 0, 0, '#sad', '#sad', -0.034, 'write_computer_program', 'laugh_oneself', 'make_card', 'mind_store', 'come_house']
senticnet['book_review'] = [0.725, -0.949, 0, 0.792, '#surprising', '#admirable', 0.822, 'rave', 'literary_criticism', 'criticism', 'critique', 'notice']
senticnet['book_store'] = [0.228, 0.123, -0.099, 0, '#joyful', '#interesting', 0.084, 'book', 'shop', 'book_library', 'library', 'bookshop']
senticnet['book_story'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'literature', 'bed_time_story', 'biography', 'fiction', 'non_fiction']
senticnet['book_subject'] = [0.725, 0, 0, 0, '#joyful', '#joyful', 0.242, 'intelligence', 'buy_textbook', 'school', 'study', 'student']
senticnet['book_ticket'] = [-0.048, 0, 0.014, -0.051, '#sad', '#disgusting', -0.038, 'purchase_ticket', 'buy_ticket', 'dress_nicely', 'plan_time', 'find_out_play']
senticnet['book_token'] = [0.921, -0.571, 0, 0.962, '#joyful', '#admirable', 0.818, 'coupon', 'meal_ticket', 'luncheon_voucher', 'twofer', 'commercial_document']
senticnet['book_worm'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'nerd', 'computer_lover', 'loser', 'underdog', 'geek']
senticnet['book_write'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'book_paper', 'book_content', 'readable', 'book_page', 'print_medium']
senticnet['bookish'] = [0.71, -0.811, 0, 0.937, '#surprising', '#admirable', 0.819, 'erudite', 'donnish', 'pedantic', 'learned', 'scholarly']
senticnet['bookkeeper'] = [-0.075, 0.228, 0.019, 0.089, '#interesting', '#admirable', 0.074, 'football_coach', 'little_child', 'accountant', 'visitor', 'child']
senticnet['bookmark'] = [0.762, 0.746, 0, 0, '#joyful', '#interesting', 0.503, 'book', 'store_knowledge', 'find_book', 'use_book', 'book_relate']
senticnet['bookshop'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'book', 'shop', 'book_library', 'library', 'book_store']
senticnet['boom'] = [0.045, 0, 0, 0.088, '#joyful', '#admirable', 0.044, 'loud_sound', 'thunder', 'rain_storm', 'sound_wave', 'rain_wind']
senticnet['boomerang'] = [-0.509, 0, 0.762, -0.891, '#angry', '#disgusting', -0.721, 'error', 'fault', 'backfire', 'mistake', 'miscalculation']
senticnet['boon'] = [0.808, -0.835, 0, 0.548, '#joyful', '#surprising', 0.73, 'successfulness', 'luckiness', 'prosperity', 'circumstances', 'blessing']
senticnet['boor'] = [0, 0, -0.758, -0.906, '#scared', '#disgusting', -0.555, 'tyke', 'barbarian', 'peasant', 'churl', 'goth']
senticnet['boorish'] = [-0.9, 0, -0.997, 0, '#sad', '#scared', -0.632, 'neandertal', 'loutish', 'swinish', 'oafish', 'neanderthal']
senticnet['boost'] = [0.66, -0.853, 0, 0.744, '#surprising', '#admirable', 0.752, 'further', 'promote', 'encourage', 'conduce', 'advance']
senticnet['boot'] = [0.306, 0.228, 0, 0.087, '#joyful', '#interesting', 0.207, 'shoe', 'moccasin', 'cowboy_boot', 'casual_shoes', 'slipper']
senticnet['boot_out'] = [-0.711, 0, 0.954, -0.563, '#sad', '#angry', -0.743, 'eject', 'chuck_out', 'exclude', 'turf_out', 'evict']
senticnet['boot_up_computer'] = [0, 0.201, 0.018, 0.077, '#interesting', '#admirable', 0.087, 'restart', 'start_up', 'connect_internet', 'buy_computer', 'shut_down']
senticnet['booted'] = [-0.591, 0, 0.553, -0.768, '#sad', '#disgusting', -0.637, 'shod', 'slippered', 'roughshod', 'sandaled', 'wear_sandal']
senticnet['bootee'] = [-0.541, 0, 0.612, -0.987, '#angry', '#disgusting', -0.713, 'scuff', 'mule', 'carpet_slipper', 'bootie', 'footwear']
senticnet['bootie'] = [-0.541, 0, 0.612, -0.987, '#angry', '#disgusting', -0.713, 'scuff', 'mule', 'bootee', 'carpet_slipper', 'footwear']
senticnet['bootlace'] = [-0.713, 0, 0.539, -0.889, '#sad', '#disgusting', -0.714, 'shoe_string', 'shoestring', 'cord', 'lace', 'shoelace']
senticnet['bootless'] = [-0.608, 0, 0.761, -0.849, '#angry', '#disgusting', -0.739, 'vain', 'unproductive', 'fruitless', 'futile', 'sleeveless']
senticnet['bootlick'] = [-0.106, 0, -0.053, -0.24, '#sad', '#disgusting', -0.133, 'adulate', 'suck_up', 'toady', 'blandish', 'kowtow']
senticnet['bootlicker'] = [-0.558, 0, 0.588, -0.65, '#angry', '#disgusting', -0.599, 'apple_polisher', 'crawler', 'fawner', 'web', 'groveler']
senticnet['booty'] = [0.09, 0.135, -0.056, 0.091, '#interesting', '#admirable', 0.087, 'self_confidence', 'find_money', 'down_payment', 'money', 'wealthy']
senticnet['booze'] = [0.11, -0.013, 0, 0, '#joyful', '#surprising', 0.041, 'alcoholic_beverage', 'adult_drink', 'alcoholic_drink', 'drink_alcohol', 'alcohol']
senticnet['boozer'] = [0.556, -0.791, 0, 0.755, '#surprising', '#admirable', 0.701, 'lush', 'alcoholic', 'alky', 'dipsomaniac', 'rummy']
senticnet['boozing'] = [0.987, -0.744, 0, 0.695, '#joyful', '#surprising', 0.809, 'vice', 'drink', 'drinking', 'intemperateness', 'drunkenness']
senticnet['bordello'] = [-0.759, 0, 0, -0.904, '#sad', '#disgusting', -0.554, 'whorehouse', 'brothel', 'massage_parlor', 'bagnio', 'house_of_prostitution']
senticnet['border'] = [0.042, 0.082, 0.026, 0, '#joyful', '#interesting', 0.033, 'boundary', 'land_mass', 'territory', 'land_area', 'large_land_mass']
senticnet['borderland'] = [0.858, -0.891, 0, 0.719, '#joyful', '#surprising', 0.823, 'mandatory', 'administrative_district', 'administrative_division', 'territorial_division', 'district']
senticnet['bore'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'boring', 'pierce', 'puncture', 'uninteresting', 'dull']
senticnet['bore_person'] = [0, 0, 0.999, -0.965, '#angry', '#disgusting', -0.655, 'boring_talk', 'yawn', 'talk_lot', 'logorrheic', 'boring_activity']
senticnet['borecole'] = [-0.569, 0, 0.892, -0.784, '#angry', '#disgusting', -0.748, 'crucifer', 'colewort', 'kail', 'cole', 'kale']
senticnet['bored'] = [-0.778, 0.27, -0.457, -0.046, '#sad', '#scared', -0.337, 'waste_time', 'boredom', 'extreme_boredom', 'enjoy_story', 'learn_news']
senticnet['bored_person'] = [-0.906, 0, 0.877, -0.911, '#sad', '#disgusting', -0.898, 'talk_too_much', 'annoy_person', 'tired_person', 'boring_movie', 'boring_show']
senticnet['boredom'] = [0, 0, 0, -0.3, '#disgusting', '#disgusting', -0.1, 'extreme_boredom', 'bored', 'become_bored', 'lose_track_time', 'kill_brain_cell']
senticnet['boring'] = [-0.023, 0, -0.101, 0, '#sad', '#scared', -0.041, 'ads', 'advertisment', 'bother', 'stop_watch', 'annoying']
senticnet['boring_activity'] = [-0.906, 0, 0.877, -0.911, '#sad', '#disgusting', -0.898, 'boring_talk', 'boring_show', 'talk_lot', 'boring_movie', 'boring_person']
senticnet['boring_movie'] = [-0.906, 0, 0.877, -0.911, '#sad', '#disgusting', -0.898, 'boring_activity', 'feel_bored', 'feel_tired', 'uninteresting', 'boring_show']
senticnet['boring_person'] = [-0.291, -0.009, 0, -0.162, '#sad', '#disgusting', -0.148, 'bother', 'nuisance', 'trouble', 'problem', 'ball_and_chain']
senticnet['boring_show'] = [-0.906, 0, 0.877, -0.911, '#sad', '#disgusting', -0.898, 'boring_activity', 'feel_bored', 'feel_tired', 'boring_movie', 'lack_of_attraction']
senticnet['boring_talk'] = [-0.939, 0, 0, -0.748, '#sad', '#disgusting', -0.562, 'fall_asleep', 'doze_off', 'disconnected', 'sleepy', 'distracted']
senticnet['born'] = [0.706, 0, 0, 0, '#joyful', '#joyful', 0.235, 'birth', 'new_baby', 'mother_womb', 'birthday', 'thanksgiving']
senticnet['born_ready'] = [0.025, 0.237, -0.073, 0.297, '#interesting', '#admirable', 0.162, 'ready', 'efficient', 'get_ready', 'preparedness', 'never_fail']
senticnet['borrow_book'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'read_article', 'buy_textbook', 'study_history', 'use_search_engine', 'buy_book']
senticnet['borrow_book_from_library'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'love_pet', 'master_skill', 'solve_equation', 'miss_bus', 'study_library']
senticnet['borrow_car'] = [-0.037, 0.134, 0, 0.057, '#interesting', '#admirable', 0.051, 'use_car', 'fill_gas_tank', 'steal_car', 'licence', 'find_car_key']
senticnet['borrow_money'] = [-0.087, 0, -0.135, 0.085, '#sad', '#scared', -0.046, 'go_debt', 'negotiate', 'pay_a_lot_of_money', 'transact_business', 'loan']
senticnet['bosom'] = [0.779, -0.756, 0, 0.526, '#joyful', '#surprising', 0.687, 'hiddenness', 'covertness', 'privateness', 'isolation', 'confidentiality']
senticnet['boss'] = [0.036, 0.129, 0, 0.06, '#interesting', '#admirable', 0.075, 'ceo', 'officer', 'supervisor', 'head_guy', 'head_person']
senticnet['boss_around'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'mobbing', 'violence', 'physical_pain', 'psychological_terror', 'bully']
senticnet['bossy'] = [0, 0, 0.92, -0.958, '#angry', '#disgusting', -0.626, 'autocratic', 'dominating', 'high-and-mighty', 'magisterial', 'peremptory']
senticnet['botch'] = [-0.782, 0, 0.81, -0.928, '#angry', '#disgusting', -0.84, 'bobble', 'error', 'misstep', 'fumble', 'stumble']
senticnet['botch_up'] = [-0.786, 0, 0.915, -0.99, '#angry', '#disgusting', -0.897, 'bodge', 'go_wrong', 'flub', 'ball_up', 'bollix']
senticnet['botched'] = [-0.983, 0, 0.505, -0.832, '#sad', '#disgusting', -0.773, 'lowly', 'bungled', 'unskilled', 'fumbling', 'bungling']
senticnet['both_functional_decorative'] = [0, 0.793, 0, 0.947, '#interesting', '#admirable', 0.58, 'use_jewelry', 'magnetic', 'shinny', 'hard_plastic', 'type_of_metal']
senticnet['both_sides'] = [0, 0.072, 0.068, 0.074, '#interesting', '#admirable', 0.026, 'part_of_book', 'book_part', 'two_sides', 'book_content', 'book_paper']
senticnet['both_word'] = [0.089, 0.133, 0.027, 0.116, '#interesting', '#admirable', 0.104, 'first', 'imperial', 'ordinal', 'count', 'greatness']
senticnet['bother'] = [-0.156, 0, 0.618, -0.65, '#angry', '#disgusting', -0.475, 'annoyance', 'bothersome', 'offend', 'irritate', 'temper']
senticnet['botheration'] = [-0.85, 0, 0.564, -0.924, '#sad', '#disgusting', -0.779, 'miff', 'impatience', 'snit', 'bummer', 'pinprick']
senticnet['bothered'] = [-0.992, 0, 0.858, -0.597, '#sad', '#angry', -0.816, 'embarrassed', 'abashed', 'chagrined', 'blushing', 'discomposed']
senticnet['bothering'] = [-0.849, 0.205, -0.484, -0.035, '#sad', '#scared', -0.388, 'depressed', 'sadness', 'blue_monday', 'feeling_low', 'feel_dejected']
senticnet['bothersome'] = [0, 0, 0.825, 0, '#angry', '#angry', -0.275, 'offend', 'pique', 'bedevil', 'frustrating', 'dun']
senticnet['bothersome_insect'] = [-0.023, -0.079, 0.368, -0.252, '#angry', '#disgusting', -0.188, 'wing_insect', 'small_insect', 'small_bug', 'flap_wing', 'nuisance_insect']
senticnet['bottle'] = [-0.873, -0.794, 0.729, -0.976, '#sad', '#disgusting', -0.595, 'empty', 'garbage', 'empty_bottle', 'empty_glass', 'thirsty']
senticnet['bottle_soda'] = [0, -0.013, 0.025, -0.06, '#angry', '#disgusting', -0.024, 'chef_special', 'hostess', 'dispense', 'bottle_wine', 'waiter']
senticnet['bottle_vodka'] = [0.704, -0.944, 0, 0, '#joyful', '#surprising', 0.549, 'ferment_grape_juice', 'chef_special', 'diet_coke', 'hostess', 'bottle_wine']
senticnet['bottle_water'] = [0.836, 0, 0, 0.944, '#joyful', '#admirable', 0.593, 'water', 'sweet_drink', 'beer', 'plastic_container', 'convenience_store']
senticnet['bottle_wine'] = [0.892, 0, 0, 0.806, '#joyful', '#admirable', 0.566, 'ferment_grape_juice', 'chef_special', 'cuisine', 'fine_dining', 'decanter']
senticnet['bottle_without_cap'] = [0, -0.094, 0, 0, '#surprising', '#surprising', 0.031, 'insure', 'ridgeback', 'endanger', 'complete_thesis', 'bad_omen']
senticnet['bottlebrush_buckeye'] = [-0.579, 0, 0.582, -0.65, '#angry', '#disgusting', -0.604, 'sweet_buckeye', 'dwarf_buckeye', 'horse_chestnut', 'red_buckeye', 'particolored_buckeye']
senticnet['bottled_water'] = [0.728, -0.517, 0, 0.811, '#joyful', '#admirable', 0.685, 'beverage', 'drinkable', 'potable', 'drinking_water', 'sugar_water']
senticnet['bottling_plant'] = [0.728, -0.517, 0, 0.811, '#joyful', '#admirable', 0.685, 'still', 'wine_maker', 'winery', 'mint', 'plant']
senticnet['bottom_fermentation'] = [0.833, -0.507, 0, 0.519, '#joyful', '#admirable', 0.62, 'zymosis', 'top_fermentation', 'vinification', 'chemical_process', 'chemical_change']
senticnet['bottom_line'] = [0, 0.298, -0.062, 0.305, '#interesting', '#admirable', 0.18, 'reason_why', 'correct', 'punctuation', 'exclamation', 'end_point']
senticnet['bottom_ocean'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'ocean_edge', 'ocean_floor', 'sea_floor', 'surface_earth', 'seabed']
senticnet['bottom_out'] = [-0.934, 0, 0.589, -0.664, '#sad', '#disgusting', -0.729, 'gain', 'reach', 'make', 'attain', 'hit']
senticnet['bottom_rot_fungus'] = [-0.872, 0, 0.723, -0.946, '#sad', '#disgusting', -0.847, 'potato_wart_fungus', 'fungus', 'potato_fungus', 'black_root_rot_fungus', 'sclerotinia']
senticnet['bottom_sea'] = [-0.036, -0.009, 0.024, -0.052, '#sad', '#disgusting', -0.034, 'under_water', 'underwater', 'water_sea', 'ocean', 'sea']
senticnet['bottom_shoes'] = [0, -0.026, 0.11, -0.04, '#angry', '#disgusting', -0.041, 'shoe', 'flip_flop', 'shoe_type', 'casual_shoes', 'moccasin']
senticnet['botulism'] = [-0.534, 0, 0.678, -0.73, '#angry', '#disgusting', -0.647, 'malady', 'mushroom_poisoning', 'food_poisoning', 'ptomaine', 'ptomaine_poisoning']
senticnet['boulder'] = [0.053, -0.035, 0, 0, '#joyful', '#surprising', 0.029, 'wheel', 'gear', 'millstone', 'pulley', 'slide']
senticnet['boulevard'] = [0, 0, 0.033, -0.045, '#angry', '#disgusting', -0.026, 'curb', 'lane', 'thoroughfare', 'intersection', 'avenue']
senticnet['bounce'] = [0.792, 0.712, 0, 0, '#joyful', '#interesting', 0.501, 'ball', 'ball_bounce', 'football', 'soccer', 'basketball']
senticnet['bounce_ball'] = [-0.099, 0, 0, -0.041, '#sad', '#disgusting', -0.047, 'roll_downhill', 'mine_gold', 'shovel_snow', 'fly_around', 'spring_up']
senticnet['bounce_check'] = [-0.326, -0.004, -0.118, -0.157, '#sad', '#disgusting', -0.199, 'become_poor', 'go_bankrupt', 'pay_fine', 'go_debt', 'go_broke']
senticnet['bounce_up_down'] = [0.987, 0, 0, 0.868, '#joyful', '#admirable', 0.618, 'bounce', 'throw', 'play_catch', 'ball_game', 'game']
senticnet['bouncer'] = [-0.904, 0, 0.943, -0.985, '#angry', '#disgusting', -0.944, 'kick_out', 'push_out', 'keep_distant', 'get_out', 'push']
senticnet['bouncing'] = [0.65, -0.614, 0, 0.711, '#joyful', '#admirable', 0.658, 'lively', 'scintillating', 'spirited', 'peppy', 'zippy']
senticnet['bouncy'] = [0, 0.807, 0, 0.952, '#interesting', '#admirable', 0.586, 'spherical_shape', 'use_sport', 'circular_object', 'round_object', 'fill_air']
senticnet['bound'] = [-0.519, 0, 0.946, -0.995, '#angry', '#disgusting', -0.82, 'trammel', 'limit', 'restrict', 'clamp_down', 'confine']
senticnet['boundary'] = [0.034, 0.09, 0.039, 0.061, '#interesting', '#admirable', 0.049, 'border', 'limit', 'edge', 'indoor', 'side']
senticnet['boundary_condition'] = [-0.657, 0, 0.65, -0.981, '#sad', '#disgusting', -0.763, 'assumption', 'precondition', 'provision', 'constraint', 'premiss']
senticnet['bounded'] = [0, -0.916, 0, 0.984, '#surprising', '#admirable', 0.633, 'finite', 'limited', 'finite_state_machine', 'wall', 'boundary']
senticnet['bounden'] = [0.924, -0.551, 0, 0.756, '#joyful', '#admirable', 0.744, 'obligatory', 'incumbent_on', 'de_rigueur', 'compulsory', 'mandatory']
senticnet['bounder'] = [-0.889, 0, 0.806, -0.638, '#sad', '#angry', -0.778, 'blackguard', 'cad', 'scoundrel', 'rogue', 'hound']
senticnet['bountiful'] = [0.851, -0.671, 0, 0.854, '#joyful', '#admirable', 0.792, 'fertile', 'breeding', 'prolific', 'fruitful', 'productive']
senticnet['bounty'] = [0.023, 0.233, -0.066, 0.16, '#interesting', '#admirable', 0.117, 'money_earn', 'financial_gain', 'pay_monthly', 'monetary_gain', 'extra_money']
senticnet['bouquet'] = [0.081, -0.032, 0, 0, '#joyful', '#surprising', 0.038, 'blossom', 'bloom', 'pollen', 'poppy', 'many_plants']
senticnet['bourbon'] = [0.882, 0.724, 0, 0, '#joyful', '#interesting', 0.535, 'scotch', 'ale', 'vodka', 'brandy', 'whiskey']
senticnet['bourgeois'] = [0.127, 0.069, 0.029, 0.16, '#joyful', '#admirable', 0.109, 'basic_human_need', 'construct', 'set_down', 'make', 'build_process']
senticnet['bout'] = [0, 0.868, 0, 0.875, '#interesting', '#admirable', 0.581, 'meeting', 'meet', 'match', 'encounter', 'round']
senticnet['bovine'] = [0.027, 0.077, 0, 0.138, '#interesting', '#admirable', 0.081, 'hoof_mammal', 'hoof_animal', 'neigh', 'smart_animal', 'critter']
senticnet['bow'] = [0.74, 0.775, 0, 0, '#joyful', '#interesting', 0.505, 'arrow', 'spear', 'buy_wood', 'baton', 'archery']
senticnet['bow_legs'] = [-0.756, 0, 0.504, -0.772, '#sad', '#disgusting', -0.677, 'astasia', 'anorgasmia', 'hearing_impairment', 'hearing_disorder', 'disablement']
senticnet['bow_string'] = [0.037, -0.113, 0.144, -0.189, '#angry', '#disgusting', -0.061, 'pluck', 'string_break', 'play_instrument', 'rock_out', 'record_song']
senticnet['bowed'] = [0, 0, -0.763, -0.879, '#scared', '#disgusting', -0.547, 'bow_down', 'submit', 'accede', 'give_in', 'bend']
senticnet['bowel'] = [0, 0, 0, -0.081, '#disgusting', '#disgusting', -0.027, 'anus', 'scrotum', 'shoulder', 'liver', 'waist']
senticnet['bowel_movement'] = [-0.897, 0, 0.925, -0.588, '#sad', '#angry', -0.803, 'shit', 'laxation', 'movement', 'dump', 'asshole']
senticnet['bowelless'] = [0.971, -0.926, 0, 0.617, '#joyful', '#surprising', 0.838, 'mortal', 'cutthroat', 'merciless', 'tigerish', 'pitiless']
senticnet['bowery'] = [-0.508, 0, 0.573, -0.893, '#angry', '#disgusting', -0.658, 'petallike', 'leafy', 'foliolate', 'unifoliate', 'bifoliate']
senticnet['bowing'] = [0.679, -0.947, 0, 0.661, '#joyful', '#surprising', 0.762, 'submissive', 'cringing', 'groveling', 'sub', 'wormlike']
senticnet['bowl'] = [-0.519, 0, 0.562, -0.699, '#angry', '#disgusting', -0.593, 'fishbowl', 'fish_bowl', 'goldfish_bowl', 'jorum', 'mazer']
senticnet['bowl_alley'] = [0.101, 0.074, 0.03, 0, '#joyful', '#interesting', 0.048, 'bowling', 'pins', 'sports', 'challenge', 'bowling_center']
senticnet['bowling'] = [0.101, 0.074, 0.03, 0, '#joyful', '#interesting', 0.048, 'bowl_alley', 'pins', 'sports', 'challenge', 'bowl_alley_center']
senticnet['bowling_center'] = [0, 0.827, 0, 0.84, '#interesting', '#admirable', 0.556, 'bowling', 'sport', 'excise', 'challenge', 'competition']
senticnet['box'] = [0, -0.023, 0, 0.051, '#surprising', '#admirable', 0.025, 'cardboard_box', 'bag', 'package', 'box_cereal', 'bin']
senticnet['box_cereal'] = [0.736, -0.744, 0, 0, '#joyful', '#surprising', 0.493, 'breakfast', 'dry_fruit', 'carton_milk', 'wheat', 'morning']
senticnet['box_ear'] = [0, 0, 0.833, -0.967, '#angry', '#disgusting', -0.6, 'bridge_difference', 'lower_standard', 'market_product', 'deal_card_player', 'stand_alone']
senticnet['box_match'] = [0.859, -0.713, 0, 0, '#joyful', '#surprising', 0.524, 'hell', 'underworld', 'funeral', 'short_circuit', 'political_rally']
senticnet['box_office'] = [0, 0, -0.1, -0.04, '#scared', '#disgusting', -0.047, 'ticket_box', 'stage_entrance', 'movie', 'ticket_booth', 'sticky_floor']
senticnet['box_ring'] = [0, 0, -0.81, -0.978, '#scared', '#disgusting', -0.596, 'convention', 'prisoner_war_camp', 'rave', 'gift_shop', 'dark_alley']
senticnet['box_tissue'] = [0, -0.046, 0.068, -0.066, '#angry', '#disgusting', -0.029, 'side_chair', 'stapler', 'tape_dispenser', 'box', 'ergonomic_chair']
senticnet['boy'] = [0.575, -0.622, 0, 0.596, '#surprising', '#admirable', 0.598, 'altar_boy', 'cub', 'ball_boy', 'bat_boy', 'lad']
senticnet['boy_girl'] = [0.025, 0.073, -0.052, 0.1, '#interesting', '#admirable', 0.049, 'little_person', 'small_kid', 'small_boy', 'young_kid', 'young_people']
senticnet['boy_scout'] = [0.798, -0.519, 0, 0.973, '#joyful', '#admirable', 0.763, 'naif', 'inexperienced_person', 'dear', 'virgin', 'mortal']
senticnet['boyfriend'] = [0.033, 0.076, 0, 0.066, '#interesting', '#admirable', 0.058, 'baby_dog', 'most_dogs', 'puppet', 'dog', 'dog_like']
senticnet['boys'] = [0.922, 0.801, 0, 0, '#joyful', '#interesting', 0.574, 'bloke', 'male', 'male_person', 'man_child', 'dude']
senticnet['bra'] = [0, 0.151, -0.088, 0.232, '#interesting', '#admirable', 0.098, 'good_human', 'active', 'healthy_activity', 'push_up', 'result_injury']
senticnet['brace'] = [0.8, -0.977, 0, 0.512, '#joyful', '#surprising', 0.763, 'energize', 'perk_up', 'reanimate', 'stimulate', 'arouse']
senticnet['bracer'] = [-0.507, 0, 0.937, -0.591, '#angry', '#disgusting', -0.678, 'restorative', 'medicine', 'medication', 'medicament', 'medicinal_drug']
senticnet['bracket'] = [0.763, -0.677, 0, 0.945, '#joyful', '#admirable', 0.795, 'set', 'income_bracket', 'tax_bracket', 'income_tax_bracket', 'price_bracket']
senticnet['bradycardia'] = [-0.83, 0, 0.987, -0.504, '#sad', '#angry', -0.774, 'heart_block', 'atrioventricular_block', 'arrhythmia', 'ventricular_fibrillation', 'tachycardia']
senticnet['brag'] = [0, 0, 0, -0.736, '#disgusting', '#disgusting', -0.245, 'convince', 'talk_much', 'discuss', 'transfer_knowledge', 'communicate_other_person']
senticnet['braggart'] = [0, 0, -0.759, -0.792, '#scared', '#disgusting', -0.517, 'blowhard', 'vaunter', 'boaster', 'line-shooter', 'bragger']
senticnet['bragging'] = [-0.887, 0, 0.666, -0.901, '#sad', '#disgusting', -0.818, 'crow', 'crowing', 'bluster', 'jactitation', 'vaporing']
senticnet['braid'] = [-0.066, -0.018, 0.05, -0.071, '#sad', '#disgusting', -0.056, 'embroidery', 'woven', 'cover_wind', 'torn', 'use_needle']
senticnet['brain'] = [0, 0.895, 0, 0.984, '#interesting', '#admirable', 0.626, 'hold_brain', 'inside_head', 'cranium', 'skull', 'mind']
senticnet['brain_activity'] = [0.933, 0.715, 0, 0, '#joyful', '#interesting', 0.549, 'recall', 'analysis', 'new_think', 'recollection', 'put_two_together']
senticnet['brain_damage'] = [-0.172, -0.023, -0.113, -0.156, '#sad', '#disgusting', -0.139, 'serious_accident', 'bang_head', 'loss_ofawareness', 'concussion', 'get_hurt']
senticnet['brain_disease'] = [-0.953, 0, 0.621, -0.725, '#sad', '#disgusting', -0.766, 'disease', 'brain_disorder', 'parkinson', 'ill', 'epilepsy']
senticnet['brain_disorder'] = [-0.942, 0, 0.868, -0.566, '#sad', '#angry', -0.792, 'disease', 'brain_disease', 'parkinson', 'ill', 'epilepsy']
senticnet['brain_failure'] = [-0.528, 0, 0.785, -0.617, '#angry', '#disgusting', -0.643, 'disease', 'feel_sick', 'brain_disease', 'eye_failure', 'epilepsy']
senticnet['brain_fever'] = [-0.773, 0, 0.871, -0.64, '#sad', '#angry', -0.761, 'leptomeningitis', 'cerebrospinal_meningitis', 'epidemic_meningitis', 'meningitis', 'cerebrospinal_fever']
senticnet['brain_function'] = [-0.075, 0.25, -0.054, 0.142, '#interesting', '#admirable', 0.088, 'brainstorm', 'recollection', 'think', 'think_process', 'new_think']
senticnet['brain_storm'] = [0.96, 0.902, 0, 0, '#joyful', '#interesting', 0.621, 'discussion', 'new_idea', 'new_insight', 'come_conclusion', 'come_up_idea']
senticnet['brain_trust'] = [-0.935, 0, 0.586, -0.669, '#sad', '#disgusting', -0.73, 'camp', 'pack', 'clique', 'coterie', 'ingroup']
senticnet['brain_tumor'] = [-0.887, 0, -0.842, 0, '#sad', '#scared', -0.576, 'lyme_disease', 'bad_hair_day', 'suffer_fool', 'bad_luck', 'disrespect']
senticnet['brainless'] = [0, 0, 0.737, -0.952, '#angry', '#disgusting', -0.563, 'idiotic', 'stupid', 'dumb', 'idiot', 'dummy']
senticnet['brainstorm'] = [-0.072, 0.231, 0, 0.087, '#interesting', '#admirable', 0.082, 'think', 'brain_function', 'hang_up', 'meeting', 'put_two_together']
senticnet['brainwash'] = [0, 0, 0, -0.947, '#disgusting', '#disgusting', -0.316, 'terrorism', 'kamikaze', 'sect', 'military_camp', 'faction']
senticnet['brake'] = [0.771, 0.702, 0, 0, '#joyful', '#interesting', 0.491, 'safe_belt', 'emergency_brake_pedal', 'stop', 'avoid_accident', 'brake_pedal']
senticnet['brake_failure'] = [-0.816, 0, 0.849, -0.532, '#sad', '#angry', -0.732, 'dud', 'fault', 'failure', 'equipment_failure', 'engine_failure']
senticnet['brake_lining'] = [0, 0.076, -0.065, 0.205, '#interesting', '#admirable', 0.072, 'refractory', 'protective_cover', 'protective_covering', 'protection', 'lining']
senticnet['brake_pedal'] = [0.798, 0.92, 0, 0, '#joyful', '#interesting', 0.573, 'safe_belt', 'emergency_brake', 'stop', 'avoid_accident', 'brake']
senticnet['braky'] = [-0.863, 0, 0.665, -0.616, '#sad', '#angry', -0.715, 'brambly', 'wooded', 'rushy', 'scrubby', 'forested']
senticnet['brambly'] = [-0.863, 0, 0.665, -0.616, '#sad', '#angry', -0.715, 'wooded', 'braky', 'rushy', 'scrubby', 'forested']
senticnet['bran_flake'] = [0.055, 0.292, -0.071, 0.345, '#interesting', '#admirable', 0.207, 'puffed_rice', 'granola', 'raisin_bran', 'corn_flake', 'cold_cereal']
senticnet['branch'] = [0.042, -0.134, 0.029, 0, '#joyful', '#surprising', 0.049, 'twig', 'leaf', 'tree_arm', 'tree_branch', 'tree_limb']
senticnet['branch_out'] = [-0.089, 0, -0.094, -0.051, '#sad', '#scared', -0.078, 'cast_shadow', 'move_wind', 'box_ear', 'fall_dead', 'jump_trampoline']
senticnet['brand'] = [0.111, -0.185, -0.095, 0.281, '#surprising', '#admirable', 0.161, 'better_good', 'most_good', 'computer_manufacturer', 'computer_company', 'puzzle']
senticnet['brand_name'] = [0.944, 0, 0, 0.847, '#joyful', '#admirable', 0.597, 'beer', 'vodka', 'whisky', 'brandy', 'alcohol']
senticnet['brandy'] = [0.842, 0.867, 0, 0, '#joyful', '#interesting', 0.57, 'rum', 'vodka', 'scotch', 'bourbon', 'whiskey']
senticnet['brashness'] = [0, 0, 0.865, -0.808, '#angry', '#disgusting', -0.558, 'foolhardiness', 'thoughtlessness', 'desperation', 'unthoughtfulness', 'glitz']
senticnet['brass'] = [0.952, -0.844, 0, 0.875, '#joyful', '#admirable', 0.89, 'administration', 'governance', 'governing_body', 'establishment', 'judiciary']
senticnet['brass_instrument'] = [0.96, 0.902, 0, 0, '#joyful', '#interesting', 0.621, 'horn', 'jew_harp', 'antler', 'trumpet', 'crash_cymbal']
senticnet['brassbound'] = [-0.806, 0, 0.507, -0.763, '#sad', '#disgusting', -0.692, 'adamant', 'inexorable', 'intransigent', 'ironclad', 'inflexible']
senticnet['brat'] = [-0.127, 0, -0.084, -0.101, '#sad', '#disgusting', -0.104, 'little_boy', 'youngster', 'youth', 'innocence', 'lad']
senticnet['brattish'] = [0.584, -0.592, 0, 0.753, '#surprising', '#admirable', 0.643, 'ungracious', 'discourteous', 'bratty', 'impolite', 'unparliamentary']
senticnet['bratty'] = [0.584, -0.592, 0, 0.753, '#surprising', '#admirable', 0.643, 'ungracious', 'discourteous', 'impolite', 'brattish', 'unparliamentary']
senticnet['brave'] = [0, 0, 0, 0.917, '#admirable', '#admirable', 0.306, 'bravery', 'anticipation', 'affect', 'encouragement', 'positive']
senticnet['brave_out'] = [0.512, 0.658, -0.254, 0.256, '#joyful', '#interesting', 0.391, 'defy', 'endure', 'brave', 'withstand', 'stand_firm']
senticnet['braveness'] = [-0.948, 0, 0.745, -0.979, '#sad', '#disgusting', -0.891, 'nerve', 'fearlessness', 'heart', 'dauntlessness', 'intrepidity']
senticnet['bravery'] = [0, 0, 0, 0.835, '#admirable', '#admirable', 0.278, 'brave', 'confidence', 'affect', 'adoration', 'sympathetic']
senticnet['brawl'] = [0.915, -0.847, 0, 0.778, '#joyful', '#surprising', 0.847, 'fall_out', 'debate', 'wrangle', 'spat', 'altercate']
senticnet['breaair'] = [-0.033, 0, -0.113, 0, '#sad', '#scared', -0.049, 'inhale_air', 'dig_up', 'flatulence', 'pour_water', 'breathe']
senticnet['breach_of_contract'] = [-0.106, 0, -0.053, -0.24, '#sad', '#disgusting', -0.133, 'breach_of_warranty', 'breach_of_trust', 'partial_breach', 'anticipatory_breach', 'constructive_breach']
senticnet['breach_of_trust'] = [-0.816, 0, 0.849, -0.532, '#sad', '#angry', -0.732, 'breach_of_warranty', 'breach_of_contract', 'partial_breach', 'anticipatory_breach', 'constructive_breach']
senticnet['breach_of_warranty'] = [-0.816, 0, 0.849, -0.532, '#sad', '#angry', -0.732, 'breach_of_contract', 'breach_of_trust', 'partial_breach', 'anticipatory_breach', 'constructive_breach']
senticnet['bread'] = [0.901, 0, 0, 0.916, '#joyful', '#admirable', 0.606, 'get_away', 'absolution', 'glory', 'counsel', 'vow']
senticnet['bread_crumb'] = [-0.088, -0.046, 0.023, -0.076, '#sad', '#disgusting', -0.047, 'toast', 'make_toast', 'messy', 'bread', 'spoilage']
senticnet['breadbox'] = [0, -0.023, 0, 0.07, '#surprising', '#admirable', 0.031, 'pastry', 'christmas_stock', 'bakery', 'sundae', 'freezer']
senticnet['breadeeply'] = [0, 0, -0.788, -0.962, '#scared', '#disgusting', -0.583, 'take_breath', 'renew_energy', 'late_work', 'feel_refreshed', 'stop_activity']
senticnet['breadstuff'] = [0.52, -0.693, 0, 0.639, '#surprising', '#admirable', 0.617, 'black_bread', 'pumpernickel', 'limpa', 'bread', 'rye_bread']
senticnet['breafast'] = [0, 0, -0.874, -0.994, '#scared', '#disgusting', -0.623, 'blister_foot', 'trip_fall', 'unfit', 'run_out_breath', 'breahard']
senticnet['breahard'] = [0, 0, -0.904, -0.793, '#scared', '#disgusting', -0.566, 'blister_foot', 'trip_fall', 'out_breath', 'pull_muscle', 'breafast']
senticnet['breaheavily'] = [0, 0, -0.817, -0.797, '#scared', '#disgusting', -0.538, 'get_exhausted', 'run_out_breath', 'heavy_breathe', 'become_wind', 'blister_foot']
senticnet['break'] = [-0.057, -0.044, 0, -0.095, '#sad', '#disgusting', -0.036, 'tear_apart', 'painful_injury', 'smash', 'dislocation', 'open_wind']
senticnet['break_ankle'] = [0, 0, -0.75, -0.762, '#scared', '#disgusting', -0.504, 'twist_ankle', 'out_breath', 'trip_fall', 'blister_foot', 'minor_injury']
senticnet['break_apart'] = [-0.119, 0.095, -0.115, 0.071, '#sad', '#scared', -0.023, 'violent_action', 'pulverize', 'break_glass', 'tear_apart', 'hit_hard']
senticnet['break_apparatus'] = [-0.879, 0, 0.682, -0.533, '#sad', '#angry', -0.698, 'break', 'crash_cymbal', 'broken_guitar', 'break_instrument', 'damage']
senticnet['break_arm'] = [-0.743, -0.818, -0.832, -0.982, '#scared', '#disgusting', -0.58, 'get_injured', 'fall_down', 'breafast', 'tackle', 'pass_out']
senticnet['break_arrow'] = [-0.961, 0, 0.704, -0.97, '#sad', '#disgusting', -0.878, 'break', 'crash', 'smash', 'damage', 'hunting_problem']
senticnet['break_bad'] = [-0.196, 0, -0.155, -0.1, '#sad', '#scared', -0.15, 'break_law', 'send_to_prison', 'revenge', 'rape', 'use_illegal_drug']
senticnet['break_bone'] = [-0.911, -0.722, -0.848, -0.808, '#sad', '#scared', -0.615, 'see_dog', 'go_downhill', 'hit_tree', 'break_leg', 'score_touchdown']
senticnet['break_chair'] = [0.98, -0.945, 0, 0, '#joyful', '#surprising', 0.642, 'break', 'rejuvenation', 'lie_back', 'slow_heart_beat', 'fat']
senticnet['break_door'] = [-0.931, 0, 0.945, -0.932, '#angry', '#disgusting', -0.936, 'break_into_house', 'break_window_shop', 'accident', 'robbery', 'force_enter']
senticnet['break_down'] = [-0.096, 0, -0.053, 0, '#sad', '#scared', -0.05, 'collide', 'crash', 'turn_steer_wheel', 'near_destination', 'get_accident']
senticnet['break_easily'] = [-0.739, 0, 0, -0.864, '#sad', '#disgusting', -0.534, 'shatter', 'see_better', 'open', 'magnify', 'shard']
senticnet['break_fingernail'] = [-0.069, 0, 0.078, -0.125, '#angry', '#disgusting', -0.091, 'stardom', 'cramp', 'accomplishment', 'knee_injury', 'sore_foot']
senticnet['break_free'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'liberate', 'set_free', 'relief', 'freedom', 'free_will']
senticnet['break_glass'] = [-0.119, 0.095, -0.115, 0.071, '#sad', '#scared', -0.023, 'violent_action', 'pulverize', 'break_apart', 'tear_apart', 'hit_hard']
senticnet['break_half'] = [-0.105, -0.083, 0.106, -0.155, '#angry', '#disgusting', -0.094, 'broken', 'cut_finger', 'cut_up', 'scrape', 'karate']
senticnet['break_in'] = [-0.816, 0, 0.849, -0.532, '#sad', '#angry', -0.732, 'break', 'change', 'alter', 'modify', 'domesticize']
senticnet['break_instrument'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'break', 'crash_cymbal', 'broken_guitar', 'break_apparatus', 'damage']
senticnet['break_into_house'] = [-0.931, 0, 0.945, -0.932, '#angry', '#disgusting', -0.936, 'break_door', 'break_window_shop', 'accident', 'robbery', 'force_enter']
senticnet['break_it'] = [-0.976, 0, 0.246, -0.901, '#sad', '#disgusting', -0.708, 'get_drunk', 'accident', 'drink_alcohol', 'rude_person', 'alcohol']
senticnet['break_law'] = [0, -0.869, 0.992, -0.92, '#angry', '#disgusting', -0.348, 'commit_crime', 'send_to_jail', 'send_to_prison', 'feel_remorse', 'go_to_prison']
senticnet['break_leg'] = [-0.072, -0.057, 0, -0.147, '#sad', '#disgusting', -0.054, 'loss_ofbreath', 'see_dog', 'hurt_back', 'fall_ground', 'fall_dead']
senticnet['break_mirror'] = [-0.931, 0, 0.945, -0.932, '#angry', '#disgusting', -0.936, 'break_window', 'break_window_shop', 'accident', 'bleeding', 'damage']
senticnet['break_neck'] = [-0.86, 0, -0.97, 0, '#sad', '#scared', -0.61, 'fall_ground', 'fall', 'fall_over', 'take_photo', 'crash_car']
senticnet['break_record'] = [0, -0.758, 0, 0.766, '#surprising', '#admirable', 0.508, 'play_rugby', 'hit_ball_hard', 'play_volleyball', 'run_basis', 'play_basketball']
senticnet['break_rule'] = [-0.931, 0, 0.945, -0.932, '#angry', '#disgusting', -0.936, 'prison_breaker', 'escape_prison', 'illegal', 'escape_justice', 'cross_red_light']
senticnet['break_silence'] = [-0.039, -0.104, -0.093, 0.114, '#surprising', '#admirable', 0.029, 'speak_up', 'make_someone_laugh', 'laugh_joke', 'thank', 'howl_laughter']
senticnet['break_something'] = [-0.983, 0, 0.265, -0.994, '#sad', '#disgusting', -0.747, 'break', 'smash', 'ruin', 'destroy', 'damage']
senticnet['break_thing'] = [-0.907, 0, 0.425, -0.907, '#sad', '#disgusting', -0.746, 'damage', 'smash', 'destroy_thing', 'break', 'destroy']
senticnet['break_tooth'] = [0, -0.844, -0.882, -0.963, '#scared', '#disgusting', -0.334, 'toothache', 'numbness', 'ice_cream_melt', 'mad_cow_disease', 'car_wreck']
senticnet['break_up'] = [-0.801, 0, -0.778, -0.993, '#sad', '#disgusting', -0.857, 'break', 'amount_nothing', 'ease_pain', 'need_companionship', 'wait_forever']
senticnet['break_window'] = [-0.931, 0, 0.945, -0.932, '#angry', '#disgusting', -0.936, 'break_mirror', 'break_window_shop', 'accident', 'accident_game', 'break_door']
senticnet['break_window_shop'] = [-0.931, 0, 0.945, -0.932, '#angry', '#disgusting', -0.936, 'break_mirror', 'break_window', 'accident', 'robbery', 'thief']
senticnet['break_work'] = [0.897, 0.959, 0, 0, '#joyful', '#interesting', 0.619, 'spend_time_with_friend', 'show_off', 'enjoy_person', 'fun', 'win_money']
senticnet['breakable'] = [-0.083, 0, -0.111, 0, '#sad', '#scared', -0.065, 'fragile', 'brittle', 'frail', 'easy_to_break', 'flimsy']
senticnet['breakage'] = [-0.697, 0, 0.74, -0.668, '#sad', '#angry', -0.702, 'large_indefinite_quantity', 'large_indefinite_amount', 'small_indefinite_quantity', 'small_indefinite_amount', 'indefinite_quantity']
senticnet['breakdown'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'crack', 'cracked_screen', 'cracked_car', 'break', 'cracked_phone']
senticnet['breakfast'] = [0.72, 0.995, 0, 0, '#joyful', '#interesting', 0.572, 'scrumble_egg', 'heat_meal', 'pan', 'beat_egg', 'food']
senticnet['breakfast_bed'] = [0.279, 0.113, -0.115, 0.209, '#joyful', '#admirable', 0.162, 'cherish', 'eat_together', 'a_lot_of_sex', 'feel_pleasure', 'good_morning']
senticnet['breakfast_food'] = [0.72, 0, 0, 0.748, '#joyful', '#admirable', 0.489, 'chewy', 'morning_food', 'food_bake', 'bakery_item', 'round_bread']
senticnet['breaking_away'] = [-0.666, 0, 0.585, -0.917, '#sad', '#disgusting', -0.723, 'withdrawal', 'exit', 'dispatch', 'going', 'farewell']
senticnet['breaking_news'] = [-0.083, 0, -0.111, 0, '#sad', '#scared', -0.065, 'crossword', 'grade_paper', 'type_of_paper', 'hit_headlines', 'narrative']
senticnet['breakstone'] = [-0.565, 0, 0.848, -0.801, '#angry', '#disgusting', -0.738, 'herb', 'yellow_mountain_saxifrage', 'meadow_saxifrage', 'mossy_saxifrage', 'western_saxifrage']
senticnet['breakthrough'] = [0.774, -0.634, 0, 0.567, '#joyful', '#surprising', 0.658, 'catching', 'discovery', 'spying', 'determination', 'tracing']
senticnet['breaout'] = [-0.129, 0.085, -0.146, 0.087, '#sad', '#scared', -0.034, 'breath_difficulty', 'exhalation', 'push_wind', 'mouth_action', 'move_air']
senticnet['breasigh_relief'] = [-0.077, 0, -0.171, -0.059, '#sad', '#scared', -0.102, 'feel_relieved', 'feel_relief', 'jump_off_bridge', 'act_foolish', 'act_silly']
senticnet['breast'] = [-0.635, 0, 0.559, -0.828, '#sad', '#disgusting', -0.674, 'take_bull_by_horns', 'confront', 'front', 'encounter', 'oppose']
senticnet['breast_feeding'] = [0.798, -0.519, 0, 0.973, '#joyful', '#admirable', 0.763, 'nursing', 'schedule_feeding', 'demand_feeding', 'infant_feeding', 'feeding']
senticnet['breast_pocket'] = [0, 0, 0.724, -0.799, '#angry', '#disgusting', -0.508, 'lymph', 'exoskeleton', 'forehead', 'toward', 'squint']
senticnet['breath'] = [0.756, 0, 0, 0.748, '#joyful', '#admirable', 0.501, 'gasp', 'wind', 'respite', 'blow', 'whiff']
senticnet['breath_difficulty'] = [0, 0, 0.933, -0.863, '#angry', '#disgusting', -0.599, 'feel_out_of_breath', 'muscle_cramp', 'throat_injury', 'run_too_fast', 'epileptic_seizures']
senticnet['breath_heavily'] = [0, 0, -0.832, -0.908, '#scared', '#disgusting', -0.58, 'breathlessness', 'heart_rate_increase', 'become_wind', 'increased_heart_rate', 'get_out_breath']
senticnet['breath_of_fresh_air'] = [0.772, -0.923, 0, 0.524, '#joyful', '#surprising', 0.74, 'change', 'modification', 'disembarrassment', 'easing', 'alteration']
senticnet['breath_sigh_relief'] = [0.083, 0.129, -0.097, 0.155, '#interesting', '#admirable', 0.09, 'relax', 'relieved', 'problem_solved', 'emotion', 'body_language']
senticnet['breathable'] = [0.909, 0.983, 0, 0, '#joyful', '#interesting', 0.631, 'oxygen', 'air', 'atmosphere', 'hydrogen', 'inhale_air']
senticnet['breathe'] = [0.822, -0.88, 0, 0.591, '#joyful', '#surprising', 0.764, 'expire', 'inspire', 'respire', 'yawn', 'hyperventilate']
senticnet['breathed'] = [-0.998, 0, 0.798, -0.716, '#sad', '#angry', -0.837, 'silent', 'voiceless', 'unsounded', 'inaudible', 'supersonic']
senticnet['breathing_problem'] = [-0.966, 0, 0.751, -0.981, '#sad', '#disgusting', -0.899, 'asthma_attack', 'asthma', 'ill', 'sick', 'sickness']
senticnet['breathing_space'] = [0.961, -0.849, 0, 0.958, '#joyful', '#admirable', 0.923, 'pause', 'break', 'intermission', 'suspension', 'rest_period']
senticnet['breathless'] = [-0.95, 0, 0.862, -0.783, '#sad', '#angry', -0.865, 'asphyxiating', 'smothering', 'suffocating', 'suffocative', 'blown']
senticnet['breathlessness'] = [-0.088, -0.067, 0, -0.121, '#sad', '#disgusting', -0.047, 'get_out_breath', 'become_wind', 'shortness_breath', 'leg_cramp', 'run_out_breath']
senticnet['breaunderwater'] = [0.907, 0.903, 0, 0, '#joyful', '#interesting', 0.603, 'live_ocean', 'fish', 'travel_fast_light', 'like_play', 'drink_sea_water']
senticnet['breeches'] = [-0.589, 0, 0.757, -0.679, '#angry', '#disgusting', -0.675, 'trunk_hose', 'knee_trunk_hose', 'knee_pants', 'knickerbockers', 'knickers']
senticnet['breed'] = [0.848, 0, 0, 0.813, '#joyful', '#admirable', 0.554, 'reproduction', 'survival', 'host_party', 'part_of_meal', 'put_ice']
senticnet['breeding'] = [0.639, -0.701, 0, 0.507, '#joyful', '#surprising', 0.616, 'tastefulness', 'daintiness', 'eclat', 'elegance', 'genteelness']
senticnet['breeding_ground'] = [-0.55, 0, 0.996, -0.506, '#sad', '#angry', -0.684, 'pesthole', 'rookery', 'tract', 'piece_of_land', 'piece_of_ground']
senticnet['breeze'] = [0.794, 0, 0, 0.878, '#joyful', '#admirable', 0.557, 'sea_breeze', 'wind', 'breezy', 'air_movement', 'air']
senticnet['breezy'] = [0.925, 0, 0, 0.859, '#joyful', '#admirable', 0.595, 'breeze', 'sea_breeze', 'air_movement', 'wind', 'air']
senticnet['brew'] = [0, 0.091, -0.053, 0.073, '#interesting', '#admirable', 0.037, 'privately', 'hold_liquid', 'make_wish', 'rinse_dish', 'find_toilet']
senticnet['brewery'] = [0.06, 0.067, 0, -0.054, '#joyful', '#interesting', 0.024, 'water_fountain', 'winery', 'flea_market', 'load_dock', 'wish_well']
senticnet['bribe'] = [-0.959, 0, -0.708, -0.966, '#sad', '#disgusting', -0.878, 'corrupt', 'bribe_police', 'debt', 'tax', 'persuade']
senticnet['bribe_police'] = [-0.959, 0, -0.708, -0.966, '#sad', '#disgusting', -0.878, 'corrupt', 'bribe', 'corruption', 'illegal', 'persuade']
senticnet['bribe_teacher'] = [-0.062, -0.017, 0.016, -0.058, '#sad', '#disgusting', -0.04, 'read_lot', 'study_hard', 'study_course_material', 'stay_school', 'graduate_college']
senticnet['brick'] = [0.962, -0.703, 0, 0.522, '#joyful', '#surprising', 0.729, 'adobe', 'adobe_brick', 'clinker', 'clinker_brick', 'firebrick']
senticnet['bride'] = [0.151, 0, -0.148, 0.157, '#joyful', '#admirable', 0.053, 'bride_groom', 'wedding_cake', 'flower_girl', 'bride_groomsmaid', 'alcohol']
senticnet['bride_groom'] = [0.151, 0, -0.148, 0.157, '#joyful', '#admirable', 0.053, 'bride', 'wedding_cake', 'flower_girl', 'bridesmaid', 'alcohol']
senticnet['bridegroom'] = [0.869, -0.535, 0, 0.772, '#joyful', '#admirable', 0.725, 'bride', 'groom', 'honeymooner', 'spouse', 'partner']
senticnet['bridesmaid'] = [0.918, 0, 0, 0.899, '#joyful', '#admirable', 0.606, 'bride_groom', 'vow', 'wedding_cake', 'bride', 'flower_girl']
senticnet['bridge'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'suspension_bridge', 'under_bridge', 'roadway', 'county_highway', 'long_road']
senticnet['bridge_difference'] = [-0.714, 0, 0.892, 0, '#sad', '#angry', -0.535, 'stand_alone', 'deal_card_player', 'forward_email', 'explain_everything', 'mind_store']
senticnet['bridge_gap'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'needy', 'come_house', 'laugh_oneself', 'group_together', 'journey_far']
senticnet['bridge_river'] = [-0.045, 0.098, 0, 0.083, '#interesting', '#admirable', 0.045, 'machine_metal', 'guard_bank', 'build_bridge', 'commit_genocide', 'even_odds']
senticnet['bridge_stream'] = [-0.051, 0.075, 0, 0.103, '#interesting', '#admirable', 0.042, 'travel_over_water', 'cross_river', 'sail_ocean', 'connect_city', 'drive_destination']
senticnet['bridgework'] = [-0.657, 0, 0.65, -0.981, '#sad', '#disgusting', -0.763, 'false_teeth', 'bridge', 'dental_plate', 'partial_denture', 'dental_appliance']
senticnet['brief'] = [0, 0.154, -0.058, 0.17, '#interesting', '#admirable', 0.089, 'court_action', 'accessory', 'legal_document', 'short', 'protective_cover']
senticnet['briefcase'] = [0, 0.084, 0, 0, '#interesting', '#interesting', 0.028, 'keychain', 'clothes_washer', 'keyhole', 'purse', 'clutch_bag']
senticnet['bright'] = [0.833, 0.995, 0, 0, '#joyful', '#interesting', 0.609, 'sunlight', 'ray', 'shine_sun', 'daylight', 'sun_down']
senticnet['bright_color'] = [0.887, 0.739, 0, 0, '#joyful', '#interesting', 0.542, 'colorful', 'color', 'color_rainbow', 'secondary_color', 'primary_color']
senticnet['bright_flash'] = [0, -0.003, -0.078, -0.061, '#scared', '#disgusting', -0.045, 'lighten', 'tornado', 'dynamite_explosion', 'forest_fire', 'lightning']
senticnet['bright_flower'] = [0.714, -0.583, 0, 0.667, '#joyful', '#admirable', 0.655, 'flower', 'bright_petals', 'leaves', 'plant', 'colorful']
senticnet['bright_light'] = [0.085, 0.107, -0.081, 0, '#joyful', '#interesting', 0.037, 'hot_sun', 'sunlight', 'hot', 'hot_day', 'light']
senticnet['bright_petals'] = [0, 0.068, -0.065, 0.081, '#interesting', '#admirable', 0.028, 'flower', 'bright_flower', 'leaves', 'plant', 'colorful']
senticnet['bright_red'] = [-0.026, 0.068, 0.04, 0.084, '#interesting', '#admirable', 0.029, 'peelable', 'green_black', 'purple', 'red', 'edible_human']
senticnet['bright_sky'] = [0.956, -0.823, 0, 0, '#joyful', '#surprising', 0.593, 'sunrise', 'good_weather', 'clean_air', 'sunny_day', 'blue_sky']
senticnet['bright_yellow'] = [0.026, 0, 0, 0.116, '#joyful', '#admirable', 0.047, 'source_light', 'celestial_body', 'limitless', 'around_earth', 'sol']
senticnet['brightness'] = [0.976, 0, 0, 0.741, '#joyful', '#admirable', 0.572, 'ray', 'light', 'electromagnetic_radiation', 'illumination', 'photon']
senticnet['brightness_level'] = [0.637, -0.713, 0, 0.932, '#surprising', '#admirable', 0.761, 'glow', 'illumination', 'incandescence', 'luminescence', 'illuminance']
senticnet['brilliant'] = [0.829, 0, 0, 0.906, '#joyful', '#admirable', 0.578, 'really_good', 'better_good', 'most_good', 'well_done', 'high_quality']
senticnet['brim'] = [0.034, 0.197, -0.085, 0.137, '#interesting', '#admirable', 0.094, 'zenith', 'top', 'apex', 'facet', 'pointy']
senticnet['brine'] = [0.02, 0.076, 0, 0, '#joyful', '#interesting', 0.032, 'land_earth', 'tidal_wave', 'puddle', 'hot_water_heater', 'spurt']
senticnet['bring'] = [0, 0.207, -0.186, 0.341, '#interesting', '#admirable', 0.121, 'carry', 'accept', 'take', 'tote', 'come']
senticnet['bring_a_lot_of_money'] = [0.719, 0.988, 0, 0, '#joyful', '#interesting', 0.569, 'go_to_shopping_mall', 'shopping', 'drive_to_store', 'go_department_store', 'find_merchant']
senticnet['bring_around'] = [0.658, -0.605, 0, 0.691, '#joyful', '#admirable', 0.651, 'bring_up', 'revive', 'resurrect', 'boot', 'reboot']
senticnet['bring_book'] = [-0.962, 0, 0, -0.876, '#sad', '#disgusting', -0.613, 'enroll_class', 'enroll', 'matriculate', 'plan_time', 'go_meet']
senticnet['bring_cash'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'find_shop', 'shopping', 'bring_money', 'go_supermarket', 'enough_money']
senticnet['bring_dog'] = [-0.078, -0.076, 0.082, -0.061, '#sad', '#angry', -0.048, 'put_sneaker', 'move_leg', 'put_jogging_shoes', 'put_shoes', 'stretch_muscle']
senticnet['bring_food'] = [0.872, 0, 0, 0.855, '#joyful', '#admirable', 0.576, 'mow_grass', 'meet_need', 'clean_sink', 'help_person', 'mop_floor']
senticnet['bring_friend'] = [-0.736, 0, 0.756, 0, '#sad', '#angry', -0.497, 'enjoy_art', 'go_symphony', 'buy_popcorn', 'understand_plot', 'insert_dvd_in_player']
senticnet['bring_gift'] = [0.719, 0.988, 0, 0, '#joyful', '#interesting', 0.569, 'anniversary', 'visit_friend', 'present', 'birthday', 'surprise']
senticnet['bring_happiness'] = [0.8, 0, 0, 0.845, '#joyful', '#admirable', 0.548, 'happy', 'good_feeling', 'make_happy', 'express_love', 'say_thank_you']
senticnet['bring_home'] = [0.935, -0.661, 0, 0.93, '#joyful', '#admirable', 0.842, 'demo', 'show', 'demonstrate', 'exhibit', 'present']
senticnet['bring_home_bacon'] = [0.945, -0.732, 0, 0.779, '#joyful', '#admirable', 0.819, 'clear', 'pan_out', 'reach', 'bring_off', 'luck_out']
senticnet['bring_joy'] = [-0.17, -0.017, -0.127, -0.126, '#sad', '#scared', -0.135, 'make_cry', 'wet_oneself', 'amount_nothing', 'play_hard', 'act_foolish']
senticnet['bring_money'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'bring_cash', 'pay_bill', 'shopping', 'purchase_ticket', 'rich']
senticnet['bring_off'] = [0.718, -0.729, 0, 0.928, '#surprising', '#admirable', 0.792, 'deliver_goods', 'succeed', 'win', 'bring_home_bacon', 'come_through']
senticnet['bring_out'] = [0.58, -0.821, 0, 0.77, '#surprising', '#admirable', 0.724, 'show', 'expose', 'trot_out', 'unfold', 'disclose']
senticnet['bring_present'] = [0, 0.076, -0.065, 0.205, '#interesting', '#admirable', 0.072, 'cover_body', 'put_clothes', 'christmas', 'carry_book', 'move_away']
senticnet['bring_together'] = [0.065, 0.209, -0.119, 0.297, '#interesting', '#admirable', 0.151, 'come_together', 'put_together', 'gather', 'fuse_together', 'inclusion']
senticnet['bring_up'] = [0, 0.296, -0.147, 0.359, '#interesting', '#admirable', 0.169, 'pull_up', 'rise_up', 'raise_up', 'upward_movement', 'go_up']
senticnet['bring_wallet'] = [0.956, -0.823, 0, 0, '#joyful', '#surprising', 0.593, 'bring_money', 'pay_bill', 'go_shopping', 'need_money', 'credit_card']
senticnet['bringing_up'] = [0.902, -0.5, 0, 0.716, '#joyful', '#admirable', 0.706, 'breeding', 'fostering', 'fosterage', 'cultivation', 'enculturation']
senticnet['brio'] = [0.586, -0.519, 0, 0.949, '#joyful', '#admirable', 0.685, 'chirpiness', 'spirit', 'sprightliness', 'liveliness', 'activity']
senticnet['brisk'] = [0.887, 0.742, 0, 0, '#joyful', '#interesting', 0.543, 'lively', 'merry', 'rattling', 'snappy', 'fresh']
senticnet['brisket'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'beef', 'pork', 'french_toast', 'steak', 'ham']
senticnet['bristle'] = [-0.027, -0.051, -0.058, -0.055, '#scared', '#disgusting', -0.03, 'motor_oil', 'make_toy', 'engine', 'emission', 'castor']
senticnet['bristletail'] = [-0.703, 0, 0.994, -0.99, '#angry', '#disgusting', -0.896, 'insect', 'thysanuran_insect', 'silverfish', 'jumping_thysanuran_insect', 'machilid']
senticnet['brittle'] = [0, -0.988, 0, 0.728, '#surprising', '#admirable', 0.572, 'translucent', 'clear_solid', 'see_thru', 'drink_container', 'transparent']
senticnet['bro'] = [0.104, 0, 0, 0.088, '#joyful', '#admirable', 0.064, 'baby_flower', 'wee', 'bud', 'part_of_plant', 'leafy']
senticnet['broad'] = [0, 0.098, -0.064, 0.118, '#interesting', '#admirable', 0.051, 'egret', 'tall_man', 'wide', 'wood_structure', 'large']
senticnet['broadcast'] = [0, 0.07, 0, 0.071, '#interesting', '#admirable', 0.047, 'film_studio', 'tv_studio', 'cinema', 'theater', 'movie']
senticnet['broaden_horizon'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'expand_knowledge', 'find_out_world', 'learn_culture', 'learn_universe', 'learn_entertainment']
senticnet['broadsword'] = [0.93, -0.78, 0, 0.873, '#joyful', '#admirable', 0.861, 'blade', 'brand', 'steel', 'claymore', 'sword']
senticnet['broadway_play'] = [-0.074, 0, -0.133, 0, '#sad', '#scared', -0.069, 'stage_play', 'role_play', 'play_part', 'play_in_theater', 'drama']
senticnet['broccoli'] = [0, -0.006, 0.053, -0.037, '#angry', '#disgusting', -0.028, 'kale', 'cucumber', 'cabbage', 'lettuce', 'pea']
senticnet['broke'] = [-0.928, 0, 0.982, 0, '#sad', '#angry', -0.637, 'lose_credibility', 'without_money', 'abuse', 'feel_stressed', 'go_bankrupt']
senticnet['broken'] = [-0.948, 0, -0.818, 0, '#sad', '#scared', -0.589, 'panic_attack', 'frighten', 'humiliation', 'depress', 'embarrass']
senticnet['broken_arm'] = [-0.265, -0.102, -0.105, -0.268, '#sad', '#disgusting', -0.179, 'broken_finger', 'hit_face', 'bad_knee', 'physical_pain', 'car_wreck']
senticnet['broken_bone'] = [0, 0, -0.748, -0.84, '#scared', '#disgusting', -0.529, 'bad_knee', 'injury', 'bruise', 'strengthful', 'hurt']
senticnet['broken_car'] = [0, 0, 0.867, -0.88, '#angry', '#disgusting', -0.582, 'work_well', 'damage_car', 'need_fix', 'car_engine', 'car_wheel']
senticnet['broken_computer'] = [-0.987, 0, 0.741, 0, '#sad', '#angry', -0.576, 'cold_hot', 'thunder', 'tropical_storm', 'hurricane', 'electric_shock']
senticnet['broken_engine'] = [0, 0, -0.943, -0.77, '#scared', '#disgusting', -0.571, 'engine_issue', 'broken_car', 'flat_tyre', 'broken_shelf', 'need_fix']
senticnet['broken_finger'] = [-0.984, 0, 0, -0.943, '#sad', '#disgusting', -0.642, 'schizophrenia', 'censorship', 'physical_pain', 'disrespect', 'black_eye']
senticnet['broken_glass'] = [-0.817, -0.739, 0, -0.766, '#sad', '#disgusting', -0.281, 'sharp_object', 'broken_limb', 'concussion', 'spoil_food', 'frostbite']
senticnet['broken_guitar'] = [-0.907, 0, 0.425, -0.907, '#sad', '#disgusting', -0.746, 'break', 'break_instrument', 'damage', 'destroy', 'broken']
senticnet['broken_heart'] = [-0.876, 0, 0, -0.784, '#sad', '#disgusting', -0.553, 'std', 'anguish', 'terminal_disease', 'bad_feeling', 'loneliness']
senticnet['broken_home'] = [-0.857, 0, 0.968, -0.895, '#angry', '#disgusting', -0.907, 'family', 'household', 'house', 'home', 'menage']
senticnet['broken_law'] = [0, 0.077, -0.127, -0.126, '#scared', '#disgusting', -0.059, 'stupidity', 'controversy', 'drink_booze', 'retribution', 'teach_lesson']
senticnet['broken_leg'] = [-0.926, 0, 0, -0.999, '#sad', '#disgusting', -0.642, 'get_injured', 'sprain_ankle', 'knee_injury', 'become_exhausted', 'broken_window']
senticnet['broken_limb'] = [-0.827, 0, -0.867, 0, '#sad', '#scared', -0.565, 'bloody_nose', 'fall_head', 'bang_head', 'fall_ground', 'crash_car']
senticnet['broken_shelf'] = [0, 0, -0.943, -0.77, '#scared', '#disgusting', -0.571, 'break', 'without_support', 'damage', 'need_fix', 'destroy']
senticnet['broken_window'] = [-0.245, -0.155, 0.011, -0.338, '#sad', '#disgusting', -0.146, 'step_dog_shit', 'broken_wrist', 'broken_leg', 'bloody_nose', 'back_pain']
senticnet['broken_wrist'] = [-0.902, 0, -0.914, -0.734, '#sad', '#scared', -0.85, 'broken_window', 'step_dog_shit', 'broken_leg', 'brain_tumor', 'bad_luck']
senticnet['brokenhearted'] = [-0.988, 0, 0.034, -0.949, '#sad', '#disgusting', -0.657, 'hurt', 'painful', 'pain', 'bad_feeling', 'injury']
senticnet['brokenheartedness'] = [-0.894, 0.161, -0.613, 0.053, '#sad', '#scared', -0.431, 'heartrending', 'heartbreaking', 'grievous', 'grievously', 'aggrieve']
senticnet['broker'] = [-0.03, 0.207, -0.09, 0.235, '#interesting', '#admirable', 0.107, 'business_transaction', 'deal', 'trade', 'transaction', 'business_deal']
senticnet['bromide'] = [0.032, -0.022, -0.045, -0.087, '#scared', '#disgusting', -0.026, 'liquid', 'carbonate_drink', 'chemical', 'soda', 'bromine']
senticnet['bromine'] = [0.032, -0.022, -0.045, -0.087, '#scared', '#disgusting', -0.026, 'liquid', 'carbonate_drink', 'chemical', 'soda', 'bromide']
senticnet['bronchial_pneumonia'] = [-0.926, 0, 0.824, -0.522, '#sad', '#angry', -0.757, 'bronchopneumonia', 'pneumonia', 'viral_pneumonia', 'pleuropneumonia', 'pneumococcal_pneumonia']
senticnet['bronchiolitis'] = [-0.788, 0, 0.993, -0.654, '#sad', '#angry', -0.812, 'bronchitis', 'chronic_bronchitis', 'respiratory_disease', 'respiratory_illness', 'respiratory_disorder']
senticnet['bronchitis'] = [-0.788, 0, 0.993, -0.654, '#sad', '#angry', -0.812, 'bronchiolitis', 'chronic_bronchitis', 'respiratory_disease', 'respiratory_illness', 'respiratory_disorder']
senticnet['bronchopneumonia'] = [-0.926, 0, 0.824, -0.522, '#sad', '#angry', -0.757, 'pneumonia', 'bronchial_pneumonia', 'viral_pneumonia', 'pleuropneumonia', 'pneumococcal_pneumonia']
senticnet['bronx_cheer'] = [-0.869, 0, 0.516, -0.769, '#sad', '#disgusting', -0.718, 'outcry', 'call', 'cry', 'yell', 'shout']
senticnet['bronze'] = [0.87, 0.822, 0, 0.717, '#joyful', '#interesting', 0.803, 'gold', 'medal', 'alloy', 'titanium', 'copper']
senticnet['brood'] = [-0.041, 0.174, 0.679, -0.655, '#angry', '#disgusting', -0.4, 'maleficence', 'malefic', 'malign', 'spitefulness', 'maliciousness']
senticnet['brooding'] = [-0.834, 0, -0.978, 0, '#sad', '#scared', -0.604, 'pondering', 'ruminative', 'broody', 'pensiveness', 'meditative']
senticnet['broody'] = [0.974, 0.904, 0, 0, '#joyful', '#interesting', 0.626, 'pondering', 'cogitative', 'contemplative', 'meditative', 'think']
senticnet['brook'] = [-0.993, 0, 0.871, -0.559, '#sad', '#angry', -0.808, 'endure', 'bear_up', 'tolerate', 'stomach', 'abide']
senticnet['broomstick'] = [0.048, -0.104, 0, 0.18, '#surprising', '#admirable', 0.111, 'door_knob', 'door_opener', 'carry_suitcase', 'handle', 'bicycle_part']
senticnet['broth'] = [0.07, 0.084, 0.023, 0, '#joyful', '#interesting', 0.044, 'hearty', 'porridge', 'hot_liquid', 'liquid_food', 'meat_vegetable']
senticnet['brothel'] = [0.754, -0.823, 0, 0.947, '#surprising', '#admirable', 0.841, 'whorehouse', 'massage_parlor', 'bordello', 'bagnio', 'house_of_prostitution']
senticnet['brother'] = [0, 0.836, 0, 0.943, '#interesting', '#admirable', 0.593, 'family_member', 'dad', 'daddy', 'mother_daddy', 'uncle']
senticnet['brother_like'] = [0.648, 0.627, -0.267, 0.329, '#joyful', '#interesting', 0.446, 'brotherly', 'brotherhood', 'fraternal', 'amicability', 'amicable']
senticnet['brother_sister'] = [0, 0.786, 0, 0.783, '#interesting', '#admirable', 0.523, 'mom_dad', 'female_sibling', 'cousin', 'mother_father', 'relation']
senticnet['brotherhood'] = [0.648, 0.627, -0.267, 0.329, '#joyful', '#interesting', 0.446, 'brotherly', 'brother_like', 'fraternal', 'amicability', 'amicable']
senticnet['brotherly'] = [0.605, 0.647, -0.266, 0.323, '#joyful', '#interesting', 0.436, 'brother_like', 'fraternal', 'amicableness', 'amicably', 'amicable']
senticnet['brown'] = [0.711, 0, 0, 0.912, '#joyful', '#admirable', 0.541, 'opaque', 'beautiful_well_useful', 'same_again', 'small', 'poisonous_human']
senticnet['brown_algae'] = [-0.659, 0, 0.523, -0.739, '#sad', '#disgusting', -0.64, 'confervoid_algae', 'seaweed', 'golden_algae', 'diatom', 'alga']
senticnet['brown_bear'] = [0, 0.967, 0, 0.795, '#interesting', '#admirable', 0.587, 'animal', 'grizzly_bear', 'forest', 'creatures', 'polar_bear']
senticnet['brown_fur'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'brown_bear', 'woodland_creature', 'hairy_animal', 'huge_animal', 'brown_hair']
senticnet['brown_hair'] = [0, 0.722, 0, 0.975, '#interesting', '#admirable', 0.566, 'plato', 'natural_world', 'hair', 'feature', 'stick_out']
senticnet['brown_hamburger'] = [-0.077, 0, 0, 0, '#sad', '#sad', -0.026, 'heat_meal', 'salt_food', 'burn_trash', 'bone_chicken', 'play_jack']
senticnet['brown_leaf'] = [0.034, 0.111, -0.094, 0.148, '#interesting', '#admirable', 0.066, 'ant_hill', 'hike_trail', 'tress', 'stake', 'oak']
senticnet['brown_meat'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'cook_meat', 'cook_hamburger', 'cook_food', 'baker', 'eat_outdoors']
senticnet['brown_rot'] = [-0.833, 0, 0.754, -0.979, '#sad', '#disgusting', -0.855, 'brown_rot_gummosis', 'ring_rot', 'ring_disease', 'tobacco_wilt', 'gummosis']
senticnet['brown_rot_gummosis'] = [-0.833, 0, 0.754, -0.979, '#sad', '#disgusting', -0.855, 'brown_rot', 'ring_rot', 'ring_disease', 'tobacco_wilt', 'gummosis']
senticnet['brownie'] = [0.084, -0.117, -0.046, 0, '#joyful', '#surprising', 0.052, 'mousse', 'cookie', 'cake', 'custard', 'doughnut']
senticnet['brownie_point'] = [0.751, 0, 0, 0.992, '#joyful', '#admirable', 0.581, 'gratification', 'good_deed', 'appreciate', 'recognition', 'acknowledgment']
senticnet['brownish_yellow'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'yellowness', 'canary_yellow', 'old_gold', 'gold', 'canary']
senticnet['brownness'] = [-0.741, 0, 0.585, -0.612, '#sad', '#disgusting', -0.646, 'buff', 'chestnut', 'chocolate', 'coffee', 'deep_brown']
senticnet['brownstone'] = [0, 0.939, 0, 0.997, '#interesting', '#admirable', 0.645, 'condominium', 'rent_apartment', 'high_rise', 'condo', 'row_house']
senticnet['browse'] = [-0.92, 0, 0.74, -0.762, '#sad', '#disgusting', -0.807, 'bush', 'flora', 'scrub', 'groundcover', 'ground_cover']
senticnet['browse_web'] = [0.771, -0.903, 0, 0, '#joyful', '#surprising', 0.558, 'operate_computer', 'entertainment', 'kill_time', 'research', 'surf_net']
senticnet['browser'] = [-0.629, 0, 0.717, -0.978, '#angry', '#disgusting', -0.775, 'witness', 'spectator', 'viewer', 'watcher', 'looker']
senticnet['bruise'] = [0, 0, 0, -0.934, '#disgusting', '#disgusting', -0.311, 'injury', 'broken_bone', 'bad_knee', 'strengthful', 'physical_pain']
senticnet['bruised'] = [0, 0, -0.903, -0.745, '#scared', '#disgusting', -0.549, 'contuse', 'hurt', 'wound', 'injure', 'offend']
senticnet['brunt'] = [-0.929, 0, 0.946, -0.567, '#sad', '#angry', -0.814, 'forcefulness', 'intensiveness', 'impulse', 'vigor', 'energy']
senticnet['brush'] = [0.947, -0.799, 0, 0, '#joyful', '#surprising', 0.582, 'use_brush', 'hair', 'brush_hair', 'brush_tooth', 'paintbrush']
senticnet['brush_down'] = [-0.582, 0, 0.633, -0.741, '#angry', '#disgusting', -0.652, 'call_on_carpet', 'take_to_task', 'chide', 'berate', 'bawl_out']
senticnet['brush_hair'] = [0.811, -0.837, 0, 0, '#joyful', '#surprising', 0.549, 'use_brush', 'hair', 'use_brush_air', 'brush', 'brush_tooth']
senticnet['brush_off'] = [-0.361, -0.076, -0.048, -0.261, '#sad', '#disgusting', -0.198, 'fail_class', 'deflate', 'investigate_fact', 'make_sad', 'ask_question']
senticnet['brush_tooth'] = [0.706, -0.944, 0, 0, '#joyful', '#surprising', 0.55, 'fresh_breathe', 'clean_teeth', 'go_bathroom', 'teeth_whitening', 'remove_stain']
senticnet['brushed'] = [0.888, -0.683, 0, 0.914, '#joyful', '#admirable', 0.828, 'tidy', 'kempt', 'sleek', 'pomaded', 'groomed']
senticnet['brusk'] = [0.694, -0.554, 0, 0.894, '#joyful', '#admirable', 0.714, 'curt', 'brusque', 'discourteous', 'abrupt', 'unceremonious']
senticnet['brusque'] = [0, 0, 0.766, -0.81, '#angry', '#disgusting', -0.525, 'curt', 'discourteous', 'brusk', 'abrupt', 'unceremonious']
senticnet['brute'] = [-0.79, 0, 0.7, -0.517, '#sad', '#angry', -0.669, 'animal', 'animate_being', 'beast', 'creature', 'giant']
senticnet['bubble'] = [-0.559, 0, 0.869, -0.838, '#angry', '#disgusting', -0.755, 'air_bubble', 'foam', 'froth', 'soap_bubble', 'globule']
senticnet['bubble_dance'] = [0.993, -0.967, 0, 0.917, '#joyful', '#surprising', 0.959, 'strip', 'fan_dance', 'striptease', 'strip_show', 'nude_dancing']
senticnet['bubbly'] = [0.838, 0.951, 0, 0, '#joyful', '#interesting', 0.596, 'clean_agent', 'foam', 'lather', 'wash_self', 'cleanser']
senticnet['bubonic_plague'] = [-0.861, 0, 0.825, -0.544, '#sad', '#angry', -0.743, 'pestis', 'plague', 'pestilence', 'pest', 'ambulant_plague']
senticnet['buck'] = [0, 0.144, 0.031, 0.129, '#interesting', '#admirable', 0.081, 'money_unit', 'currency_unit', 'form_of_money', 'monetary_unit', 'paper_currency']
senticnet['buck_fever'] = [-0.791, 0, 0, -0.71, '#sad', '#disgusting', -0.5, 'fevered', 'feverishly', 'feverish', 'hectic', 'anticipant']
senticnet['bucked_up'] = [0.485, 0.672, -0.261, 0.255, '#joyful', '#interesting', 0.384, 'encouraged', 'encouragingly', 'encouraging', 'optimistic', 'optimistically']
senticnet['bucket_overflow'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'flat', 'dirty_floor', 'spill_over', 'float', 'spoil_wood_floor']
senticnet['buckle'] = [0, 0.068, -0.065, 0.081, '#interesting', '#admirable', 0.028, 'pyramid', 'japanese_person', 'mexican_restaurant', 'anemone', 'herringbone']
senticnet['buckle_under'] = [0.839, -0.888, 0, 0.957, '#surprising', '#admirable', 0.895, 'consent', 'give_in', 'go_for', 'submit', 'accept']
senticnet['buckshee'] = [-0.972, 0, 0.53, -0.666, '#sad', '#disgusting', -0.723, 'uncompensated', 'unsalaried', 'unpaid', 'undischarged', 'complimentary']
senticnet['bud'] = [0.104, 0, 0, 0.088, '#joyful', '#admirable', 0.064, 'baby_flower', 'wee', 'bro', 'part_of_plant', 'leafy']
senticnet['buddha'] = [0.063, 0.099, 0, 0.119, '#interesting', '#admirable', 0.094, 'a_lot_of_time', 'own_computer', 'learn_program_language', 'turn_computer_on', 'write_email']
senticnet['buddhism'] = [0, 0.287, 0, 0.252, '#interesting', '#admirable', 0.18, 'judaism', 'christianity', 'religious_purpose', 'steeple', 'prayer']
senticnet['buddhist'] = [0, 0, 0, 0.071, '#admirable', '#admirable', 0.024, 'two_horses', 'horse', 'mule', 'barb', 'ride_horse']
senticnet['budding'] = [-0.778, 0, 0.764, -0.548, '#sad', '#angry', -0.697, 'pullulation', 'apomixis', 'blastogenesis', 'asexual_reproduction', 'fission']
senticnet['buddy'] = [0.17, 0.125, -0.046, 0.196, '#joyful', '#admirable', 0.148, 'pal', 'single_person', 'comrade', 'good', 'companion']
senticnet['budget'] = [-0.054, 0.282, -0.046, 0.107, '#interesting', '#admirable', 0.096, 'expense', 'dollar_cent', 'dollar_sign', 'amount_pay', 'payment_amount']
senticnet['buff'] = [-0.741, 0, 0.585, -0.612, '#sad', '#disgusting', -0.646, 'brownness', 'chestnut', 'chocolate', 'coffee', 'deep_brown']
senticnet['buffet'] = [0.128, -0.041, 0, 0, '#joyful', '#surprising', 0.056, 'banquet', 'rave', 'auction', 'limbo', 'loose_end']
senticnet['buffoon'] = [0, 0, 0, 0.07, '#admirable', '#admirable', 0.023, 'source_code', 'computer', 'browser', 'dvd', 'clown']
senticnet['buffoonery'] = [0.931, -0.847, 0, 0.829, '#joyful', '#surprising', 0.869, 'folly', 'lunacy', 'craziness', 'indulgence', 'shtik']
senticnet['bug'] = [-0.023, -0.051, 0.082, -0.072, '#angry', '#disgusting', -0.042, 'insect', 'beetle', 'cutworm', 'annoy_bug', 'pest']
senticnet['bug_person'] = [-0.126, 0, 0, -0.036, '#sad', '#disgusting', -0.054, 'throw_fit', 'poke', 'sun_oneself', 'shoulder_responsibility', 'visit_grandmother']
senticnet['bugger_all'] = [-0.554, 0, 0.882, -0.735, '#angry', '#disgusting', -0.724, 'null', 'zero', 'naught', 'zip', 'nothing']
senticnet['buggery'] = [-0.848, 0, 0.882, -0.829, '#sad', '#angry', -0.853, 'perversion', 'fetishism', 'paraphilia', 'sodomy', 'sexual_perversion']
senticnet['bugginess'] = [0.789, -0.998, 0, 0.54, '#joyful', '#surprising', 0.776, 'imperfection', 'imperfectness', 'defectiveness', 'lameness', 'sickness']
senticnet['bugle'] = [0.033, 0, 0.009, 0.057, '#joyful', '#admirable', 0.027, 'triangle', 'baton', 'type_of_bow', 'clavichord', 'horn']
senticnet['build'] = [0.994, 0, 0, 0.772, '#joyful', '#admirable', 0.589, 'large_architectural_structure', 'architectural_structure', 'home_architectural_structure', 'architect', 'structure_support']
senticnet['build_block'] = [0.84, 0, 0, 0.989, '#joyful', '#admirable', 0.61, 'game_part', 'life_like', 'child_toy', 'small_object', 'object']
senticnet['build_boat'] = [0.035, 0.083, 0, 0.128, '#interesting', '#admirable', 0.082, 'woodworking', 'sailing', 'workshop', 'repair', 'expensive']
senticnet['build_bridge'] = [-0.053, 0.111, 0, 0.12, '#interesting', '#admirable', 0.059, 'build_house', 'construct', 'build_wall', 'shore_up_wall', 'fix_car']
senticnet['build_building'] = [0, 0.139, 0.037, 0.086, '#interesting', '#admirable', 0.063, 'buy_land', 'personal_belong', 'build_structure', 'build_process', 'make']
senticnet['build_cathedral'] = [0.031, 0.202, 0.049, 0.196, '#interesting', '#admirable', 0.127, 'chapel', 'temple', 'catholic_church', 'place_of_worship', 'altar']
senticnet['build_city'] = [0, 0, 0, 0.821, '#admirable', '#admirable', 0.274, 'speak_human_language', 'assert', 'see_well', 'live_forever', 'like_play']
senticnet['build_computer'] = [0, 0, 0, 0.911, '#admirable', '#admirable', 0.304, 'find_computer', 'visit_zoo', 'start_computer', 'switch_computer', 'log_off']
senticnet['build_endurance'] = [0.08, -0.063, 0.045, 0, '#joyful', '#surprising', 0.033, 'strengthen_heart', 'get_physically_fit', 'keep_fit', 'enjoy_outdoors', 'keep_shape']
senticnet['build_foundation'] = [0.487, 0.675, -0.267, 0.266, '#joyful', '#interesting', 0.387, 'put_basis', 'solid_basis', 'study_hard', 'intelligent', 'gather_intelligence']
senticnet['build_ground'] = [-0.097, 0, 0.033, 0, '#sad', '#angry', -0.043, 'cover_ground', 'horizontal_plane', 'underfoot', 'wood_board', 'basis']
senticnet['build_home'] = [0, 0.099, -0.074, 0.135, '#interesting', '#admirable', 0.053, 'place_where_people_live', 'small_building', 'live_life', 'good_investment', 'live_area']
senticnet['build_house'] = [-0.067, 0.121, 0, 0.098, '#interesting', '#admirable', 0.051, 'build_bridge', 'new_house', 'build_wall', 'build_home', 'construct']
senticnet['build_muscle'] = [0.734, 0.729, 0, 0, '#joyful', '#interesting', 0.488, 'increase_energy', 'keep_body_healthy', 'improve_self-image', 'lower_blood_pressure', 'feel_energized']
senticnet['build_on'] = [-0.939, 0, 0.595, -0.835, '#sad', '#disgusting', -0.79, 'ride', 'owe', 'depend_on', 'depend_upon', 'turn_on']
senticnet['build_open'] = [0, 0.773, 0, 0.902, '#interesting', '#admirable', 0.558, 'home_entrance', 'aperture', 'use_farm', 'hinge', 'entry']
senticnet['build_part'] = [-0.026, 0.077, 0.048, 0.131, '#interesting', '#admirable', 0.045, 'horizontal_plane', 'entrance_room', 'room_part', 'house_part', 'build_ground']
senticnet['build_process'] = [0, 0.13, 0, 0.207, '#interesting', '#admirable', 0.112, 'make_factory', 'make_goods', 'construct', 'make', 'make_product']
senticnet['build_strength'] = [0, 0.13, 0, 0.207, '#interesting', '#admirable', 0.112, 'become_better', 'feel_better_oneself', 'strengthen_muscle', 'go_to_gym', 'increase_energy']
senticnet['build_strong_muscle'] = [0.068, -0.025, 0.016, 0, '#joyful', '#surprising', 0.026, 'build_muscle', 'become_fit', 'build_endurance', 'good_health', 'improve_health']
senticnet['build_structure'] = [-0.03, 0.138, 0, 0.168, '#interesting', '#admirable', 0.092, 'construction', 'construct', 'build_support', 'make', 'support_wall']
senticnet['build_support'] = [0, 0.115, 0, 0.124, '#interesting', '#admirable', 0.08, 'construction', 'architectural_structure', 'support_wall', 'building', 'construct_building']
senticnet['build_tower_out_toy_block'] = [0.081, 0.095, 0, 0, '#joyful', '#interesting', 0.059, 'children_toy', 'stacking_game', 'play', 'children_funtime', 'playroom']
senticnet['build_upon'] = [-0.585, 0, 0.837, -0.558, '#sad', '#angry', -0.66, 'ride', 'owe', 'depend_on', 'depend_upon', 'turn_on']
senticnet['build_wall'] = [-0.053, 0.111, 0, 0.12, '#interesting', '#admirable', 0.059, 'build_house', 'construct', 'build_bridge', 'wall', 'protection']
senticnet['builder'] = [0, 0.233, -0.079, 0.113, '#interesting', '#admirable', 0.089, 'structure', 'construction_worker', 'peasant', 'functionary', 'maker']
senticnet['building'] = [0, 0.119, 0, 0.095, '#interesting', '#admirable', 0.071, 'accommodation', 'government', 'govern_city', 'government_accommodation', 'large_accommodation']
senticnet['building_permit'] = [0.673, -0.664, 0, 0.921, '#joyful', '#admirable', 0.753, 'instrument', 'license', 'driver_license', 'driver_licence', 'driving_license']
senticnet['buildup'] = [0.942, -0.798, 0, 0.901, '#joyful', '#admirable', 0.88, 'backup', 'accretion', 'deposition', 'deposit', 'increase']
senticnet['bulge'] = [0.737, -0.96, 0, 0.552, '#joyful', '#surprising', 0.75, 'prominence', 'hump', 'bump', 'swelling', 'frontal_eminence']
senticnet['bulging'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'fat', 'heavy_dinner', 'enlarged', 'expanded', 'bloated']
senticnet['bulima_nervosa'] = [-0.525, 0, 0.786, -0.927, '#angry', '#disgusting', -0.746, 'upset', 'bulimarexia', 'eating_disorder', 'bulimia', 'disorder']
senticnet['bulimarexia'] = [-0.525, 0, 0.786, -0.927, '#angry', '#disgusting', -0.746, 'upset', 'eating_disorder', 'bulima_nervosa', 'bulimia', 'disorder']
senticnet['bulimia'] = [-0.525, 0, 0.786, -0.927, '#angry', '#disgusting', -0.746, 'upset', 'bulimarexia', 'bulima_nervosa', 'eating_disorder', 'disorder']
senticnet['bulimia_nervosa'] = [-0.525, 0, 0.786, -0.927, '#angry', '#disgusting', -0.746, 'upset', 'bulimarexia', 'eating_disorder', 'bulimia', 'disorder']
senticnet['bulk_large'] = [0.056, 0.105, 0.786, -0.681, '#angry', '#disgusting', -0.435, 'huffishness', 'sulkiness', 'sulk', 'hover', 'loom']
senticnet['bull_pine'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'ponderosa', 'ponderosa_pine', 'western_yellow_pine', 'yellow_pine', 'longleaf_pine']
senticnet['bulla'] = [-0.836, 0, 0.743, -0.678, '#sad', '#angry', -0.752, 'blood_blister', 'pustule', 'water_blister', 'vesicle', 'cyst']
senticnet['bullet'] = [0, 0, -0.77, -0.95, '#scared', '#disgusting', -0.573, 'projectile', 'bayonet', 'shotgun', 'hydrogen_bomb', 'ammunition']
senticnet['bullet_hole'] = [-0.528, 0, 0.785, -0.617, '#angry', '#disgusting', -0.643, 'gap', 'rathole', 'aperture', 'hole', 'cranny']
senticnet['bulletin'] = [0, 0.733, 0, 0.989, '#interesting', '#admirable', 0.574, 'current_event', 'headline', 'paper_write', 'paper_page', 'many_pages']
senticnet['bulletproof'] = [-0.897, 0, 0.945, -0.894, '#sad', '#angry', -0.912, 'armored', 'mailed', 'lightly_armored', 'lightly_armoured', 'scaled']
senticnet['bulletproof_vest'] = [0.939, -0.632, 0, 0.653, '#joyful', '#admirable', 0.741, 'vest', 'waistcoat', 'body_armor', 'suit_of_armor', 'coat_of_mail']
senticnet['bullheadedness'] = [-0.633, 0, 0.942, -0.528, '#sad', '#angry', -0.701, 'stubbornness', 'obstinacy', 'obstinance', 'impenitence', 'pigheadedness']
senticnet['bullrush'] = [0.656, -0.632, 0, 0.844, '#joyful', '#admirable', 0.711, 'cattail', 'bulrush', 'nailrod', 'reed_mace', 'reedmace']
senticnet['bullseye'] = [0.969, -0.872, 0, 0, '#joyful', '#surprising', 0.614, 'baseball_bat', 'water_gun', 'goalie', 'hockey_puck', 'hockey_stick']
senticnet['bullshit'] = [0, 0, 0, -0.776, '#disgusting', '#disgusting', -0.259, 'icon', 'note_pad', 'scrap_paper', 'attendee', 'agenda']
senticnet['bully'] = [0, 0, 0.894, -0.772, '#angry', '#disgusting', -0.555, 'criminal', 'revenge', 'murderer', 'kill_another_person', 'vengeance']
senticnet['bullyboy'] = [-0.684, 0, 0.837, -0.627, '#sad', '#angry', -0.716, 'hooligan', 'ruffian', 'roughneck', 'rowdy', 'yob']
senticnet['bullying'] = [-0.91, 0, 0.521, -0.811, '#sad', '#disgusting', -0.747, 'domineering', 'peremptory', 'blustery', 'roughshod', 'cavalier']
senticnet['bulrush'] = [0.656, -0.632, 0, 0.844, '#joyful', '#admirable', 0.711, 'bullrush', 'cattail', 'nailrod', 'reed_mace', 'reedmace']
senticnet['bulwark'] = [0, 0, -0.801, -0.777, '#scared', '#disgusting', -0.526, 'wall', 'mole', 'groin', 'rampart', 'breakwater']
senticnet['bum'] = [-0.127, 0, -0.063, -0.046, '#sad', '#scared', -0.079, 'graffiti', 'homeless_people', 'homeless_person', 'panhandler', 'homeless']
senticnet['bumbling'] = [-0.61, 0, 0.533, -0.971, '#sad', '#disgusting', -0.705, 'bungling', 'maladroit', 'butterfingered', 'inept', 'handless']
senticnet['bummer'] = [-0.948, 0, 0.557, -0.716, '#sad', '#disgusting', -0.74, 'tally', 'sum', 'enumeration', 'twice', 'numerical']
senticnet['bump'] = [0.03, 0, 0.017, 0.138, '#joyful', '#admirable', 0.05, 'up_down', 'curl', 'crest', 'hand_gesture', 'goodbye']
senticnet['bump_head'] = [-0.16, -0.092, 0, -0.202, '#sad', '#disgusting', -0.09, 'pass_out', 'collapse', 'dog_bark', 'breahard', 'become_fatigued']
senticnet['bump_into'] = [-0.536, 0, 0.57, -0.732, '#angry', '#disgusting', -0.613, 'run_into', 'strike', 'hit', 'impinge_on', 'collide_with']
senticnet['bumper'] = [0, -0.033, 0, 0.064, '#surprising', '#admirable', 0.032, 'clutch', 'fan_belt', 'brake_pedal', 'emergency_brake', 'windshield']
senticnet['bumpy'] = [-0.087, -0.034, 0.048, -0.029, '#sad', '#angry', -0.043, 'flat_land', 'grow_corn', 'farm_crop', 'stalk', 'cold_night']
senticnet['bun'] = [0.035, -0.049, 0.038, 0.088, '#surprising', '#admirable', 0.045, 'round_bread', 'food_bake', 'loaf', 'breakfast_food', 'chewy']
senticnet['bunch'] = [-0.635, 0, 0.862, -0.523, '#sad', '#angry', -0.673, 'knot', 'swad', 'tuft', 'tussock', 'agglomeration']
senticnet['bunch_person'] = [0.078, 0, 0.014, 0.095, '#joyful', '#admirable', 0.053, 'big_group', 'large_group', 'large_number', 'mass_person', 'push_together']
senticnet['bunchberry'] = [0.773, -0.55, 0, 0.949, '#joyful', '#admirable', 0.757, 'cornel', 'dwarf_cornel', 'crackerberry', 'pudding_berry', 'common_white_dogwood']
senticnet['bunco'] = [0.931, -0.714, 0, 0.63, '#joyful', '#surprising', 0.758, 'hustle', 'con', 'sting_operation', 'sting', 'sting_operation_game']
senticnet['bunco_game'] = [0.931, -0.714, 0, 0.63, '#joyful', '#surprising', 0.758, 'hustle', 'con', 'bunco', 'sting', 'sting_operation']
senticnet['buncombe'] = [-0.894, 0, 0.739, -0.972, '#sad', '#disgusting', -0.868, 'rot', 'bunk', 'bunkum', 'dogshit', 'guff']
senticnet['bungalow'] = [0, 0.105, 0, 0.076, '#interesting', '#admirable', 0.06, 'palace', 'mansion', 'castle', 'big_house', 'terrace']
senticnet['bungee_jump'] = [0.763, -0.707, 0, 0, '#joyful', '#surprising', 0.49, 'fun', 'exciting', 'exhilarating', 'jump', 'adrenaline']
senticnet['bungee_jump_from_high_bridge'] = [0.874, -0.789, 0, 0, '#joyful', '#surprising', 0.554, 'jump_out_of_window', 'get_involved_in_accident', 'jump_off_cliff', 'storm_castle', 'advance_battle']
senticnet['bungee_jump_high_bridge'] = [0, -0.004, -0.081, -0.085, '#scared', '#disgusting', -0.054, 'lose_consciousness', 'get_involved_in_accident', 'go_coma', 'jump_out_of_bridge', 'heart_attack']
senticnet['bungle'] = [-0.848, 0, 0.828, -0.574, '#sad', '#angry', -0.75, 'bobble', 'error', 'misstep', 'fumble', 'stumble']
senticnet['bungled'] = [-0.983, 0, 0.505, -0.832, '#sad', '#disgusting', -0.773, 'lowly', 'unskilled', 'botched', 'fumbling', 'bungling']
senticnet['bungler'] = [-0.773, 0, 0.503, -0.932, '#sad', '#disgusting', -0.736, 'butcher', 'fuckup', 'slouch', 'incompetent', 'blunderer']
senticnet['bunglesome'] = [-0.965, 0, 0.636, -0.85, '#sad', '#disgusting', -0.817, 'awkward', 'unmanageable', 'clumsy', 'cumbersome', 'ungainly']
senticnet['bungling'] = [-0.61, 0, 0.533, -0.971, '#sad', '#disgusting', -0.705, 'maladroit', 'bumbling', 'butterfingered', 'inept', 'handless']
senticnet['bunk'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'nonsense', 'meaninglessness', 'absurdity', 'nonsensicality', 'hokum']
senticnet['bunker'] = [-0.589, 0, 0.509, -0.836, '#sad', '#disgusting', -0.645, 'burial_chamber', 'sepulcher', 'chamber', 'sepulture', 'bombproof']
senticnet['bunkum'] = [-0.894, 0, 0.739, -0.972, '#sad', '#disgusting', -0.868, 'rot', 'bunk', 'dogshit', 'buncombe', 'guff']
senticnet['bunsen'] = [0.032, 0, 0, 0.052, '#joyful', '#admirable', 0.028, 'test_tube', 'chemistry_equipment', 'test', 'chemistry', 'tube']
senticnet['buoyancy'] = [0.676, 0.63, -0.235, 0.31, '#joyful', '#interesting', 0.46, 'perkiness', 'walk_on_air', 'exultingly', 'exultantly', 'jubilance']
senticnet['buoyant'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'lively', 'vivacious', 'joyful', 'cheerful', 'happy']
senticnet['burden'] = [0, -0.004, -0.081, -0.085, '#scared', '#disgusting', -0.054, 'duty', 'tax', 'concern', 'responsibility', 'onus']
senticnet['burdock'] = [0.683, -0.547, 0, 0.568, '#joyful', '#admirable', 0.599, 'subshrub', 'suffrutex', 'common_burdock', 'lesser_burdock', 'great_burdock']
senticnet['bureau'] = [0.685, -0.849, 0, 0.903, '#surprising', '#admirable', 0.812, 'agency', 'federal_agency', 'government_agency', 'bureau_of_diplomatic_security', 'office']
senticnet['bureau_of_diplomatic_security'] = [0.685, -0.849, 0, 0.903, '#surprising', '#admirable', 0.812, 'agency', 'federal_agency', 'government_agency', 'bureau', 'office']
senticnet['bureaucracy'] = [0, 0, 0, -0.947, '#disgusting', '#disgusting', -0.316, 'boring', 'fill_form', 'annoying', 'form', 'fill_out_form']
senticnet['burger'] = [0.711, 0, 0, 0, '#joyful', '#joyful', 0.237, 'cheeseburger', 'appetizer', 'chinese_food', 'porridge', 'hearty']
senticnet['burger_king'] = [0.135, 0.065, 0, 0.082, '#joyful', '#admirable', 0.094, 'breakfast', 'delicious_food', 'dinner_meal', 'sandwich', 'dine']
senticnet['burglary'] = [-0.908, 0, 0.978, 0, '#sad', '#angry', -0.629, 'steal_money', 'theft', 'stick_up', 'robbery', 'rob']
senticnet['burial'] = [-0.128, 0.091, -0.199, -0.104, '#sad', '#scared', -0.113, 'headstone', 'grave', 'bury_body', 'bury', 'bury_dead']
senticnet['burial_chamber'] = [-0.532, 0, 0.516, -0.57, '#sad', '#disgusting', -0.539, 'grave', 'tomb', 'chamber', 'monument', 'vault']
senticnet['burial_ground'] = [-0.501, 0, 0.762, -0.895, '#angry', '#disgusting', -0.719, 'cemetery', 'graveyard', 'burial_site', 'potter_field', 'burying_ground']
senticnet['burial_place'] = [-0.896, 0, -0.827, 0, '#sad', '#scared', -0.574, 'death_place', 'headstone', 'dead_place', 'bury_dead', 'bury']
senticnet['burial_site'] = [-0.501, 0, 0.762, -0.895, '#angry', '#disgusting', -0.719, 'cemetery', 'graveyard', 'potter_field', 'burial_ground', 'burying_ground']
senticnet['burial_vault'] = [-0.958, 0, 0.19, -0.99, '#sad', '#disgusting', -0.713, 'coffin', 'cemetery', 'conceal', 'corpse', 'dead_person']
senticnet['burke'] = [-0.691, 0, 0.89, -0.707, '#angry', '#disgusting', -0.763, 'still', 'suppress', 'moderate', 'hush_up', 'quell']
senticnet['burked'] = [-0.725, 0, 0.728, -0.5, '#sad', '#angry', -0.651, 'quelled', 'squelched', 'suppressed', 'quenched', 'unreleased']
senticnet['burlap'] = [0.053, 0.068, -0.052, 0.06, '#interesting', '#admirable', 0.043, 'linen', 'star_stripe', 'velvet', 'nation', 'flag']
senticnet['burlesque'] = [0, 0, 0.79, -0.834, '#angry', '#disgusting', -0.541, 'mockery', 'parody', 'spoof', 'lampoon', 'sendup']
senticnet['burn'] = [-0.025, -0.012, -0.078, -0.124, '#scared', '#disgusting', -0.072, 'grow_yard', 'stain_clothes', 'big_fire', 'set_on_fire', 'chemical_process']
senticnet['burn_calorie'] = [0.135, 0.065, 0, 0.082, '#joyful', '#admirable', 0.094, 'lose_weight', 'healthy_life', 'stay_fit', 'healty', 'go_to_gym']
senticnet['burn_down_house'] = [-0.888, 0, -0.845, -0.921, '#sad', '#disgusting', -0.885, 'heat_light', 'set_on_fire', 'arson', 'get_burnt', 'burn_hand']
senticnet['burn_fat'] = [0.861, 0, 0, 0.838, '#joyful', '#admirable', 0.566, 'expend_energy', 'run_fast', 'push_up', 'move_leg', 'limber_up']
senticnet['burn_finger'] = [0.025, 0, -0.054, -0.056, '#scared', '#disgusting', -0.028, 'create_flame', 'create_fire', 'make_fire', 'gather_wood', 'light_cigarette']
senticnet['burn_food'] = [-0.981, 0, 0.458, -0.947, '#sad', '#disgusting', -0.795, 'fire', 'ruined_meal', 'ruined_dinner', 'ruined_lunch', 'waste_food']
senticnet['burn_forest'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'light_cigarette', 'create_flame', 'ruin', 'create_fire', 'start_fire']
senticnet['burn_fuel'] = [0, 0, -0.083, 0, '#scared', '#scared', -0.028, 'burn_material', 'heat_house', 'heat_home', 'make_light', 'light_dark']
senticnet['burn_garbage'] = [0, 0.956, 0, 0.935, '#interesting', '#admirable', 0.63, 'incinerator', 'eliminate_garbage', 'incinerate_waste', 'dump', 'garbage_dump']
senticnet['burn_gas'] = [0, -0.004, -0.081, -0.085, '#scared', '#disgusting', -0.054, 'burn_heat', 'explosive', 'fire_burn', 'fatal', 'flammable']
senticnet['burn_gasoline'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'use_car', 'start_engine', 'steer_car', 'turn_ignition', 'put_gear']
senticnet['burn_hand'] = [-0.807, 0, -0.847, 0, '#sad', '#scared', -0.551, 'burn_down_house', 'get_burnt', 'arson', 'set_fire', 'burn']
senticnet['burn_heat'] = [-0.795, 0, 0.847, 0, '#sad', '#angry', -0.547, 'fire_burn', 'really_hot', 'hot', 'burn_hot', 'flame']
senticnet['burn_hot'] = [0, 0, -0.089, 0, '#scared', '#scared', -0.03, 'hot', 'big_fire', 'burn_heat', 'fire_burn', 'chemical_process']
senticnet['burn_house'] = [-0.022, -0.042, -0.061, -0.11, '#scared', '#disgusting', -0.05, 'extinguish', 'find_campsite', 'die_out', 'warm_house', 'burn_hand']
senticnet['burn_inside'] = [-0.903, 0, 0.251, -0.962, '#sad', '#disgusting', -0.705, 'heat', 'hot', 'fire', 'warmth', 'burn']
senticnet['burn_material'] = [0.1, 0, 0, 0, '#joyful', '#joyful', 0.033, 'bonfire', 'ash', 'stay_warm', 'oregano', 'campfire']
senticnet['burn_oneself'] = [0, 0, -0.062, -0.069, '#scared', '#disgusting', -0.044, 'get_burnt', 'burn_finger', 'excessive_heat', 'touch_fire', 'create_flame']
senticnet['burn_paper'] = [0, 0, -0.849, -0.732, '#scared', '#disgusting', -0.527, 'ash', 'touch_fire', 'smoke', 'create_flame', 'hot']
senticnet['burn_skin'] = [-0.907, 0, 0.209, -0.927, '#sad', '#disgusting', -0.681, 'sun_burn', 'erythema', 'fire', 'lighting', 'hurt_skin']
senticnet['burn_thing'] = [-0.974, 0, 0.707, -0.9, '#sad', '#disgusting', -0.86, 'fire', 'burn', 'flame', 'heat', 'light_match']
senticnet['burn_toast'] = [-0.368, -0.099, 0, -0.302, '#sad', '#disgusting', -0.19, 'go_insane', 'punch_face', 'follow_instruction', 'suffer_fool', 'lose_mind']
senticnet['burn_trash'] = [-0.074, 0, 0, -0.036, '#sad', '#disgusting', -0.037, 'brown_hamburger', 'heat_meal', 'beat_egg', 'salt_food', 'bone_chicken']
senticnet['burn_up'] = [-0.72, 0, 0.925, 0, '#sad', '#angry', -0.548, 'corrode', 'light_up', 'burn_heat', 'dig_up', 'heat_up']
senticnet['burn_wood'] = [0, 0, -0.849, -0.732, '#scared', '#disgusting', -0.527, 'excessive_heat', 'smoke', 'keep_warm', 'create_light', 'touch_fire']
senticnet['burn_your_finger'] = [-0.982, 0, 0.791, -0.969, '#sad', '#disgusting', -0.914, 'fire', 'burn', 'start_fire', 'light_match', 'flame']
senticnet['burn_your_hand'] = [-0.948, 0, 0.494, -0.992, '#sad', '#disgusting', -0.811, 'fire', 'burn', 'heat', 'start_fire', 'light_match']
senticnet['burned'] = [-0.739, 0, 0.641, -0.748, '#sad', '#disgusting', -0.709, 'burnt', 'treated', 'proofed', 'doped', 'activated']
senticnet['burned_thing'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'destroyed_home', 'destroyed_city', 'fire', 'mess', 'damage']
senticnet['burning'] = [-0.831, 0, 0.711, -0.639, '#sad', '#angry', -0.727, 'inflammation', 'lighting', 'arson', 'incendiarism', 'ignition']
senticnet['burning_hot'] = [-0.963, 0, 0.412, -0.962, '#sad', '#disgusting', -0.779, 'fire', 'heat', 'burn', 'flame', 'start_fire']
senticnet['burnish'] = [0.65, -0.618, 0, 0.703, '#joyful', '#admirable', 0.657, 'gleaming', 'luster', 'polish', 'glow', 'effulgence']
senticnet['burnished'] = [0.577, -0.696, 0, 0.645, '#surprising', '#admirable', 0.639, 'shining', 'lustrous', 'shiny', 'bright', 'polished']
senticnet['burnt'] = [-0.739, 0, 0.641, -0.748, '#sad', '#disgusting', -0.709, 'treated', 'burned', 'proofed', 'doped', 'activated']
senticnet['burnt_food'] = [-0.113, -0.061, 0, -0.161, '#sad', '#disgusting', -0.071, 'food', 'stir_pot', 'prepare_ingredient', 'peel_potato', 'chop_vegetable']
senticnet['burnt_skin'] = [-0.095, 0, -0.106, -0.173, '#scared', '#disgusting', -0.125, 'cloud_mind', 'skin_injury', 'make_drunk', 'dislocation', 'sunburn']
senticnet['burp'] = [-0.047, -0.013, 0, -0.045, '#sad', '#disgusting', -0.026, 'use_fork', 'drink_much_beer', 'acid_indigestion', 'add_spice', 'wipe_mouth_napkin']
senticnet['bury'] = [-0.158, 0.12, -0.196, 0, '#sad', '#scared', -0.078, 'bury_dead', 'burial', 'headstone', 'burial_place', 'death_place']
senticnet['bury_body'] = [-0.139, 0.094, -0.167, -0.083, '#sad', '#scared', -0.098, 'headstone', 'burial', 'bury_dead', 'burial_place', 'coffin']
senticnet['bury_cat'] = [-0.825, 0, -0.953, 0, '#sad', '#scared', -0.593, 'hurt_else', 'get_away_crime', 'obstruct_justice', 'kill_man', 'commit_perjury']
senticnet['bury_dead'] = [-0.14, 0.13, -0.17, -0.045, '#sad', '#scared', -0.075, 'headstone', 'bury_person', 'death_place', 'bury_dead_person', 'burial_place']
senticnet['bury_dead_person'] = [-0.782, 0, -0.71, 0, '#sad', '#scared', -0.497, 'bury_person', 'bury_dead', 'headstone', 'morgue', 'burial']
senticnet['bury_person'] = [-0.127, 0.125, -0.147, -0.078, '#sad', '#scared', -0.076, 'bury_dead_person', 'bury_dead', 'headstone', 'morgue', 'casket']
senticnet['burying_ground'] = [-0.501, 0, 0.762, -0.895, '#angry', '#disgusting', -0.719, 'cemetery', 'graveyard', 'burial_site', 'burial_ground', 'potter_field']
senticnet['bus'] = [-0.063, 0.122, -0.046, 0.113, '#interesting', '#admirable', 0.042, 'taxi', 'motorcycle', 'tram', 'airplane', 'plane']
senticnet['bus_pass'] = [0, 0.093, 0, 0, '#interesting', '#interesting', 0.031, 'subway_pass', 'train_ticket', 'transit_ticket', 'passenger_ticket', 'transit_card']
senticnet['bus_person'] = [-0.867, 0, 0, -0.848, '#sad', '#disgusting', -0.572, 'glide', 'cool_engine', 'go_stall', 'land_runway', 'buzz']
senticnet['bus_ride'] = [-0.081, 0.179, -0.06, 0.096, '#interesting', '#admirable', 0.045, 'ride_subway', 'buy_vending_machine', 'purchase_item', 'buy_lottery_ticket', 'acquire']
senticnet['bus_station'] = [0.025, 0.136, 0, 0, '#joyful', '#interesting', 0.054, 'train_station', 'bus', 'subway_station', 'public_place', 'pier']
senticnet['bus_stop'] = [0, 0, 0, -0.095, '#disgusting', '#disgusting', -0.032, 'subway', 'bus', 'train_station', 'railway_station', 'parking_lot']
senticnet['bus_table'] = [-0.962, 0, -0.916, 0, '#sad', '#scared', -0.626, 'work_team', 'dress_oneself', 'move_furniture', 'lend_hand', 'win_award']
senticnet['bus_terminal'] = [0, 0.147, 0, 0.099, '#interesting', '#admirable', 0.082, 'airport', 'subway', 'bus_stop', 'bus', 'control_tower']
senticnet['busby'] = [-0.588, 0, 0.632, -0.638, '#angry', '#disgusting', -0.619, 'skimmer', 'trilby', 'bearskin', 'chapeau', 'shako']
senticnet['bush'] = [-0.573, 0, 0.721, -0.775, '#angry', '#disgusting', -0.69, 'caper', 'native_pomegranate', 'caper_tree', 'native_orange', 'common_caper']
senticnet['bushel'] = [0, 0.067, 0, 0.07, '#interesting', '#admirable', 0.046, 'peck', 'embryo', 'chicken_egg', 'ovum', 'egg']
senticnet['business'] = [0.052, 0.206, 0, 0.153, '#interesting', '#admirable', 0.137, 'enterprise', 'corporation', 'company', 'money_maker', 'industry']
senticnet['business_account'] = [-0.043, 0.28, -0.056, 0.077, '#interesting', '#admirable', 0.086, 'finance', 'business', 'profit', 'account', 'bank_account']
senticnet['business_activity'] = [0.842, -0.731, 0, 0.662, '#joyful', '#surprising', 0.745, 'labor', 'racket', 'forlorn_hope', 'fraudulent_scheme', 'endeavor']
senticnet['business_agreement'] = [0.717, 0.84, 0, 0, '#joyful', '#interesting', 0.519, 'transact_business', 'bankruptcy', 'business_transaction', 'receive_change', 'give_change']
senticnet['business_card'] = [0.75, -0.978, 0, 0, '#joyful', '#surprising', 0.576, 'socialize', 'formal_introduction', 'database', 'professional', 'introduce_oneself']
senticnet['business_deal'] = [-0.049, 0.345, -0.15, 0.259, '#interesting', '#admirable', 0.135, 'money_exchange', 'bargain', 'financial_transaction', 'deal', 'sale']
senticnet['business_executive'] = [0.703, -0.598, 0, 0.842, '#joyful', '#admirable', 0.714, 'rainmaker', 'minister', 'administrator', 'corporate_executive', 'executive']
senticnet['business_firm'] = [0.094, 0.198, 0, 0.23, '#interesting', '#admirable', 0.174, 'large_business', 'partnership', 'business_organization', 'business_group', 'company']
senticnet['business_group'] = [0.08, 0.186, 0, 0.217, '#interesting', '#admirable', 0.161, 'business_firm', 'large_business', 'partnership', 'business_organization', 'work_group']
senticnet['business_man'] = [0, 0.105, 0, 0, '#interesting', '#interesting', 0.035, 'boss', 'visitor', 'no_doubt', 'defendant', 'dolt']
senticnet['business_organization'] = [0.093, 0.174, 0, 0.2, '#interesting', '#admirable', 0.156, 'large_business', 'partnership', 'business_firm', 'company', 'business_group']
senticnet['business_person'] = [-0.06, 0.148, 0.08, 0.111, '#interesting', '#admirable', 0.04, 'no_doubt', 'a_lot_of_work', 'business_man', 'business', 'undertake']
senticnet['business_plan'] = [0, 0.225, -0.053, 0.106, '#interesting', '#admirable', 0.093, 'money_make', 'business', 'work_hard', 'produce_goods', 'workplace']
senticnet['business_report'] = [0, 0.164, 0, 0.058, '#interesting', '#admirable', 0.074, 'restaurant_bill', 'bill', 'high_cost', 'debit', 'cost']
senticnet['business_term'] = [0.045, 0.379, -0.106, 0.272, '#interesting', '#admirable', 0.197, 'money_make', 'increase_money', 'extra_money', 'monetary_gain', 'financial_gain']
senticnet['business_transaction'] = [-0.063, 0.282, -0.114, 0.292, '#interesting', '#admirable', 0.132, 'transaction', 'obtain', 'financial_transaction', 'acquire', 'good_price']
senticnet['businesses'] = [0, 0, 0, 0.098, '#admirable', '#admirable', 0.033, 'stock', 'buy', 'earn_money', 'buy_stock', 'stock_market']
senticnet['businessman'] = [0, 0.123, -0.071, 0.097, '#interesting', '#admirable', 0.05, 'capitalist', 'make_rich', 'buyer', 'consumer', 'broker']
senticnet['busker'] = [0.54, -0.64, 0, 0.566, '#surprising', '#admirable', 0.582, 'pleaser', 'bombshell', 'mortal', 'entertainer', 'drawing_card']
senticnet['bust'] = [-0.576, 0, 0.852, -0.745, '#angry', '#disgusting', -0.724, 'tease', 'rip_up', 'tear', 'rupture', 'snap']
senticnet['bustle'] = [-0.947, 0, 0.492, -0.921, '#sad', '#disgusting', -0.787, 'make_noise', 'disturb', 'confusion', 'hustle', 'hustle_and_bustle']
senticnet['busy'] = [-0.772, 0, 0.761, -0.86, '#sad', '#disgusting', -0.798, 'business_firm', 'come_together', 'business_organization', 'large_business', 'large_group']
senticnet['busy_bee'] = [0.991, -0.733, 0, 0.668, '#joyful', '#surprising', 0.797, 'goffer', 'gopher', 'actor', 'doer', 'worker']
senticnet['busy_person'] = [-0.043, -0.02, -0.056, 0, '#sad', '#scared', -0.026, 'use_illegal_drug', 'delusional', 'human', 'cold_person', 'carpenter']
senticnet['busy_signal'] = [-0.075, -0.028, 0.034, 0, '#sad', '#angry', -0.027, 'call_back', 'busy', 'cut_off', 'engaged', 'hang_up']
senticnet['busy_street'] = [0.035, 0.065, 0.025, 0.127, '#interesting', '#admirable', 0.067, 'city_street', 'departmental_highway', 'center', 'central', 'main']
senticnet['busybodied'] = [-0.997, 0, 0.851, -0.896, '#sad', '#disgusting', -0.915, 'interfering', 'meddlesome', 'meddling', 'officious', 'intrusive']
senticnet['busybody'] = [-0.641, 0, 0.71, -0.953, '#angry', '#disgusting', -0.768, 'buttinsky', 'unwelcome_person', 'killjoy', 'backseat_driver', 'meddler']
senticnet['busyness'] = [0.681, -0.935, 0, 0.78, '#surprising', '#admirable', 0.799, 'behavior', 'state', 'play', 'agency', 'activeness']
senticnet['butane'] = [0, 0, -0.08, 0, '#scared', '#scared', -0.027, 'petrol', 'diesel', 'kerosene', 'fuel', 'gasoline']
senticnet['butcher'] = [-0.773, 0, 0.503, -0.932, '#sad', '#disgusting', -0.736, 'incompetent', 'fuckup', 'slouch', 'bungler', 'blunderer']
senticnet['butcher_paper'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'gift_wrap', 'kraft', 'kraft_paper', 'wrapping_paper', 'paper']
senticnet['butcherbird'] = [-0.845, 0, 0.655, -0.851, '#sad', '#disgusting', -0.784, 'piping_crow', 'australian_magpie', 'currawong', 'bell_magpie', 'oscine']
senticnet['butchery'] = [-0.671, 0, 0.938, -0.706, '#angry', '#disgusting', -0.772, 'massacre', 'mass_murder', 'carnage', 'slaughter', 'bloodbath']
senticnet['butt'] = [-0.052, -0.006, 0, -0.08, '#sad', '#disgusting', -0.042, 'ass', 'rut', 'foreign_country', 'dog_show', 'asshole']
senticnet['butt_against'] = [-0.748, 0, 0.627, -0.589, '#sad', '#angry', -0.655, 'touch', 'contact', 'meet', 'neighbor', 'adjoin']
senticnet['butter'] = [0.041, -0.071, 0.034, 0, '#joyful', '#surprising', 0.026, 'bagel', 'mayonaise', 'pie', 'noodle', 'muffin']
senticnet['butter_bread'] = [-0.14, 0, 0, -0.082, '#sad', '#disgusting', -0.074, 'fill_bottle', 'bread', 'butter_toast', 'feel_heat', 'quiet_child']
senticnet['butter_knife'] = [0.035, 0.065, 0.025, 0.127, '#interesting', '#admirable', 0.067, 'butter', 'kitchen_tool', 'breakfast', 'butter_toast', 'butter_bread']
senticnet['butter_toast'] = [-0.08, 0, -0.058, -0.035, '#sad', '#scared', -0.058, 'dig_grave', 'bicycle_across_town', 'mine_diamond', 'kill_specific_group', 'age_gracefully']
senticnet['buttercup'] = [-0.808, 0, 0.632, -0.71, '#sad', '#disgusting', -0.717, 'herb', 'meadow_buttercup', 'tall_buttercup', 'tall_crowfoot', 'tall_field_buttercup']
senticnet['butterfingered'] = [-0.61, 0, 0.533, -0.971, '#sad', '#disgusting', -0.705, 'bungling', 'bumbling', 'maladroit', 'inept', 'handless']
senticnet['butterfingers'] = [-0.713, 0, 0.845, -0.691, '#sad', '#angry', -0.75, 'lump', 'goon', 'mortal', 'duffer', 'clumsy_person']
senticnet['butterflower'] = [-0.679, 0, 0.515, -0.654, '#sad', '#disgusting', -0.616, 'herb', 'meadow_buttercup', 'tall_buttercup', 'tall_crowfoot', 'tall_field_buttercup']
senticnet['butterfly'] = [0, 0, -0.872, -0.827, '#scared', '#disgusting', -0.566, 'wasp', 'moth', 'parrot', 'beetle', 'falcon']
senticnet['butterfly_collection'] = [0.673, -0.664, 0, 0.921, '#joyful', '#admirable', 0.753, 'coin', 'collection', 'coin_collection', 'insect_collection', 'album_collection']
senticnet['butternut_squash'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'squash', 'acorn_squash', 'hubbard_squash', 'turban_squash', 'winter_squash']
senticnet['buttery'] = [0, 0, -0.868, -0.782, '#scared', '#disgusting', -0.55, 'pantry', 'larder', 'fulsome', 'oily', 'oleaginous']
senticnet['buttinsky'] = [-0.641, 0, 0.71, -0.953, '#angry', '#disgusting', -0.768, 'meddler', 'unwelcome_person', 'killjoy', 'backseat_driver', 'busybody']
senticnet['buttocks'] = [-0.045, 0.226, -0.208, 0.209, '#interesting', '#admirable', 0.061, 'rear', 'elongation', 'go_backwards', 'rear_end', 'hind']
senticnet['buttonhole'] = [0.857, -0.569, 0, 0.721, '#joyful', '#admirable', 0.716, 'ask_for', 'lobby', 'quest', 'canvass', 'solicit']
senticnet['buttony'] = [0.613, -0.532, 0, 0.932, '#joyful', '#admirable', 0.692, 'adorned', 'ruffled', 'fringed', 'tessellated', 'mounted']
senticnet['buttress'] = [0.846, -0.941, 0, 0.797, '#joyful', '#surprising', 0.861, 'strengthen', 'reenforce', 'mine', 'line', 'bolster']
senticnet['buxom'] = [0.636, -0.954, 0, 0.664, '#surprising', '#admirable', 0.751, 'voluptuous', 'statuesque', 'sculptured', 'shapely', 'sculptural']
senticnet['buy'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'car', 'buy_car_motorbike', 'buy_car', 'purchase_car', 'buy_car_object']
senticnet['buy_airline_ticket'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'plan_trip', 'desire_social_interaction', 'see_different', 'proselytize', 'improve_knowledge']
senticnet['buy_airplane_ticket'] = [-0.062, 0, 0.011, -0.028, '#sad', '#disgusting', -0.034, 'buy_plane_ticket', 'talk_to_travel_agent', 'decide_want_go', 'plan_time', 'decide_to_go']
senticnet['buy_alcohol'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'drink_a_lot_of_booze', 'drink_excess', 'consume_alcohol', 'drink_a_lot_of_alcohol', 'open_bottle']
senticnet['buy_ball'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'buy_game', 'play_game', 'enjoy_game', 'fun', 'have_fun']
senticnet['buy_bed'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'home_renovation', 'buy_pillow', 'buy_home_appliance', 'buy_bedroom_sheet', 'buy_bedroom']
senticnet['buy_bed_sheet'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'home_renovation', 'buy_pillow', 'buy_home_appliance', 'buy_bedroom', 'buy_bed']
senticnet['buy_bedroom'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'home_renovation', 'buy_pillow', 'buy_home_appliance', 'buy_bed_sheet', 'buy_bed']
senticnet['buy_book'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'open_book', 'go_bookshop', 'visit_library', 'book', 'read_book']
senticnet['buy_bread'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'buy_cheese', 'eat', 'go_supermarket', 'buy_pasta', 'buy_goods']
senticnet['buy_camera'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'watch_tv', 'buy_happiness', 'buy', 'turn_on_tv', 'buy_tv']
senticnet['buy_candy'] = [0.896, 0, 0, 0, '#joyful', '#joyful', 0.299, 'walk_exercise', 'pay_dinner', 'subscribe_magazine', 'gain_interest', 'buy_soda']
senticnet['buy_car'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'car', 'buy_motorbike', 'buy', 'purchase_car', 'buy_object']
senticnet['buy_cheap_item'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'make_payment', 'purchase_gift', 'buy_many', 'spread_love', 'buy_goods']
senticnet['buy_cheaper'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'save_money', 'good_customer', 'better_price', 'sales', 'on_sale']
senticnet['buy_cheese'] = [0, 0.71, 0, 0.799, '#interesting', '#admirable', 0.503, 'buy_grocery', 'do_shopping', 'go_supermarket', 'buy_food', 'buy_ingredient']
senticnet['buy_chip'] = [-0.856, 0, 0.814, -0.915, '#sad', '#disgusting', -0.862, 'lose_money', 'shuffle_card', 'go_broke', 'lose', 'go_debt']
senticnet['buy_chips'] = [0, 0.71, 0, 0.799, '#interesting', '#admirable', 0.503, 'buy_grocery', 'do_shopping', 'go_supermarket', 'buy_food', 'buy_ingredient']
senticnet['buy_christmas_present'] = [0, -0.842, 0, 0.883, '#surprising', '#admirable', 0.575, 'buy_present', 'christmas_shop', 'holiday_shop', 'christmas_present', 'buy_product']
senticnet['buy_clothes'] = [-0.045, 0, 0.03, 0, '#sad', '#angry', -0.025, 'buy_many', 'spend_money', 'get_grocery', 'buy_goods', 'buy_stuff']
senticnet['buy_coffee'] = [-0.063, -0.016, 0.027, -0.069, '#sad', '#disgusting', -0.048, 'donate_charity', 'impulse_shop', 'spend_money', 'window_shop', 'use_atm']
senticnet['buy_computer'] = [0.89, -0.616, 0, 0.757, '#joyful', '#admirable', 0.754, 'turn_computer_on', 'find_computer', 'find_address', 'go_online', 'internet_connection']
senticnet['buy_concert_ticket'] = [0, -0.964, 0, 0.858, '#surprising', '#admirable', 0.607, 'purchase_ticket', 'attend_concert', 'pay_ticket', 'go_rock_concert', 'buy_ticket_theater']
senticnet['buy_condom'] = [0, 0.143, -0.051, 0.073, '#interesting', '#admirable', 0.055, 'spend_much_money', 'spend_a_lot_of_money', 'buy_dinner', 'make_payment', 'drive_home']
senticnet['buy_credit'] = [-0.04, 0.232, -0.119, 0.183, '#interesting', '#admirable', 0.085, 'postpone_payment', 'bill_pay', 'spend', 'cashless', 'owe_money']
senticnet['buy_diamond_ring'] = [0.992, 0.86, 0, 0, '#joyful', '#interesting', 0.617, 'find_out_want', 'go_shopping', 'drive_to_store', 'go_department_store', 'know_like']
senticnet['buy_dinner'] = [0, 0, 0, 0.713, '#admirable', '#admirable', 0.238, 'invite_person', 'invite_friend_over', 'invite_guest', 'spend_much_money', 'make_payment']
senticnet['buy_drink'] = [0, 0.709, 0, 0, '#interesting', '#interesting', 0.236, 'serve_beer', 'drink_beer', 'invite_friend', 'pay_tab', 'order_beer']
senticnet['buy_flower'] = [0.983, 0.737, 0, 0, '#joyful', '#interesting', 0.573, 'buy_condom', 'drive_home', 'want_marry', 'wear_protection', 'love_back']
senticnet['buy_food'] = [0.17, -0.01, 0, 0.184, '#joyful', '#admirable', 0.121, 'go_grocery_shop', 'buy_grocery', 'stock_merchandise', 'buy_fresh_fruit_vegetable', 'buy_vegetable']
senticnet['buy_fresh_fruit_vegetable'] = [0, 0.886, 0, 0, '#interesting', '#interesting', 0.295, 'go_grocery_shop', 'buy_grocery', 'stock_merchandise', 'buy_food', 'buy_vegetable']
senticnet['buy_fruit'] = [0.02, -0.056, 0, 0, '#joyful', '#surprising', 0.025, 'many_fruits', 'peach', 'cherry', 'pineapple', 'tomato']
senticnet['buy_furniture'] = [-0.104, 0.235, -0.127, 0.246, '#interesting', '#admirable', 0.083, 'love', 'settle_down', 'build_house', 'family_nest', 'make_home']
senticnet['buy_game'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'buy_ball', 'play_game', 'enjoy_game', 'fun', 'have_fun']
senticnet['buy_gas'] = [0.848, 0.945, 0, 0, '#joyful', '#interesting', 0.598, 'collect_debt', 'buy_tool', 'negotiate_contract', 'make_work', 'increase_net_worth']
senticnet['buy_gift'] = [-0.088, 0, 0, -0.04, '#sad', '#disgusting', -0.043, 'spend_money', 'compare_price', 'comparison_shop', 'wrap_gift', 'give_present']
senticnet['buy_goods'] = [0.705, 0.953, 0, 0, '#joyful', '#interesting', 0.553, 'buy_stuff', 'buy_gum', 'buy_cheap_item', 'buy_item', 'acquire_goods']
senticnet['buy_goods_service'] = [0.929, 0.857, 0, 0, '#joyful', '#interesting', 0.595, 'go_cashless', 'pay_goods', 'incur_debt', 'postpone_payment', 'buy_item']
senticnet['buy_grocery'] = [0.813, 0.994, 0, 0, '#joyful', '#interesting', 0.602, 'purchase_grocery', 'buy_vegetable', 'shop_food', 'purchase_food', 'stock_merchandise']
senticnet['buy_guitar'] = [0.768, 0, 0, 0, '#joyful', '#joyful', 0.256, 'music_store', 'music_lover', 'music', 'buy_music_album', 'music_shop']
senticnet['buy_gum'] = [0, 0.095, -0.054, 0.132, '#interesting', '#admirable', 0.058, 'purchase_goods', 'buy', 'buy_cheap_item', 'fresh_breathe', 'spread_love']
senticnet['buy_gun'] = [-0.097, -0.005, 0, -0.223, '#sad', '#disgusting', -0.105, 'buy_weapon', 'plan_attack', 'grenade', 'weapon', 'join_military']
senticnet['buy_happiness'] = [0, 0.095, -0.054, 0.132, '#interesting', '#admirable', 0.058, 'buy_new_car', 'buy_ice_cream', 'happiness', 'book_flight', 'book_holiday']
senticnet['buy_home'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'family_nest', 'love_back', 'protection', 'shelter', 'purchase_house']
senticnet['buy_home_appliance'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'home_renovation', 'buy_pillow', 'buy_bedroom', 'buy_bed_sheet', 'buy_bed']
senticnet['buy_ice_cream'] = [0.768, 0, 0, 0, '#joyful', '#joyful', 0.256, 'buy_new_car', 'buy_happiness', 'happiness', 'book_flight', 'book_holiday']
senticnet['buy_ingredient'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'buy_grocery', 'do_shopping', 'go_supermarket', 'buy_food', 'buy_cheese']
senticnet['buy_item'] = [-0.058, 0.106, 0, 0.06, '#interesting', '#admirable', 0.036, 'purchase_item', 'get_goods', 'buy_stuff', 'buy_cheap_item', 'buy_goods']
senticnet['buy_land'] = [0.828, 0.958, 0, 0, '#joyful', '#interesting', 0.595, 'pay_money', 'establish_credit', 'compare_price', 'bankruptcy', 'cash_check']
senticnet['buy_lottery_ticket'] = [-0.081, 0.179, -0.06, 0.096, '#interesting', '#admirable', 0.045, 'gamble', 'trying_luck', 'spend_money', 'hope', 'finger_crossed']
senticnet['buy_love'] = [0, 0, 0, -0.714, '#disgusting', '#disgusting', -0.238, 'buy_present_for_others', 'give_gift', 'buy_christmas_present', 'buy_present', 'give_flower']
senticnet['buy_lunch'] = [-0.081, 0.179, -0.06, 0.096, '#interesting', '#admirable', 0.045, 'purchase_food', 'buy_food', 'provide_family', 'get_food', 'buy_grocery']
senticnet['buy_magazine'] = [-0.075, 0, 0.009, -0.125, '#sad', '#disgusting', -0.07, 'sell_book', 'check_out', 'learn_read', 'visit_library', 'buy_book']
senticnet['buy_many'] = [-0.06, 0, 0.021, 0, '#sad', '#angry', -0.027, 'buy_clothes', 'buy_gum', 'buy_cheap_item', 'buy_goods', 'buy_milk']
senticnet['buy_market'] = [-0.077, 0, 0, 0, '#sad', '#sad', -0.026, 'market', 'refrigerate', 'hammer_nail', 'put_napkin_lap', 'defrost']
senticnet['buy_meat'] = [0.71, 0.815, 0, 0, '#joyful', '#interesting', 0.508, 'supermarket', 'buy_grocery', 'compare_price', 'purchase_grocery', 'make_dinner']
senticnet['buy_milk'] = [0.902, 0.737, 0, 0, '#joyful', '#interesting', 0.546, 'buy_grocery', 'buy_bread', 'do_shopping', 'buy_pizza', 'buy_pasta']
senticnet['buy_motorbike'] = [0.768, 0, 0, 0, '#joyful', '#joyful', 0.256, 'car', 'buy_car', 'buy', 'purchase_car', 'buy_object']
senticnet['buy_movie_ticket'] = [-0.901, 0, 0.704, 0, '#sad', '#angry', -0.535, 'check_listing', 'buy_popcorn', 'go_cinema', 'go_movie_theater', 'pay_ticket']
senticnet['buy_music_album'] = [0.768, 0, 0, 0, '#joyful', '#joyful', 0.256, 'music_store', 'music_lover', 'music', 'music_shop', 'buy_guitar']
senticnet['buy_new'] = [-0.058, 0.106, 0, 0.06, '#interesting', '#admirable', 0.036, 'new_stuff', 'buy', 'buy_happiness', 'buy_new_car', 'buy_new_game']
senticnet['buy_new_car'] = [0.768, 0, 0, 0, '#joyful', '#joyful', 0.256, 'buy_happiness', 'buy_ice_cream', 'happiness', 'book_flight', 'book_holiday']
senticnet['buy_new_game'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'new_stuff', 'buy', 'buy_happiness', 'buy_new_car', 'buy_new']
senticnet['buy_newspaper'] = [-0.058, 0.106, 0, 0.06, '#interesting', '#admirable', 0.036, 'buy', 'newspaper', 'read_newspaper', 'buy_book', 'read_news']
senticnet['buy_object'] = [-0.058, 0.106, 0, 0.06, '#interesting', '#admirable', 0.036, 'purchase_item', 'get_goods', 'buy_stuff', 'buy_cheap_item', 'buy_goods']
senticnet['buy_paint'] = [0.165, 0.069, 0.028, 0.057, '#joyful', '#interesting', 0.088, 'make_paint', 'stir_paint_brush', 'wall_art', 'stir_paint', 'pick_up_brush']
senticnet['buy_paint_brush'] = [0, 0.164, 0, 0, '#interesting', '#interesting', 0.055, 'art', 'picture_person', 'buy_paint', 'pick_up_brush', 'use_oil_paint']
senticnet['buy_pants'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'buy', 'buy_shirt', 'buy_product', 'buy_happiness', 'buy_clothes']
senticnet['buy_pasta'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'buy_cheese', 'eat', 'go_supermarket', 'buy_bread', 'buy_goods']
senticnet['buy_pillow'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'home_renovation', 'buy_bedroom', 'buy_home_appliance', 'buy_bed_sheet', 'buy_bed']
senticnet['buy_pizza'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'buy_grocery', 'buy_bread', 'do_shopping', 'buy_milk', 'buy_pasta']
senticnet['buy_plane_ticket'] = [-0.055, 0.077, 0, 0.058, '#interesting', '#admirable', 0.027, 'travel', 'go_on_holiday', 'book_ticket', 'look_map', 'buy_airplane_ticket']
senticnet['buy_popcorn'] = [0.707, 0, 0, 0, '#joyful', '#joyful', 0.236, 'pay_ticket', 'see_play', 'go_movie_theater', 'buy_ticket', 'go_to_theater']
senticnet['buy_present'] = [0, -0.849, 0, 0.998, '#surprising', '#admirable', 0.616, 'buy_christmas_present', 'holiday_shop', 'christmas_shop', 'christmas_present', 'buy_product']
senticnet['buy_present_for_others'] = [0.787, 0, 0, 0.864, '#joyful', '#admirable', 0.55, 'buy_love', 'buy_christmas_present', 'buy_present', 'give_gift', 'christmas_present']
senticnet['buy_product'] = [0, -0.918, 0, 0.704, '#surprising', '#admirable', 0.541, 'buy_christmas_present', 'holiday_shop', 'christmas_shop', 'purchase_gift', 'buy_clothes']
senticnet['buy_ring'] = [-0.023, 0.219, -0.094, 0.122, '#interesting', '#admirable', 0.075, 'buy_diamond_ring', 'determine_need', 'find_out_want', 'search_item', 'think_about_someone']
senticnet['buy_sandwich'] = [0.078, 0, 0, 0, '#joyful', '#joyful', 0.026, 'cafe', 'lunch', 'eat_food', 'buy_food', 'finish_job']
senticnet['buy_sell'] = [-0.028, 0.076, 0.014, 0.082, '#interesting', '#admirable', 0.039, 'market', 'get_grocery', 'sell_goods', 'buy_stuff', 'buy_goods']
senticnet['buy_shirt'] = [-0.028, 0.076, 0.014, 0.082, '#interesting', '#admirable', 0.039, 'buy', 'buy_pants', 'buy_product', 'buy_happiness', 'buy_clothes']
senticnet['buy_shoes'] = [-0.058, 0, 0.097, 0, '#sad', '#angry', -0.052, 'put_protective_gear', 'put_helmet', 'find_mountain', 'good_shoes', 'wear_good_shoes']
senticnet['buy_snack'] = [0.065, -0.021, 0.009, 0, '#joyful', '#surprising', 0.026, 'rest_area', 'motel_room', 'gas_station', 'service_station', 'go_toilet']
senticnet['buy_soda'] = [-0.028, 0.076, 0.014, 0.082, '#interesting', '#admirable', 0.039, 'buy_candy', 'buy_drink', 'go_supermarket', 'buy_milk', 'buy']
senticnet['buy_souvenir'] = [0, 0, 0.732, -0.907, '#angry', '#disgusting', -0.546, 'learn_foreign_language', 'lose_track_time', 'learn_other_culture', 'carry_luggage', 'learn_experience']
senticnet['buy_stamp'] = [0, 0, 0, 0.098, '#admirable', '#admirable', 0.033, 'send_mail', 'snail_mail', 'stamp', 'postage', 'put_envelope']
senticnet['buy_steak'] = [0, 0, 0, 0.098, '#admirable', '#admirable', 0.033, 'salivation', 'world_hunger', 'salivate', 'weight_gain', 'loss_ofmoney']
senticnet['buy_stock'] = [0, 0, 0, 0.098, '#admirable', '#admirable', 0.033, 'stock', 'buy', 'earn_money', 'businesses', 'stock_market']
senticnet['buy_store'] = [0.834, 0.88, 0, 0, '#joyful', '#interesting', 0.571, 'buy_meat', 'buy_grocery', 'buy_vegetable', 'purchase_grocery', 'buy_dinner']
senticnet['buy_stuff'] = [0.917, 0.954, 0, 0, '#joyful', '#interesting', 0.624, 'buy_goods', 'buy_item', 'buy_gum', 'buy_cheap_item', 'return_goods']
senticnet['buy_textbook'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'read_book_subject', 'use_search_engine', 'study_history', 'ask_expert', 'book_subject']
senticnet['buy_ticket'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'purchase_ticket', 'ticket', 'pay_ticket', 'go_to_theater', 'go_movie_theater']
senticnet['buy_ticket_theater'] = [-0.061, -0.006, 0, -0.082, '#sad', '#disgusting', -0.046, 'purchase_ticket', 'money_ticket', 'buy_ticket', 'pay_ticket', 'go_to_theater']
senticnet['buy_tool'] = [-0.069, 0, 0, -0.043, '#sad', '#disgusting', -0.037, 'buy_gas', 'collect_debt', 'wage_slave', 'increase_net_worth', 'make_profit']
senticnet['buy_tv'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'watch_tv', 'buy_happiness', 'buy', 'turn_on_tv', 'buy_camera']
senticnet['buy_vegetable'] = [0.974, -0.528, 0, 0.5, '#joyful', '#surprising', 0.667, 'find_grocery_store', 'buy_grocery', 'buy_food', 'purchase_grocery', 'shop_food']
senticnet['buy_vending_machine'] = [-0.06, 0.172, 0, 0.073, '#interesting', '#admirable', 0.062, 'buy_goods_service', 'pay_goods', 'buy', 'incur_debt', 'cashless']
senticnet['buy_video_game'] = [0.896, 0.887, 0, 0.719, '#joyful', '#interesting', 0.834, 'play', 'video_game', 'turn_on_tv', 'play_video_game', 'play_game']
senticnet['buy_wash_powder'] = [0, 0.095, 0, 0.074, '#interesting', '#admirable', 0.056, 'laundry_detergent', 'water_soap', 'clothes_dirty', 'laundry', 'use_water']
senticnet['buy_water'] = [0.768, 0, 0, 0, '#joyful', '#joyful', 0.256, 'put_coin', 'buy_drink', 'play_video_game', 'coin', 'buy_cheap_item']
senticnet['buy_weapon'] = [-0.162, 0, -0.111, -0.206, '#sad', '#disgusting', -0.16, 'buy_gun', 'join_military', 'arm_oneself', 'declare_war', 'find_enemy']
senticnet['buy_wood'] = [-0.929, 0, 0, -0.702, '#sad', '#disgusting', -0.544, 'hatchet', 'knife', 'sword', 'sharp_weapon', 'angle_grinder']
senticnet['buyer'] = [0, 0.123, -0.071, 0.097, '#interesting', '#admirable', 0.05, 'capitalist', 'make_rich', 'businessman', 'consumer', 'broker']
senticnet['buzz'] = [0, 0, 0.914, -0.912, '#angry', '#disgusting', -0.609, 'glide', 'cool_engine', 'go_stall', 'land_runway', 'bus_person']
senticnet['buzzing'] = [0, 0, -0.709, -0.913, '#scared', '#disgusting', -0.541, 'bombinate', 'bombilate', 'hum', 'seethe', 'abuzz']
senticnet['bye'] = [0.775, 0, 0, 0.986, '#joyful', '#admirable', 0.587, 'get_fast', 'pay_toll', 'drive', 'drive_upon', 'access']
senticnet['byproduct'] = [-0.58, 0, 0.535, -0.72, '#sad', '#disgusting', -0.612, 'epiphenomenon', 'effect', 'issue', 'consequence', 'outcome']
senticnet['bystander'] = [-0.826, 0, 0.652, -0.719, '#sad', '#disgusting', -0.732, 'witness', 'spectator', 'viewer', 'watcher', 'looker']
senticnet['c_clamp'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'fine', 'speeding_ticket', 'break_law', 'clamp', 'restriction']
senticnet['cabaret'] = [-0.901, 0, 0.848, -0.944, '#sad', '#disgusting', -0.898, 'dive', 'nightclub', 'night_club', 'club', 'nightspot']
senticnet['cabbage'] = [0, -0.006, 0.053, -0.037, '#angry', '#disgusting', -0.028, 'kale', 'cucumber', 'broccoli', 'lettuce', 'pea']
senticnet['cabin'] = [0, 0, 0.012, -0.063, '#angry', '#disgusting', -0.025, 'shack', 'college_dorm', 'hostel', 'dormitory', 'student_home']
senticnet['cable_car'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'mini_van', 'baggage_compartment', 'subway', 'amusement_park', 'terminal']
senticnet['cachet'] = [0.682, -0.705, 0, 0.98, '#surprising', '#admirable', 0.789, 'prize', 'seal_of_approval', 'honorable_mention', 'aliyah', 'laurels']
senticnet['cachexia'] = [0.576, -0.959, 0, 0.998, '#surprising', '#admirable', 0.844, 'debility', 'cachexy', 'wasting', 'softness', 'unfitness']
senticnet['cachexy'] = [0.576, -0.959, 0, 0.998, '#surprising', '#admirable', 0.844, 'cachexia', 'debility', 'wasting', 'softness', 'unfitness']
senticnet['cacoethes'] = [-0.898, 0, 0.987, -0.904, '#angry', '#disgusting', -0.93, 'logorrhea', 'logomania', 'agromania', 'pyromania', 'necrophilia']
senticnet['cacogenesis'] = [-0.738, 0, 0.634, -0.856, '#sad', '#disgusting', -0.743, 'infertility', 'impotence', 'impotency', 'barrenness', 'dysgenesis']
senticnet['cacography'] = [-0.842, 0, 0.579, -0.747, '#sad', '#disgusting', -0.723, 'squiggle', 'hand', 'chicken_scratch', 'handwriting', 'script']
senticnet['cacophonic'] = [-0.937, 0, 0.576, -0.545, '#sad', '#angry', -0.686, 'grating', 'rasping', 'raspy', 'jarring', 'gruff']
senticnet['cacophonous'] = [-0.652, 0, 0.578, -0.769, '#sad', '#disgusting', -0.666, 'grating', 'rasping', 'raspy', 'jarring', 'gruff']
senticnet['cad'] = [-0.889, 0, 0.806, -0.638, '#sad', '#angry', -0.778, 'blackguard', 'scoundrel', 'bounder', 'rogue', 'hound']
senticnet['cadaver'] = [0, 0, -0.753, -0.749, '#scared', '#disgusting', -0.501, 'dead_person', 'corpse', 'in_person', 'human_chest', 'below_neck']
senticnet['cadenced'] = [-0.841, 0, 0.574, -0.668, '#sad', '#disgusting', -0.694, 'rhythmical', 'cadent', 'metrical', 'metric', 'lilting']
senticnet['cadent'] = [-0.841, 0, 0.574, -0.668, '#sad', '#disgusting', -0.694, 'cadenced', 'rhythmical', 'metrical', 'metric', 'lilting']
senticnet['cadge'] = [0.866, -0.917, 0, 0.893, '#surprising', '#admirable', 0.892, 'mooch', 'freeload', 'grub', 'sponge', 'bum']
senticnet['cadre'] = [0.942, -0.797, 0, 0.561, '#joyful', '#surprising', 0.767, 'sleeper_cell', 'terrorist_cell', 'radical_cell', 'political_unit', 'political_entity']
senticnet['caenogenesis'] = [-0.595, 0, 0.983, -0.675, '#angry', '#disgusting', -0.751, 'growth', 'growing', 'maturation', 'development', 'ontogeny']
senticnet['cafe'] = [0.078, 0, 0, 0, '#joyful', '#joyful', 0.026, 'buy_sandwich', 'lunch', 'eat_food', 'buy_food', 'finish_job']
senticnet['caffeine'] = [0, 0, 0, 0.128, '#admirable', '#admirable', 0.043, 'wooden_spoon', 'cereal_bowl', 'teaspoon', 'container_cup', 'large_container']
senticnet['caffeine_intoxication'] = [-0.72, 0, 0.884, -0.758, '#angry', '#disgusting', -0.787, 'ergotism', 'paraquat_poisoning', 'alkali_poisoning', 'caffeinism', 'poisoning']
senticnet['caffeinism'] = [-0.72, 0, 0.884, -0.758, '#angry', '#disgusting', -0.787, 'ergotism', 'paraquat_poisoning', 'alkali_poisoning', 'poisoning', 'caffeine_intoxication']
senticnet['cage'] = [0, -0.101, 0, 0, '#surprising', '#surprising', 0.034, 'mammal', 'animal', 'reptile', 'wildlife', 'zoo']
senticnet['cage_animal'] = [-0.895, 0, 0, -0.898, '#sad', '#disgusting', -0.598, 'hound', 'zoo', 'kind_animal', 'hunter', 'animal']
senticnet['caged_lion'] = [-0.907, 0, 0, -0.786, '#sad', '#disgusting', -0.564, 'oppression', 'enslavement', 'slave', 'captivity', 'misery']
senticnet['caiman'] = [-0.853, 0, 0.685, -0.838, '#sad', '#disgusting', -0.792, 'alligator', 'crocodile', 'false_gavial', 'gator', 'crocodilian']
senticnet['cajole'] = [0, 0, -0.925, -0.823, '#scared', '#disgusting', -0.583, 'wheedle', 'sweet-talk', 'blarney', 'palaver', 'coax']
senticnet['cake'] = [0.029, -0.16, 0, 0, '#joyful', '#surprising', 0.063, 'mousse', 'brownie', 'pancake', 'custard', 'doughnut']
senticnet['cake_candle'] = [0.124, -0.187, -0.068, 0, '#joyful', '#surprising', 0.081, 'yearly_celebration', 'special_day', 'occasion', 'party_time', 'celebration']
senticnet['cake_eat'] = [0.24, -0.058, -0.073, 0.127, '#joyful', '#admirable', 0.117, 'party_time', 'special_event', 'special_occasion', 'special_day', 'new_baby']
senticnet['calamity'] = [-0.848, 0, -0.824, 0, '#sad', '#scared', -0.557, 'unsafe', 'bad_news', 'chemical_reaction', 'disaster', 'big_monster']
senticnet['calcium'] = [0.752, 0.763, 0, 0, '#joyful', '#interesting', 0.505, 'breakfast', 'box_cereal', 'carton_milk', 'drink', 'pasta']
senticnet['calculable'] = [0.983, -0.807, 0, 0.966, '#joyful', '#admirable', 0.919, 'estimable', 'computable', 'countable', 'denumerable', 'enumerable']
senticnet['calculate'] = [0.047, 0.148, 0, 0.107, '#interesting', '#admirable', 0.101, 'add_number', 'calculation', 'compute', 'surf_internet', 'word_process']
senticnet['calculate_quickly'] = [-0.866, 0, 0.726, 0, '#sad', '#angry', -0.531, 'add_up_number', 'add_up_column_number', 'compute_sum', 'program_computer', 'write_program']
senticnet['calculating'] = [0, -0.908, 0, 0.775, '#surprising', '#admirable', 0.561, 'compute', 'work_out', 'reckon', 'figure', 'estimate']
senticnet['calculation'] = [0, 0.951, 0, 0, '#interesting', '#interesting', 0.317, 'enter_data_computer', 'train_open_mind', 'write_computer_program', 'add_two_numbers_together', 'add_number']
senticnet['calculator'] = [0, 0, 0.128, 0, '#angry', '#angry', -0.043, 'grid', 'efficient', 'typewriter', 'computer', 'personal_computer']
senticnet['calculus'] = [0.808, 0, 0, 0.947, '#joyful', '#admirable', 0.585, 'algebra', 'math', 'mathematics', 'math_equation', 'mathematical_function']
senticnet['calendar'] = [0, -0.003, 0.063, -0.037, '#angry', '#disgusting', -0.032, 'thirty', 'date', 'day_month', 'day', 'time_measurement']
senticnet['calendar_book'] = [0, -0.757, 0, 0.944, '#surprising', '#admirable', 0.567, 'diary', 'program', 'database', 'schedule', 'timetable']
senticnet['calendar_date'] = [0.989, 0.976, 0, 0, '#joyful', '#interesting', 0.655, 'due', 'tax', 'owe', 'amount_owe', 'payment']
senticnet['calendar_event'] = [0, 0.069, 0, 0.092, '#interesting', '#admirable', 0.054, 'time_frame', 'time_period', 'short_time', 'event', 'time_length']
senticnet['calf_love'] = [0.522, 0.674, -0.277, 0.27, '#joyful', '#interesting', 0.396, 'puppy_love', 'infatuation', 'amatory', 'amorousness', 'amorous']
senticnet['caliber'] = [0.887, -0.95, 0, 0.913, '#surprising', '#admirable', 0.917, 'high_quality', 'superiority', 'level', 'grade', 'degree']
senticnet['calibration'] = [0.667, -0.885, 0, 0.92, '#surprising', '#admirable', 0.824, 'adjustment', 'activity', 'tuning', 'registration', 'readjustment']
senticnet['call'] = [0, 0, 0, 0.141, '#admirable', '#admirable', 0.047, 'phone_conversation', 'use_phone', 'telephone_ring', 'make_call', 'say']
senticnet['call_911'] = [-0.076, 0, -0.145, -0.062, '#sad', '#scared', -0.094, 'emergency', 'accident', 'crime_scene', 'need_help', 'call_police']
senticnet['call_back'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'keep_in_touch', 'polite', 'take_care', 'kind', 'gentle']
senticnet['call_center'] = [0.065, -0.021, 0.009, 0, '#joyful', '#surprising', 0.026, 'recollection', 'brain_activity', 'memorization', 'memory', 'recall']
senticnet['call_dad'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'talk_telephone', 'call', 'call_family', 'call_mom', 'use_phone']
senticnet['call_doctor'] = [-0.133, 0, -0.183, -0.154, '#scared', '#disgusting', -0.157, 'doctor_appointment', 'make_appointment_with_doctor', 'make_doctor_appointment', 'find_doctor', 'turn_head_cough']
senticnet['call_dog'] = [-0.071, 0, 0, 0, '#sad', '#sad', -0.024, 'kiss_partner', 'change_diaper', 'need_companionship', 'enjoy_sex', 'smoke_cigar']
senticnet['call_down'] = [-0.718, 0, 0.5, -0.68, '#sad', '#disgusting', -0.633, 'beshrew', 'damn', 'bedamn', 'maledict', 'anathemize']
senticnet['call_family'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'talk_telephone', 'call', 'call_mom', 'call_dad', 'use_phone']
senticnet['call_forth'] = [-0.836, 0, 0.555, -0.642, '#sad', '#disgusting', -0.678, 'call_down', 'stir', 'anathemize', 'conjure', 'bring_up']
senticnet['call_friend'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'friend', 'communication', 'talk_on_phone', 'chat', 'talk_spouse']
senticnet['call_friend_phone'] = [0.945, 0, 0, 0.939, '#joyful', '#admirable', 0.628, 'answer_telephone', 'answer_phone', 'hunt_duck', 'call_mom', 'receive_letter']
senticnet['call_girl'] = [-0.917, 0, 0.974, -0.612, '#sad', '#angry', -0.834, 'slattern', 'camp_follower', 'bawd', 'comfort_woman', 'ianfu']
senticnet['call_help'] = [-0.201, -0.06, -0.162, -0.22, '#sad', '#disgusting', -0.174, 'arrest_police', 'feel_anger', 'die', 'end_life', 'get_arrested']
senticnet['call_lawyer'] = [-0.219, 0.108, -0.134, 0, '#sad', '#scared', -0.082, 'hire_lawyer', 'settle_dispute', 'verdict', 'seek_justice', 'go_court']
senticnet['call_mom'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'talk_telephone', 'call', 'call_family', 'call_dad', 'use_phone']
senticnet['call_mother'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'talk_telephone', 'call_mom', 'call_family', 'call', 'use_phone']
senticnet['call_name'] = [-0.404, -0.068, 0, -0.367, '#sad', '#disgusting', -0.234, 'overwhelm', 'feel_hurt', 'lose_mind', 'become_angry', 'black_eye']
senticnet['call_number'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'use_phone', 'take_number', 'write_number', 'contact', 'add_number']
senticnet['call_on_carpet'] = [-0.559, 0, 0.685, -0.502, '#sad', '#angry', -0.582, 'castigate', 'tell_off', 'brush_down', 'chasten', 'objurgate']
senticnet['call_out'] = [-0.139, -0.057, -0.166, -0.045, '#sad', '#scared', -0.098, 'cry', 'cry_help', 'make_face', 'feel_stupid', 'end_relationship']
senticnet['call_person'] = [0, -0.872, 0, 0.904, '#surprising', '#admirable', 0.592, 'dial_phone', 'chat', 'say_name', 'converse', 'talkative']
senticnet['call_phone'] = [0, 0, 0, 0.077, '#admirable', '#admirable', 0.026, 'find_person', 'contact_friend', 'arrange_meet', 'chat', 'start_conversation']
senticnet['call_police'] = [-0.217, 0.16, -0.194, 0.057, '#sad', '#scared', -0.065, 'murder', 'make_judgment', 'testify', 'arrest_criminal', 'tell_truth']
senticnet['call_restaurant'] = [0, 0.084, 0, 0, '#interesting', '#interesting', 0.028, 'enquiries', 'reservation', 'reserve', 'dinner', 'reserved']
senticnet['call_sick'] = [-0.983, 0, 0, 0, '#sad', '#sad', -0.328, 'put_pyjamas', 'count_sheep', 'go_room', 'sleepwalk', 'turn_out_light']
senticnet['call_telephone'] = [0, -0.966, 0, 0.814, '#surprising', '#admirable', 0.593, 'call_phone', 'meet_at_coffee_shop', 'call_person', 'use_telephone', 'make_telephone_call']
senticnet['call_up'] = [0.026, -0.05, 0, 0.051, '#surprising', '#admirable', 0.042, 'clean_apartment', 'hump_leg', 'call_phone', 'start_conversation', 'call_telephone']
senticnet['call_witness'] = [-0.032, 0.112, 0, 0.062, '#interesting', '#admirable', 0.047, 'hold_trial', 'become_judge', 'enter_courtroom', 'consider_evidence', 'become_lawyer']
senticnet['calligraphy'] = [0, 0.074, 0.026, 0.105, '#interesting', '#admirable', 0.051, 'handwritten', 'scribble', 'music_part', 'written_message', 'jot']
senticnet['callous'] = [-0.911, 0, 0.886, 0, '#sad', '#angry', -0.599, 'thickened', 'tougheneded', 'heartless', 'unfeeling', 'uncaring']
senticnet['calloused'] = [0.641, -0.577, 0, 0.707, '#joyful', '#admirable', 0.642, 'enured', 'inured', 'thickened', 'toughened', 'callous']
senticnet['callowness'] = [-0.938, 0, 0.906, -0.539, '#sad', '#angry', -0.794, 'juvenility', 'state', 'greenness', 'immatureness', 'jejuneness']
senticnet['callus'] = [-0.072, -0.063, 0.079, -0.182, '#angry', '#disgusting', -0.09, 'keep_rhythm', 'make_feel_bad', 'part_of_band', 'make_a_lot_of_noise', 'make_noise']
senticnet['calm'] = [0, 0, 0, 0.915, '#admirable', '#admirable', 0.305, 'calmness', 'peacefulness', 'serenity', 'ease', 'soothe']
senticnet['calm_down'] = [0.494, 0.45, -0.113, 0.056, '#joyful', '#interesting', 0.296, 'recreate', 'peacefulness', 'euphoria', 'serenity', 'closeness']
senticnet['calm_mind'] = [0, 0, 0, 0.94, '#admirable', '#admirable', 0.313, 'accomplish_goal', 'happiness', 'better_life', 'sexual_pleasure', 'get_hired']
senticnet['calml'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'lull', 'quiet', 'soothing', 'assuasive', 'tranquillize']
senticnet['calmly'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'quieten', 'soothing', 'assuasive', 'tranquility', 'tranquilize']
senticnet['calmness'] = [0, 0, 0, 0.911, '#admirable', '#admirable', 0.304, 'calm', 'peacefulness', 'serenity', 'joy', 'tranquility']
senticnet['calorie'] = [0.136, 0, -0.05, 0.099, '#joyful', '#admirable', 0.062, 'hyper', 'carbohydrate', 'natural_resource', 'create_destroy', 'necessary_live']
senticnet['calumniate'] = [-0.835, 0, 0, -0.758, '#sad', '#disgusting', -0.531, 'charge', 'accuse', 'malign', 'libel', 'slander']
senticnet['calumniation'] = [-0.639, 0, 0.581, -0.843, '#sad', '#disgusting', -0.688, 'malignment', 'vilification', 'smear', 'character_assassination', 'libel']
senticnet['calumny'] = [-0.721, 0, 0.951, -0.969, '#angry', '#disgusting', -0.88, 'malignment', 'vilification', 'smear', 'character_assassination', 'libel']
senticnet['calve'] = [0.032, 0.109, -0.079, 0.085, '#interesting', '#admirable', 0.049, 'plural', 'kin', 'relate_person', 'younger', 'young_people']
senticnet['calyx'] = [0, 0, 0.064, -0.04, '#angry', '#disgusting', -0.035, 'bird_food', 'funiculus', 'plant_product', 'fuzz', 'agricultural_product']
senticnet['camera'] = [0, -0.028, 0.048, -0.058, '#angry', '#disgusting', -0.026, 'telescope', 'read_glass', 'eyeglass', 'binoculars', 'monocle']
senticnet['camera_film'] = [0, 0.156, -0.06, 0.198, '#interesting', '#admirable', 0.098, 'wall_decoration', 'image', 'wall_hang', 'like_paint', 'illustration']
senticnet['camera_store'] = [0, 0.07, 0, 0.071, '#interesting', '#admirable', 0.047, 'tv_studio', 'film_studio', 'opus', 'cinema', 'theater']
senticnet['camion'] = [0.65, -0.634, 0, 0.629, '#joyful', '#surprising', 0.638, 'motortruck', 'rig', 'wrecker', 'dump_truck', 'dumper']
senticnet['camouflage'] = [0, 0, -0.077, 0, '#scared', '#scared', -0.026, 'shield', 'squire', 'carry_gun', 'samurai', 'soldier']
senticnet['camp'] = [0, 0.156, -0.06, 0.198, '#interesting', '#admirable', 0.098, 'field', 'camping', 'camp_out', 'campsite', 'campground']
senticnet['camp_follower'] = [-0.62, 0, 0.98, -0.812, '#angry', '#disgusting', -0.804, 'tart', 'prostitute', 'harlot', 'bawd', 'sporting_lady']
senticnet['camp_out'] = [0.786, 0, 0, 0, '#joyful', '#joyful', 0.262, 'camping', 'outdoor', 'tent', 'bonfire', 'fresh_air']
senticnet['campaign'] = [-0.811, 0, 0, 0, '#sad', '#sad', -0.27, 'take_charge', 'anti', 'go_against', 'death_wish', 'file_complaint']
senticnet['campaigning'] = [-0.797, 0, 0.525, -0.635, '#sad', '#disgusting', -0.652, 'whispering_campaign', 'candidacy', 'candidature', 'electioneering', 'political_campaign']
senticnet['campfire'] = [0.1, 0, 0, 0, '#joyful', '#joyful', 0.033, 'burn_material', 'ash', 'stay_warm', 'oregano', 'bonfire']
senticnet['campground'] = [0, 0.156, -0.06, 0.198, '#interesting', '#admirable', 0.098, 'field', 'camping', 'camp_out', 'campsite', 'camp']
senticnet['camping'] = [0, 0.156, -0.06, 0.198, '#interesting', '#admirable', 0.098, 'field', 'camp', 'camp_out', 'campsite', 'campground']
senticnet['campsite'] = [0.786, 0, 0, 0, '#joyful', '#joyful', 0.262, 'camping', 'outdoor', 'camp_out', 'camp', 'enjoy_nature']
senticnet['campus'] = [0.053, -0.12, 0.015, -0.036, '#joyful', '#surprising', 0.041, 'student_place', 'learning_place', 'school_session', 'after_school', 'professor']
senticnet['can'] = [0.661, -0.821, 0, 0.952, '#surprising', '#admirable', 0.811, 'displace', 'fire', 'give_notice', 'pension_off', 'dismiss']
senticnet['can_fly'] = [0.114, 0, 0, 0, '#joyful', '#joyful', 0.038, 'mallard', 'vulture', 'pigeon', 'bird', 'most_birds']
senticnet['canary'] = [-0.514, 0, 0.626, -0.544, '#angry', '#disgusting', -0.561, 'brownish_yellow', 'yellowness_yellow', 'old_gold', 'gold', 'yellowness']
senticnet['canary_yellow'] = [0.065, -0.021, 0.009, 0, '#joyful', '#surprising', 0.026, 'brownish_yellow', 'yellowness', 'old_gold', 'gold', 'canary']
senticnet['cancel'] = [-0.221, 0, -0.118, -0.126, '#sad', '#disgusting', -0.155, 'give_up', 'failure', 'military_action', 'beaten', 'cost_fortune']
senticnet['cancel_appointment'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'escape', 'escape_situation', 'cancel_meeting', 'no_show', 'bail_out']
senticnet['cancel_meeting'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'escape', 'escape_situation', 'bail_out', 'no_show', 'cancel_appointment']
senticnet['cancer'] = [0, 0, -0.873, -0.819, '#scared', '#disgusting', -0.564, 'infection', 'get_lung_cancer', 'nuclear_war', 'bigot', 'torture']
senticnet['cancer_of_liver'] = [-0.917, 0, 0.974, -0.612, '#sad', '#angry', -0.834, 'disease', 'fatty_liver', 'hepatitis', 'liver_cancer', 'liver_disease']
senticnet['candela'] = [-0.639, 0, 0.897, -0.915, '#angry', '#disgusting', -0.817, 'cd-rom', 'international_candle', 'candle', 'candlepower_unit', 'standard_candle']
senticnet['candid'] = [0.05, 0.166, -0.071, 0.152, '#interesting', '#admirable', 0.099, 'direct', 'person', 'outspoken', 'frank', 'direct_person']
senticnet['candidacy'] = [-0.797, 0, 0.525, -0.635, '#sad', '#disgusting', -0.652, 'campaigning', 'whispering_campaign', 'candidature', 'electioneering', 'political_campaign']
senticnet['candidate'] = [0, 0.232, -0.106, 0.156, '#interesting', '#admirable', 0.094, 'election', 'elect', 'government', 'president', 'vote']
senticnet['candidature'] = [-0.797, 0, 0.525, -0.635, '#sad', '#disgusting', -0.652, 'campaigning', 'candidacy', 'whispering_campaign', 'electioneering', 'political_campaign']
senticnet['candied'] = [0.789, -0.58, 0, 0.715, '#joyful', '#admirable', 0.695, 'desiccated', 'aged', 'lyophilized', 'cured', 'preserved']
senticnet['candied_citrus_peel'] = [-0.952, 0, 0.845, -0.679, '#sad', '#angry', -0.825, 'grapefruit_peel', 'lemon_peel', 'orange_peel', 'candied_fruit', 'succade']
senticnet['candied_fruit'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'grapefruit_peel', 'lemon_peel', 'orange_peel', 'candied_citrus_peel', 'succade']
senticnet['candle'] = [0, 0.232, -0.106, 0.156, '#interesting', '#admirable', 0.094, 'light', 'eat_cake', 'birthday_party', 'candle_light', 'romantic_atmosphere']
senticnet['candle_light'] = [0, 0.232, -0.106, 0.156, '#interesting', '#admirable', 0.094, 'light', 'eat_cake', 'birthday_party', 'candle', 'romantic_atmosphere']
senticnet['candlepower'] = [-0.934, 0, 0.698, -0.857, '#sad', '#disgusting', -0.83, 'intensity', 'light_intensity', 'acoustic_power', 'sound_pressure_level', 'threshold_level']
senticnet['candlepower_unit'] = [-0.639, 0, 0.897, -0.915, '#angry', '#disgusting', -0.817, 'cd-rom', 'international_candle', 'candle', 'candela', 'standard_candle']
senticnet['candy'] = [0.066, -0.079, 0, 0, '#joyful', '#surprising', 0.048, 'ice_cream', 'muffin', 'chocolate_dessert', 'pudding', 'chocolate']
senticnet['candy_cane'] = [0, -0.068, 0, 0, '#surprising', '#surprising', 0.023, 'ripe_apple', 'custard', 'cookie', 'candy', 'orange_fruit']
senticnet['candy_machine'] = [0.727, 0.945, 0, 0, '#joyful', '#interesting', 0.557, 'candy', 'park_meter', 'coin_purse', 'pocket', 'purse']
senticnet['candy_shop'] = [0, 0.136, -0.098, 0.213, '#interesting', '#admirable', 0.084, 'good', 'tasty_good', 'uncommon', 'make_fruit', 'serve_cold']
senticnet['candy_store'] = [0, 0.074, 0, 0.071, '#interesting', '#admirable', 0.048, 'candy', 'sweet', 'sugar', 'sweet_tooth', 'chocolate']
senticnet['cane'] = [0.609, -0.744, 0, 0.716, '#surprising', '#admirable', 0.69, 'malacca', 'sword', 'swagger_stick', 'sword_cane', 'sword_stick']
senticnet['canella'] = [0, 0.158, -0.125, 0.138, '#interesting', '#admirable', 0.057, 'spice', 'sweet', 'sweetener', 'smell_good', 'white_cinnamon']
senticnet['canella_bark'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'cork', 'cassia_bark', 'canella', 'bark', 'white_cinnamon']
senticnet['canine'] = [0.039, 0, 0, 0.059, '#joyful', '#admirable', 0.033, 'big_dog', 'dog_cat', 'smart_dog', 'pet', 'domesticated_animal']
senticnet['caning'] = [-0.764, -0.836, -0.896, -0.967, '#scared', '#disgusting', -0.597, 'capital_punishment', 'death_destruction', 'kill', 'murder', 'get_rid_of_enemy']
senticnet['cannabis'] = [0.962, 0, 0, 0, '#joyful', '#joyful', 0.321, 'marijuana', 'pleasure_garden', 'trellis', 'mushroom', 'cabbage']
senticnet['cannibal'] = [-0.73, 0, 0.734, -0.786, '#angry', '#disgusting', -0.75, 'primitive', 'headhunter', 'barbarian', 'anthropophagus', 'anthropophagite']
senticnet['cannibalism'] = [-0.177, 0, -0.168, -0.093, '#sad', '#scared', -0.146, 'murder', 'hurt_others', 'death_penalty', 'death_destruction', 'end_live']
senticnet['cannibalize'] = [-0.994, 0, 0.553, -0.528, '#sad', '#angry', -0.692, 'take_in', 'take', 'ingest', 'have', 'consume']
senticnet['cannon'] = [0, 0, 0.715, -0.978, '#angry', '#disgusting', -0.564, 'machine_gun', 'handgun', 'big_gun', 'weapon', 'grenade']
senticnet['cannonball'] = [0, 0, 0.972, -0.791, '#angry', '#disgusting', -0.588, 'aerial_bomb', 'grenade', 'cannon', 'weapon', 'machine_gun']
senticnet['canoe'] = [0, 0, 0, -0.072, '#disgusting', '#disgusting', -0.024, 'submarine', 'lifeboat', 'titanic', 'large_ship', 'battleship']
senticnet['canoes'] = [0, 0, 0, 0.135, '#admirable', '#admirable', 0.045, 'kayak', 'ferries', 'boat_type', 'towboats', 'yachts']
senticnet['canon'] = [0.028, 0.138, -0.048, 0.215, '#interesting', '#admirable', 0.111, 'fee', 'rule', 'standard', 'criterion', 'tenet']
senticnet['cant'] = [-0.393, 0.149, -0.166, 0.062, '#sad', '#scared', -0.116, 'bad_action', 'bad_behavior', 'negative', 'inherit', 'badness']
senticnet['cantankerous'] = [-0.964, 0, 0.858, -0.876, '#sad', '#disgusting', -0.899, 'contrarious', 'dogged', 'pertinacious', 'unregenerate', 'bolshy']
senticnet['cantata'] = [0.514, -0.586, 0, 0.927, '#surprising', '#admirable', 0.676, 'genre', 'fugue', 'chamber_music', 'opera', 'serious_music']
senticnet['canteen'] = [0.619, -0.834, 0, 0.912, '#surprising', '#admirable', 0.788, 'hipflask', 'pocket_flask', 'ampulla', 'flask', 'vacuum_flask']
senticnet['canvas'] = [0.041, 0.112, 0, 0.077, '#interesting', '#admirable', 0.077, 'oil_paint', 'artist', 'brush', 'palette', 'artist_tool']
senticnet['canvass'] = [0.722, -0.872, 0, 0.9, '#surprising', '#admirable', 0.831, 'study', 'explore', 'analyze', 'examine', 'diagnose']
senticnet['canyon'] = [0, 0.069, 0, 0.065, '#interesting', '#admirable', 0.045, 'alp', 'high_mountain', 'rocky_area', 'ski_resort', 'high_place']
senticnet['cap'] = [0.179, 0.164, -0.052, 0.163, '#joyful', '#interesting', 0.151, 'shower_cover_hair', 'hat', 'cover_hair', 'head_wear', 'scarf']
senticnet['capability'] = [0.515, -0.544, 0, 0.579, '#surprising', '#admirable', 0.546, 'executability', 'ability', 'associability', 'associableness', 'strength']
senticnet['capable'] = [0.028, 0.138, -0.048, 0.215, '#interesting', '#admirable', 0.111, 'skilled', 'expert', 'tin', 'dense_water', 'metal_container']
senticnet['capableness'] = [0.946, -0.641, 0, 0.602, '#joyful', '#surprising', 0.73, 'grasp', 'perfectibility', 'imperfectibility', 'reach', 'aptitude']
senticnet['capacity'] = [-0.828, 0, 0.948, -0.855, '#angry', '#disgusting', -0.877, 'resistance', 'potential', 'reluctance', 'distortion', 'electrical_phenomenon']
senticnet['caparisoned'] = [-0.533, 0, 0.937, -0.802, '#angry', '#disgusting', -0.757, 'gowned', 'petticoated', 'surpliced', 'arrayed', 'clad']
senticnet['cape'] = [0, 0, 0.851, -0.711, '#angry', '#disgusting', -0.521, 'vest', 'suit', 'garment', 'outer_wear', 'kimono']
senticnet['caper'] = [-0.573, 0, 0.721, -0.775, '#angry', '#disgusting', -0.69, 'bush', 'native_pomegranate', 'caper_tree', 'native_orange', 'common_caper']
senticnet['caper_tree'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'bush', 'native_pomegranate', 'caper', 'native_orange', 'common_caper']
senticnet['capillary_fracture'] = [-0.812, 0, 0.745, -0.94, '#sad', '#disgusting', -0.832, 'injury', 'hairline_fracture', 'fracture', 'incomplete_fracture', 'simple_fracture']
senticnet['capital'] = [0.059, 0.143, 0, 0, '#joyful', '#interesting', 0.067, 'capitol', 'feudalism', 'district', 'citizen', 'empire']
senticnet['capital_build'] = [0.02, 0.222, 0.023, 0.176, '#interesting', '#admirable', 0.132, 'monastery', 'cathedral', 'temple', 'church', 'synagogue']
senticnet['capital_gains_tax'] = [-0.836, 0, 0.555, -0.642, '#sad', '#disgusting', -0.678, 'single_tax', 'income_tax', 'taxation', 'capital_levy', 'departure_tax']
senticnet['capital_levy'] = [-0.836, 0, 0.555, -0.642, '#sad', '#disgusting', -0.678, 'single_tax', 'income_tax', 'capital_gains_tax', 'taxation', 'departure_tax']
senticnet['capital_punishment'] = [-0.197, 0, -0.171, -0.148, '#sad', '#scared', -0.172, 'death_penalty', 'die', 'death_destruction', 'kill', 'murder']
senticnet['capitalism'] = [0, 0.224, -0.053, 0.128, '#interesting', '#admirable', 0.1, 'save', 'receive_service', 'money_maker', 'commerce', 'item_sell']
senticnet['capitalist'] = [0.022, 0, 0.074, -0.042, '#angry', '#disgusting', -0.031, 'sell_goods', 'buy_cheese', 'buy_sell', 'impulse_shop', 'make_rich']
senticnet['capitalize'] = [0.101, 0.275, -0.112, 0.376, '#interesting', '#admirable', 0.213, 'important', 'good_etiquette', 'good_quality', 'earn_money', 'good']
senticnet['capitol'] = [0.066, 0.179, 0, 0.066, '#joyful', '#interesting', 0.104, 'capital', 'citizen', 'district', 'feudalism', 'empire']
senticnet['capitol_build'] = [0, 0.128, 0.01, 0.093, '#interesting', '#admirable', 0.07, 'giant', 'sumo_wrestler', 'tall_man', 'egret', 'capital_build']
senticnet['capoeira'] = [-0.061, -0.003, -0.092, 0, '#sad', '#scared', -0.05, 'madman', 'trouble', 'agony', 'cause_problem', 'river_stream']
senticnet['capoeira_angola'] = [0, 0.066, 0.06, 0.075, '#interesting', '#admirable', 0.027, 'viewer', 'stuff_use_calculation', 'dwarf_planet', 'bluetooth', 'ridgeback']
senticnet['capsaicin'] = [-0.829, 0, 0.642, -0.72, '#sad', '#disgusting', -0.73, 'substance', 'chemical_irritant', 'gingerol', 'piperine', 'pepper_spray']
senticnet['capsule'] = [0, 0, 0.892, -0.965, '#angry', '#disgusting', -0.619, 'aspirin', 'scalpel', 'ibuprofen', 'pushpin', 'palliative']
senticnet['captain'] = [0.045, 0, 0, 0.088, '#joyful', '#admirable', 0.044, 'leader', 'seaman', 'lieutenant', 'officer', 'traitor']
senticnet['captain_boat'] = [-0.745, 0, -0.835, 0, '#sad', '#scared', -0.527, 'welcome_friend', 'bicycle_across_town', 'mine_diamond', 'age_gracefully', 'dig_grave']
senticnet['captain_ship'] = [-0.958, 0, -0.717, 0, '#sad', '#scared', -0.558, 'chair_committee', 'sail_around_world', 'voice_concern', 'age_gracefully', 'storm_out_room']
senticnet['captivate'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'captivated', 'charmed', 'bewitch', 'enthrallment', 'enchantment']
senticnet['captivated'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'charmed', 'enamor', 'enthralling', 'becharm', 'beguiled']
senticnet['captivating'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['captivation'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['captive'] = [-0.931, 0, -0.71, 0, '#sad', '#scared', -0.547, 'jailbird', 'prisoner', 'imprisoned', 'convict', 'inmate']
senticnet['captivity'] = [0, 0, 0.763, -0.976, '#angry', '#disgusting', -0.58, 'oppression', 'enslavement', 'slave', 'caged_lion', 'misery']
senticnet['capture'] = [0.619, 0.663, -0.281, 0.362, '#joyful', '#interesting', 0.454, 'captivated', 'charmed', 'beguiled', 'enthralling', 'bewitching']
senticnet['car'] = [0.722, 0.865, 0, 0.748, '#interesting', '#admirable', 0.778, 'safety', 'traffic_light', 'slow_speed', 'safety_belt', 'avoid_crash']
senticnet['car_accident'] = [-0.83, 0, -0.777, 0, '#sad', '#scared', -0.536, 'die_painfully', 'arrest_police', 'get_accident', 'fall_head', 'skin_knee']
senticnet['car_action'] = [0.024, 0.097, -0.06, 0.235, '#interesting', '#admirable', 0.099, 'passenger_car', 'car_travel', 'steer_car', 'car_movement', 'conveyance']
senticnet['car_break_down'] = [-0.705, 0, 0.925, 0, '#sad', '#angry', -0.543, 'receive_paycheck', 'present_bill', 'car_crash', 'dig_ground', 'work']
senticnet['car_bus'] = [0, 0, 0, 0.089, '#admirable', '#admirable', 0.03, 'car_truck', 'vehicle', 'car_drive', 'big_car', 'truck']
senticnet['car_crash'] = [0, 0, -0.983, -0.732, '#scared', '#disgusting', -0.572, 'accident', 'skid_mark', 'automobile_accident', 'speeding_ticket', 'traffic_jam']
senticnet['car_dealership'] = [0, 0, 0, -0.077, '#disgusting', '#disgusting', -0.026, 'sell_car', 'truck_stop', 'vehicle', 'insurance', 'car']
senticnet['car_drive'] = [0, 0, 0, 0.089, '#admirable', '#admirable', 0.03, 'car_truck', 'vehicle', 'car_bus', 'big_car', 'truck']
senticnet['car_engine'] = [0, -0.019, 0, 0.064, '#surprising', '#admirable', 0.028, 'car_gas', 'car_power', 'fossil_fuel', 'run_car', 'motor_vehicle']
senticnet['car_gas'] = [0, -0.019, 0, 0.064, '#surprising', '#admirable', 0.028, 'car_power', 'car_engine', 'fossil_fuel', 'oil', 'fuel']
senticnet['car_go'] = [0, 0, 0, 0.165, '#admirable', '#admirable', 0.055, 'get_around', 'passenger_car', 'transportation', 'car_travel', 'use_vehicle']
senticnet['car_home'] = [0, 0.281, 0, 0.206, '#interesting', '#admirable', 0.162, 'type_of_car', 'car', 'theater', 'movie_theater', 'back_airplane']
senticnet['car_key'] = [0, 0.757, 0, 0.811, '#interesting', '#admirable', 0.523, 'find_car_key', 'car', 'drive_license', 'start_car_engine', 'transportation']
senticnet['car_mirror'] = [0.584, -0.627, 0, 0.815, '#surprising', '#admirable', 0.675, 'cheval_glass', 'mirror', 'hand_glass', 'hand_mirror', 'looking_glass']
senticnet['car_model'] = [0, 0, 0, 0.103, '#admirable', '#admirable', 0.034, 'fancy_car', 'old_car', 'expensive_car', 'most_cars', 'car']
senticnet['car_movement'] = [0, 0, 0, 0.196, '#admirable', '#admirable', 0.065, 'steer_car', 'car_action', 'car_travel', 'car_steer', 'control_car']
senticnet['car_park'] = [0.043, 0.087, 0, 0, '#joyful', '#interesting', 0.043, 'park_area', 'park_structure', 'taxiway', 'parking_lot', 'park_zone']
senticnet['car_part'] = [0.722, 0.807, 0, 0, '#joyful', '#interesting', 0.51, 'gear', 'two_wheels', 'wheel', 'car', 'windshield']
senticnet['car_path'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'path', 'roadside', 'trail', 'intersection', 'under_bridge']
senticnet['car_power'] = [0, -0.019, 0, 0.064, '#surprising', '#admirable', 0.028, 'car_gas', 'car_engine', 'fossil_fuel', 'run_car', 'crude']
senticnet['car_race'] = [0, 0, -0.056, -0.037, '#scared', '#disgusting', -0.031, 'loose_end', 'another_planet', 'death_row', 'auction', 'smithsonian']
senticnet['car_repair'] = [-0.045, -0.045, 0.056, -0.1, '#angry', '#disgusting', -0.052, 'exercise', 'exercise_regularly', 'need_fresh_air', 'excercise', 'strong_muscle']
senticnet['car_steer'] = [0, 0, 0, 0.177, '#admirable', '#admirable', 0.059, 'car_movement', 'make_go', 'car_bus', 'run_car', 'turn_car']
senticnet['car_stereo'] = [0.802, 0.805, 0, 0, '#joyful', '#interesting', 0.536, 'dashboard', 'battery', 'seatbelt', 'spare_tire', 'brake_pedal']
senticnet['car_travel'] = [0.025, 0, 0, 0.171, '#joyful', '#admirable', 0.065, 'transportation', 'trucking', 'steer_car', 'car_action', 'passenger_car']
senticnet['car_truck'] = [0, -0.043, 0, 0.053, '#surprising', '#admirable', 0.032, 'vehicle', 'machine_transportation', 'big_car', 'car', 'truck']
senticnet['car_trunk'] = [0, 0.07, 0, 0.067, '#interesting', '#admirable', 0.046, 'boot', 'put_groceries', 'extra_tyre', 'store', 'storage_place']
senticnet['car_type'] = [0.027, 0, 0, 0.146, '#joyful', '#admirable', 0.058, 'long_car', 'big_car', 'machine_transportation', 'large_car', 'work_well']
senticnet['car_wash'] = [0, 0.07, 0, 0.067, '#interesting', '#admirable', 0.046, 'clean', 'polish', 'shiny', 'looks_like_new', 'sexy_girl']
senticnet['car_wheel'] = [-0.041, -0.163, 0, 0.056, '#surprising', '#admirable', 0.059, 'car_part', 'under_car', 'automobile', 'wheel', 'car']
senticnet['car_workshop'] = [0, 0.71, 0, 0.799, '#interesting', '#admirable', 0.503, 'repair_car', 'repair_shop', 'workshop', 'repair_motorcycle', 'check_up_car']
senticnet['car_wreck'] = [0, 0, 0.96, -0.761, '#angry', '#disgusting', -0.574, 'physical_pain', 'screw_up', 'broken_finger', 'meanness', 'bloody_nose']
senticnet['carafe'] = [0.214, 0.258, -0.09, 0.2, '#joyful', '#interesting', 0.194, 'cup', 'container_cup', 'pitcher', 'mug', 'glasses']
senticnet['carat'] = [-0.027, 0.143, -0.05, 0.082, '#interesting', '#admirable', 0.049, 'medallion', 'merit', 'value', 'price', 'prize']
senticnet['caravan_inn'] = [0.931, -0.745, 0, 0.729, '#joyful', '#surprising', 0.802, 'caravansary', 'caravanserai', 'khan', 'hostel', 'imaret']
senticnet['caravansary'] = [0.931, -0.745, 0, 0.729, '#joyful', '#surprising', 0.802, 'hostel', 'caravanserai', 'khan', 'caravan_inn', 'imaret']
senticnet['caravanserai'] = [0.931, -0.745, 0, 0.729, '#joyful', '#surprising', 0.802, 'caravansary', 'hostel', 'khan', 'caravan_inn', 'imaret']
senticnet['carbohydrate'] = [0.037, 0, 0, 0.063, '#joyful', '#admirable', 0.033, 'food_type', 'food_group', 'lard', 'starch', 'staple_food']
senticnet['carbon'] = [0.053, 0.264, -0.119, 0.23, '#interesting', '#admirable', 0.143, 'natural_resource', 'petroleum', 'fossil_fuel', 'energy_source', 'potential_energy']
senticnet['carbon_fiber'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'lightweight', 'aluminium', 'light', 'thin', 'performant']
senticnet['carbon_monoxide'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'flora', 'eukaryote', 'endangered_species', 'rodent', 'tree_animal']
senticnet['carbonate_drink'] = [0.032, -0.022, -0.045, -0.087, '#scared', '#disgusting', -0.026, 'liquid', 'sparkling_water', 'sweet', 'soda', 'drink']
senticnet['carbonated_drink'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'diet_coke', 'sugar_free', 'energy_drink', 'drink', 'beverage']
senticnet['carbonation'] = [0.789, -0.925, 0, 0.964, '#surprising', '#admirable', 0.893, 'ammonification', 'permeation', 'impregnation', 'saturation', 'diffusion']
senticnet['carboxylic_acid'] = [-0.652, 0, 0.935, -0.968, '#angry', '#disgusting', -0.852, 'acid', 'hexanedioic_acid', 'adipic_acid', 'succinic_acid', 'valeric_acid']
senticnet['card'] = [0, -0.72, 0, 0.861, '#surprising', '#admirable', 0.527, 'habit_form', 'poker_chip', 'bet', 'chance', 'letter']
senticnet['card_case'] = [0.029, -0.033, 0.066, -0.086, '#angry', '#disgusting', -0.03, 'blotter', 'drawer', 'file_box', 'desk_tray', 'letter_scale']
senticnet['card_deck'] = [0, 0.133, 0, 0, '#interesting', '#interesting', 0.044, 'jewelry_store', 'hold_change', 'bank_account', 'coffer', 'wallet']
senticnet['card_game'] = [-0.035, 0.085, -0.077, 0.114, '#interesting', '#admirable', 0.029, 'many_games', 'poker', 'form_of_gambling', 'billiards', 'backgammon']
senticnet['card_type'] = [0.07, 0, 0, 0.086, '#joyful', '#admirable', 0.052, 'ephemeral', 'enjoyable_activity', 'good_sport', 'competitive', 'medical_test']
senticnet['cardboard_box'] = [0, -0.023, 0, 0.051, '#surprising', '#admirable', 0.025, 'box', 'storage', 'package', 'gift_box', 'bin']
senticnet['cardiac_arrhythmia'] = [-0.839, 0, 0.667, -0.717, '#sad', '#disgusting', -0.741, 'heart_block', 'atrioventricular_block', 'bradycardia', 'ventricular_fibrillation', 'tachycardia']
senticnet['cardiac_drug'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'heart_disease', 'heart_attack', 'cholesterol', 'blocked_artery', 'need_medicine']
senticnet['cardinal'] = [0.029, 0.147, 0.031, 0.102, '#interesting', '#admirable', 0.082, 'bishop', 'unbeliever', 'saint', 'rector', 'goddess']
senticnet['cardiomyopathy'] = [0.852, -0.988, 0, 0.67, '#joyful', '#surprising', 0.837, 'cardiac_arrhythmia', 'arrhythmia', 'cardiopathy', 'heart_disease', 'rheumatic_heart_disease']
senticnet['cardiopathy'] = [0.852, -0.988, 0, 0.67, '#joyful', '#surprising', 0.837, 'cardiac_arrhythmia', 'arrhythmia', 'cardiomyopathy', 'heart_disease', 'rheumatic_heart_disease']
senticnet['carditis'] = [-0.548, 0, 0.67, -0.926, '#angry', '#disgusting', -0.715, 'pericarditis', 'rubor', 'redness', 'endocarditis', 'inflammation']
senticnet['care'] = [0.784, 0, 0, 0, '#joyful', '#joyful', 0.261, 'precaution', 'type_of_bear', 'look_after', 'sympathy', 'assistance']
senticnet['care_child'] = [0.909, 0, 0, 0.859, '#joyful', '#admirable', 0.589, 'name_child', 'name_baby', 'quiet_cry_baby', 'quiet_child', 'care']
senticnet['care_deeply'] = [0.86, 0.967, 0, 0, '#joyful', '#interesting', 0.609, 'love_oneself', 'show_empathy', 'find_woman', 'love_another_person', 'feel_love']
senticnet['care_giver'] = [0, 0.823, 0, 0.971, '#interesting', '#admirable', 0.598, 'woman_child', 'female_relative', 'relative', 'kin', 'female_parent']
senticnet['care_patient'] = [0.829, 0.821, 0, 0, '#joyful', '#interesting', 0.55, 'cost_lot', 'doctor_patient', 'battle_disease', 'niceness', 'uncommon']
senticnet['care_person'] = [0.751, 0, 0, 0.857, '#joyful', '#admirable', 0.536, 'friendly_person', 'exercise_much', 'custom', 'moderation', 'feel_faint']
senticnet['career'] = [-0.023, 0.148, -0.081, 0.092, '#interesting', '#admirable', 0.045, 'occupation', 'police_work', 'task', 'profession', 'vocation']
senticnet['career_advancement'] = [0.882, 0.768, 0, 0, '#joyful', '#interesting', 0.55, 'have_something_to_do', 'finish_school', 'get_high_education', 'learn_skill', 'keep_job']
senticnet['carefree'] = [0.69, 0.626, -0.234, 0.317, '#joyful', '#interesting', 0.466, 'lightheartedness', 'insouciance', 'lightsomeness', 'unworried', 'carefreeness']
senticnet['carefreeness'] = [0.69, 0.626, -0.234, 0.317, '#joyful', '#interesting', 0.466, 'lightheartedness', 'insouciance', 'carefree', 'lightsomeness', 'unworried']
senticnet['careful'] = [0.095, 0.204, -0.123, 0.174, '#interesting', '#admirable', 0.117, 'go_outdoors', 'sleep_tent', 'keep_dry', 'pitch_tent', 'warm_up']
senticnet['careful_plan'] = [0.95, 0.806, 0, 0, '#joyful', '#interesting', 0.585, 'plan', 'eat_potato_chip', 'intelligent', 'healthy_food', 'stuff_face']
senticnet['carefulness'] = [0.512, -0.945, 0, 0.5, '#joyful', '#surprising', 0.652, 'scrupulousness', 'painstakingness', 'diligence', 'meticulousness', 'meticulosity']
senticnet['careless'] = [0, 0, 0.775, -0.831, '#angry', '#disgusting', -0.535, 'warmer', 'injure_oneself', 'catch_fire', 'light_cigar', 'light_pipe']
senticnet['carelessness'] = [-0.933, 0, 0.689, -0.851, '#sad', '#disgusting', -0.824, 'neglectfulness', 'inattentiveness', 'negligence', 'neglect', 'unconscientiousness']
senticnet['caress'] = [0.032, 0, 0, 0.077, '#joyful', '#admirable', 0.036, 'embrace', 'hug', 'cuddle', 'kiss', 'love']
senticnet['caribou'] = [0, 0.161, -0.089, 0.09, '#interesting', '#admirable', 0.054, 'cheetah', 'giraffe', 'kangaroo', 'mule', 'horse']
senticnet['caring'] = [0.528, 0.673, -0.275, 0.272, '#joyful', '#interesting', 0.399, 'lovingness', 'warmheartedness', 'amorousness', 'amative', 'amorous']
senticnet['cark'] = [-0.592, 0, 0.827, -0.6, '#angry', '#disgusting', -0.673, 'upset', 'trouble', 'worry', 'disturb', 'vex']
senticnet['carnage'] = [-0.793, 0, 0.624, -0.614, '#sad', '#angry', -0.677, 'murder', 'slaying', 'bloodbath', 'bloodshed', 'bloodletting']
senticnet['carnality'] = [0.509, -0.863, 0, 0.691, '#surprising', '#admirable', 0.688, 'amorousness', 'sexiness', 'amativeness', 'eroticism', 'erotism']
senticnet['carnauba'] = [0.557, -0.534, 0, 0.704, '#joyful', '#admirable', 0.598, 'palm', 'fan_palm', 'wax_palm', 'palmetto', 'palmyra']
senticnet['carnauba_palm'] = [0.557, -0.534, 0, 0.704, '#joyful', '#admirable', 0.598, 'fan_palm', 'carnauba', 'wax_palm', 'palmetto', 'palmyra']
senticnet['carnival'] = [0.957, 0.7, 0, 0, '#joyful', '#interesting', 0.552, 'ballpark', 'coven', 'disneyland', 'hockey_game', 'symposium']
senticnet['carnival_mask'] = [0.108, -0.044, 0.043, 0.065, '#joyful', '#admirable', 0.058, 'sunglasses', 'glass', 'mask', 'drink_cup', 'focus_light']
senticnet['carnival_ride'] = [0.086, -0.035, 0, 0, '#joyful', '#surprising', 0.04, 'carny', 'fortune_teller', 'midway', 'ferris_wheel', 'roller-coaster']
senticnet['carnivore'] = [-0.025, 0, 0.044, 0, '#sad', '#angry', -0.023, 'large_cat', 'fast_person', 'household_pet', 'big_cat', 'good_pet']
senticnet['carny'] = [0.082, -0.031, 0, 0, '#joyful', '#surprising', 0.038, 'carnival_ride', 'fortune_teller', 'midway', 'ferris_wheel', 'roller-coaster']
senticnet['carpal'] = [-0.744, 0, 0.598, -0.756, '#sad', '#disgusting', -0.699, 'lunate_bone', 'semilunar_bone', 'carpal_bone', 'triquetral', 'triquetral_bone']
senticnet['carpal_bone'] = [-0.66, 0, 0.947, -0.74, '#angry', '#disgusting', -0.782, 'lunate_bone', 'semilunar_bone', 'bone', 'triquetral', 'triquetral_bone']
senticnet['carpal_tunnel_syndrome'] = [-0.413, 0, -0.284, -0.058, '#sad', '#scared', -0.252, 'numbness', 'median_nerve', 'weakness', 'pain', 'muscle_damage']
senticnet['carpel'] = [0.842, 0, 0, 0.813, '#joyful', '#admirable', 0.552, 'fruit_tree', 'baby_flower', 'fig', 'strawberry', 'star_anise']
senticnet['carpenter'] = [-0.043, -0.02, -0.056, 0, '#sad', '#scared', -0.026, 'use_illegal_drug', 'delusional', 'human', 'cold_person', 'busy_person']
senticnet['carpet'] = [0.891, 0.754, 0, 0, '#joyful', '#interesting', 0.548, 'rug', 'walk_closet', 'linoleum', 'pillow_case', 'floor']
senticnet['carpet_slipper'] = [-0.541, 0, 0.612, -0.987, '#angry', '#disgusting', -0.713, 'scuff', 'mule', 'bootee', 'bootie', 'footwear']
senticnet['carpet_store'] = [-0.075, 0.228, 0.019, 0.089, '#interesting', '#admirable', 0.074, 'home_depot', 'lumberyard', 'furniture_store', 'front_porch', 'shoe_shop']
senticnet['carrier'] = [0, 0.089, 0.01, 0.118, '#interesting', '#admirable', 0.066, 'crate', 'mom_house', 'sack', 'poker_game', 'safekeep']
senticnet['carron_oil'] = [-0.644, 0, 0.941, -0.923, '#angry', '#disgusting', -0.836, 'unction', 'salve', 'ointment', 'unguent', 'balm']
senticnet['carrot_juice'] = [0.557, -0.534, 0, 0.704, '#joyful', '#admirable', 0.598, 'lemon_juice', 'chocolate_pudding', 'grape_juice', 'orange_juice', 'juice']
senticnet['carry'] = [-0.03, 0.178, -0.127, 0.279, '#interesting', '#admirable', 0.1, 'carry_item', 'haul', 'carry_object', 'spring_leak', 'carry_belongings']
senticnet['carry_around'] = [0, 0.13, -0.058, 0.184, '#interesting', '#admirable', 0.085, 'portable', 'hold_place', 'carry_belongings', 'carry_clothes', 'carry_stuff']
senticnet['carry_baby'] = [0.108, -0.044, 0.043, 0.065, '#joyful', '#admirable', 0.058, 'family', 'love_back', 'mother', 'father', 'change_diaper']
senticnet['carry_belongings'] = [0, 0.148, -0.093, 0.282, '#interesting', '#admirable', 0.112, 'carry_clothes', 'carry_book', 'carry_item', 'carry_stuff', 'carry_object']
senticnet['carry_blood'] = [0, 0.1, -0.064, 0.171, '#interesting', '#admirable', 0.069, 'carry_belongings', 'trucking', 'carry_clothes', 'transport_person', 'haul']
senticnet['carry_book'] = [-0.041, 0.149, -0.092, 0.236, '#interesting', '#admirable', 0.084, 'carry_stuff', 'carry_belongings', 'carry_clothes', 'carry_item', 'carry_grocery']
senticnet['carry_briefcase'] = [-0.91, 0, -0.865, 0, '#sad', '#scared', -0.592, 'hurry_work', 'voice_concern', 'sail_around_world', 'storm_out_room', 'age_gracefully']
senticnet['carry_clothes'] = [0, 0.108, -0.055, 0.209, '#interesting', '#admirable', 0.087, 'carry_belongings', 'carry_book', 'carry_item', 'carry_stuff', 'carry_laundry']
senticnet['carry_credit_card'] = [-0.047, 0, 0.03, 0, '#sad', '#angry', -0.026, 'use_atm', 'carry_wallet', 'take_out_wallet', 'decide_buy', 'look_price']
senticnet['carry_disease'] = [-0.116, 0, 0.03, -0.075, '#sad', '#disgusting', -0.074, 'scratch_back', 'train_open_mind', 'wrong_another_person', 'lose_key', 'voice_opinion']
senticnet['carry_document'] = [0.023, 0.085, 0, 0.061, '#interesting', '#admirable', 0.056, 'carry_paper', 'store_document', 'organize_document', 'store_checkbook', 'keep_paper_together']
senticnet['carry_food'] = [0, -0.174, 0, 0.244, '#surprising', '#admirable', 0.139, 'obtain_food', 'serve_food', 'take_order', 'consumption', 'make_dinner']
senticnet['carry_goods'] = [-0.043, 0.066, 0, 0.149, '#interesting', '#admirable', 0.057, 'carry_laundry', 'carry_item', 'hold_grocery', 'hold_flower', 'carry_grocery']
senticnet['carry_grocery'] = [-0.04, 0.166, -0.108, 0.207, '#interesting', '#admirable', 0.075, 'carry_stuff', 'carry_book', 'carry_laundry', 'carry_clothes', 'carry_item']
senticnet['carry_gun'] = [-0.047, 0, -0.08, -0.123, '#scared', '#disgusting', -0.083, 'arm_oneself', 'find_victim', 'buy_weapon', 'bomb', 'buy_gun']
senticnet['carry_hand'] = [0, -0.951, 0, 0.744, '#surprising', '#admirable', 0.565, 'carry_item', 'carry_goods', 'carry_object', 'carry', 'upkeep']
senticnet['carry_heavy_load'] = [-0.146, 0, -0.076, 0, '#sad', '#scared', -0.074, 'read_science_book', 'look_up_word_in_dictionary', 'study_biology', 'finish_test', 'pull_wagon']
senticnet['carry_home'] = [-0.711, 0, -0.849, 0, '#sad', '#scared', -0.52, 'pay_dinner', 'go_debt', 'count_change', 'gain_interest', 'receive_change']
senticnet['carry_item'] = [-0.023, 0.107, -0.079, 0.287, '#interesting', '#admirable', 0.097, 'carry_belongings', 'carry_stuff', 'carry_object', 'carry', 'carry_clothes']
senticnet['carry_laundry'] = [-0.023, 0.139, -0.086, 0.24, '#interesting', '#admirable', 0.09, 'carry_item', 'carry_clothes', 'hold_stuff', 'carry_belongings', 'carry_goods']
senticnet['carry_liquid'] = [-0.035, 0.146, -0.087, 0.208, '#interesting', '#admirable', 0.077, 'sail_ocean', 'hold_flower', 'carry_book', 'bail_water', 'hold_stuff']
senticnet['carry_luggage'] = [0, 0, 0.814, -0.84, '#angry', '#disgusting', -0.551, 'pull_off_road', 'locate_place', 'discover_new_place', 'pack_luggage', 'drive_destination']
senticnet['carry_lunch'] = [0.063, -0.406, 0.026, 0.348, '#surprising', '#admirable', 0.264, 'super', 'better_good', 'most_good', 'wonderful', 'stupid']
senticnet['carry_money'] = [0, 0.147, 0, 0.099, '#interesting', '#admirable', 0.082, 'hold_money', 'put_money', 'store_money', 'keep_money', 'money_holder']
senticnet['carry_object'] = [0, 0.145, -0.094, 0.259, '#interesting', '#admirable', 0.103, 'carry_item', 'carry', 'carry_belongings', 'carry_book', 'carry_stuff']
senticnet['carry_off'] = [0.701, -0.563, 0, 0.921, '#joyful', '#admirable', 0.728, 'deliver_goods', 'succeed', 'win', 'bring_home_bacon', 'come_through']
senticnet['carry_on'] = [-0.291, -0.009, 0, -0.162, '#sad', '#disgusting', -0.148, 'act_up', 'move', 'fall_from_grace', 'misdemean', 'act']
senticnet['carry_out'] = [-0.025, 0.087, 0, 0.107, '#interesting', '#admirable', 0.056, 'do_it_now', 'act', 'perform', 'fulfill', 'execute']
senticnet['carry_paper'] = [0.025, 0.083, 0, 0.06, '#interesting', '#admirable', 0.056, 'organize_document', 'carry_document', 'keep_paper_together', 'bind_paper_together', 'store_document']
senticnet['carry_person'] = [0, 0, 0, 0.077, '#admirable', '#admirable', 0.026, 'transport_person', 'corner_well', 'travel_road', 'move_person', 'travel_place']
senticnet['carry_stuff'] = [-0.048, 0.133, -0.071, 0.218, '#interesting', '#admirable', 0.077, 'carry_book', 'carry_item', 'carry_clothes', 'carry_belongings', 'put_stuff']
senticnet['carry_suitcase'] = [0.914, 0.737, 0, 0, '#joyful', '#interesting', 0.55, 'enter_door', 'bicycle_store', 'turn_knob', 'take_responsibility', 'broomstick']
senticnet['carry_through'] = [-0.291, -0.009, 0, -0.162, '#sad', '#disgusting', -0.148, 'move', 'execute', 'fulfill', 'consummate', 'accomplish']
senticnet['carry_umbrella'] = [-0.023, -0.024, 0.076, -0.054, '#angry', '#disgusting', -0.043, 'wear_raincoat', 'wet', 'feel_cold', 'camp_out', 'splash_water']
senticnet['carry_vessel'] = [0, 0, 0.075, 0, '#angry', '#angry', -0.025, 'ship_container', 'covenant', 'big_boat', 'military_ship', 'water_vehicle']
senticnet['carry_wallet'] = [-0.062, 0, 0.018, 0, '#sad', '#angry', -0.027, 'out_money', 'decide_buy', 'look_price', 'use_atm', 'establish_credit']
senticnet['carry_water'] = [0.025, -0.06, -0.056, 0.161, '#surprising', '#admirable', 0.063, 'cloudy', 'up_high', 'weather_condition', 'dew', 'hazy']
senticnet['carry_weight'] = [0.933, -0.836, 0, 0.826, '#joyful', '#surprising', 0.865, 'influence', 'determine', 'shape', 'mold', 'regulate']
senticnet['carte_blanche'] = [0.742, -0.927, 0, 0.564, '#joyful', '#surprising', 0.744, 'imperium', 'lordship', 'power_of_appointment', 'potency', 'command']
senticnet['cartel'] = [0.776, -0.86, 0, 0.893, '#surprising', '#admirable', 0.843, 'trust', 'combine', 'corporate_trust', 'consortium', 'association']
senticnet['cartilage'] = [0, 0, 0.025, -0.099, '#angry', '#disgusting', -0.041, 'body_fluid', 'artery', 'skeletal_system', 'bodily_fluid', 'near_mouth']
senticnet['carton'] = [0.035, -0.015, 0.009, 0.063, '#joyful', '#admirable', 0.035, 'container', 'jar', 'contain', 'hold_cupcake', 'store_dish']
senticnet['carton_milk'] = [0.717, 0.804, 0, 0, '#joyful', '#interesting', 0.507, 'breakfast', 'box_cereal', 'calcium', 'drink', 'pasta']
senticnet['cartoon'] = [0, -0.753, 0, 0.778, '#surprising', '#admirable', 0.51, 'manga', 'anime', 'radio-control_helicopter', 'beat_off', 'see_someone_play_game']
senticnet['cartoon_character'] = [-0.073, 0, 0, -0.074, '#sad', '#disgusting', -0.049, 'paint', 'use_tool', 'mould', 'use_oil_paint', 'buy_paint']
senticnet['carve'] = [0.045, 0, 0, 0.051, '#joyful', '#admirable', 0.032, 'tree', 'forest', 'wood', 'find_forest', 'mass_production']
senticnet['carve_niche'] = [0, 0, 0, -0.092, '#disgusting', '#disgusting', -0.031, 'stand_queue', 'wait_line', 'stand_in_line', 'wait_turn', 'get_line']
senticnet['carving'] = [0.969, -0.686, 0, 0.756, '#joyful', '#admirable', 0.804, 'vermiculation', 'cinquefoil', 'glyptic_art', 'glyptography', 'scrimshaw']
senticnet['cascade_effect'] = [0, -0.807, 0, 0.73, '#surprising', '#admirable', 0.512, 'compel', 'cause_change', 'change_life', 'extinction', 'eco_system']
senticnet['case'] = [0.658, -0.749, 0, 0.782, '#surprising', '#admirable', 0.73, 'suit', 'cause', 'lawsuit', 'countersuit', 'causa']
senticnet['case_beer'] = [0.161, -0.146, 0.031, -0.104, '#joyful', '#surprising', 0.057, 'keg', 'reception', 'champagne', 'beer', 'wine']
senticnet['case_build'] = [-0.145, 0, -0.067, 0, '#sad', '#scared', -0.071, 'case_joint', 'case_house', 'make_compost', 'grow_beard', 'wear_mask']
senticnet['case_house'] = [-0.084, 0, 0, 0, '#sad', '#sad', -0.028, 'shave_head', 'dye_hair', 'get_haircut', 'consult_expert', 'cut_hair']
senticnet['case_joint'] = [-0.158, 0.074, -0.083, 0, '#sad', '#scared', -0.056, 'case_build', 'case_house', 'wear_mask', 'make_compost', 'grow_beard']
senticnet['cash'] = [-0.05, 0.14, 0.015, 0.082, '#interesting', '#admirable', 0.052, 'debit_card', 'cash_pay', 'need_earn_money', 'open_wallet', 'earn_wage']
senticnet['cash_bill'] = [0.766, 0.8, 0, 0, '#joyful', '#interesting', 0.522, 'dollar_bill', 'paper_bill', 'cash_coin', 'check', 'euro']
senticnet['cash_check'] = [0, 0.224, -0.047, 0.098, '#interesting', '#admirable', 0.092, 'purchase', 'cash', 'establish_credit', 'bankruptcy', 'incur_debt']
senticnet['cash_coin'] = [0.898, 0.748, 0, 0, '#joyful', '#interesting', 0.549, 'cash_bill', 'paper_bill', 'debit_card', 'dollar_bill', 'piece_of_change']
senticnet['cash_drawer'] = [0.021, 0.139, 0, 0, '#joyful', '#interesting', 0.053, 'bank', 'wallet', 'safe', 'bank_vault', 'coffer']
senticnet['cash_in_hand'] = [0.534, -0.868, 0, 0.736, '#surprising', '#admirable', 0.713, 'funds', 'finances', 'monetary_resource', 'escrow_funds', 'pecuniary_resource']
senticnet['cash_pay'] = [0.891, 0.945, 0, 0, '#joyful', '#interesting', 0.612, 'give_money', 'work_for_money', 'pay_money', 'extra_money', 'money_earn']
senticnet['cash_register'] = [0.05, 0.139, 0.037, 0, '#joyful', '#interesting', 0.051, 'bank_machine', 'piggy_bank', 'billfold', 'spare_change', 'bank_account']
senticnet['cashier'] = [0.038, 0.155, 0, 0.074, '#interesting', '#admirable', 0.089, 'merchandise', 'trolley', 'goods', 'shopper', 'grocery']
senticnet['cashless'] = [-0.052, 0.17, 0, 0.091, '#interesting', '#admirable', 0.07, 'postpone_payment', 'credit_card', 'buy_goods_service', 'pay_goods', 'pay_item']
senticnet['casket'] = [-0.952, 0, -0.92, 0, '#sad', '#scared', -0.624, 'morgue', 'coffin', 'grave', 'corpse', 'dead_person']
senticnet['casque'] = [-0.595, 0, 0.887, -0.715, '#angry', '#disgusting', -0.732, 'armet', 'basinet', 'helmet', 'heaume', 'morion']
senticnet['casserole'] = [0.041, -0.045, 0, 0, '#joyful', '#surprising', 0.029, 'meatloaf', 'salad', 'delicious_meal', 'garden_salad', 'apple_pie']
senticnet['cassette'] = [0, -0.974, 0, 0.813, '#surprising', '#admirable', 0.596, 'compact_disc', 'music_storage', 'store_music', 'cd-rom', 'seventy']
senticnet['cassia_bark'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'cork', 'bark', 'canella', 'canella_bark', 'white_cinnamon']
senticnet['cassock'] = [0.849, -0.503, 0, 0.845, '#joyful', '#admirable', 0.732, 'robe', 'gown', 'veil', 'vest', 'vestment']
senticnet['cast'] = [0, 0, 0, 0.068, '#admirable', '#admirable', 0.023, 'dark_corner', 'child_game', 'play_person', 'role_play', 'part_of_play']
senticnet['cast_down'] = [-0.81, 0.239, -0.443, -0.064, '#sad', '#scared', -0.359, 'feel_down', 'deject', 'get_down', 'dispirit', 'demoralize']
senticnet['cast_iron'] = [0.706, -0.941, 0, 0.622, '#joyful', '#surprising', 0.756, 'alloy_iron', 'alloy_cast_iron', 'pot_metal', 'iron', 'atomic_number_26']
senticnet['cast_shadow'] = [-0.08, 0, 0, 0, '#sad', '#sad', -0.027, 'blow_horn', 'weather_storm', 'cross_bridge', 'jump_trampoline', 'box_ear']
senticnet['caste'] = [0.025, 0.176, -0.065, 0.114, '#interesting', '#admirable', 0.083, 'tribe', 'hierarchy', 'council', 'social_status', 'social_rank']
senticnet['casteless'] = [-0.828, 0, 0.85, -0.709, '#sad', '#angry', -0.796, 'outcaste', 'unwanted', 'unclaimed', 'unwelcome', 'undesired']
senticnet['castigate'] = [-0.816, 0, 0.967, -0.961, '#angry', '#disgusting', -0.915, 'call_on_carpet', 'take_to_task', 'chide', 'berate', 'bawl_out']
senticnet['castigation'] = [-0.898, 0, 0.974, -0.984, '#angry', '#disgusting', -0.952, 'reprimand', 'rebuke', 'reproof', 'reproval', 'reprehension']
senticnet['castle'] = [0.021, 0.119, 0, 0.129, '#interesting', '#admirable', 0.09, 'manor', 'palace', 'medieval', 'tower', 'chess_game']
senticnet['castor'] = [-0.027, -0.051, -0.058, -0.055, '#scared', '#disgusting', -0.03, 'motor_oil', 'make_toy', 'engine', 'emission', 'bristle']
senticnet['castrate'] = [-0.785, 0, 0.91, -0.917, '#angry', '#disgusting', -0.871, 'desex', 'neuter', 'alter', 'emasculate', 'spay']
senticnet['castrated'] = [0.945, -0.861, 0, 0.802, '#joyful', '#surprising', 0.869, 'cut', 'altered', 'neutered', 'emasculated', 'gelded']
senticnet['casual'] = [-0.155, 0, 0.028, 0, '#sad', '#angry', -0.061, 'use_leg', 'walk_quickly', 'gait', 'take_step', 'strut']
senticnet['casual_shoes'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'shoe', 'moccasin', 'flip_flop', 'footwear', 'shoe_type']
senticnet['casualty'] = [-0.16, 0, -0.184, -0.239, '#scared', '#disgusting', -0.194, 'attack_enemy', 'cause_death', 'die', 'lose_war', 'imprisonment']
senticnet['casuistry'] = [-0.69, 0, 0.697, -0.609, '#sad', '#angry', -0.665, 'argumentation', 'argument', 'logical_argument', 'line_of_reasoning', 'line']
senticnet['casus_belli'] = [-0.615, 0, 0.606, -0.539, '#sad', '#angry', -0.587, 'issue', 'start', 'beginning', 'emergence', 'egress']
senticnet['cat'] = [0.028, 0, 0.013, 0.061, '#joyful', '#admirable', 0.025, 'cute_big_cat', 'domestibig_cate_animal', 'big_cat', 'big_animal', 'big']
senticnet['cat_fancier'] = [0.534, -0.868, 0, 0.736, '#surprising', '#admirable', 0.713, 'enthusiast', 'animal_fancier', 'horseman', 'horse_fancier', 'fancier']
senticnet['cat_food'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'attract_dog', 'food', 'dog', 'dog_food', 'pet_food']
senticnet['cat_hair'] = [0, -0.084, 0.125, -0.11, '#angry', '#disgusting', -0.05, 'sleep_cat', 'cookie_crumb', 'dust_mite', 'coffee_table', 'dirty_sock']
senticnet['cat_purr'] = [0.833, 0.89, 0, 0, '#joyful', '#interesting', 0.574, 'express_love', 'receive_thank', 'get_present', 'make_happy', 'celebrate_special_occasion']
senticnet['cat_thyme'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'subshrub', 'suffrutex', 'wood_sage', 'wall_germander', 'germander']
senticnet['cataclysm'] = [-0.968, 0, 0.501, -0.596, '#sad', '#disgusting', -0.688, 'calamity', 'catastrophe', 'tragedy', 'disaster', 'apocalypse']
senticnet['cataleptic'] = [-0.606, 0, 0.892, -0.921, '#angry', '#disgusting', -0.806, 'schizophrenic', 'psycho', 'paranoid', 'paranoiac', 'sick_person']
senticnet['catalyst'] = [0.754, 0.837, 0, 0, '#joyful', '#interesting', 0.53, 'consequence', 'cause', 'bad_action', 'problem', 'political_statement']
senticnet['catastrophe'] = [-0.158, -0.01, -0.073, -0.215, '#sad', '#disgusting', -0.145, 'disaster', 'broken_finger', 'censorship', 'destruction', 'schizophrenia']
senticnet['catcall'] = [-0.698, 0, 0.792, -0.984, '#angry', '#disgusting', -0.825, 'outcry', 'call', 'cry', 'yell', 'shout']
senticnet['catch'] = [0.378, 0.388, -0.219, 0.203, '#joyful', '#interesting', 0.25, 'thrill', 'encourage', 'console', 'exhilaration', 'strike']
senticnet['catch_ball'] = [0.885, 0, 0, 0, '#joyful', '#joyful', 0.295, 'ball_game', 'strike_out', 'throw_ball', 'field_ball', 'toss_ball']
senticnet['catch_baseball'] = [0, -0.05, 0.066, -0.134, '#angry', '#disgusting', -0.05, 'strike_out', 'throw_ball', 'hit_ball', 'hit_ball_with_bat', 'run_first_base']
senticnet['catch_bass'] = [0, 0, 0.816, -0.934, '#angry', '#disgusting', -0.583, 'catch_catfish', 'experience_joy', 'fish_trout', 'fish_compliment', 'catch_butterfly']
senticnet['catch_breath'] = [0.898, 0.88, 0, 0, '#joyful', '#interesting', 0.593, 'exercise', 'breathing', 'relax', 'rest_up', 'regain_energy']
senticnet['catch_bus'] = [-0.108, 0, 0, -0.067, '#sad', '#disgusting', -0.058, 'board_boat', 'ride_bus', 'travel_by_airplane', 'near_destination', 'push_limit']
senticnet['catch_butterfly'] = [-0.068, 0, -0.051, 0, '#sad', '#scared', -0.04, 'fish_lake', 'fish_trout', 'fish_compliment', 'fish_stream', 'catch_fly']
senticnet['catch_catfish'] = [0, 0, 0.947, -0.999, '#angry', '#disgusting', -0.649, 'catch_bass', 'catch_shark', 'catch_fish', 'catch_butterfly', 'fish_lake']
senticnet['catch_cold'] = [-0.1, 0, -0.072, -0.096, '#sad', '#disgusting', -0.089, 'trade_stock', 'become_depressed', 'absorb_moisture', 'catch_fire', 'part_of_hair']
senticnet['catch_fire'] = [0, 0, -0.066, -0.059, '#scared', '#disgusting', -0.042, 'light_candle', 'light_cigar', 'light_pipe', 'age_prematurely', 'light_cigarette']
senticnet['catch_fish'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'fishing_rod', 'fishing', 'patience', 'fish_lake', 'bait']
senticnet['catch_fly'] = [0.042, 0.088, 0, 0, '#joyful', '#interesting', 0.043, 'jump_over_obstacle', 'hide_shell', 'save_someone_from_drowning', 'swim', 'attempt_fly']
senticnet['catch_fly_ball'] = [0, 0, 0.916, -0.783, '#angry', '#disgusting', -0.566, 'catch_baseball', 'hit_home_run', 'lose_game', 'eat_hot_dog', 'skate_ice']
senticnet['catch_football'] = [-0.023, 0.117, -0.082, 0.18, '#interesting', '#admirable', 0.064, 'go_ahead', 'football_play', 'flee', 'throw_football', 'option']
senticnet['catch_mouse'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'kill_mouse', 'trap', 'pest', 'trap_mouse', 'bait']
senticnet['catch_mumps'] = [0, 0, -0.106, 0, '#scared', '#scared', -0.035, 'become_ill', 'get_sick', 'disease', 'bad_health', 'sickness']
senticnet['catch_out'] = [-0.779, 0, 0.816, -0.85, '#angry', '#disgusting', -0.815, 'find', 'detect', 'observe', 'discover', 'notice']
senticnet['catch_rain'] = [0.072, 0.071, 0, 0.053, '#joyful', '#interesting', 0.065, 'cold', 'coldness', 'icy', 'cold_outside', 'ice_crystal']
senticnet['catch_shark'] = [0, 0, 0.724, -0.737, '#angry', '#disgusting', -0.487, 'catch_catfish', 'catch_bass', 'catch_fish', 'talk_companion', 'splash']
senticnet['catch_some_z'] = [-0.621, 0, 0.944, -0.729, '#angry', '#disgusting', -0.765, 'catnap', 'sleep_late', 'sleep_in', 'rest', 'practice_bundling']
senticnet['catch_train'] = [0.194, 0.118, 0, 0.216, '#joyful', '#admirable', 0.176, 'travel', 'transportation', 'subway', 'public_transport', 'take_vacation']
senticnet['catch_trout'] = [0.094, -0.036, 0.028, 0, '#joyful', '#surprising', 0.034, 'fishing_rod', 'fishing', 'patience', 'food', 'bait']
senticnet['catch_up'] = [0.094, -0.036, 0.028, 0, '#joyful', '#surprising', 0.034, 'reach', 'achieve', 'attain', 'get', 'get_to']
senticnet['catch_up_news'] = [0.823, 0.812, 0, 0, '#joyful', '#interesting', 0.545, 'distraction', 'learn_new_skill', 'go_symphony', 'negative_reaction', 'enjoy_show']
senticnet['catch_wind'] = [0, 0, 0.735, -0.869, '#angry', '#disgusting', -0.535, 'water_vehicle', 'big_boat', 'boat_type', 'small_boat', 'large_boat']
senticnet['catching'] = [0.774, -0.634, 0, 0.567, '#joyful', '#surprising', 0.658, 'discovery', 'breakthrough', 'spying', 'determination', 'tracing']
senticnet['catechesis'] = [0.548, -0.982, 0, 0.769, '#surprising', '#admirable', 0.766, 'education', 'teaching_reading', 'spoonfeeding', 'lecture', 'teaching']
senticnet['catechism'] = [-0.587, 0, 0.701, -0.979, '#angry', '#disgusting', -0.756, 'inquisition', 'interview', 'interrogatory', 'deposition', 'third_degree']
senticnet['catecholamine'] = [0.672, -0.552, 0, 0.992, '#joyful', '#admirable', 0.739, 'pressor', 'hormone', 'endocrine', 'internal_secretion', 'adrenalin']
senticnet['categoric'] = [-0.669, 0, 0.721, -0.539, '#sad', '#angry', -0.643, 'unlimited', 'outright', 'unconditional', 'unqualified', 'unqualifiedal']
senticnet['categorical'] = [-0.669, 0, 0.721, -0.539, '#sad', '#angry', -0.643, 'unlimited', 'outright', 'unconditional', 'categoric', 'unqualified']
senticnet['category'] = [0, 0.108, 0, 0.113, '#interesting', '#admirable', 0.074, 'taken', 'visual', 'green_red', 'yellow_green', 'green_orange']
senticnet['cater'] = [0.877, -0.766, 0, 0.996, '#joyful', '#admirable', 0.88, 'meet', 'accommodate', 'satisfy', 'help', 'gratify']
senticnet['caterpillar'] = [0, 0, 0.947, -0.762, '#angry', '#disgusting', -0.57, 'moth', 'mole_cricket', 'gypsy_moth', 'japanese_beetle', 'cucumber_beetle']
senticnet['catharsis'] = [0, 0, 0.813, -0.963, '#angry', '#disgusting', -0.592, 'entertain_oneself', 'see_actor', 'wish_entertain', 'enjoyment', 'pastime']
senticnet['cathartic'] = [0.722, -0.606, 0, 0.596, '#joyful', '#surprising', 0.641, 'medicament', 'medicinal_drug', 'medication', 'aloe', 'bitter_aloe']
senticnet['cathedral'] = [0.971, 0, 0, 0.752, '#joyful', '#admirable', 0.574, 'church', 'temple', 'chapel', 'catholic_church', 'confession']
senticnet['catholic'] = [0, 0.25, 0, 0.283, '#interesting', '#admirable', 0.178, 'christianity', 'catholic_church', 'holy_place', 'judaism', 'worship_place']
senticnet['catholic_church'] = [0, 0.221, 0.037, 0.227, '#interesting', '#admirable', 0.137, 'christianity', 'church', 'chapel', 'church_part', 'cathedral']
senticnet['catholicon'] = [-0.552, 0, 0.5, -0.554, '#sad', '#disgusting', -0.535, 'remedy', 'cure', 'elixir', 'therapeutic', 'curative']
senticnet['catling'] = [0.932, -0.521, 0, 0.534, '#joyful', '#admirable', 0.662, 'lancet', 'surgical_knife', 'lance', 'scalpel', 'knife']
senticnet['catnap'] = [-0.621, 0, 0.944, -0.729, '#angry', '#disgusting', -0.765, 'catch_some_z', 'sleep_late', 'sleep_in', 'rest', 'practice_bundling']
senticnet['cattail'] = [0.656, -0.632, 0, 0.844, '#joyful', '#admirable', 0.711, 'bullrush', 'bulrush', 'nailrod', 'reed_mace', 'reedmace']
senticnet['cattiness'] = [-0.945, 0, 0.897, -0.932, '#sad', '#disgusting', -0.925, 'malevolency', 'bitchiness', 'spitefulness', 'cruelness', 'evil']
senticnet['cattish'] = [-0.887, 0, 0.864, -0.725, '#sad', '#angry', -0.825, 'vixenish', 'venomous', 'bitchy', 'catty', 'malicious']
senticnet['catty'] = [-0.887, 0, 0.864, -0.725, '#sad', '#angry', -0.825, 'vixenish', 'venomous', 'bitchy', 'malicious', 'cattish']
senticnet['catwalk'] = [0.096, -0.017, 0, 0, '#joyful', '#surprising', 0.038, 'chain', 'rail', 'platform_rail', 'column', 'token_turnstile']
senticnet['caucasian'] = [-0.934, 0, 0.77, -0.792, '#sad', '#disgusting', -0.832, 'whitey', 'honky', 'honkey', 'honkie', 'mortal']
senticnet['cauliflower'] = [0, 0.073, -0.093, -0.087, '#scared', '#disgusting', -0.036, 'cotton_boll', 'asbestos', 'corn', 'opium', 'rice']
senticnet['causa'] = [0.658, -0.749, 0, 0.782, '#surprising', '#admirable', 0.73, 'suit', 'cause', 'lawsuit', 'case', 'countersuit']
senticnet['causation'] = [-0.997, 0, 0.651, -0.513, '#sad', '#angry', -0.72, 'sending', 'compulsion', 'influence', 'inducement', 'trigger']
senticnet['causative'] = [0.59, -0.599, 0, 0.527, '#joyful', '#surprising', 0.572, 'responsible', 'inducive', 'activating', 'tributary', 'motivative']
senticnet['cause'] = [0, -0.935, 0, 0.98, '#surprising', '#admirable', 0.638, 'effect', 'consequence', 'impact', 'outcome', 'conclusion']
senticnet['cause_accident'] = [-0.121, 0, -0.066, -0.033, '#sad', '#scared', -0.073, 'follow_person', 'stay_in_house', 'mark_territory', 'sense_fear', 'guide_blind']
senticnet['cause_allergy'] = [-0.943, 0, 0.891, -0.939, '#sad', '#disgusting', -0.924, 'peanut', 'seafood', 'wrong_food', 'sick', 'allergy_symptom']
senticnet['cause_bleed'] = [-0.137, -0.025, -0.059, -0.154, '#sad', '#disgusting', -0.108, 'open_wind', 'laceration', 'gash', 'injury', 'painful_injury']
senticnet['cause_bleeding'] = [-0.917, 0, 0.513, -0.932, '#sad', '#disgusting', -0.787, 'beat_to_bleeding', 'cause_strong_pain', 'cut_finger', 'kill_person', 'beat_person']
senticnet['cause_cancer'] = [-0.137, -0.025, -0.059, -0.154, '#sad', '#disgusting', -0.108, 'cancer', 'smoke', 'smoke_cigarette', 'smoke_cigar', 'eat_unhealthy_food']
senticnet['cause_change'] = [0, -0.832, 0, 0.872, '#surprising', '#admirable', 0.568, 'compel', 'cascade_effect', 'change_life', 'permission', 'take']
senticnet['cause_cold'] = [0, 0, 0, -0.966, '#disgusting', '#disgusting', -0.322, 'reproduce', 'start_family', 'procreate', 'copulate', 'give_birth_child']
senticnet['cause_death'] = [-0.17, 0, -0.184, -0.188, '#scared', '#disgusting', -0.181, 'take_life', 'lose_war', 'attack_enemy', 'blown_up', 'enslave_person']
senticnet['cause_dehydration'] = [-0.826, 0, 0, -0.821, '#sad', '#disgusting', -0.549, 'feel_faint', 'lack_of_water', 'much_exercise', 'weak', 'feel_lousy']
senticnet['cause_effect'] = [-0.788, 0, -0.822, 0, '#sad', '#scared', -0.537, 'careless', 'scare_dog', 'startle', 'accident', 'embarrassment']
senticnet['cause_fire'] = [0, 0, 0.96, -0.887, '#angry', '#disgusting', -0.616, 'destroy_home', 'danger', 'kill_life', 'destroy_property', 'destroy_city']
senticnet['cause_headache'] = [0, 0.099, -0.052, 0.113, '#interesting', '#admirable', 0.053, 'make_throw_up', 'blind', 'big_rat', 'grizzly', 'hare']
senticnet['cause_heart_disease'] = [0, 0, 0.832, -0.808, '#angry', '#disgusting', -0.547, 'kill_person', 'fats', 'unhealthy_food', 'kill', 'blocked_artery']
senticnet['cause_illness'] = [-0.129, -0.029, -0.09, -0.14, '#sad', '#disgusting', -0.11, 'get_rid_of_enemy', 'hurt_others', 'end_live', 'destroy_live', 'murder']
senticnet['cause_injury'] = [0, 0, 0.783, -0.86, '#angry', '#disgusting', -0.548, 'stab', 'maim', 'injure', 'damage', 'destroy']
senticnet['cause_mental_illness'] = [-0.029, 0, -0.063, 0, '#sad', '#scared', -0.031, 'age_prematurely', 'catch_fire', 'light_pipe', 'light_cigar', 'smoke_cigarette']
senticnet['cause_pain'] = [-0.216, -0.165, -0.143, -0.209, '#sad', '#disgusting', -0.134, 'physical_pain', 'poke_pin', 'suffer', 'broken_finger', 'black_eye']
senticnet['cause_problem'] = [-0.347, 0.102, -0.362, 0, '#sad', '#scared', -0.202, 'trouble', 'caution', 'unsafe', 'reprimand', 'big_monster']
senticnet['cause_sickness'] = [-0.174, 0, -0.102, -0.127, '#sad', '#disgusting', -0.134, 'infection', 'cause_illness', 'end_life', 'kill_self', 'threaten']
senticnet['cause_side_effect'] = [-0.615, 0, 0.606, -0.539, '#sad', '#angry', -0.587, 'birth_control_pill', 'condom', 'contraceptive_device', 'contraceptive_pills', 'prevent_pregnancy']
senticnet['cause_someone_embarrassment'] = [-0.928, 0, 0.016, -0.912, '#sad', '#disgusting', -0.619, 'sadness', 'sorrow', 'cry', 'regret', 'grief']
senticnet['cause_someone_to_die'] = [-0.239, -0.012, -0.158, -0.261, '#sad', '#disgusting', -0.215, 'feel_pain', 'poor_health', 'experience_pain', 'feel_anger', 'arrest_police']
senticnet['cause_stress'] = [-0.676, 0.233, -0.463, 0.222, '#sad', '#scared', -0.228, 'confuse', 'feel_sorry', 'guilt', 'say_sorry', 'regret']
senticnet['cause_strong_pain'] = [-0.917, 0, 0.513, -0.932, '#sad', '#disgusting', -0.787, 'cause_someone_embarrassment', 'cause_bleeding', 'strong_pain', 'kill_person', 'beat_person']
senticnet['cause_suffer'] = [0, 0, 0.754, -0.787, '#angry', '#disgusting', -0.514, 'lose_team', 'leave_out', 'loathing', 'disrespect', 'lyme_disease']
senticnet['cause_to_perceive'] = [0.84, -0.836, 0, 0.528, '#joyful', '#surprising', 0.735, 'sound', 'smart', 'sensation', 'scent', 'ache']
senticnet['causing'] = [-0.944, 0, 0.709, -0.979, '#sad', '#disgusting', -0.877, 'sending', 'compulsion', 'influence', 'inducement', 'trigger']
senticnet['caution'] = [-0.325, 0.133, -0.389, 0, '#sad', '#scared', -0.194, 'big_monster', 'unsafe', 'phobia', 'mock', 'feel_scared']
senticnet['cavalier'] = [-0.91, 0, 0.521, -0.811, '#sad', '#disgusting', -0.747, 'bullying', 'peremptory', 'blustery', 'roughshod', 'domineering']
senticnet['cave'] = [-0.025, 0, 0, -0.052, '#sad', '#disgusting', -0.026, 'tunnel', 'dark_place', 'ski_resort', 'top_tree', 'compost_pile']
senticnet['caveat_emptor'] = [0.841, -0.657, 0, 0.645, '#joyful', '#surprising', 0.714, 'moral_principle', 'rule', 'precept', 'higher_law', 'hypothetical_imperative']
senticnet['cavern'] = [-0.951, 0, -0.751, 0, '#sad', '#scared', -0.567, 'tunnel', 'international_space_station', 'stick_wall', 'car_race', 'auction']
senticnet['cavernous'] = [-0.986, 0, 0.702, -0.704, '#sad', '#disgusting', -0.797, 'expandable', 'expandible', 'expansible', 'erectile', 'expansive']
senticnet['caviar'] = [0.061, 0.07, -0.056, 0.073, '#interesting', '#admirable', 0.049, 'italian_food', 'eat_food', 'fine_dining', 'expensive_food', 'lobster']
senticnet['caviare'] = [-0.527, 0, 0.748, -0.926, '#angry', '#disgusting', -0.734, 'coral', 'caviar', 'hard_roe', 'shad_roe', 'seafood']
senticnet['cavity'] = [-0.053, 0.068, -0.105, -0.084, '#scared', '#disgusting', -0.058, 'tooth_decay', 'body_ache', 'symptom', 'pierce', 'tooth']
senticnet['cavum'] = [0.718, -0.882, 0, 0.83, '#surprising', '#admirable', 0.81, 'throat', 'pharynx', 'cavity', 'bodily_cavity', 'tubular_cavity']
senticnet['cctv'] = [-0.032, -0.012, -0.11, -0.031, '#sad', '#scared', -0.054, 'movie_theater', 'theater', 'cinema', 'movie', 'drive-in_movie']
senticnet['cd-rom'] = [-0.639, 0, 0.897, -0.915, '#angry', '#disgusting', -0.817, 'candlepower_unit', 'international_candle', 'candle', 'candela', 'standard_candle']
senticnet['cease'] = [-0.914, 0, 0.576, -0.956, '#sad', '#disgusting', -0.815, 'stop', 'halt', 'lock_in', 'lock', 'block']
senticnet['cease_fire'] = [0.299, 0.299, -0.157, 0.233, '#joyful', '#interesting', 0.225, 'desirable', 'stay_calm', 'no_war', 'stillness', 'get_along']
senticnet['cedar'] = [0.048, -0.097, 0, 0.086, '#surprising', '#admirable', 0.077, 'elm', 'tree', 'willow', 'pine', 'timber']
senticnet['cedar_nut'] = [0.534, -0.868, 0, 0.736, '#surprising', '#admirable', 0.713, 'palm_nut', 'palm_kernel', 'edible_nut', 'cembra_nut', 'nut']
senticnet['ceiling'] = [0, 0.128, -0.122, 0.183, '#interesting', '#admirable', 0.063, 'support_roof', 'interior', 'furnish', 'window_door', 'frame']
senticnet['ceiling_fan'] = [0.063, 0, 0, 0.05, '#joyful', '#admirable', 0.038, 'indoor', 'ventilation', 'breeze', 'cool_air', 'fan']
senticnet['celebrate'] = [0.719, 0, 0, 0, '#joyful', '#joyful', 0.24, 'go_party', 'enjoy_company_friend', 'friend_over', 'drink_a_lot_of_beer', 'entertain_person']
senticnet['celebrate_anniversary'] = [0.859, 0, 0, 0, '#joyful', '#joyful', 0.286, 'win_lottery', 'say_thank_you', 'birthday', 'christmas', 'make_happy']
senticnet['celebrate_birthday'] = [0.812, 0, 0, 0, '#joyful', '#joyful', 0.271, 'child_birthday', 'special_occasion', 'celebrate_special_occasion', 'special_event', 'show_care']
senticnet['celebrate_event'] = [0.799, 0, 0, 0, '#joyful', '#joyful', 0.266, 'celebrate_birthday', 'special_occasion', 'celebrate_holiday', 'child_birthday', 'show_care']
senticnet['celebrate_holiday'] = [0.172, -0.204, 0.015, -0.148, '#joyful', '#surprising', 0.071, 'celebrate_occasion', 'celebrate_special_occasion', 'amuse_oneself', 'hospitable', 'good_time']
senticnet['celebrate_occasion'] = [0.7, 0, 0, 0, '#joyful', '#joyful', 0.233, 'celebrate_holiday', 'celebrate_special_occasion', 'see_friend', 'celebrate_wedding', 'good_time']
senticnet['celebrate_special_occasion'] = [0.78, 0.739, 0, 0.798, '#joyful', '#admirable', 0.772, 'friend_wedding', 'wedding', 'cake', 'celebrate_wedding', 'wedding_cake']
senticnet['celebrate_special_occcasion'] = [0.78, 0.739, 0, 0.798, '#joyful', '#admirable', 0.772, 'friend_wedding', 'wedding', 'cake', 'celebrate_wedding', 'wedding_cake']
senticnet['celebrate_specific_group_dead'] = [0, 0, 0, -0.966, '#disgusting', '#disgusting', -0.322, 'raise_flag', 'commit_genocide', 'kill_oneself', 'kill', 'give_blood']
senticnet['celebrate_wed'] = [0.833, 0, 0, 0.727, '#joyful', '#admirable', 0.52, 'celebrate_special_occasion', 'see_friend', 'celebrate_occasion', 'celebrate_holiday', 'gather_friend']
senticnet['celebrate_wedding'] = [0.7, 0, 0, 0, '#joyful', '#joyful', 0.233, 'celebrate_holiday', 'celebrate_special_occasion', 'see_friend', 'celebrate_occasion', 'good_time']
senticnet['celebrated'] = [0, 0.939, 0, 0.75, '#interesting', '#admirable', 0.563, 'observe', 'keep', 'famed', 'notable', 'renowned']
senticnet['celebration'] = [0.816, 0, 0, 0, '#joyful', '#joyful', 0.272, 'special_occasion', 'special_event', 'special_time', 'party_time', 'special_day']
senticnet['celebrity'] = [0, 0, 0, 0.993, '#admirable', '#admirable', 0.331, 'senator', 'ceo', 'egalitarian', 'champion', 'vip']
senticnet['celerity'] = [0.548, -0.622, 0, 0.695, '#surprising', '#admirable', 0.622, 'quickness', 'instancy', 'rapidity', 'rapidness', 'speediness']
senticnet['celery'] = [-0.05, -0.039, 0.023, -0.095, '#sad', '#disgusting', -0.043, 'moldy_food', 'spam', 'paper_product', 'orange_juice', 'after_lunch']
senticnet['celestial_body'] = [0, -0.735, 0, 0.977, '#surprising', '#admirable', 0.571, 'heavenly_body', 'around_earth', 'source_light', 'sol', 'celestial_object']
senticnet['celestial_object'] = [0, -0.898, 0, 0.863, '#surprising', '#admirable', 0.587, 'heavenly_body', 'around_earth', 'source_light', 'sol', 'celestial_body']
senticnet['celibate'] = [0.839, -0.704, 0, 0.93, '#joyful', '#admirable', 0.824, 'virtuous', 'chaste', 'pure', 'continent', 'virginal']
senticnet['cell'] = [0.026, 0.069, 0, 0, '#joyful', '#interesting', 0.032, 'atom', 'fuse', 'nucleus', 'human_body', 'rash']
senticnet['cellphone'] = [0.035, -0.01, 0.027, 0.085, '#joyful', '#admirable', 0.034, 'telephone', 'find_phone_number', 'telephone_room', 'phone', 'use_telephone']
senticnet['cellular_phone'] = [0, -0.122, 0.011, 0.089, '#surprising', '#admirable', 0.067, 'cordless', 'telephone', 'wireless', 'connect', 'message']
senticnet['cellulose'] = [-0.039, -0.031, 0.026, -0.068, '#sad', '#disgusting', -0.034, 'cut_tree', 'cut_wood', 'cut_lumber', 'timber', 'chop_tree']
senticnet['cellulose_acetate'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'cellulose_nitrate', 'nitrocellulose', 'guncotton', 'nitrocotton', 'cellulose_ester']
senticnet['cellulose_ester'] = [-0.608, 0, 0.546, -0.948, '#sad', '#disgusting', -0.701, 'cellulose_nitrate', 'nitrocellulose', 'guncotton', 'nitrocotton', 'cellulose_acetate']
senticnet['cellulose_nitrate'] = [-0.886, 0, 0.87, -0.761, '#sad', '#angry', -0.839, 'cellulose_ester', 'pyroxylin', 'pyroxyline', 'pyrocellulose', 'nitrate']
senticnet['celsius'] = [0, 0.155, 0, 0, '#interesting', '#interesting', 0.052, 'diploma', 'certificate', 'qualification', 'temperature_measure', 'temperature_measurement']
senticnet['cembra_nut'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'palm_nut', 'palm_kernel', 'edible_nut', 'nut', 'cedar_nut']
senticnet['cement'] = [0, 0.127, -0.046, 0.194, '#interesting', '#admirable', 0.092, 'concrete', 'tar', 'pavement', 'big_city_life', 'popular_building_material']
senticnet['cemetery'] = [0, 0.702, 0, 0.864, '#interesting', '#admirable', 0.522, 'graveyard', 'funeral', 'funeral_home', 'tombstone', 'die']
senticnet['cenogenesis'] = [-0.902, 0, 0.774, -0.627, '#sad', '#angry', -0.768, 'growth', 'growing', 'maturation', 'development', 'ontogeny']
senticnet['censorship'] = [0, 0, 0.977, -0.798, '#angry', '#disgusting', -0.592, 'bigot', 'broken_finger', 'schizophrenia', 'hurt_other_person', 'black_eye']
senticnet['census'] = [0.039, 0, 0, 0.053, '#joyful', '#admirable', 0.031, 'pledge_allegiance', 'democratic_country', 'free_country', 'unite', 'big_country']
senticnet['cent'] = [0.799, 0.905, 0, 0, '#joyful', '#interesting', 0.568, 'franc', 'dime', 'dollar', 'shilling', 'banknote']
senticnet['centaury'] = [-0.902, 0, 0.726, -0.534, '#sad', '#angry', -0.721, 'broad_leaved_centaury', 'rosita', 'lesser_centaury', 'tufted_centaury', 'seaside_centaury']
senticnet['centenarian'] = [0.556, -0.641, 0, 0.64, '#surprising', '#admirable', 0.612, 'golden_ager', 'nonagenarian', 'octogenarian', 'septuagenarian', 'sexagenarian']
senticnet['centennial'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'yearly_celebration', 'special_day', 'age', 'occasion', 'annual']
senticnet['center'] = [0.043, 0.14, 0.01, 0.245, '#interesting', '#admirable', 0.139, 'in_between', 'middle', 'in_middle', 'downtown', 'placement']
senticnet['center_attention'] = [0.944, 0.894, 0, 0, '#joyful', '#interesting', 0.613, 'orgy', 'pia_lot_of_seat', 'seat_chair', 'loose_end', 'death_row']
senticnet['center_passage'] = [0.076, 0.094, -0.062, 0, '#joyful', '#interesting', 0.036, 'center', 'control_room', 'graffiti', 'passage', 'ticket_box']
senticnet['centerfold'] = [-0.791, 0, -0.868, 0, '#sad', '#scared', -0.553, 'fairy', 'genus', 'honey_bee', 'infant', 'dove']
senticnet['centering'] = [0.633, -0.968, 0, 0.612, '#joyful', '#surprising', 0.738, 'particularism', 'absorption', 'concentration', 'engrossment', 'immersion']
senticnet['centimetre'] = [0, 0.082, 0.076, 0.111, '#interesting', '#admirable', 0.039, 'measurement_unit', 'measure', 'imperial_measurement', 'length', 'measurement']
senticnet['central'] = [0.035, 0.065, 0.025, 0.127, '#interesting', '#admirable', 0.067, 'vicinity', 'asset', 'center', 'busy_street', 'main']
senticnet['central_passage'] = [0, 0, 0, 0.128, '#admirable', '#admirable', 0.043, 'vestibule', 'door', 'doorway', 'gate', 'door_handle']
senticnet['century'] = [0.978, -0.601, 0, 0.895, '#joyful', '#admirable', 0.825, 'period', 'quattrocento', 'twentieth_century', 'time_period', 'period_of_time']
senticnet['ceo'] = [0.046, 0.116, -0.058, 0.076, '#interesting', '#admirable', 0.06, 'head_guy', 'boss', 'officer', 'leader', 'supervisor']
senticnet['cephalaspid'] = [-0.542, 0, 0.992, -0.872, '#angry', '#disgusting', -0.802, 'hag', 'osteostracan', 'jawless_fish', 'ostracoderm', 'heterostracan']
senticnet['cephalitis'] = [-0.552, 0, 0.757, -0.528, '#sad', '#angry', -0.612, 'rubor', 'redness', 'sleeping_sickness', 'sleepy_sickness', 'epidemic_encephalitis']
senticnet['cephalopod'] = [-0.523, 0, 0.728, -0.926, '#angry', '#disgusting', -0.726, 'nautilus', 'octopod', 'octopod_mollusk', 'paper_nautilus', 'octopus']
senticnet['cephalopod_mollusk'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'nautilus', 'cephalopod', 'octopod', 'paper_nautilus', 'octopus']
senticnet['ceramics'] = [0.528, -0.606, 0, 0.724, '#surprising', '#admirable', 0.619, 'gastronomy', 'arts_and_crafts', 'carving', 'decoupage', 'artistic_creation']
senticnet['cereal'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'veal', 'beef', 'food_group', 'animal_flesh', 'curry']
senticnet['cereal_bowl'] = [0, 0, 0, 0.128, '#admirable', '#admirable', 0.043, 'wooden_spoon', 'caffeine', 'teaspoon', 'container_cup', 'large_container']
senticnet['cereal_crop'] = [0, 0.082, 0.052, 0.08, '#interesting', '#admirable', 0.037, 'starch', 'food_type', 'farm_plant', 'farm_crop', 'staple_food']
senticnet['cereal_grain'] = [0.061, 0.093, 0.037, 0.114, '#interesting', '#admirable', 0.077, 'whole_grain', 'food_ingredient', 'staple_food', 'starchy_food', 'food_grain']
senticnet['cerebral_peduncle'] = [0.7, 0, 0, 0, '#joyful', '#joyful', 0.233, 'commissure', 'optic_radiation', 'radiatio_optica', 'peduncle', 'pathway']
senticnet['cerebration'] = [0.621, -0.604, 0, 0.53, '#joyful', '#surprising', 0.585, 'reasoning', 'consideration', 'logical_thinking', 'abstract_thought', 'excogitation']
senticnet['cerebrospinal_fever'] = [-0.773, 0, 0.871, -0.64, '#sad', '#angry', -0.761, 'leptomeningitis', 'cerebrospinal_meningitis', 'epidemic_meningitis', 'brain_fever', 'meningitis']
senticnet['cerebrospinal_meningitis'] = [-0.773, 0, 0.871, -0.64, '#sad', '#angry', -0.761, 'leptomeningitis', 'meningitis', 'epidemic_meningitis', 'brain_fever', 'cerebrospinal_fever']
senticnet['ceremony'] = [0.908, 0, 0, 0.819, '#joyful', '#admirable', 0.576, 'religious_event', 'sunday', 'happy_event', 'tradition', 'wedding']
senticnet['certain'] = [0, 0, 0, 0.884, '#admirable', '#admirable', 0.295, 'aware', 'truth', 'discovery', 'fact', 'help_find']
senticnet['certainty'] = [0, 0.793, 0, 0, '#interesting', '#interesting', 0.264, 'attitude', 'prefer', 'thoughtful', 'strong_feeling', 'wish']
senticnet['certificate'] = [0, 0.155, 0, 0, '#interesting', '#interesting', 0.052, 'diploma', 'celsius', 'qualification', 'temperature_measure', 'temperature_measurement']
senticnet['certificate_of_incorporation'] = [0.931, -0.526, 0, 0.67, '#joyful', '#admirable', 0.709, 'document', 'credential', 'birth_certificate', 'diploma', 'sheepskin']
senticnet['certification'] = [-0.024, 0.102, 0, 0.07, '#interesting', '#admirable', 0.049, 'qualification', 'grade', 'diploma', 'pass_fail', 'graduate']
senticnet['certificatory'] = [0.9, -0.742, 0, 0.721, '#joyful', '#surprising', 0.788, 'accessary', 'demonstrative_of', 'encouraging', 'supportive', 'supporting']
senticnet['cerussite'] = [0.555, -0.994, 0, 0.851, '#surprising', '#admirable', 0.8, 'quartz', 'mineral', 'white_lead_ore', 'cobaltite', 'molybdenite']
senticnet['chachka'] = [-0.744, 0, 0.877, -0.975, '#angry', '#disgusting', -0.865, 'miss', 'girl', 'missy', 'young_lady', 'young_woman']
senticnet['chafe'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['chaff'] = [0, 0, 0.788, -0.75, '#angry', '#disgusting', -0.513, 'rubbish', 'refuse', 'waste', 'garbage', 'litter']
senticnet['chagrin'] = [-0.869, 0, 0, -0.705, '#sad', '#disgusting', -0.525, 'abashed', 'chagrined', 'abash', 'embarrassingly', 'unenviable']
senticnet['chagrined'] = [0, 0, 0.755, -0.916, '#angry', '#disgusting', -0.557, 'abashed', 'embarrassingly', 'abash', 'awkward', 'unenviable']
senticnet['chain'] = [0.096, -0.017, 0, 0, '#joyful', '#surprising', 0.038, 'platform_rail', 'rail', 'catwalk', 'column', 'token_turnstile']
senticnet['chain_up'] = [-0.773, 0, 0.871, -0.64, '#sad', '#angry', -0.761, 'hold', 'prisoner', 'prison', 'tie_down', 'enchain']
senticnet['chainsaw'] = [0, 0, -0.754, -0.745, '#scared', '#disgusting', -0.5, 'handgun', 'firearm', 'cannon', 'weapon', 'machine_gun']
senticnet['chair'] = [0, 0, 0.763, -0.999, '#angry', '#disgusting', -0.587, 'sofa_bed', 'small_seat', 'beanbag_airline_seat', 'hide-a-bed_sofa', 'airline_seat']
senticnet['chair_committee'] = [-0.978, 0, 0, -0.765, '#sad', '#disgusting', -0.581, 'voice_concern', 'sail_around_world', 'age_gracefully', 'lose_key', 'storm_out_room']
senticnet['chair_meet'] = [-0.802, 0, -0.758, 0, '#sad', '#scared', -0.52, 'age_gracefully', 'wrong_another_person', 'storm_out_room', 'sail_around_world', 'voice_concern']
senticnet['chairman'] = [0.027, 0.074, 0, 0.087, '#interesting', '#admirable', 0.063, 'president', 'use_school', 'wood_plank', 'chairperson', 'sound_like']
senticnet['chairperson'] = [-0.029, 0, 0, -0.079, '#sad', '#disgusting', -0.036, 'manager', 'investigator', 'slut', 'seeker', 'commuter']
senticnet['chalk_board'] = [0, -0.013, 0.027, -0.1, '#angry', '#disgusting', -0.038, 'sand_paper', 'obstacle', 'golf_place', 'paper', 'school_class']
senticnet['chalk_dust'] = [-0.025, 0.087, 0, 0.107, '#interesting', '#admirable', 0.056, 'fallout', 'dust', 'radioactive_dust', 'particulate', 'particulate_matter']
senticnet['challenge'] = [0.104, -0.068, 0.057, 0, '#joyful', '#surprising', 0.038, 'enjoy_game', 'competition', 'challenge_oneself', 'recreation', 'enjoy_challenge']
senticnet['challenge_oneself'] = [0.112, 0.178, -0.055, 0.143, '#interesting', '#admirable', 0.126, 'win_marathon', 'support_cause', 'prove_fitness', 'enjoy_competition', 'earn_a_lot_of_money']
senticnet['challengeable'] = [0.544, -0.693, 0, 0.658, '#surprising', '#admirable', 0.632, 'shakable', 'shakeable', 'contestable', 'disputable', 'debatable']
senticnet['challenger'] = [0.85, -0.894, 0, 0.634, '#joyful', '#surprising', 0.793, 'rival', 'competition', 'comer', 'competitor', 'contender']
senticnet['chamber'] = [-0.589, 0, 0.509, -0.836, '#sad', '#disgusting', -0.645, 'burial_chamber', 'sepulcher', 'bunker', 'sepulture', 'bombproof']
senticnet['chamber_music'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'classical_music', 'make_beautiful_music', 'create_music', 'part_of_band', 'make_music']
senticnet['chambermaid'] = [-0.626, 0, 0.649, -0.673, '#angry', '#disgusting', -0.649, 'handmaid', 'handmaiden', 'maid', 'lady_maid', 'parlormaid']
senticnet['chameleon'] = [0.63, -0.889, 0, 0.503, '#joyful', '#surprising', 0.674, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['champagne'] = [0.153, -0.058, 0, 0, '#joyful', '#surprising', 0.07, 'beer', 'wine', 'vodka', 'whiskey', 'whisky']
senticnet['champion'] = [0, 0, 0, 0.834, '#admirable', '#admirable', 0.278, 'royal_person', 'royal_title', 'earl', 'master', 'rank']
senticnet['champion_lode'] = [0.614, -0.956, 0, 0.584, '#joyful', '#surprising', 0.718, 'mother_lode', 'lode', 'deposit', 'sedimentation', 'alluviation']
senticnet['championship'] = [0, 0, 0, 0.879, '#admirable', '#admirable', 0.293, 'sport_competition', 'win_competition', 'race', 'match', 'competition']
senticnet['chance'] = [0, -0.747, 0, 0.982, '#surprising', '#admirable', 0.576, 'bet', 'card', 'dare', 'cope', 'jeopardy']
senticnet['chance_event'] = [-0.912, 0, 0.769, -0.841, '#sad', '#disgusting', -0.841, 'break', 'good_luck', 'happy_chance', 'hap', 'coincidence']
senticnet['change'] = [-0.034, 0.212, 0, 0.093, '#interesting', '#admirable', 0.09, 'account', 'bank_loan', 'deposit', 'spare_change', 'banknote']
senticnet['change_appearance'] = [0, -0.053, 0.016, 0.053, '#surprising', '#admirable', 0.03, 'dress_nice', 'improve_image', 'straighten_hair', 'haircut', 'dye_hair']
senticnet['change_aspect'] = [0.642, -0.585, 0, 0.751, '#joyful', '#admirable', 0.659, 'change', 'become_better', 'metamorphosis', 'look_better', 'become_bigger']
senticnet['change_attitude'] = [-0.026, -0.025, -0.081, -0.046, '#scared', '#disgusting', -0.043, 'new_information', 'misunderstanding', 'exchange_idea', 'find_solution', 'get_know_better']
senticnet['change_behavior'] = [0.794, 0.888, 0, 0, '#joyful', '#interesting', 0.561, 'felony', 'vengeance', 'restrict_freedom', 'revenge', 'commit_crime']
senticnet['change_channel'] = [0, 0, 0.91, -0.726, '#angry', '#disgusting', -0.545, 'see_commercial', 'laugh', 'channel_surf', 'entertain', 'kill_brain_cell']
senticnet['change_clothes'] = [0.928, 0.778, 0, 0, '#joyful', '#interesting', 0.569, 'nice_clothes', 'put_clean_clothes', 'put_nice_clothes', 'take_bath', 'take_shower']
senticnet['change_color'] = [0, 0.073, 0, 0.056, '#interesting', '#admirable', 0.043, 'yoga', 'eat_healthy_diet', 'exercise_much', 'move_place_another', 'make_look_better']
senticnet['change_diaper'] = [0.769, 0.974, 0, 0, '#joyful', '#interesting', 0.581, 'make_love', 'family', 'baby', 'mother', 'father']
senticnet['change_direction'] = [0, 0.114, -0.051, 0.207, '#interesting', '#admirable', 0.09, 'rotate', 'go_around', 'rotate_movement', 'turn_around', 'revolve']
senticnet['change_gear'] = [0, 0, 0, 0.093, '#admirable', '#admirable', 0.031, 'steer_car', 'car_travel', 'control_car', 'transportation', 'car_movement']
senticnet['change_government'] = [0.887, 0.915, 0, 0, '#joyful', '#interesting', 0.601, 'change_law', 'change', 'documentation', 'recollection', 'recall']
senticnet['change_hair'] = [0.05, -0.029, 0, 0.111, '#joyful', '#admirable', 0.063, 'grow_beard', 'makeover', 'haircut', 'dye_hair', 'get_haircut']
senticnet['change_hair_style'] = [0.065, 0, 0.01, 0.049, '#joyful', '#admirable', 0.035, 'look_smart', 'improve_appearance', 'short_hair', 'look_neat', 'get_new_hairstyle']
senticnet['change_hairstyle'] = [0.642, -0.585, 0, 0.751, '#joyful', '#admirable', 0.659, 'dye_hair', 'case_house', 'consult_expert', 'cut_hair', 'get_manicure']
senticnet['change_idea'] = [-0.045, 0.343, -0.052, 0.179, '#interesting', '#admirable', 0.142, 'change_law', 'idea', 'make_right_decision', 'new_think', 'change_government']
senticnet['change_job'] = [0.928, 0.778, 0, 0, '#joyful', '#interesting', 0.569, 'look_for_job', 'change_work', 'change_life', 'go_interview', 'new_job']
senticnet['change_law'] = [-0.045, 0.343, -0.052, 0.179, '#interesting', '#admirable', 0.142, 'change_idea', 'idea', 'make_right_decision', 'new_think', 'change_government']
senticnet['change_life'] = [-0.108, 0.068, -0.129, -0.116, '#scared', '#disgusting', -0.095, 'mentor', 'housewife', 'know_well', 'finish_college', 'get_high_education']
senticnet['change_lifestyle'] = [-0.13, 0.098, -0.154, 0, '#sad', '#scared', -0.062, 'pour_water', 'remove_clothes', 'wear_bath_suit', 'malfunction', 'use_shower']
senticnet['change_location'] = [0, 0, 0, 0.19, '#admirable', '#admirable', 0.063, 'personal_transport', 'get_around', 'get_somewhere_fast', 'locomotion', 'movement']
senticnet['change_mind'] = [0, -0.854, 0, 0, '#surprising', '#surprising', 0.285, 'think_logically', 'learn_new_idea', 'share_opinion', 'form_opinion', 'desire_travel']
senticnet['change_money'] = [0, 0.144, -0.091, 0.196, '#interesting', '#admirable', 0.083, 'capable', 'travel', 'currency_exchange', 'pocket_money', 'dynamic']
senticnet['change_mood'] = [0.971, 0, 0, 0.995, '#joyful', '#admirable', 0.655, 'like', 'deafness', 'enjoy_music', 'sing_along', 'tap_foot']
senticnet['change_of_color'] = [0.995, -0.533, 0, 0.977, '#joyful', '#admirable', 0.835, 'change_of_state', 'discoloration', 'discolouration', 'whitening', 'lightening']
senticnet['change_of_shape'] = [0.592, -0.913, 0, 0.61, '#surprising', '#admirable', 0.705, 'folding', 'angulation', 'narrowing', 'elongation', 'fold']
senticnet['change_of_state'] = [0.588, -0.759, 0, 0.574, '#joyful', '#surprising', 0.64, 'rousing', 'improvement', 'beautification', 'degradation', 'change_of_color']
senticnet['change_opinion'] = [-0.891, 0, 0, -0.95, '#sad', '#disgusting', -0.614, 'eye_strain', 'time_waste', 'become_smart', 'see_ad', 'gain_knowledge']
senticnet['change_plan'] = [-0.943, 0, -0.854, 0, '#sad', '#scared', -0.599, 'use_thermometer', 'pay_close_attention', 'form_opinion', 'new_insight', 'thirst_knowledge']
senticnet['change_position'] = [-0.069, 0.154, -0.058, 0.192, '#interesting', '#admirable', 0.073, 'relocation', 'go_forward', 'move_around', 'take_action', 'movement']
senticnet['change_quickly'] = [0, -0.289, -0.114, 0.258, '#surprising', '#admirable', 0.144, 'change', 'quick_change', 'surprise', 'new_beginning', 'wow']
senticnet['change_shape'] = [0.24, 0.289, -0.118, 0.328, '#interesting', '#admirable', 0.246, 'become_liquid', 'circumstance', 'ice_crystal', 'ice_rain', 'icy']
senticnet['change_society'] = [-0.032, -0.049, 0, 0.06, '#surprising', '#admirable', 0.026, 'make_better_world', 'go_public', 'take_oath', 'sex_same_gender', 'marry']
senticnet['change_someone_greatly'] = [0.959, 0, 0, 0.933, '#joyful', '#admirable', 0.631, 'oneself', 'cut_finger', 'dishonor', 'lay_off', 'call_name']
senticnet['change_state'] = [-0.045, 0.343, -0.052, 0.179, '#interesting', '#admirable', 0.142, 'swoon', 'pass_out', 'faint', 'conk', 'zonk_out']
senticnet['change_style'] = [0, 0.088, -0.08, 0.085, '#interesting', '#admirable', 0.031, 'short_hair', 'hair_become_short', 'keep_hair_short', 'hair_get_short', 'look_smart']
senticnet['change_taste'] = [-0.707, 0, 0.518, -0.514, '#sad', '#angry', -0.58, 'bitter', 'modify', 'acidulate', 'acidify', 'acetify']
senticnet['change_tire'] = [-0.1, 0, -0.11, 0, '#sad', '#scared', -0.07, 'driving', 'fix_flat_tire', 'lie_floor', 'workshop', 'car']
senticnet['change_work'] = [0.928, 0.778, 0, 0, '#joyful', '#interesting', 0.569, 'look_for_job', 'change_job', 'change_life', 'go_interview', 'new_job']
senticnet['change_world'] = [0, 0.871, 0, 0.982, '#interesting', '#admirable', 0.618, 'write_email', 'learn_skill', 'process_data', 'word_process', 'calculate']
senticnet['changeability'] = [0.772, -0.731, 0, 0.958, '#joyful', '#admirable', 0.82, 'quality', 'mutability', 'mutableness', 'changefulness', 'exchangeability']
senticnet['changeable'] = [0, 0, 0.852, -0.743, '#angry', '#disgusting', -0.532, 'cute', 'hairy', 'fun_around', 'driven_person', 'fickle']
senticnet['changeableness'] = [0.729, -0.538, 0, 0.612, '#joyful', '#admirable', 0.626, 'quality', 'mutability', 'mutableness', 'changefulness', 'exchangeability']
senticnet['changed'] = [0.78, -0.799, 0, 0.954, '#surprising', '#admirable', 0.844, 'transformed', 'varied', 'exchanged', 'denatured', 'denaturized']
senticnet['changeful'] = [0.896, -0.663, 0, 0.667, '#joyful', '#admirable', 0.742, 'mutable', 'distortable', 'reversible', 'adjustable', 'unstable']
senticnet['changefulness'] = [0.772, -0.731, 0, 0.958, '#joyful', '#admirable', 0.82, 'quality', 'mutability', 'mutableness', 'changeability', 'exchangeability']
senticnet['changeless'] = [-0.905, 0, 0.653, -0.998, '#sad', '#disgusting', -0.852, 'unalterable', 'static', 'unchangeable', 'confirmed', 'fixed']
senticnet['changelessness'] = [0.949, -0.552, 0, 0.595, '#joyful', '#admirable', 0.699, 'metastability', 'monotony', 'invariance', 'constancy', 'unchangeability']
senticnet['changing'] = [0.74, -0.755, 0, 0.815, '#surprising', '#admirable', 0.77, 'propellant', 'propellent', 'propelling', 'dynamical', 'propulsive']
senticnet['changing_room'] = [0, 0.144, -0.091, 0.196, '#interesting', '#admirable', 0.083, 'fit_room', 'clothes_store_change_room', 'dress_room', 'clothes_shelf', 'garment_bag']
senticnet['channel_selector'] = [0.02, -0.026, 0, 0.061, '#surprising', '#admirable', 0.036, 'power_switch', 'female_television_connector', 'speaker', 'tuner', 'handset']
senticnet['channel_surf'] = [0, 0, 0.972, -0.794, '#angry', '#disgusting', -0.589, 'change_channel', 'entertain', 'laugh', 'see_commercial', 'eat_popcorn']
senticnet['chant'] = [0.083, 0.239, -0.111, 0.271, '#interesting', '#admirable', 0.161, 'hymn', 'christmas_song', 'instrumental', 'melodic_noise', 'song_lyric']
senticnet['chaos'] = [-0.441, -0.138, -0.08, -0.407, '#sad', '#disgusting', -0.263, 'disorder', 'untidy', 'mess', 'jumble', 'heap']
senticnet['chap'] = [0.055, 0.189, -0.097, 0.113, '#interesting', '#admirable', 0.087, 'tame', 'male_and_female', 'sense_fear', 'friend_person', 'good_manner']
senticnet['chapeau'] = [-0.588, 0, 0.632, -0.638, '#angry', '#disgusting', -0.619, 'skimmer', 'trilby', 'bearskin', 'busby', 'shako']
senticnet['chapel'] = [0, 0.236, 0.026, 0.212, '#interesting', '#admirable', 0.141, 'catholic_church', 'cathedral', 'temple', 'church', 'altar']
senticnet['chapter'] = [0.074, 0.114, 0, 0.126, '#interesting', '#admirable', 0.105, 'paragraph', 'newspaper_write', 'news_paper', 'newspaper_story', 'index']
senticnet['char'] = [-0.043, 0, -0.114, -0.036, '#sad', '#scared', -0.064, 'chemical_reaction', 'burn', 'chemical_process', 'get_burnt', 'set_on_fire']
senticnet['character'] = [-0.829, 0, 0.958, -0.557, '#sad', '#angry', -0.781, 'baddie', 'role', 'theatrical_role', 'part', 'persona']
senticnet['character_assassination'] = [-0.926, 0, 0.755, -0.784, '#sad', '#disgusting', -0.822, 'calumniation', 'traducement', 'hatchet_job', 'defamation', 'calumny']
senticnet['character_play'] = [0, -0.808, 0, 0.732, '#surprising', '#admirable', 0.513, 'coincidence', 'math_homework', 'sign_autograph', 'role', 'write']
senticnet['character_trait'] = [0.136, 0.293, -0.119, 0.371, '#interesting', '#admirable', 0.227, 'characteristic', 'peculiar', 'good_quality', 'description', 'good_character']
senticnet['characteristic'] = [0.055, 0.247, -0.122, 0.347, '#interesting', '#admirable', 0.176, 'character_trait', 'special', 'description', 'greatness', 'peculiar']
senticnet['characterize'] = [-0.931, 0, 0.778, -0.93, '#sad', '#disgusting', -0.88, 'differentiate', 'remember', 'think_of', 'distinguish', 'mark']
senticnet['charade'] = [0, -0.79, 0, 0.89, '#surprising', '#admirable', 0.56, 'behave', 'act', 'perpetrator', 'portray', 'stage_play']
senticnet['charcoal'] = [0.037, 0.084, 0, 0, '#joyful', '#interesting', 0.04, 'leave_over', 'leftover', 'cellulose', 'cane', 'remainder']
senticnet['charge'] = [0.172, 0.399, -0.209, 0.227, '#interesting', '#admirable', 0.196, 'human_trait', 'bribe', 'mastercard', 'afford', 'tax']
senticnet['charge_battery'] = [0, 0, 0.838, -0.817, '#angry', '#disgusting', -0.552, 'sightsee', 'camera', 'electronics_device', 'see_countryside', 'go_to_another_place']
senticnet['charge_card'] = [-0.028, -0.022, 0.05, -0.032, '#angry', '#disgusting', -0.029, 'go_to_shopping_mall', 'go_shopping', 'drive_to_store', 'go_department_store', 'find_market']
senticnet['charge_credit_card'] = [-0.925, 0, 0, -0.796, '#sad', '#disgusting', -0.574, 'gather_berry', 'hang_picture_on_wall', 'see_star_night', 'sit_toilet', 'air_grievance']
senticnet['charge_money'] = [-0.054, 0.207, 0, 0.126, '#interesting', '#admirable', 0.093, 'clearance', 'cashless', 'discount', 'spend', 'cheap_price']
senticnet['charge_up'] = [-0.623, 0, 0.806, -0.538, '#sad', '#angry', -0.656, 'upset', 'hype_up', 'psych_up', 'bother', 'trouble']
senticnet['charged'] = [0.626, -0.603, 0, 0.769, '#joyful', '#admirable', 0.666, 'positive', 'electropositive', 'positively_charged', 'live', 'polar']
senticnet['charisma'] = [0, 0.729, 0, 0.769, '#interesting', '#admirable', 0.499, 'charm', 'presence', 'aura', 'personality', 'strength_of_character']
senticnet['charitable'] = [0.552, 0.681, -0.294, 0.297, '#joyful', '#interesting', 0.412, 'good-hearted', 'large-hearted', 'openhearted', 'benevolent', 'kindly']
senticnet['charity'] = [0, 0, 0, 0.939, '#admirable', '#admirable', 0.313, 'give_money', 'offer', 'gift', 'give', 'reward']
senticnet['charlatan'] = [0.969, -0.885, 0, 0.736, '#joyful', '#surprising', 0.863, 'slicker', 'beguiler', 'quack', 'phrenologist', 'craniologist']
senticnet['charlatanism'] = [0.847, -0.721, 0, 0.927, '#joyful', '#admirable', 0.832, 'wrongdoing', 'treachery', 'perfidy', 'knavery', 'treason']
senticnet['charm'] = [0, 0, 0, 0.751, '#admirable', '#admirable', 0.25, 'enchant', 'favorable', 'favorably', 'charmy', 'comfortableness']
senticnet['charmed'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'captivated', 'enamor', 'enthralling', 'becharm', 'beguiled']
senticnet['charmer'] = [0.85, -0.716, 0, 0.617, '#joyful', '#surprising', 0.728, 'pretender', 'phony', 'phoney', 'hypocrite', 'dissembler']
senticnet['charming'] = [0.708, 0.862, 0, 0, '#joyful', '#interesting', 0.523, 'capture', 'enamour', 'trance', 'catch', 'becharm']
senticnet['charmy'] = [0, 0, 0, 0.751, '#admirable', '#admirable', 0.25, 'enchant', 'favorable', 'favorably', 'charm', 'comfortableness']
senticnet['chart'] = [0.094, 0.091, 0, 0.125, '#joyful', '#admirable', 0.103, 'diagram', 'graph', 'medium', 'fragment', 'representation']
senticnet['chase'] = [0, 0, 0, -0.079, '#disgusting', '#disgusting', -0.026, 'go_away', 'ask_to_leave', 'anger', 'back_off', 'hold_onto']
senticnet['chase_away'] = [0.705, -0.552, 0, 0.684, '#joyful', '#admirable', 0.647, 'move', 'displace', 'clear_air', 'fire', 'banish']
senticnet['chase_ball'] = [-0.092, -0.043, 0.081, -0.065, '#sad', '#angry', -0.065, 'run_quickly', 'run_fast', 'monitor_heart_rate', 'bring_dog', 'strike_out']
senticnet['chase_dog'] = [-0.05, -0.025, 0, -0.07, '#sad', '#disgusting', -0.032, 'feel_out_breath', 'muscle_cramp', 'cramp', 'sore_muscle', 'stiffness']
senticnet['chassis'] = [0, -0.01, 0, 0.069, '#surprising', '#admirable', 0.026, 'brake_pedal', 'emergency_brake', 'air_vent', 'fan_belt', 'clutch']
senticnet['chaste'] = [0.839, -0.704, 0, 0.93, '#joyful', '#admirable', 0.824, 'virtuous', 'celibate', 'pure', 'continent', 'virginal']
senticnet['chasten'] = [-0.722, 0, 0.737, -0.603, '#sad', '#angry', -0.687, 'call_on_carpet', 'take_to_task', 'chide', 'berate', 'bawl_out']
senticnet['chastening'] = [-0.619, 0, 0.719, -0.718, '#angry', '#disgusting', -0.685, 'reprimand', 'rebuke', 'reproof', 'reproval', 'reprehension']
senticnet['chat'] = [-0.515, 0, 0.545, -0.911, '#angry', '#disgusting', -0.657, 'gossip', 'chitchat', 'chit_chat', 'gab', 'small_talk']
senticnet['chat_friend'] = [0, -0.985, 0, 0.967, '#surprising', '#admirable', 0.651, 'conversation', 'take_phone_call', 'communicate', 'talk_far_away', 'chat']
senticnet['chatspeak'] = [-0.043, -0.021, 0.041, -0.039, '#sad', '#angry', -0.034, 'jargon', 'lingo', 'cant', 'slang', 'unusual_language']
senticnet['chatter_tooth'] = [0, -0.829, 0, 0.953, '#surprising', '#admirable', 0.594, 'remote_control', 'air_pump', 'safety_pin', 'slinky', 'typewriter_ribbon']
senticnet['chatty'] = [0.949, -0.694, 0, 0.992, '#joyful', '#admirable', 0.878, 'voluble', 'gabby', 'garrulous', 'loquacious', 'talky']
senticnet['chauffeur'] = [0.066, 0, -0.059, 0.066, '#joyful', '#admirable', 0.024, 'cyclist', 'smoker', 'homeowner', 'programmer', 'stalactite']
senticnet['chauvinism'] = [0.553, -0.728, 0, 0.752, '#surprising', '#admirable', 0.678, 'jingoism', 'trueness', 'loyalty', 'nationalism', 'superpatriotism']
senticnet['chauvinist'] = [0, 0, -0.888, -0.702, '#scared', '#disgusting', -0.53, 'jingo', 'hundred-percenter', 'flag-waver', 'patrioteer', 'jingoist']
senticnet['chauvinistic'] = [0.585, -0.7, 0, 0.586, '#surprising', '#admirable', 0.624, 'jingoistic', 'ultranationalistic', 'superpatriotic', 'nationalistic', 'patriotic']
senticnet['cheap'] = [-0.047, 0.201, -0.063, 0.312, '#interesting', '#admirable', 0.134, 'save_money', 'good_price', 'inexpensive', 'bargain', 'discount']
senticnet['cheap_buy'] = [-0.033, 0.292, -0.096, 0.35, '#interesting', '#admirable', 0.171, 'good_price', 'business_transaction', 'get_rid', 'cheap_price', 'good_buy']
senticnet['cheap_camera'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'slow', 'long_focus', 'focus_time', 'bad_camera', 'long_focus_time']
senticnet['cheap_food'] = [0.043, 0, 0.041, 0.086, '#joyful', '#admirable', 0.029, 'starchy_food', 'food_ingredient', 'whole_grain', 'white_brown', 'staple_food']
senticnet['cheap_hotel'] = [-0.983, 0, 0.058, -0.921, '#sad', '#disgusting', -0.654, 'bad_staff', 'bad_service', 'cheap_restaurant', 'unfriendly_staff', 'long_waiting_time']
senticnet['cheap_price'] = [-0.036, 0.273, -0.046, 0.244, '#interesting', '#admirable', 0.145, 'good_price', 'bargain', 'good_buy', 'sale', 'good_deal']
senticnet['cheap_restaurant'] = [-0.983, 0, 0.058, -0.921, '#sad', '#disgusting', -0.654, 'bad_staff', 'cheap_hotel', 'bad_service', 'unfriendly_staff', 'long_waiting_time']
senticnet['cheap_shot'] = [0.695, -0.525, 0, 0.957, '#joyful', '#admirable', 0.726, 'jibe', 'slam', 'gibe', 'shot', 'shaft']
senticnet['cheap_stuff'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'discount_store', 'save_money', 'cheap_food', 'sales', 'on_sale']
senticnet['cheapen'] = [-0.641, 0, 0.805, -0.579, '#sad', '#angry', -0.675, 'worsen', 'aggravate', 'exacerbate', 'devalue', 'devaluate']
senticnet['cheapjack'] = [-0.774, 0, 0.874, -0.803, '#angry', '#disgusting', -0.817, 'peddler', 'pedlar', 'packman', 'hawker', 'pitchman']
senticnet['cheat'] = [-0.889, 0, -0.812, 0, '#sad', '#scared', -0.567, 'flunk', 'a_lot_of_stress', 'further_goal', 'failure', 'shuffle_card']
senticnet['cheat_on'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'unfaithful', 'cheat_partner', 'plagiarism', 'deceive', 'trick']
senticnet['cheat_partner'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'unfaithful', 'cheat_on', 'plagiarism', 'deceive', 'trick']
senticnet['cheat_spouse'] = [0, 0, 0.771, -0.955, '#angry', '#disgusting', -0.575, 'ridicule', 'need_help', 'vengeance', 'infidelity', 'caution']
senticnet['cheater'] = [-0.97, 0, 0.549, -0.805, '#sad', '#disgusting', -0.775, 'beguiler', 'slicker', 'deceiver', 'cheat', 'dodger']
senticnet['cheating'] = [-0.993, 0, 0, -0.764, '#sad', '#disgusting', -0.586, 'gerrymander', 'dissimulation', 'dissembling', 'deception', 'deceit']
senticnet['check'] = [-0.028, 0.193, 0.013, 0.053, '#interesting', '#admirable', 0.068, 'dollar_bill', 'cash_bill', 'piece_of_change', 'debit_card', 'dollar']
senticnet['check_account'] = [0, 0.218, 0, 0.074, '#interesting', '#admirable', 0.097, 'store_money', 'savings', 'money_inside', 'save_money', 'money_storage']
senticnet['check_balance'] = [-0.025, 0.207, 0.028, 0.094, '#interesting', '#admirable', 0.083, 'money_hold', 'money_place', 'store_money', 'money_storage', 'check_account']
senticnet['check_blood_pressure'] = [-0.128, 0, -0.126, -0.086, '#sad', '#scared', -0.113, 'hospital', 'check_up', 'check_doctor', 'check_pulse', 'healthcare']
senticnet['check_body'] = [0.642, -0.585, 0, 0.751, '#joyful', '#admirable', 0.659, 'syringe', 'latex_glove', 'x-ray_machine', 'wait_room', 'novocaine']
senticnet['check_breathe'] = [0, 0, -0.811, -0.911, '#scared', '#disgusting', -0.574, 'stop_bleed', 'check_oneself_mirror', 'desire_help', 'look_out_window', 'fee_animal']
senticnet['check_doctor'] = [-0.062, 0, -0.059, 0, '#sad', '#scared', -0.04, 'go_gym', 'join_gym', 'workout', 'lift_weight', 'eat_balance_diet']
senticnet['check_email'] = [-0.069, 0.224, 0, 0.133, '#interesting', '#admirable', 0.096, 'check_mail', 'search_information', 'use_search_engine', 'look_for_information', 'phone_line_busy']
senticnet['check_health'] = [-0.949, 0, -0.72, 0, '#sad', '#scared', -0.556, 'diagnose_illness', 'eat_well', 'stay_healthy', 'do_exercise', 'maintain_good_health']
senticnet['check_how_much'] = [0, 0.254, 0.017, 0.148, '#interesting', '#admirable', 0.128, 'item_worth', 'like_cost', 'amount', 'sticker', 'item_value']
senticnet['check_into'] = [0.738, -0.757, 0, 0.854, '#surprising', '#admirable', 0.783, 'watch_over', 'keep_an_eye_on', 'watch', 'study', 'observe']
senticnet['check_listing'] = [-0.719, 0, -0.824, 0, '#sad', '#scared', -0.514, 'go_cinema', 'go_to_theater', 'go_movie_theater', 'pay_ticket', 'buy_popcorn']
senticnet['check_mail'] = [-0.122, 0, -0.053, -0.029, '#sad', '#scared', -0.068, 'page_through_book', 'open_letter', 'crowd_elevator', 'think_issue', 'wind_watch']
senticnet['check_mirror'] = [-0.065, -0.007, 0.016, 0, '#sad', '#angry', -0.025, 'adjust_seat', 'fasten_seatbelt', 'turn_engine', 'mirror', 'put_key_ignition']
senticnet['check_off'] = [0.547, -0.961, 0, 0.89, '#surprising', '#admirable', 0.799, 'check', 'support', 'assure', 'affirm', 'verify']
senticnet['check_oneself_mirror'] = [-0.094, 0, 0, -0.069, '#sad', '#disgusting', -0.054, 'stop_bleed', 'look_out_window', 'fee_animal', 'turn_off_engine', 'drink_coffee']
senticnet['check_out'] = [-0.075, 0, 0.009, -0.125, '#sad', '#disgusting', -0.07, 'hotel', 'travel', 'holiday', 'go_home', 'staycation']
senticnet['check_over'] = [0.934, -0.825, 0, 0.729, '#joyful', '#surprising', 0.829, 'watch_over', 'keep_an_eye_on', 'watch', 'study', 'observe']
senticnet['check_price'] = [-0.072, 0, 0, -0.029, '#sad', '#disgusting', -0.034, 'buy_stuff', 'acquire_goods', 'buy_item', 'make_purchase', 'buy_goods']
senticnet['check_pulse'] = [-0.135, -0.033, 0, -0.104, '#sad', '#disgusting', -0.069, 'become_fatigued', 'leg_cramp', 'become_tired', 'sore_foot', 'tiredness']
senticnet['check_spelling'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'review', 'double_check', 'spelling', 'correct_homework', 'mark_exam']
senticnet['check_time'] = [-0.079, -0.004, 0.079, -0.206, '#sad', '#angry', -0.12, 'act_bored', 'think_dog', 'finish_test', 'get_bored', 'watch_other_person']
senticnet['check_tire'] = [-0.072, 0, 0.009, 0, '#sad', '#angry', -0.027, 'drive_license', 'start_car_engine', 'know_how_drive', 'find_car_key', 'put_key_ignition']
senticnet['check_traffic'] = [0, 0, 0.974, -0.758, '#angry', '#disgusting', -0.577, 'check', 'relieve_boredom', 'find_out_weather', 'learn_news', 'date_activity']
senticnet['check_up'] = [-0.128, 0, -0.126, -0.086, '#sad', '#scared', -0.113, 'talk_doctor', 'check_blood_pressure', 'check_doctor', 'check_pulse', 'bladder_full']
senticnet['check_up_car'] = [0.642, -0.585, 0, 0.751, '#joyful', '#admirable', 0.659, 'repair_car', 'repair_shop', 'workshop', 'repair_motorcycle', 'car_workshop']
senticnet['check_up_on'] = [0.936, -0.722, 0, 0.894, '#joyful', '#admirable', 0.851, 'watch_over', 'keep_an_eye_on', 'watch', 'study', 'observe']
senticnet['check_vital_sign'] = [-0.075, 0, -0.133, 0, '#sad', '#scared', -0.069, 'know_healthy', 'nervous_breakdown', 'physical_exam', 'examination', 'epileptic_fit']
senticnet['check_wallet'] = [-0.049, 0, 0.011, -0.029, '#sad', '#disgusting', -0.03, 'look_price', 'decide_buy', 'compare_price', 'take_out_wallet', 'pay_food']
senticnet['check_weather'] = [-0.094, -0.124, 0.126, -0.234, '#angry', '#disgusting', -0.11, 'go_park', 'put_shoes', 'put_jogging_shoes', 'put_running_shoes', 'go_outside']
senticnet['checkbook'] = [0.761, 0.9, 0, 0, '#joyful', '#interesting', 0.554, 'spare_change', 'checkbook_cover', 'savings', 'banknote', 'billfold']
senticnet['checkbook_cover'] = [0.022, -0.037, 0.07, -0.13, '#angry', '#disgusting', -0.047, 'checkbook_holder', 'lip_balm', 'account_book', 'passport_case', 'cover']
senticnet['checkbook_holder'] = [0, 0, 0.036, -0.11, '#angry', '#disgusting', -0.049, 'credit_card_wallet', 'clutch_bag', 'pouch', 'checkbook_cover', 'coin_purse']
senticnet['checker'] = [0.771, 0, 0, 0.899, '#joyful', '#admirable', 0.557, 'ball_game', 'verbosity', 'scrabble', 'sport_play', 'many_sports']
senticnet['checkmate'] = [0.595, -0.5, 0, 0.712, '#joyful', '#admirable', 0.602, 'master', 'walk_over', 'beat_out', 'outfight', 'screw']
senticnet['checkup'] = [0.934, -0.884, 0, 0.797, '#joyful', '#surprising', 0.872, 'scan', 'scrutiny', 'medical_scrutiny', 'medical_examination', 'medical_exam']
senticnet['cheek'] = [0, 0, -0.05, -0.052, '#scared', '#disgusting', -0.034, 'jaw', 'mouth', 'dimple', 'nose', 'mucus']
senticnet['cheekiness'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'rudeness', 'discourtesy', 'insolence', 'chutzpah', 'hutzpah']
senticnet['cheer'] = [0.703, 0.534, -0.216, 0.243, '#joyful', '#interesting', 0.421, 'euphoria', 'glee', 'contentment', 'jubilation', 'closeness']
senticnet['cheer_team'] = [0, 0, 0, 0.717, '#admirable', '#admirable', 0.239, 'enjoyment', 'have_fun', 'enjoy_oneself', 'spend_time_with_friend', 'eat_hot_dog']
senticnet['cheer_up'] = [0.841, 0, 0, 0, '#joyful', '#joyful', 0.28, 'great_time', 'glee', 'have_fun', 'crowd_cheer', 'joke_around']
senticnet['cheerer'] = [0.574, -0.854, 0, 0.668, '#surprising', '#admirable', 0.699, 'looker', 'spectator', 'viewer', 'watcher', 'witness']
senticnet['cheerful'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerfully', 'jolly_up', 'hearten', 'chirk_up', 'embolden']
senticnet['cheerfully'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerful', 'jolly_up', 'hearten', 'chirk_up', 'embolden']
senticnet['cheerfulness'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerfully', 'cheerful', 'jolly_up', 'hearten', 'chirk_up']
senticnet['cheering'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'gratifyingly', 'satiable', 'satisfactorily', 'comforting', 'satisfyingly']
senticnet['cheerleader'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'supporter', 'cheer', 'cheer_up', 'cheer_team', 'cheerful']
senticnet['cheerless'] = [-0.759, 0.282, -0.429, -0.066, '#sad', '#scared', -0.324, 'depressing', 'uncheerful', 'low-spiritedness', 'lowness', 'dispiritedness']
senticnet['cheerlessly'] = [-0.718, 0.307, -0.407, -0.076, '#sad', '#scared', -0.298, 'uncheerfulness', 'cheerlessness', 'lachrymose', 'weeping', 'dolorous']
senticnet['cheerlessness'] = [-0.718, 0.307, -0.407, -0.076, '#sad', '#scared', -0.298, 'uncheerfulness', 'cheerlessly', 'lachrymose', 'weeping', 'dolorous']
senticnet['cheery'] = [0.918, 0.476, -0.197, 0.417, '#joyful', '#interesting', 0.538, 'happy', 'gaiety', 'festal', 'playfulness', 'pridefulness']
senticnet['cheese'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'cheese_platter', 'cold_cuts', 'cottage_cheese_platter', 'platter', 'appetizer']
senticnet['cheese_platter'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'cheese', 'cold_cuts', 'cottage_cheese', 'platter', 'appetizer']
senticnet['cheeseburger'] = [0.711, 0, 0, 0, '#joyful', '#joyful', 0.237, 'burger', 'appetizer', 'chinese_food', 'porridge', 'hearty']
senticnet['cheetah'] = [0, 0.161, -0.089, 0.09, '#interesting', '#admirable', 0.054, 'kangaroo', 'giraffe', 'caribou', 'mule', 'horse']
senticnet['chef_special'] = [0.842, 0, 0, 0.844, '#joyful', '#admirable', 0.562, 'good_meal', 'hot_table', 'special', 'plate_silverware', 'chopstick']
senticnet['chemical'] = [0.045, 0, 0, 0.051, '#joyful', '#admirable', 0.032, 'science', 'battery', 'chemistry', 'ph_level', 'alkaline']
senticnet['chemical_change'] = [0.833, -0.507, 0, 0.519, '#joyful', '#admirable', 0.62, 'bottom_fermentation', 'top_fermentation', 'vinification', 'chemical_process', 'zymosis']
senticnet['chemical_element'] = [-0.575, 0, 0.954, -0.806, '#angry', '#disgusting', -0.778, 'nonmetal', 'transactinide', 'hydrogen', 'atomic_number_1', 'xenon']
senticnet['chemical_irritant'] = [-0.829, 0, 0.642, -0.72, '#sad', '#disgusting', -0.73, 'substance', 'capsaicin', 'gingerol', 'piperine', 'pepper_spray']
senticnet['chemical_process'] = [-0.025, -0.012, -0.078, -0.124, '#scared', '#disgusting', -0.072, 'grow_yard', 'stain_clothes', 'big_fire', 'set_on_fire', 'burn']
senticnet['chemical_reaction'] = [-0.848, 0, -0.824, 0, '#sad', '#scared', -0.557, 'unsafe', 'bad_news', 'calamity', 'disaster', 'big_monster']
senticnet['chemiluminescence'] = [-0.925, 0, 0.734, -0.51, '#sad', '#angry', -0.723, 'luminescence', 'light', 'bioluminescence', 'visible_light', 'visible_radiation']
senticnet['chemist'] = [0.711, 0, 0, 0, '#joyful', '#joyful', 0.237, 'analyst', 'expert', 'scientist', 'esaminatore', 'physicist']
senticnet['chemistry'] = [0.045, 0, 0, 0.051, '#joyful', '#admirable', 0.032, 'science', 'battery', 'alkaline', 'ph_level', 'chemical']
senticnet['chemistry_equipment'] = [0.032, 0, 0, 0.052, '#joyful', '#admirable', 0.028, 'bunsen', 'test_tube', 'test', 'chemistry', 'tube']
senticnet['chemosurgery'] = [-0.833, 0, 0.579, -0.815, '#sad', '#disgusting', -0.742, 'operation', 'surgery', 'surgical_operation', 'surgical_procedure', 'surgical_process']
senticnet['cherish'] = [0.362, 0.214, -0.178, 0.28, '#joyful', '#admirable', 0.226, 'foreplay', 'express_gratitude', 'a_lot_of_sex', 'express_love', 'show_love']
senticnet['cherry'] = [0.02, -0.056, 0, 0, '#joyful', '#surprising', 0.025, 'many_fruits', 'peach', 'buy_fruit', 'pineapple', 'tomato']
senticnet['cherry_tree'] = [0, 0.17, 0, 0.151, '#interesting', '#admirable', 0.107, 'allotment', 'cherry', 'money_involve', 'monetary_value', 'worth']
senticnet['cherub'] = [0.026, 0.18, -0.111, 0.18, '#interesting', '#admirable', 0.092, 'deity', 'god', 'fallen_angel', 'goddess', 'rabbi']
senticnet['cherubic'] = [0.936, -0.815, 0, 0.83, '#joyful', '#admirable', 0.86, 'lovable', 'lovely', 'adorable', 'endearing', 'angelic']
senticnet['chess'] = [0, 0.119, 0.015, 0.165, '#interesting', '#admirable', 0.09, 'game_chess', 'many_games', 'billiards', 'play_marble', 'chess_game']
senticnet['chess_bishop'] = [0, 0, 0, 0.128, '#admirable', '#admirable', 0.043, 'chess_knight', 'chess_pawn', 'chess_piece', 'chess_queen', 'pawn']
senticnet['chess_game'] = [0, 0.106, 0.029, 0.216, '#interesting', '#admirable', 0.098, 'bishop', 'chess', 'castle', 'sanctuary', 'chess_set']
senticnet['chess_king'] = [0, 0.12, 0, 0.134, '#interesting', '#admirable', 0.085, 'chess_queen', 'chess_knight', 'chess_bishop', 'chess_pawn', 'chess_rook']
senticnet['chess_knight'] = [0, -0.936, 0, 0.723, '#surprising', '#admirable', 0.553, 'chess_pawn', 'chess_queen', 'chess_piece', 'pawn', 'chess_bishop']
senticnet['chess_pawn'] = [0, -0.007, 0, 0.063, '#surprising', '#admirable', 0.023, 'chess_knight', 'pawn', 'chess_piece', 'chess_bishop', 'chess_queen']
senticnet['chess_piece'] = [0, 0, 0, 0.115, '#admirable', '#admirable', 0.038, 'chess_knight', 'strategy', 'pawn', 'chess_queen', 'chess_rook']
senticnet['chess_queen'] = [0.027, -0.02, 0.023, 0.101, '#joyful', '#admirable', 0.042, 'chess_knight', 'chess_rook', 'chess_king', 'chess_bishop', 'chess_pawn']
senticnet['chess_rook'] = [0.042, -0.009, 0.027, 0.099, '#joyful', '#admirable', 0.041, 'chess_knight', 'chess_queen', 'chess_pawn', 'pawn', 'chess_bishop']
senticnet['chess_set'] = [0, 0.106, 0.029, 0.216, '#interesting', '#admirable', 0.098, 'chess_knight', 'chess', 'castle', 'sanctuary', 'chess_game']
senticnet['chess_tournament'] = [0, 0, -0.05, -0.034, '#scared', '#disgusting', -0.028, 'grandma_house', 'game_room', 'old_folk_home', 'computer_lab', 'mortuary']
senticnet['chest'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'blood_vessel', 'artery', 'vein', 'internal_organ', 'under_head']
senticnet['chest_pain'] = [-0.207, 0, -0.228, -0.191, '#sad', '#scared', -0.209, 'go_hospital', 'death', 'die', 'take_aspirin', 'kill_oneself']
senticnet['chesterfield'] = [0.128, -0.111, 0, -0.057, '#joyful', '#surprising', 0.061, 'tripod_dolly', 'stool', 'tape_machine_room', 'chair', 'bicyle']
senticnet['chestnut'] = [-0.741, 0, 0.585, -0.612, '#sad', '#disgusting', -0.646, 'buff', 'brownness', 'chocolate', 'coffee', 'deep_brown']
senticnet['chestnut_oak'] = [0.776, -0.6, 0, 0.568, '#joyful', '#surprising', 0.648, 'swamp_chestnut_oak', 'chinquapin_oak', 'chinkapin_oak', 'yellow_chestnut_oak', 'basket_oak']
senticnet['chesty'] = [-0.532, 0, 0.798, -0.73, '#angry', '#disgusting', -0.687, 'husky', 'hardy', 'sturdy', 'robust', 'stalwart']
senticnet['cheval_glass'] = [0.584, -0.627, 0, 0.815, '#surprising', '#admirable', 0.675, 'mirror', 'car_mirror', 'hand_glass', 'hand_mirror', 'looking_glass']
senticnet['chevvy'] = [-0.603, 0, 0.517, -0.768, '#sad', '#disgusting', -0.629, 'torment', 'nettle', 'bedevil', 'bother', 'devil']
senticnet['chevy'] = [-0.523, 0, 0.562, -0.722, '#angry', '#disgusting', -0.602, 'torment', 'nettle', 'bedevil', 'bother', 'devil']
senticnet['chew'] = [-0.063, 0.183, 0.651, -0.642, '#angry', '#disgusting', -0.391, 'runny_nose', 'allergic_reaction', 'pierce', 'mastication', 'put_mouth']
senticnet['chew_bone'] = [0.11, 0, 0, 0.095, '#joyful', '#admirable', 0.068, 'play_fetch', 'ride_car', 'dog', 'play_human', 'run']
senticnet['chew_fat'] = [0.651, -0.929, 0, 0.657, '#surprising', '#admirable', 0.746, 'schmooze', 'schmoose', 'shmooze', 'shmoose', 'jawbone']
senticnet['chew_food'] = [0.026, 0.069, 0, 0, '#joyful', '#interesting', 0.032, 'eat_food', 'eat_beef', 'eat_dinner', 'put_food_mouth', 'eat_much']
senticnet['chew_gum'] = [-0.097, 0, 0.023, -0.125, '#sad', '#disgusting', -0.082, 'read_paper', 'use_logic', 'order_food', 'tell_secret', 'find_book_library']
senticnet['chew_out'] = [-0.553, 0, 0.577, -0.505, '#sad', '#angry', -0.545, 'castigate', 'tell_off', 'brush_down', 'chasten', 'objurgate']
senticnet['chew_pencil'] = [-0.742, 0, 0, -0.829, '#sad', '#disgusting', -0.524, 'get_nervous', 'write_essay', 'scratch_head', 'write_down', 'look_clock']
senticnet['chew_tobacco'] = [-0.105, -0.067, 0.075, -0.288, '#sad', '#disgusting', -0.134, 'make_anger', 'shit', 'fall_down_flight_stair', 'lean_over', 'ooze']
senticnet['chew_up'] = [-0.64, 0, 0.716, -0.761, '#angry', '#disgusting', -0.706, 'castigate', 'tell_off', 'brush_down', 'chasten', 'objurgate']
senticnet['chewing_out'] = [-0.949, 0, 0.808, -0.636, '#sad', '#angry', -0.798, 'reprimand', 'rebuke', 'reproof', 'reproval', 'reprehension']
senticnet['chewy'] = [0.949, 0, 0, 0.819, '#joyful', '#admirable', 0.589, 'breakfast_food', 'morning_food', 'food_bake', 'bakery_item', 'round_bread']
senticnet['chic'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'elegant', 'stylish', 'smart', 'posh', 'sleek']
senticnet['chicanery'] = [-0.601, 0, 0.982, -0.562, '#sad', '#angry', -0.715, 'humbug', 'deceit', 'deception', 'fraudulence', 'dissembling']
senticnet['chichi'] = [0.973, -0.509, 0, 0.612, '#joyful', '#admirable', 0.698, 'chic', 'chicness', 'jauntiness', 'modishness', 'stylishness']
senticnet['chick'] = [0.042, 0.088, 0, 0, '#joyful', '#interesting', 0.043, 'jump_over_obstacle', 'attempt_fly', 'aircraft', 'pilot', 'wings']
senticnet['chicken'] = [0.026, 0.069, 0, 0, '#joyful', '#interesting', 0.032, 'chicken_egg', 'chicken_soup', 'chick', 'male_chicken', 'quail']
senticnet['chicken_breast'] = [0.584, -0.627, 0, 0.815, '#surprising', '#admirable', 0.675, 'affliction', 'pigeon_breast', 'deformity', 'clubfoot', 'talipes']
senticnet['chicken_egg'] = [-0.109, 0, -0.09, 0, '#sad', '#scared', -0.066, 'quail', 'wren', 'sparrow', 'chicken', 'stork']
senticnet['chicken_pox'] = [0, 0, 0.753, -0.732, '#angry', '#disgusting', -0.495, 'diabetes', 'influenza', 'cripple', 'disability', 'smelly_foot']
senticnet['chicken_rice'] = [0.711, 0, 0, 0, '#joyful', '#joyful', 0.237, 'noodles', 'dumpling', 'chinese_food', 'porridge', 'rice']
senticnet['chicken_scratch'] = [0.584, -0.627, 0, 0.815, '#surprising', '#admirable', 0.675, 'squiggle', 'hand', 'cacography', 'handwriting', 'script']
senticnet['chicken_soup'] = [0.957, 0.818, 0, 0.919, '#joyful', '#admirable', 0.898, 'healthy_food', 'groceries', 'fresh_produce', 'delicious_food', 'food']
senticnet['chickweed'] = [-0.642, 0, 0.555, -0.627, '#sad', '#disgusting', -0.608, 'herb', 'common_chickweed', 'stitchwort', 'greater_stitchwort', 'starwort']
senticnet['chicness'] = [0.853, -0.764, 0, 0.966, '#joyful', '#admirable', 0.861, 'elegance', 'jauntiness', 'rakishness', 'nattiness', 'dapperness']
senticnet['chide'] = [-0.957, 0, 0.52, -0.705, '#sad', '#disgusting', -0.727, 'castigate', 'tell_off', 'brush_down', 'chasten', 'objurgate']
senticnet['chiding'] = [-0.99, 0, 0.709, -0.602, '#sad', '#angry', -0.767, 'reprimand', 'wigging', 'rebuke', 'reproof', 'reproval']
senticnet['chief'] = [-0.801, 0, 0.522, -0.83, '#sad', '#disgusting', -0.718, 'head', 'executive', 'executive_director', 'administrator', 'academic_administrator']
senticnet['chigger'] = [-0.292, -0.177, 0.073, -0.315, '#sad', '#disgusting', -0.168, 'eat_bad_food', 'chicken_pox', 'diabetes', 'smelly_foot', 'beetle']
senticnet['chihuahua'] = [0.059, 0.073, 0, 0, '#joyful', '#interesting', 0.044, 'bloodhound', 'dog', 'domesticate_dog', 'domesticate_animal', 'truffle_dog']
senticnet['child'] = [0.026, 0.069, 0, 0, '#joyful', '#interesting', 0.032, 'young_child', 'childhood', 'boy', 'girl', 'smile_child']
senticnet['child_abuse'] = [-0.8, 0, 0.875, -0.745, '#sad', '#angry', -0.807, 'inhuman_treatment', 'cruelty', 'child_neglect', 'mistreatment', 'maltreatment']
senticnet['child_birthday'] = [0.776, 0, 0, 0.853, '#joyful', '#admirable', 0.543, 'celebrate_birthday', 'special_occasion', 'special_event', 'cake_eat', 'celebrate_event']
senticnet['child_book'] = [0, -0.171, -0.046, 0.091, '#surprising', '#admirable', 0.072, 'comic_book', 'encyclopaedia', 'children_story', 'comic', 'disney_cartoon']
senticnet['child_cry'] = [-0.883, 0, 0, 0, '#sad', '#sad', -0.294, 'moan', 'common_emotion', 'depress_person', 'smart_man', 'severe_pain']
senticnet['child_game'] = [0, -0.794, 0, 0.769, '#surprising', '#admirable', 0.521, 'form_of_social_interaction', 'kid_activity', 'have_fun', 'fun_activity', 'fun_game']
senticnet['child_growth'] = [0.776, 0, 0, 0.853, '#joyful', '#admirable', 0.543, 'get_high_education', 'learn_evolution', 'teach_person', 'child', 'finish_college']
senticnet['child_movie'] = [0.928, 0.778, 0, 0, '#joyful', '#interesting', 0.569, 'child_book', 'disney_cartoon', 'children_story', 'funny_moment', 'childhood']
senticnet['child_neglect'] = [-0.8, 0, 0.875, -0.745, '#sad', '#angry', -0.807, 'inhuman_treatment', 'cruelty', 'maltreatment', 'mistreatment', 'child_abuse']
senticnet['child_play'] = [0, -0.918, 0, 0.756, '#surprising', '#admirable', 0.558, 'child_plaything', 'kid_play', 'play_object', 'plaything', 'play_device']
senticnet['child_plaything'] = [0, -0.758, 0, 0.985, '#surprising', '#admirable', 0.581, 'child_play', 'kid_play', 'play_object', 'plaything', 'play_device']
senticnet['child_prodigy'] = [0.592, -0.931, 0, 0.935, '#surprising', '#admirable', 0.819, 'child', 'small_fry', 'tyke', 'tike', 'kid']
senticnet['child_smile'] = [0.833, -0.507, 0, 0.519, '#joyful', '#admirable', 0.62, 'child', 'youth', 'young_child', 'kid', 'childhood']
senticnet['child_suffer'] = [-0.781, 0, 0, 0, '#sad', '#sad', -0.26, 'suffer_fool', 'brain_tumor', 'disrespect', 'lyme_disease', 'sadness']
senticnet['child_toy'] = [0, -0.833, 0, 0.858, '#surprising', '#admirable', 0.564, 'plaything', 'spherical_shape', 'play_object', 'use_sport', 'stretchy']
senticnet['childhood'] = [-0.066, 0.19, 0.039, 0.103, '#interesting', '#admirable', 0.063, 'young_child', 'child', 'baby', 'small_child', 'playtime']
senticnet['childless'] = [-0.705, 0, 0.919, -0.732, '#angry', '#disgusting', -0.785, 'unfruitful', 'unsuccessful', 'acarpous', 'abortive', 'stillborn']
senticnet['childlike'] = [0, 0, 0.957, -0.857, '#angry', '#disgusting', -0.605, 'ingenuous', 'gullible', 'artless', 'naive', 'guileless']
senticnet['children'] = [0.029, 0.076, 0, 0, '#joyful', '#interesting', 0.035, 'youngster', 'adolescent', 'grandchild', 'lad', 'two_children']
senticnet['children_funtime'] = [0.711, 0, 0, 0, '#joyful', '#joyful', 0.237, 'children_toy', 'stacking_game', 'play', 'build_tower_out_toy_block', 'playroom']
senticnet['children_in_safe_hands'] = [0.833, -0.507, 0, 0.519, '#joyful', '#admirable', 0.62, 'take_care', 'baby', 'free_time', 'baby_sitter', 'free_night']
senticnet['children_story'] = [0, -0.171, -0.046, 0.091, '#surprising', '#admirable', 0.072, 'child_book', 'encyclopaedia', 'comic_book', 'comic', 'disney_cartoon']
senticnet['children_toy'] = [0.081, 0.095, 0, 0, '#joyful', '#interesting', 0.059, 'build_tower_out_toy_block', 'stacking_game', 'play', 'children_funtime', 'playroom']
senticnet['chili_sauce'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'taco_sauce', 'condiment', 'steak_sauce', 'duck_sauce', 'hoisin_sauce']
senticnet['chill'] = [0.703, 0.883, 0, 0, '#joyful', '#interesting', 0.529, 'bitterness', 'nip', 'bite', 'sting', 'sharpness']
senticnet['chill_drink'] = [0, 0.091, -0.06, 0.114, '#interesting', '#admirable', 0.048, 'put_liquid', 'drink_liquid', 'hold_coffee', 'serve_beer', 'store_liquid']
senticnet['chill_out'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'drink', 'party', 'friend_gathering', 'rest_area', 'relax_time']
senticnet['chillax'] = [-0.04, 0.139, -0.078, 0.106, '#interesting', '#admirable', 0.042, 'garden', 'relax', 'use_garden', 'chill_out', 'outdoor']
senticnet['chilliness'] = [-0.923, 0, 0.972, -0.674, '#sad', '#angry', -0.856, 'cold', 'low_temperature', 'frigidity', 'frigidness', 'coldness']
senticnet['chilling'] = [-0.924, 0, -0.897, 0, '#sad', '#scared', -0.607, 'shivery', 'shuddery', 'apprehension', 'apprehensiveness', 'scare_off']
senticnet['chilly'] = [0.851, 0.768, 0, 0, '#joyful', '#interesting', 0.54, 'snowy', 'cool_temperature', 'coldness', 'ice_rain', 'season_year']
senticnet['chime'] = [0, 0.086, 0.019, 0.182, '#interesting', '#admirable', 0.083, 'ring_loudly', 'school_end', 'bell_noise', 'bell', 'bell_sound']
senticnet['chimpanzee'] = [0.02, 0.071, 0, 0.069, '#interesting', '#admirable', 0.053, 'many_animals', 'donkey', 'panda', 'cute_animal', 'creature']
senticnet['china'] = [0.039, 0, 0, 0.053, '#joyful', '#admirable', 0.031, 'big_country', 'democratic_country', 'free_country', 'unite', 'russia']
senticnet['chinatown'] = [-0.065, -0.022, -0.054, -0.118, '#sad', '#disgusting', -0.072, 'radio_station', 'old_movie', 'movie', 'pirate_ship', 'military_base']
senticnet['chinese_food'] = [0.711, 0, 0, 0, '#joyful', '#joyful', 0.237, 'noodles', 'appetizer', 'chicken_rice', 'porridge', 'hearty']
senticnet['chinkapin_oak'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'swamp_chestnut_oak', 'chinquapin_oak', 'chestnut_oak', 'yellow_chestnut_oak', 'basket_oak']
senticnet['chinquapin_oak'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'swamp_chestnut_oak', 'chestnut_oak', 'chinkapin_oak', 'yellow_chestnut_oak', 'basket_oak']
senticnet['chintzy'] = [-0.919, 0, 0.598, -0.522, '#sad', '#angry', -0.68, 'parsimonious', 'penurious', 'scrimy', 'beggarly', 'stingy']
senticnet['chip'] = [-0.838, 0, 0.521, -0.713, '#sad', '#disgusting', -0.691, 'stool', 'dejection', 'droppings', 'cow_droppings', 'cow_dung']
senticnet['chipmunk'] = [0.026, 0.082, -0.047, 0.068, '#interesting', '#admirable', 0.043, 'hare', 'bear', 'big_rat', 'omnivore', 'grizzly']
senticnet['chips'] = [0.532, -0.682, 0, 0.984, '#surprising', '#admirable', 0.733, 'potato', 'white_potato', 'murphy', 'spud', 'tater']
senticnet['chirk_up'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerfully', 'cheerful', 'jolly_up', 'hearten', 'embolden']
senticnet['chirpiness'] = [0.975, -0.984, 0, 0.988, '#surprising', '#admirable', 0.982, 'spiritedness', 'brio', 'invigoration', 'vivification', 'animation']
senticnet['chisel'] = [0, 0, 0.907, -0.908, '#angry', '#disgusting', -0.605, 'air_pump', 'drill_bite', 'power_drill', 'adjustable_wrench', 'screwdriver']
senticnet['chiseler'] = [-0.524, 0, 0.506, -0.94, '#sad', '#disgusting', -0.657, 'gouger', 'swindler', 'defrauder', 'fraud', 'welcher']
senticnet['chit_chat'] = [0.048, -0.08, 0.036, 0, '#joyful', '#surprising', 0.031, 'meet_person', 'meet_friend', 'make_friend', 'meet_girl', 'socialize']
senticnet['chitchat'] = [-0.515, 0, 0.545, -0.911, '#angry', '#disgusting', -0.657, 'gossip', 'chat', 'chit_chat', 'gab', 'small_talk']
senticnet['chivalry'] = [0.268, 0.252, -0.136, 0.332, '#joyful', '#admirable', 0.239, 'kingly', 'blue_blood', 'regal', 'royal_person', 'royal_title']
senticnet['chivvy'] = [-0.837, 0, 0.978, -0.729, '#sad', '#angry', -0.848, 'torment', 'nettle', 'bedevil', 'bother', 'devil']
senticnet['chivy'] = [-0.996, 0, 0.604, -0.917, '#sad', '#disgusting', -0.839, 'torment', 'nettle', 'bedevil', 'bother', 'devil']
senticnet['chlorine'] = [0, 0, -0.058, -0.074, '#scared', '#disgusting', -0.044, 'lifeguard', 'swimmer', 'still_water', 'large_body', 'shallow_water']
senticnet['chlorobenzene'] = [0.843, -0.958, 0, 0.648, '#joyful', '#surprising', 0.816, 'medium', 'acetone', 'propanone', 'dimethyl_ketone', 'dissolvent']
senticnet['chocolate'] = [0.088, -0.081, 0, 0, '#joyful', '#surprising', 0.056, 'ice_cream', 'biscuit', 'candy', 'pudding', 'bagel']
senticnet['chocolate_bar'] = [0.077, -0.11, 0.031, -0.049, '#joyful', '#surprising', 0.036, 'unhealthy_food', 'carton_milk', 'candy', 'pumpkin_pie', 'leftover']
senticnet['chocolate_biscuit'] = [0.547, -0.961, 0, 0.89, '#surprising', '#admirable', 0.799, 'pudding', 'ice_cream', 'chocolate', 'chocolate_pudding', 'chocolate_dessert']
senticnet['chocolate_dessert'] = [0.081, -0.089, 0, 0, '#joyful', '#surprising', 0.057, 'chocolate', 'pumpkin_pie', 'candy', 'pudding', 'ice_cream']
senticnet['chocolate_pudding'] = [0.081, -0.089, 0, 0, '#joyful', '#surprising', 0.057, 'pudding', 'ice_cream', 'chocolate', 'chocolate_biscuit', 'chocolate_dessert']
senticnet['chocolate_treat'] = [0.136, -0.112, 0, 0, '#joyful', '#surprising', 0.083, 'chocolate_dessert', 'chocolate', 'candy', 'pudding', 'pumpkin_pie']
senticnet['choice'] = [0, 0.35, -0.095, 0.31, '#interesting', '#admirable', 0.188, 'decision', 'conclude', 'explanation', 'reason', 'think_process']
senticnet['choiceness'] = [0.757, -0.827, 0, 0.982, '#surprising', '#admirable', 0.855, 'first_class', 'superiority', 'first_water', 'fineness', 'quality']
senticnet['choir'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'sing', 'music_studio', 'music_room', 'symphony_orchestra', 'symphony']
senticnet['choir_orchestra'] = [0.445, 0.37, -0.142, 0.483, '#joyful', '#admirable', 0.385, 'sing', 'instruments', 'music_room', 'symphony', 'choir']
senticnet['choir_stall'] = [0.024, 0.211, 0, 0.209, '#interesting', '#admirable', 0.148, 'pulpit', 'rastafarian', 'fundamentalist', 'pew', 'altar']
senticnet['choke'] = [-0.105, -0.042, -0.057, -0.15, '#sad', '#disgusting', -0.09, 'acid_indigestion', 'get_full', 'burp', 'indigestion', 'become_full']
senticnet['choke_death'] = [-0.074, -0.008, -0.145, -0.2, '#scared', '#disgusting', -0.137, 'stomach_ache', 'indigestion', 'get_sick', 'sick', 'embarrassment']
senticnet['choke_food'] = [-0.082, 0, 0, -0.072, '#sad', '#disgusting', -0.051, 'drink_tea', 'suck', 'spill_food_clothes', 'open_close_mouth', 'wind_watch']
senticnet['choker'] = [-0.628, 0, 0.94, -0.998, '#angry', '#disgusting', -0.855, 'poisoner', 'slayer', 'mortal', 'executioner', 'public_executioner']
senticnet['cholecystokinin'] = [0.685, -0.898, 0, 0.765, '#surprising', '#admirable', 0.783, 'motilin', 'gastrin', 'gastrointestinal_hormone', 'secretin', 'ghrelin']
senticnet['choler'] = [-0.161, 0.179, 0.568, -0.612, '#angry', '#disgusting', -0.387, 'angrily', 'ire', 'see_red', 'dander', 'hackles']
senticnet['choleric'] = [-0.124, 0.13, 0.646, -0.64, '#angry', '#disgusting', -0.427, 'irascibility', 'quick_temper', 'short_temper', 'irascible', 'ill_temper']
senticnet['cholesterol'] = [0.074, 0, -0.065, 0.107, '#joyful', '#admirable', 0.039, 'frustrate_person', 'round_white', 'baby_chicken', 'inside_egg', 'oval_shape']
senticnet['chondroma'] = [-0.704, 0, 0.639, -0.56, '#sad', '#angry', -0.634, 'fibroma', 'adenoma', 'benign_tumor', 'enbenign_tumor', 'myoma']
senticnet['choose'] = [-0.04, 0.339, -0.134, 0.252, '#interesting', '#admirable', 0.139, 'decide', 'select', 'selection', 'decision', 'make_choice']
senticnet['choose_book'] = [0.746, 0.796, 0, 0, '#joyful', '#interesting', 0.514, 'book_library', 'find_book', 'hold_book', 'ability_read', 'good_book']
senticnet['choose_color'] = [0, -0.727, 0, 0.969, '#surprising', '#admirable', 0.565, 'squeeze', 'charge_credit_card', 'sit_toilet', 'ship_goods', 'group_object']
senticnet['choose_destination'] = [-0.083, 0, 0.032, 0, '#sad', '#angry', -0.038, 'good_shoes', 'decide_want_go', 'decide_to_go_first', 'talk_to_travel_agent', 'decide_to_go']
senticnet['choose_eat'] = [-0.032, -0.004, 0.043, -0.076, '#angry', '#disgusting', -0.049, 'decide_eat', 'fix_breakfast', 'prepare_breakfast', 'piece_of_meat', 'sell_vegetable']
senticnet['choose_game'] = [0, 0.086, -0.06, 0.134, '#interesting', '#admirable', 0.053, 'find_partner', 'win_hand', 'shake_hand', 'shuffle_card', 'know_other']
senticnet['choose_option'] = [0, 0.142, 0, 0.125, '#interesting', '#admirable', 0.089, 'change_direction', 'rotate', 'turn_around', 'turn', 'politician']
senticnet['choose_seat'] = [-0.04, -0.082, 0.092, -0.254, '#angry', '#disgusting', -0.101, 'change_opinion', 'fall_asleep', 'drink_cup_tea', 'learn_new_idea', 'look_picture']
senticnet['choose_subject'] = [-0.071, 0, 0.02, -0.093, '#sad', '#disgusting', -0.061, 'review_material', 'knowledge_subject', 'revise', 'study_material', 'go_college']
senticnet['choose_topic'] = [0.917, 0.711, 0, 0, '#joyful', '#interesting', 0.543, 'speak_up', 'use_language', 'think_first', 'know_talk', 'think_say']
senticnet['choose_victim'] = [0, 0, 0.905, -0.783, '#angry', '#disgusting', -0.563, 'murder_weapon', 'alibi', 'shoot_person', 'hide_evidence', 'shoot_target']
senticnet['chop'] = [-0.045, -0.031, 0, -0.061, '#sad', '#disgusting', -0.025, 'cut_wood', 'cut', 'slit', 'cover_wound', 'split']
senticnet['chop_down_tree'] = [-0.889, 0, 0.778, -0.794, '#sad', '#disgusting', -0.82, 'climb_mountain', 'skate', 'prune_tree', 'ski', 'jump_out_of_window']
senticnet['chop_onion'] = [-0.059, 0, -0.071, 0, '#sad', '#scared', -0.043, 'cry', 'sad_movie', 'watch_sad_film', 'see_sad_show', 'see_sad_movie']
senticnet['chop_tree'] = [-0.039, -0.031, 0.026, -0.068, '#sad', '#disgusting', -0.034, 'cut_tree', 'cut_wood', 'cut_lumber', 'timber', 'cellulose']
senticnet['chop_vegetable'] = [-0.068, -0.01, 0, -0.078, '#sad', '#disgusting', -0.045, 'stir_pot', 'brown_hamburger', 'prepare_breakfast', 'open_package', 'cut_food']
senticnet['chop_wood'] = [0, 0, 0.804, -0.716, '#angry', '#disgusting', -0.507, 'lacerate', 'word_frequently_misspell', 'slash', 'cut', 'cover_wound']
senticnet['chopstick'] = [0.77, 0, 0, 0.967, '#joyful', '#admirable', 0.579, 'good_meal', 'hot_table', 'special', 'plate_silverware', 'chef_special']
senticnet['choral'] = [0.023, 0.303, -0.087, 0.261, '#interesting', '#admirable', 0.167, 'high_school_band', 'drum_set', 'band', 'string_quartet', 'school_band']
senticnet['chord'] = [0.056, -0.019, 0.036, 0.073, '#joyful', '#admirable', 0.037, 'song', 'musical_note', 'amplifier', 'music_note', 'lyrics']
senticnet['chore'] = [-0.05, 0.197, -0.119, 0.184, '#interesting', '#admirable', 0.071, 'question_ask', 'office_job', 'task', 'obligation', 'day_job']
senticnet['chorus'] = [0.023, 0.303, -0.087, 0.261, '#interesting', '#admirable', 0.167, 'school_choral', 'drum_set', 'choral', 'string_quartet', 'band']
senticnet['chow'] = [0.061, 0, 0, 0.052, '#joyful', '#admirable', 0.038, 'noodle', 'result_cook', 'biscuit', 'nutrient', 'cream']
senticnet['chowder'] = [-0.024, -0.022, 0.064, -0.071, '#angry', '#disgusting', -0.046, 'ocean_water', 'fillet_fish', 'fillet', 'port', 'underwater']
senticnet['christ'] = [0, 0, 0, 0.984, '#admirable', '#admirable', 0.328, 'spiritual', 'religious_purpose', 'prayer', 'religious', 'faith']
senticnet['christian'] = [0.023, 0.303, -0.087, 0.261, '#interesting', '#admirable', 0.167, 'church_head', 'protestant', 'preacher', 'pastor', 'holy_man']
senticnet['christian_fundamentalist'] = [0, 0, 0.938, -0.803, '#angry', '#disgusting', -0.58, 'fundamentalist', 'christian', 'religion', 'pope', 'crusade']
senticnet['christianity'] = [0, 0.245, 0.017, 0.244, '#interesting', '#admirable', 0.157, 'catholic_church', 'judaism', 'chapel', 'church', 'confessional']
senticnet['christmas'] = [0.855, 0, 0, 0, '#joyful', '#joyful', 0.285, 'birthday', 'occasion', 'holiday', 'new_baby', 'celebrate_anniversary']
senticnet['christmas_gift'] = [0.088, -0.099, -0.07, 0.141, '#surprising', '#admirable', 0.086, 'play_device', 'play_object', 'plaything', 'child_plaything', 'kid_game']
senticnet['christmas_holiday'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'christmas_tree', 'christmas_gift', 'family_time', 'family_gathering', 'christmas']
senticnet['christmas_present'] = [0.087, -0.28, -0.098, 0.108, '#surprising', '#admirable', 0.126, 'anniversary_gift', 'play_device', 'christmas_gift', 'make_child_laugh', 'stuff_animal']
senticnet['christmas_shop'] = [0, -0.813, 0, 0.967, '#surprising', '#admirable', 0.593, 'buy_present', 'holiday_shop', 'buy_christmas_present', 'christmas_present', 'buy_product']
senticnet['christmas_song'] = [0.758, 0.856, 0, 0, '#joyful', '#interesting', 0.538, 'hymn', 'chant', 'proper_name', 'melodic_noise', 'common_language']
senticnet['christmas_stock'] = [0, -0.023, 0, 0.07, '#surprising', '#admirable', 0.031, 'pastry', 'bakery', 'breadbox', 'sundae', 'freezer']
senticnet['christmas_time'] = [0.976, 0, 0, 0, '#joyful', '#joyful', 0.325, 'happy_occasion', 'happy_event', 'gala', 'special_occasion', 'birthday_party']
senticnet['christmas_tree'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'tree', 'evergreen_tree', 'big_tree', 'tree_item', 'christmas']
senticnet['christmas_tree_item'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'christmas_tree', 'jingles', 'star', 'tree', 'socks']
senticnet['chromatography'] = [0.838, -0.618, 0, 0.556, '#joyful', '#surprising', 0.671, 'activity', 'natural_process', 'natural_action', 'column_chromatography', 'paper_chromatography']
senticnet['chrome'] = [0.02, 0.085, -0.056, 0.085, '#interesting', '#admirable', 0.045, 'gold', 'silver', 'medal', 'carat', 'medallion']
senticnet['chromosomal_aberration'] = [-0.859, 0, 0.936, -0.807, '#sad', '#angry', -0.867, 'abnormalcy', 'abnormality', 'deflection', 'warp', 'aberrance']
senticnet['chronic_bronchitis'] = [-0.788, 0, 0.993, -0.654, '#sad', '#angry', -0.812, 'bronchiolitis', 'bronchitis', 'respiratory_disease', 'respiratory_illness', 'respiratory_disorder']
senticnet['chronic_gastritis'] = [-0.959, 0, 0.729, -0.989, '#sad', '#disgusting', -0.892, 'gastritis', 'rubor', 'redness', 'acute_gastritis', 'inflammation']
senticnet['chronic_kidney_failure'] = [-0.603, 0, 0.544, -0.539, '#sad', '#angry', -0.562, 'acute_renal_failure', 'acute_kidney_failure', 'chronic_renal_failure', 'kidney_failure', 'nephrosis']
senticnet['chronic_malaria'] = [-0.98, 0, 0.355, -0.93, '#sad', '#disgusting', -0.755, 'malaria', 'sick', 'sickness', 'ill', 'need_cure']
senticnet['chronic_renal_failure'] = [-0.603, 0, 0.544, -0.539, '#sad', '#angry', -0.562, 'acute_renal_failure', 'acute_kidney_failure', 'kidney_failure', 'chronic_kidney_failure', 'nephrosis']
senticnet['chuck_out'] = [-0.711, 0, 0.954, -0.563, '#sad', '#angry', -0.743, 'eject', 'evict', 'exclude', 'turf_out', 'boot_out']
senticnet['chuckle'] = [0.936, 0, 0, 0.942, '#joyful', '#admirable', 0.626, 'giggle', 'make_fun', 'make_others_laugh', 'hear_joke', 'laughter']
senticnet['church'] = [0, 0.213, 0.034, 0.202, '#interesting', '#admirable', 0.127, 'confession', 'cathedral', 'catholic_church', 'temple', 'chapel']
senticnet['church_build'] = [0, 0.183, 0.047, 0.25, '#interesting', '#admirable', 0.129, 'church_part', 'worship_house', 'religious_build', 'worship_place', 'holy_place']
senticnet['church_head'] = [0.029, 0.262, 0, 0.237, '#interesting', '#admirable', 0.176, 'protestant', 'pastor', 'religious_official', 'christian', 'monk']
senticnet['church_leader'] = [0, 0.181, 0.038, 0.161, '#interesting', '#admirable', 0.101, 'church_head', 'pastor', 'religious_official', 'cleric', 'religious_leader']
senticnet['church_official'] = [0.03, 0.153, 0, 0.14, '#interesting', '#admirable', 0.108, 'clergyman', 'religious_man', 'religious_leader', 'cleric', 'religious_official']
senticnet['church_part'] = [0, 0.215, 0.046, 0.228, '#interesting', '#admirable', 0.132, 'worship_house', 'worship_place', 'religious_build', 'catholic_church', 'holy_place']
senticnet['church_person'] = [0, 0.225, 0, 0.183, '#interesting', '#admirable', 0.136, 'church_head', 'protestant', 'pastor', 'evangelist', 'religious_official']
senticnet['church_service'] = [0.032, 0.255, 0, 0.28, '#interesting', '#admirable', 0.189, 'religious_service', 'religious_ceremony', 'catholic', 'religious', 'religious_purpose']
senticnet['churl'] = [-0.834, 0, 0.614, -0.769, '#sad', '#disgusting', -0.739, 'grouch', 'grump', 'crosspatch', 'crabby_person', 'crank']
senticnet['churn_up'] = [-0.075, 0.142, 0.685, -0.668, '#angry', '#disgusting', -0.429, 'loathsome', 'gross_out', 'sicken', 'nauseate', 'repel']
senticnet['churr'] = [0.691, -0.973, 0, 0.771, '#surprising', '#admirable', 0.812, 'squeal', 'blate', 'let_loose', 'honk', 'sibilate']
senticnet['chute'] = [-0.9, 0, 0.749, -0.719, '#sad', '#angry', -0.789, 'gutter', 'slide', 'slideway', 'sloping_trough', 'cullis']
senticnet['chutzpah'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'rudeness', 'discourtesy', 'insolence', 'cheekiness', 'hutzpah']
senticnet['chutzpanik'] = [-0.953, 0, 0.581, -0.579, '#sad', '#angry', -0.704, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['cider'] = [0.079, -0.024, 0.023, 0, '#joyful', '#surprising', 0.027, 'wine', 'lemonade', 'juice', 'whisky', 'soft_drink']
senticnet['cigar'] = [-0.999, 0, 0.056, -0.982, '#sad', '#disgusting', -0.679, 'smoke', 'bad_airette', 'tobacco', 'pollution', 'bad_air']
senticnet['cigar_band'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'adornment', 'stripe', 'hatband', 'neckband', 'pinstripe']
senticnet['cigarette'] = [0.057, -0.008, -0.087, -0.1, '#scared', '#disgusting', -0.041, 'cigar', 'smoke_pipe', 'cigarette_smoke', 'wash_mouth_soap', 'tobacco']
senticnet['cigarette_lighter'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'rub_two_stick_together', 'strike_match', 'light_cigarette', 'light_match', 'magnify_glass']
senticnet['cigarette_smoke'] = [0.047, 0, -0.102, -0.06, '#scared', '#disgusting', -0.038, 'smoke', 'tobacco_product', 'smoke_tobacco', 'lung_cancer', 'cigar']
senticnet['cinch'] = [0.746, -0.678, 0, 0.529, '#joyful', '#surprising', 0.651, 'labor', 'doddle', 'undertaking', 'project', 'task']
senticnet['cincture'] = [-0.534, 0, 0.682, -0.748, '#angry', '#disgusting', -0.655, 'girdle', 'cummerbund', 'sash', 'waistband', 'waistcloth']
senticnet['cinder'] = [0.024, 0, -0.095, -0.031, '#scared', '#disgusting', -0.034, 'fire', 'huge_fire', 'flame', 'rapid_oxidation', 'heat_light']
senticnet['cinderella'] = [-0.065, 0.068, -0.123, -0.163, '#scared', '#disgusting', -0.094, 'go_home_early', 'rule', 'restriction', 'curfew', 'limitation']
senticnet['cinema'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'movie_house', 'movie_theater', 'movie', 'drive-in_movie', 'theater']
senticnet['cinema_verite'] = [-0.859, 0, 0.514, -0.739, '#sad', '#disgusting', -0.704, 'flick', 'movie', 'film', 'picture', 'moving_picture']
senticnet['cinquefoil'] = [0.969, -0.686, 0, 0.756, '#joyful', '#admirable', 0.804, 'vermiculation', 'carving', 'glyptic_art', 'glyptography', 'scrimshaw']
senticnet['cipher'] = [-0.529, 0, 0.821, -0.651, '#angry', '#disgusting', -0.667, 'work_out', 'reckon', 'calculate', 'average_out', 'cypher']
senticnet['circle'] = [0, -0.897, 0, 0.75, '#surprising', '#admirable', 0.549, 'round', 'round_shape', 'circular_shape', 'circular', 'no_corner']
senticnet['circle_part'] = [0.088, 0.148, 0.047, 0.103, '#interesting', '#admirable', 0.097, 'heat_measure', 'temperature_measure', 'celsius', 'measure_heat', 'temperature_measurement']
senticnet['circle_prey'] = [0, 0, 0.768, -0.86, '#angry', '#disgusting', -0.543, 'corner_prey', 'hunt_food', 'kill_man', 'scare_person', 'kill']
senticnet['circle_shape'] = [0, -0.741, 0, 0.883, '#surprising', '#admirable', 0.541, 'ball_shape', 'round_shape', 'orange', 'cornerless', 'orb']
senticnet['circuit'] = [0, -0.781, 0, 0.914, '#surprising', '#admirable', 0.565, 'electrical_connection', 'electricity', 'board', 'glue', 'connection']
senticnet['circular'] = [0, 0.706, 0, 0.986, '#interesting', '#admirable', 0.564, 'round', 'circular_shape', 'circle_shape', 'circle', 'no_corner']
senticnet['circular_motion'] = [0.024, 0.095, -0.054, 0.291, '#interesting', '#admirable', 0.119, 'rotate_movement', 'rotate', 'go_around', 'manoeuvre', 'full_circle']
senticnet['circular_object'] = [0, -0.871, 0, 0.972, '#surprising', '#admirable', 0.614, 'round_object', 'spherical_shape', 'circle_shape', 'use_sport', 'bouncy']
senticnet['circular_route'] = [0.051, 0.162, 0.026, 0, '#joyful', '#interesting', 0.062, 'row_house', 'human_hair', 'semi-truck', 'expressway', 'park_structure']
senticnet['circular_shape'] = [0, -0.843, 0, 0.96, '#surprising', '#admirable', 0.601, 'no_corner', 'circle_shape', 'round_shape', 'circular', 'no_edge']
senticnet['circularize'] = [0.517, -0.672, 0, 0.549, '#surprising', '#admirable', 0.579, 'send_around', 'circulate', 'pass_around', 'pass_on', 'distribute']
senticnet['circulate'] = [0.517, -0.672, 0, 0.549, '#surprising', '#admirable', 0.579, 'circularize', 'send_around', 'pass_around', 'pass_on', 'distribute']
senticnet['circulate_air'] = [0.305, 0.195, 0, 0.129, '#joyful', '#interesting', 0.21, 'cool_room', 'blow_air', 'cool_car_engine', 'cool_off', 'move_air']
senticnet['circulate_blood'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'exercise', 'massage', 'sex', 'blood', 'circulation']
senticnet['circulating_blood'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'keep_alive', 'body_system', 'body_working', 'blood_pressure', 'heart']
senticnet['circulation'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'exercise', 'massage', 'sex', 'blood', 'circulate_blood']
senticnet['circumlocution'] = [-0.89, 0, 0.669, -0.766, '#sad', '#disgusting', -0.775, 'deceit', 'deception', 'misrepresentation', 'indirect_expression', 'equivocation']
senticnet['circumspect'] = [0.625, -0.88, 0, 0.782, '#surprising', '#admirable', 0.762, 'judicious', 'discreet', 'prudential', 'heady', 'prudent']
senticnet['circumspection'] = [-0.805, 0, 0.65, -0.986, '#sad', '#disgusting', -0.814, 'discernment', 'sagacity', 'sagaciousness', 'confidentiality', 'judgment']
senticnet['circumstance'] = [0.723, 0, 0, 0.909, '#joyful', '#admirable', 0.544, 'phenomenon', 'criterion', 'prediction', 'reciprocal', 'weather_prediction']
senticnet['circumstances'] = [0.981, -0.993, 0, 0.934, '#joyful', '#surprising', 0.969, 'luckiness', 'good_fortune', 'good_luck', 'failure', 'tough_luck']
senticnet['circumvent'] = [0, 0, -0.719, -0.783, '#scared', '#disgusting', -0.501, 'beleaguer', 'besiege', 'outwit', 'surround', 'hem_in']
senticnet['circus'] = [0.954, 0, 0, 0, '#joyful', '#joyful', 0.318, 'clown', 'halloween', 'entertainment', 'fun', 'happiness']
senticnet['circus_act'] = [0.106, -0.018, 0, 0, '#joyful', '#surprising', 0.041, 'western', 'sumo', 'rodeo', 'grand_canyon', 'have_fun']
senticnet['circus_performer'] = [0, 0, 0, 0.987, '#admirable', '#admirable', 0.329, 'emote', 'bold', 'form_of_social_interaction', 'act', 'stage_play']
senticnet['cissy'] = [-0.63, 0, 0.986, -0.946, '#angry', '#disgusting', -0.854, 'womanish', 'effeminate', 'emasculate', 'unmanful', 'sissified']
senticnet['citation'] = [0.878, 0, 0, 0.856, '#joyful', '#admirable', 0.578, 'suspicion', 'effect', 'cite', 'demand', 'permit']
senticnet['cite'] = [0, -0.859, 0, 0.943, '#surprising', '#admirable', 0.601, 'suspicion', 'effect', 'citation', 'demand', 'permit']
senticnet['citizen'] = [0, 0.713, 0, 0.761, '#interesting', '#admirable', 0.491, 'feudalism', 'nation', 'capitol', 'capital', 'democracy']
senticnet['citizens_committee'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'denomination', 'committee', 'ngo', 'mission', 'missionary_post']
senticnet['citizien'] = [0, 0.754, 0, 0.804, '#interesting', '#admirable', 0.519, 'tenant', 'ceiling_fan', 'resident', 'stair_rail', 'roommate']
senticnet['citrus'] = [0, 0.903, 0, 0.932, '#interesting', '#admirable', 0.612, 'citrus_fruit', 'orange_fruit', 'orange_color', 'hair_color', 'fruits']
senticnet['citrus_fruit'] = [0.106, -0.018, 0, 0, '#joyful', '#surprising', 0.041, 'citrus', 'orange_fruit', 'orange_color', 'fruits', 'healthy']
senticnet['city'] = [0, 0, 0, 0.104, '#admirable', '#admirable', 0.035, 'downtown', 'govern_city', 'large_town', 'govern', 'small_govern_city']
senticnet['city_area'] = [0, -0.898, 0, 0.801, '#surprising', '#admirable', 0.566, 'govern_city', 'large_town', 'city_life', 'large_building', 'downtown']
senticnet['city_block'] = [0.106, -0.018, 0, 0, '#joyful', '#surprising', 0.041, 'street_corner', 'corner_two_streets', 'city_street', 'city_road', 'junk_yard']
senticnet['city_center'] = [-0.033, 0.099, 0.017, 0.102, '#interesting', '#admirable', 0.05, 'every_town', 'downtown', 'monument', 'cathedral', 'town_center']
senticnet['city_country'] = [0.02, 0, 0, 0.081, '#joyful', '#admirable', 0.034, 'grocery_store', 'supermarket', 'fast_food', 'restaurant', 'retail_store']
senticnet['city_hall'] = [0.025, 0.136, 0, 0, '#joyful', '#interesting', 0.054, 'town_hall', 'courthouse', 'subway_station', 'public_place', 'bus_station']
senticnet['city_life'] = [0, -0.704, 0, 0.866, '#surprising', '#admirable', 0.523, 'govern_city', 'large_town', 'city_area', 'large_building', 'downtown']
senticnet['city_park'] = [0.048, 0.077, 0, -0.031, '#joyful', '#interesting', 0.031, 'soccer_field', 'outhouse', 'memorial', 'baseball_field', 'garden']
senticnet['city_road'] = [0.048, 0.077, 0, -0.031, '#joyful', '#interesting', 0.031, 'street_corner', 'corner_two_streets', 'city_block', 'city_street', 'junk_yard']
senticnet['city_street'] = [0, 0, 0.021, -0.056, '#angry', '#disgusting', -0.026, 'street_corner', 'corner_two_streets', 'city_block', 'city_road', 'junk_yard']
senticnet['civic_center'] = [0.048, 0.077, 0, -0.031, '#joyful', '#interesting', 0.031, 'house', 'city_center', 'city_street', 'city_block', 'city_park']
senticnet['civil_action'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'antitrust_case', 'action_at_law', 'counterclaim', 'custody_case', 'lis_pendens']
senticnet['civil_disobedience'] = [-0.903, 0, 0.771, -0.995, '#sad', '#disgusting', -0.89, 'fight', 'battle', 'war', 'protest', 'attack']
senticnet['civil_libertarian'] = [0.677, -0.529, 0, 0.714, '#joyful', '#admirable', 0.64, 'economic_libertarian', 'libertarian', 'advocate', 'advocator', 'proponent']
senticnet['civil_war'] = [-0.991, 0, 0.738, -0.947, '#sad', '#disgusting', -0.892, 'war', 'battle', 'soldier', 'fight', 'weapon']
senticnet['civility'] = [0, 0.128, -0.049, 0.064, '#interesting', '#admirable', 0.048, 'line_up', 'find_end_line', 'come_early', 'find_line', 'wait_patiently']
senticnet['civilization'] = [0, 0.08, 0, 0.117, '#interesting', '#admirable', 0.066, 'stand_still', 'go_home', 'pull_out', 'stretch_out', 'advance_civilization']
senticnet['clad'] = [-0.533, 0, 0.937, -0.802, '#angry', '#disgusting', -0.757, 'gowned', 'petticoated', 'surpliced', 'arrayed', 'caparisoned']
senticnet['cladding'] = [0.937, -0.799, 0, 0.634, '#joyful', '#surprising', 0.79, 'protective_cover', 'protective_covering', 'protection', 'revetment', 'cover']
senticnet['clade'] = [-0.96, 0, 0.556, -0.872, '#sad', '#disgusting', -0.796, 'animal_group', 'group', 'genotype', 'biological_group', 'taxonomic_group']
senticnet['claim'] = [0, 0.25, -0.227, 0.281, '#interesting', '#admirable', 0.101, 'possess', 'ask', 'heap', 'have', 'belong']
senticnet['clairvoyance'] = [0, 0.25, -0.227, 0.281, '#interesting', '#admirable', 0.101, 'psychic_phenomenon', 'predict_future', 'parapsychology', 'precognition', 'foreknowledge']
senticnet['clam'] = [0, 0.158, -0.123, 0.359, '#interesting', '#admirable', 0.131, 'statement', 'affirmation', 'proexclamationation', 'exclamation', 'proposition']
senticnet['clamor'] = [0, 0, 0.958, -0.852, '#angry', '#disgusting', -0.603, 'noise', 'clang', 'squeak', 'roar', 'loud_noise']
senticnet['clamp'] = [0, 0, 0.717, -0.859, '#angry', '#disgusting', -0.525, 'nut_bolt', 'power_drill', 'wrench', 'c_clamp', 'tool']
senticnet['clamp_binder'] = [0, 0, 0.999, -1.0, '#angry', '#disgusting', -0.666, 'stapler', 'fastener_binder', 'ball_point_pen', 'pencil_sharpener', 'white-out']
senticnet['clamp_down'] = [-0.519, 0, 0.946, -0.995, '#angry', '#disgusting', -0.82, 'trammel', 'limit', 'restrict', 'bound', 'confine']
senticnet['clan'] = [0.092, 0.14, -0.098, 0.128, '#interesting', '#admirable', 0.087, 'a_little_specific', 'happy_together', 'many_people', 'aunt_uncle', 'human_group']
senticnet['clandestine'] = [0, 0, -0.806, -0.738, '#scared', '#disgusting', -0.515, 'secret', 'hush-hush', 'hugger-mugger', 'cloak-and-dagger', 'hole-and-corner']
senticnet['clang'] = [0.056, -0.021, 0, 0.066, '#joyful', '#admirable', 0.048, 'clamor', 'noise', 'roar', 'squeak', 'sound']
senticnet['clannishness'] = [-0.948, 0, 0.687, -0.75, '#sad', '#disgusting', -0.795, 'snobbery', 'cliquishness', 'exclusiveness', 'arrogance', 'haughtiness']
senticnet['clap'] = [0.787, 0.762, 0, 0, '#joyful', '#interesting', 0.516, 'tear_eye', 'applaud', 'emotional_reaction', 'hurt_ear', 'giggle']
senticnet['clapping'] = [0.857, -0.773, 0, 0.878, '#joyful', '#admirable', 0.836, 'hand', 'round', 'approval', 'commendation', 'handclap']
senticnet['claptrap'] = [-0.544, 0, 0.7, -0.64, '#angry', '#disgusting', -0.628, 'flourish', 'rant', 'bombast', 'fustian', 'ornateness']
senticnet['claret'] = [0.59, -0.866, 0, 0.561, '#joyful', '#surprising', 0.672, 'dark_red', 'wine', 'oxblood_red', 'red', 'redness']
senticnet['clarification'] = [-0.125, 0, 0, -0.061, '#sad', '#disgusting', -0.062, 'understand', 'teach_others', 'trivia', 'tell_other_person', 'seek_understanding']
senticnet['clarify'] = [-0.092, 0.18, -0.046, 0.141, '#interesting', '#admirable', 0.061, 'acknowledge', 'explanation', 'solution', 'get_answer', 'make_sense']
senticnet['clarity'] = [0.833, 0.927, 0, 0, '#joyful', '#interesting', 0.587, 'no_color', 'transparency', 'sunny_weather', 'intelligent', 'water_color']
senticnet['clash'] = [-0.053, -0.037, -0.076, -0.241, '#scared', '#disgusting', -0.111, 'struggle', 'fight', 'quarrel', 'debate', 'combat']
senticnet['clash_together'] = [-0.995, 0, 0.27, -0.98, '#sad', '#disgusting', -0.748, 'weep', 'cry', 'sob', 'clash', 'tear']
senticnet['clasp'] = [0, 0.084, 0, 0, '#interesting', '#interesting', 0.028, 'pin', 'drill_bite', 'without_space', 'clamp', 'badge']
senticnet['clasp_knife'] = [-0.711, 0, 0.954, -0.563, '#sad', '#angry', -0.743, 'jackknife', 'pocket_knife', 'penknife', 'switchblade', 'switchblade_knife']
senticnet['class'] = [-0.078, 0, 0, 0, '#sad', '#sad', -0.026, 'take_music_lesson', 'take_lesson', 'learn_read_music', 'find_teacher', 'look_up_word_in_dictionary']
senticnet['class_act'] = [0.77, -0.922, 0, 0.535, '#joyful', '#surprising', 0.742, 'nonesuch', 'nonsuch', 'ideal', 'nonpareil', 'apotheosis']
senticnet['class_action'] = [-0.033, 0.22, -0.099, 0.21, '#interesting', '#admirable', 0.099, 'petition', 'political_statement', 'require', 'go_against', 'posture']
senticnet['class_feeling'] = [0, 0, 0, -0.744, '#disgusting', '#disgusting', -0.248, 'antagonism', 'belligerently', 'hostilely', 'aggressiveness', 'envy']
senticnet['class_lesson'] = [0.677, -0.529, 0, 0.714, '#joyful', '#admirable', 0.64, 'team_work', 'student', 'college_course', 'university', 'group_student']
senticnet['classes'] = [0.061, -0.049, 0, 0, '#joyful', '#surprising', 0.037, 'education', 'teach_to_read', 'study', 'teach_school', 'find_school']
senticnet['classic'] = [-0.052, -0.197, -0.179, 0.219, '#surprising', '#admirable', 0.062, 'book_genre', 'novel', 'long_story', 'fiction', 'literature']
senticnet['classical'] = [0.136, -0.119, 0.031, 0, '#joyful', '#surprising', 0.075, 'rap', 'popular_music', 'music', 'band_play', 'rock_roll']
senticnet['classical_music'] = [0.802, 0, 0, 0, '#joyful', '#joyful', 0.267, 'tune', 'melody', 'harmony', 'type_of_music', 'lyric']
senticnet['classifiable'] = [0.935, -0.958, 0, 0.949, '#surprising', '#admirable', 0.947, 'acknowledgeable', 'specifiable', 'recognizable', 'diagnosable', 'identifiable']
senticnet['classification'] = [0.028, 0.117, 0.024, 0.078, '#interesting', '#admirable', 0.066, 'military_group', 'status', 'placement', 'rank', 'nobleman']
senticnet['classify'] = [-0.076, 0.331, -0.111, 0.275, '#interesting', '#admirable', 0.14, 'intend', 'let', 'right', 'determine', 'selection']
senticnet['classify_ad'] = [0, -0.083, -0.054, 0.099, '#surprising', '#admirable', 0.043, 'phone_book', 'side_build', 'city_center', 'letter_alphabet', 'ads']
senticnet['classroom_chair'] = [0, 0, 0.763, -0.775, '#angry', '#disgusting', -0.513, 'text_book', 'exam_table', 'lead_pencil', 'eraser_holder', 'pencil_sharpener']
senticnet['classy'] = [0, -0.895, 0, 0.743, '#surprising', '#admirable', 0.546, 'elegant', 'use_binoculars', 'sophisticated', 'pretty', 'female_person']
senticnet['clause'] = [-0.044, 0.183, -0.168, 0.33, '#interesting', '#admirable', 0.1, 'question_starter', 'inquiry', 'question_start', 'question', 'ask']
senticnet['claustrophobe'] = [-0.707, 0, 0.624, -0.653, '#sad', '#disgusting', -0.661, 'sick_person', 'diseased_person', 'sufferer', 'mental_case', 'hysteric']
senticnet['claver'] = [0.882, -0.678, 0, 0.769, '#joyful', '#admirable', 0.776, 'schmooze', 'schmoose', 'shmooze', 'shmoose', 'jawbone']
senticnet['clavichord'] = [0.033, 0, 0.009, 0.057, '#joyful', '#admirable', 0.027, 'triangle', 'baton', 'bugle', 'type_of_bow', 'horn']
senticnet['claw'] = [0, -0.036, 0.08, -0.057, '#angry', '#disgusting', -0.034, 'tic', 'whisker', 'paw', 'fur_keep_warm', 'worm_intestine']
senticnet['claws'] = [0, -0.01, 0.041, -0.065, '#angry', '#disgusting', -0.032, 'animal_part', 'paw', 'long_tail', 'sharp_tooth', 'fang']
senticnet['claymore'] = [0.93, -0.78, 0, 0.873, '#joyful', '#admirable', 0.861, 'blade', 'brand', 'steel', 'broadsword', 'sword']
senticnet['clean'] = [0.986, 0, 0, 0, '#joyful', '#joyful', 0.329, 'personal_cleanliness', 'cleanness', 'wipe_up_spill', 'smell_good', 'clean_carpet']
senticnet['clean_agent'] = [0, -0.814, 0, 0.997, '#surprising', '#admirable', 0.604, 'hand_wash', 'hygiene', 'cleanser', 'body_care', 'foam']
senticnet['clean_air'] = [0.85, 0, 0, 0, '#joyful', '#joyful', 0.283, 'eat_fruit', 'accomplish_goal', 'healthy_environment', 'nice_place_to_live', 'calm_mind']
senticnet['clean_apartment'] = [0.714, 0, 0, 0, '#joyful', '#joyful', 0.238, 'call_up', 'kill_spider', 'clean_sink', 'clean_floor', 'tidy_up']
senticnet['clean_bathroom'] = [0, 0, 0, -0.82, '#disgusting', '#disgusting', -0.273, 'clean_house', 'clean_carpet', 'clean', 'clean_room', 'wipe_up_spill']
senticnet['clean_between_tooth'] = [-0.051, -0.017, 0.012, -0.04, '#sad', '#disgusting', -0.029, 'remove_plaque', 'keep_tooth_clean', 'close_mouth', 'chew', 'suck']
senticnet['clean_body'] = [0.076, -0.008, 0, 0, '#joyful', '#surprising', 0.028, 'personal_hygiene', 'clean_oneself', 'remove_dirt_body', 'shower', 'feel_refreshed']
senticnet['clean_car'] = [0.952, 0, 0, 0.862, '#joyful', '#admirable', 0.605, 'clean_skin', 'run_out_soap', 'remove_dirt', 'clean_hair', 'cleanliness']
senticnet['clean_carpet'] = [0, 0.733, 0, 0.784, '#interesting', '#admirable', 0.506, 'clean_floor', 'vacuum', 'keep_house_clean', 'expect_guest', 'clean_bathroom']
senticnet['clean_cloth'] = [0.159, 0, 0.041, 0.174, '#joyful', '#admirable', 0.097, 'clean_hand', 'use_clean', 'clean_supply', 'cleanse', 'sweeper']
senticnet['clean_clothes'] = [0, 0, 0, 0.068, '#admirable', '#admirable', 0.023, 'become_clean', 'wash_clothes', 'take_shower', 'get_clean', 'clean_body']
senticnet['clean_dish'] = [0.785, 0, 0, 0.841, '#joyful', '#admirable', 0.542, 'clean_oneself', 'wash_up', 'wash_oneself', 'wash_body', 'clean_self']
senticnet['clean_fish'] = [0.029, 0, 0.042, -0.072, '#angry', '#disgusting', -0.028, 'fry_fish', 'make_coffee', 'make_ice', 'piss', 'relieve_oneself']
senticnet['clean_floor'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'cleanness', 'dust_furniture', 'sweep', 'vacuum_floor', 'clean']
senticnet['clean_hair'] = [0.986, 0, 0, 0, '#joyful', '#joyful', 0.329, 'clean_skin', 'cleanliness', 'run_out_soap', 'remove_dirt', 'clean_kitchen']
senticnet['clean_hand'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'remove_dirt', 'wash_behind_ear', 'cleanse_body', 'clean_skin', 'cleaner']
senticnet['clean_house'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'clean_bathroom', 'clean_carpet', 'clean', 'clean_room', 'wipe_up_spill']
senticnet['clean_kitchen'] = [0.986, 0, 0, 0, '#joyful', '#joyful', 0.329, 'cleanness', 'kill_germ', 'personal_cleanliness', 'clean_hair', 'clean']
senticnet['clean_lady'] = [0, 0.073, -0.083, -0.085, '#scared', '#disgusting', -0.032, 'cleaning', 'maid', 'lady', 'servant', 'staff']
senticnet['clean_laundry'] = [0, 0.133, 0, 0.206, '#interesting', '#admirable', 0.113, 'clean_clothes', 'cleanse', 'washing_machine', 'remove_dirt', 'laundry']
senticnet['clean_mess'] = [0.101, 0, 0.015, 0.063, '#joyful', '#admirable', 0.05, 'wipe_up_spill', 'kill_germ', 'clean_floor', 'clean', 'personal_cleanliness']
senticnet['clean_mouth'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'wipe', 'wipe_mouth', 'napkin', 'oral_cleaning', 'toothbrush']
senticnet['clean_object'] = [0.813, 0, 0, 0, '#joyful', '#joyful', 0.271, 'wash_body', 'wash_dog', 'lather', 'use_washcloth', 'clean_oneself']
senticnet['clean_often'] = [-0.027, 0.165, -0.08, 0.14, '#interesting', '#admirable', 0.066, 'maintenance', 'vacuum_carpet', 'use_vacuum_cleaner', 'tidy_up', 'vacuum_floor']
senticnet['clean_oneself'] = [0.076, -0.008, 0, 0, '#joyful', '#surprising', 0.028, 'personal_hygiene', 'clean_oneself_up', 'remove_dirt_body', 'clean_body', 'feel_refreshed']
senticnet['clean_oneself_up'] = [0.076, -0.008, 0, 0, '#joyful', '#surprising', 0.028, 'personal_hygiene', 'clean_oneself', 'remove_dirt_body', 'clean_body', 'feel_refreshed']
senticnet['clean_product'] = [0.078, 0, 0, 0.06, '#joyful', '#admirable', 0.046, 'clean_agent', 'cleanser', 'hand_wash', 'use_clean', 'tv_drama']
senticnet['clean_room'] = [0, 0, 0, -0.82, '#disgusting', '#disgusting', -0.273, 'clean_house', 'clean_carpet', 'clean', 'clean_bathroom', 'wipe_up_spill']
senticnet['clean_self'] = [0.785, 0, 0, 0.841, '#joyful', '#admirable', 0.542, 'clean_oneself', 'wash_up', 'wash_oneself', 'wash_body', 'bathing']
senticnet['clean_shoes'] = [0, -0.754, 0, 0.975, '#surprising', '#admirable', 0.576, 'paint_nail', 'make_pretty', 'remove_paint', 'find_home', 'sanitary']
senticnet['clean_sink'] = [0, 0, 0, -0.97, '#disgusting', '#disgusting', -0.323, 'sit_on_beach', 'pet_cat', 'absorb_moisture', 'mow_grass', 'wash_window']
senticnet['clean_skin'] = [0.025, -0.004, 0.013, 0.061, '#joyful', '#admirable', 0.026, 'run_out_soap', 'remove_dirt', 'wash_away_dirt', 'cleanse_body', 'cleanliness']
senticnet['clean_supply'] = [0.159, 0, 0.041, 0.174, '#joyful', '#admirable', 0.097, 'clean_hand', 'use_clean', 'clean_cloth', 'cleanse', 'soap']
senticnet['clean_teeth'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'teeth_whitening', 'brush_tooth', 'clean_mouth', 'after_meal', 'dentist']
senticnet['clean_toilet'] = [-0.124, -0.013, 0, -0.07, '#sad', '#disgusting', -0.06, 'clean_sink', 'dust_furniture', 'clean_floor', 'sit_on_beach', 'wash_window']
senticnet['clean_tooth'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'teeth_whitening', 'brush_tooth', 'clean_mouth', 'after_meal', 'dentist']
senticnet['clean_underwear'] = [0.998, 0, 0, 0, '#joyful', '#joyful', 0.333, 'panties', 'lingerie', 'pantyhose', 'slack', 'prescription_medication']
senticnet['clean_up'] = [0.935, 0, 0, 0, '#joyful', '#joyful', 0.312, 'clean_up_kitchen', 'feel_dirty', 'remove_stain', 'stink', 'stink_mess']
senticnet['clean_up_kitchen'] = [0.935, 0, 0, 0, '#joyful', '#joyful', 0.312, 'clean_up', 'eat_sushi', 'make_dinner', 'eat_pudding', 'enjoy_meal']
senticnet['clean_up_mess'] = [0.813, 0.832, 0, 0.874, '#interesting', '#admirable', 0.84, 'remove_stain', 'clean', 'clean_up', 'relief', 'clean_house']
senticnet['clean_water'] = [0.718, 0, 0, 0, '#joyful', '#joyful', 0.239, 'water_container', 'still_water', 'dampness', 'water', 'cool_water']
senticnet['clean_window'] = [-0.065, -0.027, 0.021, -0.06, '#sad', '#disgusting', -0.04, 'feel_dirty', 'remove_stain', 'clean_agent', 'cleanser', 'remove_dirt']
senticnet['cleaned'] = [0, 0.877, 0, 0, '#interesting', '#interesting', 0.292, 'after_shower', 'reinvigorated', 'shower', 'feel_refreshed', 'relax_time']
senticnet['cleaner'] = [0.035, 0, 0, 0.057, '#joyful', '#admirable', 0.031, 'clean_hand', 'clean_product', 'remove_dirt', 'clean_skin', 'soapy']
senticnet['cleaning'] = [0, 0.073, -0.083, -0.085, '#scared', '#disgusting', -0.032, 'clean_lady', 'maid', 'lady', 'servant', 'staff']
senticnet['cleanliness'] = [0.033, 0, 0, 0.087, '#joyful', '#admirable', 0.04, 'wash_away_dirt', 'cleanness', 'personal_cleanliness', 'run_out_soap', 'get_rid_of_dirt']
senticnet['cleanness'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'personal_cleanliness', 'cleanliness', 'clean', 'run_out_soap', 'wash_away_dirt']
senticnet['cleanse'] = [0.866, 0.855, 0, 0, '#joyful', '#interesting', 0.574, 'wash', 'lather', 'floss', 'decontaminate', 'bathe']
senticnet['cleanse_body'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'remove_dirt', 'wash_behind_ear', 'clean_hand', 'clean_skin', 'cleaner']
senticnet['cleanser'] = [0.829, 0.967, 0, 0, '#joyful', '#interesting', 0.599, 'clean_agent', 'foam', 'lather', 'wash_self', 'bubbly']
senticnet['clear'] = [0.945, -0.732, 0, 0.779, '#joyful', '#admirable', 0.819, 'bring_home_bacon', 'pan_out', 'reach', 'bring_off', 'luck_out']
senticnet['clear_air'] = [-0.501, 0, 0.817, -0.512, '#angry', '#disgusting', -0.61, 'drive_out', 'dispel', 'chase_away', 'drive_away', 'drive_off']
senticnet['clear_away'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'clean', 'abolish', 'discharge', 'remove', 'cut_out']
senticnet['clear_head'] = [0.825, 0.844, 0, 0, '#joyful', '#interesting', 0.556, 'clear_mind', 'feel_energized', 'reduce_stress', 'increase_energy', 'feel_better']
senticnet['clear_mind'] = [0, 0, 0, 0.795, '#admirable', '#admirable', 0.265, 'clear_head', 'read_good_book', 'relax_mind', 'recover_illness', 'reduce_stress']
senticnet['clear_mind_bad_thought'] = [0.84, 0.803, 0, 0.81, '#joyful', '#admirable', 0.818, 'cultural_experience', 'entertain_oneself', 'entertainment', 'pastime', 'get_entertain']
senticnet['clear_sailing'] = [0.501, -0.506, 0, 0.683, '#surprising', '#admirable', 0.563, 'forward_motion', 'onward_motion', 'progression', 'procession', 'progress']
senticnet['clear_solid'] = [0, -0.919, 0, 0.797, '#surprising', '#admirable', 0.572, 'see_thru', 'translucent', 'see_through', 'transparent', 'transparency']
senticnet['clear_table'] = [0.801, 0, 0, 0.573, '#joyful', '#admirable', 0.458, 'keep_eye_open', 'find_table', 'bend_over', 'order_menu', 'place_order']
senticnet['clear_think'] = [0, 0, 0, 0.897, '#admirable', '#admirable', 0.299, 'organize_life', 'declutter', 'neatness', 'sort', 'organizational_skill']
senticnet['clear_throat'] = [-0.046, 0, 0.032, 0, '#sad', '#angry', -0.026, 'use_voice', 'whisper', 'hear_voice', 'mouth_move', 'move_tongue']
senticnet['clear_up'] = [-0.035, 0.24, 0, 0.093, '#interesting', '#admirable', 0.099, 'organizational_skill', 'arrange', 'elect_president', 'orderly', 'decision']
senticnet['clearance'] = [-0.055, 0.228, -0.054, 0.157, '#interesting', '#admirable', 0.092, 'sale', 'charge_money', 'bargain', 'cheap_price', 'discount']
senticnet['clearcutness'] = [0.645, -0.623, 0, 0.94, '#joyful', '#admirable', 0.736, 'lucidness', 'clarity', 'clearness', 'lucidity', 'pellucidity']
senticnet['clearing'] = [-0.538, 0, 0.771, -0.696, '#angry', '#disgusting', -0.668, 'tract', 'piece_of_land', 'piece_of_ground', 'parcel_of_land', 'parcel']
senticnet['clearness'] = [0.538, -0.595, 0, 0.721, '#surprising', '#admirable', 0.618, 'clearcutness', 'explicitness', 'preciseness', 'perspicuity', 'perspicuousness']
senticnet['cleat'] = [0, -0.921, 0, 0.767, '#surprising', '#admirable', 0.563, 'propeller', 'hull', 'boat_part', 'gunwale', 'stern']
senticnet['cleavable'] = [0.998, -0.635, 0, 0.574, '#joyful', '#surprising', 0.736, 'divisible', 'dissociable', 'separable', 'severable', 'dissociative']
senticnet['cleaver'] = [-0.031, -0.021, -0.054, -0.158, '#scared', '#disgusting', -0.074, 'knife', 'hatchet', 'sword', 'razor_blade', 'scalpel']
senticnet['clematis'] = [0.518, -0.519, 0, 0.65, '#surprising', '#admirable', 0.562, 'climber', 'legume', 'leguminous_plant', 'climbing_fern', 'root_climber']
senticnet['clenched'] = [-0.956, 0, 0.159, -0.941, '#sad', '#disgusting', -0.685, 'narrow_road', 'poky', 'tight', 'narrow', 'cramped']
senticnet['cleome'] = [-0.81, 0, 0.699, -0.526, '#sad', '#angry', -0.678, 'herb', 'spider_flower', 'spider_plant', 'stinking_clover', 'herbaceous_plant']
senticnet['clergy'] = [0.039, 0.267, -0.065, 0.23, '#interesting', '#admirable', 0.157, 'priest', 'church_head', 'preacher', 'jewish', 'rabbi']
senticnet['clergyman'] = [0.03, 0.146, 0, 0.138, '#interesting', '#admirable', 0.105, 'church_official', 'religious_man', 'religious_leader', 'cleric', 'religious_figure']
senticnet['cleric'] = [0, 0.226, -0.049, 0.205, '#interesting', '#admirable', 0.127, 'religious_leader', 'religious_man', 'religious_official', 'believer', 'true_believer']
senticnet['clerisy'] = [0.594, -0.735, 0, 0.909, '#surprising', '#admirable', 0.746, 'intelligentsia', 'elite', 'nobility', 'elect', 'aristocracy']
senticnet['clerk'] = [0.824, 0.743, 0, 0, '#joyful', '#interesting', 0.522, 'shopper', 'customer', 'patron', 'vintner', 'hairdresser']
senticnet['clever'] = [0.701, 0.724, 0, 0, '#joyful', '#interesting', 0.475, 'touch_heart', 'sincere', 'others_understand', 'spread_word', 'look_sexy']
senticnet['cleverness'] = [0.909, -0.734, 0, 0.894, '#joyful', '#admirable', 0.846, 'creativity', 'creativeness', 'creative_thinking', 'imagination', 'resourcefulness']
senticnet['clew'] = [-0.926, 0, 0.783, -0.511, '#sad', '#angry', -0.74, 'clot', 'coagulum', 'gob', 'lump', 'agglomeration']
senticnet['cliche'] = [0, -0.026, 0.033, -0.089, '#angry', '#disgusting', -0.032, 'tooth', 'teeth', 'dimple', 'mouth', 'jaw']
senticnet['cliched'] = [-0.655, 0, 0.804, -0.945, '#angry', '#disgusting', -0.801, 'cold', 'unoriginal', 'dusty', 'slavish', 'banal']
senticnet['click'] = [0, 0.15, 0.067, 0.118, '#interesting', '#admirable', 0.067, 'representation', 'outline', 'arithmetic', 'diagram', 'list_number']
senticnet['click_link'] = [0, -0.965, 0, 0.84, '#surprising', '#admirable', 0.602, 'write_email', 'learn_program', 'learn_program_language', 'learn_computer_language', 'find_porn']
senticnet['cliff'] = [0.057, 0.075, 0.039, 0.059, '#interesting', '#admirable', 0.051, 'summit', 'big_rock', 'high_land', 'peak', 'mountain_side']
senticnet['cliff-hanging'] = [0, 0, -0.733, 0, '#scared', '#scared', -0.244, 'suspenseful', 'suspensive', 'nail-biting', 'apathetically', 'unconcern']
senticnet['climate'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'weather', 'sunny', 'spring', 'snow', 'four_seasons']
senticnet['climb'] = [0, 0.166, -0.134, 0.275, '#interesting', '#admirable', 0.102, 'mountain_climb_mountain', 'climb_mountain', 'chop_down_tree', 'reflect_water', 'store_garage']
senticnet['climb_hill'] = [-0.059, -0.047, 0.091, -0.055, '#sad', '#angry', -0.053, 'enjoy_nature', 'view_nature', 'expend_energy', 'little_pollution', 'strain_muscle']
senticnet['climb_ladder'] = [-0.068, 0, 0, 0, '#sad', '#sad', -0.023, 'picture_scene', 'take_photograph', 'paint_ceiling', 'frame_picture', 'staircase']
senticnet['climb_mountain'] = [0, 0.166, -0.134, 0.275, '#interesting', '#admirable', 0.102, 'mountain_climb', 'climb', 'chop_down_tree', 'reflect_water', 'store_garage']
senticnet['climb_rock'] = [0, 0, -0.756, 0, '#scared', '#scared', -0.252, 'exercise_much', 'play_saxophone', 'dance_well', 'feel_faint', 'eat_healthy_diet']
senticnet['climb_stair'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'take_hike', 'exercise_daily', 'stay_up_night', 'skydive', 'staircase']
senticnet['climb_to_top'] = [0.677, -0.529, 0, 0.714, '#joyful', '#admirable', 0.64, 'group_object', 'meet_greet', 'hot_summer', 'price_goods', 'appear_beautiful']
senticnet['climb_tree'] = [0, 0.095, 0, 0.127, '#interesting', '#admirable', 0.074, 'upside_down', 'fun_activity', 'swing', 'nocturnal', 'tree_house']
senticnet['climb_up'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'walk_up', 'get_floor_another', 'go_upstairs', 'go_up_down', 'move_between_floor_building']
senticnet['climbable'] = [-0.996, 0, 0.641, -0.765, '#sad', '#disgusting', -0.801, 'navigable', 'negotiable', 'surmountable', 'passable', 'traversable']
senticnet['climber'] = [0.518, -0.519, 0, 0.65, '#surprising', '#admirable', 0.562, 'clematis', 'legume', 'leguminous_plant', 'climbing_fern', 'root_climber']
senticnet['climbing_fern'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'clematis', 'legume', 'leguminous_plant', 'climber', 'root_climber']
senticnet['cling'] = [0.51, -0.562, 0, 0.768, '#surprising', '#admirable', 0.613, 'hold', 'clasp', 'hold_on', 'latch_on', 'hang']
senticnet['clinic'] = [-0.037, 0, -0.151, -0.154, '#scared', '#disgusting', -0.114, 'medical_office', 'hospital', 'doctor_office', 'emergency_room', 'nurse_home']
senticnet['clinical_depression'] = [-0.997, 0, 0.982, -0.62, '#sad', '#angry', -0.866, 'dysthymia', 'dysthymic_depression', 'affective_disorder', 'major_affective_disorder', 'emotional_disorder']
senticnet['clinical_problem'] = [0, 0, -0.98, -0.978, '#scared', '#disgusting', -0.653, 'disease', 'heart_attack', 'worse', 'health_issue', 'obese']
senticnet['clink'] = [-0.606, 0, 0.866, -0.613, '#angry', '#disgusting', -0.695, 'pokey', 'holding_cell', 'slammer', 'jail', 'jailhouse']
senticnet['clinker'] = [0.962, -0.703, 0, 0.522, '#joyful', '#surprising', 0.729, 'adobe', 'adobe_brick', 'brick', 'building_block', 'firebrick']
senticnet['clinker_brick'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'adobe', 'adobe_brick', 'clinker', 'brick', 'firebrick']
senticnet['clip'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'paperclip', 'clasp', 'glue_stick', 'clothespin', 'clamp']
senticnet['clipboard'] = [0, 0, 0.907, -0.816, '#angry', '#disgusting', -0.574, 'eraser_holder', 'pencil_sharpener', 'stick_eraser', 'intern', 'electric_pencil_sharpener']
senticnet['clipper'] = [0, 0, 0.856, -0.787, '#angry', '#disgusting', -0.548, 'scissor', 'razor', 'pair_of_scissors', 'haircut_scissor', 'double_edge_razor']
senticnet['clique'] = [0.042, 0, 0, 0.067, '#joyful', '#admirable', 0.036, 'big_group', 'several_people', 'multitude', 'group', 'favorite']
senticnet['cliquishness'] = [-0.948, 0, 0.687, -0.75, '#sad', '#disgusting', -0.795, 'clannishness', 'snobbery', 'exclusiveness', 'arrogance', 'haughtiness']
senticnet['cloak'] = [0, 0, 0.931, -0.86, '#angry', '#disgusting', -0.597, 'winter_clothes', 'outerwear', 'coat', 'jacket', 'shirt']
senticnet['clock'] = [0, 0, 0.736, -0.772, '#angry', '#disgusting', -0.503, 'watch', 'stopwatch', 'timepiece', 'wristwatch', 'find_pawnshop']
senticnet['clock_face'] = [0, -0.781, 0, 0.924, '#surprising', '#admirable', 0.568, 'time', 'swiss_watch', 'tell_time', 'timekeeper', 'device_measure_time']
senticnet['clock_out'] = [-0.046, 0, -0.071, -0.101, '#scared', '#disgusting', -0.073, 'put_clothes_back', 'sit_back_relax', 'quit_work', 'make_sex', 'stop_work']
senticnet['clog'] = [0.092, -0.197, 0.053, 0.089, '#joyful', '#surprising', 0.108, 'hairball', 'waste_water', 'false_tooth', 'still_water', 'go_lake']
senticnet['clog_artery'] = [0, 0, -0.964, 0, '#scared', '#scared', -0.321, 'world_hunger', 'eat', 'full_stomach', 'salivate', 'satisfy_crave']
senticnet['clogged'] = [-0.809, 0, -0.823, 0, '#sad', '#scared', -0.544, 'block', 'obstruct', 'close', 'shutter', 'occluded']
senticnet['cloistered'] = [-0.948, 0, 0.779, -0.858, '#sad', '#disgusting', -0.862, 'eremitic', 'eremitical', 'unworldly', 'anchoritic', 'hermitic']
senticnet['clon'] = [0.027, 0.111, -0.055, 0.167, '#interesting', '#admirable', 0.083, 'price_product', 'draw', 'fillet_fish', 'design', 'create']
senticnet['clone'] = [0, 0.143, 0, 0.264, '#interesting', '#admirable', 0.136, 'replicate', 'imitation', 'duplicate', 'jot', 'make_copy']
senticnet['close'] = [0.609, 0.597, -0.239, 0.398, '#joyful', '#interesting', 0.455, 'near', 'pick_up', 'togetherness', 'gay', 'capture']
senticnet['close_book'] = [-0.107, 0, -0.056, -0.157, '#sad', '#disgusting', -0.107, 'study_library', 'jot_down_note', 'study_book', 'sleep_back', 'drink_cup_coffee']
senticnet['close_case'] = [-0.937, 0, 0, -0.813, '#sad', '#disgusting', -0.583, 'question_witness', 'convict_criminal', 'find_guilty', 'seek_justice', 'call_police']
senticnet['close_curtain'] = [0.942, 0.79, 0, 0, '#joyful', '#interesting', 0.577, 'pull_up_cover', 'look_out_window', 'page_through_book', 'check_email', 'oversleep']
senticnet['close_deal'] = [-0.081, 0.074, -0.073, -0.093, '#sad', '#disgusting', -0.058, 'forget_name', 'finish_task', 'reply_question', 'arrive_work', 'buy_stock']
senticnet['close_door'] = [-0.094, -0.02, 0.019, -0.028, '#sad', '#disgusting', -0.04, 'open_door', 'find_location', 'drop_ball', 'try_best', 'blow_horn']
senticnet['close_down'] = [-0.939, 0, -0.998, -0.928, '#sad', '#scared', -0.955, 'language_barrier', 'shut', 'shut_down', 'barrier', 'obstacle']
senticnet['close_eye'] = [0, 0, 0, -0.089, '#disgusting', '#disgusting', -0.03, 'sleepwalk', 'wear_pyjamas', 'lay_down', 'wind_down', 'lie_down']
senticnet['close_mouth'] = [-0.076, 0, -0.145, -0.062, '#sad', '#scared', -0.094, 'inhale', 'eat_peanut', 'shut_up', 'call_911', 'cough']
senticnet['close_together'] = [-0.11, 0, -0.078, 0, '#sad', '#scared', -0.063, 'feel_heat', 'smoke_joint', 'explain_everything', 'shovel_snow', 'position_furniture']
senticnet['close_up'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'block', 'jam', 'block_off', 'obstruct', 'obturate']
senticnet['close_window'] = [-0.082, 0, 0.039, 0, '#sad', '#angry', -0.04, 'open_car_door', 'put_key_ignition', 'find_car_key', 'stay_sober', 'start_car_engine']
senticnet['closed_minded'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'follow_rule_blindly', 'strict', 'inflexible', 'dumb', 'go_by_book']
senticnet['closeness'] = [0.675, 0.6, -0.226, 0.259, '#joyful', '#interesting', 0.436, 'cheer_up', 'recreate', 'joyful', 'glee', 'jubilation']
senticnet['closer'] = [-0.922, 0, 0.767, -0.85, '#sad', '#disgusting', -0.846, 'relief_pitcher', 'finisher', 'pitcher', 'hurler', 'twirler']
senticnet['closet'] = [-0.023, 0, 0, -0.058, '#sad', '#disgusting', -0.027, 'sock_drawer', 'under_carpet', 'back_sofa', 'under_back_sofa', 'under_bed']
senticnet['closing'] = [0.699, -0.836, 0, 0.919, '#surprising', '#admirable', 0.818, 'move', 'movement', 'access', 'coming', 'closure']
senticnet['closing_time'] = [0.1, 0.104, 0, 0, '#joyful', '#interesting', 0.068, 'sleep_time', 'rest_night', 'rest_dream', 'shut_eye', 'inactivity']
senticnet['closure'] = [0.079, 0.204, -0.093, 0.23, '#interesting', '#admirable', 0.14, 'open', 'control_access', 'tug', 'separate_room', 'enter']
senticnet['clot'] = [-0.926, 0, 0.783, -0.511, '#sad', '#angry', -0.74, 'lump', 'coagulum', 'gob', 'clew', 'agglomeration']
senticnet['clotbur'] = [0.685, -0.522, 0, 0.779, '#joyful', '#admirable', 0.662, 'subshrub', 'suffrutex', 'common_burdock', 'lesser_burdock', 'great_burdock']
senticnet['cloth'] = [0, -0.04, 0.126, -0.054, '#angry', '#disgusting', -0.047, 'make_shirt', 'make_make_clothes', 'make_cloth', 'article_make_clothes', 'apparel']
senticnet['cloth_fabric'] = [0.085, 0, 0.035, 0.147, '#joyful', '#admirable', 0.066, 'soft', 'material_type', 'fabric_type', 'type_of_cloth', 'biodegradable']
senticnet['cloth_material'] = [0.816, 0, 0, 0.705, '#joyful', '#admirable', 0.507, 'soft_fabric', 'fabric_type', 'clothes_fabric', 'dry_clean', 'cloth_fabric']
senticnet['clothe'] = [-0.635, 0, 0.694, -0.997, '#angry', '#disgusting', -0.775, 'raiment', 'garb', 'dress', 'overclothe', 'enoverclothe']
senticnet['clothed'] = [-0.596, 0, 0.748, -0.99, '#angry', '#disgusting', -0.778, 'gowned', 'petticoated', 'surpliced', 'arrayed', 'caparisoned']
senticnet['clothes'] = [0.829, 0.797, 0, 0, '#joyful', '#interesting', 0.542, 'piece_of_clothing', 'fashion', 'robe', 'dress', 'shirt']
senticnet['clothes_accessory'] = [0, -0.754, 0, 0.873, '#surprising', '#admirable', 0.542, 'waterproof', 'animal_hide', 'animal_pelt', 'pantyhose', 'panties']
senticnet['clothes_clean'] = [0, 0, 0, 0.07, '#admirable', '#admirable', 0.023, 'remove_dirt', 'run_out_soap', 'clean_skin', 'become_cleaner', 'feel_clean']
senticnet['clothes_dirty'] = [0.02, 0, 0, 0.096, '#joyful', '#admirable', 0.039, 'sort_clothes', 'clothes_clean', 'use_water', 'smell_better', 'remove_dirt']
senticnet['clothes_drawer'] = [0, -0.94, 0, 0.955, '#surprising', '#admirable', 0.632, 'department_store', 'clothes_store', 'woman_closet', 'store', 'many_stores']
senticnet['clothes_fabric'] = [0.03, 0, 0, 0.093, '#joyful', '#admirable', 0.041, 'softness', 'soft_fabric', 'cloth_fabric', 'silky', 'cloth_material']
senticnet['clothes_factory'] = [-0.035, 0, 0, -0.116, '#sad', '#disgusting', -0.05, 'store_cloth', 'sheath', 'clothes', 'pollution', 'factory']
senticnet['clothes_hanger'] = [0, 0.702, 0, 0.975, '#interesting', '#admirable', 0.559, 'hanger', 'hang_up_clothes', 'hang_clothes', 'storage_space', 'laundry']
senticnet['clothes_holder'] = [-0.203, 0, -0.077, 0, '#sad', '#scared', -0.093, 'sewn', 'clothes_repair', 'wind_thread', 'keep_clothes', 'make_fabric']
senticnet['clothes_material'] = [0.069, 0.112, 0, 0.167, '#interesting', '#admirable', 0.116, 'plant_material', 'silk', 'natural_fiber', 'natural_fabric', 'fabric_type']
senticnet['clothes_repair'] = [-0.071, -0.022, 0.021, -0.09, '#sad', '#disgusting', -0.053, 'weave', 'use_needle', 'mend', 'keep_clothes', 'make_fabric']
senticnet['clothes_shelf'] = [0.069, 0.112, 0, 0.167, '#interesting', '#admirable', 0.116, 'cupboard', 'hangers', 'compartment', 'jeans', 'drawers']
senticnet['clothes_shrink'] = [0.035, 0, 0, 0.05, '#joyful', '#admirable', 0.028, 'become_cleaner', 'become_wet', 'dry_skin', 'smell_better', 'clothes_clean']
senticnet['clothes_storage'] = [-0.961, 0, 0.776, 0, '#sad', '#angry', -0.579, 'hang_up_clothes', 'store_clothes', 'clothes', 'hang_clothes', 'storage_space']
senticnet['clothes_store'] = [-0.027, -0.021, 0.034, -0.037, '#angry', '#disgusting', -0.026, 'department_store', 'clothes_drawer', 'woman_closet', 'store', 'many_stores']
senticnet['clothes_store_change_room'] = [0, 0.144, -0.091, 0.196, '#interesting', '#admirable', 0.083, 'fit_room', 'changing_room', 'dress_room', 'clothes_shelf', 'garment_bag']
senticnet['clothes_style'] = [0.035, 0.101, 0.033, 0.142, '#interesting', '#admirable', 0.082, 'fancy_clothes', 'style', 'glamour', 'model', 'formal_clothes']
senticnet['clothes_type'] = [0, 0.081, 0.015, 0.052, '#interesting', '#admirable', 0.039, 'white_cotton', 'fabric_material', 'woven_fabric', 'fabric', 'sheepskin']
senticnet['clothes_washer'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'purse', 'pocket', 'washer', 'wallet_purse', 'woman_purse']
senticnet['clothespin'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'paperclip', 'clasp', 'glue_stick', 'clip', 'clamp']
senticnet['clothing'] = [0.57, -0.566, 0, 0.888, '#joyful', '#admirable', 0.675, 'wearable', 'wear', 'muff', 'glove', 'hand_wear']
senticnet['cloud'] = [-0.934, 0, 0.508, -0.848, '#sad', '#disgusting', -0.763, 'nakedness', 'glumness', 'bleakness', 'desolation', 'bareness']
senticnet['cloud_judgment'] = [0, -0.038, -0.079, -0.179, '#scared', '#disgusting', -0.073, 'make_drunk', 'make_confused', 'set_on_fire', 'confuse', 'drug']
senticnet['cloud_mind'] = [-0.129, -0.035, -0.128, -0.168, '#sad', '#disgusting', -0.13, 'hurt', 'damage', 'harm', 'burn_skin', 'cut_skin']
senticnet['cloud_sky'] = [0, -0.738, 0, 0.96, '#surprising', '#admirable', 0.566, 'sky', 'come_down', 'water_fall', 'water_drop', 'water_droplet']
senticnet['cloudiness'] = [-0.927, 0, 0.929, -0.566, '#sad', '#angry', -0.807, 'overcast', 'weather', 'raw_weather', 'storminess', 'inclemency']
senticnet['cloudy'] = [0.025, -0.06, -0.056, 0.161, '#surprising', '#admirable', 0.063, 'carry_water', 'up_high', 'weather_condition', 'dew', 'hazy']
senticnet['clout'] = [-0.94, 0, 0.863, -0.984, '#sad', '#disgusting', -0.929, 'poke', 'knockout_punch', 'lick', 'punch', 'biff']
senticnet['clover'] = [0, 0.067, 0, 0.05, '#interesting', '#admirable', 0.039, 'bloom', 'daisy', 'tulip', 'rose', 'daffodil']
senticnet['clown'] = [0.954, 0, 0, 0, '#joyful', '#joyful', 0.318, 'circus', 'halloween', 'entertainment', 'fun', 'happiness']
senticnet['clowning'] = [0.662, -0.809, 0, 0.651, '#joyful', '#surprising', 0.707, 'folly', 'lunacy', 'craziness', 'indulgence', 'shtik']
senticnet['cloze_procedure'] = [0.747, -0.581, 0, 0.92, '#joyful', '#admirable', 0.749, 'assay', 'biopsy', 'diagnostic_assay', 'cloze_test', 'fecal_occult_test']
senticnet['cloze_test'] = [0.747, -0.581, 0, 0.92, '#joyful', '#admirable', 0.749, 'assay', 'biopsy', 'cloze_procedure', 'diagnostic_assay', 'fecal_occult_test']
senticnet['club'] = [0.202, -0.047, 0, 0, '#joyful', '#surprising', 0.083, 'bart', 'bar', 'fraternity', 'metal_stick', 'tavern']
senticnet['club_chair'] = [0.868, 0, 0, 0.865, '#joyful', '#admirable', 0.578, 'sofa_bed', 'armchair', 'sofa_hide_bed', 'chair', 'rock_chair']
senticnet['clubfoot'] = [-0.854, 0, 0.695, -0.658, '#sad', '#angry', -0.736, 'affliction', 'pigeon_breast', 'chicken_breast', 'deformity', 'talipes']
senticnet['clue'] = [0, 0.161, -0.113, 0.189, '#interesting', '#admirable', 0.079, 'find_play', 'verbosity', 'hint', 'opponent', 'option']
senticnet['clump'] = [-0.51, 0, 0.551, -0.815, '#angry', '#disgusting', -0.625, 'knot', 'swad', 'tuft', 'tussock', 'agglomeration']
senticnet['clumsiness'] = [0.983, -0.637, 0, 0.697, '#joyful', '#admirable', 0.772, 'amateurishness', 'inability', 'ineptness', 'unskillfulness', 'awkwardness']
senticnet['clumsy'] = [-0.766, 0, 0.994, -0.605, '#sad', '#angry', -0.788, 'unfortunate', 'inapt', 'inept', 'awkward', 'infelicitous']
senticnet['clumsy_person'] = [-0.713, 0, 0.845, -0.691, '#sad', '#angry', -0.75, 'lump', 'goon', 'mortal', 'duffer', 'butterfingers']
senticnet['cluster'] = [0, 0, 0, 0.07, '#admirable', '#admirable', 0.023, 'bunch', 'several_people', 'clique', 'big_group', 'group']
senticnet['clustered_lady_slipper'] = [0.277, 0.161, 0, 0.337, '#joyful', '#admirable', 0.258, 'moccasin_flower', 'nerveroot', 'showy_lady_slipper', 'yellow_lady_slipper', 'ladies_slipper']
senticnet['clustering'] = [-0.646, 0, 0.637, -0.889, '#sad', '#disgusting', -0.724, 'knot', 'swad', 'tuft', 'tussock', 'agglomeration']
senticnet['clutch'] = [0, -0.033, 0, 0.064, '#surprising', '#admirable', 0.032, 'bumper', 'fan_belt', 'brake_pedal', 'emergency_brake', 'windshield']
senticnet['clutch_bag'] = [0, 0.084, 0, 0, '#interesting', '#interesting', 0.028, 'credit_card_wallet', 'checkbook_holder', 'pouch', 'bag', 'coin_purse']
senticnet['clutter'] = [0.035, 0.076, 0, 0.067, '#interesting', '#admirable', 0.059, 'postal_counter', 'paperwork', 'coworker', 'white-out', 'stapler']
senticnet['cnn'] = [0, 0.987, 0, 0.787, '#interesting', '#admirable', 0.591, 'tv_program', 'daily', 'eat_breakfast', 'wake_up', 'medium']
senticnet['coach'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'trainer', 'instructor', 'personal_trainer', 'fit_person', 'train']
senticnet['coach_seat'] = [0.033, -0.039, 0, 0, '#joyful', '#surprising', 0.024, 'chair', 'bench', 'couch', 'stool', 'seat']
senticnet['coagulum'] = [-0.926, 0, 0.783, -0.511, '#sad', '#angry', -0.74, 'clot', 'lump', 'gob', 'clew', 'agglomeration']
senticnet['coal'] = [0, 0, -0.9, -0.804, '#scared', '#disgusting', -0.568, 'diesel', 'fuel', 'kerosene', 'gas', 'inert_gas']
senticnet['coal_black'] = [-0.604, 0, 0.895, -0.541, '#sad', '#angry', -0.68, 'black', 'jet_black', 'pitch_black', 'soot_black', 'achromatic_color']
senticnet['coal_mine'] = [0, -0.106, -0.058, 0.076, '#surprising', '#admirable', 0.041, 'mine', 'dirt', 'compost', 'footprint', 'soil']
senticnet['coalesce'] = [0, 0, -0.754, -0.924, '#scared', '#disgusting', -0.559, 'blend', 'conflate', 'mix', 'flux', 'commingle']
senticnet['coarse'] = [0, 0, -0.972, -0.993, '#scared', '#disgusting', -0.655, 'harsh', 'common', 'rough-cut', 'uncouth', 'vulgar']
senticnet['coarseness'] = [0.989, -0.997, 0, 0.728, '#joyful', '#surprising', 0.905, 'quality', 'tastelessness', 'sleaziness', 'inelegance', 'commonness']
senticnet['coast'] = [0.03, 0.117, 0, 0.084, '#interesting', '#admirable', 0.077, 'ocean_beach', 'waterfront', 'ocean', 'beach', 'sea']
senticnet['coaster'] = [0, -0.042, 0.061, -0.074, '#angry', '#disgusting', -0.031, 'computer_monitor', 'address_book', 'post_note', 'glue_stick', 'post-it_note']
senticnet['coat'] = [0.053, -0.013, -0.052, 0.121, '#joyful', '#admirable', 0.045, 'adorn', 'winter_clothes', 'stylish', 'outerwear', 'protective_cover']
senticnet['coat_hanger'] = [0, 0, 0.887, -0.842, '#angry', '#disgusting', -0.576, 'gay_person', 'hanger', 'storage_item', 'slipper', 'bikini']
senticnet['coat_of_mail'] = [0.939, -0.632, 0, 0.653, '#joyful', '#admirable', 0.741, 'vest', 'waistcoat', 'body_armor', 'suit_of_armor', 'bulletproof_vest']
senticnet['coat_surface'] = [0.035, -0.053, 0, 0.101, '#surprising', '#admirable', 0.063, 'dry', 'coat_wall', 'artist_tool', 'palette', 'protect_wood']
senticnet['coat_wall'] = [0.035, -0.053, 0, 0.101, '#surprising', '#admirable', 0.063, 'dry', 'coat_surface', 'artist_tool', 'palette', 'paint']
senticnet['coating'] = [-0.944, 0, 0.569, -0.721, '#sad', '#disgusting', -0.745, 'bitumastic', 'veneer', 'veneering', 'lacquer', 'seal']
senticnet['coattail'] = [-0.585, 0, 0.715, -0.597, '#angry', '#disgusting', -0.632, 'fly', 'overlap', 'barndoor', 'flap', 'codpiece']
senticnet['cobalt'] = [-0.055, -0.004, 0.031, -0.036, '#sad', '#disgusting', -0.039, 'pigment', 'many_shades', 'cyan', 'green_yellow', 'material']
senticnet['cobaltite'] = [0.555, -0.994, 0, 0.851, '#surprising', '#admirable', 0.8, 'quartz', 'cerussite', 'white_lead_ore', 'mineral', 'molybdenite']
senticnet['cobol'] = [0, -0.867, 0, 0.912, '#surprising', '#admirable', 0.593, 'helpful_tool', 'woodworking_tool', 'helpful', 'type_of_fruit', 'hand_tool']
senticnet['cobra'] = [0, 0.11, 0, 0.077, '#interesting', '#admirable', 0.062, 'snake', 'python', 'reptile', 'animal', 'rattlesnake']
senticnet['cobweb'] = [0, 0, -0.753, -0.749, '#scared', '#disgusting', -0.501, 'storage_box', 'undead', 'dust', 'wine_bottle', 'read']
senticnet['cocaine'] = [0.022, -0.134, 0.153, -0.314, '#angry', '#disgusting', -0.104, 'codeine', 'morphine', 'infection', 'hash', 'nuclear_war']
senticnet['coccidioidomycosis'] = [-0.859, 0, 0.549, -0.938, '#sad', '#disgusting', -0.782, 'mycosis', 'coccidiomycosis', 'valley_fever', 'desert_rheumatism', 'cryptococcosis']
senticnet['coccidiomycosis'] = [-0.859, 0, 0.549, -0.938, '#sad', '#disgusting', -0.782, 'coccidioidomycosis', 'mycosis', 'valley_fever', 'desert_rheumatism', 'cryptococcosis']
senticnet['cock'] = [-0.541, 0, 0.811, -0.516, '#sad', '#angry', -0.623, 'bird_of_prey', 'raptor', 'raptorial_bird', 'parrot', 'bird']
senticnet['cockamamie'] = [0.764, -0.667, 0, 0.898, '#joyful', '#admirable', 0.776, 'farfetched', 'unbelievable', 'implausible', 'cockamamy', 'unlikely']
senticnet['cockamamy'] = [0.764, -0.667, 0, 0.898, '#joyful', '#admirable', 0.776, 'farfetched', 'unbelievable', 'cockamamie', 'implausible', 'unlikely']
senticnet['cockroach'] = [0, 0, -0.839, -0.735, '#scared', '#disgusting', -0.525, 'annoy_bug', 'insect', 'bug', 'hare', 'nymph']
senticnet['cocktail'] = [0.122, -0.011, 0, 0, '#joyful', '#surprising', 0.044, 'bourbon', 'alcoholic_beverage', 'booze', 'vodka', 'beverage']
senticnet['cocktail_cabinet'] = [0.863, 0.966, 0, 0, '#joyful', '#interesting', 0.61, 'rest_room', 'stool', 'chair', 'coffee_table', 'bar_stool']
senticnet['cocktail_party'] = [0.962, 0, 0, 0, '#joyful', '#joyful', 0.321, 'interest_person', 'social_occasion', 'become_intoxicated', 'network', 'get_sex']
senticnet['coco_de_macao'] = [0.635, -0.847, 0, 0.85, '#surprising', '#admirable', 0.777, 'oil_palm', 'babassu', 'babassu_palm', 'feather_palm', 'wax_palm']
senticnet['coconut'] = [0.081, 0, 0, 0, '#joyful', '#joyful', 0.027, 'bottle_wine', 'table_chair', 'human_intelligence', 'chef_special', 'oatmeal']
senticnet['cocotte'] = [-0.676, 0, 0.589, -0.966, '#sad', '#disgusting', -0.744, 'slattern', 'camp_follower', 'call_girl', 'comfort_woman', 'ianfu']
senticnet['cod'] = [-0.62, 0, 0.9, -0.911, '#angry', '#disgusting', -0.81, 'dupe', 'slang', 'put_on', 'pull_leg_of', 'take_in']
senticnet['coddle'] = [0, 0, -0.73, -0.945, '#scared', '#disgusting', -0.558, 'cocker', 'baby', 'cosset', 'featherbed', 'pamper']
senticnet['coddler'] = [0.551, -0.868, 0, 0.854, '#surprising', '#admirable', 0.758, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['code'] = [-0.034, 0.201, -0.049, 0.201, '#interesting', '#admirable', 0.106, 'plan', 'oversee', 'decision', 'skill', 'make_decision']
senticnet['codeine'] = [0.047, -0.019, -0.082, -0.215, '#scared', '#disgusting', -0.077, 'morphine', 'phenobarbital', 'drug', 'analgesic', 'palliative']
senticnet['coding'] = [0.634, -0.738, 0, 0.974, '#surprising', '#admirable', 0.782, 'decompression', 'cryptography', 'decipherment', 'secret_writing', 'steganography']
senticnet['codings'] = [0, 0, 0, 0.074, '#admirable', '#admirable', 0.025, 'write_message', 'grammar', 'computer_language', 'english', 'program_language']
senticnet['codpiece'] = [-0.585, 0, 0.715, -0.597, '#angry', '#disgusting', -0.632, 'fly', 'overlap', 'barndoor', 'coattail', 'flap']
senticnet['codswallop'] = [0.739, -0.899, 0, 0.702, '#joyful', '#surprising', 0.78, 'pap', 'content', 'pablum', 'folderol', 'drivel']
senticnet['coeducation'] = [0.702, -0.607, 0, 0.784, '#joyful', '#admirable', 0.698, 'continuing_education', 'activity', 'course', 'extracurricular_activity', 'didactics']
senticnet['coerce'] = [-0.876, 0, 0, -0.937, '#sad', '#disgusting', -0.604, 'turn_up_heat', 'turn_up_pressure', 'steamroller', 'steamroll', 'sandbag']
senticnet['coercion'] = [0, 0, -1, -1, '#scared', '#disgusting', -0.667, 'moon_gravity', 'force', 'volt', 'watt', 'power_source']
senticnet['coffee'] = [0.825, 0.941, 0, 0, '#joyful', '#interesting', 0.589, 'bubble', 'steam', 'hot', 'boil_water', 'tea']
senticnet['coffee_break'] = [0.251, 0.207, -0.082, 0.18, '#joyful', '#interesting', 0.185, 'middle_day', 'work_break', 'inactivity', 'recover', 'take_break']
senticnet['coffee_cup'] = [0.095, 0, 0, 0, '#joyful', '#joyful', 0.032, 'coffee', 'drink_coffee', 'coffee_shop', 'caffeine', 'drink_tea']
senticnet['coffee_house'] = [0.042, -0.056, 0, 0, '#joyful', '#surprising', 0.033, 'drink_coffee', 'meet_up', 'internet_cafe', 'backpack', 'coffee']
senticnet['coffee_mug'] = [0.095, 0, 0, 0, '#joyful', '#joyful', 0.032, 'coffee', 'drink_coffee', 'coffee_shop', 'caffeine', 'drink_tea']
senticnet['coffee_roll'] = [-0.843, 0, 0.713, -0.636, '#sad', '#angry', -0.731, 'cross_bun', 'hot_cross_bun', 'bear_paw', 'bear_claw', 'bun']
senticnet['coffee_shop'] = [0, -0.069, 0, 0, '#surprising', '#surprising', 0.023, 'drink_coffee', 'beverage', 'food_and_beverage', 'kitchen', 'eat_dinner']
senticnet['coffee_table'] = [0, -0.069, 0, 0, '#surprising', '#surprising', 0.023, 'coffee', 'table', 'coffee_shop', 'coffee_house', 'hot_chocolate']
senticnet['coffer'] = [0, 0.149, 0, 0, '#interesting', '#interesting', 0.05, 'wallet', 'billfold', 'bank', 'piggy_bank', 'bank_vault']
senticnet['coffin'] = [0, 0, -0.873, -0.855, '#scared', '#disgusting', -0.576, 'grave', 'casket', 'morgue', 'headstone', 'graveyard']
senticnet['cogged'] = [0.845, -0.716, 0, 0.775, '#joyful', '#admirable', 0.779, 'toothy', 'toothed', 'sabertoothed', 'toothlike', 'tusked']
senticnet['cogitate'] = [0, 0.844, 0, 0.827, '#interesting', '#admirable', 0.557, 'think', 'contemplate', 'remember', 'brainstorm', 'use_memory']
senticnet['cogitation'] = [0.937, -0.939, 0, 0.933, '#joyful', '#surprising', 0.936, 'consideration', 'introspection', 'rumination', 'study', 'speculation']
senticnet['cogitative'] = [0.91, 0.868, 0, 0, '#joyful', '#interesting', 0.593, 'pondering', 'broody', 'contemplative', 'meditative', 'think']
senticnet['cogito_ergo_sum'] = [0, -0.94, 0, 0.974, '#surprising', '#admirable', 0.638, 'live', 'strong_desire', 'live_life', 'existence', 'essential']
senticnet['cognisance'] = [0.657, -0.88, 0, 0.631, '#joyful', '#surprising', 0.723, 'feel', 'knowingness', 'awareness', 'cognizance', 'consciousness']
senticnet['cognisant'] = [0.74, -0.856, 0, 0.732, '#joyful', '#surprising', 0.776, 'alert', 'sensible', 'alive', 'conscious', 'awake']
senticnet['cognition'] = [-0.05, 0.21, -0.072, 0.102, '#interesting', '#admirable', 0.063, 'figure_out', 'brain_activity', 'resolve_problem', 'intellect', 'arrive_conclusion']
senticnet['cognitive_content'] = [0.95, -0.863, 0, 0.947, '#joyful', '#admirable', 0.92, 'content', 'old_wives_tale', 'folklore', 'lore', 'mental_object']
senticnet['cognitive_factor'] = [-0.849, 0, 0.627, -0.768, '#sad', '#disgusting', -0.748, 'difficulty', 'inspiration', 'determinant', 'determinative', 'divine_guidance']
senticnet['cognizance'] = [0.657, -0.88, 0, 0.631, '#joyful', '#surprising', 0.723, 'cognisance', 'knowingness', 'awareness', 'feel', 'consciousness']
senticnet['cognizant'] = [0.853, -0.848, 0, 0.794, '#joyful', '#surprising', 0.832, 'alert', 'sensible', 'alive', 'conscious', 'awake']
senticnet['coherence'] = [0.869, -0.88, 0, 0.598, '#joyful', '#surprising', 0.782, 'connectedness', 'connection', 'consistency', 'continuity', 'link']
senticnet['coherency'] = [0.792, -0.834, 0, 0.575, '#joyful', '#surprising', 0.734, 'connectedness', 'connection', 'consistency', 'continuity', 'link']
senticnet['coif'] = [-0.974, 0, 0.567, -0.598, '#sad', '#disgusting', -0.713, 'marcel', 'marcelfure', 'hairdo', 'hairstyle', 'hair_style']
senticnet['coiffure'] = [-0.974, 0, 0.567, -0.598, '#sad', '#disgusting', -0.713, 'coif', 'marcel', 'hairdo', 'hairstyle', 'hair_style']
senticnet['coiled'] = [0.612, -0.536, 0, 0.532, '#joyful', '#surprising', 0.56, 'convoluted', 'convolute', 'involute', 'rolled', 'wound']
senticnet['coin'] = [-0.05, 0.21, -0.072, 0.102, '#interesting', '#admirable', 0.063, 'coin_collection', 'collection', 'butterfly_collection', 'insect_collection', 'album_collection']
senticnet['coin_collection'] = [-0.05, 0.21, -0.072, 0.102, '#interesting', '#admirable', 0.063, 'coin', 'collection', 'butterfly_collection', 'insect_collection', 'album_collection']
senticnet['coin_purse'] = [0.902, 0.85, 0, 0, '#joyful', '#interesting', 0.584, 'purse', 'clutch_bag', 'credit_card_wallet', 'pocket', 'cash']
senticnet['coin_slot'] = [0.752, 0.869, 0, 0, '#joyful', '#interesting', 0.54, 'spare_change', 'loose_change', 'checkbook_cover', 'paper_bill', 'banknote']
senticnet['coincidence'] = [0, -0.788, 0, 0.93, '#surprising', '#admirable', 0.573, 'character_play', 'math_homework', 'sign_autograph', 'role', 'write']
senticnet['coitus'] = [0.947, -0.811, 0, 0.656, '#joyful', '#surprising', 0.805, 'sexual_intercourse', 'intercourse', 'sex_act', 'copulation', 'hank_panky']
senticnet['coke'] = [0.078, 0, 0, 0, '#joyful', '#joyful', 0.026, 'glass_water', 'refreshed', 'smoothie', 'lemonade', 'cold_water']
senticnet['coke_zero'] = [0.907, 0, 0, 0.901, '#joyful', '#admirable', 0.603, 'carbonated_drink', 'sugar_free', 'coke', 'diet_coke', 'beverage']
senticnet['cola'] = [0.151, 0.11, -0.045, 0.11, '#joyful', '#interesting', 0.109, 'cool_drink', 'sprite', 'soft_drink', 'cold_drink', 'keep_cold']
senticnet['cold'] = [0.214, 0.16, -0.064, 0.101, '#joyful', '#interesting', 0.137, 'cold_outside', 'coldness', 'icy', 'ice_crystal', 'bitter']
senticnet['cold-blooded'] = [0, 0, 0.073, 0, '#angry', '#angry', -0.024, 'amphibian', 'reptile', 'scaly', 'frog', 'aquatic']
senticnet['cold_air'] = [0.923, 0.994, 0, 0, '#joyful', '#interesting', 0.639, 'dew', 'fog', 'spray', 'sleet', 'cloudy']
senticnet['cold_bed'] = [0, 0, 0.943, -0.736, '#angry', '#disgusting', -0.56, 'get_cold', 'wet_clothes', 'become_cold', 'cold_food', 'cold_body']
senticnet['cold_beer'] = [0.186, -0.104, 0.046, 0, '#joyful', '#surprising', 0.081, 'hold_liquor', 'whisky', 'alcohol', 'adult_drink', 'liquor']
senticnet['cold_blood'] = [0, 0, 0.073, 0, '#angry', '#angry', -0.024, 'cold-blooded', 'reptile', 'scaly', 'blood', 'amphibian']
senticnet['cold_body'] = [0, 0, -0.895, -0.856, '#scared', '#disgusting', -0.584, 'get_cold', 'wet_clothes', 'cold_bed', 'cold_food', 'become_cold']
senticnet['cold_cereal'] = [-0.923, 0, 0.609, -0.745, '#sad', '#disgusting', -0.759, 'puffed_rice', 'granola', 'raisin_bran', 'corn_flake', 'bran_flake']
senticnet['cold_color'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'cyan', 'yellow_blue', 'violet', 'color', 'cool_color']
senticnet['cold_cuts'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'cheese', 'cheese_platter', 'cottage_cheese', 'platter', 'appetizer']
senticnet['cold_day'] = [0, 0.103, -0.083, 0.095, '#interesting', '#admirable', 0.038, 'darkness', 'no_sun', 'bleak', 'moon_star', 'before_night']
senticnet['cold_drink'] = [0.025, -0.062, 0, 0.135, '#surprising', '#admirable', 0.074, 'grocery', 'groceries', 'fresh_vegetable', 'vendor', 'goods']
senticnet['cold_flu'] = [-0.032, 0, -0.055, -0.159, '#scared', '#disgusting', -0.082, 'sign_sickness', 'sneeze', 'sleep_disorder', 'flu', 'narcolepsy']
senticnet['cold_food'] = [0, 0, 0.75, -0.715, '#angry', '#disgusting', -0.488, 'get_cold', 'wet_clothes', 'cold_bed', 'become_cold', 'cold_body']
senticnet['cold_foot'] = [-0.298, -0.137, 0.031, -0.283, '#sad', '#disgusting', -0.158, 'mistreat', 'lose_team', 'bird_prey', 'leave_out', 'cause_suffer']
senticnet['cold_gangrene'] = [-0.682, 0, 0.916, -0.912, '#angry', '#disgusting', -0.837, 'dry_gangrene', 'slough', 'mumification_necrosis', 'mummification', 'pathology']
senticnet['cold_head'] = [-0.042, 0, -0.092, -0.084, '#scared', '#disgusting', -0.073, 'keep_hair_short', 'hair_become_short', 'little_hair', 'short_hair', 'new_look']
senticnet['cold_hot'] = [-0.176, -0.073, 0, -0.159, '#sad', '#disgusting', -0.087, 'snow_storm', 'rain_snow', 'rainy', 'natural_phenomenon', 'weather_type']
senticnet['cold_night'] = [-0.294, 0.076, -0.118, 0.104, '#sad', '#scared', -0.077, 'windy', 'breeze', 'jacket', 'chilly', 'cuddle']
senticnet['cold_outside'] = [0.157, 0, 0, 0, '#joyful', '#joyful', 0.052, 'icy', 'cold', 'coldness', 'cold_weather', 'catch_rain']
senticnet['cold_person'] = [0, 0, 0.988, -0.711, '#angry', '#disgusting', -0.566, 'human', 'delusional', 'use_illegal_drug', 'busy_person', 'smart_man']
senticnet['cold_shoulder'] = [-0.755, 0, 0.666, -0.518, '#sad', '#angry', -0.646, 'discourtesy', 'snub', 'rebuff', 'offense', 'cut']
senticnet['cold_storage'] = [0.045, -0.053, 0, -0.029, '#joyful', '#surprising', 0.023, 'refrigerator', 'store_refrigerator', 'icebox', 'restaurant_storage_area', 'icy']
senticnet['cold_war'] = [-0.951, 0, 0.84, -0.979, '#sad', '#disgusting', -0.923, 'war', 'battle', 'fight', 'conflict', 'soldier']
senticnet['cold_water'] = [0.078, 0, 0, 0, '#joyful', '#joyful', 0.026, 'glass_water', 'refreshed', 'smoothie', 'lemonade', 'coke']
senticnet['cold_weather'] = [0.15, -0.025, 0, 0, '#joyful', '#surprising', 0.058, 'winter', 'winter_time', 'snow_fall', 'snowy', 'put_warm_clothes']
senticnet['cold_winter'] = [-0.969, 0, 0.172, -0.997, '#sad', '#disgusting', -0.713, 'severe_cold', 'cold', 'hypothermia', 'possibility_to_die', 'freeze']
senticnet['coldheartedness'] = [-0.848, 0, -0.739, 0, '#sad', '#scared', -0.529, 'hardheartedness', 'heartlessly', 'heartlessness', 'heartless', 'hardhearted']
senticnet['coldness'] = [0.094, 0, 0, 0, '#joyful', '#joyful', 0.031, 'ice_rain', 'cold_weather', 'snowy', 'cold', 'chilly']
senticnet['cole'] = [-0.569, 0, 0.892, -0.784, '#angry', '#disgusting', -0.748, 'borecrucifer', 'cruciferwort', 'kail', 'crucifer', 'kale']
senticnet['colewort'] = [-0.569, 0, 0.892, -0.784, '#angry', '#disgusting', -0.748, 'borecole', 'crucifer', 'kail', 'cole', 'kale']
senticnet['coliseum'] = [0.052, 0.118, 0.03, 0, '#joyful', '#interesting', 0.047, 'circular_route', 'cemetery', 'memorial', 'station', 'row_house']
senticnet['colitis'] = [-0.755, 0, 0.868, -0.992, '#angry', '#disgusting', -0.872, 'regional_enteritis', 'regional_ileitis', 'ulcerative_colitis', 'rubor', 'redness']
senticnet['collaborate'] = [0.979, 0.93, 0, 0.723, '#joyful', '#interesting', 0.877, 'information_transfer', 'tranfer', 'inform_person', 'inform_others', 'information']
senticnet['collaboration'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'educate_others', 'share_knowledge', 'share_opinion', 'discover_new', 'cooperation']
senticnet['collage'] = [0.043, 0.112, 0, 0, '#joyful', '#interesting', 0.052, 'art_object', 'drawing', 'artwork', 'gallery', 'sculpture']
senticnet['collage_film'] = [0.571, -0.701, 0, 0.941, '#surprising', '#admirable', 0.738, 'flick', 'movie', 'film', 'picture', 'moving_picture']
senticnet['collapse'] = [-0.133, -0.053, 0, -0.086, '#sad', '#disgusting', -0.055, 'monitor_heart_rate', 'feel_tired', 'bump_head', 'exhaustion', 'become_fatigued']
senticnet['collation'] = [0.789, -0.68, 0, 0.729, '#joyful', '#admirable', 0.733, 'refreshment', 'nosh', 'coffee_break', 'tea_break', 'meal']
senticnet['colleague'] = [0.05, 0.141, -0.073, 0.132, '#interesting', '#admirable', 0.083, 'public_servant', 'worker', 'manager', 'laborer', 'office_job']
senticnet['collect'] = [0, -0.853, 0, 0.808, '#surprising', '#admirable', 0.554, 'add_two_numbers', 'delight_audience', 'amuse_child', 'bounce_up_down', 'make_move']
senticnet['collect_data'] = [0, 0.716, 0, 0.741, '#interesting', '#admirable', 0.486, 'listen_heart', 'make_drawing', 'make_noise', 'backup', 'make_a_lot_of_noise']
senticnet['collect_debt'] = [0, 0.117, -0.048, 0.089, '#interesting', '#admirable', 0.053, 'get_money', 'get_paid', 'receive_money', 'collect_money', 'pay_service']
senticnet['collect_information'] = [0.574, 0.561, 0, 0.795, '#joyful', '#admirable', 0.643, 'take_note', 'transfer_information', 'take_note_class', 'search_information', 'listen_lecture']
senticnet['collect_item'] = [0, 0, 0, 0.101, '#admirable', '#admirable', 0.034, 'collector', 'numismatics', 'coin', 'collect', 'stamp']
senticnet['collect_money'] = [-0.1, 0.272, -0.147, 0.15, '#interesting', '#admirable', 0.058, 'give_change', 'settle_bill', 'pay_back', 'owe_money', 'make_change']
senticnet['collect_ticket'] = [-0.091, 0, -0.05, 0, '#sad', '#scared', -0.047, 'buy_ticket', 'purchase_ticket', 'ticket', 'sell_ticket', 'pay_ticket']
senticnet['collectible'] = [0.031, -0.108, 0, 0, '#joyful', '#surprising', 0.046, 'teddy_bear', 'beanie_baby', 'yo-yo', 'board_game', 'toy']
senticnet['collectibles'] = [0.086, -0.107, 0.064, 0, '#joyful', '#surprising', 0.043, 'art_piece', 'lifetime', 'museum', 'vintage', 'ancient_artifact']
senticnet['collection'] = [0, 0.188, -0.082, 0.137, '#interesting', '#admirable', 0.081, 'clique', 'several_people', 'big_group', 'group', 'mob']
senticnet['collective_intelligence'] = [0.487, 0.675, -0.267, 0.266, '#joyful', '#interesting', 0.387, 'solve_big_problem', 'gather_intelligence', 'intelligent', 'team_work', 'clever']
senticnet['collector'] = [0, 0, 0, 0.101, '#admirable', '#admirable', 0.034, 'child', 'young_child', 'numismatics', 'collect_item', 'stamp']
senticnet['collector_item'] = [0.808, -0.981, 0, 0.628, '#joyful', '#surprising', 0.806, 'curio', 'oddity', 'curiosity', 'peculiarity', 'oddment']
senticnet['college'] = [-0.883, 0, 0, -0.863, '#sad', '#disgusting', -0.582, 'school', 'school_system', 'class', 'time_waster', 'time_waster_class']
senticnet['college_class'] = [0.2, 0.154, -0.08, 0.166, '#joyful', '#admirable', 0.147, 'laboratory', 'elementary_school', 'science_class', 'lab', 'school_session']
senticnet['college_course'] = [0.93, 0.734, 0, 0.958, '#joyful', '#admirable', 0.874, 'scholar', 'school_division', 'group_student', 'pupil', 'learning_place']
senticnet['college_degree'] = [0.059, 0, 0, 0.076, '#joyful', '#admirable', 0.045, 'college_student', 'teacher', 'graduate_student', 'professor', 'student']
senticnet['college_dorm'] = [0, 0, 0.012, -0.063, '#angry', '#disgusting', -0.025, 'shack', 'cabin', 'hostel', 'dormitory', 'student_home']
senticnet['college_girl'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'lowerclassman', 'underclassman', 'senior', 'undergrad', 'collegian']
senticnet['college_major'] = [0, 0.084, 0, 0.065, '#interesting', '#admirable', 0.05, 'physic', 'chemistry', 'science', 'geology', 'school_course']
senticnet['college_professor'] = [0.904, 0.932, 0, 0.976, '#interesting', '#admirable', 0.937, 'reliability', 'husband_wife', 'good_teacher', 'smart_man', 'voyeur']
senticnet['college_student'] = [0.059, 0, 0, 0.076, '#joyful', '#admirable', 0.045, 'college_degree', 'teacher', 'graduate_student', 'professor', 'student']
senticnet['college_teacher'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'lecturer', 'teacher', 'instructor', 'professor', 'teach_lesson']
senticnet['college_tuition'] = [-0.077, 0, 0.073, -0.262, '#sad', '#disgusting', -0.137, 'tuition', 'private_tuition', 'pay_tuition', 'enroll_class', 'enroll_school']
senticnet['collegian'] = [-0.519, 0, 0.762, -0.861, '#angry', '#disgusting', -0.714, 'lowerclassman', 'underclassman', 'senior', 'college_girl', 'undergrad']
senticnet['collide'] = [-0.129, 0, -0.092, -0.042, '#sad', '#scared', -0.088, 'hold_two_together', 'install_window', 'float_through_air', 'spring_up', 'collision']
senticnet['collide_with'] = [-0.536, 0, 0.57, -0.732, '#angry', '#disgusting', -0.613, 'run_into', 'strike', 'hit', 'impinge_on', 'bump_into']
senticnet['collision'] = [-0.936, 0, 0, -0.724, '#sad', '#disgusting', -0.553, 'trauma', 'car_wreck', 'broken_bone', 'bad_knee', 'wreck']
senticnet['colly'] = [-0.623, 0, 0.713, -0.985, '#angry', '#disgusting', -0.774, 'muddy_up', 'muck_up', 'foul', 'blemish', 'smear']
senticnet['cologne'] = [0.053, 0.078, 0, 0, '#joyful', '#interesting', 0.044, 'wash_clothes', 'wash_oneself', 'clean_clothes', 'get_clean', 'wash_hand']
senticnet['colonnaded'] = [0.897, -0.985, 0, 0.692, '#joyful', '#surprising', 0.858, 'amphistylar', 'columned', 'pillared', 'columnar', 'columniform']
senticnet['colony'] = [0, 0, 0, 0.744, '#admirable', '#admirable', 0.248, 'committee', 'association', 'egalitarian_society', 'organization', 'population']
senticnet['color'] = [0.053, 0.078, 0, 0, '#joyful', '#interesting', 0.044, 'colorful', 'bright_color', 'secondary_color', 'color_rainbow', 'primary_color']
senticnet['color_bar'] = [-0.077, 0, 0.073, -0.262, '#sad', '#disgusting', -0.137, 'iron_curtain', 'bamboo_curtain', 'ideological_barrier', 'color_line', 'barrier']
senticnet['color_blindness'] = [-0.743, 0, 0.793, -0.625, '#sad', '#angry', -0.72, 'visual_impairment', 'visual_defect', 'vision_defect', 'visual_disorder', 'monochromacy']
senticnet['color_glass'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'see_out', 'house_open', 'stain_glass', 'open_close', 'look_out']
senticnet['color_line'] = [-0.765, 0, 0.692, -0.845, '#sad', '#disgusting', -0.767, 'iron_curtain', 'bamboo_curtain', 'color_bar', 'ideological_barrier', 'barrier']
senticnet['color_paint'] = [0, 0, 0.046, -0.037, '#angry', '#disgusting', -0.028, 'many_shades', 'paint', 'bright_color', 'color', 'secondary_color']
senticnet['color_paper'] = [0, -0.959, 0, 0.719, '#surprising', '#admirable', 0.559, 'photo_copy', 'writing_paper', 'printing_paper', 'note_book', 'white_paper']
senticnet['color_rainbow'] = [0, 0.907, 0, 0.929, '#interesting', '#admirable', 0.612, 'colorful', 'color', 'bright_color', 'happiness', 'primary_color']
senticnet['color_red'] = [-0.025, 0, 0.068, 0, '#sad', '#angry', -0.031, 'finite', 'danger', 'attention', 'stop', 'bright_red']
senticnet['color_vision_deficiency'] = [-0.728, 0, 0.736, -0.957, '#angry', '#disgusting', -0.807, 'visual_impairment', 'visual_defect', 'vision_defect', 'visual_disorder', 'monochromacy']
senticnet['coloradillo'] = [0.938, -0.773, 0, 0.944, '#joyful', '#admirable', 0.885, 'bush', 'scarlet_bush', 'scarlet_hamelia', 'hamelia', 'shrub']
senticnet['coloration'] = [0.62, -0.598, 0, 0.967, '#joyful', '#admirable', 0.728, 'rainbow', 'color', 'paint', 'colorful', 'protective_coloration']
senticnet['colored_green'] = [0, 0.152, -0.088, 0.208, '#interesting', '#admirable', 0.091, 'to_go', 'plant', 'depart', 'green_color', 'tree']
senticnet['colorful'] = [0.043, 0.084, 0, 0.139, '#interesting', '#admirable', 0.089, 'sexual', 'pink', 'fragrant', 'purple', 'green']
senticnet['colossus'] = [-0.881, 0, 0.882, -0.586, '#sad', '#angry', -0.783, 'mortal', 'behemoth', 'unusual_person', 'aberrant', 'giant']
senticnet['colourful'] = [0.528, -0.685, 0, 0.798, '#surprising', '#admirable', 0.67, 'gay', 'showy', 'picturesque', 'sporty', 'brave']
senticnet['colposcope'] = [0.255, 0.182, -0.06, 0.314, '#joyful', '#admirable', 0.23, 'doctor_office', 'urethroscope', 'sigmoidoscope', 'hospital', 'check_health']
senticnet['colt'] = [0, 0, 0, -0.12, '#disgusting', '#disgusting', -0.04, 'big_gun', 'explosive_device', 'firearm', 'cannon', 'civil_war']
senticnet['columbus'] = [0.731, 0, 0, 0.843, '#joyful', '#admirable', 0.525, 'find_country', 'learn_much', 'know', 'find_america', 'become_knowledgeable']
senticnet['column'] = [0.076, 0, 0, 0.104, '#joyful', '#admirable', 0.06, 'post', 'newspaper_article', 'rail', 'paper_sign', 'peg']
senticnet['column_chromatography'] = [0.838, -0.618, 0, 0.556, '#joyful', '#surprising', 0.671, 'activity', 'natural_process', 'natural_action', 'chromatography', 'paper_chromatography']
senticnet['columnar'] = [0.897, -0.985, 0, 0.692, '#joyful', '#surprising', 0.858, 'amphistylar', 'colonnaded', 'pillared', 'columned', 'columniform']
senticnet['columned'] = [0.897, -0.985, 0, 0.692, '#joyful', '#surprising', 0.858, 'amphistylar', 'colonnaded', 'pillared', 'columnar', 'columniform']
senticnet['columniform'] = [0.897, -0.985, 0, 0.692, '#joyful', '#surprising', 0.858, 'amphistylar', 'colonnaded', 'pillared', 'columnar', 'columned']
senticnet['coma'] = [-0.107, 0.068, -0.154, -0.137, '#scared', '#disgusting', -0.11, 'loss_of_consciousness', 'concussion', 'control_machine', 'sick', 'crowd_room']
senticnet['comb'] = [0, -0.732, 0, 0.972, '#surprising', '#admirable', 0.568, 'barrette', 'haircut_scissor', 'sculpt_gel', 'hair_shape_gel', 'hair_gel']
senticnet['comb_hair'] = [0, 0.152, -0.088, 0.208, '#interesting', '#admirable', 0.091, 'make_hair_look_nice', 'arrange_hair', 'fix_hair', 'groom_hair', 'style_hair']
senticnet['comb_jelly'] = [-0.79, 0, 0.709, -0.854, '#sad', '#disgusting', -0.784, 'animal', 'animate_being', 'ctenophore', 'invertebrate', 'beast']
senticnet['combat'] = [-0.068, 0, -0.099, -0.188, '#scared', '#disgusting', -0.118, 'big_fight', 'battle', 'fight', 'war', 'conflict']
senticnet['combat_fatigue'] = [-0.754, 0, 0.87, -0.514, '#sad', '#angry', -0.713, 'battle_fatigue', 'posttraumatic_stress_disorder', 'combat_neurosis', 'shell_shock', 'anxiety_disorder']
senticnet['combat_neurosis'] = [-0.754, 0, 0.87, -0.514, '#sad', '#angry', -0.713, 'battle_fatigue', 'combat_fatigue', 'posttraumatic_stress_disorder', 'shell_shock', 'anxiety_disorder']
senticnet['combatant'] = [0.833, -0.974, 0, 0.91, '#surprising', '#admirable', 0.906, 'fencer', 'battler', 'belligerent', 'fighter', 'scrapper']
senticnet['combination'] = [0.03, 0.215, -0.064, 0.18, '#interesting', '#admirable', 0.12, 'combo', 'hold_coin', 'money_storage', 'money_place', 'money_holder']
senticnet['combinative'] = [-0.938, 0, 0.944, -0.922, '#sad', '#angry', -0.935, 'integrative', 'combinatory', 'consolidative', 'unifying', 'combinatorial']
senticnet['combinatorial'] = [-0.938, 0, 0.944, -0.922, '#sad', '#angry', -0.935, 'combinative', 'combinatory', 'consolidative', 'unifying', 'integrative']
senticnet['combinatory'] = [-0.938, 0, 0.944, -0.922, '#sad', '#angry', -0.935, 'combinative', 'integrative', 'consolidative', 'unifying', 'combinatorial']
senticnet['combine'] = [0, -0.946, 0, 0.861, '#surprising', '#admirable', 0.602, 'join_together', 'final', 'include', 'math_function', 'bring_together']
senticnet['combine_above'] = [0, 0.082, 0, 0.107, '#interesting', '#admirable', 0.063, 'fuse_together', 'oneself', 'type_of_store', 'combine', 'multiple_people']
senticnet['combine_sound'] = [0.067, 0.193, 0, 0.294, '#interesting', '#admirable', 0.185, 'compose_music', 'placement', 'small_group', 'mix_tracks', 'location']
senticnet['combo'] = [0.03, 0.215, -0.064, 0.18, '#interesting', '#admirable', 0.12, 'combination', 'hold_coin', 'money_storage', 'money_place', 'money_holder']
senticnet['combo_pass'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'theme_park', 'short_cut', 'save_time', 'multiple_entry', 'ticket']
senticnet['combustible'] = [-0.767, 0, -0.931, 0, '#sad', '#scared', -0.566, 'flame', 'flammable', 'dangerous', 'incendiary', 'heat']
senticnet['combustible_material'] = [0, 0, -0.064, -0.099, '#scared', '#disgusting', -0.054, 'fire', 'todd', 'wood_pulp', 'steel_wool', 'campfire']
senticnet['combustion'] = [-0.904, 0, 0.825, -0.61, '#sad', '#angry', -0.78, 'flaming', 'deflagration', 'fire', 'flame', 'internal_combustion']
senticnet['come'] = [-0.03, 0.212, -0.176, 0.33, '#interesting', '#admirable', 0.112, 'arrive', 'tow', 'take', 'permission', 'continue']
senticnet['come_across'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'stumble', 'tripped_over', 'lose_balance', 'stammer', 'stutter']
senticnet['come_back'] = [0.04, 0.269, -0.202, 0.251, '#interesting', '#admirable', 0.119, 'donation', 'investment_return', 'extra_money', 'pay_back', 'return']
senticnet['come_back_home'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'travel', 'get_plane', 'get_bus', 'go_new_place', 'reach_destination']
senticnet['come_conclusion'] = [-0.091, 0.106, 0, 0.093, '#interesting', '#admirable', 0.036, 'figure_out', 'revelation', 'arrive_conclusion', 'resolve_problem', 'deduce']
senticnet['come_decision'] = [0.833, 0.976, 0, 0, '#joyful', '#interesting', 0.603, 'consider_fact', 'look_evidence', 'sit_jury', 'find_out_fact', 'make_decision']
senticnet['come_down'] = [0, -0.907, 0, 1.0, '#surprising', '#admirable', 0.636, 'down', 'snow', 'water_fall', 'water_drop', 'water_droplet']
senticnet['come_early'] = [0, 0.787, 0, 0.977, '#interesting', '#admirable', 0.588, 'wait_patiently', 'learn_patience', 'conformist_attitude', 'line_up', 'stand_queue']
senticnet['come_from'] = [0.102, 0.142, -0.081, 0.224, '#interesting', '#admirable', 0.129, 'origin', 'from_here', 'travel', 'source', 'place_of_origin']
senticnet['come_house'] = [-0.097, 0, -0.062, 0, '#sad', '#scared', -0.053, 'needy', 'laugh_oneself', 'welcome_friend', 'captain_boat', 'page_person']
senticnet['come_in'] = [0.686, -0.776, 0, 0.797, '#surprising', '#admirable', 0.753, 'get_on', 'board', 'intrude', 'irrupt', 'invade']
senticnet['come_off'] = [0.829, 0, 0, 0.928, '#joyful', '#admirable', 0.586, 'same_answer', 'organic_material', 'natural', 'fluffy_white', 'come_out']
senticnet['come_out'] = [0, 0, 0, 0.861, '#admirable', '#admirable', 0.287, 'become_known', 'debut', 'become_famous', 'vip', 'admit']
senticnet['come_out_and_play'] = [0.967, 0.785, 0, 0.958, '#joyful', '#admirable', 0.903, 'play', 'travel_fast_light', 'live_ocean', 'eat_dog', 'control_weather']
senticnet['come_pair'] = [0.213, 0.273, -0.136, 0.29, '#interesting', '#admirable', 0.213, 'trip', 'stumble', 'almost_fall', 'move_upwards', 'swing_arm']
senticnet['come_through'] = [0.718, -0.729, 0, 0.928, '#surprising', '#admirable', 0.792, 'deliver_goods', 'succeed', 'win', 'bring_home_bacon', 'bring_off']
senticnet['come_to'] = [0.694, -0.567, 0, 0.888, '#joyful', '#admirable', 0.716, 'bear_on', 'touch', 'concern', 'go_for', 'refer']
senticnet['come_to_conclusion'] = [0.814, 0, 0, 0, '#joyful', '#joyful', 0.271, 'smart', 'act_smart', 'focus_attention', 'find_answer', 'solve_mystery']
senticnet['come_to_nothing'] = [-0.973, 0, 0.009, -0.929, '#sad', '#disgusting', -0.637, 'without_end_product', 'waste_of_time', 'failure', 'unsuccessful', 'no_result']
senticnet['come_together'] = [0.094, 0.193, -0.092, 0.261, '#interesting', '#admirable', 0.152, 'bring_together', 'join', 'together', 'membership', 'organize_group']
senticnet['come_true'] = [-0.08, 0.199, -0.098, 0.168, '#interesting', '#admirable', 0.063, 'imaginative', 'lie', 'falsehood', 'night_vision', 'lucid']
senticnet['come_up'] = [0.055, 0.237, -0.114, 0.24, '#interesting', '#admirable', 0.139, 'sun_up', 'raise_up', 'move_upward', 'levitate', 'get_up']
senticnet['come_up_idea'] = [-0.063, 0.21, 0, 0.076, '#interesting', '#admirable', 0.074, 'creativity', 'figure_out', 'brain_activity', 'idea', 'eureka']
senticnet['come_up_new_idea'] = [0.829, 0.898, 0, 0, '#joyful', '#interesting', 0.576, 'come_conclusion', 'invention', 'resolve_problem', 'come_up_idea', 'figure_out']
senticnet['come_warranty'] = [-0.134, 0, 0, -0.035, '#sad', '#disgusting', -0.056, 'want_buy', 'determine_need', 'search_item', 'discuss_friend', 'ask_a_lot_of_question']
senticnet['comeback'] = [0.715, 0, 0, 0.783, '#joyful', '#admirable', 0.499, 'reply', 'response', 'rebound', 'backtalk', 'revival']
senticnet['comedian'] = [0.915, -0.728, 0, 0, '#joyful', '#surprising', 0.548, 'spread_happiness', 'give_pleasure', 'make_feel_happy', 'get_happy', 'make_laugh']
senticnet['comedy'] = [0.206, -0.138, 0, 0, '#joyful', '#surprising', 0.115, 'dancer', 'old_dance', 'dance', 'slow_dance', 'ballroom_dance']
senticnet['comer'] = [0.85, -0.894, 0, 0.634, '#joyful', '#surprising', 0.793, 'rival', 'competition', 'challenger', 'competitor', 'contender']
senticnet['comfort'] = [0.54, 0.398, -0.207, 0.251, '#joyful', '#interesting', 0.327, 'comfortable', 'calm', 'calmness', 'cozy', 'soothe']
senticnet['comfort_friend'] = [0.643, 0.69, 0, 0.874, '#interesting', '#admirable', 0.736, 'give_assistance', 'create_help_other_person', 'forgive', 'please_parent', 'make_better_world']
senticnet['comfort_woman'] = [-0.917, 0, 0.974, -0.612, '#sad', '#angry', -0.834, 'slattern', 'camp_follower', 'call_girl', 'bawd', 'ianfu']
senticnet['comfortable'] = [0.76, 0, 0, 0, '#joyful', '#joyful', 0.253, 'comfort', 'calm', 'peacefulness', 'ease', 'calmness']
senticnet['comfortable_chair'] = [0.749, 0, 0, 0, '#joyful', '#joyful', 0.25, 'warm_bed', 'alleyway', 'home', 'veterinarian_office', 'animal_shelter']
senticnet['comfortable_clothes'] = [0.303, 0.223, -0.08, 0.392, '#joyful', '#admirable', 0.279, 'complement', 'taken_seriously', 'much_need', 'live_long_healthy_life', 'nice_place_to_live']
senticnet['comfortable_house'] = [0.027, 0.075, 0, 0.144, '#interesting', '#admirable', 0.082, 'neat', 'keep_house_clean', 'expect_guest', 'tidy', 'tidy_up']
senticnet['comfortable_place_sleep'] = [0.165, 0, 0.032, 0.114, '#joyful', '#admirable', 0.082, 'good_sleep', 'shut_eye', 'place_sleep', 'use_bed', 'lie_down_bed']
senticnet['comfortable_position'] = [0, 0, -0.905, 0, '#scared', '#scared', -0.302, 'sleeping', 'asleep', 'take_nap', 'lie_back', 'comfort']
senticnet['comfortable_sit'] = [0.209, 0.115, 0, 0.109, '#joyful', '#interesting', 0.144, 'sit_furniture', 'sit_place', 'horizontal_surface', 'comfortable', 'comfortable_chair']
senticnet['comfortableness'] = [0.661, 0.641, -0.24, 0.309, '#joyful', '#interesting', 0.457, 'comfortably', 'solace', 'nigh', 'belonging', 'euphoric']
senticnet['comfortably'] = [0.661, 0.641, -0.24, 0.309, '#joyful', '#interesting', 0.457, 'comfortableness', 'solace', 'nigh', 'belonging', 'euphoric']
senticnet['comforter'] = [0, 0.092, 0.016, 0.074, '#interesting', '#admirable', 0.05, 'armoire', 'pillowcase', 'bed_sheet', 'duvet_cover', 'beach_towel']
senticnet['comforting'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'gratifyingly', 'satiable', 'satisfactorily', 'satisfyingly', 'cheering']
senticnet['comfy'] = [0.157, 0.126, 0, 0.166, '#joyful', '#admirable', 0.15, 'sleep_area', 'sleep_place', 'rest_place', 'restful', 'occur']
senticnet['comic'] = [0, -0.131, -0.053, 0.08, '#surprising', '#admirable', 0.053, 'child_book', 'disney_cartoon', 'enjoyment', 'children_story', 'biology_book']
senticnet['comic_book'] = [0, -0.171, -0.046, 0.091, '#surprising', '#admirable', 0.072, 'child_book', 'encyclopaedia', 'children_story', 'comic', 'disney_cartoon']
senticnet['comic_strip'] = [0.146, -0.217, -0.046, 0.139, '#joyful', '#surprising', 0.152, 'comic_book', 'cartoon', 'book', 'comic', 'old_lady_house']
senticnet['coming'] = [0.699, -0.836, 0, 0.919, '#surprising', '#admirable', 0.818, 'move', 'movement', 'access', 'closing', 'closure']
senticnet['comity'] = [0.742, -0.993, 0, 0.918, '#surprising', '#admirable', 0.884, 'peace', 'accord', 'concordance', 'agreement', 'order']
senticnet['command'] = [0, 0.221, -0.114, 0.192, '#interesting', '#admirable', 0.1, 'control', 'military_order', 'authority', 'hierarchy', 'rank']
senticnet['commander'] = [0.037, 0.097, 0, 0, '#joyful', '#interesting', 0.045, 'head_guy', 'navy_officer', 'navy_leader', 'police_rank', 'head_person']
senticnet['commemorate_event'] = [-0.772, 0, -0.9, 0, '#sad', '#scared', -0.557, 'remember', 'contemplation', 'remember_past', 'use_memory', 'honor_person']
senticnet['commence'] = [0, 0.276, -0.138, 0.309, '#interesting', '#admirable', 0.149, 'end_point', 'start', 'new_chapter', 'inclusion', 'start_adventure']
senticnet['commencement'] = [0.658, -0.521, 0, 0.626, '#joyful', '#admirable', 0.602, 'point_in_time', 'threshold', 'birth', 'incipiency', 'incipience']
senticnet['commend'] = [0.62, -0.993, 0, 0.621, '#surprising', '#admirable', 0.745, 'hand', 'entrust', 'reach', 'charge', 'give']
senticnet['commendable'] = [0.575, 0.636, -0.268, 0.318, '#joyful', '#interesting', 0.42, 'laudably', 'admirably', 'praiseworthily', 'look_up_to', 'admirable']
senticnet['commendation'] = [0.857, -0.773, 0, 0.878, '#joyful', '#admirable', 0.836, 'hand', 'round', 'approval', 'clapping', 'handclap']
senticnet['comment'] = [-0.071, 0.112, -0.062, 0.191, '#interesting', '#admirable', 0.057, 'response', 'remark', 'answer_back', 'retort', 'explain']
senticnet['commerce'] = [0, 0.148, 0, 0.167, '#interesting', '#admirable', 0.105, 'economics', 'economic_activity', 'exchange_goods', 'make_rich', 'sell']
senticnet['commercial'] = [0, -0.01, -0.064, -0.073, '#scared', '#disgusting', -0.042, 'satire', 'presentation', 'circus_performer', 'demonstrate', 'ads']
senticnet['commercial_document'] = [0.921, -0.571, 0, 0.962, '#joyful', '#admirable', 0.818, 'book_token', 'meal_ticket', 'luncheon_voucher', 'twofer', 'coupon']
senticnet['commination'] = [0.638, -0.838, 0, 0.852, '#surprising', '#admirable', 0.776, 'blessing', 'grace', 'orison', 'benediction', 'supplication']
senticnet['commingle'] = [0, 0, 0.977, -0.775, '#angry', '#disgusting', -0.584, 'flux', 'mix', 'blend', 'conflate', 'immix']
senticnet['commiserate'] = [-0.931, 0, 0, -0.818, '#sad', '#disgusting', -0.583, 'sympathize', 'commiseration', 'feel_sorry', 'ruth', 'pathos']
senticnet['commiseration'] = [0.702, 0, 0, 0.928, '#joyful', '#admirable', 0.543, 'sympathize', 'commiserate', 'feel_sorry', 'ruth', 'pathos']
senticnet['commissioned'] = [-0.784, 0, 0.657, -0.868, '#sad', '#disgusting', -0.77, 'authorized', 'accredited', 'licensed', 'licenced', 'approved']
senticnet['commissure'] = [0.683, -0.918, 0, 0.679, '#joyful', '#surprising', 0.76, 'pathway', 'corpus_callosum', 'nerve_pathway', 'tract', 'nerve_tract']
senticnet['commit'] = [0.702, 0, 0, 0.928, '#joyful', '#admirable', 0.543, 'propose_woman', 'kiss', 'commit_to_memory', 'love', 'marriage']
senticnet['commit_crime'] = [-0.93, 0, 0.408, -0.923, '#sad', '#disgusting', -0.754, 'kill', 'murder', 'kill_person', 'kill_someone', 'crime']
senticnet['commit_genocide'] = [-0.117, 0, -0.095, -0.086, '#sad', '#scared', -0.099, 'hunt_game', 'arm_bomb', 'kill_man', 'guard_bank', 'drug_addiction']
senticnet['commit_murder'] = [-0.721, 0, 0.623, -0.688, '#sad', '#disgusting', -0.677, 'murder_another_person', 'kill_person', 'kill', 'take_life', 'kill_man']
senticnet['commit_perjury'] = [0, 0, -0.973, -0.837, '#scared', '#disgusting', -0.603, 'forswear_oneself', 'fabricate', 'prejure_oneself', 'misrepresent', 'prevaricate']
senticnet['commit_suicide'] = [-0.036, -0.055, -0.062, -0.098, '#scared', '#disgusting', -0.047, 'apnea', 'eat_poison', 'drunk_drive', 'drug_addiction', 'cut_oneself']
senticnet['commit_to_memory'] = [0, 0.148, 0, 0.167, '#interesting', '#admirable', 0.105, 'memorize', 'learn_science', 'learn_subject', 'commit', 'study']
senticnet['commitment'] = [0, 0, 0, 0.704, '#admirable', '#admirable', 0.235, 'engage', 'vow', 'want_badly', 'demand', 'holy_matrimony']
senticnet['committee'] = [0.051, 0.154, -0.068, 0.07, '#interesting', '#admirable', 0.069, 'organization', 'association', 'tribe', 'majority', 'egalitarian_society']
senticnet['commode'] = [0.778, -0.932, 0, 0.578, '#joyful', '#surprising', 0.763, 'flushless_toilet', 'flush_toilet', 'lavatory', 'potty_seat', 'potty_chair']
senticnet['common'] = [0, 0.212, -0.065, 0.138, '#interesting', '#admirable', 0.095, 'ordinary', 'usual', 'typical', 'normal', 'usual_ordinary']
senticnet['common_bean'] = [0.861, -0.549, 0, 0.976, '#joyful', '#admirable', 0.795, 'kidney_bean', 'frijol', 'frijole', 'green_bean', 'wax_bean']
senticnet['common_burdock'] = [0.683, -0.547, 0, 0.568, '#joyful', '#admirable', 0.599, 'subshrub', 'suffrutex', 'burdock', 'lesser_burdock', 'great_burdock']
senticnet['common_caper'] = [0.683, -0.547, 0, 0.568, '#joyful', '#admirable', 0.599, 'bush', 'native_pomegranate', 'caper_tree', 'native_orange', 'caper']
senticnet['common_chickweed'] = [0.683, -0.547, 0, 0.568, '#joyful', '#admirable', 0.599, 'herb', 'chickweed', 'stitchwort', 'greater_stitchwort', 'starwort']
senticnet['common_cold'] = [0, 0, -0.897, -0.712, '#scared', '#disgusting', -0.536, 'runny_nose', 'allergy', 'savor', 'flu', 'sign_sickness']
senticnet['common_emotion'] = [-0.184, -0.131, -0.224, -0.119, '#sad', '#scared', -0.132, 'psychoneurosis', 'paper_cut', 'feel_hurt', 'ridicule', 'startle']
senticnet['common_good'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'same_interest', 'group_of_people', 'community', 'similar_like', 'common_interest']
senticnet['common_interest'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'same_interest', 'group_of_people', 'community', 'similar_like', 'common_good']
senticnet['common_knowledge'] = [0.745, -0.771, 0, 0.655, '#joyful', '#surprising', 0.724, 'light', 'open', 'general_knowledge', 'surface', 'cognition']
senticnet['common_land'] = [-0.907, 0, 0.765, -0.98, '#sad', '#disgusting', -0.884, 'pastureland', 'grazing_land', 'ley', 'pasture', 'lea']
senticnet['common_language'] = [0.097, -0.011, 0.026, 0.144, '#joyful', '#admirable', 0.075, 'universal_language', 'melodic_noise', 'audio', 'instrumental', 'human_sound']
senticnet['common_mallow'] = [0.683, -0.547, 0, 0.568, '#joyful', '#admirable', 0.599, 'bush', 'musk_mallow', 'mus_rose', 'mallow', 'tall_mallow']
senticnet['common_man'] = [0.813, 0, 0, 0.874, '#joyful', '#admirable', 0.562, 'sophisticated', 'lovely', 'elegant', 'contrary', 'feminine']
senticnet['common_name'] = [0.024, 0, 0, 0.05, '#joyful', '#admirable', 0.025, 'metal_container', 'thin_metal', 'metal_alloy', 'metal_type', 'silver_metal']
senticnet['common_pet'] = [0, 0, 0, -0.873, '#disgusting', '#disgusting', -0.291, 'domestic_pet', 'popular_pet', 'similar', 'nothing_special', 'common']
senticnet['common_practice'] = [0.974, 0.789, 0, 0.828, '#joyful', '#admirable', 0.864, 'daily_routine', 'eternal', 'eat_breakfast', 'routine', 'good_trait']
senticnet['common_scold'] = [-0.718, 0, 0.972, -0.625, '#sad', '#angry', -0.772, 'scold', 'nag', 'scolder', 'nagger', 'harridan']
senticnet['common_sense'] = [0, 0, 0, 0.951, '#admirable', '#admirable', 0.317, 'wit', 'culture', 'eat_fruit', 'take_ticket', 'adapt']
senticnet['common_wart'] = [-0.585, 0, 0.727, -0.596, '#angry', '#disgusting', -0.636, 'blemish', 'keratosis', 'mar', 'defect', 'verruca']
senticnet['common_water_snake'] = [-0.514, 0, 0.625, -0.984, '#angry', '#disgusting', -0.708, 'water_snake', 'banded_water_snake', 'water_moccasin', 'grass_snake', 'ring_snake']
senticnet['common_watercress'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'marsh_cress', 'yellow_watercress', 'mountain_watercress', 'watercress', 'great_yellowcress']
senticnet['common_white_dogwood'] = [0.773, -0.55, 0, 0.949, '#joyful', '#admirable', 0.757, 'bunchberry', 'dwarf_cornel', 'crackerberry', 'pudding_berry', 'cornel']
senticnet['commonly'] = [0.05, 0, 0.049, 0.071, '#joyful', '#admirable', 0.024, 'dairy_product', 'high_protein', 'type_of_food', 'food_item', 'tree_fruit']
senticnet['commonness'] = [0.989, -0.997, 0, 0.728, '#joyful', '#surprising', 0.905, 'quality', 'tastelessness', 'sleaziness', 'coarseness', 'inelegance']
senticnet['commonplace'] = [-0.793, 0, 0, -0.992, '#sad', '#disgusting', -0.595, 'cliche', 'banality', 'prosaic', 'unexciting', 'humdrum']
senticnet['commonplaceness'] = [0.741, -0.748, 0, 0.666, '#joyful', '#surprising', 0.718, 'mundaneness', 'mundanity', 'prosiness', 'prosaicness', 'ordinariness']
senticnet['commons'] = [-0.726, 0, 0.978, -0.861, '#angry', '#disgusting', -0.855, 'amusement_park', 'funfair', 'pleasure_ground', 'village_green', 'tract']
senticnet['commonsense'] = [0.843, -0.6, 0, 0.698, '#joyful', '#admirable', 0.714, 'levelheaded', 'sound', 'healthy', 'sensible', 'commonsensible']
senticnet['commonsensible'] = [0.843, -0.6, 0, 0.698, '#joyful', '#admirable', 0.714, 'levelheaded', 'sound', 'healthy', 'commonsense', 'sensible']
senticnet['commonwealth'] = [0.716, -0.51, 0, 0.647, '#joyful', '#admirable', 0.624, 'state', 'nation', 'country', 'land', 'ally']
senticnet['commotion'] = [-0.701, 0, 0.725, -0.523, '#sad', '#angry', -0.65, 'turmoil', 'convulsion', 'tempest', 'disorder', 'earthquake']
senticnet['commove'] = [-0.747, 0, 0.69, -0.683, '#sad', '#angry', -0.707, 'upset', 'hype_up', 'psych_up', 'bother', 'trouble']
senticnet['communicate'] = [0.856, -0.868, 0, 0, '#joyful', '#surprising', 0.575, 'dictation', 'verbal', 'beckon', 'call', 'phone_conversation']
senticnet['communicate_family'] = [0.881, 0, 0, 0.724, '#joyful', '#admirable', 0.535, 'communicate_with_others', 'communicate_idea', 'exchange_information', 'social_life', 'keep_in_touch']
senticnet['communicate_friend'] = [0.072, -0.02, 0, 0, '#joyful', '#surprising', 0.031, 'communicate_person', 'teach_new', 'communicate_other_person', 'engage_conversation', 'exchange_information']
senticnet['communicate_idea'] = [0.881, 0, 0, 0.724, '#joyful', '#admirable', 0.535, 'communicate_with_others', 'communicate_family', 'exchange_information', 'social_life', 'keep_in_touch']
senticnet['communicate_other_person'] = [0.881, 0, 0, 0.724, '#joyful', '#admirable', 0.535, 'communicate_person', 'communicate_idea', 'communicate_friend', 'engage_conversation', 'exchange_information']
senticnet['communicate_person'] = [0.849, 0, 0, 0.861, '#joyful', '#admirable', 0.57, 'exchange_idea', 'social_life', 'keep_in_touch', 'give_information', 'exchange_information']
senticnet['communicate_thought'] = [0.963, 0.606, 0, 0.955, '#joyful', '#admirable', 0.841, 'represent_idea', 'convey_message', 'communicate', 'send_message', 'record_data']
senticnet['communicate_with_others'] = [0.881, 0, 0, 0.724, '#joyful', '#admirable', 0.535, 'communicate_family', 'communicate_idea', 'exchange_information', 'social_life', 'keep_in_touch']
senticnet['communication'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'discuss', 'autograph', 'communicate_person', 'talk_another_person', 'discussion']
senticnet['communication_method'] = [0, 0.077, 0, 0.154, '#interesting', '#admirable', 0.077, 'form_of_communication', 'note_down', 'written_language', 'written_communication', 'written_note']
senticnet['communication_system'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'land_fish', 'fish', 'catch_fish', 'triathlon', 'bait']
senticnet['communicativeness'] = [0.664, -0.941, 0, 0.613, '#joyful', '#surprising', 0.739, 'outspokenness', 'frankness', 'garrulity', 'garrulousness', 'loquaciousness']
senticnet['communicator'] = [0.874, 0.734, 0, 0, '#joyful', '#interesting', 0.536, 'mouth_noise', 'vocal_cord', 'vocalization', 'vocal_sound', 'loud_soft']
senticnet['communicatory'] = [-0.607, 0, 0.523, -0.959, '#sad', '#disgusting', -0.696, 'blabbermouthed', 'expansive', 'heraldic', 'talkative', 'leaky']
senticnet['communism'] = [0.045, 0.286, -0.142, 0.229, '#interesting', '#admirable', 0.139, 'socialism', 'parliament', 'elect', 'government', 'elect_president']
senticnet['communist'] = [0, 0, -0.744, -0.82, '#scared', '#disgusting', -0.521, 'settle_disagreement', 'hitler', 'republican', 'conservative', 'kill_another_person']
senticnet['community'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'common_interest', 'group_of_people', 'urban', 'many_people', 'metropolis']
senticnet['commutable'] = [0.623, -0.566, 0, 0.974, '#joyful', '#admirable', 0.721, 'alterable', 'convertible', 'translatable', 'transformable', 'transmutable']
senticnet['commute'] = [-0.047, -0.014, 0, -0.062, '#sad', '#disgusting', -0.032, 'drive_to_work', 'transportation', 'go_to_work', 'drive', 'drive_car']
senticnet['commute_work'] = [0.916, -0.831, 0, 0, '#joyful', '#surprising', 0.582, 'get_around_town', 'get_place', 'sightsee', 'get_school', 'place_of_work']
senticnet['commuter'] = [-0.029, 0, 0, -0.079, '#sad', '#disgusting', -0.036, 'manager', 'investigator', 'slut', 'seeker', 'chairperson']
senticnet['compact_disc'] = [0.738, 0.943, 0, 0, '#joyful', '#interesting', 0.56, 'cassette', 'cd-rom', 'music_storage', 'store_music', 'disc']
senticnet['companion'] = [0.756, 0, 0, 0, '#joyful', '#joyful', 0.252, 'companionship', 'cherish', 'lover', 'significant_other', 'buddy']
senticnet['companionship'] = [0.746, 0, 0, 0.907, '#joyful', '#admirable', 0.551, 'foreplay', 'enjoy_company', 'new_friendship', 'friendship', 'make_new_friend']
senticnet['company'] = [0.111, 0.18, 0, 0.128, '#interesting', '#admirable', 0.14, 'corporation', 'partnership', 'large_business', 'business_organization', 'enterprise']
senticnet['company_come'] = [0.058, 0, 0, 0.074, '#joyful', '#admirable', 0.044, 'expect_guest', 'clean_floor', 'give_thank', 'wipe_up_spill', 'keep_house_clean']
senticnet['company_name'] = [0.075, 0.148, -0.077, 0.094, '#interesting', '#admirable', 0.08, 'special_person', 'group_of_people', 'masculine', 'member_of_family', 'male_person']
senticnet['comparative'] = [-0.05, 0.286, -0.206, 0.351, '#interesting', '#admirable', 0.127, 'compare', 'similar', 'different', 'same', 'encompass']
senticnet['compare'] = [0, 0.342, -0.118, 0.309, '#interesting', '#admirable', 0.178, 'rate', 'estimate', 'determine', 'bail', 'excise']
senticnet['compare_price'] = [0.924, 0.839, 0, 0, '#joyful', '#interesting', 0.588, 'money_spend', 'look_price', 'decide_buy', 'cash_check', 'pay_money']
senticnet['comparing'] = [-0.946, 0, 0.904, -0.751, '#sad', '#angry', -0.867, 'confrontation', 'contrast', 'scrutiny', 'collation', 'likening']
senticnet['comparison'] = [0.118, 0.181, -0.076, 0.374, '#interesting', '#admirable', 0.199, 'compare', 'confrontation', 'collation', 'comparative', 'paragon']
senticnet['comparison_shop'] = [0.831, 0.705, 0, 0, '#joyful', '#interesting', 0.512, 'spend_a_lot_of_money', 'window_shop', 'spend_much_money', 'check_price', 'compare_price']
senticnet['compartment'] = [0.069, 0.112, 0, 0.167, '#interesting', '#admirable', 0.116, 'cupboard', 'hangers', 'clothes_shelf', 'jeans', 'drawers']
senticnet['compass'] = [0.721, 0.884, 0, 0, '#joyful', '#interesting', 0.535, 'travel', 'find_way', 'help_travelling', 'compass_direction', 'use_compass']
senticnet['compass_direction'] = [0.066, 0.144, 0, 0.233, '#interesting', '#admirable', 0.148, 'direction', 'left_right', 'proximity', 'end_point', 'commence']
senticnet['compassion'] = [0.981, 0, 0, 0.706, '#joyful', '#admirable', 0.562, 'forgiveness', 'mercy', 'pity', 'concern', 'occupy']
senticnet['compassionate'] = [0.954, 0, 0, 0.964, '#joyful', '#admirable', 0.639, 'feel_for', 'sympathize_with', 'compassionateness', 'condole_with', 'commiserate']
senticnet['compassionateness'] = [0.918, 0, 0.73, 0.954, '#joyful', '#admirable', 0.381, 'sympathize_with', 'feel_for', 'condole_with', 'sympathize', 'commiserate']
senticnet['compatibility'] = [0.587, 0.698, -0.53, 0.52, '#joyful', '#interesting', 0.425, 'good_match', 'compatible', 'kind', 'kindhearted', 'kindheartedness']
senticnet['compatible'] = [0.587, 0.698, -0.53, 0.52, '#joyful', '#interesting', 0.425, 'good_match', 'compatibility', 'kind', 'kindhearted', 'kindheartedness']
senticnet['compatibly'] = [0.587, 0.698, -0.53, 0.52, '#joyful', '#interesting', 0.425, 'compatibility', 'kindheartedness', 'kind-hearted', 'kindhearted', 'kind-heartedness']
senticnet['compatriot'] = [0.052, 0, 0, 0.069, '#joyful', '#admirable', 0.04, 'philanthropist', 'nazi', 'man', 'pervert', 'healthy_person']
senticnet['compel'] = [0, 0, 0.88, -0.724, '#angry', '#disgusting', -0.535, 'cause_change', 'imperative', 'take_over', 'enforce', 'force']
senticnet['compensate'] = [0.846, -0.534, 0, 0.919, '#joyful', '#admirable', 0.766, 'correct', 'overcompensate', 'counterbalance', 'make_up', 'even_out']
senticnet['compensated'] = [0.521, -0.859, 0, 0.727, '#surprising', '#admirable', 0.702, 'paid', 'remunerated', 'paying', 'stipendiary', 'remunerative']
senticnet['compensation'] = [-0.03, 0.315, -0.128, 0.233, '#interesting', '#admirable', 0.13, 'give_money', 'money', 'earnings', 'earn_income', 'repay']
senticnet['compete'] = [0.887, 0, 0, 0, '#joyful', '#joyful', 0.296, 'fun', 'difficult_play', 'enjoy_sport', 'accept_challenge', 'competition']
senticnet['compete_against'] = [-0.029, 0.068, 0.017, 0.055, '#interesting', '#admirable', 0.026, 'compete', 'play_game_chess', 'score_home_run', 'play_chess', 'reach_advantage']
senticnet['compete_others'] = [0.747, 0.864, 0, 0, '#joyful', '#interesting', 0.537, 'traveling_water', 'recreation', 'fun_exercise', 'competition', 'get_physically_fit']
senticnet['compete_race'] = [0, 0, 0.87, -0.806, '#angry', '#disgusting', -0.559, 'go_fast_walk', 'tire', 'enjoy_fresh_air', 'enjoy_nature', 'movement_place_another']
senticnet['competence'] = [0, 0, 0, 0.879, '#admirable', '#admirable', 0.293, 'realize', 'knack', 'talent', 'ability', 'illustrate']
senticnet['competent'] = [0.982, -0.67, 0, 0.682, '#joyful', '#admirable', 0.778, 'workmanlike', 'effective', 'efficient', 'able', 'capable']
senticnet['competition'] = [0, 0, 0, 0.879, '#admirable', '#admirable', 0.293, 'sport_competition', 'win_competition', 'race', 'match', 'championship']
senticnet['competitive'] = [0, 0.706, 0, 0.714, '#interesting', '#admirable', 0.473, 'ambitious', 'driven', 'vying', 'combative', 'contentious']
senticnet['competitive_activity'] = [0, -0.787, 0, 0.995, '#surprising', '#admirable', 0.594, 'stuff_use_calculation', 'ridgeback', 'written_programmer', 'low_blood_pressure', 'minor_planet']
senticnet['competitive_nature'] = [0.827, 0.913, 0, 0.867, '#interesting', '#admirable', 0.869, 'good_habit', 'improve_oneself', 'competitive', 'fighting_spirit', 'want_to_win']
senticnet['competitive_spirit'] = [0.097, 0.166, -0.05, 0, '#joyful', '#interesting', 0.071, 'place_bet', 'self-motivation', 'deserve', 'need_job', 'down_payment']
senticnet['competitiveness'] = [-0.827, 0, 0, -0.751, '#sad', '#disgusting', -0.526, 'win_money', 'team_lose', 'winner_loser', 'fun', 'exercise_entertainment']
senticnet['competitor'] = [0.85, -0.894, 0, 0.634, '#joyful', '#surprising', 0.793, 'rival', 'competition', 'challenger', 'comer', 'contender']
senticnet['complacence'] = [0.788, 0.592, -0.207, 0.342, '#joyful', '#interesting', 0.505, 'complacent', 'complacency', 'self-complacency', 'self-satisfaction', 'self-complacent']
senticnet['complacency'] = [0.788, 0.592, -0.207, 0.342, '#joyful', '#interesting', 0.505, 'complacent', 'self-complacency', 'complacence', 'self-satisfaction', 'self-complacent']
senticnet['complacent'] = [-0.796, 0, 0, -0.738, '#sad', '#disgusting', -0.511, 'complacency', 'self-complacency', 'complacence', 'self_satisfaction', 'self_complacent']
senticnet['complain'] = [0, 0, 0.958, -0.813, '#angry', '#disgusting', -0.59, 'disagree', 'paranoid', 'yell', 'shout', 'scream']
senticnet['complain_state_world'] = [0, 0, 0.958, 0, '#angry', '#angry', -0.319, 'perform_magic', 'find_love', 'own_pet', 'jump_off_bridge', 'live_apartment']
senticnet['complainer'] = [-0.747, 0, 0.68, -0.586, '#sad', '#angry', -0.671, 'whiner', 'kvetch', 'moaner', 'sniveller', 'crybaby']
senticnet['complaining'] = [-0.679, 0, 0.78, -0.816, '#angry', '#disgusting', -0.758, 'querulous', 'whiney', 'whiny', 'fretful', 'protestant']
senticnet['complaint'] = [0, 0, 0.958, -0.813, '#angry', '#disgusting', -0.59, 'complain', 'disagree', 'yell', 'shout', 'scream']
senticnet['complaintive'] = [-0.724, 0, 0.649, -0.663, '#sad', '#disgusting', -0.679, 'querulous', 'whiney', 'whiny', 'fretful', 'protestant']
senticnet['complaisance'] = [0.604, -0.576, 0, 0.935, '#joyful', '#admirable', 0.705, 'affirmativeness', 'deference', 'compliance', 'disposition', 'agreeability']
senticnet['complect'] = [0.63, -0.556, 0, 0.946, '#joyful', '#admirable', 0.711, 'intercommunicate', 'connect', 'link', 'link_up', 'join']
senticnet['complement'] = [0.42, 0.2, 0, 0.437, '#joyful', '#admirable', 0.352, 'taken_seriously', 'good_sense_of_humor', 'much_need', 'knowledgeable', 'spice_life']
senticnet['complementarity'] = [-0.819, 0, 0.931, -0.777, '#sad', '#angry', -0.842, 'mutualness', 'mutuality', 'reciprocity', 'correlation', 'correlativity']
senticnet['complementary'] = [0.538, -0.721, 0, 0.606, '#surprising', '#admirable', 0.622, 'attraction', 'opposites_attract_each_other', 'magnetic_attraction', 'attract', 'magnetism']
senticnet['complete'] = [0.059, 0.294, -0.121, 0.271, '#interesting', '#admirable', 0.168, 'totality', 'all_of_it', 'total', 'full', 'alternative']
senticnet['complete_assignment'] = [0, 0.125, 0, 0.18, '#interesting', '#admirable', 0.102, 'study_biology', 'question_teacher', 'discover_fact', 'teach_computer', 'surf_internet']
senticnet['complete_course'] = [-0.119, -0.044, 0, -0.137, '#sad', '#disgusting', -0.071, 'get_grade', 'show_know', 'test_knowledge', 'receive_grade', 'want_pass_class']
senticnet['complete_job'] = [0, 0, 0, 0.819, '#admirable', '#admirable', 0.273, 'complete_task', 'finished', 'concluded', 'accomplished', 'completed']
senticnet['complete_sentence'] = [0.82, 0.899, 0, 0, '#joyful', '#interesting', 0.573, 'point_out', 'help_another_person', 'erase_blackboard', 'report_crime', 'master_skill']
senticnet['complete_task'] = [0.881, 0.864, 0, 0, '#joyful', '#interesting', 0.582, 'ended', 'completed', 'finish_job', 'complete_job', 'wrapped_up']
senticnet['complete_thesis'] = [-0.048, -0.056, 0, 0.095, '#surprising', '#admirable', 0.034, 'bluetooth', 'stuff_use_calculation', 'insure', 'pour_hot_coffee_mug', 'low_blood_pressure']
senticnet['completed'] = [0, 0, 0, 0.819, '#admirable', '#admirable', 0.273, 'complete_task', 'finished', 'concluded', 'accomplished', 'complete_job']
senticnet['completely'] = [0.799, 0.791, 0, 0, '#joyful', '#interesting', 0.53, 'large_land_mass', 'complete', 'land_mass', 'land_area', 'land_form']
senticnet['completeness'] = [0.898, -0.536, 0, 0.841, '#joyful', '#admirable', 0.758, 'integrity', 'wholeness', 'fullness', 'comprehensiveness', 'unity']
senticnet['completion'] = [0.086, 0.148, 0, 0.157, '#interesting', '#admirable', 0.13, 'end_point', 'commence', 'success', 'done', 'mission_accomplished']
senticnet['complex_machine'] = [0.028, 0, 0, 0.131, '#joyful', '#admirable', 0.053, 'mechanical_device', 'mechanism', 'human_invention', 'machine', 'device']
senticnet['complex_organ'] = [0, 0.078, 0.056, 0.099, '#interesting', '#admirable', 0.04, 'sensor', 'organ', 'head_organ', 'part_of_face', 'face_feature']
senticnet['complex_structure'] = [0.128, 0.103, 0, 0.208, '#joyful', '#admirable', 0.146, 'complicated_figure', 'vicinity', 'no_edge', 'circular', 'three_dimensions']
senticnet['complexion'] = [-0.665, 0, 0.782, -0.529, '#sad', '#angry', -0.659, 'lividness', 'pallidness', 'pallor', 'wanness', 'achromasia']
senticnet['complexity'] = [0.632, -0.62, 0, 0.923, '#joyful', '#admirable', 0.725, 'quality', 'intricacy', 'elaborateness', 'tapestry', 'complicatedness']
senticnet['complexness'] = [0.669, -0.717, 0, 0.914, '#surprising', '#admirable', 0.767, 'quality', 'intricacy', 'elaborateness', 'tapestry', 'complicatedness']
senticnet['compliance'] = [0.594, -0.651, 0, 0.503, '#joyful', '#surprising', 0.583, 'keeping', 'formality', 'honoring', 'line', 'observance']
senticnet['complicate'] = [-0.972, 0, 0.7, -0.964, '#sad', '#disgusting', -0.879, 'unfair', 'difficult', 'complicated', 'big_issue', 'problem']
senticnet['complicated'] = [-0.972, 0, 0.7, -0.964, '#sad', '#disgusting', -0.879, 'issue', 'difficult', 'big_issue', 'terrorist_attack', 'problem']
senticnet['complicated_figure'] = [-0.969, 0, 0.172, -0.997, '#sad', '#disgusting', -0.713, 'complex_structure', 'vicinity', 'difficult', 'circular', 'three_dimensions']
senticnet['complicatedness'] = [0.632, -0.62, 0, 0.923, '#joyful', '#admirable', 0.725, 'quality', 'intricacy', 'elaborateness', 'tapestry', 'complexity']
senticnet['complication'] = [-0.326, -0.087, -0.046, -0.387, '#sad', '#disgusting', -0.224, 'bad_feeling', 'black_eye', 'schizophrenia', 'disrespect', 'disability']
senticnet['compliment'] = [0.986, 0, 0, 0.939, '#joyful', '#admirable', 0.642, 'dignity', 'virtue', 'good_look', 'good_fortune', 'good_etiquette']
senticnet['complimentary'] = [0.722, -0.981, 0, 0.832, '#surprising', '#admirable', 0.845, 'laudatory', 'praiseful', 'praising', 'encomiastic', 'eulogistic']
senticnet['component'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'fragment', 'part_of_whole', 'math_problem', 'segment', 'small_unit']
senticnet['comport'] = [0.759, -0.767, 0, 0.878, '#surprising', '#admirable', 0.801, 'remember_oneself', 'move', 'walk', 'assert_oneself', 'act']
senticnet['comportment'] = [0.841, -0.568, 0, 0.654, '#joyful', '#admirable', 0.688, 'dignity', 'gravitas', 'lordliness', 'personal_manner', 'manner']
senticnet['compose_draft'] = [0.051, 0.074, -0.05, 0.084, '#interesting', '#admirable', 0.053, 'sketch', 'scheme', 'draft', 'draw_draft', 'draftsman']
senticnet['compose_music'] = [0, 0.716, 0, 0.741, '#interesting', '#admirable', 0.486, 'make_music', 'hear_music', 'artist', 'make_drawing', 'art']
senticnet['composed'] = [0.68, -0.799, 0, 0.661, '#joyful', '#surprising', 0.713, 'unflurried', 'unflustered', 'unperturbed', 'unruffled', 'coolheaded']
senticnet['composer'] = [0.937, 0, 0, 0, '#joyful', '#joyful', 0.312, 'music', 'classical', 'band_play', 'songwriter', 'rock_band']
senticnet['composite'] = [-0.934, 0, 0.691, -0.971, '#sad', '#disgusting', -0.865, 'cudweed', 'strawflower', 'everlasting_flower', 'everlasting_flower_plant', 'pink_paper_daisy']
senticnet['composite_plant'] = [0.782, -0.695, 0, 0.684, '#joyful', '#surprising', 0.72, 'mayweed', 'stinking_mayweed', 'stinking_chamomile', 'dog_fennel', 'oxeye_daisy']
senticnet['composition'] = [0.045, 0, 0.033, 0.089, '#joyful', '#admirable', 0.034, 'spanish', 'vocalization', 'verbal_communication', 'vocal', 'mouth_noise']
senticnet['compost'] = [-0.125, 0, -0.103, -0.038, '#sad', '#scared', -0.089, 'dog_poop', 'picnic', 'hike_trail', 'detritus', 'wildlife']
senticnet['compost_pile'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'organic_matter', 'decompose', 'recycle', 'soil', 'fertiliser']
senticnet['composure'] = [0.724, -0.921, 0, 0.854, '#surprising', '#admirable', 0.833, 'tranquility', 'serenity', 'disposition', 'repose', 'placidity']
senticnet['compound'] = [0.737, -0.808, 0, 0.611, '#joyful', '#surprising', 0.719, 'enhance', 'intensify', 'deepen', 'potentiate', 'heighten']
senticnet['comprehend'] = [0.507, 0.667, 0, 0.949, '#interesting', '#admirable', 0.708, 'accumulate_knowledge', 'understand', 'know', 'acquire_knowledge', 'information_gathering']
senticnet['comprehended'] = [0.632, -0.612, 0, 0.732, '#joyful', '#admirable', 0.659, 'appreciated', 'apprehended', 'understood', 'interpreted', 'taken']
senticnet['comprehendible'] = [0.744, -0.766, 0, 0.669, '#joyful', '#surprising', 0.726, 'accessible', 'fathomable', 'approachable', 'perceivable', 'intelligible']
senticnet['comprehensible'] = [0.515, -0.803, 0, 0.791, '#surprising', '#admirable', 0.703, 'accessible', 'fathomable', 'approachable', 'perceivable', 'intelligible']
senticnet['comprehension'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'comprehend', 'understand', 'acquire_knowledge', 'knowledge', 'obtain_information']
senticnet['comprehensiveness'] = [0.898, -0.536, 0, 0.841, '#joyful', '#admirable', 0.758, 'integrity', 'wholeness', 'fullness', 'completeness', 'unity']
senticnet['compress'] = [0, 0, -0.1, 0, '#scared', '#scared', -0.033, 'grow_yard', 'heat', 'burn', 'corrode', 'stain_clothes']
senticnet['compress_air'] = [0.021, -0.067, 0, 0, '#joyful', '#surprising', 0.029, 'plastic_bottle', 'party', 'use_party', 'lighter_air', 'ninja']
senticnet['compression'] = [0, 0.929, 0, 0.848, '#interesting', '#admirable', 0.592, 'press', 'rub', 'push_hard', 'coercion', 'print_newspaper']
senticnet['compromise'] = [0.026, 0.212, -0.105, 0.188, '#interesting', '#admirable', 0.107, 'preliminary_agreement', 'accord', 'arrangement', 'deal', 'pact']
senticnet['compulsion'] = [-0.945, 0, -0.765, 0, '#sad', '#scared', -0.57, 'repetitive_action', 'cigar', 'smoke', 'tobacco_product', 'cigarette_smoke']
senticnet['compulsory'] = [0.924, -0.551, 0, 0.756, '#joyful', '#admirable', 0.744, 'bounden', 'incumbent_on', 'de_rigueur', 'obligatory', 'mandatory']
senticnet['compunction'] = [-0.894, 0.166, -0.614, 0.051, '#sad', '#scared', -0.43, 'self-reproach', 'rue', 'attrition', 'ruefully', 'contritely']
senticnet['computable'] = [0.983, -0.807, 0, 0.966, '#joyful', '#admirable', 0.919, 'estimable', 'calculable', 'countable', 'denumerable', 'enumerable']
senticnet['computation'] = [0.58, 0.651, -0.264, 0.308, '#joyful', '#interesting', 0.425, 'calculator', 'scholar', 'computer', 'compute_sum', 'research']
senticnet['compute'] = [0.026, 0.212, -0.105, 0.188, '#interesting', '#admirable', 0.107, 'surf_internet', 'computation', 'predict_weather', 'calculate', 'word_process']
senticnet['compute_sum'] = [0.026, 0.212, -0.105, 0.188, '#interesting', '#admirable', 0.107, 'add_up_column_number', 'add_up_number', 'calculate_quickly', 'program_computer', 'write_program']
senticnet['computer'] = [0, 0, 0, 0.07, '#admirable', '#admirable', 0.023, 'source_code', 'buffoon', 'browser', 'dvd', 'clown']
senticnet['computer_application'] = [0, 0.778, 0, 0.988, '#interesting', '#admirable', 0.589, 'form_of_communication', 'medium', 'grammar_part', 'show_how', 'unit_language']
senticnet['computer_chip'] = [0.037, 0.073, 0.027, 0.072, '#interesting', '#admirable', 0.052, 'transistor', 'grain_sand', 'sand', 'silica', 'amethyst']
senticnet['computer_command'] = [0, 0.068, -0.055, 0.256, '#interesting', '#admirable', 0.09, 'output', 'make_copy', 'computer_term', 'ink_paper', 'source']
senticnet['computer_company'] = [0.063, 0, 0.037, 0.099, '#joyful', '#admirable', 0.042, 'computer_manufacturer', 'variable', 'crunchy', 'computer', 'redness']
senticnet['computer_crash'] = [-0.737, 0, 0.708, 0, '#sad', '#angry', -0.482, 'make_error', 'fail_test', 'brush_off', 'fail_class', 'type_of_keyboard']
senticnet['computer_desk'] = [0.038, 0, 0.01, 0.059, '#joyful', '#admirable', 0.029, 'paper_clip', 'eraser_holder', 'pencil_box', 'electric_pencil_sharpener', 'folder']
senticnet['computer_disk'] = [0, 0.091, 0, 0, '#interesting', '#interesting', 0.03, 'rotary_file', 'computer', 'general_ledger', 'cd-rom', 'personal_computer']
senticnet['computer_error'] = [-0.985, 0, 0.869, -0.803, '#sad', '#angry', -0.886, 'error', 'syntax_error', 'semantic_error', 'runtime_error', 'programming_error']
senticnet['computer_internet_connection'] = [0, 0, 0.845, -0.947, '#angry', '#disgusting', -0.597, 'slow_speed', 'wifi', 'hotspot', 'internet_connection', 'boot_up_computer']
senticnet['computer_key'] = [-0.033, 0.217, -0.085, 0.33, '#interesting', '#admirable', 0.143, 'imperative', 'enter_area', 'password', 'enter', 'go_build']
senticnet['computer_lab'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'laboratory', 'science_class', 'lab', 'scientist', 'science_laboratory']
senticnet['computer_language'] = [0, 0, 0, 0.074, '#admirable', '#admirable', 0.025, 'write_message', 'grammar', 'codings', 'english', 'program_language']
senticnet['computer_lesson'] = [0.737, 0, 0, 0.94, '#joyful', '#admirable', 0.559, 'teach', 'teach_computer', 'teacher', 'teach_lesson', 'teach_class']
senticnet['computer_lover'] = [-0.969, 0, 0.172, -0.997, '#sad', '#disgusting', -0.713, 'nerd', 'wear_glasses', 'geek', 'big_glasses', 'addicted_computer_games']
senticnet['computer_manufacturer'] = [0.074, 0.069, 0.036, 0.055, '#joyful', '#interesting', 0.054, 'computer', 'browser', 'efficient', 'telephone_computer', 'modem']
senticnet['computer_monitor'] = [0.044, 0.08, 0, -0.03, '#joyful', '#interesting', 0.031, 'screen', 'pixel', 'visual_information', 'image', 'display']
senticnet['computer_operative_system'] = [-0.023, 0.084, 0.036, 0.118, '#interesting', '#admirable', 0.048, 'house_open', 'operative_system', 'look_out', 'look_glass', 'see_out']
senticnet['computer_part'] = [-0.049, 0.161, 0, 0.061, '#interesting', '#admirable', 0.058, 'recollection', 'brain_function', 'think', 'brainstorm', 'recall']
senticnet['computer_program'] = [0, 0.084, 0.027, 0.095, '#interesting', '#admirable', 0.051, 'efficient', 'hard_drive', 'browser', 'telephone_computer', 'internet_connection']
senticnet['computer_science'] = [0, 0.072, 0, 0, '#interesting', '#interesting', 0.024, 'study_hard', 'physic', 'efficient', 'hard_drive', 'computer_program']
senticnet['computer_software'] = [0, -0.016, 0.038, -0.079, '#angry', '#disgusting', -0.034, 'give_performance', 'play_instrument', 'annoy_person', 'like_music', 'play_musical_instrument']
senticnet['computer_term'] = [0, 0.085, 0, 0.087, '#interesting', '#admirable', 0.057, 'computer_command', 'ink_paper', 'make_copy', 'copy', 'calculator']
senticnet['computer_type'] = [0, 0.94, 0, 0.774, '#interesting', '#admirable', 0.571, 'processor', 'browse_web', 'laptop', 'desktop', 'language']
senticnet['computer_user'] = [0, 0.777, 0, 0.775, '#interesting', '#admirable', 0.517, 'computer', 'engineer', 'user', 'internet_user', 'computer_software']
senticnet['computer_virus'] = [-0.752, 0, 0.822, 0, '#sad', '#angry', -0.525, 'strangle', 'hear_bad_news', 'handicap', 'broken_finger', 'bloodshed']
senticnet['comrade'] = [0.092, 0.146, -0.099, 0.168, '#interesting', '#admirable', 0.102, 'nobleman', 'ceo', 'elect_official', 'boss', 'top_dog']
senticnet['con'] = [0.931, -0.714, 0, 0.63, '#joyful', '#surprising', 0.758, 'hustle', 'sting_operation', 'bunco', 'sting', 'bunco_game']
senticnet['con_brio'] = [0.716, -0.57, 0, 0.681, '#joyful', '#admirable', 0.656, 'vibrant', 'vivacious', 'spirited', 'lively', 'dashing']
senticnet['concatenation'] = [-0.934, 0, 0.931, -0.964, '#sad', '#disgusting', -0.943, 'contact', 'coherence', 'coherency', 'connectedness', 'interconnection']
senticnet['conceal'] = [0, 0.141, -0.065, 0.215, '#interesting', '#admirable', 0.097, 'concealment', 'front_page', 'bedspread', 'lid', 'surround']
senticnet['conceal_evidence'] = [-0.24, 0.068, -0.233, -0.134, '#sad', '#scared', -0.18, 'go_jail', 'arrest', 'send_to_jail', 'go_to_prison', 'feel_bad']
senticnet['concealed'] = [-0.519, 0, 0.979, -0.89, '#angry', '#disgusting', -0.796, 'occult', 'invisible', 'nonvisual', 'hidden', 'out_of_sight']
senticnet['concealer'] = [-0.796, 0, -0.778, 0, '#sad', '#scared', -0.525, 'protect_from_sun', 'shade', 'meaning', 'corrector', 'sunglasses']
senticnet['concealment'] = [-0.026, 0.095, -0.049, 0.166, '#interesting', '#admirable', 0.062, 'conceal', 'front_page', 'bedspread', 'false', 'sheet']
senticnet['concede'] = [-0.117, 0.154, -0.123, 0.253, '#interesting', '#admirable', 0.056, 'get_back', 'give_up', 'try_hard', 'locate', 'military_action']
senticnet['conceit'] = [0, 0, 0.875, -0.793, '#angry', '#disgusting', -0.556, 'self_love', 'amour_propre', 'self_pride', 'egotism', 'self-importance']
senticnet['conceitedness'] = [-0.845, 0, 0.969, -0.685, '#sad', '#angry', -0.833, 'posturing', 'swelled_head', 'egotism', 'boastfulness', 'vainglory']
senticnet['conceivability'] = [-0.968, 0, 0.603, -0.915, '#sad', '#disgusting', -0.829, 'potential', 'potency', 'conceivableness', 'possibleness', 'achievability']
senticnet['conceivable'] = [0.878, -0.678, 0, 0.631, '#joyful', '#surprising', 0.729, 'ponderable', 'presumable', 'supposable', 'surmisable', 'thinkable']
senticnet['conceivableness'] = [-0.968, 0, 0.603, -0.915, '#sad', '#disgusting', -0.829, 'potential', 'potency', 'possibleness', 'conceivability', 'achievability']
senticnet['conceive'] = [0.624, -0.811, 0, 0.773, '#surprising', '#admirable', 0.736, 'find', 'design', 'preconceive', 'discover', 'create_by_mental_act']
senticnet['conceive_of'] = [-0.809, 0, 0.945, -0.639, '#sad', '#angry', -0.798, 'fancy', 'foresee', 'fantasy', 'daydream', 'woolgather']
senticnet['concentrate'] = [-0.029, 0.304, -0.059, 0.279, '#interesting', '#admirable', 0.165, 'focus', 'read_aloud', 'go_to_library', 'quiet_place', 'silence']
senticnet['concentration'] = [0.633, -0.968, 0, 0.612, '#joyful', '#surprising', 0.738, 'particularism', 'absorption', 'centering', 'engrossment', 'immersion']
senticnet['concept'] = [-0.029, 0.304, -0.059, 0.279, '#interesting', '#admirable', 0.165, 'abstract', 'assurance', 'addition', 'importance', 'totality']
senticnet['conceptive'] = [0.702, -0.95, 0, 0.997, '#surprising', '#admirable', 0.883, 'fertilizable', 'fecund', 'fertile', 'impregnable', 'rank']
senticnet['conceptualization'] = [0.878, -0.587, 0, 0.624, '#joyful', '#admirable', 0.696, 'framing', 'approach', 'attack', 'plan_of_attack', 'creating_by_mental_acts']
senticnet['conceptualize'] = [0.868, -0.958, 0, 0.548, '#joyful', '#surprising', 0.791, 'find', 'design', 'preconceive', 'discover', 'create_by_mental_act']
senticnet['concern'] = [-0.84, 0, -0.853, 0, '#sad', '#scared', -0.564, 'compassion', 'worry', 'pity', 'care', 'fear']
senticnet['concern_health'] = [-0.15, -0.004, -0.145, -0.161, '#sad', '#disgusting', -0.151, 'injury', 'strengthful', 'pain', 'feel_sick', 'poor_health']
senticnet['concerned'] = [-0.999, 0, -0.922, 0, '#sad', '#scared', -0.64, 'anxious', 'disturbed', 'concern', 'distressed', 'troubled']
senticnet['concert'] = [0.068, -0.03, 0, 0, '#joyful', '#surprising', 0.033, 'ballet', 'nightclub', 'venue', 'disco', 'ballroom']
senticnet['concert_hall'] = [0.813, 0.832, 0, 0.874, '#interesting', '#admirable', 0.84, 'opus_house', 'opus', 'studio', 'opera', 'concert']
senticnet['concession'] = [0, 0.243, -0.173, 0.292, '#interesting', '#admirable', 0.121, 'citation', 'permit', 'deliver', 'allow', 'permission']
senticnet['concession_stand'] = [0.813, 0.832, 0, 0.874, '#interesting', '#admirable', 0.84, 'ferris_wheel', 'kiosk', 'food', 'carnival_ride', 'theme_park']
senticnet['concierge'] = [0.954, 0.726, 0, 0, '#joyful', '#interesting', 0.56, 'porter', 'beverage_service', 'luggage_trolley', 'bar_service', 'minibar']
senticnet['conciliate'] = [0.509, -0.65, 0, 0.638, '#surprising', '#admirable', 0.599, 'tranquilize', 'tranquillize', 'calm_down', 'quieten', 'calm']
senticnet['conciliative'] = [-0.606, 0, 0.694, -0.651, '#angry', '#disgusting', -0.65, 'appeasing', 'placating', 'placative', 'placatory', 'pacific']
senticnet['conciseness'] = [-0.666, 0, 0.812, -0.881, '#angry', '#disgusting', -0.786, 'laconism', 'laconicism', 'terseness', 'concision', 'pithiness']
senticnet['concision'] = [-0.666, 0, 0.812, -0.881, '#angry', '#disgusting', -0.786, 'laconism', 'laconicism', 'conciseness', 'terseness', 'pithiness']
senticnet['conclude'] = [-0.042, 0.296, -0.109, 0.291, '#interesting', '#admirable', 0.145, 'explanation', 'conclusion', 'choice', 'done', 'tell_why']
senticnet['concluded'] = [0, 0, 0, 0.819, '#admirable', '#admirable', 0.273, 'complete_task', 'finished', 'complete_job', 'accomplished', 'completed']
senticnet['conclusion'] = [-0.046, 0.26, -0.154, 0.239, '#interesting', '#admirable', 0.1, 'conclude', 'result', 'end_point', 'end', 'done']
senticnet['concoction'] = [0.87, -0.856, 0, 0.94, '#joyful', '#admirable', 0.889, 'mincemeat', 'stuffing', 'dressing', 'roux', 'batter']
senticnet['concord'] = [-0.048, 0.105, -0.061, 0.115, '#interesting', '#admirable', 0.037, 'airplane', 'aeroplane', 'covenant', 'back_airplane', 'jet']
senticnet['concordance'] = [0.742, -0.993, 0, 0.918, '#surprising', '#admirable', 0.884, 'peace', 'accord', 'comity', 'agreement', 'order']
senticnet['concrete'] = [0, 0.127, -0.046, 0.194, '#interesting', '#admirable', 0.092, 'cement', 'tar', 'pavement', 'big_city_life', 'popular_building_material']
senticnet['concrete_representation'] = [0.693, -0.529, 0, 0.82, '#joyful', '#admirable', 0.681, 'embodiment', 'shape', 'representation', 'mental_representation', 'internal_representation']
senticnet['concreteness'] = [0.68, -0.684, 0, 0.907, '#surprising', '#admirable', 0.757, 'materiality', 'literalness', 'physicalness', 'corporeality', 'corporality']
senticnet['concretism'] = [0.93, -0.936, 0, 0.771, '#joyful', '#surprising', 0.879, 'embodiment', 'shape', 'representation', 'mental_representation', 'internal_representation']
senticnet['concretize'] = [0.519, -0.554, 0, 0.746, '#surprising', '#admirable', 0.606, 'narrow_down', 'peg_down', 'nail_down', 'narrow', 'pin_down']
senticnet['concupiscence'] = [0.718, -0.726, 0, 0.952, '#surprising', '#admirable', 0.799, 'love', 'aphrodisia', 'lecherousness', 'lustfulness', 'amorousness']
senticnet['concussion'] = [0, 0, 0, -0.868, '#disgusting', '#disgusting', -0.289, 'loss_ofawareness', 'bang_head', 'brain_damage', 'serious_accident', 'get_hurt']
senticnet['condemn'] = [0.749, -0.796, 0, 0.768, '#surprising', '#admirable', 0.771, 'prove', 'show', 'attest', 'authenticate', 'reflect']
senticnet['condemnatory'] = [-0.953, 0, 0.771, -0.677, '#sad', '#angry', -0.8, 'inculpative', 'condemning', 'accusatory', 'accusing', 'accusive']
senticnet['condemning'] = [-0.953, 0, 0.771, -0.677, '#sad', '#angry', -0.8, 'condemnatory', 'inculpative', 'accusatory', 'accusing', 'accusive']
senticnet['condensation'] = [0, 0.073, -0.052, 0.093, '#interesting', '#admirable', 0.038, 'thicken', 'condense_water', 'condensed_milk', 'weather_condition', 'condense']
senticnet['condense'] = [0, 0.073, -0.052, 0.093, '#interesting', '#admirable', 0.038, 'thicken', 'condense_water', 'condensed_milk', 'weather_condition', 'condensation']
senticnet['condense_water'] = [0, 0.073, -0.052, 0.093, '#interesting', '#admirable', 0.038, 'vapor', 'water_vapor', 'evaporate', 'gaseous', 'bubble']
senticnet['condensed_milk'] = [0.051, 0.074, -0.05, 0.084, '#interesting', '#admirable', 0.053, 'thicken', 'condense_water', 'condense', 'weather_condition', 'condensation']
senticnet['condescendingness'] = [0.593, -0.658, 0, 0.711, '#surprising', '#admirable', 0.654, 'sweetness_and_light', 'condescension', 'affability', 'mellowness', 'friendliness']
senticnet['condescension'] = [0.593, -0.658, 0, 0.711, '#surprising', '#admirable', 0.654, 'sweetness_and_light', 'affability', 'condescendingness', 'mellowness', 'friendliness']
senticnet['condiment'] = [-0.756, 0, 0.593, -0.591, '#sad', '#angry', -0.647, 'taco_sauce', 'chili_sauce', 'steak_sauce', 'duck_sauce', 'hoisin_sauce']
senticnet['condition'] = [0, 0.861, 0, 0.797, '#interesting', '#admirable', 0.553, 'diagnose', 'criterion', 'medical', 'sleep_disorder', 'ailment']
senticnet['conditioned_emotion'] = [0.708, -0.608, 0, 0.661, '#joyful', '#admirable', 0.659, 'love', 'emotional_response', 'emotion', 'fright', 'reverence']
senticnet['conditioned_emotional_response'] = [0.708, -0.608, 0, 0.661, '#joyful', '#admirable', 0.659, 'love', 'emotion', 'conditioned_emotion', 'fright', 'reverence']
senticnet['conditioning'] = [0.887, -0.989, 0, 0.611, '#joyful', '#surprising', 0.829, 'education', 'internalization', 'incorporation', 'study', 'learning']
senticnet['condo'] = [0.913, 0.8, 0, 0, '#joyful', '#interesting', 0.571, 'brownstone', 'rent_apartment', 'high_rise', 'condominium', 'row_house']
senticnet['condole_with'] = [-0.723, 0, 0.798, 0, '#sad', '#angry', -0.507, 'sympathize_with', 'compassionateness', 'feel_for', 'sympathize', 'commiserate']
senticnet['condom'] = [0.732, 0.83, 0, 0, '#joyful', '#interesting', 0.521, 'birth_control_pill', 'prevent_disease', 'prevent_pregnancy', 'safety', 'safe_sex']
senticnet['condominium'] = [0.927, 0.76, 0, 0, '#joyful', '#interesting', 0.562, 'brownstone', 'rent_apartment', 'high_rise', 'condo', 'row_house']
senticnet['conduce'] = [0.66, -0.853, 0, 0.744, '#surprising', '#admirable', 0.752, 'further', 'promote', 'encourage', 'boost', 'advance']
senticnet['conduct'] = [0.203, 0.241, -0.198, 0.343, '#interesting', '#admirable', 0.196, 'honor', 'mandatory', 'courtesy', 'good_etiquette', 'behavior']
senticnet['conduct_business'] = [0, 0.926, 0, 0.824, '#interesting', '#admirable', 0.583, 'see_know', 'talk_person', 'make_hotel_reservation', 'make_deals', 'send_information']
senticnet['conduct_electricity'] = [0, 0.869, 0, 0.726, '#interesting', '#admirable', 0.532, 'scrap', 'mine_ore', 'hard', 'hard_plastic', 'hard_material']
senticnet['conduct_experiment'] = [-0.072, 0, -0.051, -0.082, '#sad', '#disgusting', -0.068, 'head_class', 'crowd_room', 'seat_chair', 'leave_table', 'page_through_book']
senticnet['conduct_research'] = [0.504, 0.674, 0, 0.641, '#interesting', '#admirable', 0.606, 'gather_information', 'search_information', 'educate_oneself', 'read_out_loud', 'learn_much']
senticnet['cone'] = [0.06, -0.036, 0.037, 0.075, '#joyful', '#admirable', 0.045, 'semicircle', 'trapezoid', 'circle', 'triangular', 'facet']
senticnet['confab'] = [-0.794, 0, 0.948, -0.828, '#angry', '#disgusting', -0.857, 'gossip', 'chitchat', 'chit_chat', 'gab', 'small_talk']
senticnet['confabulate'] = [0.542, -0.609, 0, 0.757, '#surprising', '#admirable', 0.636, 'fabricate', 'manufacture', 'cook_up', 'invent', 'make_up']
senticnet['confabulation'] = [-0.606, 0, 0.837, -0.588, '#sad', '#angry', -0.677, 'gossip', 'chitchat', 'chit_chat', 'gab', 'small_talk']
senticnet['conference'] = [0, 0.214, 0.012, 0.208, '#interesting', '#admirable', 0.137, 'lecture_hall', 'lecture_theater', 'lesson', 'lecture', 'school_session']
senticnet['conference_auditorium'] = [0.077, 0.073, 0.013, -0.028, '#joyful', '#interesting', 0.036, 'lecture_theater', 'lecture', 'lecture_hall', 'exhibition', 'text_book']
senticnet['conferrer'] = [0.883, -0.664, 0, 0.732, '#joyful', '#admirable', 0.76, 'giver', 'donor', 'presenter', 'bestower', 'subsidizer']
senticnet['confervoid_algae'] = [-0.659, 0, 0.523, -0.739, '#sad', '#disgusting', -0.64, 'alga', 'seaweed', 'golden_algae', 'diatom', 'brown_algae']
senticnet['confess_sin'] = [-0.115, 0.205, -0.104, 0.219, '#interesting', '#admirable', 0.068, 'confessional', 'confession', 'judaism', 'christianity', 'church']
senticnet['confession'] = [0, 0.235, 0.012, 0.222, '#interesting', '#admirable', 0.148, 'church', 'cathedral', 'catholic_church', 'christianity', 'temple']
senticnet['confessional'] = [-0.053, 0.22, -0.045, 0.233, '#interesting', '#admirable', 0.118, 'christianity', 'chapel', 'altar', 'church', 'catholic_church']
senticnet['confetti'] = [0.104, -0.112, 0, -0.046, '#joyful', '#surprising', 0.057, 'reception', 'disco', 'manhole_cover', 'dance_club', 'balloon']
senticnet['confide'] = [0.807, -0.732, 0, 0.768, '#joyful', '#admirable', 0.769, 'relieve', 'expose', 'break', 'let_out', 'bring_out']
senticnet['confidence'] = [0.997, 0, 0, 0.972, '#joyful', '#admirable', 0.656, 'sympathetic', 'adoration', 'confident', 'enthusiasm', 'grateful']
senticnet['confidence_man'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'gouger', 'swindler', 'defrauder', 'conman', 'fraud']
senticnet['confident'] = [0, 0, 0, 0.754, '#admirable', '#admirable', 0.251, 'large-hearted', 'openhearted', 'good-hearted', 'kindly', 'benevolent']
senticnet['confidential'] = [0.742, 0, 0, 0.905, '#joyful', '#admirable', 0.549, 'wear', 'cover_leg', 'robe', 'make_fashion_statement', 'intimate']
senticnet['confidential_information'] = [0.503, -0.571, 0, 0.66, '#surprising', '#admirable', 0.578, 'guidance', 'counsel', 'counseling', 'counselor', 'direction']
senticnet['confidentiality'] = [-0.805, 0, 0.65, -0.986, '#sad', '#disgusting', -0.814, 'discernment', 'sagacity', 'sagaciousness', 'circumspection', 'judgment']
senticnet['configured'] = [-0.906, 0, 0.533, -0.934, '#sad', '#disgusting', -0.791, 'incorporated', 'arranged', 'organized', 'corporate', 'reorganized']
senticnet['confine'] = [0, 0, -0.875, -0.996, '#scared', '#disgusting', -0.624, 'broken_window', 'step_dog_shit', 'physical_pain', 'car_wreck', 'live_alone']
senticnet['confines'] = [0.989, -0.905, 0, 0.876, '#joyful', '#surprising', 0.923, 'reach', 'range', 'compass', 'scope', 'orbit']
senticnet['confirm'] = [-0.022, 0, 0, -0.116, '#sad', '#disgusting', -0.046, 'show_how', 'demonstrate', 'help_understand', 'misunderstand', 'hear_speech']
senticnet['confirmation'] = [0.031, 0.218, -0.094, 0.299, '#interesting', '#admirable', 0.151, 'nominate', 'axiom', 'supreme', 'govern', 'tenet']
senticnet['confirmed'] = [-0.905, 0, 0.653, -0.998, '#sad', '#disgusting', -0.852, 'unalterable', 'static', 'changeless', 'unchangeable', 'fixed']
senticnet['conflict'] = [0, 0, 0.818, 0, '#angry', '#angry', -0.273, 'big_fight', 'siege', 'declare_war', 'combat', 'battle']
senticnet['confluence'] = [-0.773, 0, 0.914, -0.501, '#sad', '#angry', -0.729, 'blending', 'conflux', 'merging', 'homogenization', 'combination']
senticnet['conflux'] = [-0.773, 0, 0.914, -0.501, '#sad', '#angry', -0.729, 'confluence', 'blending', 'merging', 'homogenization', 'combination']
senticnet['conform'] = [0.731, 0.729, 0, 0.866, '#joyful', '#admirable', 0.775, 'stand_behind', 'start_move', 'able_run', 'stand', 'go_end']
senticnet['conform_to'] = [0.731, -0.592, 0, 0.634, '#joyful', '#admirable', 0.652, 'accommodate', 'obey', 'abide_by', 'toe_line', 'oblige']
senticnet['conformable'] = [0.726, -0.888, 0, 0.529, '#joyful', '#surprising', 0.714, 'reconciled', 'accordant', 'agreeable', 'consistent', 'pursuant']
senticnet['conformation'] = [0.559, -0.839, 0, 0.593, '#surprising', '#admirable', 0.664, 'abidance', 'compliance', 'punctilio', 'conformity', 'honoring']
senticnet['conformist_attitude'] = [-0.057, 0, 0, -0.155, '#sad', '#disgusting', -0.071, 'learn_patience', 'wait_turn', 'wait_patiently', 'wait_service', 'wait_line']
senticnet['conformity'] = [0.928, 0, 0, 0.712, '#joyful', '#admirable', 0.547, 'geek', 'go_by_book', 'cheerleader', 'new_knowledge', 'obedience']
senticnet['confound'] = [-0.827, 0, 0.66, -0.514, '#sad', '#angry', -0.667, 'demoralize', 'pose', 'disorient', 'disorientate', 'amaze']
senticnet['confront'] = [-0.635, 0, 0.559, -0.828, '#sad', '#disgusting', -0.674, 'take_bull_by_horns', 'breast', 'front', 'encounter', 'oppose']
senticnet['confrontation'] = [-0.2, -0.036, 0, -0.237, '#sad', '#disgusting', -0.134, 'beat_up', 'fight', 'conflict', 'violence', 'fight_against']
senticnet['confuse'] = [-0.882, 0, 0, -0.89, '#sad', '#disgusting', -0.591, 'shame', 'dread', 'consternation', 'terrible', 'embarrass']
senticnet['confused'] = [-0.938, 0, 0, -0.978, '#sad', '#disgusting', -0.639, 'put_off', 'confusedly', 'disordered', 'discombobulation', 'confusing']
senticnet['confusedly'] = [-0.984, 0, 0, -0.924, '#sad', '#disgusting', -0.636, 'put_off', 'disordered', 'discombobulation', 'confused', 'confusing']
senticnet['confusedness'] = [-0.506, 0, 0.85, -0.828, '#angry', '#disgusting', -0.728, 'confusion', 'disarray', 'mental_confusion', 'bafflement', 'muddiness']
senticnet['confusing'] = [-0.924, 0, 0, -0.945, '#sad', '#disgusting', -0.623, 'put_off', 'confusedly', 'disordered', 'discombobulation', 'confused']
senticnet['confusion'] = [-0.743, 0, -0.793, 0, '#sad', '#scared', -0.512, 'embarrassment', 'panic', 'nervousness', 'anxiety', 'worry']
senticnet['confutable'] = [0.906, -0.624, 0, 0.698, '#joyful', '#admirable', 0.743, 'disavowable', 'questionable', 'refutable', 'deniable', 'confutative']
senticnet['confutative'] = [0.906, -0.624, 0, 0.698, '#joyful', '#admirable', 0.743, 'disavowable', 'questionable', 'refutable', 'confutable', 'deniable']
senticnet['confute'] = [0.872, 0.997, 0, 0, '#joyful', '#interesting', 0.623, 'controvert', 'refute', 'confutation', 'negate', 'rebut']
senticnet['congealment'] = [-0.716, 0, 0.509, -0.922, '#sad', '#disgusting', -0.716, 'natural_process', 'natural_action', 'activity', 'curing', 'congelation']
senticnet['congelation'] = [-0.716, 0, 0.509, -0.922, '#sad', '#disgusting', -0.716, 'natural_process', 'natural_action', 'activity', 'congealment', 'curing']
senticnet['congenital_abnormality'] = [-0.579, 0, 0.888, -0.883, '#angry', '#disgusting', -0.783, 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder', 'amelia']
senticnet['congenital_anomaly'] = [-0.917, 0, 0.961, -0.556, '#sad', '#angry', -0.811, 'hypopigmentation', 'birth_defect', 'albinism', 'congenital_defect', 'congenital_disorder']
senticnet['congenital_defect'] = [-0.917, 0, 0.961, -0.556, '#sad', '#angry', -0.811, 'hypopigmentation', 'birth_defect', 'congenital_anomaly', 'albinism', 'congenital_disorder']
senticnet['congenital_disease'] = [-0.503, 0, 0.542, -0.511, '#angry', '#disgusting', -0.519, 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect', 'hirschsprung_disease']
senticnet['congenital_disorder'] = [-0.917, 0, 0.961, -0.556, '#sad', '#angry', -0.811, 'hypopigmentation', 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'albinism']
senticnet['congestion'] = [-0.633, 0, 0.829, -0.794, '#angry', '#disgusting', -0.752, 'stuffiness', 'blocked', 'problem', 'traffic', 'stuck']
senticnet['congestive_heart_failure'] = [-0.614, 0, 0.699, -0.773, '#angry', '#disgusting', -0.695, 'coronary_failure', 'heart_attack', 'failure', 'heart_disease', 'cardiopathy']
senticnet['congoo_mallee'] = [-0.605, 0, 0.787, -0.909, '#angry', '#disgusting', -0.767, 'white_mallee', 'mallee', 'black_mallee', 'black_sally', 'black_gum']
senticnet['congratulate'] = [0.819, 0, 0, 0.746, '#joyful', '#admirable', 0.522, 'proudly', 'smug', 'congratulation', 'self-satisfied', 'applause']
senticnet['congratulation'] = [0.947, 0.922, 0, 0.926, '#joyful', '#admirable', 0.932, 'finish_college', 'college_student', 'serious_student', 'graduate_student', 'college_degree']
senticnet['congratulations'] = [0.561, -0.793, 0, 0.89, '#surprising', '#admirable', 0.748, 'superlative', 'compliment', 'testimonial', 'good_word', 'approval']
senticnet['congregation'] = [0.081, 0.146, 0, 0.167, '#interesting', '#admirable', 0.131, 'cult', 'sect', 'conservative', 'worshiper', 'pastor']
senticnet['congress'] = [0, 0.896, 0, 0.791, '#interesting', '#admirable', 0.562, 'united_nations', 'meeting', 'government_job', 'discussion', 'world_hunger']
senticnet['conjecture'] = [-0.071, 0.18, -0.06, 0.167, '#interesting', '#admirable', 0.072, 'scientific_statement', 'invention', 'hypothetical', 'procedure', 'logical']
senticnet['conjoin'] = [-0.838, 0, 0.64, -0.536, '#sad', '#angry', -0.671, 'marry', 'get_married', 'wed', 'mismarry', 'hook_up_with']
senticnet['conjunctivitis'] = [-0.698, 0, 0.852, -0.697, '#sad', '#angry', -0.749, 'ophthalmia', 'ophthalmitis', 'rubor', 'redness', 'inflammation']
senticnet['conjuration'] = [-0.829, 0, 0.72, -0.535, '#sad', '#angry', -0.695, 'invocation', 'charm', 'spell', 'magic_spell', 'magical_spell']
senticnet['conjure'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'curse', 'bless', 'imprecate', 'anathemize', 'beshrew']
senticnet['conjure_up'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'curse', 'bless', 'imprecate', 'anathemize', 'beshrew']
senticnet['conjurer'] = [0.9, -0.882, 0, 0.687, '#joyful', '#surprising', 0.823, 'escapologist', 'escape_expert', 'mind_reader', 'telepathist', 'performer']
senticnet['conjuror'] = [0.672, -0.657, 0, 0.535, '#joyful', '#surprising', 0.621, 'escapologist', 'escape_expert', 'mind_reader', 'telepathist', 'performer']
senticnet['conk'] = [-0.608, 0, 0.541, -0.525, '#sad', '#angry', -0.558, 'swoon', 'pass_out', 'faint', 'zonk_out', 'change_state']
senticnet['conk_out'] = [-0.928, 0, 0.682, -0.668, '#sad', '#angry', -0.759, 'blow', 'change', 'crash', 'go_down', 'blow_out']
senticnet['conman'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'gouger', 'swindler', 'defrauder', 'fake', 'fraud']
senticnet['connect'] = [0.059, 0.132, -0.12, 0.201, '#interesting', '#admirable', 0.091, 'join', 'include', 'link', 'bring_together', 'heap']
senticnet['connect_city'] = [0, 0, 0, 0.134, '#admirable', '#admirable', 0.045, 'travel_car', 'drive_upon', 'travel_long_distance', 'get_fast', 'trucking']
senticnet['connect_internet'] = [0, 0.201, 0.018, 0.077, '#interesting', '#admirable', 0.087, 'type_url', 'boot_up_computer', 'go_online', 'buy_computer', 'find_address']
senticnet['connect_room'] = [0, 0.936, 0, 0.929, '#interesting', '#admirable', 0.622, 'entrance_room', 'home_entrance', 'walk_through', 'corridor', 'entry']
senticnet['connect_two_rooms'] = [-0.043, 0.072, 0, 0.145, '#interesting', '#admirable', 0.058, 'walk_through', 'connect_room', 'enter_place', 'go_through', 'entrance_room']
senticnet['connectedness'] = [-0.934, 0, 0.931, -0.964, '#sad', '#disgusting', -0.943, 'contact', 'coherence', 'coherency', 'concatenation', 'interconnection']
senticnet['connection'] = [0.078, 0.103, -0.098, 0.191, '#interesting', '#admirable', 0.091, 'connect', 'aunt_uncle', 'short_form', 'relationship', 'kinship']
senticnet['connective_tissue'] = [0.73, -0.726, 0, 0.653, '#joyful', '#surprising', 0.703, 'red_marrow', 'red_bone_marrow', 'yellow_marrow', 'yellow_bone_marrow', 'bone_marrow']
senticnet['connector'] = [0.066, 0.175, -0.108, 0.295, '#interesting', '#admirable', 0.143, 'direction', 'red_light', 'eight_sides', 'indication', 'clause']
senticnet['connexion'] = [-0.671, 0, 0.97, -0.64, '#sad', '#angry', -0.76, 'joint', 'node', 'articulation', 'join', 'juncture']
senticnet['conniption'] = [-0.127, 0.138, 0.626, -0.62, '#angry', '#disgusting', -0.412, 'tantrum', 'irascibility', 'irascible', 'choleric', 'quick_temper']
senticnet['conniving'] = [-0.819, 0, 0.823, 0, '#sad', '#angry', -0.547, 'connive', 'collusive', 'intrigue', 'calculating', 'scheme']
senticnet['connoisseur'] = [0, 0, 0, 0.966, '#admirable', '#admirable', 0.322, 'egalitarian', 'specialist', 'pioneer', 'scientist', 'expert']
senticnet['connotational'] = [0.734, -0.56, 0, 0.64, '#joyful', '#admirable', 0.645, 'inferential', 'suggestive', 'implicative', 'connotative', 'connotative_of']
senticnet['connotative'] = [0.734, -0.56, 0, 0.64, '#joyful', '#admirable', 0.645, 'inferential', 'suggestive', 'implicative', 'connotational', 'connotative_of']
senticnet['connotative_of'] = [0.734, -0.56, 0, 0.64, '#joyful', '#admirable', 0.645, 'inferential', 'suggestive', 'implicative', 'connotational', 'connotative']
senticnet['conquer'] = [0, 0.764, 0, 0, '#interesting', '#interesting', 0.255, 'gain_ground', 'good_strategy', 'win_battle', 'kill_enemy', 'win_war']
senticnet['conquer_enemy'] = [-0.065, 0, -0.087, -0.19, '#scared', '#disgusting', -0.114, 'gain_territory', 'make_war', 'keep_peace', 'protect_country', 'kill_soldier']
senticnet['conquer_nation'] = [0, 0, 0.854, -0.857, '#angry', '#disgusting', -0.57, 'fight_enemy', 'bigotry', 'destroy_enemy', 'genocide', 'wage_war']
senticnet['conquer_opponent'] = [-0.039, 0.085, 0, 0.078, '#interesting', '#admirable', 0.041, 'compete_against', 'score_homer', 'reach_advantage', 'score_home_run', 'win_baseball_game']
senticnet['conquerable'] = [0.702, -0.944, 0, 0.582, '#joyful', '#surprising', 0.743, 'beatable', 'vanquishable', 'vincible', 'subduable', 'subjugable']
senticnet['conqueror'] = [0.556, -0.688, 0, 0.978, '#surprising', '#admirable', 0.741, 'victor', 'vanquisher', 'combatant', 'battler', 'belligerent']
senticnet['conscience'] = [0, 0, 0, 0.891, '#admirable', '#admirable', 0.297, 'consternation', 'humility', 'confuse', 'concerned', 'dread']
senticnet['conscious'] = [0.052, 0, 0, 0.131, '#joyful', '#admirable', 0.061, 'run_treadmill', 'dangerous_drive', 'helpful_tool', 'profitable', 'creepy']
senticnet['consciousness'] = [0.638, -0.996, 0, 0.631, '#joyful', '#surprising', 0.755, 'awareness', 'ego', 'state_of_mind', 'conscious', 'aesthesia']
senticnet['consecrate'] = [0.693, -0.699, 0, 0.714, '#surprising', '#admirable', 0.702, 'vow', 'dedicate', 'apply', 'rededicate', 'use']
senticnet['consecutive'] = [-0.605, 0, 0.509, -0.674, '#sad', '#disgusting', -0.596, 'dogging', 'persisting', 'sustained', 'continuous', 'perpetual']
senticnet['consent'] = [0.02, 0.237, -0.157, 0.396, '#interesting', '#admirable', 0.165, 'say_yes', 'agree', 'make_right', 'neediness', 'request']
senticnet['consentaneous'] = [0.509, -0.626, 0, 0.786, '#surprising', '#admirable', 0.64, 'agreeable', 'accordant', 'consentient', 'unanimous', 'according']
senticnet['consentient'] = [0.509, -0.626, 0, 0.786, '#surprising', '#admirable', 0.64, 'agreeable', 'consentaneous', 'accordant', 'unanimous', 'according']
senticnet['consequence'] = [-0.234, 0.202, -0.3, 0.142, '#sad', '#scared', -0.063, 'judge_decision', 'bad_action', 'outcome', 'cause', 'problem']
senticnet['consequence_war'] = [-0.88, 0, 0, -0.701, '#sad', '#disgusting', -0.527, 'disgrace', 'death_love', 'lament', 'negative_feeling', 'undesirable']
senticnet['conservation'] = [0, 0, 0, 0.857, '#admirable', '#admirable', 0.286, 'say', 'beckon', 'call', 'conserve', 'retort']
senticnet['conservative'] = [0.026, 0.111, -0.078, 0.139, '#interesting', '#admirable', 0.066, 'fundamentalist', 'christian', 'pastor', 'preacher', 'church_person']
senticnet['conserve'] = [0.069, 0.121, 0, 0.187, '#interesting', '#admirable', 0.126, 'verbal', 'talkative', 'dialogue', 'conservation', 'verbalize']
senticnet['conserve_energy'] = [0, 0, 0, 0.875, '#admirable', '#admirable', 0.292, 'meditate', 'watch_others', 'wait_bus', 'take_time', 'go_home']
senticnet['conserves'] = [-0.61, 0, 0.513, -0.976, '#sad', '#disgusting', -0.7, 'conserve', 'preserve', 'strawberry_jam', 'strawberry_preserves', 'jam']
senticnet['consider'] = [-0.053, 0.331, -0.157, 0.235, '#interesting', '#admirable', 0.119, 'decide', 'reason', 'forethought', 'thoughtfulness', 'decision']
senticnet['consider_beautiful'] = [0.734, 0, 0, 0.981, '#joyful', '#admirable', 0.572, 'beautiful', 'cultivate_yard', 'pretty', 'sexual', 'elegant']
senticnet['consider_consequence'] = [-0.039, 0.085, 0, 0.078, '#interesting', '#admirable', 0.041, 'weigh_consequence', 'reconsider', 'strategy', 'plan_attack', 'good_plan']
senticnet['consider_cost'] = [0, 0.251, 0, 0.163, '#interesting', '#admirable', 0.138, 'item_worth', 'sticker', 'worth', 'item_value', 'monetary']
senticnet['consider_evidence'] = [-0.055, 0.137, -0.05, 0.074, '#interesting', '#admirable', 0.035, 'examine_evidence', 'determine_guilt_innocence', 'become_judge', 'become_lawyer', 'decide_case']
senticnet['consider_fact'] = [0, 0.192, -0.09, 0.105, '#interesting', '#admirable', 0.069, 'make_judgment', 'look_evidence', 'come_decision', 'find_out_fact', 'examine_evidence']
senticnet['consider_good_luck'] = [0, -0.049, 0, 0.129, '#surprising', '#admirable', 0.059, 'form_of_gambling', 'game', 'old_game', 'popular_game', 'game_skill']
senticnet['consider_option'] = [0.822, 0.769, 0, 0, '#joyful', '#interesting', 0.53, 'look_clue', 'make_decision', 'revelation', 'deduce', 'solve_problem']
senticnet['considerable'] = [-0.055, 0, 0, -0.075, '#sad', '#disgusting', -0.043, 'favorite', 'mill', 'crowd', 'several_people', 'grind']
senticnet['considerateness'] = [0.594, -0.603, 0, 0.813, '#surprising', '#admirable', 0.67, 'tact', 'delicacy', 'thoughtfulness', 'consideration', 'finesse']
senticnet['consideration'] = [0.024, 0.167, -0.046, 0.123, '#interesting', '#admirable', 0.089, 'cum', 'find_mate', 'lower_standard_live', 'ovary', 'pregnant']
senticnet['consignment'] = [0.887, 0.976, 0, 0, '#joyful', '#interesting', 0.621, 'mission', 'expedition', 'delivery', 'shipment', 'dispatch']
senticnet['consistence'] = [-0.676, 0, 0.863, -0.862, '#angry', '#disgusting', -0.8, 'incompressibility', 'substance', 'firmness', 'consistency', 'hardness']
senticnet['consistency'] = [0, 0, 0, 0.76, '#admirable', '#admirable', 0.253, 'big_paycheck', 'self_confidence', 'balance_check_account', 'look_beautiful', 'much_money']
senticnet['consistent'] = [0.726, -0.888, 0, 0.529, '#joyful', '#surprising', 0.714, 'reconciled', 'accordant', 'agreeable', 'conformable', 'pursuant']
senticnet['console'] = [0.686, 0.621, -0.241, 0.335, '#joyful', '#interesting', 0.467, 'closeness', 'joyful', 'intoxicate', 'cheer_up', 'solace']
senticnet['consolidative'] = [-0.938, 0, 0.944, -0.922, '#sad', '#angry', -0.935, 'combinative', 'combinatory', 'integrative', 'unifying', 'combinatorial']
senticnet['consonant'] = [0, -0.931, 0, 0.78, '#surprising', '#admirable', 0.57, 'letter', 'vowel', 'alphabet', 'word', 'kind_gesture']
senticnet['consortium'] = [0.776, -0.86, 0, 0.893, '#surprising', '#admirable', 0.843, 'trust', 'combine', 'corporate_trust', 'cartel', 'association']
senticnet['conspicuous'] = [0.7, 0.922, 0, 0, '#joyful', '#interesting', 0.541, 'prominent', 'vivid', 'striking', 'dramatic', 'flagrant']
senticnet['constabulary'] = [0.632, -0.965, 0, 0.632, '#joyful', '#surprising', 0.743, 'police', 'police_force', 'law_enforcement_agency', 'law', 'agency']
senticnet['constancy'] = [0.949, -0.552, 0, 0.595, '#joyful', '#admirable', 0.699, 'metastability', 'monotony', 'invariance', 'changelessness', 'unchangeability']
senticnet['constant'] = [0, 0.1, 0, 0.131, '#interesting', '#admirable', 0.077, 'good_trait', 'unending', 'time_frame', 'short_time', 'time_length']
senticnet['constellation'] = [0.054, 0.098, 0, 0.076, '#interesting', '#admirable', 0.076, 'sky', 'heaven', 'paradise', 'thunder_storm', 'orbit_around_earth']
senticnet['consternation'] = [-0.895, 0, -0.73, 0, '#sad', '#scared', -0.542, 'humility', 'hysteria', 'raring', 'impatiently', 'intimidation']
senticnet['constipation'] = [-0.169, -0.023, -0.115, -0.219, '#sad', '#disgusting', -0.16, 'much_fat', 'cigarette_smoke', 'smoke_pipe', 'lung_cancer', 'wash_mouth_soap']
senticnet['constitution'] = [0.071, 0.165, -0.076, 0.107, '#interesting', '#admirable', 0.089, 'empire', 'socialism', 'feudalism', 'citizen', 'kingdom']
senticnet['constitutional'] = [0.716, -0.627, 0, 0.896, '#joyful', '#admirable', 0.746, 'intrinsic', 'integral', 'intimate', 'inner', 'inbuilt']
senticnet['construct'] = [-0.038, 0.14, 0, 0.208, '#interesting', '#admirable', 0.103, 'make', 'construction', 'make_stuff', 'build_process', 'find_suburb']
senticnet['construct_building'] = [0, 0.081, 0.018, 0.133, '#interesting', '#admirable', 0.065, 'home_build', 'construction', 'make_building', 'construction_site', 'architect']
senticnet['construct_skyscraper'] = [0.051, 0.074, -0.05, 0.084, '#interesting', '#admirable', 0.053, 'build_house', 'put_up_construction', 'set_up', 'put_up', 'erect']
senticnet['construction'] = [0, 0.11, 0.009, 0.165, '#interesting', '#admirable', 0.089, 'make_building', 'construct', 'build_structure', 'find_suburb', 'structure']
senticnet['construction_material'] = [0.047, 0.069, 0.025, 0.133, '#interesting', '#admirable', 0.075, 'solid', 'opaque', 'hard_material', 'hard', 'substance']
senticnet['construction_site'] = [-0.057, -0.032, 0.018, -0.083, '#sad', '#disgusting', -0.042, 'build', 'nuclear_power_plant', 'skyscraper', 'tall_building', 'construct_building']
senticnet['construction_vehicle'] = [0, 0, 0.03, -0.128, '#angry', '#disgusting', -0.053, 'hard_material', 'hard_mineral', 'hard', 'hard_rock', 'sturdy']
senticnet['construction_work'] = [0, 0, -0.077, 0, '#scared', '#scared', -0.026, 'travel_fast', 'find_victim', 'slay', 'nuclear_weapon', 'angle_grinder']
senticnet['construction_worker'] = [0, 0.887, 0, 0.839, '#interesting', '#admirable', 0.575, 'personnel', 'duty', 'policeman', 'vocation', 'laborer']
senticnet['constructive'] = [0.678, -0.897, 0, 0.804, '#surprising', '#admirable', 0.793, 'reconstructive', 'formative', 'shaping', 'creative', 'inferential']
senticnet['constructive_breach'] = [-0.106, 0, -0.053, -0.24, '#sad', '#disgusting', -0.133, 'breach_of_warranty', 'breach_of_trust', 'partial_breach', 'anticipatory_breach', 'breach_of_contract']
senticnet['consult_expert'] = [-0.058, 0, 0.028, 0, '#sad', '#angry', -0.029, 'dye_hair', 'case_house', 'change_hairstyle', 'cut_hair', 'get_manicure']
senticnet['consultative'] = [0.795, -0.977, 0, 0.679, '#joyful', '#surprising', 0.817, 'advisory', 'informatory', 'consultatory', 'consultive', 'revealing']
senticnet['consultatory'] = [0.795, -0.977, 0, 0.679, '#joyful', '#surprising', 0.817, 'advisory', 'consultative', 'informatory', 'consultive', 'revealing']
senticnet['consultive'] = [0.795, -0.977, 0, 0.679, '#joyful', '#surprising', 0.817, 'advisory', 'consultative', 'consultatory', 'informatory', 'revealing']
senticnet['consumable'] = [0.184, 0.159, 0, 0.234, '#joyful', '#admirable', 0.192, 'ingest', 'sip', 'better_cold', 'gulp', 'like_eat']
senticnet['consume'] = [0.094, 0.166, -0.059, 0.164, '#interesting', '#admirable', 0.122, 'ingest', 'like_eat', 'better_cold', 'mouth_activity', 'gulp']
senticnet['consume_alcohol'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'drink_a_lot_of_booze', 'drink_excess', 'open_bottle', 'drink_a_lot_of_alcohol', 'buy_alcohol']
senticnet['consume_alcoholic_beverage'] = [0.081, -0.058, 0, -0.032, '#joyful', '#surprising', 0.036, 'drink_alcohol', 'meet_woman', 'drink_much', 'socialize', 'drink_liquor']
senticnet['consume_food'] = [0.097, 0, 0, 0, '#joyful', '#joyful', 0.032, 'serve_liquid', 'eat_food', 'swallow', 'fill_up', 'drink_soup']
senticnet['consume_nourishment'] = [0.055, 0.131, -0.065, 0.121, '#interesting', '#admirable', 0.081, 'masticate', 'ingest_food', 'swallow_food', 'satisfy_appetite', 'feed']
senticnet['consumer'] = [-0.058, -0.025, 0, -0.068, '#sad', '#disgusting', -0.034, 'capitalist', 'buyer', 'merchandise', 'buy_bread', 'buy_meat']
senticnet['consumer_price_index'] = [0.538, -0.802, 0, 0.517, '#joyful', '#surprising', 0.619, 'indicator', 'retail_price_index', 'producer_price_index', 'wholesale_price_index', 'price_index']
senticnet['consumerism'] = [0, 0, -0.869, -0.819, '#scared', '#disgusting', -0.563, 'generosity', 'oral_sex', 'win_lottery', 'gift_wrap', 'give_away']
senticnet['consummate'] = [0.513, -0.811, 0, 0.917, '#surprising', '#admirable', 0.747, 'sex', 'execute', 'fulfill', 'carry_through', 'accomplish']
senticnet['consumption'] = [0, -0.174, 0, 0.244, '#surprising', '#admirable', 0.139, 'obtain_food', 'serve_food', 'take_order', 'carry_food', 'make_dinner']
senticnet['contact'] = [0, 0.845, 0, 0.701, '#interesting', '#admirable', 0.515, 'beckon', 'dial_phone', 'telephone_ring', 'make_contact', 'dial_telephone']
senticnet['contact_friend'] = [0, 0, 0, 0.077, '#admirable', '#admirable', 0.026, 'find_person', 'meet_at_coffee_shop', 'arrange_meet', 'chat', 'call_phone']
senticnet['contact_lawyer'] = [-0.152, 0.088, -0.101, 0, '#sad', '#scared', -0.055, 'hire_lawyer', 'call_lawyer', 'pass_judgment', 'question_witness', 'become_lawyer']
senticnet['contact_lens'] = [0.026, -0.166, -0.05, 0.076, '#surprising', '#admirable', 0.073, 'monocle', 'eyeglass', 'spectacle', 'lens', 'sheer']
senticnet['contact_police'] = [0.214, 0.258, -0.09, 0.2, '#joyful', '#interesting', 0.194, 'gather_evidence', 'testify', 'crime_scene', 'give_testimony', 'receive_help']
senticnet['contact_sport'] = [0, -0.085, 0, 0.085, '#surprising', '#admirable', 0.057, 'rough_game', 'rough_sport', 'type_of_sport', 'team_sport', 'ball_sport']
senticnet['contagion'] = [0.925, -0.561, 0, 0.626, '#joyful', '#admirable', 0.704, 'influenza', 'flu', 'grippe', 'measles', 'rubeola']
senticnet['contagious'] = [-0.857, 0, 0, -0.982, '#sad', '#disgusting', -0.613, 'infectious', 'communicable', 'epidemic', 'pandemic', 'epizootic']
senticnet['contagious_disease'] = [-0.116, 0, -0.153, -0.241, '#scared', '#disgusting', -0.17, 'disease', 'infectious_disease', 'polio', 'malady', 'sickness']
senticnet['contain'] = [0.064, 0.201, -0.143, 0.211, '#interesting', '#admirable', 0.111, 'hold_onto', 'upkeep', 'keep', 'hold', 'store_dry_goods']
senticnet['contain_food'] = [0.034, 0, 0.012, 0.106, '#joyful', '#admirable', 0.043, 'metal_container', 'food_container', 'common_name', 'metal_cylinder', 'thin_metal']
senticnet['contain_liquid'] = [-0.038, -0.024, -0.063, -0.099, '#scared', '#disgusting', -0.059, 'kill_enemy', 'protect_country', 'target_practice', 'self_defense', 'shoot_target']
senticnet['container'] = [0.035, -0.015, 0.009, 0.063, '#joyful', '#admirable', 0.035, 'carton', 'jar', 'contain', 'hold_cupcake', 'store_dish']
senticnet['container_cup'] = [0.214, 0.258, -0.09, 0.2, '#joyful', '#interesting', 0.194, 'cup', 'carafe', 'pitcher', 'mug', 'glasses']
senticnet['container_pitcher'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'pitcher', 'carafe', 'cup', 'mug', 'glass_of_water']
senticnet['contaminative'] = [-0.657, 0, 0.995, -0.625, '#sad', '#angry', -0.759, 'dirty', 'putrefactive', 'putrefacient', 'abscessed', 'infected']
senticnet['contemn'] = [-0.093, 0.188, 0.625, -0.637, '#angry', '#disgusting', -0.389, 'disdain', 'misanthropy', 'misoneism', 'misopedia', 'misology']
senticnet['contemplate'] = [-0.061, 0.145, 0.03, 0.062, '#interesting', '#admirable', 0.039, 'cogitate', 'remember', 'remember_phone_number', 'use_memory', 'system_abstract_think']
senticnet['contemplation'] = [0, 0, -0.831, -0.969, '#scared', '#disgusting', -0.6, 'remember', 'commemorate_event', 'remember_past', 'use_memory', 'honor_person']
senticnet['contemplative'] = [0.703, 0.725, 0, 0, '#joyful', '#interesting', 0.476, 'pondering', 'ruminative', 'broody', 'meditative', 'think']
senticnet['contemporary'] = [0, 0.776, 0, 0.887, '#interesting', '#admirable', 0.554, 'timely', 'right_now', 'up_date', 'art', 'modern']
senticnet['contemporary_world'] = [0.86, -0.794, 0, 0.93, '#joyful', '#admirable', 0.861, 'modern_times', 'present_times', 'modern_world', 'time', 'period']
senticnet['contempt'] = [0, 0, 1, -1, '#angry', '#disgusting', -0.667, 'despite', 'disincline', 'disinclination', 'disinclined', 'indispose']
senticnet['contemptible'] = [-0.722, 0, 0.569, -0.861, '#sad', '#disgusting', -0.717, 'abject', 'scurvy', 'miserable', 'scummy', 'pathetic']
senticnet['contender'] = [0.85, -0.894, 0, 0.634, '#joyful', '#surprising', 0.793, 'rival', 'competition', 'challenger', 'competitor', 'comer']
senticnet['content'] = [0.966, 0, 0, 0, '#joyful', '#joyful', 0.322, 'satisfy', 'gratify', 'jubilation', 'contentment', 'fulfill']
senticnet['contented'] = [0.701, 0.624, -0.226, 0.311, '#joyful', '#interesting', 0.47, 'jubilant', 'exuberant', 'jubilate', 'wallow', 'exult']
senticnet['contention'] = [0, 0, 0.914, -0.748, '#angry', '#disgusting', -0.554, 'testimony', 'claim', 'charge', 'assertion', 'accusation']
senticnet['contentious'] = [0.702, -0.515, 0, 0.658, '#joyful', '#admirable', 0.625, 'argumentative', 'disputatious', 'disputative', 'eristic', 'eristical']
senticnet['contentment'] = [0.822, 0, 0, 0, '#joyful', '#joyful', 0.274, 'euphoria', 'jubilation', 'elation', 'cheer', 'glee']
senticnet['contest'] = [0.072, -0.037, 0, 0, '#joyful', '#surprising', 0.036, 'sport_play', 'excite_game', 'verbosity', 'scrabble', 'sport']
senticnet['contestable'] = [0.544, -0.693, 0, 0.658, '#surprising', '#admirable', 0.632, 'shakable', 'shakeable', 'challengeable', 'disputable', 'debatable']
senticnet['contestant'] = [-0.081, -0.032, 0, -0.057, '#sad', '#disgusting', -0.035, 'graduate_student', 'student', 'serious_student', 'competition', 'hard_worker']
senticnet['contestation'] = [0.797, -0.877, 0, 0.83, '#surprising', '#admirable', 0.835, 'firestorm', 'dispute', 'fight', 'conflict', 'polemic']
senticnet['continent'] = [0.839, -0.704, 0, 0.93, '#joyful', '#admirable', 0.824, 'virtuous', 'celibate', 'pure', 'chaste', 'virginal']
senticnet['contingency'] = [0.809, -0.588, 0, 0.702, '#joyful', '#admirable', 0.7, 'state', 'reliance', 'subordination', 'helplessness', 'dependence']
senticnet['continuation'] = [-0.046, 0.173, -0.126, 0.209, '#interesting', '#admirable', 0.07, 'extend', 'reach_out', 'grow_long', 'reach', 'further']
senticnet['continue'] = [0, 0.223, -0.156, 0.272, '#interesting', '#admirable', 0.113, 'tow', 'come', 'arrive', 'carry', 'allow']
senticnet['continue_story'] = [-0.067, -0.011, 0, -0.064, '#sad', '#disgusting', -0.04, 'make_paper_airplane', 'write_note', 'story', 'witting', 'make_mark_paper']
senticnet['continuing_education'] = [0.695, -0.654, 0, 0.926, '#joyful', '#admirable', 0.758, 'education', 'didactics', 'educational_activity', 'pedagogy', 'instruction']
senticnet['continuing_trespass'] = [-0.961, 0, 0.589, -0.572, '#sad', '#angry', -0.707, 'trespass', 'trespass_de_bonis_asportatis', 'trespass_on_case', 'trespass_quare_clausum_fregit', 'trespass_viet_armis']
senticnet['continuity'] = [0.869, -0.88, 0, 0.598, '#joyful', '#surprising', 0.782, 'connectedness', 'connection', 'consistency', 'coherence', 'link']
senticnet['continuous'] = [-0.605, 0, 0.509, -0.674, '#sad', '#disgusting', -0.596, 'dogging', 'persisting', 'sustained', 'consecutive', 'perpetual']
senticnet['contorted'] = [-0.93, 0, 0.861, -0.504, '#sad', '#angry', -0.765, 'knotty', 'crooked', 'writhed', 'writhen', 'anfractuous']
senticnet['contrabandist'] = [-0.909, 0, 0.526, -0.631, '#sad', '#disgusting', -0.689, 'criminal', 'outlaw', 'malefactor', 'felon', 'crook']
senticnet['contraception'] = [0, 0.88, 0, 0.91, '#interesting', '#admirable', 0.597, 'safe_sex', 'sex', 'prevent_pregnancy', 'avoid_pregnancy', 'become_aroused']
senticnet['contraceptive'] = [0, 0, -0.772, -0.736, '#scared', '#disgusting', -0.503, 'painkiller', 'wax_dental_floss', 'aspirin', 'disposable_razor', 'contraceptive_device']
senticnet['contraceptive_device'] = [0, 0, -0.885, -0.747, '#scared', '#disgusting', -0.544, 'birth_control_pill', 'condom', 'contraceptive_pills', 'sex_toy', 'prevent_pregnancy']
senticnet['contraceptive_pills'] = [0, 0, -0.837, -0.734, '#scared', '#disgusting', -0.524, 'birth_control_pill', 'condom', 'contraceptive_device', 'cause_side_effect', 'prevent_pregnancy']
senticnet['contract'] = [0.865, -0.844, 0, 0.915, '#joyful', '#admirable', 0.875, 'grant', 'sale_in_gross', 'contract_of_hazard', 'adhesion_contract', 'contract_of_adhesion']
senticnet['contract_of_adhesion'] = [0.865, -0.844, 0, 0.915, '#joyful', '#admirable', 0.875, 'grant', 'sale_in_gross', 'contract_of_hazard', 'adhesion_contract', 'contract']
senticnet['contract_of_hazard'] = [0.865, -0.844, 0, 0.915, '#joyful', '#admirable', 0.875, 'grant', 'sale_in_gross', 'contract', 'adhesion_contract', 'contract_of_adhesion']
senticnet['contraction'] = [0, 0.86, 0, 0.719, '#interesting', '#admirable', 0.526, 'mathematical', 'muscle', 'math_function', 'feel_sick', 'separation']
senticnet['contractor'] = [0, 0.316, 0, 0.214, '#interesting', '#admirable', 0.177, 'monthly_pay', 'account_term', 'money_loss', 'money', 'money_relate']
senticnet['contradiction'] = [0, 0, 0.857, -0.71, '#angry', '#disgusting', -0.522, 'contrary', 'opposite', 'lie', 'liar', 'bad_person']
senticnet['contradiction_in_terms'] = [-0.569, 0, 0.593, -0.595, '#angry', '#disgusting', -0.586, 'antinomy', 'paradox', 'falsehood', 'falsity', 'untruth']
senticnet['contradictory'] = [-0.971, 0, 0.712, -0.786, '#sad', '#disgusting', -0.823, 'discrepant', 'unreconciled', 'scratchy', 'uneven', 'inconsistent']
senticnet['contradistinguish'] = [0.933, -0.638, 0, 0.59, '#joyful', '#surprising', 0.72, 'tell_apart', 'severalize', 'differentiate', 'secern', 'secernate']
senticnet['contralto'] = [0.961, 0.965, 0, 0, '#joyful', '#interesting', 0.642, 'sound_control_room', 'beat_box', 'ticket_taker', 'speaker', 'microphone_boom']
senticnet['contrariness'] = [-0.751, 0, 0.683, -0.992, '#sad', '#disgusting', -0.809, 'cussedness', 'orneriness', 'unruliness', 'fractiousness', 'willfulness']
senticnet['contrarious'] = [-0.964, 0, 0.858, -0.876, '#sad', '#disgusting', -0.899, 'unregenerate', 'dogged', 'pertinacious', 'cantankerous', 'bolshy']
senticnet['contrary'] = [-0.768, 0, 0.85, -0.778, '#angry', '#disgusting', -0.799, 'fussy', 'pester', 'fastidious', 'touch_ball', 'inquisitive']
senticnet['contrast'] = [-0.946, 0, 0.904, -0.751, '#sad', '#angry', -0.867, 'confrontation', 'comparing', 'scrutiny', 'collation', 'likening']
senticnet['contrastive'] = [-0.668, 0, 0.502, -0.796, '#sad', '#disgusting', -0.655, 'adversative', 'oppositive', 'disjunctive', 'alternative', 'separative']
senticnet['contravene'] = [-0.933, 0, 0.669, -0.931, '#sad', '#disgusting', -0.844, 'offend', 'violate', 'go_against', 'break', 'transgress']
senticnet['contribute'] = [0.87, -0.943, 0, 0.508, '#joyful', '#surprising', 0.774, 'instill', 'transfuse', 'change', 'throw_in', 'alter']
senticnet['contribution'] = [0, 0, 0, 0.762, '#admirable', '#admirable', 0.254, 'offer', 'cope', 'give', 'receive', 'charity']
senticnet['contributory_negligence'] = [-0.691, 0, 0.516, -0.966, '#sad', '#disgusting', -0.724, 'criminal_negligence', 'culpable_negligence', 'evasion', 'dereliction', 'negligence']
senticnet['contrite'] = [-0.884, 0.178, -0.6, 0, '#sad', '#scared', -0.435, 'remorseful', 'rueful', 'ruthful', 'bereaved', 'sorrowing']
senticnet['contritely'] = [-0.891, 0.168, -0.609, 0.05, '#sad', '#scared', -0.427, 'remorsefully', 'contrition', 'contriteness', 'ruefully', 'attrition']
senticnet['contriteness'] = [-0.891, 0.168, -0.609, 0.05, '#sad', '#scared', -0.427, 'remorsefully', 'contritely', 'contrition', 'ruefully', 'attrition']
senticnet['contrition'] = [-0.891, 0.168, -0.609, 0.05, '#sad', '#scared', -0.427, 'remorsefully', 'contritely', 'contriteness', 'ruefully', 'attrition']
senticnet['contrivance'] = [0.843, -0.998, 0, 0.706, '#joyful', '#surprising', 0.849, 'gadgetry', 'gimbal', 'injector', 'mod_con', 'device']
senticnet['control'] = [0, 0.203, -0.137, 0.18, '#interesting', '#admirable', 0.082, 'check', 'inspection', 'examination', 'audit', 'command']
senticnet['control_access'] = [0.041, 0.158, -0.056, 0.229, '#interesting', '#admirable', 0.124, 'restrict_access', 'keep_someone_out', 'use_farm', 'separate_room', 'latch']
senticnet['control_car'] = [0, 0, 0, 0.093, '#admirable', '#admirable', 0.031, 'steer_car', 'car_travel', 'change_gear', 'transportation', 'car_movement']
senticnet['control_center'] = [0.865, -0.844, 0, 0.915, '#joyful', '#admirable', 0.875, 'airport', 'subway', 'bus_stop', 'control_tower', 'bus_terminal']
senticnet['control_computer'] = [-0.084, -0.068, 0.123, -0.133, '#angry', '#disgusting', -0.091, 'process_information', 'write_text', 'write_code', 'program', 'learn_program_language']
senticnet['control_horse'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'jockey', 'lead_ropes', 'horse', 'sprinter', 'saddle']
senticnet['control_machine'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'engineer', 'pilot', 'computer', 'instructions', 'mechanical_room']
senticnet['control_person'] = [-0.165, 0.238, -0.163, 0.179, '#interesting', '#admirable', 0.03, 'government', 'nominate', 'legislature', 'government_person', 'pass_law']
senticnet['control_road'] = [0.038, 0, 0.01, 0.059, '#joyful', '#admirable', 0.029, 'traffic_rule', 'develop_city', 'bicycle_area', 'red_light', 'yellow_line']
senticnet['control_room'] = [0.119, 0, 0, 0, '#joyful', '#joyful', 0.04, 'control', 'technician', 'indoor_object', 'room', 'tape_player']
senticnet['control_tower'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'airport', 'subway', 'bus_stop', 'control_center', 'bus_terminal']
senticnet['control_weather'] = [0.814, 0.773, 0, 0, '#joyful', '#interesting', 0.529, 'rain_check', 'check_weather', 'weather_forecast', 'forecast', 'weather']
senticnet['controled'] = [-0.072, 0.109, 0, 0.095, '#interesting', '#admirable', 0.044, 'car_path', 'drive', 'pave', 'pathway', 'driven']
senticnet['controllable'] = [0.5, -0.9, 0, 0.525, '#surprising', '#admirable', 0.642, 'administrable', 'manageable', 'governable', 'steerable', 'dirigible']
senticnet['controlled'] = [0.858, -0.933, 0, 0.58, '#joyful', '#surprising', 0.79, 'regimented', 'obsessed', 'possessed', 'disciplined', 'dominated']
senticnet['controversial'] = [-0.856, 0, 0.749, -0.998, '#sad', '#disgusting', -0.868, 'arguable', 'contentious', 'disputable', 'disputed', 'polemic']
senticnet['controversialist'] = [-0.856, 0, 0.749, -0.998, '#sad', '#disgusting', -0.868, 'hairsplitter', 'fight', 'quarrel', 'obstructor', 'obstructer']
senticnet['controversy'] = [0, 0, 0.94, 0, '#angry', '#angry', -0.313, 'feel_angry', 'hurt_feeling', 'feel_hurt', 'ridicule', 'vengeance']
senticnet['controvert'] = [-0.687, 0, 0.923, -0.684, '#sad', '#angry', -0.765, 'negative', 'veto', 'refute', 'rebut', 'blackball']
senticnet['contumacious'] = [-0.652, 0, 0.795, -0.96, '#angry', '#disgusting', -0.802, 'insubordinate', 'disobedient', 'unruly', 'rebellious', 'mutinous']
senticnet['contumely'] = [-0.648, 0, 0.594, -0.947, '#sad', '#disgusting', -0.73, 'scurrility', 'billingsgate', 'disrespect', 'discourtesy', 'vituperation']
senticnet['contusion'] = [-0.1, -0.062, 0.017, -0.133, '#sad', '#disgusting', -0.063, 'physical_injury', 'soreness', 'increased_heart_rate', 'better_cardiovascular_health', 'much_exercise']
senticnet['conundrum'] = [-0.149, 0, -0.145, 0.144, '#sad', '#scared', -0.05, 'problem', 'jeopardy', 'outcome', 'difficulty', 'unwanted_outcome']
senticnet['convalesce'] = [0.815, -0.757, 0, 0.744, '#joyful', '#surprising', 0.772, 'perk', 'perk_up', 'improve', 'look_better', 'meliorate']
senticnet['convenience'] = [0.054, 0.076, 0, 0.127, '#interesting', '#admirable', 0.086, 'purchase_food', 'donate_charity', 'walk_exercise', 'buy_bread', 'buy_new']
senticnet['convenience_food_store'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'large_supermarket', 'food_store', 'large_food_store', 'corner_shop', 'corner_grocery']
senticnet['convenience_shop'] = [0, 0.113, 0.041, 0.058, '#interesting', '#admirable', 0.043, 'corner_shop', 'general_store', 'bazaar', 'large_supermarket', 'goods']
senticnet['convenience_store'] = [0, 0.088, 0, 0, '#interesting', '#interesting', 0.029, 'buy_food', 'convenience', 'grocery_store', 'corner_shop', 'petrol_kiosk']
senticnet['convenient'] = [-0.043, 0.172, -0.052, 0.057, '#interesting', '#admirable', 0.045, 'carry_money', 'put_money', 'require_signature', 'store_money', 'keep_money']
senticnet['convent'] = [0.042, 0.233, 0, 0.195, '#interesting', '#admirable', 0.157, 'monastery', 'capital_build', 'steeple', 'confession', 'cathedral']
senticnet['convention'] = [0.976, -0.921, 0, 0, '#joyful', '#surprising', 0.632, 'meeting', 'symposium', 'death_row', 'another_planet', 'loose_end']
senticnet['conventional'] = [0.84, -0.646, 0, 0.912, '#joyful', '#admirable', 0.799, 'received', 'customary', 'formulaic', 'stuffy', 'stodgy']
senticnet['conventionalism'] = [0.646, -0.924, 0, 0.816, '#surprising', '#admirable', 0.795, 'conventionality', 'traditionalism', 'orthodoxy', 'traditionality', 'unoriginality']
senticnet['conventionality'] = [0.646, -0.924, 0, 0.816, '#surprising', '#admirable', 0.795, 'orthodoxy', 'traditionalism', 'conventionalism', 'traditionality', 'unoriginality']
senticnet['conversant'] = [0.61, -0.983, 0, 0.795, '#surprising', '#admirable', 0.796, 'enlightened', 'informed', 'hep', 'hip', 'hip_to']
senticnet['conversation'] = [0, -0.761, 0, 0.98, '#surprising', '#admirable', 0.58, 'chat_friend', 'take_phone_call', 'communicate', 'talk_far_away', 'chat']
senticnet['conversational_partner'] = [0.727, -0.622, 0, 0.57, '#joyful', '#surprising', 0.64, 'utterer', 'deipnosophist', 'interlocutor', 'conversationalist', 'speaker']
senticnet['conversationalist'] = [0.727, -0.622, 0, 0.57, '#joyful', '#surprising', 0.64, 'utterer', 'deipnosophist', 'interlocutor', 'conversational_partner', 'speaker']
senticnet['conversationist'] = [0.947, -0.99, 0, 0.936, '#joyful', '#surprising', 0.958, 'utterer', 'deipnosophist', 'interlocutor', 'conversational_partner', 'speaker']
senticnet['converse'] = [0, -0.881, 0, 0.886, '#surprising', '#admirable', 0.589, 'dial_phone', 'chat', 'say_name', 'call_person', 'talkative']
senticnet['conversion_disorder'] = [-0.525, 0, 0.839, -0.865, '#angry', '#disgusting', -0.743, 'encopresis', 'upset', 'psychosomatic_disorder', 'folie', 'conversion_reaction']
senticnet['conversion_reaction'] = [-0.525, 0, 0.839, -0.865, '#angry', '#disgusting', -0.743, 'encopresis', 'upset', 'psychosomatic_disorder', 'conversion_disorder', 'folie']
senticnet['convert_energy'] = [0, 0.906, 0, 0.883, '#interesting', '#admirable', 0.596, 'energy', 'tai_chi', 'emotion', 'human_emotion', 'sentiment']
senticnet['convertibility'] = [0.912, -0.757, 0, 0.512, '#joyful', '#surprising', 0.727, 'transferability', 'exchangeability', 'changeableness', 'changeability', 'permutability']
senticnet['convertible'] = [0.623, -0.566, 0, 0.974, '#joyful', '#admirable', 0.721, 'alterable', 'commutable', 'translatable', 'transformable', 'transmutable']
senticnet['convey_idea'] = [0.528, 0.564, 0, 0.925, '#interesting', '#admirable', 0.672, 'relay_information', 'get_information', 'spread_knowledge', 'express_idea', 'pass_knowledge']
senticnet['convey_information'] = [0.995, 0.708, 0, 0.906, '#joyful', '#admirable', 0.87, 'share_thought', 'fact_right', 'take_message', 'express_idea', 'teach_new']
senticnet['convey_message'] = [0.963, 0.606, 0, 0.955, '#joyful', '#admirable', 0.841, 'represent_idea', 'communicate_thought', 'message', 'send_message', 'record_data']
senticnet['conveyance'] = [0, 0, 0, 0.184, '#admirable', '#admirable', 0.061, 'car_action', 'passenger_car', 'car_bus', 'car_travel', 'run_car']
senticnet['convict'] = [0, 0, -0.723, -0.808, '#scared', '#disgusting', -0.51, 'jailbird', 'prisoner', 'imprisoned', 'captive', 'inmate']
senticnet['convict_crime'] = [0, 0, 0, -0.875, '#disgusting', '#disgusting', -0.292, 'druggy', 'steal', 'criminal', 'get_away_crime', 'obstruct_justice']
senticnet['convict_criminal'] = [0, 0, 0, 0.867, '#admirable', '#admirable', 0.289, 'seek_justice', 'punish_crime', 'find_guilty', 'punish_criminal', 'question_witness']
senticnet['convince'] = [0, 0.967, 0, 0.801, '#interesting', '#admirable', 0.589, 'talk_much', 'discuss', 'transfer_knowledge', 'communicate_other_person', 'knowledge']
senticnet['convinced'] = [0.542, 0.668, -0.268, 0.288, '#joyful', '#interesting', 0.41, 'reassured', 'reassuring', 'assure', 'reassuringly', 'reassure']
senticnet['convolute'] = [0.612, -0.536, 0, 0.532, '#joyful', '#surprising', 0.56, 'coiledd', 'coiled', 'involute', 'rolled', 'wound']
senticnet['convoluted'] = [0.612, -0.536, 0, 0.532, '#joyful', '#surprising', 0.56, 'coiled', 'convolute', 'involute', 'rolled', 'wound']
senticnet['convulse'] = [0.152, 0.099, -0.07, 0.107, '#joyful', '#admirable', 0.096, 'strong_taste', 'ale', 'cocktail', 'dark_beer', 'beer']
senticnet['convulsion'] = [-0.701, 0, 0.725, -0.523, '#sad', '#angry', -0.65, 'turmoil', 'commotion', 'tempest', 'disorder', 'earthquake']
senticnet['convulsive'] = [-0.569, 0, 0.849, -0.618, '#angry', '#disgusting', -0.679, 'unsteady', 'arrhythmic', 'jerky', 'spasmodic', 'spastic']
senticnet['cook'] = [0.04, 0, 0, 0.067, '#joyful', '#admirable', 0.036, 'add_flavor', 'food', 'taste', 'ingredient', 'tongue']
senticnet['cook_before_eaten'] = [0, 0.804, 0, 0.765, '#interesting', '#admirable', 0.523, 'yummy', 'starchy_food', 'edible', 'eatable', 'high_protein']
senticnet['cook_book'] = [0, 0.076, 0, 0.066, '#interesting', '#admirable', 0.047, 'bookmark', 'cooking_class', 'teacher', 'instructions', 'a_lot_of_books']
senticnet['cook_breakfast'] = [0.025, 0.084, 0, 0.062, '#interesting', '#admirable', 0.057, 'eat_tasty_food', 'serve', 'eat_together', 'work_restaurant', 'take_order']
senticnet['cook_curry'] = [0.936, -0.998, 0, 0, '#joyful', '#surprising', 0.645, 'make_bread', 'cook_dinner', 'cook_meal', 'curry_powder', 'follow_recipe']
senticnet['cook_dinner'] = [0.744, -0.985, 0, 0, '#joyful', '#surprising', 0.576, 'make_bread', 'bake_cake', 'cook_meal', 'cook_curry', 'follow_recipe']
senticnet['cook_food'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'cook_meat', 'cook_hamburger', 'roast_meat', 'cook_rice', 'brown_meat']
senticnet['cook_grill'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'grill', 'red_meat', 'barbecue', 'cook', 'grilled_vegetables']
senticnet['cook_hamburger'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'cook_meat', 'eat_outdoors', 'cook_food', 'roast_meat', 'brown_meat']
senticnet['cook_lunch'] = [0.754, 0.903, 0, 0, '#joyful', '#interesting', 0.552, 'make_bread', 'cook_dinner', 'cook_meal', 'follow_recipe', 'bake_cake']
senticnet['cook_meal'] = [-0.026, 0.073, 0.025, 0.054, '#interesting', '#admirable', 0.025, 'make_food', 'make_bread', 'follow_recipe', 'cook_curry', 'cook_meat']
senticnet['cook_meat'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'eat_outdoors', 'cook_hamburger', 'cook_food', 'baker', 'brown_meat']
senticnet['cook_rice'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'heat_food', 'roast_meat', 'cook_food', 'make_food_taste_better', 'cook_hamburger']
senticnet['cook_tool'] = [0.997, 0.814, 0, 0, '#joyful', '#interesting', 0.604, 'stove', 'pan', 'spoon', 'thongs', 'pot']
senticnet['cook_up'] = [-0.959, 0, 0.721, -0.75, '#sad', '#disgusting', -0.81, 'fix', 'ready', 'make', 'cook', 'prepare']
senticnet['cook_vegetable'] = [-0.051, 0, -0.045, -0.052, '#sad', '#disgusting', -0.049, 'warm_hand', 'cut_knife', 'even_odds', 'shine_car', 'dig_gold']
senticnet['cookbook'] = [0.044, 0, 0, 0.206, '#joyful', '#admirable', 0.083, 'book_end', 'begin_end', 'good_book', 'novel', 'book']
senticnet['cooked'] = [-0.967, 0, 0, -0.991, '#sad', '#disgusting', -0.653, 'make', 'prepare', 'fudge', 'manipulate', 'fake']
senticnet['cookie'] = [0.035, -0.091, 0, 0, '#joyful', '#surprising', 0.042, 'custard', 'pie', 'mousse', 'doughnut', 'muffin']
senticnet['cookie_crumb'] = [0, -0.059, 0.1, -0.106, '#angry', '#disgusting', -0.049, 'dust_mite', 'cat_hair', 'old_sock', 'dirty_sock', 'sleep_cat']
senticnet['cooking_class'] = [0, 0.076, 0, 0.066, '#interesting', '#admirable', 0.047, 'bookmark', 'cook_book', 'teacher', 'instruction', 'a_lot_of_books']
senticnet['cool'] = [0.515, 0.568, -0.227, 0.331, '#joyful', '#interesting', 0.396, 'serene', 'easy', 'cool_down', 'gay', 'romantic']
senticnet['cool_air'] = [0.515, 0.568, -0.227, 0.331, '#joyful', '#interesting', 0.396, 'fresh', 'air', 'cool', 'fresh_air', 'chilly']
senticnet['cool_car_engine'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'cool_room', 'keep_cool', 'circulate_air', 'car_engine', 'reflect_image']
senticnet['cool_color'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'painting', 'primary_color', 'color_rainbow', 'color', 'warm_color']
senticnet['cool_down'] = [0.534, 0.625, -0.233, 0.271, '#joyful', '#interesting', 0.399, 'imperturbability', 'imperturbableness', 'tranquilly', 'quietude', 'quietness']
senticnet['cool_drink'] = [0.151, 0.11, -0.045, 0.11, '#joyful', '#interesting', 0.109, 'cola', 'sprite', 'soft_drink', 'cold_drink', 'keep_cold']
senticnet['cool_engine'] = [-0.048, -0.043, 0.083, -0.114, '#angry', '#disgusting', -0.067, 'bus_person', 'glide', 'fly_high', 'fly', 'six_legs']
senticnet['cool_food'] = [0.167, 0.161, -0.056, 0.173, '#joyful', '#admirable', 0.148, 'keep_food_cool', 'keep_food_spoil', 'keep_food_cold', 'keep_cool', 'cool_car_engine']
senticnet['cool_house'] = [0.276, 0.207, -0.141, 0.123, '#joyful', '#interesting', 0.155, 'generate_heat', 'last_long_time', 'cool_room', 'warm_house', 'power_engine']
senticnet['cool_moment'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'smart_technology', 'electric_fan', 'relax', 'refreshing', 'wind']
senticnet['cool_off'] = [0.305, 0.195, 0, 0.129, '#joyful', '#interesting', 0.21, 'cool_room', 'blow_air', 'cool_car_engine', 'circulate_air', 'move_air']
senticnet['cool_room'] = [0.45, 0.322, -0.12, 0.243, '#joyful', '#interesting', 0.298, 'circulate_air', 'cool_car_engine', 'cool', 'blow_air', 'switch_off']
senticnet['cool_temperature'] = [0, 0.727, 0, 0.88, '#interesting', '#admirable', 0.536, 'snowy', 'chilly', 'coldness', 'ice_rain', 'no_sun']
senticnet['cool_water'] = [0.718, 0, 0, 0, '#joyful', '#joyful', 0.239, 'water_container', 'still_water', 'cold_water', 'water', 'clean_water']
senticnet['cooler'] = [0, 0.094, 0, 0, '#interesting', '#interesting', 0.031, 'dark_area', 'cavern', 'under_umbrella', 'parasol', 'stick_wall']
senticnet['coolheaded'] = [0.68, -0.799, 0, 0.661, '#joyful', '#surprising', 0.713, 'unflurried', 'unflustered', 'unperturbed', 'unruffled', 'composed']
senticnet['cooling'] = [-0.641, 0, 0.612, -0.848, '#sad', '#disgusting', -0.7, 'chilling', 'frost', 'lyophilization', 'icing', 'freeze']
senticnet['coolness'] = [0.497, 0.594, -0.2, 0.263, '#joyful', '#interesting', 0.385, 'imperturbability', 'imperturbableness', 'placid', 'placidness', 'placidly']
senticnet['cooperate'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'interact', 'help_each_other', 'connect', 'face_to_face', 'interaction']
senticnet['cooperation'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'educate_others', 'share_knowledge', 'share_opinion', 'discover_new', 'collaboration']
senticnet['cooperative'] = [0, 0, -0.764, -0.874, '#scared', '#disgusting', -0.546, 'co-op', 'concerted', 'conjunct', 'conjunctive', 'accommodative']
senticnet['coordinate'] = [0, 0.115, 0, 0, '#interesting', '#interesting', 0.038, 'ledge', 'middle_road', 'mountain_top', 'coordinator', 'tennis_match']
senticnet['coordinated'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'highly_skilled', 'coordination', 'find_ball', 'cooperation', 'teamwork']
senticnet['coordination'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'highly_skilled', 'coordinated', 'find_ball', 'cooperation', 'teamwork']
senticnet['coordinator'] = [0, 0.115, 0, 0, '#interesting', '#interesting', 0.038, 'ledge', 'middle_road', 'mountain_top', 'coordinate', 'tennis_match']
senticnet['cope'] = [0, 0.928, 0, 0.872, '#interesting', '#admirable', 0.6, 'offer', 'receive', 'contribution', 'give', 'propose']
senticnet['coperation'] = [0.72, 0, 0, 0.982, '#joyful', '#admirable', 0.567, 'teamwork', 'gather_together', 'play_together', 'play', 'team_play']
senticnet['copper'] = [0.87, 0.822, 0, 0.717, '#joyful', '#interesting', 0.803, 'gold', 'bronze', 'alloy', 'titanium', 'medal']
senticnet['copper_wire'] = [0.085, 0, 0, 0, '#joyful', '#joyful', 0.028, 'wire', 'several_types', 'gas_stove', 'tape_player', 'control_room']
senticnet['copperplate'] = [-0.958, 0, 0.517, -0.536, '#sad', '#disgusting', -0.67, 'cursive', 'hand', 'minuscule', 'italic', 'round_hand']
senticnet['copulate'] = [0.049, 0.098, -0.079, 0.121, '#interesting', '#admirable', 0.063, 'procreate', 'reproduce', 'start_family', 'cause_cold', 'unprotect_sex']
senticnet['copulation'] = [0.947, -0.811, 0, 0.656, '#joyful', '#surprising', 0.805, 'sexual_intercourse', 'intercourse', 'sex_act', 'hank_panky', 'coitus']
senticnet['copy'] = [-0.024, 0.114, 0, 0.204, '#interesting', '#admirable', 0.098, 'mimic', 'halve', 'separate', 'divide', 'make_copy']
senticnet['copy_paste'] = [-0.109, 0, 0.032, -0.163, '#sad', '#disgusting', -0.101, 'slit', 'sever', 'open_wind', 'cause_bleed', 'draw_blood']
senticnet['copycat'] = [-0.132, 0, 0, -0.25, '#sad', '#disgusting', -0.127, 'intend', 'mimic', 'imitation', 'copy', 'heap']
senticnet['copyright'] = [0, 0.701, 0, 0.844, '#interesting', '#admirable', 0.515, 'write_down', 'run_out_paper', 'write_word', 'write_essay', 'realization']
senticnet['coquetry'] = [0.525, -0.857, 0, 0.599, '#surprising', '#admirable', 0.66, 'frolic', 'gambol', 'romp', 'play', 'caper']
senticnet['coral'] = [0.053, 0.073, -0.065, 0.104, '#interesting', '#admirable', 0.055, 'aquatic_life', 'small_fish', 'horizon', 'ocean', 'waves']
senticnet['coral_reef'] = [0, 0, -0.065, -0.036, '#scared', '#disgusting', -0.034, 'tidal_pool', 'saltwater', 'fish_market', 'sea', 'reef']
senticnet['cord'] = [-0.973, 0, 0.865, -0.543, '#sad', '#angry', -0.794, 'piping', 'lace', 'lacing', 'perpendicular', 'slack']
senticnet['cordial'] = [0.693, -0.945, 0, 0.713, '#surprising', '#admirable', 0.784, 'anisette', 'maraschino', 'ratafia', 'pastis', 'ratafee']
senticnet['cordite'] = [-0.585, 0, 0.661, -0.954, '#angry', '#disgusting', -0.733, 'explosive', 'explosive_compound', 'dynamite', 'plastic_explosive', 'plastique']
senticnet['cordless'] = [0, -0.122, 0.011, 0.089, '#surprising', '#admirable', 0.067, 'cellular_phone', 'telephone', 'wireless', 'connect', 'message']
senticnet['cordon_bleu'] = [0.538, -0.802, 0, 0.517, '#joyful', '#surprising', 0.619, 'blue_ribbon', 'badge', 'allegory', 'stripe', 'merit_badge']
senticnet['cork'] = [0.108, -0.113, 0.014, 0, '#joyful', '#surprising', 0.069, 'lumber', 'beam', 'cedar', 'mahogany', 'plank']
senticnet['corkscrew'] = [0.043, -0.028, 0.063, -0.113, '#angry', '#disgusting', -0.035, 'swiss_army_knife', 'whisk', 'ladle', 'coffee_mug', 'container_cup']
senticnet['corn'] = [0, 0.065, 0.031, 0.052, '#interesting', '#admirable', 0.029, 'wheat', 'white_rice', 'rye', 'grain', 'oat']
senticnet['corn_flake'] = [0.538, -0.802, 0, 0.517, '#joyful', '#surprising', 0.619, 'puffed_rice', 'granola', 'raisin_bran', 'cold_cereal', 'bran_flake']
senticnet['corn_sugar'] = [0.677, -0.545, 0, 0.587, '#joyful', '#admirable', 0.603, 'glucosamine', 'glucose', 'dextrose', 'dextroglucose', 'grape_sugar']
senticnet['cornel'] = [0.773, -0.55, 0, 0.949, '#joyful', '#admirable', 0.757, 'bunchberry', 'dwarf_cornel', 'crackerberry', 'pudding_berry', 'common_white_dogwood']
senticnet['corner'] = [-0.873, 0, 0.673, -0.553, '#sad', '#angry', -0.7, 'hot_water', 'difficulty', 'care', 'plight', 'box']
senticnet['corner_grocery'] = [0, 0, 0.044, -0.03, '#angry', '#disgusting', -0.025, 'large_supermarket', 'food_store', 'large_food_store', 'corner_shop', 'convenience_food_store']
senticnet['corner_prey'] = [-0.12, -0.053, -0.047, -0.127, '#sad', '#disgusting', -0.08, 'hunt_game', 'even_odds', 'kill_people', 'kill_pest', 'shoot_bullet']
senticnet['corner_shop'] = [0, 0.113, 0.041, 0.058, '#interesting', '#admirable', 0.043, 'convenience_shop', 'general_store', 'bazaar', 'large_supermarket', 'goods']
senticnet['corner_store'] = [0, 0.081, 0, 0.071, '#interesting', '#admirable', 0.051, 'thrift_store', 'type_of_store', 'wall_street', 'many_shops', 'department_store']
senticnet['corner_two_streets'] = [0, 0, 0.011, -0.078, '#angry', '#disgusting', -0.03, 'street_corner', 'city_street', 'junk_yard', 'street', 'junction']
senticnet['corner_well'] = [-0.098, 0, -0.081, 0, '#sad', '#scared', -0.06, 'appear_suddenly', 'gain_speed', 'travel_road', 'drive_down_street', 'get_accident']
senticnet['cornerless'] = [0, -0.896, 0, 0.988, '#surprising', '#admirable', 0.628, 'ball_shape', 'round_shape', 'orange', 'circle_shape', 'orb']
senticnet['cornfield'] = [0, 0, 0.933, -0.866, '#angry', '#disgusting', -0.6, 'mess', 'trap', 'snake_belly', 'dirty_house', 'dirty_kitchen']
senticnet['corona'] = [0.931, -0.825, 0, 0.709, '#joyful', '#surprising', 0.822, 'light', 'aureole', 'radiance', 'visible_light', 'visible_radiation']
senticnet['coronary_failure'] = [-0.614, 0, 0.699, -0.773, '#angry', '#disgusting', -0.695, 'congestive_heart_failure', 'heart_attack', 'failure', 'heart_disease', 'cardiopathy']
senticnet['corporal'] = [-0.151, 0.081, -0.123, 0, '#sad', '#scared', -0.064, 'anatomy', 'body_extremity', 'body_member', 'below_neck', 'body_appendage']
senticnet['corporal_punishment'] = [-0.839, 0, 0.924, -0.79, '#sad', '#angry', -0.851, 'kick_in_butt', 'licking', 'whacking', 'stoning', 'lapidation']
senticnet['corporality'] = [-0.639, 0, 0.694, -0.667, '#angry', '#disgusting', -0.667, 'tangibility', 'tangibleness', 'palpability', 'reality', 'solidness']
senticnet['corporate'] = [0.037, 0.177, 0, 0.147, '#interesting', '#admirable', 0.12, 'business_organization', 'company', 'economic_activity', 'large_business', 'partnership']
senticnet['corporate_executive'] = [0.703, -0.598, 0, 0.842, '#joyful', '#admirable', 0.714, 'rainmaker', 'minister', 'administrator', 'executive', 'business_executive']
senticnet['corporate_trust'] = [0.776, -0.86, 0, 0.893, '#surprising', '#admirable', 0.843, 'trust', 'combine', 'consortium', 'cartel', 'association']
senticnet['corporation'] = [0.08, 0.195, 0, 0.137, '#interesting', '#admirable', 0.137, 'company', 'enterprise', 'business', 'partnership', 'large_business']
senticnet['corporeality'] = [-0.768, 0, 0.821, -0.71, '#sad', '#angry', -0.766, 'tangibility', 'tangibleness', 'palpability', 'reality', 'solidness']
senticnet['corpse'] = [-0.042, 0.077, -0.092, -0.08, '#scared', '#disgusting', -0.046, 'body', 'inside_body', 'normal_human_body', 'dead_person', 'nervous_system']
senticnet['corpulency'] = [-0.728, 0, 0.973, -0.579, '#sad', '#angry', -0.76, 'exogenous_obesity', 'blubber', 'fat', 'embonpoint', 'stoutness']
senticnet['corpus_callosum'] = [0.683, -0.918, 0, 0.679, '#joyful', '#surprising', 0.76, 'pathway', 'commissure', 'nerve_pathway', 'tract', 'nerve_tract']
senticnet['corpuscle'] = [-0.85, 0, 0.743, -0.839, '#sad', '#disgusting', -0.811, 'atom', 'molecule', 'particle', 'grinding', 'mote']
senticnet['corrasion'] = [-0.88, 0, 0.907, -0.522, '#sad', '#angry', -0.77, 'wearing', 'erosion', 'eroding', 'eating_away', 'wearing_away']
senticnet['correct'] = [0.026, 0.25, -0.049, 0.28, '#interesting', '#admirable', 0.169, 'make_better', 'bottom_line', 'tell_everyone', 'make_right', 'band_together']
senticnet['correct_behavior'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'retribution', 'end_marriage', 'vengeance', 'misbehavior', 'feel_bad']
senticnet['correct_homework'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'review', 'double_check', 'spelling', 'check_spelling', 'mark_exam']
senticnet['correct_mistake'] = [-0.12, 0.089, -0.101, 0, '#sad', '#scared', -0.044, 'wave_flag', 'kill_specific_group', 'age_gracefully', 'hurt_animal', 'bicycle_across_town']
senticnet['correct_vision'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'vision', 'eyes', 'contact_lens', 'use_eye', 'improve_vision']
senticnet['correctable'] = [0.779, -0.882, 0, 0.521, '#joyful', '#surprising', 0.727, 'amendable', 'corrigible', 'improvable', 'reformable', 'redeemable']
senticnet['correctional'] = [-0.753, 0, 0.981, -0.588, '#sad', '#angry', -0.774, 'retaliatory', 'penitentiary', 'punitive', 'retributive', 'retributory']
senticnet['correctional_rehabilitation'] = [0.641, -0.784, 0, 0.721, '#surprising', '#admirable', 0.715, 'rehabilitation', 'physical_rehabilitation', 'physical_restoration', 'therapeutic_rehabilitation', 'vocational_rehabilitation']
senticnet['correctitude'] = [0.85, -0.858, 0, 0.712, '#joyful', '#surprising', 0.807, 'decency', 'decorum', 'decorousness', 'correctness', 'seemliness']
senticnet['corrective'] = [-0.621, 0, 0.996, -0.683, '#angry', '#disgusting', -0.767, 'pack', 'face_pack', 'pickup', 'prosthesis', 'prosthetic_device']
senticnet['correctness'] = [0.85, -0.858, 0, 0.712, '#joyful', '#surprising', 0.807, 'decency', 'decorum', 'decorousness', 'correctitude', 'seemliness']
senticnet['corrector'] = [0, 0, -0.889, -0.726, '#scared', '#disgusting', -0.538, 'protect_from_sun', 'shade', 'meaning', 'concealer', 'sunglasses']
senticnet['correlation'] = [-0.819, 0, 0.931, -0.777, '#sad', '#angry', -0.842, 'mutualness', 'mutuality', 'complementarity', 'reciprocity', 'correlativity']
senticnet['correlativity'] = [-0.819, 0, 0.931, -0.777, '#sad', '#angry', -0.842, 'mutualness', 'mutuality', 'complementarity', 'correlation', 'reciprocity']
senticnet['correspond'] = [0.521, -0.511, 0, 0.814, '#joyful', '#admirable', 0.615, 'suit', 'befit', 'beseem', 'adhere', 'support']
senticnet['correspondence'] = [0, 0, 0, 0.12, '#admirable', '#admirable', 0.04, 'written_communication', 'written_message', 'handwritten', 'message', 'written_note']
senticnet['correspondent'] = [0.703, 0.913, 0, 0.701, '#joyful', '#interesting', 0.772, 'discovery', 'egalitarian', 'pioneer', 'adventurer', 'humankind']
senticnet['corridor'] = [0, 0, 0, 0.085, '#admirable', '#admirable', 0.028, 'use_farm', 'gate', 'door', 'doorway', 'entranceway']
senticnet['corrigible'] = [0.779, -0.882, 0, 0.521, '#joyful', '#surprising', 0.727, 'amendable', 'correctable', 'improvable', 'reformable', 'redeemable']
senticnet['corroborate'] = [0, 0, -0.908, -0.975, '#scared', '#disgusting', -0.628, 'affirm', 'support', 'confirm', 'sustain', 'substantiate']
senticnet['corrode'] = [-0.062, 0, -0.072, -0.035, '#sad', '#scared', -0.056, 'hold_two_together', 'deteriorate', 'burn_up', 'travel_through_space', 'float_through_air']
senticnet['corrosion'] = [-0.972, 0, 0.752, -0.834, '#sad', '#disgusting', -0.853, 'decay', 'wear', 'deterioration', 'devastation', 'dilapidation']
senticnet['corrupt'] = [-0.854, 0, 0.872, -0.946, '#angry', '#disgusting', -0.891, 'political_body', 'have_something', 'take_over', 'vote', 'status']
senticnet['corruptibility'] = [-0.693, 0, 0.89, -0.988, '#angry', '#disgusting', -0.857, 'evil', 'wrongness', 'putrefaction', 'wantonness', 'immorality']
senticnet['corrupting'] = [-0.798, 0, 0, -0.971, '#sad', '#disgusting', -0.59, 'seductive', 'pervert', 'debauch', 'deprave', 'warp']
senticnet['corruption'] = [-0.959, 0, -0.708, -0.966, '#sad', '#disgusting', -0.878, 'corrupt', 'bribe', 'bribe_police', 'illegal', 'persuade']
senticnet['corticoid'] = [-0.763, 0, 0.681, -0.578, '#sad', '#angry', -0.674, 'corticosteroid', 'spironolactone', 'adrenal_cortical_steroid', 'antihypertensive', 'antihypertensive_drug']
senticnet['corticosteroid'] = [-0.763, 0, 0.681, -0.578, '#sad', '#angry', -0.674, 'spironolactone', 'corticoid', 'adrenal_cortical_steroid', 'antihypertensive', 'antihypertensive_drug']
senticnet['coruscation'] = [-0.663, 0, 0.616, -0.708, '#sad', '#disgusting', -0.662, 'flicker', 'flash', 'streak', 'glint', 'gleam']
senticnet['coryza'] = [-0.606, 0, 0.931, -0.922, '#angry', '#disgusting', -0.82, 'rhinitis', 'allergic_rhinitis', 'hay_fever', 'pollinosis', 'hypersensitivity_reaction']
senticnet['cosmetic'] = [0, 0.83, 0, 0.879, '#interesting', '#admirable', 0.57, 'hair_accessory', 'hair_roller', 'hairdresser_chair', 'straighten_hair', 'sculpt_gel']
senticnet['cosmetician'] = [0.814, -0.582, 0, 0.646, '#joyful', '#admirable', 0.681, 'seller', 'marketer', 'vender', 'vendor', 'trafficker']
senticnet['cosmic_ray'] = [0, 0, -0.074, -0.169, '#scared', '#disgusting', -0.081, 'radio_wave', 'sun', 'solar_cell', 'x-ray', 'gamma_ray']
senticnet['cosmos'] = [-0.731, 0, 0.884, -0.601, '#sad', '#angry', -0.739, 'world', 'universe', 'existence', 'creation', 'natural_order']
senticnet['cost'] = [-0.028, 0.249, 0, 0.116, '#interesting', '#admirable', 0.112, 'price', 'expense', 'sort_mail', 'item_value', 'debit']
senticnet['cost_a_lot_of_money'] = [-0.135, 0, -0.108, 0, '#sad', '#scared', -0.081, 'enter_door', 'grunt', 'find_church', 'bicycle_store', 'hang_door']
senticnet['cost_fortune'] = [-0.19, -0.004, -0.092, -0.137, '#sad', '#disgusting', -0.138, 'loss', 'loose', 'lose_game', 'beaten', 'exhilarate']
senticnet['cost_little_money'] = [0.045, 0, 0.017, 0.052, '#joyful', '#admirable', 0.027, 'inexpensive', 'good_deal', 'cutlass', 'cheap', 'integer']
senticnet['cost_lot'] = [0, -0.73, 0, 0.903, '#surprising', '#admirable', 0.544, 'care_patient', 'make_drunk', 'burn_up', 'crispy', 'rude']
senticnet['cost_money'] = [0.753, 0.979, 0, 0, '#joyful', '#interesting', 0.577, 'first_class', 'shopping', 'travel_across_world', 'spending', 'run_out_fuel']
senticnet['cost_nothing'] = [0, 0.157, -0.075, 0.152, '#interesting', '#admirable', 0.078, 'inexpensive', 'unbearable', 'liberate', 'physical_reaction', 'three_syllables']
senticnet['costia'] = [0.807, -0.868, 0, 0.611, '#joyful', '#surprising', 0.762, 'flagellate', 'zoomastigote', 'zooflagellate', 'dinoflagellate', 'hypermastigote']
senticnet['costliness'] = [0.902, -0.726, 0, 0.919, '#joyful', '#admirable', 0.849, 'preciousness', 'expensiveness', 'dearness', 'cost', 'lavishness']
senticnet['costly'] = [-0.12, 0, 0, -0.063, '#sad', '#disgusting', -0.061, 'painful', 'uncomfortable', 'violent', 'fun_learn_play', 'expensive']
senticnet['costume'] = [-0.768, 0, 0.672, -0.887, '#sad', '#disgusting', -0.776, 'attire', 'garb', 'dress', 'fancy_dress', 'masquerade']
senticnet['coterie'] = [-0.935, 0, 0.586, -0.669, '#sad', '#disgusting', -0.73, 'camp', 'pack', 'clique', 'brain_trust', 'ingroup']
senticnet['cottage_cheese'] = [0.043, -0.055, 0, 0, '#joyful', '#surprising', 0.033, 'dairy_product', 'savory', 'cheese_platter', 'biscuit', 'appetizer']
senticnet['cotton'] = [-0.035, 0, 0, -0.045, '#sad', '#disgusting', -0.027, 'asbestos', 'silk', 'wool', 'asbestos_boll', 'velvet']
senticnet['cotton_ball'] = [0.606, -0.504, 0, 0.795, '#joyful', '#admirable', 0.635, 'plant_disease', 'pinkroot', 'disease', 'rust', 'scorch']
senticnet['cotton_boll'] = [0.731, 0, 0, 0.974, '#joyful', '#admirable', 0.568, 'cotton', 'silk', 'wool', 'fleece', 'plant']
senticnet['cotton_candy'] = [0.149, -0.061, 0.014, 0.064, '#joyful', '#admirable', 0.087, 'carnival_ride', 'carny', 'candy', 'fortune_teller', 'ice_cream']
senticnet['cotton_up'] = [0.985, -0.759, 0, 0.894, '#joyful', '#admirable', 0.879, 'cozy_up', 'ingratiate', 'shine_up', 'sidle_up', 'play_up']
senticnet['cotyloid_cavity'] = [0.681, -0.632, 0, 0.647, '#joyful', '#admirable', 0.653, 'hip_socket', 'tooth_socket', 'alveolus', 'acetabulum', 'socket']
senticnet['couch'] = [0.033, -0.039, 0, 0, '#joyful', '#surprising', 0.024, 'chair', 'bench', 'coach_seat', 'stool', 'seat']
senticnet['couch_potato'] = [0.868, 0.99, 0, 0, '#joyful', '#interesting', 0.619, 'entertainment_education', 'acculturation', 'cultural_experience', 'zone_out', 'get_news']
senticnet['cougar'] = [0, -0.977, 0, 0, '#surprising', '#surprising', 0.326, 'mountain_lion', 'skunk', 'lion', 'tiger', 'lynx']
senticnet['cough'] = [-0.076, 0, -0.145, -0.062, '#sad', '#scared', -0.094, 'inhale', 'eat_peanut', 'blow_smoke', 'call_911', 'close_mouth']
senticnet['cough_syrup'] = [0, 0, -0.133, -0.115, '#scared', '#disgusting', -0.083, 'opiate', 'sleep_drug', 'analgesic', 'ibuprofen', 'medicine']
senticnet['council'] = [0.051, 0.181, -0.101, 0.13, '#interesting', '#admirable', 0.087, 'committee', 'tribe', 'representative', 'association', 'caste']
senticnet['counsel'] = [0.901, 0, 0, 0.916, '#joyful', '#admirable', 0.606, 'get_away', 'bread', 'glory', 'absolution', 'vow']
senticnet['counseling'] = [0.503, -0.571, 0, 0.66, '#surprising', '#admirable', 0.578, 'guidance', 'counsel', 'confidential_information', 'counselor', 'direction']
senticnet['counselor'] = [0.503, -0.571, 0, 0.66, '#surprising', '#admirable', 0.578, 'guidance', 'counsel', 'counseling', 'confidential_information', 'direction']
senticnet['count'] = [0, 0.14, 0.07, 0.178, '#interesting', '#admirable', 0.083, 'tally', 'numerical', 'number', 'ordinal', 'equal']
senticnet['count_change'] = [0.725, 0.813, 0, 0, '#joyful', '#interesting', 0.513, 'gain_interest', 'carry_home', 'sign_agreement', 'make_offer', 'price_goods']
senticnet['count_damage'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'destroyed_home', 'destroyed_city', 'burned_thing', 'mess', 'after_fire']
senticnet['count_finger'] = [-0.889, 0, 0, -0.806, '#sad', '#disgusting', -0.565, 'promise_good', 'make_mistake', 'make_error', 'wear_silly_hat', 'face_music']
senticnet['count_item'] = [0, 0.834, 0, 0.715, '#interesting', '#admirable', 0.516, 'dimension', 'measure', 'gauge', 'length', 'measurement']
senticnet['count_money'] = [0.845, 0.912, 0, 0, '#joyful', '#interesting', 0.586, 'pay_cashier', 'go_town', 'live_simply', 'complete_job', 'enter_store']
senticnet['count_number'] = [-0.048, 0.146, 0.063, 0.126, '#interesting', '#admirable', 0.054, 'learn_add', 'add_number_together', 'learn_math', 'add_two_numbers_together', 'turn_calculator']
senticnet['count_person'] = [0.033, 0.122, 0.051, 0.158, '#interesting', '#admirable', 0.087, 'number_person', 'enumerate', 'small_group', 'twice', 'count']
senticnet['count_sheep'] = [0.169, 0.113, -0.047, 0.127, '#joyful', '#admirable', 0.121, 'inactivity', 'rest_night', 'shut_eye', 'sleep_well', 'good_night']
senticnet['countable'] = [0.983, -0.807, 0, 0.966, '#joyful', '#admirable', 0.919, 'estimable', 'computable', 'calculable', 'denumerable', 'enumerable']
senticnet['countenance'] = [0.719, -0.58, 0, 0.739, '#joyful', '#admirable', 0.679, 'poker_face', 'look', 'face', 'expression', 'aspect']
senticnet['counterbalance'] = [0.846, -0.534, 0, 0.919, '#joyful', '#admirable', 0.766, 'correct', 'compensate', 'overcompensate', 'make_up', 'even_out']
senticnet['counterbalanced'] = [0.814, -0.658, 0, 0.782, '#joyful', '#admirable', 0.751, 'harmonious', 'stable', 'symmetrical', 'balanced', 'proportionate']
senticnet['countercheck'] = [0.954, -0.681, 0, 0.997, '#joyful', '#admirable', 0.877, 'check', 'arrest', 'hitch', 'halt', 'stay']
senticnet['counterclaim'] = [0.804, -0.993, 0, 0.507, '#joyful', '#surprising', 0.768, 'antitrust_case', 'civil_action', 'action_at_law', 'custody_case', 'lis_pendens']
senticnet['counterpoint'] = [0.673, -0.598, 0, 0.594, '#joyful', '#surprising', 0.622, 'deviate', 'differ', 'depart', 'contrast', 'diverge']
senticnet['counterpoison'] = [-0.635, 0, 0.765, -0.93, '#angry', '#disgusting', -0.777, 'remedy', 'cure', 'therapeutic', 'curative', 'atropine']
senticnet['countersuit'] = [0.658, -0.749, 0, 0.782, '#surprising', '#admirable', 0.73, 'suit', 'cause', 'lawsuit', 'case', 'causa']
senticnet['counting'] = [-0.602, 0, 0.673, -0.915, '#angry', '#disgusting', -0.73, 'count', 'numeration', 'tally', 'miscount', 'enumeration']
senticnet['countless'] = [-0.615, 0, 0.784, -0.84, '#angry', '#disgusting', -0.746, 'indeterminable', 'infinite', 'myriad', 'immeasurable', 'incalculable']
senticnet['countlessness'] = [-0.852, 0, 0.605, -0.739, '#sad', '#disgusting', -0.732, 'fewness', 'numerousness', 'numerosity', 'innumerableness', 'number']
senticnet['country'] = [0.716, -0.51, 0, 0.647, '#joyful', '#admirable', 0.624, 'state', 'nation', 'ally', 'land', 'commonwealth']
senticnet['country_area'] = [0, 0.072, 0, 0.092, '#interesting', '#admirable', 0.055, 'country_live', 'big_land', 'cow_home', 'acreage', 'farm']
senticnet['country_band'] = [0, 0, -0.98, -0.994, '#scared', '#disgusting', -0.658, 'bluegrass_band', 'string_quartet', 'music_shop', 'live_band', 'high_school_band']
senticnet['country_doctor'] = [0.738, -0.537, 0, 0.856, '#joyful', '#admirable', 0.71, 'doctor', 'general_practitioner', 'family_doctor', 'doctor_office', 'physician']
senticnet['country_leader'] = [0.054, 0.17, 0, 0.144, '#interesting', '#admirable', 0.123, 'prime_minister', 'emperor', 'elect_official', 'royalty', 'royal_leader']
senticnet['country_live'] = [0, 0.072, 0, 0.092, '#interesting', '#admirable', 0.055, 'country_area', 'big_land', 'cow_home', 'acreage', 'large_land']
senticnet['country_person'] = [0.059, 0.071, 0.017, 0.084, '#interesting', '#admirable', 0.066, 'unity', 'political_state', 'political_unit', 'census', 'united_country']
senticnet['country_road'] = [0, 0.072, 0, 0.092, '#interesting', '#admirable', 0.055, 'street', 'wide_street', 'freeway', 'highway', 'road']
senticnet['country_side'] = [0.038, 0.079, 0.03, 0.083, '#interesting', '#admirable', 0.057, 'farm_animal', 'farm_house', 'large_area', 'rural_area', 'farm_area']
senticnet['countryside'] = [0.038, 0.079, 0.03, 0.083, '#interesting', '#admirable', 0.057, 'farm', 'farm_area', 'farm_animal', 'cow', 'fresh_milk']
senticnet['county'] = [0.089, 0, 0, 0.13, '#joyful', '#admirable', 0.073, 'metropolis', 'beautiful_place', 'good_view', 'complex_structure', 'populate_area']
senticnet['county_highway'] = [0.038, 0.079, 0.03, 0.083, '#interesting', '#admirable', 0.057, 'suspension_bridge', 'under_bridge', 'roadway', 'bridge', 'long_road']
senticnet['couple'] = [0.123, 0.072, -0.078, 0.152, '#joyful', '#admirable', 0.09, 'movie_star', 'two_people', 'man_and_woman', 'novelist', 'impression']
senticnet['coupon'] = [0.921, -0.571, 0, 0.962, '#joyful', '#admirable', 0.818, 'book_token', 'meal_ticket', 'luncheon_voucher', 'twofer', 'commercial_document']
senticnet['courage'] = [0, 0, 0, 0.766, '#admirable', '#admirable', 0.255, 'courageous', 'identify', 'tell_everyone', 'death_wish', 'make_plan']
senticnet['courageous'] = [0, 0, 0, 0.811, '#admirable', '#admirable', 0.27, 'file_complaint', 'raise_flag', 'kill_oneself', 'arm_oneself', 'hot_summer']
senticnet['courageousness'] = [0.788, 0, 0, 0.82, '#joyful', '#admirable', 0.536, 'nerve', 'fearlessness', 'heart', 'dauntlessness', 'intrepidity']
senticnet['courbaril'] = [-0.856, 0, 0.5, -0.709, '#sad', '#disgusting', -0.688, 'locust_tree', 'water_locust', 'swamp_locust', 'honey_locust', 'black_locust']
senticnet['courier'] = [0, 0.095, 0, 0.131, '#interesting', '#admirable', 0.075, 'ask_person', 'job', 'hire_help', 'settle', 'task']
senticnet['course'] = [-0.787, 0, 0.754, -0.961, '#sad', '#disgusting', -0.834, 'tramp', 'crisscross', 'cut_across', 'take', 'stride']
senticnet['course_of_study'] = [0.731, -0.97, 0, 0.957, '#surprising', '#admirable', 0.886, 'reading_program', 'program', 'programme', 'curriculum', 'syllabus']
senticnet['court'] = [0.028, 0.097, 0, 0.086, '#interesting', '#admirable', 0.07, 'gavel', 'trial', 'judge_jury', 'jury', 'arbiter']
senticnet['court_action'] = [0.025, 0.157, 0, 0.191, '#interesting', '#admirable', 0.124, 'legal_process', 'court_trial', 'legal_proceed', 'nominate', 'edict']
senticnet['court_favor'] = [-0.856, 0, 0.749, -0.998, '#sad', '#disgusting', -0.868, 'suck_up', 'toady', 'bootlick', 'kowtow', 'mafia']
senticnet['court_system'] = [-0.06, 0, -0.057, -0.055, '#sad', '#scared', -0.057, 'book', 'religious_book', 'organize_book', 'book_genre', 'book_poetry']
senticnet['court_trial'] = [0, 0.109, 0, 0.107, '#interesting', '#admirable', 0.072, 'gavel', 'judge_jury', 'trial', 'negotiator', 'juror']
senticnet['courteous'] = [0, -0.705, 0, 0.943, '#surprising', '#admirable', 0.549, 'politeness', 'courtesy', 'want_badly', 'good_behavior', 'demand']
senticnet['courtesy'] = [0, 0, 0, 0.817, '#admirable', '#admirable', 0.272, 'politeness', 'good_behavior', 'good_etiquette', 'want_badly', 'courteous']
senticnet['courthouse'] = [0.041, 0.086, 0.016, 0, '#joyful', '#interesting', 0.037, 'city_hall', 'whorehouse', 'town_hall', 'basketball_game', 'prison']
senticnet['courthouse_look_public_record'] = [-0.029, 0.075, 0, 0.059, '#interesting', '#admirable', 0.035, 'human_memory', 'transportation_device', 'new_caledonia', 'minor_planet', 'poo']
senticnet['courtly'] = [0.898, -0.562, 0, 0.513, '#joyful', '#surprising', 0.658, 'stately', 'imposing', 'dignified', 'distinguished', 'grand']
senticnet['courtroom'] = [0, 0.117, 0, 0.089, '#interesting', '#admirable', 0.069, 'court', 'gavel', 'trial', 'jury', 'arbiter']
senticnet['courtship'] = [0, 0, -0.756, -0.909, '#scared', '#disgusting', -0.555, 'reckon', 'yore', 'yesterday', 'year', 'time']
senticnet['cousin'] = [0, 0.758, 0, 0.98, '#interesting', '#admirable', 0.579, 'foster_kid', 'daughter', 'relation', 'sister', 'adopt']
senticnet['coven'] = [0, 0, -0.077, -0.057, '#scared', '#disgusting', -0.045, 'death_row', 'another_planet', 'loose_end', 'car_race', 'mortuary']
senticnet['covenant'] = [0, 0.184, -0.065, 0.22, '#interesting', '#admirable', 0.113, 'carry_vessel', 'direct_person', 'ship_container', 'water_vehicle', 'big_boat']
senticnet['cover'] = [0.024, 0, 0, 0.074, '#joyful', '#admirable', 0.033, 'sheet', 'bedsheet', 'quilt', 'comforter', 'modesty']
senticnet['cover_bed'] = [0.069, 0, 0, 0, '#joyful', '#joyful', 0.023, 'keep_warm_night', 'sleep_under', 'keep_warm_bed', 'sleep', 'use_bed']
senticnet['cover_body'] = [0.069, 0, 0, 0, '#joyful', '#joyful', 0.023, 'knit_sweater', 'make_drape', 'weave', 'weave_cloth', 'wear_jacket']
senticnet['cover_face'] = [-0.148, 0.094, -0.132, 0, '#sad', '#scared', -0.062, 'fallacy', 'lie', 'falsehood', 'dishonesty', 'pillow']
senticnet['cover_floor'] = [0.069, 0, 0, 0, '#joyful', '#joyful', 0.023, 'floor_cover', 'carpet', 'floor', 'mat', 'underfoot']
senticnet['cover_fur'] = [-0.078, -0.04, 0.02, -0.132, '#sad', '#disgusting', -0.063, 'cut', 'cover_wound', 'gore', 'cover_wind', 'sting']
senticnet['cover_furniture'] = [0, 0.184, -0.065, 0.22, '#interesting', '#admirable', 0.113, 'sleep_under', 'bed_cover', 'pyjamas', 'keep_warm_night', 'cover']
senticnet['cover_ground'] = [-0.127, -0.021, 0.058, 0, '#sad', '#angry', -0.055, 'build_ground', 'underfoot', 'horizontal_plane', 'wood_board', 'hardwood']
senticnet['cover_hair'] = [0.179, 0.164, -0.052, 0.163, '#joyful', '#interesting', 0.151, 'shower_cap', 'hat', 'cap', 'head_wear', 'scarf']
senticnet['cover_head'] = [0, -0.777, 0, 0.896, '#surprising', '#admirable', 0.558, 'protect_head', 'helmet', 'keep_hair_place', 'safety_cap', 'shade_eye']
senticnet['cover_ice'] = [0.082, -0.021, 0.015, 0.118, '#joyful', '#admirable', 0.069, 'round_pastry', 'bake_good', 'bake_treat', 'bakery_item', 'bake_goods']
senticnet['cover_leg'] = [0.742, 0, 0, 0.905, '#joyful', '#admirable', 0.549, 'stockings', 'intimate', 'robe', 'make_fashion_statement', 'leg']
senticnet['cover_oneself_with_blanket'] = [0.808, 0, 0, 0, '#joyful', '#joyful', 0.269, 'fall_asleep', 'relax_mind', 'snuggle', 'make_out', 'bed_time']
senticnet['cover_pillow'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'find_motel', 'find_bedroom', 'find_car', 'find_hospice', 'save_space']
senticnet['cover_sand'] = [0.047, 0.11, 0, 0, '#joyful', '#interesting', 0.052, 'near_sea', 'sandy', 'sand_rock', 'near_beach', 'beach']
senticnet['cover_snow'] = [0.037, 0.074, 0.028, 0.103, '#interesting', '#admirable', 0.062, 'high_land', 'steep', 'landscape_feature', 'incline', 'knoll']
senticnet['cover_stone'] = [-0.074, 0, 0, -0.054, '#sad', '#disgusting', -0.043, 'small_light', 'find_garden', 'walk', 'cover_floor', 'meander']
senticnet['cover_table'] = [0.024, 0, 0.017, 0.151, '#joyful', '#admirable', 0.053, 'make_pretty', 'pretty', 'make_up', 'remove_paint', 'paint_nail']
senticnet['cover_up'] = [-0.767, 0, 0, 0, '#sad', '#sad', -0.256, 'dissimulation', 'hide_mistake', 'camouflage', 'deception', 'error']
senticnet['cover_wall'] = [0, 0, 0, 0.1, '#admirable', '#admirable', 0.033, 'wall_cover', 'latex', 'two-dimensional', 'decorator', 'home_improvement']
senticnet['cover_water'] = [0, 0.787, 0, 0.837, '#interesting', '#admirable', 0.541, 'water', 'make_up_water', 'large_body', 'water_spill', 'adenozine']
senticnet['cover_wind'] = [-0.072, -0.025, 0.036, -0.137, '#sad', '#disgusting', -0.073, 'cover_wound', 'cut', 'heal_wind', 'seam', 'open_wind']
senticnet['cover_window'] = [-0.088, -0.046, 0.047, -0.037, '#sad', '#angry', -0.042, 'block_light', 'block_sunlight', 'window_cover', 'sunglasses', 'window_treatment']
senticnet['cover_wound'] = [-0.063, -0.049, 0.049, -0.147, '#sad', '#disgusting', -0.07, 'cut', 'cover_wind', 'heal_wind', 'welt', 'open_wind']
senticnet['coverall'] = [-0.675, 0, 0.688, -0.899, '#angry', '#disgusting', -0.754, 'protective_garment', 'boilersuit', 'boilers_suit', 'overall', 'duster']
senticnet['covered_smut'] = [-0.935, 0, 0.699, -0.91, '#sad', '#disgusting', -0.848, 'onion_smut', 'head_smut', 'stinking_smut', 'flag_smut_fungus', 'smut_fungus']
senticnet['covert'] = [-0.898, 0, 0.627, -0.547, '#sad', '#angry', -0.691, 'shielded', 'weatherproof', 'protected', 'stormproof', 'fortified']
senticnet['covertness'] = [0.779, -0.756, 0, 0.526, '#joyful', '#surprising', 0.687, 'hiddenness', 'privateness', 'bosom', 'isolation', 'confidentiality']
senticnet['covet'] = [0.098, 0.084, 0.819, -0.682, '#angry', '#disgusting', -0.44, 'grasp', 'covetousness', 'avaricious', 'prehensile', 'grabby']
senticnet['covetous'] = [0.09, 0.089, 0.812, -0.682, '#angry', '#disgusting', -0.438, 'jealously', 'enviously', 'envious', 'covetously', 'green-eyed']
senticnet['covetously'] = [0.087, 0.091, 0.809, -0.681, '#angry', '#disgusting', -0.437, 'envious', 'enviously', 'jealously', 'covetous', 'overjealous']
senticnet['covetousness'] = [0.098, 0.084, 0.819, -0.682, '#angry', '#disgusting', -0.44, 'grasp', 'covet', 'avaricious', 'prehensile', 'grabby']
senticnet['cow'] = [0.053, 0.094, 0, 0.136, '#interesting', '#admirable', 0.094, 'farm', 'domesticate', 'stand_field', 'sheep', 'barn_animal']
senticnet['cow_chip'] = [-0.838, 0, 0.521, -0.713, '#sad', '#disgusting', -0.691, 'stool', 'dejection', 'chip', 'droppings', 'cow_dung']
senticnet['cow_dung'] = [-0.838, 0, 0.521, -0.713, '#sad', '#disgusting', -0.691, 'stool', 'dejection', 'chip', 'cow_chip', 'droppings']
senticnet['cow_food'] = [0, 0.141, 0, 0.096, '#interesting', '#admirable', 0.079, 'leafy_green', 'usual_green', 'green_stuff', 'greenery', 'vegetation']
senticnet['cow_home'] = [0.024, 0, 0.017, 0.151, '#joyful', '#admirable', 0.053, 'acreage', 'acre', 'big_land', 'crop_place', 'large_land']
senticnet['cow_shark'] = [-0.54, 0, 0.983, -0.911, '#angry', '#disgusting', -0.811, 'elasmobranch', 'selachian', 'hammerhead', 'shark', 'mackerel_shark']
senticnet['cow_skin'] = [-0.039, 0.074, 0, 0.146, '#interesting', '#admirable', 0.06, 'fabric_type', 'clothes_fabric', 'texture', 'cloth_fabric', 'soft_fabric']
senticnet['coward'] = [-0.956, 0, 0.825, -0.806, '#sad', '#angry', -0.862, 'cur', 'dastard', 'craven', 'recreant', 'mortal']
senticnet['cowardice'] = [0, 0, 0.881, -0.754, '#angry', '#disgusting', -0.545, 'meme', 'immortality', 'glory', 'exclusion', 'live_peace']
senticnet['cowardly'] = [-0.152, 0, 0.079, -0.166, '#sad', '#disgusting', -0.132, 'please_mother', 'venomous', 'household_animal', 'immoral', 'home_animal']
senticnet['cowboy_boot'] = [0.059, -0.024, 0.123, -0.064, '#angry', '#disgusting', -0.035, 'casual_shoes', 'shoe', 'moccasin', 'slipper', 'loafer']
senticnet['cower'] = [-0.999, 0, -0.971, 0, '#sad', '#scared', -0.657, 'creeps', 'cringe', 'grovel', 'creep', 'hysterically']
senticnet['cowhide'] = [0.028, 0.066, 0, 0, '#joyful', '#interesting', 0.031, 'handkerchief', 'kerchief', 'hanky', 'facial_tissue', 'zipper']
senticnet['coworker'] = [0.035, 0.076, 0, 0.067, '#interesting', '#admirable', 0.059, 'postal_counter', 'paperwork', 'clutter', 'white-out', 'stapler']
senticnet['coy'] = [-0.61, 0, 0.856, -0.826, '#angry', '#disgusting', -0.764, 'unfixed', 'one', 'nebulous', 'indecisive', 'indefinite']
senticnet['coyness'] = [-0.562, 0, 0.757, -0.991, '#angry', '#disgusting', -0.77, 'unnaturalness', 'airs', 'pose', 'affectedness', 'demureness']
senticnet['cozen'] = [-0.668, 0, 0.789, -0.631, '#sad', '#angry', -0.696, 'humbug', 'play_trick', 'fob', 'pull_fast_one_on', 'play_trick_on']
senticnet['cozy'] = [0.203, 0.14, -0.053, 0.093, '#joyful', '#interesting', 0.128, 'good_night', 'inactivity', 'shut_eye', 'restful', 'sleep_furniture']
senticnet['cozy_up'] = [0.985, -0.759, 0, 0.894, '#joyful', '#admirable', 0.879, 'ingratiate', 'cotton_up', 'shine_up', 'sidle_up', 'play_up']
senticnet['cpu'] = [0, 0.102, 0.016, 0.076, '#interesting', '#admirable', 0.054, 'computer_part', 'system', 'motherboard', 'pencil_pen', 'monitor']
senticnet['crab'] = [-0.698, 0, 0.766, -0.826, '#angry', '#disgusting', -0.763, 'stone_crab', 'swimming_crab', 'rock_crab', 'fiddler_crab', 'pea_crab']
senticnet['crabbedness'] = [-0.959, 0, 0.694, -0.949, '#sad', '#disgusting', -0.867, 'sullenness', 'moroseness', 'crabbiness', 'ill_nature', 'crankiness']
senticnet['crabbiness'] = [-0.959, 0, 0.694, -0.949, '#sad', '#disgusting', -0.867, 'sullenness', 'moroseness', 'ill_nature', 'crabbedness', 'crankiness']
senticnet['crabby_person'] = [-0.834, 0, 0.614, -0.769, '#sad', '#disgusting', -0.739, 'grouch', 'grump', 'crosspatch', 'churl', 'crank']
senticnet['crabs'] = [-0.841, 0, 0.767, -0.996, '#sad', '#disgusting', -0.868, 'pediculosis_capitis', 'head_lice', 'pediculosis_corporis', 'pediculosis_pubis', 'lousiness']
senticnet['crack'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'break_apart', 'cracked_screen', 'cracked_phone', 'break', 'break_glass']
senticnet['crack_down'] = [-0.716, 0, 0.981, -0.683, '#sad', '#angry', -0.793, 'trammel', 'limit', 'restrict', 'bound', 'confine']
senticnet['crack_house'] = [-0.767, 0, 0, 0, '#sad', '#sad', -0.256, 'broken', 'home', 'homeless_shelter', 'slum', 'poor']
senticnet['crack_shot'] = [0.801, -0.874, 0, 0.916, '#surprising', '#admirable', 0.864, 'rifleman', 'deadeye', 'sniper', 'shot', 'shooter']
senticnet['crack_up'] = [-0.943, 0, 0.095, -0.952, '#sad', '#disgusting', -0.663, 'knock', 'break', 'knock_into', 'break_it', 'kick']
senticnet['cracked_car'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'crack', 'cracked_screen', 'cracked_phone', 'break', 'breakdown']
senticnet['cracked_phone'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'crack', 'cracked_screen', 'cracked_car', 'break', 'breakdown']
senticnet['cracked_screen'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'crack', 'cracked_phone', 'cracked_car', 'break', 'breakdown']
senticnet['cracker'] = [-0.955, 0, 0.762, -0.648, '#sad', '#angry', -0.788, 'saltine', 'soda_cracker', 'oyster_cracker', 'water_biscuit', 'graham_cracker']
senticnet['crackerberry'] = [0.773, -0.55, 0, 0.949, '#joyful', '#admirable', 0.757, 'bunchberry', 'dwarf_cornel', 'cornel', 'pudding_berry', 'common_white_dogwood']
senticnet['crackerjack'] = [0.59, -0.906, 0, 0.54, '#joyful', '#surprising', 0.679, 'nonesuch', 'nonsuch', 'ideal', 'nonpareil', 'apotheosis']
senticnet['cradle'] = [0, -0.028, -0.083, -0.059, '#scared', '#disgusting', -0.038, 'mattress', 'sleep_furniture', 'master_bedroom', 'small_bed', 'pillow']
senticnet['craft'] = [0.08, 0, 0, 0.106, '#joyful', '#admirable', 0.062, 'design', 'wall_hang', 'artwork', 'like_paint', 'painting']
senticnet['craftiness'] = [0.784, -0.595, 0, 0.846, '#joyful', '#admirable', 0.742, 'foxiness', 'slyness', 'wiliness', 'astuteness', 'cunning']
senticnet['craftsman'] = [0.633, -0.502, 0, 0.59, '#joyful', '#admirable', 0.575, 'beautician', 'manicurist', 'artisan', 'journeyman', 'artificer']
senticnet['craftsmanship'] = [0.921, -0.615, 0, 0.91, '#joyful', '#admirable', 0.815, 'housecraft', 'tradecraft', 'watercraft', 'acquirement', 'skill']
senticnet['crafty'] = [0, -0.811, 0, 0.796, '#surprising', '#admirable', 0.536, 'cunning', 'dodgy', 'guileful', 'knavish', 'tricksy']
senticnet['cramp'] = [-0.079, -0.075, 0.03, -0.099, '#sad', '#disgusting', -0.044, 'become_exhausted', 'breathlessness', 'become_wind', 'pull_muscle', 'muscle_cramp']
senticnet['cramped'] = [-0.956, 0, 0.159, -0.941, '#sad', '#disgusting', -0.685, 'narrow_road', 'poky', 'tight', 'clenched', 'narrow']
senticnet['cranberry'] = [0, 0.102, 0.016, 0.076, '#interesting', '#admirable', 0.054, 'cherry', 'tomato', 'plum', 'apricot', 'pineapple']
senticnet['craniologist'] = [0.969, -0.885, 0, 0.736, '#joyful', '#surprising', 0.863, 'slicker', 'beguiler', 'quack', 'phrenologist', 'charlatan']
senticnet['cranium'] = [0, 0.971, 0, 0.819, '#interesting', '#admirable', 0.597, 'hold_brain', 'inside_head', 'brain', 'skull', 'mind']
senticnet['crank'] = [-0.058, -0.01, -0.053, -0.069, '#sad', '#disgusting', -0.057, 'dynamo', 'air_vent', 'emergency_brake', 'brake_pedal', 'grunt']
senticnet['crankiness'] = [-0.959, 0, 0.694, -0.949, '#sad', '#disgusting', -0.867, 'sullenness', 'moroseness', 'crabbiness', 'crabbedness', 'ill_nature']
senticnet['cranky'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'bad_tempered', 'nervous', 'neurasthenic', 'irritable', 'testy']
senticnet['cranny'] = [0.788, -0.605, 0, 0.884, '#joyful', '#admirable', 0.759, 'gap', 'rathole', 'aperture', 'bullet_hole', 'hole']
senticnet['crap'] = [0, 0, 0, -0.881, '#disgusting', '#disgusting', -0.294, 'hunt_fox', 'software_company', 'waste', 'last_forever', 'useless']
senticnet['crash'] = [-0.085, -0.036, 0, -0.145, '#sad', '#disgusting', -0.065, 'accident', 'stop_red_light', 'get_accident', 'break_down', 'automobile_accident']
senticnet['crash_car'] = [-0.832, 0, -0.703, 0, '#sad', '#scared', -0.512, 'accident', 'fall_ground', 'loss_ofawareness', 'broken_limb', 'hit_car']
senticnet['crash_cymbal'] = [-0.046, -0.017, 0, -0.054, '#sad', '#disgusting', -0.028, 'break', 'break_instrument', 'broken_guitar', 'trumpet', 'antler']
senticnet['crash_tree'] = [0, 0, -0.744, 0, '#scared', '#scared', -0.248, 'fall_butt', 'accident', 'hit_tree', 'fall_over', 'take_photo']
senticnet['crate'] = [0, 0.088, 0.022, 0.099, '#interesting', '#admirable', 0.055, 'storage_place', 'storage', 'sack', 'carrier', 'stick_wall']
senticnet['crave'] = [0, 0.895, 0, 0.721, '#interesting', '#admirable', 0.539, 'hunger', 'hungry', 'survive', 'stay_alive', 'like_taste']
senticnet['craven'] = [-0.033, 0, -0.088, 0, '#sad', '#scared', -0.04, 'lion', 'leopard', 'mountain_lion', 'bobcat', 'wolf']
senticnet['craving'] = [-0.872, 0, 0.919, -0.899, '#angry', '#disgusting', -0.897, 'appetite', 'appetency', 'appetence', 'addiction', 'desire']
senticnet['crawl'] = [-0.91, 0, 0.926, 0, '#sad', '#angry', -0.612, 'dash', 'uneasiness', 'fright', 'disquiet', 'upset']
senticnet['crawler'] = [-0.558, 0, 0.588, -0.65, '#angry', '#disgusting', -0.599, 'apple_polisher', 'bootlicker', 'fawner', 'web', 'groveler']
senticnet['crayon'] = [0.031, 0.103, 0, 0.06, '#interesting', '#admirable', 0.065, 'graphical_representation', 'photo', 'artwork', 'photograph', 'varnish']
senticnet['craze'] = [-0.875, 0, 0.599, -0.717, '#sad', '#disgusting', -0.73, 'hysteria', 'fury', 'delirium', 'frenzy', 'nympholepsy']
senticnet['craziness'] = [-0.727, 0, 0, -0.785, '#sad', '#disgusting', -0.504, 'folly', 'lunacy', 'buffoonery', 'shtik', 'insanity']
senticnet['crazy'] = [-0.159, 0, -0.122, -0.096, '#sad', '#scared', -0.126, 'feel_ashamed', 'hunt_animal', 'play_dead', 'feel_confident', 'vicious']
senticnet['crazy_house'] = [-0.559, 0, 0.517, -0.834, '#sad', '#disgusting', -0.637, 'asylum', 'mental_hospital', 'psychiatric_hospital', 'mental_institution', 'mental_home']
senticnet['crazy_mind'] = [-0.955, 0, 0.902, -0.917, '#sad', '#disgusting', -0.925, 'sadness', 'mental_disease', 'mental_problem', 'depression', 'disease']
senticnet['crazy_moment'] = [0.979, -0.941, 0, 0, '#joyful', '#surprising', 0.64, 'funny_moment', 'dance_in_rain', 'sing_in_rain', 'playful', 'dance']
senticnet['crazy_person'] = [-0.045, -0.037, 0, -0.167, '#sad', '#disgusting', -0.058, 'crazy', 'damage_body', 'marathon_runner', 'threat', 'max']
senticnet['cream'] = [0.028, 0.138, -0.048, 0.215, '#interesting', '#admirable', 0.111, 'water', 'dense', 'thick', 'milk', 'dense_water']
senticnet['cream_cheese'] = [0.737, 0, 0, 0, '#joyful', '#joyful', 0.246, 'cheese', 'stick_butter', 'butter', 'leftover', 'lasagna']
senticnet['cream_soup'] = [0.974, 0.844, 0, 0, '#joyful', '#interesting', 0.606, 'main_course', 'stew', 'soup', 'ragout', 'goulash']
senticnet['creamy'] = [0.092, 0, 0.028, 0.134, '#joyful', '#admirable', 0.066, 'yummy', 'delicious', 'bake_product', 'eatable', 'bake_good']
senticnet['crease'] = [-0.137, 0, -0.117, -0.045, '#sad', '#scared', -0.1, 'concern_health', 'medical_problem', 'strengthful', 'surgery', 'injury']
senticnet['create'] = [0, 0.168, 0, 0.157, '#interesting', '#admirable', 0.108, 'creation', 'create_form', 'artistic', 'make', 'draw_blueprint']
senticnet['create_art'] = [0.936, 0.749, 0, 0.871, '#joyful', '#admirable', 0.852, 'paint_picture', 'tie-dye', 'paint_house', 'make_patchwork_quilt', 'letter_sign']
senticnet['create_by_mental_act'] = [0.624, -0.811, 0, 0.773, '#surprising', '#admirable', 0.736, 'find', 'design', 'preconceive', 'discover', 'conceive']
senticnet['create_comfortable_environment'] = [0.115, 0.11, 0, 0.111, '#joyful', '#admirable', 0.112, 'neatness', 'neat', 'get_rid_of_dirt', 'hygiene', 'sanitary']
senticnet['create_destroy'] = [0, -0.718, 0, 0.921, '#surprising', '#admirable', 0.546, 'power_source', 'potential', 'hyper', 'like_electricity', 'power']
senticnet['create_document'] = [0, -0.903, 0, 0.991, '#surprising', '#admirable', 0.631, 'type_of_document', 'write_text', 'enter_data', 'type', 'send_email']
senticnet['create_fire'] = [0.025, 0, -0.07, -0.062, '#scared', '#disgusting', -0.036, 'light_cigarette', 'create_flame', 'burn_finger', 'burn_forest', 'start_fire']
senticnet['create_flame'] = [0, 0, 0.897, -0.835, '#angry', '#disgusting', -0.577, 'create_fire', 'burn_down_house', 'excessive_heat', 'burn_oneself', 'huge_fire']
senticnet['create_food'] = [0.119, 0, 0, 0, '#joyful', '#joyful', 0.04, 'make_sandwich', 'stuff_face', 'make_toast', 'snack', 'fill_stomach']
senticnet['create_form'] = [-0.025, 0.233, -0.076, 0.284, '#interesting', '#admirable', 0.139, 'make', 'creation', 'creationism', 'fabricate', 'publicity']
senticnet['create_help_other_person'] = [0, 0.771, 0, 0.924, '#interesting', '#admirable', 0.565, 'give_assistance', 'make_better_world', 'please_parent', 'see_idea_become_reality', 'forgive']
senticnet['create_image'] = [0, 0.086, 0, 0.096, '#interesting', '#admirable', 0.061, 'pencil_art', 'like_paint', 'use_crayon', 'artwork', 'sketch']
senticnet['create_light'] = [0.937, 0, 0, 0.828, '#joyful', '#admirable', 0.588, 'switch_on_light', 'light_candle', 'light_match', 'turn_on_torch', 'create_flame']
senticnet['create_meal'] = [0.937, 0, 0, 0.828, '#joyful', '#admirable', 0.588, 'prepare_dinner', 'measure_ingredient', 'prepare_soup', 'prepare_table', 'make_toast']
senticnet['create_mood'] = [0.924, 0.968, 0, 0.876, '#joyful', '#interesting', 0.923, 'listen', 'like_music', 'perform_on_stage', 'entertain_other_person', 'sing_song']
senticnet['create_music'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'make_music', 'play_music', 'produce_musical_sound', 'play_orchestra', 'play_tune']
senticnet['create_new'] = [0.723, 0.816, 0, 0.922, '#interesting', '#admirable', 0.82, 'make_drape', 'weave_cloth', 'knit_sweater', 'cover_body', 'make_suit']
senticnet['create_new_idea'] = [0.723, 0.816, 0, 0.922, '#interesting', '#admirable', 0.82, 'paint_canvas', 'letter_sign', 'create_music', 'make_paint', 'create']
senticnet['create_new_life'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'procreation', 'personal_fulfillment', 'make_baby', 'make_beautiful', 'pleasure']
senticnet['create_order'] = [0, 0.737, 0, 0.756, '#interesting', '#admirable', 0.498, 'get_turn', 'line_up', 'pick_team', 'put_order', 'declutter']
senticnet['create_picture'] = [0, 0.07, 0.041, 0.058, '#interesting', '#admirable', 0.029, 'highlight', 'write_word', 'carpal_tunnel_syndrome', 'show_picture', 'draw_diagram']
senticnet['create_pollution'] = [0.087, 0.091, 0.809, -0.681, '#angry', '#disgusting', -0.437, 'make_pollution', 'get_around_town', 'show_off_wealth', 'drive_car', 'travel_to_another_place']
senticnet['create_product'] = [0.866, 0.983, 0, 0, '#joyful', '#interesting', 0.616, 'industry', 'assembly_line', 'factory', 'manufacturer', 'corporation']
senticnet['create_program'] = [-0.058, -0.037, 0.072, -0.067, '#angry', '#disgusting', -0.053, 'dig_ground', 'work_hard', 'work', 'program', 'hard_work']
senticnet['create_questions'] = [0, 0.069, 0, 0.108, '#interesting', '#admirable', 0.059, 'succeed_school', 'succeed_carrier', 'create_thought', 'creative_mind', 'creative_soul']
senticnet['create_smoke'] = [0, 0, -0.062, -0.069, '#scared', '#disgusting', -0.044, 'get_burnt', 'burn_finger', 'create_flame', 'burn_oneself', 'create_light']
senticnet['create_sound'] = [0, 0.769, 0, 0, '#interesting', '#interesting', 0.256, 'good_music', 'listen', 'demo', 'music', 'create_new_idea']
senticnet['create_thought'] = [0, 0.069, 0, 0.108, '#interesting', '#admirable', 0.059, 'succeed_school', 'succeed_carrier', 'creative_mind', 'create_questions', 'creative_soul']
senticnet['create_thoughts'] = [0.624, -0.811, 0, 0.773, '#surprising', '#admirable', 0.736, 'succeed_school', 'succeed_carrier', 'creative_mind', 'create_questions', 'creative_soul']
senticnet['create_warmth'] = [0.296, 0.278, -0.145, 0.128, '#joyful', '#interesting', 0.186, 'warm', 'keep_warm', 'body_heat', 'warmth', 'heat_house']
senticnet['creating_by_mental_acts'] = [0.878, -0.587, 0, 0.624, '#joyful', '#admirable', 0.696, 'framing', 'approach', 'attack', 'plan_of_attack', 'conceptualization']
senticnet['creation'] = [0, 0.195, -0.073, 0.231, '#interesting', '#admirable', 0.118, 'factory_output', 'make', 'create_form', 'make_stuff', 'fabricate']
senticnet['creationism'] = [0, 0.148, -0.051, 0.174, '#interesting', '#admirable', 0.09, 'create_form', 'publicity', 'clothes_style', 'creation', 'floral']
senticnet['creationist'] = [0, 0.177, -0.086, 0.164, '#interesting', '#admirable', 0.085, 'fundamentalist', 'fascism', 'church_person', 'worshiper', 'believer']
senticnet['creative'] = [0.056, 0.099, 0.036, 0, '#joyful', '#interesting', 0.04, 'hobby', 'creativity', 'creative_expression', 'creative_soul', 'artistic']
senticnet['creative_activity'] = [0.03, 0.101, 0, 0.193, '#interesting', '#admirable', 0.108, 'form_of_art', 'art_creation', 'communication_method', 'media', 'art_form']
senticnet['creative_expression'] = [0.103, -0.064, 0.061, -0.038, '#joyful', '#surprising', 0.023, 'artistic_expression', 'creativity', 'self_expression', 'creative_soul', 'make_beautiful']
senticnet['creative_mind'] = [0, 0.069, 0, 0.108, '#interesting', '#admirable', 0.059, 'succeed_school', 'succeed_carrier', 'create_thoughts', 'create_questions', 'creative_soul']
senticnet['creative_person'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'artist', 'oil_paint', 'painter', 'paint_brush', 'make_paint']
senticnet['creative_soul'] = [0.056, 0.099, 0.036, 0, '#joyful', '#interesting', 0.04, 'hobby', 'creativity', 'creative_expression', 'creative', 'artistic']
senticnet['creative_thinking'] = [0.703, -0.593, 0, 0.739, '#joyful', '#admirable', 0.678, 'fruitfulness', 'genius', 'fecundity', 'ability', 'wizardry']
senticnet['creative_work'] = [0, 0.898, 0, 0, '#interesting', '#interesting', 0.299, 'opus_house', 'concert_hall', 'opus', 'studio', 'tv_studio']
senticnet['creativeness'] = [0.794, -0.612, 0, 0.675, '#joyful', '#admirable', 0.694, 'fruitfulness', 'genius', 'fecundity', 'ability', 'wizardry']
senticnet['creativity'] = [0, 0.19, 0, 0.101, '#interesting', '#admirable', 0.097, 'honor_person', 'new_think', 'idea', 'eureka', 'come_up_idea']
senticnet['creator'] = [0, 0, 0, 0.851, '#admirable', '#admirable', 0.284, 'almighty', 'maker', 'deity', 'supreme', 'lord']
senticnet['creature'] = [-0.78, 0, 0.577, -0.869, '#sad', '#disgusting', -0.742, 'stunt', 'game', 'mutant', 'invertebrate', 'varmint']
senticnet['creatures'] = [0, -0.958, 0, 0.849, '#surprising', '#admirable', 0.602, 'animal', 'grizzly_bear', 'forest', 'brown_bear', 'polar_bear']
senticnet['credential'] = [0.931, -0.526, 0, 0.67, '#joyful', '#admirable', 0.709, 'document', 'certificate_of_incorporation', 'birth_certificate', 'diploma', 'sheepskin']
senticnet['credentials'] = [0.531, -0.562, 0, 0.573, '#surprising', '#admirable', 0.555, 'document', 'certificate_of_incorporation', 'birth_certificate', 'diploma', 'sheepskin']
senticnet['credibility'] = [0.726, -0.824, 0, 0.966, '#surprising', '#admirable', 0.839, 'real_thing', 'real_stuff', 'authenticity', 'credibleness', 'believability']
senticnet['credibleness'] = [0.726, -0.824, 0, 0.966, '#surprising', '#admirable', 0.839, 'real_thing', 'real_stuff', 'credibility', 'authenticity', 'believability']
senticnet['credit'] = [0, 0.148, -0.106, 0.143, '#interesting', '#admirable', 0.062, 'credit_card', 'check', 'wealth', 'identification', 'loan']
senticnet['credit_card'] = [-0.028, 0.119, 0, 0.054, '#interesting', '#admirable', 0.048, 'credit_card_company', 'debit_card', 'check', 'visa_card', 'cash_coin']
senticnet['credit_card_bill'] = [0, 0.87, 0, 0.969, '#interesting', '#admirable', 0.613, 'gain_interest', 'sign_agreement', 'price_goods', 'carry_home', 'charge_credit_card']
senticnet['credit_card_company'] = [-0.028, 0.119, 0, 0.054, '#interesting', '#admirable', 0.048, 'credit_card', 'debit_card', 'check', 'visa_card', 'cash_coin']
senticnet['credit_card_wallet'] = [0, 0.149, 0, 0, '#interesting', '#interesting', 0.05, 'wallet', 'checkbook_holder', 'credit_card', 'bank_vault', 'billfold']
senticnet['credit_check'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'bill', 'file_bill', 'get_salary', 'get_paid', 'bank']
senticnet['credit_limit'] = [-0.938, 0, 0.832, -0.934, '#sad', '#disgusting', -0.901, 'limit', 'mortgage', 'buy', 'spend_money', 'shop']
senticnet['creek'] = [0.728, 0.713, 0, 0.715, '#joyful', '#admirable', 0.719, 'brook', 'stream', 'river', 'well', 'pond']
senticnet['creep'] = [-0.981, 0, 0, -0.962, '#sad', '#disgusting', -0.648, 'creeps', 'cringe', 'grovel', 'cower', 'hysterically']
senticnet['creeper'] = [0, 0, -0.148, -0.036, '#scared', '#disgusting', -0.061, 'pine_cone', 'fallen_leaf', 'poison_ivy', 'detritus', 'tress']
senticnet['creepiness'] = [-0.943, 0, 0.827, -0.553, '#sad', '#angry', -0.774, 'cutaneous_sensation', 'haptic_sensation', 'skin_sensation', 'perception', 'tactual_sensation']
senticnet['creeps'] = [-0.773, 0, 0, -0.991, '#sad', '#disgusting', -0.588, 'cringe', 'grovel', 'creep', 'cower', 'hysterically']
senticnet['creepy'] = [0.052, 0, 0, 0.131, '#joyful', '#admirable', 0.061, 'run_treadmill', 'dangerous_drive', 'helpful_tool', 'profitable', 'conscious']
senticnet['cremate'] = [0, 0, 0, -0.787, '#disgusting', '#disgusting', -0.262, 'find_farm', 'find_bank', 'find_subway_stop', 'even_odds', 'warm_hand']
senticnet['crescent'] = [0.09, 0, 0, 0.094, '#joyful', '#admirable', 0.061, 'heavenly_body', 'celestial_body', 'around_earth', 'celestial_object', 'bright_yellow']
senticnet['cress'] = [0.598, -0.721, 0, 0.941, '#surprising', '#admirable', 0.753, 'sicklepod', 'tower_rock_cress', 'tower_mustard', 'rock_cress', 'rock_cress_plant']
senticnet['cress_plant'] = [0.598, -0.721, 0, 0.941, '#surprising', '#admirable', 0.753, 'sicklepod', 'tower_cress', 'tower_mustard', 'cress', 'rock_cress']
senticnet['crest'] = [0.03, 0, 0.017, 0.138, '#joyful', '#admirable', 0.05, 'up_down', 'curl', 'bump', 'hand_gesture', 'goodbye']
senticnet['crime'] = [-0.944, 0, -0.935, 0, '#sad', '#scared', -0.626, 'felony', 'revenge', 'theft', 'retribution', 'criminal']
senticnet['crime_scene'] = [-0.03, -0.009, 0, -0.209, '#sad', '#disgusting', -0.077, 'military_base', 'holster', 'gun_store', 'gun_shop', 'roadblock']
senticnet['criminal'] = [-0.94, 0, -0.977, 0, '#sad', '#scared', -0.639, 'murderer', 'thief', 'crime', 'harden_criminal', 'revenge']
senticnet['criminal_activity'] = [-0.167, -0.019, -0.177, 0.062, '#sad', '#scared', -0.088, 'heart_attack', 'sign_paper', 'understand_fact', 'freedom', 'sign_document']
senticnet['criminal_congress'] = [0.752, -0.577, 0, 0.967, '#joyful', '#admirable', 0.765, 'incest', 'extramarital_sex', 'free_love', 'sexual_intercourse', 'intercourse']
senticnet['criminal_conversation'] = [-0.985, 0, 0.662, -0.738, '#sad', '#disgusting', -0.795, 'fornication', 'unlawful_carnal_knowledge', 'criminal_congress', 'adultery', 'extramarital_sex']
senticnet['criminal_negligence'] = [-0.691, 0, 0.516, -0.966, '#sad', '#disgusting', -0.724, 'negligence', 'culpable_negligence', 'evasion', 'dereliction', 'contributory_negligence']
senticnet['criminal_offense'] = [-0.952, 0, 0.434, -0.985, '#sad', '#disgusting', -0.79, 'crime', 'criminal', 'thief', 'murder', 'kill']
senticnet['criminalize'] = [0.778, -0.964, 0, 0.702, '#joyful', '#surprising', 0.815, 'require', 'bar', 'debar', 'forbid', 'outlaw']
senticnet['criminate'] = [-0.708, 0, 0.905, -0.84, '#angry', '#disgusting', -0.818, 'reproach', 'upbraid', 'arraign', 'charge', 'accuse']
senticnet['crimp'] = [0.688, -0.733, 0, 0.955, '#surprising', '#admirable', 0.792, 'angular_shape', 'angularity', 'ruck', 'pucker', 'pleat']
senticnet['cringe'] = [-0.938, 0, 0, -0.912, '#sad', '#disgusting', -0.617, 'creeps', 'grovel', 'creep', 'cower', 'hysterically']
senticnet['cringing'] = [0.679, -0.947, 0, 0.661, '#joyful', '#surprising', 0.762, 'bowing', 'submissive', 'groveling', 'sub', 'wormlike']
senticnet['crinkle'] = [0.689, -0.565, 0, 0.74, '#joyful', '#admirable', 0.665, 'crease', 'heart_line', 'wrinkle', 'furrow', 'seam']
senticnet['cripple'] = [-0.904, 0, -0.942, 0, '#sad', '#scared', -0.615, 'influenza', 'chicken_pox', 'sexually_transmit_disease', 'overpay', 'diabetes']
senticnet['crisis'] = [-0.996, 0, 0.691, -0.655, '#sad', '#angry', -0.781, 'depression', 'economic_crisis', 'exigency', 'slump', 'juncture']
senticnet['crisp'] = [0.059, -0.044, 0.015, 0.064, '#joyful', '#admirable', 0.051, 'cold_water', 'dampness', 'like_food', 'cover_water', 'give_water']
senticnet['crispy'] = [-0.08, 0.232, 0, 0.099, '#interesting', '#admirable', 0.084, 'bee_product', 'gooey', 'red_skin', 'really_hot', 'bee_house']
senticnet['crisscross'] = [-0.787, 0, 0.754, -0.961, '#sad', '#disgusting', -0.834, 'tramp', 'cut_across', 'course', 'take', 'stride']
senticnet['criterion'] = [0, 0.225, -0.158, 0.236, '#interesting', '#admirable', 0.101, 'condition', 'diagnose', 'circumstance', 'axiom', 'tv_channel']
senticnet['critic'] = [0.811, -0.63, 0, 0.959, '#joyful', '#admirable', 0.8, 'drama_critic', 'theater_critic', 'professional', 'art_critic', 'literary_critic']
senticnet['critical'] = [-0.117, 0, -0.203, 0, '#sad', '#scared', -0.107, 'liberate', 'smartness', 'trustworthy', 'notoriety', 'sometimes_bad']
senticnet['criticism'] = [-0.296, -0.121, 0, -0.29, '#sad', '#disgusting', -0.155, 'complication', 'bad_feeling', 'screw_up', 'make_mistake', 'black_eye']
senticnet['criticize'] = [0, 0, 0, -0.879, '#disgusting', '#disgusting', -0.293, 'move_eye', 'learn_current_event', 'become_informed', 'time_waste', 'eye_strain']
senticnet['critique'] = [0.725, -0.949, 0, 0.792, '#surprising', '#admirable', 0.822, 'rave', 'literary_criticism', 'criticism', 'book_review', 'notice']
senticnet['critter'] = [0.03, 0.068, -0.044, 0.093, '#interesting', '#admirable', 0.049, 'beast', 'equine', 'live_creature', 'furry_creature', 'domesticate_animal']
senticnet['croak'] = [-0.102, -0.017, -0.056, -0.132, '#sad', '#disgusting', -0.091, 'clamor', 'roar', 'groan', 'squeak', 'loud_noise']
senticnet['crochet'] = [-0.057, 0, 0.01, -0.029, '#sad', '#disgusting', -0.032, 'shovel_snow', 'fly_around', 'blow_away', 'smoke_joint', 'hold_two_together']
senticnet['crockery'] = [0.022, 0.069, 0.027, 0.059, '#interesting', '#admirable', 0.041, 'perfect_surface', 'flat_land', 'flat_surface', 'flat_object', 'plate']
senticnet['crocodile'] = [-0.853, 0, 0.685, -0.838, '#sad', '#disgusting', -0.792, 'alligator', 'crocodilian', 'false_gavial', 'gator', 'caiman']
senticnet['crocodile_tears'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'pretense', 'feigning', 'dissembling', 'pretence', 'hypocrisy']
senticnet['crocodilian'] = [-0.853, 0, 0.685, -0.838, '#sad', '#disgusting', -0.792, 'alligator', 'crocodile', 'false_gavial', 'gator', 'caiman']
senticnet['crocodilian_reptile'] = [-0.52, 0, 0.981, -0.65, '#angry', '#disgusting', -0.717, 'alligator', 'crocodile', 'false_gavial', 'gator', 'caiman']
senticnet['crook'] = [-0.839, 0, 0.831, -0.693, '#sad', '#angry', -0.788, 'toughie', 'accessory', 'highbinder', 'hoodlum', 'thug']
senticnet['crooked'] = [-0.93, 0, 0.861, -0.504, '#sad', '#angry', -0.765, 'knotty', 'contorted', 'writhed', 'writhen', 'anfractuous']
senticnet['crop'] = [-0.031, 0.079, 0.013, 0.05, '#interesting', '#admirable', 0.028, 'maize', 'wheat_corn', 'wheat', 'reap', 'wheat_rice']
senticnet['crop_field'] = [0, 0.074, 0, 0.078, '#interesting', '#admirable', 0.051, 'plant_crop', 'grow_crop', 'raise_animal', 'harvest', 'food_production']
senticnet['crop_place'] = [0, 0.095, 0.021, 0.092, '#interesting', '#admirable', 0.055, 'cow_home', 'grow_place', 'vegetable_grow', 'grow_stuff', 'agriculture']
senticnet['croquet'] = [0.032, -0.009, 0, 0.09, '#joyful', '#admirable', 0.044, 'umpire', 'referee', 'equestrian_sport', 'backgammon', 'traffic_control']
senticnet['cross'] = [0.037, 0.184, 0, 0.211, '#interesting', '#admirable', 0.144, 'crucifix', 'religious_icon', 'steeple', 'bless', 'jesus_crucify']
senticnet['cross_bridge'] = [-0.091, 0, -0.077, 0, '#sad', '#scared', -0.056, 'weather_storm', 'smoke_cigar', 'smoke_joint', 'shovel_snow', 'deal_card']
senticnet['cross_bun'] = [-0.902, 0, 0, -0.89, '#sad', '#disgusting', -0.597, 'coffee_roll', 'hot_coffee_roll', 'bear_paw', 'bear_claw', 'bun']
senticnet['cross_country_ski'] = [-0.028, 0.119, 0, 0.054, '#interesting', '#admirable', 0.048, 'snow', 'experience_fear', 'stumble', 'folly', 'tumble']
senticnet['cross_eye'] = [-0.359, -0.103, 0, -0.345, '#sad', '#disgusting', -0.2, 'lose_mind', 'go_insane', 'punch_face', 'pull_trigger', 'feel_stupid']
senticnet['cross_guard'] = [0.076, 0.067, 0.049, 0, '#joyful', '#interesting', 0.031, 'traffic_sign', 'road_sign', 'street_sign', 'sharpness', 'point']
senticnet['cross_ocean'] = [-0.036, 0.111, -0.061, 0.084, '#interesting', '#admirable', 0.033, 'sailing', 'travel_over_water', 'transport_goods', 'vacation', 'sail_ocean']
senticnet['cross_red_light'] = [-0.921, 0, 0.833, -0.973, '#sad', '#disgusting', -0.909, 'escape_prison', 'drive_fast', 'car_accident', 'break_rule', 'drink_drive']
senticnet['cross_river'] = [0, 0, 0, 0.099, '#admirable', '#admirable', 0.033, 'travel_over_water', 'cross_water', 'bridge_stream', 'connect_city', 'cross_bridge']
senticnet['cross_road'] = [-0.073, 0, 0, -0.076, '#sad', '#disgusting', -0.05, 'swim_sea', 'play_dead', 'eat_animal', 'produce_egg', 'hurry_work']
senticnet['cross_room'] = [0, 0.846, 0, 0.782, '#interesting', '#admirable', 0.543, 'keep_record', 'list_item', 'check_balance', 'strive', 'record']
senticnet['cross_talking'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'witty_remark', 'banter', 'swordplay', 'wordplay', 'jester']
senticnet['cross_water'] = [0.055, 0, 0.038, 0.119, '#joyful', '#admirable', 0.045, 'cross_river', 'travel_over_water', 'sail', 'water_activity', 'cross_bridge']
senticnet['crosscheck'] = [0.84, -0.979, 0, 0.713, '#joyful', '#surprising', 0.844, 'proof', 'bed_check', 'substantiation', 'parity_check', 'redundancy_check']
senticnet['crosshatch'] = [-0.912, 0, 0.796, -0.872, '#sad', '#disgusting', -0.86, 'hatch', 'hatching', 'shading', 'hachure', 'marking']
senticnet['crossing'] = [0.508, -0.726, 0, 0.727, '#surprising', '#admirable', 0.654, 'crosswalk', 'pelican_pedestrian_crossing', 'school_pedestrian_crossing', 'pedestrian_crossing', 'crossover']
senticnet['crossness'] = [-0.892, 0, 0.943, -0.561, '#sad', '#angry', -0.799, 'ill_humor', 'distemper', 'pet', 'testiness', 'touchiness']
senticnet['crossover'] = [0.508, -0.726, 0, 0.727, '#surprising', '#admirable', 0.654, 'crosswalk', 'pelican_crossing', 'school_crossing', 'crossing', 'pedestrian_crossing']
senticnet['crosspatch'] = [-0.854, 0, 0.915, -0.82, '#sad', '#angry', -0.863, 'hothead', 'unpleasant_person', 'disagreeable_person', 'crabby_person', 'crab']
senticnet['crossroad'] = [0.04, 0.07, 0, 0, '#joyful', '#interesting', 0.037, 'intersection', 'interstate', 'parking_lot', 'expressway', 'traffic_artery']
senticnet['crosstalk'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'short_circuit', 'error', 'mistake', 'undesired', 'trouble']
senticnet['crosswalk'] = [0.508, -0.726, 0, 0.727, '#surprising', '#admirable', 0.654, 'pedestrian_crossing', 'pelican_crossing', 'school_crossing', 'crossing', 'crossover']
senticnet['crossword'] = [0.04, 0.07, 0, 0, '#joyful', '#interesting', 0.037, 'breaking_news', 'grade_paper', 'puzzle_game', 'crossword_puzzle', 'game']
senticnet['crossword_puzzle'] = [0.04, 0.07, 0, 0, '#joyful', '#interesting', 0.037, 'crossword', 'puzzle_game', 'game', 'newspaper', 'puzzle']
senticnet['crotch'] = [0, 0, 0, -0.068, '#disgusting', '#disgusting', -0.023, 'body', 'nervous_system', 'normal_human_body', 'human_body', 'head_shoulder']
senticnet['crotchet'] = [-0.561, 0, 0.977, -0.869, '#angry', '#disgusting', -0.802, 'freakishness', 'quaintness', 'abnormality', 'queerness', 'strangeness']
senticnet['crow'] = [-0.03, -0.029, 0.027, -0.109, '#sad', '#disgusting', -0.046, 'bird_prey', 'eagle', 'hawk', 'raven', 'bird_type']
senticnet['crowd'] = [-0.983, 0, 0.058, -0.921, '#sad', '#disgusting', -0.654, 'traffic_jam', 'accumulate_stress', 'stress', 'accumulate_stress_city', 'bad_service']
senticnet['crowd_cheer'] = [0.514, 0.122, -0.088, 0.081, '#joyful', '#interesting', 0.21, 'become_addicted', 'happiness', 'happy', 'feel_proud', 'cheer_up']
senticnet['crowd_city'] = [-0.983, 0, 0.058, -0.921, '#sad', '#disgusting', -0.654, 'traffic_jam', 'crowd', 'stress', 'accumulate_stress', 'bad_service']
senticnet['crowd_elevator'] = [-0.851, 0, 0, -0.947, '#sad', '#disgusting', -0.599, 'position_furniture', 'explain_everything', 'forward_email', 'rush_job', 'stand_alone']
senticnet['crowd_room'] = [0, 0, -0.735, -0.82, '#scared', '#disgusting', -0.518, 'leave_table', 'seat_chair', 'reciprocate', 'learn_love_another', 'swim_lake']
senticnet['crowfoot'] = [-0.744, 0, 0.603, -0.765, '#sad', '#disgusting', -0.704, 'herb', 'meadow_buttercup', 'tall_buttercup', 'tall_crowfoot', 'tall_field_buttercup']
senticnet['crowing'] = [-0.887, 0, 0.666, -0.901, '#sad', '#disgusting', -0.818, 'crow', 'jactitation', 'bluster', 'bragging', 'vaporing']
senticnet['crown'] = [-0.626, 0, 0.961, -0.544, '#sad', '#angry', -0.71, 'jeweled_headdress', 'diadem', 'tiara', 'headdress', 'headgear']
senticnet['crown_jewel'] = [0.522, -0.88, 0, 0.965, '#surprising', '#admirable', 0.789, 'overage', 'assets', 'security', 'capital', 'hole_card']
senticnet['crown_of_thorns'] = [-0.912, 0, 0.921, -0.733, '#sad', '#angry', -0.855, 'affliction', 'adversity', 'hardship', 'hard_knocks', 'cross']
senticnet['crucifer'] = [-0.569, 0, 0.892, -0.784, '#angry', '#disgusting', -0.748, 'borecole', 'colewort', 'kail', 'cole', 'kale']
senticnet['cruciferous_plant'] = [-0.76, 0, 0.744, -0.751, '#sad', '#disgusting', -0.752, 'borecole', 'colewort', 'kail', 'cole', 'kale']
senticnet['crucifix'] = [-0.983, 0, 0.058, -0.921, '#sad', '#disgusting', -0.654, 'cross', 'religious_icon', 'bewilderment', 'steeple', 'religion']
senticnet['crucify'] = [-0.132, 0.071, 0.694, -0.674, '#angry', '#disgusting', -0.476, 'bedevil', 'dun', 'frustrating', 'aggravate', 'exasperation']
senticnet['crude'] = [0, 0, -0.068, 0, '#scared', '#scared', -0.023, 'greasy', 'car_gas', 'fossil_fuel', 'liquid_fuel', 'lubrication']
senticnet['crudeness'] = [0.606, -0.978, 0, 0.742, '#surprising', '#admirable', 0.775, 'bad_manners', 'rudeness', 'gaucheness', 'impoliteness', 'crudity']
senticnet['crudity'] = [0.606, -0.978, 0, 0.742, '#surprising', '#admirable', 0.775, 'bad_manners', 'rudeness', 'gaucheness', 'crudeness', 'impoliteness']
senticnet['cruel'] = [-0.795, 0, 0.691, -0.886, '#sad', '#disgusting', -0.791, 'cold', 'pitiless', 'inhumane', 'fell', 'vicious']
senticnet['cruelly'] = [-0.907, 0, 0, -0.926, '#sad', '#disgusting', -0.611, 'mercilessness', 'unkind', 'ruthlessness', 'pitilessness', 'unassertively']
senticnet['cruelness'] = [-0.874, 0, 0.53, -0.659, '#sad', '#disgusting', -0.688, 'malevolence', 'malevolency', 'malice', 'murderousness', 'ferociousness']
senticnet['cruelty'] = [0, 0, 0.817, -0.785, '#angry', '#disgusting', -0.534, 'terrible', 'horrible', 'dread', 'hopeless', 'fearful']
senticnet['cruise'] = [0, 0.951, 0, 0.752, '#interesting', '#admirable', 0.568, 'boat', 'vacation', 'trip', 'go_on_holiday', 'sail']
senticnet['cruiser'] = [0.02, 0, 0, 0.057, '#joyful', '#admirable', 0.026, 'ship', 'boat', 'yacht', 'sail_ship', 'large_ship']
senticnet['crumble'] = [0.022, -0.133, 0, 0, '#joyful', '#surprising', 0.052, 'amount_nothing', 'feel_heat', 'fall_off_chair', 'pulse', 'blow_up_balloon']
senticnet['crumple'] = [0, -0.872, 0, 0.791, '#surprising', '#admirable', 0.554, 'stick_paper', 'white_paper', 'stick_together', 'paper_piece', 'piece_of_paper']
senticnet['crunchy'] = [0.049, 0.078, 0.05, 0.121, '#interesting', '#admirable', 0.066, 'green_fruit', 'tree_fruit', 'round_fruit', 'red_fruit', 'redness']
senticnet['crusade'] = [-0.817, 0, 0, -0.938, '#sad', '#disgusting', -0.585, 'fundamentalist', 'christian', 'religion', 'pope', 'christian_fundamentalist']
senticnet['crusader'] = [0, 0.992, 0, 0.906, '#interesting', '#admirable', 0.633, 'insurgent', 'passive_resister', 'demonstrator', 'fighter', 'activist']
senticnet['crush'] = [0, 0, 0.716, -0.799, '#angry', '#disgusting', -0.505, 'strike', 'tingle', 'affect', 'shudder', 'smash']
senticnet['crush_ice'] = [0, -0.025, 0.064, -0.085, '#angry', '#disgusting', -0.041, 'land_earth', 'spurt', 'brine', 'river_lake', 'puddle']
senticnet['crushing'] = [0, 0, -0.896, -0.792, '#scared', '#disgusting', -0.563, 'suppression', 'quelling', 'stifling', 'oppress', 'squeeze']
senticnet['crust'] = [0.033, 0, 0.013, 0.064, '#joyful', '#admirable', 0.028, 'yeast', 'flour', 'dough', 'sweetness', 'staple_food']
senticnet['crustacean'] = [0.052, 0.066, 0, 0.106, '#interesting', '#admirable', 0.075, 'shell_fish', 'seafood', 'marine_animal', 'ocean_animal', 'sometimes']
senticnet['crutch'] = [0.048, 0.19, -0.061, 0.077, '#interesting', '#admirable', 0.085, 'circular_route', 'city_hall', 'walking_stick', 'other_half_marriage', 'hardware_shop']
senticnet['cry'] = [-0.153, 0, -0.218, -0.152, '#sad', '#scared', -0.174, 'shed_tear', 'cry_lot', 'tear_eye', 'cry_hard', 'emotional_pain']
senticnet['cry_child'] = [-0.129, 0, -0.19, -0.078, '#sad', '#scared', -0.132, 'bigot', 'bad_word', 'intolerance', 'kidnap', 'much_fat']
senticnet['cry_for'] = [-0.662, 0, 0.813, -0.946, '#angry', '#disgusting', -0.807, 'demand', 'need', 'require', 'take', 'postulate']
senticnet['cry_for_help'] = [-1.0, 0, 0.619, -0.934, '#sad', '#disgusting', -0.851, 'fear', 'scream', 'shout', 'yell', 'cry']
senticnet['cry_hard'] = [-0.98, 0, -0.712, 0, '#sad', '#scared', -0.564, 'cry', 'weep', 'sob', 'tear_eye', 'pee_pants']
senticnet['cry_help'] = [-0.719, 0, 0, 0, '#sad', '#sad', -0.24, 'feel_stupid', 'go_scuba_dive', 'die_young', 'end_relationship', 'feel_ashamed']
senticnet['cry_lot'] = [-0.188, -0.061, -0.111, -0.256, '#sad', '#disgusting', -0.165, 'cry', 'talk_nonsense', 'sadness', 'bring_joy', 'cry_hard']
senticnet['cry_loudly'] = [-0.096, -0.019, -0.128, -0.127, '#scared', '#disgusting', -0.111, 'cry_lot', 'wet_oneself', 'invigorate', 'alter_state_consciousness', 'talk_nonsense']
senticnet['cry_out'] = [-0.786, 0, 0.701, -0.782, '#sad', '#disgusting', -0.756, 'express', 'utter', 'gee', 'ooh', 'aah']
senticnet['cry_out_for'] = [-0.781, 0, 0.569, -0.91, '#sad', '#disgusting', -0.753, 'demand', 'need', 'require', 'take', 'postulate']
senticnet['cry_wolf'] = [-0.11, -0.046, 0.033, -0.08, '#sad', '#disgusting', -0.059, 'fancy_girl', 'group_together', 'kiss_girl', 'journey_far', 'wedge_door']
senticnet['cryaesthesia'] = [-0.587, 0, 0.577, -0.64, '#sad', '#disgusting', -0.601, 'cryesthesia', 'hypersensitivity', 'hypersensitivity_reaction', 'sensitivity', 'predisposition']
senticnet['crybaby'] = [-0.918, 0, 0.681, -0.818, '#sad', '#disgusting', -0.806, 'chicken', 'softy', 'softie', 'doormat', 'wimp']
senticnet['cryesthesia'] = [-0.587, 0, 0.577, -0.64, '#sad', '#disgusting', -0.601, 'hypersensitivity', 'cryaesthesia', 'hypersensitivity_reaction', 'sensitivity', 'predisposition']
senticnet['crying_baby'] = [0.062, -0.037, 0.116, -0.096, '#angry', '#disgusting', -0.038, 'bad_music', 'noise', 'stress', 'a_lot_of_work', 'stressful_situation']
senticnet['cryopathy'] = [-0.503, 0, 0.737, -0.741, '#angry', '#disgusting', -0.66, 'injury', 'harm', 'hurt', 'trench_foot', 'immersion_foot']
senticnet['cryptanalyst'] = [0.615, -0.935, 0, 0.812, '#surprising', '#admirable', 0.787, 'intellectual', 'intellect', 'decipherer', 'cryptographer', 'cryptologist']
senticnet['cryptic'] = [-0.77, 0, -0.991, 0, '#sad', '#scared', -0.587, 'inscrutable', 'cabalistic', 'deep', 'mysterious', 'mystifying']
senticnet['cryptic_coloration'] = [0.62, -0.598, 0, 0.967, '#joyful', '#admirable', 0.728, 'aposematic_coloration', 'warning_coloration', 'apatetic_coloration', 'protective_coloration', 'coloration']
senticnet['cryptococcosis'] = [-0.859, 0, 0.549, -0.938, '#sad', '#disgusting', -0.782, 'coccidioidomycosis', 'coccidiomycosis', 'valley_fever', 'desert_rheumatism', 'mycosis']
senticnet['cryptographer'] = [0.615, -0.935, 0, 0.812, '#surprising', '#admirable', 0.787, 'intellectual', 'intellect', 'cryptanalyst', 'decipherer', 'cryptologist']
senticnet['cryptography'] = [0.634, -0.738, 0, 0.974, '#surprising', '#admirable', 0.782, 'decompression', 'decipherment', 'coding', 'secret_writing', 'steganography']
senticnet['cryptologist'] = [0.615, -0.935, 0, 0.812, '#surprising', '#admirable', 0.787, 'intellectual', 'intellect', 'cryptanalyst', 'cryptographer', 'decipherer']
senticnet['crystal_clear'] = [0.522, -0.88, 0, 0.965, '#surprising', '#admirable', 0.789, 'blue_color', 'munchkin', 'imaginary', 'blue_sky', 'water_sky']
senticnet['crystal_gazing'] = [0.958, -0.508, 0, 0.527, '#joyful', '#admirable', 0.664, 'divination', 'anticipation', 'prevision', 'prophecy', 'foretelling']
senticnet['crystalline_solid'] = [0.032, 0, 0, 0.077, '#joyful', '#admirable', 0.036, 'fluid', 'liquid', 'white_color', 'like_food', 'use_cook']
senticnet['crystallize'] = [0.548, -0.867, 0, 0.938, '#surprising', '#admirable', 0.784, 'elaborate', 'clear', 'elucidate', 'clear_up', 'make_clear']
senticnet['ctenophore'] = [-0.79, 0, 0.709, -0.854, '#sad', '#disgusting', -0.784, 'animal', 'animate_being', 'invertebrate', 'comb_jelly', 'beast']
senticnet['cub'] = [-0.954, 0, 0.735, -0.842, '#sad', '#disgusting', -0.844, 'novice', 'beginner', 'tyro', 'tiro', 'initiate']
senticnet['cuban_cigar'] = [0.031, 0, -0.081, -0.088, '#scared', '#disgusting', -0.046, 'smoke_cigarette', 'smoke', 'cinder', 'tobacco_product', 'smoke_pipe']
senticnet['cube'] = [0, 0.703, 0, 0.874, '#interesting', '#admirable', 0.526, 'block', 'dice', 'ping_pong_paddle', 'ball_player', 'trapezoid']
senticnet['cubicle'] = [0.053, 0.1, 0, 0, '#joyful', '#interesting', 0.051, 'registry_office', 'lodgings', 'telephone_booth', 'board_room', 'reception_area']
senticnet['cuckold'] = [-0.753, 0, 0.547, -0.787, '#sad', '#disgusting', -0.696, 'cheat_on', 'play_around', 'wander', 'betray', 'cheat']
senticnet['cuckoo_nest'] = [-0.604, 0, 0.716, -0.527, '#sad', '#angry', -0.616, 'asylum', 'mental_hospital', 'psychiatric_hospital', 'mental_institution', 'mental_home']
senticnet['cucumber'] = [0, -0.006, 0.053, -0.037, '#angry', '#disgusting', -0.028, 'kale', 'broccoli', 'cabbage', 'lettuce', 'pea']
senticnet['cucumber_beetle'] = [0, -0.093, 0.119, -0.119, '#angry', '#disgusting', -0.048, 'japanese_beetle', 'mole_cricket', 'gypsy_moth', 'mosquito', 'earwig']
senticnet['cuddle'] = [0.032, 0, 0, 0.077, '#joyful', '#admirable', 0.036, 'embrace', 'hug', 'caress', 'kiss', 'love']
senticnet['cudweed'] = [-0.934, 0, 0.691, -0.971, '#sad', '#disgusting', -0.865, 'everlasting_flower', 'strawflower', 'composite', 'composite_plant', 'pink_paper_daisy']
senticnet['cue'] = [0.067, -0.2, 0.064, 0, '#joyful', '#surprising', 0.068, 'wand', 'long_stick', 'branch', 'twig', 'stick']
senticnet['cuisine'] = [0.847, -0.771, 0, 0, '#joyful', '#surprising', 0.539, 'ferment_grape_juice', 'chef_special', 'bottle_wine', 'fine_dining', 'decanter']
senticnet['cullis'] = [-0.9, 0, 0.749, -0.719, '#sad', '#angry', -0.789, 'chute', 'slide', 'slideway', 'sloping_trough', 'gutter']
senticnet['culpability'] = [-0.985, 0, 0.657, -0.959, '#sad', '#disgusting', -0.867, 'impeachability', 'indictability', 'blameworthiness', 'guiltiness', 'culpableness']
senticnet['culpable_negligence'] = [-0.691, 0, 0.516, -0.966, '#sad', '#disgusting', -0.724, 'criminal_negligence', 'negligence', 'evasion', 'dereliction', 'contributory_negligence']
senticnet['culpableness'] = [-0.985, 0, 0.657, -0.959, '#sad', '#disgusting', -0.867, 'impeachability', 'indictability', 'blameworthiness', 'culpability', 'guiltiness']
senticnet['cult'] = [0.052, 0.223, -0.068, 0.163, '#interesting', '#admirable', 0.123, 'congregation', 'committee', 'majority', 'gang', 'bunch']
senticnet['cultivate'] = [0, 0.111, 0, 0.116, '#interesting', '#admirable', 0.076, 'plant_field', 'vegetable_field', 'edible_plant', 'farm_vegetable', 'plant_food']
senticnet['cultivate_yard'] = [0.101, 0.137, 0, 0.193, '#interesting', '#admirable', 0.144, 'sexual', 'use_decoration', 'organic', 'juicy', 'nutritious']
senticnet['cultivated'] = [0.03, 0.068, -0.044, 0.093, '#interesting', '#admirable', 0.049, 'domesticate_animal', 'tamed', 'live_creature', 'furry_creature', 'farm']
senticnet['cultivated_land'] = [0.958, -0.508, 0, 0.527, '#joyful', '#admirable', 0.664, 'fallow', 'farmland', 'plowland', 'ploughland', 'tilled_land']
senticnet['cultivated_parsnip'] = [0.861, -0.879, 0, 0.597, '#joyful', '#surprising', 0.779, 'herb', 'pastinaca_sativa', 'wild_parsnip', 'madnep', 'herbaceous_plant']
senticnet['cultivation'] = [0, 0.105, 0, 0.1, '#interesting', '#admirable', 0.068, 'agricultural', 'grow_food', 'harvest_food', 'grow_stuff', 'grow_crop']
senticnet['cultural'] = [-0.058, 0, -0.059, 0, '#sad', '#scared', -0.039, 'land_area', 'political_state', 'large_land', 'large_state', 'political_unit']
senticnet['cultural_change'] = [0, 0.744, 0, 0.807, '#interesting', '#admirable', 0.517, 'funny_look', 'soldier_group', 'rival', 'anti', 'military_force']
senticnet['cultural_experience'] = [0.973, 0.822, 0, 0.735, '#joyful', '#interesting', 0.843, 'acculturation', 'golfer', 'stimulate_mind', 'pastime', 'kill_time']
senticnet['culture'] = [0.096, 0.097, -0.075, 0, '#joyful', '#interesting', 0.039, 'craft', 'design', 'religion', 'artist', 'art']
senticnet['cultured'] = [0, 0.969, 0, 0.759, '#interesting', '#admirable', 0.576, 'civilized', 'civilised', 'cultivated', 'genteel', 'polite']
senticnet['cum'] = [0, 0.079, 0, 0, '#interesting', '#interesting', 0.026, 'change_diaper', 'lower_standard_live', 'become_pregnant', 'find_mate', 'make_baby']
senticnet['cumbersome'] = [-0.965, 0, 0.636, -0.85, '#sad', '#disgusting', -0.817, 'awkward', 'bunglesome', 'clumsy', 'unmanageable', 'ungainly']
senticnet['cumbersomeness'] = [-0.647, 0, 0.625, -0.882, '#sad', '#disgusting', -0.718, 'difficulty', 'awkwardness', 'flea_bite', 'difficultness', 'troublesomeness']
senticnet['cumbrous'] = [0.834, -0.717, 0, 0.649, '#joyful', '#surprising', 0.733, 'unwieldy', 'ungainly', 'clumsy', 'cumbersome', 'awkward']
senticnet['cummerbund'] = [-0.534, 0, 0.682, -0.748, '#angry', '#disgusting', -0.655, 'girdle', 'cincture', 'sash', 'waistband', 'waistcloth']
senticnet['cumulation'] = [-0.77, 0, 0.588, -0.801, '#sad', '#disgusting', -0.72, 'heap', 'agglomerate', 'piles', 'mound', 'funeral_pyre']
senticnet['cuneus'] = [0.763, -0.612, 0, 0.777, '#joyful', '#admirable', 0.717, 'acute_triangle', 'wedge_shape', 'triangle', 'wedge', 'oblique_triangle']
senticnet['cunning'] = [0.738, -0.965, 0, 0.727, '#joyful', '#surprising', 0.81, 'ingenious', 'clever', 'adroit', 'clean', 'neat']
senticnet['cunt'] = [-0.119, 0, -0.162, 0.062, '#sad', '#scared', -0.073, 'tile_floor', 'wicker', 'miss', 'short_form', 'happy_together']
senticnet['cup'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'pitcher', 'carafe', 'container_pitcher', 'mug', 'glass_of_water']
senticnet['cup_breast'] = [-0.91, 0, 0, -0.89, '#sad', '#disgusting', -0.6, 'wave_hello', 'wedge_door_open', 'wank', 'tear_paper', 'write_computer_program']
senticnet['cup_coffee'] = [0.911, 0, 0, 0, '#joyful', '#joyful', 0.304, 'read_book', 'stay_awake', 'cafe', 'peace_quiet', 'find_quiet_place']
senticnet['cup_hand'] = [-0.796, 0, 0, -0.847, '#sad', '#disgusting', -0.548, 'bicycle_across_town', 'storm_out_room', 'mine_diamond', 'kill_specific_group', 'speak_english']
senticnet['cup_tea'] = [0.836, 0.996, 0, 0, '#joyful', '#interesting', 0.611, 'romance_novel', 'hold_book', 'instinct', 'feel_warm', 'tea']
senticnet['cupboard'] = [0.069, 0.112, 0, 0.167, '#interesting', '#admirable', 0.116, 'clothes_shelf', 'hangers', 'compartment', 'jeans', 'drawers']
senticnet['cupcake'] = [0.085, -0.175, -0.05, 0, '#joyful', '#surprising', 0.07, 'apple_pie', 'pie', 'ice_cream', 'muffin', 'cookie']
senticnet['cur'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'dog', 'feist', 'fice', 'pariah_dog', 'domestic_dog']
senticnet['curative'] = [-0.601, 0, 0.544, -0.628, '#sad', '#disgusting', -0.591, 'remedy', 'cure', 'therapeutic', 'antidote', 'atropine']
senticnet['curb'] = [0, 0, 0.033, -0.045, '#angry', '#disgusting', -0.026, 'boulevard', 'lane', 'thoroughfare', 'intersection', 'avenue']
senticnet['cure'] = [0.713, 0, 0, 0.766, '#joyful', '#admirable', 0.493, 'doctor', 'nurse', 'medical_procedure', 'medicine', 'doctor_surgery']
senticnet['cure_all'] = [0.955, 0.862, 0, 0, '#joyful', '#interesting', 0.606, 'cure', 'ointment', 'medication', 'lotion', 'application']
senticnet['cure_disease'] = [0.911, 0, 0, 0, '#joyful', '#joyful', 0.304, 'treat_illness', 'heal', 'cure_illness', 'get_well', 'heal_disease']
senticnet['cure_illness'] = [-0.065, 0.068, -0.123, -0.163, '#scared', '#disgusting', -0.094, 'sickness', 'ailment', 'illness', 'ill', 'determine_health']
senticnet['cured'] = [0.789, -0.58, 0, 0.715, '#joyful', '#admirable', 0.695, 'desiccated', 'aged', 'lyophilized', 'preserved', 'candied']
senticnet['curfew'] = [-0.065, 0.068, -0.123, -0.163, '#scared', '#disgusting', -0.094, 'go_home_early', 'rule', 'restriction', 'cinderella', 'limitation']
senticnet['curing'] = [-0.716, 0, 0.509, -0.922, '#sad', '#disgusting', -0.716, 'natural_process', 'natural_action', 'activity', 'congealment', 'congelation']
senticnet['curio'] = [0.743, -0.815, 0, 0.632, '#joyful', '#surprising', 0.73, 'piece_de_resistance', 'nicknack', 'knickknackery', 'whatnot', 'collector_item']
senticnet['curiosity'] = [0.911, 0, 0, 0, '#joyful', '#joyful', 0.304, 'interest', 'seek_truth', 'desire_learn', 'curious', 'learn_new']
senticnet['curious'] = [0, 0.943, 0, 0, '#interesting', '#interesting', 0.314, 'enlightenment', 'smartness', 'become_wise', 'intelligent', 'comprehend']
senticnet['curious_animal'] = [0.911, 0, 0, 0, '#joyful', '#joyful', 0.304, 'small_cat', 'curiosity', 'little_animal', 'small_animal', 'baby_cat']
senticnet['curiousness'] = [-0.909, 0, 0.865, -0.772, '#sad', '#angry', -0.849, 'nosiness', 'snoopiness', 'prying', 'curiosity', 'wonder']
senticnet['curl'] = [0.063, 0, 0.01, 0.16, '#joyful', '#admirable', 0.071, 'goodbye', 'hand_gesture', 'arm_movement', 'crest', 'water_splash']
senticnet['curl_iron'] = [-0.906, 0, 0, -0.995, '#sad', '#disgusting', -0.634, 'barrette', 'hair_dryer', 'hair_clip', 'haircut_scissor', 'bobby_pin']
senticnet['curly'] = [0.03, 0.069, 0, 0.168, '#interesting', '#admirable', 0.089, 'softness', 'soft_cloth', 'texture', 'soft_fabric', 'fuzzy']
senticnet['curly_endive'] = [0.636, -0.796, 0, 0.552, '#joyful', '#surprising', 0.661, 'lettuce', 'endive', 'green', 'salad_green', 'food']
senticnet['currawong'] = [-0.845, 0, 0.655, -0.851, '#sad', '#disgusting', -0.784, 'piping_crow', 'butcherbird', 'australian_magpie', 'bell_magpie', 'oscine']
senticnet['currency'] = [0, 0.237, 0.039, 0.098, '#interesting', '#admirable', 0.099, 'euro', 'small_change', 'dollar_change', 'dollar_bill', 'paper_currency']
senticnet['currency_exchange'] = [-0.059, 0.308, -0.095, 0.182, '#interesting', '#admirable', 0.112, 'give_cash', 'send_money', 'money', 'money_exchange', 'money_due']
senticnet['currency_system'] = [-0.149, -0.018, -0.142, -0.028, '#sad', '#scared', -0.1, 'currency_exchange', 'person', 'dangerous_activity', 'stockholder', 'guilty_person']
senticnet['currency_unit'] = [0, 0.12, 0.086, 0.11, '#interesting', '#admirable', 0.048, 'form_of_money', 'money_unit', 'monetary_unit', 'american_coin', 'american_money']
senticnet['current'] = [0.051, 0.126, -0.074, 0.164, '#interesting', '#admirable', 0.089, 'edifice', 'palace', 'high_rise', 'workhouse', 'bell_tower']
senticnet['current_event'] = [0, -0.822, 0, 0.835, '#surprising', '#admirable', 0.552, 'headline', 'bulletin', 'paper_write', 'world_event', 'newsfeed']
senticnet['currently'] = [0, 0.884, 0, 0.987, '#interesting', '#admirable', 0.624, 'feel_presence', 'instant', 'person', 'make_effort', 'presence']
senticnet['curriculum'] = [0.731, -0.97, 0, 0.957, '#surprising', '#admirable', 0.886, 'course_of_study', 'program', 'programme', 'reading_program', 'syllabus']
senticnet['curry'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'veal', 'beef', 'food_group', 'cereal', 'animal_flesh']
senticnet['curry_favor'] = [0.632, -0.865, 0, 0.799, '#surprising', '#admirable', 0.765, 'suck_up', 'toady', 'bootlick', 'kowtow', 'mafia']
senticnet['curry_powder'] = [0.904, -0.892, 0, 0, '#joyful', '#surprising', 0.599, 'make_curry', 'cook_dinner', 'cook_meal', 'cook_curry', 'powder']
senticnet['curse'] = [-0.202, 0.109, -0.155, -0.096, '#sad', '#scared', -0.115, 'die_young', 'make_offer', 'charge_credit_card', 'smoke_cigar', 'buy_stock']
senticnet['curse_word'] = [-0.919, 0, 0.833, -0.945, '#sad', '#disgusting', -0.899, 'bad_communication', 'bad_word', 'rude', 'rude_man', 'curse']
senticnet['cursed'] = [-0.62, 0, 0.627, -0.599, '#sad', '#angry', -0.615, 'execrable', 'blame', 'damnable', 'maledict', 'damn']
senticnet['cursive'] = [-0.958, 0, 0.517, -0.536, '#sad', '#disgusting', -0.67, 'copperplate', 'hand', 'minuscule', 'italic', 'round_hand']
senticnet['cursive_script'] = [-0.899, 0, 0.78, -0.662, '#sad', '#angry', -0.78, 'copperplate', 'hand', 'minuscule', 'italic', 'round_hand']
senticnet['curst'] = [-0.652, 0, 0.973, -0.933, '#angry', '#disgusting', -0.853, 'execrable', 'blame', 'damnable', 'maledict', 'damn']
senticnet['curt'] = [0, 0, 0.782, -0.799, '#angry', '#disgusting', -0.527, 'discourteous', 'brusque', 'brusk', 'abrupt', 'unceremonious']
senticnet['curtail'] = [0.63, -0.696, 0, 0.865, '#surprising', '#admirable', 0.73, 'immobilize', 'limit', 'abridge', 'ration', 'restrict']
senticnet['curtailment'] = [0.953, -0.65, 0, 0.866, '#joyful', '#admirable', 0.823, 'economy_of_scale', 'retrenchment', 'saving', 'downsizing', 'action']
senticnet['curtain'] = [0, 0.117, -0.077, 0.094, '#interesting', '#admirable', 0.045, 'stage_door', 'balcony', 'backdrop', 'stage_border', 'row_seat']
senticnet['curvature'] = [-0.716, 0, 0.871, -0.75, '#angry', '#disgusting', -0.779, 'partial', 'differential', 'partial_derivative', 'calculation', 'computation']
senticnet['curve'] = [0.052, 0.086, 0.052, 0.224, '#interesting', '#admirable', 0.103, 'arc', 'octagon', 'spiral', 'no_corner', 'no_edge']
senticnet['curvy'] = [0, 0, -0.749, -0.756, '#scared', '#disgusting', -0.502, 'bosomy', 'busty', 'buxom', 'curvaceous', 'full-bosomed']
senticnet['cushion'] = [-0.5, 0, 0.598, -0.809, '#angry', '#disgusting', -0.636, 'temper', 'corrupt', 'modify', 'syncopate', 'spoil']
senticnet['cuss'] = [-0.998, 0, 0.636, -0.808, '#sad', '#disgusting', -0.814, 'pest', 'dullard', 'bore', 'blighter', 'nudnick']
senticnet['cussedness'] = [-0.751, 0, 0.683, -0.992, '#sad', '#disgusting', -0.809, 'contrariness', 'orneriness', 'unruliness', 'fractiousness', 'willfulness']
senticnet['custard'] = [0, -0.874, 0, 0.891, '#surprising', '#admirable', 0.588, 'mousse', 'cookie', 'brownie', 'cake', 'pudding']
senticnet['custody'] = [-0.914, 0, 0.931, -0.724, '#sad', '#angry', -0.856, 'get_arrested', 'detention', 'incarceration', 'quarantine', 'prisoner']
senticnet['custody_case'] = [-0.691, 0, 0.516, -0.966, '#sad', '#disgusting', -0.724, 'antitrust_case', 'civil_action', 'counterclaim', 'action_at_law', 'lis_pendens']
senticnet['custom'] = [0.976, 0, 0, 0.95, '#joyful', '#admirable', 0.642, 'care_person', 'ceremony', 'religious_event', 'ritual', 'tradition']
senticnet['customary'] = [0.84, -0.646, 0, 0.912, '#joyful', '#admirable', 0.799, 'received', 'conventional', 'formulaic', 'stuffy', 'stodgy']
senticnet['customer'] = [0, 0.743, 0, 0.771, '#interesting', '#admirable', 0.505, 'shopper', 'clerk', 'patron', 'vintner', 'hairdresser']
senticnet['customer_service'] = [0, 0.936, 0, 0.889, '#interesting', '#admirable', 0.608, 'come_warranty', 'make_comparison', 'guest_service', 'put_pocket', 'see_action']
senticnet['cut'] = [-0.066, -0.051, 0.037, -0.148, '#sad', '#disgusting', -0.067, 'cover_wound', 'cover_wind', 'welt', 'heal_wind', 'open_wind']
senticnet['cut_across'] = [-0.787, 0, 0.754, -0.961, '#sad', '#disgusting', -0.834, 'tramp', 'crisscross', 'course', 'take', 'stride']
senticnet['cut_back'] = [0.636, -0.796, 0, 0.552, '#joyful', '#surprising', 0.661, 'dress', 'trim', 'disbud', 'prune', 'snip']
senticnet['cut_cheese'] = [0.924, 0.972, 0, 0, '#joyful', '#interesting', 0.632, 'play_checker', 'place_chess_piece', 'play_game_chess', 'play_chess', 'play_game']
senticnet['cut_down'] = [-0.713, 0, 0.944, -0.997, '#angry', '#disgusting', -0.885, 'cut_down_tree', 'cut_lumber', 'cut_tree', 'chop_tree', 'make_wood']
senticnet['cut_down_tree'] = [0, 0, -0.787, -0.856, '#scared', '#disgusting', -0.548, 'parry', 'kill_life', 'destroy_city', 'destroy_target', 'murder_another_person']
senticnet['cut_edge'] = [0, 0, 0.022, -0.14, '#angry', '#disgusting', -0.054, 'prisoner_war_camp', 'dark_alley', 'hatchet', 'mountain_top', 'spear']
senticnet['cut_fabric'] = [-0.041, -0.062, 0.087, -0.132, '#angry', '#disgusting', -0.066, 'woven', 'use_needle', 'needle_thread', 'cover_wind', 'seam']
senticnet['cut_finger'] = [0, 0, 0, -0.717, '#disgusting', '#disgusting', -0.239, 'draw_blood', 'cause_bleed', 'hurt', 'open_wind', 'laceration']
senticnet['cut_flower'] = [0.102, 0, 0, 0, '#joyful', '#joyful', 0.034, 'fresh_vegetable', 'cabbage', 'fruit_vegetable', 'plant_matter', 'fruit']
senticnet['cut_food'] = [-0.086, -0.084, 0.021, -0.138, '#sad', '#disgusting', -0.054, 'spread_butter', 'open_package', 'lacerate', 'pierce', 'chop_vegetable']
senticnet['cut_grass'] = [0, -0.097, 0.035, 0.1, '#surprising', '#admirable', 0.054, 'dig_dirt', 'plant_flower', 'decorate_yard', 'plant_garden', 'grow_flower']
senticnet['cut_hair'] = [0, -0.097, 0.035, 0.1, '#surprising', '#admirable', 0.054, 'go_to_hairdresser', 'go_get_haircut', 'haircut', 'hairdressing_salon', 'hairdresser_chair']
senticnet['cut_half'] = [-0.022, 0, 0.061, 0, '#sad', '#angry', -0.028, 'cut_up', 'cut', 'half', 'separate', 'bake_cookie']
senticnet['cut_knife'] = [-0.097, -0.02, -0.046, -0.087, '#sad', '#disgusting', -0.07, 'raise_flag', 'kill_oneself', 'butter_toast', 'kill_other_person', 'hurt_animal']
senticnet['cut_line'] = [-0.081, -0.042, 0.062, -0.046, '#sad', '#angry', -0.049, 'grow_impatient', 'fall_off', 'use_brake', 'become_impatient', 'lose_balance']
senticnet['cut_lumber'] = [-0.049, 0, 0.06, -0.042, '#sad', '#angry', -0.05, 'cut_wood', 'cut_tree', 'chop_tree', 'use_school', 'chop']
senticnet['cut_meat'] = [0, -0.02, 0.043, -0.045, '#angry', '#disgusting', -0.023, 'meat_cut', 'high_protein', 'cut', 'red_meat', 'spread']
senticnet['cut_of_pork'] = [0.648, -0.539, 0, 0.94, '#joyful', '#admirable', 0.709, 'bacon_strip', 'flitch', 'side_of_bacon', 'gammon', 'bacon']
senticnet['cut_off'] = [0, -0.02, 0.043, -0.045, '#angry', '#disgusting', -0.023, 'painful', 'cut', 'cut_finger', 'get_hurt', 'cut_oneself']
senticnet['cut_oneself'] = [0, 0, -0.887, -0.894, '#scared', '#disgusting', -0.594, 'terrorism', 'drunk_drive', 'murder_another_person', 'kill_man', 'kill_person']
senticnet['cut_open'] = [-0.099, 0, -0.15, -0.058, '#sad', '#scared', -0.102, 'doctor_work', 'operation', 'doctor_surgery', 'medical_procedure', 'treatment']
senticnet['cut_out'] = [-0.77, 0.277, -0.449, -0.051, '#sad', '#scared', -0.331, 'delete', 'abolish', 'discharge', 'clear_away', 'remove']
senticnet['cut_paper'] = [-0.043, -0.026, 0.057, -0.083, '#angry', '#disgusting', -0.052, 'shave_beard', 'trim_hair', 'shave_leg', 'use_scissor', 'cut_ribbon']
senticnet['cut_price'] = [0.554, -0.726, 0, 0.651, '#surprising', '#admirable', 0.644, 'reasonableness', 'modestness', 'cost', 'cut_rate', 'inexpensiveness']
senticnet['cut_rate'] = [0.554, -0.726, 0, 0.651, '#surprising', '#admirable', 0.644, 'reasonableness', 'modestness', 'cost', 'inexpensiveness', 'cut_price']
senticnet['cut_ribbon'] = [0, 0, -0.78, -0.989, '#scared', '#disgusting', -0.59, 'cut_paper', 'use_scissor', 'draw_blood', 'cut_finger', 'copy_paste']
senticnet['cut_short'] = [-0.046, 0.127, -0.121, 0.223, '#interesting', '#admirable', 0.061, 'abbreviate', 'abridge', 'curtail', 'shorten', 'shortcut']
senticnet['cut_skin'] = [0, 0, -0.819, -0.911, '#scared', '#disgusting', -0.577, 'gash', 'ache', 'abrasion', 'ouch', 'laceration']
senticnet['cut_thing'] = [-0.949, 0, 0.655, -0.959, '#sad', '#disgusting', -0.854, 'use_knife', 'use_blade', 'cut', 'sharp_tool', 'dangerous']
senticnet['cut_throat'] = [-0.971, 0, 0.775, -0.95, '#sad', '#disgusting', -0.899, 'die', 'terrorist_action', 'death', 'kill', 'dead_person']
senticnet['cut_tool'] = [-0.054, -0.029, 0.05, -0.133, '#sad', '#disgusting', -0.069, 'dagger', 'machete', 'sharp', 'sharp_edge', 'use_knife']
senticnet['cut_tree'] = [-0.046, 0, 0.026, -0.048, '#sad', '#disgusting', -0.04, 'chop_tree', 'cut_wood', 'cut_lumber', 'cellulose', 'timber']
senticnet['cut_up'] = [-0.061, -0.027, 0.068, -0.09, '#angry', '#disgusting', -0.064, 'slice', 'sever', 'slash', 'cut', 'separation']
senticnet['cut_vegetable'] = [-0.042, -0.021, 0, -0.105, '#sad', '#disgusting', -0.042, 'stir_pot', 'chop_vegetable', 'open_package', 'cut_food', 'heat_pot_water']
senticnet['cut_wood'] = [-0.074, -0.024, 0.036, -0.128, '#sad', '#disgusting', -0.071, 'cut_tree', 'chop_tree', 'cut_lumber', 'chop', 'chop_wood']
senticnet['cutaneous_sensation'] = [-0.773, 0, 0.895, -0.733, '#sad', '#angry', -0.8, 'itch', 'urtication', 'itchiness', 'itching', 'tickle']
senticnet['cute'] = [0.057, 0, 0.023, 0.124, '#joyful', '#admirable', 0.053, 'hairy', 'nocturnal', 'furry', 'domestic_pet', 'animal_furry']
senticnet['cute_animal'] = [0.02, 0.071, 0, 0.069, '#interesting', '#admirable', 0.053, 'many_animals', 'little_animal', 'chihuahua', 'panda', 'small_creature']
senticnet['cute_cat'] = [0.636, -0.796, 0, 0.552, '#joyful', '#surprising', 0.661, 'big_cat', 'domesticate_animal', 'cat', 'big_animal', 'big']
senticnet['cuticle'] = [0, 0.097, 0, 0.085, '#interesting', '#admirable', 0.061, 'lunula', 'arm_part', 'leave_hand', 'ten_fingers', 'five_fingers']
senticnet['cutlass'] = [0.045, 0, 0.017, 0.052, '#joyful', '#admirable', 0.027, 'inexpensive', 'good_deal', 'cost_little_money', 'cheap', 'integer']
senticnet['cutlery'] = [0.054, -0.077, 0.025, 0, '#joyful', '#surprising', 0.035, 'table', 'dine_room_table', 'dine_table', 'restaurant', 'cafe']
senticnet['cutlery_drawer'] = [0.036, -0.052, 0, 0, '#joyful', '#surprising', 0.029, 'neat', 'kitchen_drawer', 'silverware_drawer', 'dine_table', 'table']
senticnet['cutthroat'] = [0.971, -0.926, 0, 0.617, '#joyful', '#surprising', 0.838, 'mortal', 'merciless', 'bowelless', 'tigerish', 'pitiless']
senticnet['cutworm'] = [-0.022, -0.098, 0.11, -0.131, '#angry', '#disgusting', -0.055, 'beetle', 'gypsy_moth', 'mole_cricket', 'grasshopper', 'many_insects']
senticnet['cyan'] = [0.036, -0.052, 0, 0, '#joyful', '#surprising', 0.029, 'indigo', 'yellow', 'water_color', 'red', 'violet']
senticnet['cyberspace'] = [0, 0, -0.047, -0.049, '#scared', '#disgusting', -0.032, 'bad_luck', 'wrong', 'hockey_rink', 'wrong_place', 'deli_case']
senticnet['cycad'] = [-0.772, 0, 0.585, -0.835, '#sad', '#disgusting', -0.731, 'progymnosperm', 'welwitschia', 'gymnosperm', 'seed_fern', 'pteridosperm']
senticnet['cycle'] = [0, 0, 0, 0.106, '#admirable', '#admirable', 0.035, 'stay_young', 'spin', 'move_quickly', 'jump_up', 'athletics']
senticnet['cyclist'] = [0.073, -0.022, 0, 0, '#joyful', '#surprising', 0.032, 'chauffeur', 'angler', 'homeowner', 'stalactite', 'smoker']
senticnet['cyclothymia'] = [-0.975, 0, 0.793, -0.688, '#sad', '#angry', -0.819, 'affective_disorder', 'major_affective_disorder', 'emotional_disorder', 'emotional_disturbance', 'bipolar_disorder']
senticnet['cylinder'] = [0.042, -0.02, 0.035, 0.065, '#joyful', '#admirable', 0.031, 'food_container', 'metal_cylinder', 'metal_container', 'small_ball', 'storage_container']
senticnet['cylindric'] = [0.022, 0, 0.015, 0.096, '#joyful', '#admirable', 0.034, 'write_tool', 'write_implement', 'cylindrical', 'write_device', 'write_paper']
senticnet['cylindrical'] = [0.022, 0, 0.015, 0.096, '#joyful', '#admirable', 0.034, 'write_tool', 'write_implement', 'cylindric', 'write_device', 'write_paper']
senticnet['cylindrical_shape'] = [0, -0.857, 0, 0.746, '#surprising', '#admirable', 0.534, 'finger', 'cylindric', 'thumb', 'five_digits', 'cylinder']
senticnet['cynic'] = [0.899, -0.775, 0, 0.866, '#joyful', '#admirable', 0.847, 'unpleasant_person', 'disagreeable_person', 'detractor', 'disparager', 'depreciator']
senticnet['cynical'] = [-0.72, 0, 0.707, 0, '#sad', '#angry', -0.476, 'cynicism', 'pessimistically', 'pessimism', 'pessimistic', 'despairing']
senticnet['cynicism'] = [-0.767, 0, 0.979, 0, '#sad', '#angry', -0.582, 'cynical', 'pessimistically', 'pessimism', 'pessimistic', 'despairing']
senticnet['cynophobia'] = [-0.57, 0, 0.814, -0.936, '#angry', '#disgusting', -0.773, 'phobia', 'acarophobia', 'fear', 'arachnophobia', 'zoophobia']
senticnet['cynosure'] = [0.724, -0.846, 0, 0.919, '#surprising', '#admirable', 0.83, 'guidance', 'counsel', 'counseling', 'mentor', 'direction']
senticnet['cypher'] = [-0.529, 0, 0.821, -0.651, '#angry', '#disgusting', -0.667, 'work_out', 'reckon', 'calculate', 'cipher', 'average_out']
senticnet['cyprian'] = [-0.863, 0, 0.783, -0.577, '#sad', '#angry', -0.741, 'slattern', 'camp_follower', 'call_girl', 'comfort_woman', 'ianfu']
senticnet['cyst'] = [-0.784, 0, 0.855, -0.996, '#angry', '#disgusting', -0.878, 'blood_blister', 'pustule', 'water_blister', 'vesicle', 'bleb']
senticnet['cystoid_macular_edema'] = [-0.865, 0, 0.858, -0.911, '#sad', '#disgusting', -0.878, 'edema', 'oedema', 'hydrops', 'dropsy', 'eye_disease']
senticnet['cystoscope'] = [0.255, 0.182, -0.06, 0.314, '#joyful', '#admirable', 0.23, 'doctor_office', 'urethroscope', 'sigmoidoscope', 'hospital', 'check_health']
senticnet['cytoplasm'] = [0, 0.095, 0.016, 0.106, '#interesting', '#admirable', 0.062, 'blood_plasma', 'plasma', 'germplasm', 'nucleoplasm', 'protoplasm']
senticnet['dabbler'] = [-0.982, 0, 0.937, -0.689, '#sad', '#angry', -0.869, 'sciolist', 'amateur', 'mortal', 'dilettante', 'bird_watcher']
senticnet['dad'] = [0, 0.725, 0, 0.779, '#interesting', '#admirable', 0.501, 'family_member', 'daddy', 'brother', 'mother_brother', 'uncle']
senticnet['daddy'] = [0, 0.944, 0, 0.97, '#interesting', '#admirable', 0.638, 'family_member', 'dad', 'brother', 'mother_brother', 'uncle']
senticnet['daemon'] = [-0.793, 0, 0.92, -0.752, '#sad', '#angry', -0.822, 'evil_spirit', 'incubus', 'succubus', 'succuba', 'dybbuk']
senticnet['daffodil'] = [0.994, 0.852, 0, 0, '#joyful', '#interesting', 0.615, 'blossom', 'dandelion', 'daisy', 'bloom', 'pollen']
senticnet['daft'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'simple', 'stupid', 'idiotic', 'moron', 'imbecile']
senticnet['dagger'] = [-0.821, 0, 0, -0.777, '#sad', '#disgusting', -0.533, 'machete', 'vaccination', 'cut_tool', 'knife', 'blade']
senticnet['daily'] = [0, -0.763, 0, 0.88, '#surprising', '#admirable', 0.548, 'tv_program', 'cnn', 'eat_breakfast', 'wake_up', 'medium']
senticnet['daily_activity'] = [-0.03, 0.157, -0.156, 0.22, '#interesting', '#admirable', 0.064, 'do_something', 'wake_up', 'form_of_social_interaction', 'act', 'behave']
senticnet['daily_news'] = [0.03, 0, 0.01, 0.071, '#joyful', '#admirable', 0.03, 'thin_wood', 'book_content', 'flat_thin', 'print_medium', 'book_page']
senticnet['daily_routine'] = [0, 0.188, -0.047, 0.191, '#interesting', '#admirable', 0.111, 'usual_ordinary', 'normal', 'typical', 'usual', 'frequent']
senticnet['daimon'] = [-0.866, 0, 0.914, -0.69, '#sad', '#angry', -0.823, 'evil_spirit', 'incubus', 'succubus', 'succuba', 'dybbuk']
senticnet['daintiness'] = [0.639, -0.701, 0, 0.507, '#joyful', '#surprising', 0.616, 'tastefulness', 'elegance', 'eclat', 'breeding', 'genteelness']
senticnet['dainty'] = [0.682, -0.525, 0, 0.613, '#joyful', '#admirable', 0.607, 'nice', 'meticulous', 'fastidious', 'prissy', 'pernickety']
senticnet['dairy'] = [0.037, 0, 0, 0.067, '#joyful', '#admirable', 0.035, 'veal', 'milk_product', 'salad_dress', 'ranch', 'food_group']
senticnet['dairy_cattle'] = [0.546, -0.969, 0, 0.533, '#joyful', '#surprising', 0.683, 'ayrshire', 'dairy_cow', 'milch_cow', 'milk_cow', 'milcher']
senticnet['dairy_cow'] = [0.546, -0.969, 0, 0.533, '#joyful', '#surprising', 0.683, 'dairy_cattle', 'ayrshire', 'milch_cow', 'milk_cow', 'milcher']
senticnet['dairy_product'] = [0.057, 0, 0.018, 0.058, '#joyful', '#admirable', 0.032, 'porridge', 'food_item', 'milk', 'food', 'morning_food']
senticnet['dais'] = [0, 0, -0.883, -0.934, '#scared', '#disgusting', -0.606, 'stage', 'thespian', 'actor', 'show_how', 'drama']
senticnet['daisy'] = [0.833, 0.775, 0, 0, '#joyful', '#interesting', 0.536, 'blossom', 'dandelion', 'daffodil', 'bloom', 'pollen']
senticnet['dale'] = [-0.056, 0, -0.095, -0.115, '#scared', '#disgusting', -0.089, 'clinic', 'medical_office', 'doctor', 'doctor_office', 'nurse']
senticnet['dally'] = [0, 0, 0.849, -0.952, '#angry', '#disgusting', -0.6, 'dawdle', 'chat_up', 'toy', 'play', 'flirt']
senticnet['dam'] = [-0.03, 0.085, 0, 0.127, '#interesting', '#admirable', 0.061, 'small_stream', 'riverside', 'reservoir', 'big_lake', 'oceanside']
senticnet['damage'] = [-0.775, 0, -0.786, 0, '#sad', '#scared', -0.52, 'harm', 'hurt', 'cut_skin', 'bloody', 'ouch']
senticnet['damage_body'] = [-0.943, 0, 0.434, -0.949, '#sad', '#disgusting', -0.775, 'damage', 'injury', 'hurt', 'physical_pain', 'painful']
senticnet['damage_car'] = [-0.163, -0.079, -0.086, -0.163, '#sad', '#disgusting', -0.111, 'broken_car', 'road_rage', 'adjust_seat', 'car_crash', 'skid_mark']
senticnet['damage_ear'] = [-0.08, -0.047, 0.201, -0.419, '#angry', '#disgusting', -0.218, 'hear_loss', 'earring', 'tinnitus', 'loud_music', 'damaged_eardrums']
senticnet['damaged'] = [-0.753, 0, 0.68, -0.599, '#sad', '#angry', -0.677, 'battered', 'bedraggled', 'hurt', 'derelict', 'dilapidated']
senticnet['damaged_eardrums'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'hear_loss', 'high_music', 'deaf', 'loud_music', 'damage_ear']
senticnet['damages'] = [-0.822, 0, 0.672, -0.546, '#sad', '#angry', -0.68, 'amends', 'atonement', 'indemnification', 'redress', 'restitution']
senticnet['dame'] = [0.824, -0.715, 0, 0.732, '#joyful', '#admirable', 0.757, 'girl', 'miss', 'missy', 'young_lady', 'young_woman']
senticnet['damn'] = [-0.04, 0, 0, -0.05, '#sad', '#disgusting', -0.03, 'bad_luck', 'tundra', 'artic', 'mammal_family', 'bad_mood']
senticnet['damnable'] = [-0.62, 0, 0.627, -0.599, '#sad', '#angry', -0.615, 'execrable', 'blame', 'cursed', 'maledict', 'damn']
senticnet['damoiselle'] = [-0.81, 0, 0.885, -0.923, '#angry', '#disgusting', -0.873, 'miss', 'girl', 'damsel', 'demoiselle', 'maiden']
senticnet['damp'] = [0, -0.037, 0.05, -0.142, '#angry', '#disgusting', -0.052, 'humidity', 'wetness', 'moisture', 'humid', 'dank']
senticnet['dampness'] = [0.718, 0, 0, 0, '#joyful', '#joyful', 0.239, 'water_container', 'still_water', 'clean_water', 'water', 'cool_water']
senticnet['damsel'] = [0, 0, -0.875, -0.828, '#scared', '#disgusting', -0.568, 'female_human', 'female_person', 'niece', 'female', 'woman']
senticnet['dance'] = [0.922, 0, 0, 0.762, '#joyful', '#admirable', 0.561, 'slow_dance', 'old_dance', 'have_fun', 'dancer', 'ballroom_dance']
senticnet['dance_around'] = [0.02, 0.071, 0, 0.069, '#interesting', '#admirable', 0.053, 'make_face', 'wave_hand', 'dancing_in_rain', 'playful', 'studio']
senticnet['dance_club'] = [0.966, 0.921, 0, 0.892, '#joyful', '#interesting', 0.926, 'disco', 'nightclub', 'shop_complex', 'discotheque', 'fast_food_restaurant']
senticnet['dance_in_rain'] = [0.02, 0.071, 0, 0.069, '#interesting', '#admirable', 0.053, 'funny_moment', 'crazy_moment', 'sing_in_rain', 'playful', 'dance']
senticnet['dance_joy'] = [0, 0.091, 0, 0.073, '#interesting', '#admirable', 0.055, 'perform_service', 'arrive_mail', 'bind_agreement', 'need_money', 'responsible']
senticnet['dance_move'] = [0.073, 0, 0, 0.231, '#joyful', '#admirable', 0.101, 'swirl', 'sway', 'motion', 'rotate_movement', 'rotate']
senticnet['dance_music'] = [0.884, 0.942, 0, 0.743, '#joyful', '#interesting', 0.856, 'experience_pleasure', 'feel_emotion', 'watch_sunset', 'win_contest', 'listen_rock_music']
senticnet['dance_samba'] = [0.925, 0.993, 0, 0.832, '#joyful', '#interesting', 0.917, 'karaoke', 'dance', 'skate', 'jump_rope', 'play_frisbee']
senticnet['dance_step'] = [0.702, 0, 0, 0.703, '#joyful', '#admirable', 0.468, 'swirl', 'relate_music', 'dance', 'waltz', 'dance_move']
senticnet['dance_together'] = [0.96, 0.884, 0, 0.755, '#joyful', '#interesting', 0.866, 'kiss_other', 'sexual_arousal', 'fall_love', 'laugh', 'feel_happy']
senticnet['dance_type'] = [0.17, -0.048, 0.021, 0.124, '#joyful', '#admirable', 0.107, 'old_dance', 'swirl', 'pretzel', 'dance_move', 'dance']
senticnet['dance_well'] = [0.742, 0.911, 0, 0.956, '#interesting', '#admirable', 0.87, 'enter_contest', 'adjust_volume', 'knock', 'dance_music', 'old_dance']
senticnet['dancer'] = [0.965, 0, 0, 0.907, '#joyful', '#admirable', 0.624, 'dance', 'old_dance', 'slow_dance', 'stout', 'ballroom_dance']
senticnet['dancing'] = [0.584, -0.783, 0, 0.546, '#joyful', '#surprising', 0.638, 'acting', 'musical_performance', 'performing_art', 'dance', 'terpsichore']
senticnet['dancing_in_rain'] = [0.546, -0.969, 0, 0.533, '#joyful', '#surprising', 0.683, 'make_face', 'wave_hand', 'dance_around', 'playful', 'studio']
senticnet['dandelion'] = [0.886, 0.731, 0, 0, '#joyful', '#interesting', 0.539, 'blossom', 'daisy', 'daffodil', 'bloom', 'pollen']
senticnet['dander'] = [-0.15, 0.162, 0.596, -0.625, '#angry', '#disgusting', -0.403, 'hackles', 'umbrage', 'offense', 'ire', 'see_red']
senticnet['dandruff'] = [-0.195, -0.105, 0.041, -0.233, '#sad', '#disgusting', -0.121, 'hailstone', 'cold_hot', 'snow', 'monsoon', 'rain']
senticnet['dandruff_shampoo'] = [0.702, 0, 0, 0.703, '#joyful', '#admirable', 0.468, 'sculpt_gel', 'prevent_dandruff', 'hair_care_article', 'get_clean', 'hair_conditioner']
senticnet['danger'] = [-0.806, 0, -0.992, -0.813, '#scared', '#disgusting', -0.87, 'intolerance', 'illiteracy', 'big_monster', 'unsafe', 'menace']
senticnet['dangerous'] = [-0.09, 0, -0.147, 0, '#sad', '#scared', -0.079, 'destructive', 'violent', 'dangerous_health', 'illegal', 'danger']
senticnet['dangerous_activity'] = [0.094, 0.14, -0.053, -0.047, '#joyful', '#interesting', 0.045, 'danger', 'matter_lot', 'dangerous', 'currency_system', 'person']
senticnet['dangerous_animal'] = [-0.968, 0, 0.108, -0.908, '#sad', '#disgusting', -0.661, 'danger', 'dangerous_insect', 'dangerous_fly', 'shark', 'snake']
senticnet['dangerous_drive'] = [0.242, 0.07, 0, 0.099, '#joyful', '#admirable', 0.137, 'profitable', 'just_fun', 'taboo', 'creepy', 'competitive']
senticnet['dangerous_fly'] = [-0.968, 0, 0.108, -0.908, '#sad', '#disgusting', -0.661, 'wasp', 'dangerous_insect', 'poisonous_fly', 'dangerous_animal', 'poisonous']
senticnet['dangerous_health'] = [-0.216, 0.147, -0.275, 0.131, '#sad', '#scared', -0.071, 'hazardous_health', 'bad_health', 'uncontrollable', 'unhealthy', 'destructive']
senticnet['dangerous_human'] = [-0.074, 0.07, -0.138, 0, '#sad', '#scared', -0.047, 'burn_heat', 'really_hot', 'fire_burn', 'hot', 'burn_hot']
senticnet['dangerous_insect'] = [-0.968, 0, 0.108, -0.908, '#sad', '#disgusting', -0.661, 'wasp', 'poisonous_fly', 'dangerous_fly', 'dangerous_animal', 'poisonous']
senticnet['dangerous_item'] = [0, 0, -0.848, -0.927, '#scared', '#disgusting', -0.592, 'many_chemicals', 'many_cultures', 'venomous', 'many_countries', 'dangerous']
senticnet['dangerous_job'] = [-0.765, 0, 0, -0.961, '#sad', '#disgusting', -0.575, 'cause_suffer', 'leave_out', 'lose_team', 'hear_bad_news', 'disrespect']
senticnet['dangerous_person'] = [-0.981, 0, 0.677, -0.917, '#sad', '#disgusting', -0.858, 'evil_man', 'bad_person', 'murderer', 'killer', 'thief']
senticnet['dangerous_sport'] = [0, -0.036, 0, 0.149, '#surprising', '#admirable', 0.062, 'type_of_sport', 'rough_game', 'ball_sport', 'popular_sport', 'rough_sport']
senticnet['dangerous_to_person'] = [-0.943, 0, 0.427, -0.904, '#sad', '#disgusting', -0.758, 'electricity', 'poison', 'accident', 'fire', 'gun']
senticnet['dangerous_tool'] = [-0.956, 0, 0.618, -0.981, '#sad', '#disgusting', -0.852, 'gun', 'bullet', 'rifle', 'weapon', 'dangerous']
senticnet['dangerous_weapon'] = [-0.067, -0.046, 0, -0.204, '#sad', '#disgusting', -0.075, 'weapon', 'firearm', 'sharp_weapon', 'bayonet', 'handgun']
senticnet['dank'] = [0, -0.037, 0.05, -0.142, '#angry', '#disgusting', -0.052, 'humidity', 'wetness', 'damp', 'humid', 'moisture']
senticnet['dapper'] = [0, 0, -0.733, -0.706, '#scared', '#disgusting', -0.48, 'dashing', 'jaunty', 'natty', 'raffish', 'spiffy']
senticnet['dapperness'] = [0.853, -0.764, 0, 0.966, '#joyful', '#admirable', 0.861, 'elegance', 'jauntiness', 'rakishness', 'nattiness', 'chicness']
senticnet['dapple'] = [-0.583, 0, 0.561, -0.622, '#sad', '#disgusting', -0.589, 'spot', 'speckle', 'worn_spot', 'patch', 'fleck']
senticnet['dare'] = [0.754, 0, 0, 0.861, '#joyful', '#admirable', 0.538, 'clown', 'juggler', 'swing', 'halloween', 'acrobat']
senticnet['daredevil'] = [-0.558, 0, 0.967, -0.777, '#angry', '#disgusting', -0.767, 'madcap', 'swashbuckler', 'lunatic', 'hothead', 'tearaway']
senticnet['daredevilry'] = [0.775, -0.978, 0, 0.731, '#joyful', '#surprising', 0.828, 'boldness', 'daredeviltry', 'temerity', 'audacity', 'audaciousness']
senticnet['daredeviltry'] = [0.775, -0.978, 0, 0.731, '#joyful', '#surprising', 0.828, 'daredevilry', 'boldness', 'temerity', 'audacity', 'audaciousness']
senticnet['daring'] = [0.706, -0.87, 0, 0.968, '#surprising', '#admirable', 0.848, 'audacious', 'swaggering', 'adventuresome', 'venturesome', 'venturous']
senticnet['dark'] = [-0.722, 0, -0.894, 0, '#sad', '#scared', -0.539, 'dim', 'darkness', 'after_sundown', 'no_light', 'without_light']
senticnet['dark_alley'] = [0, 0, -0.823, -0.923, '#scared', '#disgusting', -0.582, 'prisoner_war_camp', 'war_museum', 'police_station', 'battlefield', 'shoot_range']
senticnet['dark_area'] = [-0.025, 0.096, 0, 0.079, '#interesting', '#admirable', 0.05, 'no_light', 'dark_light', 'block_light', 'parasol', 'without_light']
senticnet['dark_beer'] = [0.152, 0.099, -0.07, 0.107, '#joyful', '#admirable', 0.096, 'strong_taste', 'ale', 'cocktail', 'convulse', 'beer']
senticnet['dark_color'] = [-0.102, 0, 0, 0, '#sad', '#sad', -0.034, 'cool_color', 'primary_color', 'darkness', 'color', 'secondary_color']
senticnet['dark_corner'] = [0, 0, -0.801, -0.875, '#scared', '#disgusting', -0.559, 'cast', 'child_game', 'play_person', 'role_play', 'part_of_play']
senticnet['dark_light'] = [0, 0.114, 0, 0.08, '#interesting', '#admirable', 0.065, 'no_light', 'dark_area', 'purple', 'dark', 'hue_tint']
senticnet['dark_liquid'] = [0, 0, -0.093, 0, '#scared', '#scared', -0.031, 'black_liquid', 'oil', 'fossil', 'liquid_fuel', 'inert_gas']
senticnet['dark_magic'] = [-0.888, 0, 0.589, -0.856, '#sad', '#disgusting', -0.778, 'phantom', 'shadow', 'disbelief', 'illusion', 'fool']
senticnet['dark_outside'] = [-0.083, 0, -0.045, 0, '#sad', '#scared', -0.043, 'get_dark', 'night_time', 'day_end', 'sundown', 'dusk']
senticnet['dark_place'] = [-0.025, 0, 0, -0.052, '#sad', '#disgusting', -0.026, 'tunnel', 'cave', 'underground', 'top_tree', 'compost_pile']
senticnet['dark_red'] = [0.59, -0.866, 0, 0.561, '#joyful', '#surprising', 0.672, 'claret', 'wine', 'oxblood_red', 'red', 'redness']
senticnet['dark_road'] = [-0.956, 0, 0.159, -0.941, '#sad', '#disgusting', -0.685, 'road', 'narrow', 'poky', 'narrow_road', 'rough_road']
senticnet['dark_side'] = [-0.968, 0, 0.108, -0.908, '#sad', '#disgusting', -0.661, 'evil', 'darkness', 'dark', 'sun_down', 'shadow']
senticnet['darkness'] = [-0.118, 0.074, -0.129, 0, '#sad', '#scared', -0.058, 'sun_down', 'night', 'night_time', 'moon_star', 'without_light']
senticnet['darling'] = [0.59, -0.815, 0, 0.571, '#joyful', '#surprising', 0.659, 'preferred', 'wanted', 'admired', 'loved', 'precious']
senticnet['darn'] = [-0.564, 0, 0.917, -0.889, '#angry', '#disgusting', -0.79, 'troubleshoot', 'fiddle', 'fill', 'furbish_up', 'sole']
senticnet['dart'] = [0, 0, 0.919, -0.746, '#angry', '#disgusting', -0.555, 'knife_sharp', 'decline', 'dullness', 'unpleasantness', 'rim']
senticnet['dart_board'] = [0.035, -0.108, 0.026, 0, '#joyful', '#surprising', 0.039, 'helium_balloon', 'most_balls', 'ball', 'roller_coaster', 'horseshoe']
senticnet['dartboard'] = [0, 0.826, 0, 0.801, '#interesting', '#admirable', 0.542, 'loop', 'horse_shoes', 'ring', 'gray_hair', 'rotary_phone']
senticnet['darwin'] = [-0.049, 0.192, -0.079, 0.152, '#interesting', '#admirable', 0.072, 'hypothetical', 'supposition', 'scientific_statement', 'psychology', 'educate_guess']
senticnet['dash'] = [-0.863, 0, -0.8, 0, '#sad', '#scared', -0.554, 'dreadful', 'disquiet', 'scary', 'fearful', 'frighteningly']
senticnet['dashboard'] = [0, 0.73, 0, 0.802, '#interesting', '#admirable', 0.511, 'car_stereo', 'battery', 'seatbelt', 'spare_tire', 'brake_pedal']
senticnet['dashing'] = [0.716, -0.57, 0, 0.681, '#joyful', '#admirable', 0.656, 'vibrant', 'vivacious', 'con_brio', 'lively', 'spirited']
senticnet['dastard'] = [-0.956, 0, 0.825, -0.806, '#sad', '#angry', -0.862, 'cur', 'coward', 'craven', 'recreant', 'mortal']
senticnet['data'] = [0, 0.811, 0, 0.73, '#interesting', '#admirable', 0.514, 'fact', 'scientific_statement', 'report', 'educate_guess', 'hypothesis']
senticnet['data_processing'] = [0.783, -0.606, 0, 0.512, '#joyful', '#surprising', 0.634, 'refinement', 'blowing', 'processing', 'development', 'developing']
senticnet['database'] = [0, -0.812, 0, 0.758, '#surprising', '#admirable', 0.523, 'socialize', 'formal_introduction', 'business_card', 'professional', 'introduce_oneself']
senticnet['date'] = [0.863, -0.55, 0, 0.653, '#joyful', '#admirable', 0.689, 'day', 'maturity', 'maturity_date', 'due_date', 'birthday']
senticnet['date_activity'] = [0.793, 0.739, 0, 0, '#joyful', '#interesting', 0.511, 'recreation', 'pastime', 'leisure', 'leisure_time', 'enjoy_game']
senticnet['date_bread'] = [0.644, -0.946, 0, 0.729, '#surprising', '#admirable', 0.773, 'gem', 'banana_bread', 'quick_bread', 'nut_bread', 'oatcake']
senticnet['date_girl'] = [-0.101, 0, -0.056, 0, '#sad', '#scared', -0.052, 'fancy_girl', 'kiss_girl', 'wedge_door', 'jump_off_bridge', 'rake_leave']
senticnet['date_man'] = [-0.775, 0, 0, -0.86, '#sad', '#disgusting', -0.545, 'date_woman', 'marry_man', 'service_car', 'oil_hinge', 'voice_concern']
senticnet['date_woman'] = [-0.821, 0, 0, -0.758, '#sad', '#disgusting', -0.526, 'marry_man', 'service_car', 'date_man', 'oil_hinge', 'man_post']
senticnet['dated'] = [-0.874, 0, 0.83, -0.611, '#sad', '#angry', -0.772, 'out', 'unfashionable', 'stodgy', 'prehistoric', 'antique']
senticnet['dating'] = [0.577, -0.502, 0, 0.901, '#joyful', '#admirable', 0.66, 'show_ticket', 'dress_nicely', 'dinner', 'find_place_to_sit', 'restaurant']
senticnet['daub'] = [0.707, -0.527, 0, 0.634, '#joyful', '#admirable', 0.623, 'spot', 'smirch', 'blotch', 'smudge', 'blot']
senticnet['daughter'] = [0, 0.981, 0, 0.916, '#interesting', '#admirable', 0.632, 'foster_kid', 'adopt', 'relation', 'sister', 'cousin']
senticnet['daunt'] = [-0.994, 0, -0.945, 0, '#sad', '#scared', -0.646, 'scarily', 'scared', 'frighten_away', 'scare_away', 'frighten_off']
senticnet['dauntless'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'intrepidly', 'hardy', 'fearlessness', 'fearlessly', 'unafraid']
senticnet['dauntlessly'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'intrepidly', 'hardy', 'fearlessness', 'fearlessly', 'unafraid']
senticnet['dauntlessness'] = [-0.948, 0, 0.745, -0.979, '#sad', '#disgusting', -0.891, 'nerve', 'fearlessness', 'heart', 'braveness', 'intrepidity']
senticnet['dawdler'] = [-0.648, 0, 0.879, -0.98, '#angry', '#disgusting', -0.836, 'drone', 'poke', 'straggler', 'laggard', 'lagger']
senticnet['dawn'] = [0.02, 0.067, 0, 0, '#joyful', '#interesting', 0.029, 'sunrise', 'light_in_sky', 'begin_day', 'daylight', 'sun']
senticnet['day'] = [0.936, -0.796, 0, 0.552, '#joyful', '#surprising', 0.761, 'today', 'day_of_month', 'date', 'tomorrow', 'yesterday']
senticnet['day_end'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'dusk', 'nightfall', 'sundown', 'sunset', 'twilight']
senticnet['day_job'] = [-0.05, 0.197, -0.119, 0.184, '#interesting', '#admirable', 0.071, 'question_ask', 'office_job', 'task', 'obligation', 'chore']
senticnet['day_month'] = [0, -0.003, 0.063, -0.037, '#angry', '#disgusting', -0.032, 'thirty', 'date', 'calendar', 'day', 'time_measurement']
senticnet['day_of_month'] = [0.585, -0.928, 0, 0.508, '#joyful', '#surprising', 0.674, 'day', 'maturity', 'maturity_date', 'due_date', 'birthday']
senticnet['day_of_week'] = [0.867, 0.821, 0, 0, '#joyful', '#interesting', 0.563, 'friday', 'monday', 'fortnight', 'weekend', 'midweek']
senticnet['day_off'] = [0.981, 0.791, 0, 0, '#joyful', '#interesting', 0.591, 'retirement', 'make_oneself_happy', 'time_relax', 'make_others_happy', 'win_lottery']
senticnet['day_part'] = [-0.048, 0.088, 0.013, 0.069, '#interesting', '#admirable', 0.032, 'nightfall', 'sunrise', 'time_day', 'day_end', 'late_time']
senticnet['day_period'] = [0, -0.026, 0.085, -0.094, '#angry', '#disgusting', -0.051, 'time_pass', 'watch_clock', 'tie_score', 'keep_track_time', 'even_out']
senticnet['daycare'] = [-0.048, 0.088, 0.013, 0.069, '#interesting', '#admirable', 0.032, 'kindergarden', 'nursery_school', 'nursery', 'child', 'asylum']
senticnet['daydream'] = [-0.097, 0, 0, -0.121, '#sad', '#disgusting', -0.073, 'desire_travel', 'think_critically', 'keep_word', 'act_out', 'turn_light']
senticnet['daydreamer'] = [-0.644, 0, 0.524, -0.598, '#sad', '#disgusting', -0.589, 'bum', 'dreamer', 'stargazer', 'escapist', 'wishful_thinker']
senticnet['daydreaming'] = [0.846, -0.928, 0, 0.504, '#joyful', '#surprising', 0.759, 'woolgathering', 'revery', 'daydream', 'reverie', 'dreaming']
senticnet['daylight'] = [0.02, 0.067, 0, 0, '#joyful', '#interesting', 0.029, 'sunrise', 'light_in_sky', 'dawn', 'begin_day', 'sun']
senticnet['daze'] = [-0.743, 0, 0, -0.739, '#sad', '#disgusting', -0.494, 'scared', 'fulgurant', 'eye_popping', 'fulgurous', 'dazzling']
senticnet['dazed'] = [0, 0, 0.719, -0.969, '#angry', '#disgusting', -0.563, 'stun', 'stunned', 'stupefied', 'stupefy', 'dumbstricken']
senticnet['dazzling'] = [0.739, -0.918, 0, 0, '#joyful', '#surprising', 0.552, 'surprise', 'fulgurant', 'eye-popping', 'fulgurous', 'bedaze']
senticnet['dazzlingly'] = [-0.984, 0, 0, -0.763, '#sad', '#disgusting', -0.582, 'daze', 'fulgurant', 'eye-popping', 'fulgurous', 'dazzling']
senticnet['de_rigueur'] = [0.644, -0.946, 0, 0.729, '#surprising', '#admirable', 0.773, 'bounden', 'incumbent_on', 'obligatory', 'compulsory', 'mandatory']
senticnet['deacon'] = [0.546, -0.768, 0, 0.74, '#surprising', '#admirable', 0.685, 'exorcist', 'holy_order', 'acolyte', 'anagnost', 'doorkeeper']
senticnet['dead'] = [0, 0, -0.753, -0.749, '#scared', '#disgusting', -0.501, 'dead_person', 'death', 'die_in_war', 'dead_leaf', 'dead_cow']
senticnet['dead_animal'] = [-0.888, 0, 0.589, -0.856, '#sad', '#disgusting', -0.778, 'dead_person', 'death', 'dead_cow', 'dead_leaf', 'dead']
senticnet['dead_body'] = [-0.092, 0, -0.1, -0.196, '#scared', '#disgusting', -0.129, 'dead_person', 'morgue', 'coffin', 'headstone', 'bury_dead_person']
senticnet['dead_cow'] = [0, 0, -0.753, -0.749, '#scared', '#disgusting', -0.501, 'dead_person', 'death', 'dead_animal', 'dead_leaf', 'dead']
senticnet['dead_fish'] = [0, 0, 0.021, -0.053, '#angry', '#disgusting', -0.025, 'driftwood', 'tidal_wave', 'seashell', 'titanic', 'jelly_fish']
senticnet['dead_hungry'] = [-0.828, 0, 0, -0.742, '#sad', '#disgusting', -0.523, 'need_food', 'a_little_hungry', 'snack', 'prepare_food', 'dead']
senticnet['dead_leaf'] = [-0.791, 0, 0, -0.946, '#sad', '#disgusting', -0.579, 'fallen_leaf', 'pine_cone', 'detritus', 'autumn', 'fall']
senticnet['dead_person'] = [-0.09, 0.069, -0.148, -0.14, '#scared', '#disgusting', -0.103, 'dead_body', 'morgue', 'corpse', 'cadaver', 'casket']
senticnet['dead_place'] = [-0.147, 0.123, -0.159, -0.043, '#sad', '#scared', -0.075, 'death_place', 'burial_place', 'headstone', 'bury_dead', 'bury']
senticnet['dead_president'] = [0, 0.237, 0.035, 0.099, '#interesting', '#admirable', 0.1, 'dollar_cent', 'paper_currency', 'four_quarters', 'denomination', 'dollar_sign']
senticnet['dead_reckoning'] = [-0.046, 0.127, -0.121, 0.223, '#interesting', '#admirable', 0.061, 'underestimation', 'underrating', 'underreckoning', 'approximation', 'underestimate']
senticnet['dead_skin'] = [-0.041, -0.016, 0, -0.092, '#sad', '#disgusting', -0.039, 'sweat', 'feces', 'urine', 'bodily_waste', 'shit']
senticnet['dead_soul'] = [-0.793, 0, 0.885, -0.768, '#sad', '#angry', -0.815, 'infernal', 'mortal', 'zombi', 'zombie', 'living_dead']
senticnet['dead_stay_dead'] = [0, 0.833, 0, 0.919, '#interesting', '#admirable', 0.584, 'dead', 'sentence_end', 'reason_why', 'negative', 'no_end']
senticnet['dead_tree'] = [0, -0.026, 0.085, -0.094, '#angry', '#disgusting', -0.051, 'tree_wood', 'forest', 'sideways', 'deforestation', 'wood']
senticnet['dead_weight'] = [-0.939, 0, 0.922, -0.796, '#sad', '#angry', -0.886, 'onus', 'burden', 'encumbrance', 'incumbrance', 'load']
senticnet['deadening'] = [-0.661, 0, 0.594, -0.675, '#sad', '#disgusting', -0.643, 'boring', 'uninteresting', 'irksome', 'tiresome', 'wearisome']
senticnet['deadeye'] = [0.801, -0.874, 0, 0.916, '#surprising', '#admirable', 0.864, 'rifleman', 'crack_shot', 'sniper', 'shot', 'shooter']
senticnet['deadline'] = [0.893, 0.746, 0, 0, '#joyful', '#interesting', 0.546, 'amount_owe', 'percentage', 'money_payment', 'money_owe', 'due']
senticnet['deadly'] = [0, 0, -0.712, 0, '#scared', '#scared', -0.237, 'hazardous', 'violent', 'take_life', 'threat', 'lethal']
senticnet['deadly_sin'] = [0, 0, 0.753, -0.72, '#angry', '#disgusting', -0.491, 'sinful', 'human_emotion', 'want_badly', 'demand', 'yearn']
senticnet['deadness'] = [-0.812, 0, 0.83, -0.978, '#angry', '#disgusting', -0.873, 'inelasticity', 'rigidity', 'rigidness', 'stiffness', 'physical_property']
senticnet['deadwood'] = [-0.775, 0, 0.9, -0.799, '#angry', '#disgusting', -0.825, 'embarrassment', 'fifth_wheel', 'redundance', 'overplus', 'plethora']
senticnet['deaf'] = [-0.946, 0, 0, 0, '#sad', '#sad', -0.315, 'drive_recklessly', 'discord', 'mute', 'deny', 'oneself']
senticnet['deaf_person'] = [-0.691, 0, 0.99, -0.716, '#angry', '#disgusting', -0.799, 'mute', 'mortal', 'lip_reader', 'person', 'individual']
senticnet['deafening'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'hear_loud_sound', 'roaring', 'ear_splitting', 'rowdy', 'noisy']
senticnet['deafness'] = [0.881, -0.8, 0, 0, '#joyful', '#surprising', 0.56, 'like', 'change_mood', 'enjoy_music', 'hear_loss', 'earring']
senticnet['deal'] = [-0.042, 0.274, -0.153, 0.278, '#interesting', '#admirable', 0.119, 'business_deal', 'trade', 'exchange', 'bargain', 'offer']
senticnet['deal_card'] = [-0.767, 0, -0.939, 0, '#sad', '#scared', -0.569, 'smoke_cigar', 'deal_card_player', 'smoke_joint', 'stand_alone', 'explain_everything']
senticnet['deal_card_player'] = [-0.98, 0, -0.78, 0, '#sad', '#scared', -0.587, 'forward_email', 'stand_alone', 'explain_everything', 'bridge_difference', 'mind_store']
senticnet['deal_drug'] = [0, 0, 0.937, -0.879, '#angry', '#disgusting', -0.605, 'make_porn', 'sell_new_book', 'go_off_strike', 'go_public', 'open_business']
senticnet['deal_gently'] = [0.76, -0.593, 0, 0.713, '#joyful', '#admirable', 0.689, 'spare_enemy', 'magnanimous', 'generous', 'forgiving', 'spareness']
senticnet['dear'] = [0.94, 0.864, 0, 0, '#joyful', '#interesting', 0.601, 'respect', 'expect', 'kind', 'affection', 'regard']
senticnet['dearie'] = [0.591, -0.769, 0, 0.66, '#surprising', '#admirable', 0.673, 'darling', 'pet', 'favorite', 'favourite', 'macushla']
senticnet['dearness'] = [0.902, -0.726, 0, 0.919, '#joyful', '#admirable', 0.849, 'preciousness', 'costliness', 'expensiveness', 'cost', 'lavishness']
senticnet['dearth'] = [-0.543, 0, 0.92, -0.843, '#angry', '#disgusting', -0.769, 'deficiency', 'demand', 'mineral_deficiency', 'famine', 'need']
senticnet['death'] = [-0.992, 0, -0.852, 0, '#sad', '#scared', -0.615, 'loss_oflife', 'chest_pain', 'die', 'tumor', 'end_life']
senticnet['death_adder'] = [-0.517, 0, 0.582, -0.976, '#angry', '#disgusting', -0.692, 'elapid', 'ophidian', 'serpent', 'krait', 'taipan']
senticnet['death_bed'] = [-0.952, 0, 0.198, -0.968, '#sad', '#disgusting', -0.706, 'grave', 'corpse', 'coffin', 'tomb', 'dead_person']
senticnet['death_destruction'] = [-0.731, 0, -0.913, 0, '#sad', '#scared', -0.548, 'kill', 'murder', 'destroy_live', 'defend_oneself', 'get_rid_of_enemy']
senticnet['death_knell'] = [-0.527, 0, 0.986, -0.943, '#angry', '#disgusting', -0.819, 'omen', 'portent', 'presage', 'prognostic', 'prognostication']
senticnet['death_love'] = [-0.591, -0.06, -0.355, -0.252, '#sad', '#scared', -0.379, 'anguish', 'bad_feeling', 'get_fired', 'disgrace', 'feel_stressed']
senticnet['death_penalty'] = [-0.307, -0.017, -0.186, -0.181, '#sad', '#scared', -0.219, 'capital_punishment', 'send_to_prison', 'imprison', 'die', 'feel_remorse']
senticnet['death_place'] = [0, 0, -0.753, -0.749, '#scared', '#disgusting', -0.501, 'dead_place', 'burial_place', 'headstone', 'bury_dead', 'bury']
senticnet['death_row'] = [0, 0, 0.869, 0, '#angry', '#angry', -0.29, 'another_planet', 'loose_end', 'car_race', 'auction', 'mortuary']
senticnet['death_sentence'] = [-0.728, 0, -0.817, 0, '#sad', '#scared', -0.515, 'revenge', 'harden_criminal', 'arrest', 'send_to_jail', 'felony']
senticnet['death_wish'] = [-0.811, 0, 0, 0, '#sad', '#sad', -0.27, 'take_charge', 'anti', 'go_against', 'campaign', 'file_complaint']
senticnet['debacle'] = [-0.647, 0, 0.717, -0.983, '#angry', '#disgusting', -0.782, 'licking', 'lurch', 'whitewash', 'finish', 'failure']
senticnet['debar'] = [-0.88, 0, 0.903, -0.504, '#sad', '#angry', -0.762, 'send_down', 'rusticate', 'expel', 'throw_out', 'kick_out']
senticnet['debase'] = [-0.604, 0, 0.872, -0.567, '#sad', '#angry', -0.681, 'suborn', 'modify', 'poison', 'lead_astray', 'alter']
senticnet['debasement'] = [0, 0, 0.828, -0.717, '#angry', '#disgusting', -0.515, 'impureness', 'dirtiness', 'pollution', 'taint', 'adulteration']
senticnet['debasing'] = [-0.918, 0, 0.907, -0.601, '#sad', '#angry', -0.809, 'opprobrious', 'dishonorable', 'disgraceful', 'degrading', 'inglorious']
senticnet['debatable'] = [0.544, -0.693, 0, 0.658, '#surprising', '#admirable', 0.632, 'shakable', 'shakeable', 'challengeable', 'disputable', 'contestable']
senticnet['debate'] = [0.915, -0.847, 0, 0.778, '#joyful', '#surprising', 0.847, 'fall_out', 'altercate', 'wrangle', 'spat', 'brawl']
senticnet['debate_politics'] = [0, 0, 0.933, -0.887, '#angry', '#disgusting', -0.607, 'opinioned', 'let_heard', 'conquer_opponent', 'dicussion', 'debate']
senticnet['debauch'] = [0, 0, 0.793, -0.791, '#angry', '#disgusting', -0.528, 'pervert', 'corrupt', 'deprave', 'warp', 'subvert']
senticnet['debilitating'] = [-0.8, 0, 0, -0.942, '#sad', '#disgusting', -0.581, 'draining', 'exhausting', 'debilitative', 'enervating', 'enfeebling']
senticnet['debilitative'] = [0.753, -0.745, 0, 0.587, '#joyful', '#surprising', 0.695, 'draining', 'exhausting', 'debilitating', 'enervating', 'enfeebling']
senticnet['debility'] = [-0.877, 0, 0, -0.963, '#sad', '#disgusting', -0.613, 'cachexia', 'cachexy', 'wasting', 'unfitness', 'asthenia']
senticnet['debit'] = [-0.05, 0.26, -0.082, 0.142, '#interesting', '#admirable', 0.09, 'expense', 'afford', 'payment', 'cost', 'owe']
senticnet['debit_card'] = [-0.05, 0.14, 0.015, 0.082, '#interesting', '#admirable', 0.052, 'cash', 'cash_pay', 'need_earn_money', 'open_wallet', 'earn_wage']
senticnet['debris_storm'] = [-0.798, 0, 0.59, -0.567, '#sad', '#angry', -0.652, 'debris_surge', 'surge', 'flowing', 'onrush', 'flow']
senticnet['debris_surge'] = [-0.798, 0, 0.59, -0.567, '#sad', '#angry', -0.652, 'surge', 'debris_storm', 'flowing', 'onrush', 'flow']
senticnet['debt'] = [-0.959, 0, -0.708, -0.966, '#sad', '#disgusting', -0.878, 'bribe', 'owe', 'payment', 'bribe_police', 'afford']
senticnet['debug'] = [0.918, 0.988, 0, 0, '#joyful', '#interesting', 0.635, 'learn_program_language', 'write_code', 'learn_program', 'a_lot_of_time', 'learn_computer_language']
senticnet['debut'] = [0.093, -0.188, -0.046, 0, '#joyful', '#surprising', 0.078, 'streamer', 'dance', 'balloon', 'comedy', 'basketball']
senticnet['decade'] = [-0.888, 0, 0, -0.78, '#sad', '#disgusting', -0.556, 'friday', 'day_of_week', 'monday', 'sadness', 'slack']
senticnet['decadence'] = [-0.566, 0, 0.512, -0.506, '#sad', '#angry', -0.528, 'depth', 'humiliation', 'degeneration', 'abjection', 'decadency']
senticnet['decadency'] = [-0.566, 0, 0.512, -0.506, '#sad', '#angry', -0.528, 'depth', 'humiliation', 'degeneration', 'decadence', 'abjection']
senticnet['decanter'] = [0.703, 0.913, 0, 0, '#joyful', '#interesting', 0.539, 'ferment_grape_juice', 'chef_special', 'cuisine', 'fine_dining', 'bottle_wine']
senticnet['decay'] = [-0.09, -0.006, -0.164, -0.096, '#scared', '#disgusting', -0.115, 'dig_up', 'non-renewable_resource', 'fuel_source', 'radiation', 'mine_ore']
senticnet['deceased'] = [-0.547, 0, 0.962, -0.728, '#angry', '#disgusting', -0.746, 'infernal', 'mortal', 'zombi', 'zombie', 'living_dead']
senticnet['deceased_person'] = [-0.65, 0, 0.597, -0.898, '#sad', '#disgusting', -0.715, 'infernal', 'mortal', 'zombi', 'zombie', 'living_dead']
senticnet['decedent'] = [-0.726, 0, 0.934, -0.723, '#sad', '#angry', -0.794, 'infernal', 'mortal', 'zombi', 'zombie', 'living_dead']
senticnet['deceit'] = [0, 0, 0.738, -0.848, '#angry', '#disgusting', -0.529, 'falsehood', 'dishonesty', 'untruth', 'fallacy', 'false']
senticnet['deceitful'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'strong_feeling', 'think_process', 'make_sense', 'thoughtfulness', 'acknowledge']
senticnet['deceitfulness'] = [-0.837, 0, 0.802, -0.521, '#sad', '#angry', -0.72, 'dishonesty', 'disingenuousness', 'craftiness', 'guile', 'artfulness']
senticnet['deceive'] = [0, 0, 0.87, -0.948, '#angry', '#disgusting', -0.606, 'deception', 'distrust', 'fool', 'against_law', 'hide_truth']
senticnet['deceiver'] = [0.527, -0.582, 0, 0.784, '#surprising', '#admirable', 0.631, 'slicker', 'beguiler', 'roper', 'shill', 'decoy']
senticnet['december'] = [0.768, 0.81, 0, 0.819, '#interesting', '#admirable', 0.799, 'buy_christmas_present', 'christmas', 'winter_time', 'annual_celebration', 'holiday']
senticnet['decency'] = [0.686, -0.631, 0, 0.959, '#joyful', '#admirable', 0.759, 'propriety', 'properness', 'correctitude', 'modesty', 'modestness']
senticnet['decent'] = [0.666, -0.831, 0, 0.896, '#surprising', '#admirable', 0.798, 'nice', 'respectable', 'solid', 'presentable', 'upstanding']
senticnet['deception'] = [0, 0, 0.858, -0.817, '#angry', '#disgusting', -0.558, 'deceive', 'against_law', 'false', 'fool', 'trick']
senticnet['decibel'] = [0.036, 0, 0.02, 0.112, '#joyful', '#admirable', 0.043, 'loudness', 'sound', 'noise', 'audio', 'loud_sound']
senticnet['decide'] = [-0.04, 0.339, -0.134, 0.252, '#interesting', '#admirable', 0.139, 'choose', 'select', 'selection', 'decision', 'make_choice']
senticnet['decide_buy'] = [-0.047, 0, 0.03, 0, '#sad', '#angry', -0.026, 'use_atm', 'carry_wallet', 'take_out_wallet', 'carry_credit_card', 'look_price']
senticnet['decide_case'] = [-0.038, 0.182, -0.05, 0.096, '#interesting', '#admirable', 0.063, 'consider_evidence', 'serve_jury', 'determine_guilt_innocence', 'judgment', 'examine_evidence']
senticnet['decide_eat'] = [-0.038, 0.182, -0.05, 0.096, '#interesting', '#admirable', 0.063, 'choose_eat', 'find_restaurant', 'order_lunch', 'decide_want_eat', 'go_kitchen']
senticnet['decide_guilt'] = [0, 0.144, 0, 0.077, '#interesting', '#admirable', 0.074, 'negotiator', 'try_case', 'jury', 'become_judge', 'juror']
senticnet['decide_order'] = [-0.026, 0, 0.046, -0.061, '#angry', '#disgusting', -0.044, 'place_order', 'order_dinner', 'order_fry', 'read_menu', 'order_hamburger']
senticnet['decide_to_go'] = [-0.055, 0.077, 0, 0.058, '#interesting', '#admirable', 0.027, 'buy_plane_ticket', 'talk_to_travel_agent', 'decide_want_go', 'plan_time', 'buy_airplane_ticket']
senticnet['decide_to_go_first'] = [0, 0, 0, 0.703, '#admirable', '#admirable', 0.234, 'choose_destination', 'book_hotel_room', 'talk_to_travel_agent', 'make_reservation', 'pay_fee']
senticnet['decide_want'] = [0.027, 0.151, 0, 0.078, '#interesting', '#admirable', 0.085, 'pay_grocery', 'get_turn', 'take_number', 'come_early', 'find_line']
senticnet['decide_want_eat'] = [0.854, 0.659, 0, 0.545, '#joyful', '#interesting', 0.686, 'find_restaurant', 'obtain_food', 'bite_food', 'order_lunch', 'decide_eat']
senticnet['decide_want_go'] = [-0.055, 0.077, 0, 0.058, '#interesting', '#admirable', 0.027, 'talk_to_travel_agent', 'decide_to_go', 'buy_plane_ticket', 'look_map', 'buy_airplane_ticket']
senticnet['deciding'] = [0.698, -0.988, 0, 0.651, '#joyful', '#surprising', 0.779, 'fateful', 'decisive', 'determinant', 'determinative', 'determining']
senticnet['decimated'] = [0, 0, -0.819, -0.995, '#scared', '#disgusting', -0.605, 'annihilate', 'eradicate', 'extinguish', 'eliminate', 'wipe_out']
senticnet['decipherer'] = [0.615, -0.935, 0, 0.812, '#surprising', '#admirable', 0.787, 'intellectual', 'intellect', 'cryptanalyst', 'cryptographer', 'cryptologist']
senticnet['decipherment'] = [0.634, -0.738, 0, 0.974, '#surprising', '#admirable', 0.782, 'decompression', 'cryptography', 'coding', 'secret_writing', 'steganography']
senticnet['decision'] = [-0.062, 0.32, -0.101, 0.248, '#interesting', '#admirable', 0.135, 'decide', 'select', 'selection', 'make_choice', 'choice']
senticnet['decision_making'] = [0, 0.197, -0.069, 0.233, '#interesting', '#admirable', 0.12, 'make_rule', 'decision', 'stubborn', 'advise', 'make_decision']
senticnet['decisive'] = [0.698, -0.988, 0, 0.651, '#joyful', '#surprising', 0.779, 'fateful', 'deciding', 'determinant', 'determinative', 'determining']
senticnet['decisiveness'] = [0.96, -0.926, 0, 0.606, '#joyful', '#surprising', 0.831, 'resoluteness', 'firmness_of_purpose', 'firmness', 'resolve', 'resolution']
senticnet['deck'] = [0.831, -0.821, 0, 0.826, '#joyful', '#admirable', 0.826, 'upper_deck', 'freeboard_upper_deck', 'weather_upper_deck', 'shelter_upper_deck', 'boat_upper_deck']
senticnet['deck_card'] = [0, -0.038, 0, 0.075, '#surprising', '#admirable', 0.038, 'poker_chip', 'go_casino', 'toy_car', 'yo-yo', 'poker']
senticnet['declaim'] = [0.584, -0.938, 0, 0.927, '#surprising', '#admirable', 0.816, 'elocute', 'perorate', 'perform', 'orate', 'spout']
senticnet['declamation'] = [-0.912, 0, 0.704, -0.702, '#sad', '#angry', -0.773, 'rant', 'raving', 'harangue', 'ranting', 'tirade']
senticnet['declarable'] = [0.683, -0.553, 0, 0.552, '#joyful', '#surprising', 0.596, 'accepted', 'recognized', 'acknowledged', 'given', 'putative']
senticnet['declare'] = [0, -0.864, 0, 0.709, '#surprising', '#admirable', 0.524, 'remark', 'reply', 'oath', 'announcement', 'mention']
senticnet['declare_war'] = [-0.091, 0, -0.064, -0.199, '#sad', '#disgusting', -0.118, 'arm_oneself', 'prepare_army', 'battle', 'fight_man', 'siege']
senticnet['declared'] = [0.843, -0.935, 0, 0.952, '#surprising', '#admirable', 0.91, 'asserted', 'avowed', 'professed', 'alleged', 'announced']
senticnet['declination'] = [-0.632, 0, 0.663, -0.828, '#angry', '#disgusting', -0.708, 'wreck', 'twilight', 'neglect', 'disuse', 'condition']
senticnet['decline'] = [-0.069, 0, 0.043, 0, '#sad', '#angry', -0.037, 'downward', 'angle', 'incline_plane', 'water_drip', 'mountain_side']
senticnet['decline_in_quality'] = [-0.952, 0, 0.862, -0.973, '#sad', '#disgusting', -0.929, 'decline', 'slack', 'slump', 'falloff', 'falling_off']
senticnet['declutter'] = [0, 0, 0, 0.897, '#admirable', '#admirable', 0.299, 'organize_life', 'clear_think', 'neatness', 'sort', 'organizational_skill']
senticnet['decoding'] = [0.972, -0.863, 0, 0.588, '#joyful', '#surprising', 0.808, 'decompression', 'cryptography', 'coding', 'secret_writing', 'steganography']
senticnet['decompose'] = [-0.227, 0, -0.199, 0, '#sad', '#scared', -0.142, 'collide', 'lift_leg', 'feel_terrible', 'travel_through_space', 'fly_around']
senticnet['decomposition'] = [-0.477, 0, -0.462, -0.041, '#sad', '#scared', -0.327, 'sadness', 'deep_sadness', 'psychoneurosis', 'lament', 'feel_sorry']
senticnet['decompress'] = [-0.519, 0, 0.738, -0.834, '#angry', '#disgusting', -0.697, 'relax', 'loosen_up', 'unbend', 'unwind', 'sit_back']
senticnet['decompression'] = [0.634, -0.738, 0, 0.974, '#surprising', '#admirable', 0.782, 'decipherment', 'cryptography', 'coding', 'secret_writing', 'steganography']
senticnet['decontaminate'] = [-0.604, 0, 0.992, -0.948, '#angry', '#disgusting', -0.848, 'wash', 'lather', 'floss', 'cleanse', 'bathe']
senticnet['decorate'] = [0.092, 0, -0.057, 0.158, '#joyful', '#admirable', 0.064, 'home_improvement', 'please_eye', 'decoration', 'decorate_room', 'cover_wall']
senticnet['decorate_home'] = [0.875, 0, 0, 0.962, '#joyful', '#admirable', 0.612, 'make_easy', 'strum', 'sing_dance', 'play_song', 'backup']
senticnet['decorate_house'] = [0.216, 0.154, -0.055, 0.342, '#joyful', '#admirable', 0.219, 'own_space', 'nice_house', 'rich_house', 'another_house', 'place_to_live']
senticnet['decorate_oneself'] = [0.075, 0.078, -0.075, 0.185, '#interesting', '#admirable', 0.088, 'display_wealth', 'propose_marriage', 'marriage_ceremony', 'engage', 'engagement']
senticnet['decorate_room'] = [0.046, 0.092, 0, 0.089, '#interesting', '#admirable', 0.076, 'creativity', 'creative', 'wall_decoration', 'decorate_wall', 'please_eye']
senticnet['decorate_wall'] = [0.046, 0.092, 0, 0.089, '#interesting', '#admirable', 0.076, 'creativity', 'creative', 'wall_decoration', 'decorate_room', 'design_wall']
senticnet['decorate_yard'] = [0, -0.097, 0.035, 0.1, '#surprising', '#admirable', 0.054, 'dig_dirt', 'plant_flower', 'cut_grass', 'plant_garden', 'grow_flower']
senticnet['decorated'] = [0.558, -0.946, 0, 0.837, '#surprising', '#admirable', 0.78, 'buttony', 'ruffled', 'fringed', 'tessellated', 'mounted']
senticnet['decoration'] = [0.059, -0.017, 0, 0.109, '#joyful', '#admirable', 0.062, 'decorate', 'home_improvement', 'accessorize_outfit', 'decorative', 'cover_up']
senticnet['decorative'] = [0.06, 0, 0, 0.23, '#joyful', '#admirable', 0.097, 'please_eye', 'two-dimensional', 'colorful', 'beautiful', 'visible']
senticnet['decorator'] = [0, 0.098, 0, 0.144, '#interesting', '#admirable', 0.081, 'wall_cover', 'cover_wall', 'latex', 'two-dimensional', 'home_improvement']
senticnet['decorousness'] = [0.85, -0.858, 0, 0.712, '#joyful', '#surprising', 0.807, 'decency', 'decorum', 'correctitude', 'correctness', 'seemliness']
senticnet['decorum'] = [0.85, -0.858, 0, 0.712, '#joyful', '#surprising', 0.807, 'decency', 'correctitude', 'decorousness', 'correctness', 'seemliness']
senticnet['decoupage'] = [0.528, -0.606, 0, 0.724, '#surprising', '#admirable', 0.619, 'gastronomy', 'arts_and_crafts', 'carving', 'artistic_creation', 'ceramics']
senticnet['decouple'] = [-0.989, 0, 0.737, -0.922, '#sad', '#disgusting', -0.883, 'separate', 'severalize', 'contrast', 'differentiate', 'dissociate']
senticnet['decoy'] = [0.527, -0.582, 0, 0.784, '#surprising', '#admirable', 0.631, 'slicker', 'beguiler', 'roper', 'shill', 'deceiver']
senticnet['decrease'] = [-0.129, -0.058, 0, -0.134, '#sad', '#disgusting', -0.068, 'diminish', 'reduce', 'lower', 'lower_music', 'low_level']
senticnet['decrease_hunger'] = [0.896, 0, 0, 0.809, '#joyful', '#admirable', 0.568, 'get_fat', 'eat_food', 'feel_satisfied', 'obesity', 'eat_better']
senticnet['decreased'] = [-0.978, 0, 0.584, -0.789, '#sad', '#disgusting', -0.784, 'remittent', 'diminished', 'weakened', 'faded', 'small']
senticnet['decreasing'] = [-0.983, 0, 0.962, -0.956, '#sad', '#angry', -0.967, 'depreciative', 'depreciatory', 'falling', 'depreciating', 'detractive']
senticnet['decree'] = [0, 0.173, -0.091, 0.092, '#interesting', '#admirable', 0.058, 'regulation', 'march_rear', 'legislation', 'edict', 'law']
senticnet['decrement'] = [-0.129, -0.058, 0, -0.134, '#sad', '#disgusting', -0.068, 'reduction', 'diminution', 'decrease', 'inferior', 'reduce']
senticnet['decryption'] = [0.584, -0.726, 0, 0.742, '#surprising', '#admirable', 0.684, 'decompression', 'cryptography', 'coding', 'secret_writing', 'steganography']
senticnet['dedicate'] = [0.693, -0.699, 0, 0.714, '#surprising', '#admirable', 0.702, 'vow', 'consecrate', 'apply', 'rededicate', 'use']
senticnet['dedication'] = [0, 0, 0, 0.946, '#admirable', '#admirable', 0.315, 'persistence', 'effort', 'eat_properly', 'healthy_environment', 'physical_effort']
senticnet['deduce'] = [-0.091, 0.106, 0, 0.093, '#interesting', '#admirable', 0.036, 'figure_out', 'revelation', 'arrive_conclusion', 'resolve_problem', 'come_conclusion']
senticnet['deduction'] = [0.064, 0.4, -0.155, 0.308, '#interesting', '#admirable', 0.206, 'honesty', 'determine', 'compare', 'depend', 'right']
senticnet['deed'] = [-0.028, 0.202, -0.156, 0.266, '#interesting', '#admirable', 0.095, 'heap', 'let', 'allow', 'come', 'mimic']
senticnet['deem'] = [0.862, -0.611, 0, 0.549, '#joyful', '#surprising', 0.674, 'consider', 'view', 'regard', 'reckon', 'see']
senticnet['deep'] = [-0.028, 0.202, -0.156, 0.266, '#interesting', '#admirable', 0.095, 'sea', 'ocean', 'color', 'deep_blue', 'blue']
senticnet['deep_blue'] = [-0.028, 0.202, -0.156, 0.266, '#interesting', '#admirable', 0.095, 'sea', 'ocean', 'color', 'deep', 'blue']
senticnet['deep_brown'] = [0, 0, -0.827, -0.819, '#scared', '#disgusting', -0.549, 'buff', 'chestnut', 'chocolate', 'coffee', 'brownness']
senticnet['deep_fried'] = [-0.98, 0, 0.594, -0.988, '#sad', '#disgusting', -0.854, 'fast_food', 'junk_food', 'unhealthy_food', 'reuse_oil', 'fattening_food']
senticnet['deep_hole'] = [-0.937, 0, 0.955, -0.905, '#sad', '#angry', -0.932, 'grave', 'hole', 'burial', 'corpse', 'deep']
senticnet['deep_resentment'] = [-0.906, 0, 0.48, -0.998, '#sad', '#disgusting', -0.795, 'strong_dislike', 'hate', 'hatred', 'enemy', 'animosity']
senticnet['deep_sadness'] = [-0.859, 0, 0, 0, '#sad', '#sad', -0.286, 'feel_sorry', 'sadness', 'bad_feeling', 'negative_feeling', 'lament']
senticnet['deep_sleep'] = [0.896, 0, 0, 0.809, '#joyful', '#admirable', 0.568, 'set_alarm_clock', 'go_bed_early', 'set_alarm', 'sleep_early', 'take_nap']
senticnet['deep_thinker'] = [0.995, 0.801, 0, 0.968, '#joyful', '#admirable', 0.921, 'scientist', 'knowledge', 'scholar', 'smart', 'advance_knowledge']
senticnet['deepen'] = [-0.765, 0, 0.86, -0.667, '#sad', '#angry', -0.764, 'screw_up', 'fan', 'enhance', 'amplify', 'heat_up']
senticnet['deepening'] = [0.652, -0.649, 0, 0.953, '#joyful', '#admirable', 0.751, 'heightening', 'thickening', 'aggravating', 'exacerbating', 'intensifying']
senticnet['deer'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'life', 'bear', 'woodland_animal', 'woodland_creature', 'woodland_mushroom']
senticnet['deface'] = [-0.624, 0, 0.756, -0.626, '#angry', '#disgusting', -0.669, 'vitiate', 'mar', 'maul', 'mangle', 'impair']
senticnet['defamation'] = [-0.651, 0, 0.537, -0.95, '#sad', '#disgusting', -0.713, 'malignment', 'vilification', 'smear', 'character_assassination', 'libel']
senticnet['defame'] = [-0.82, 0, 0, -0.948, '#sad', '#disgusting', -0.589, 'charge', 'accuse', 'malign', 'libel', 'slander']
senticnet['defaulter'] = [-0.514, 0, 0.63, -0.842, '#angry', '#disgusting', -0.662, 'hooky_player', 'truant', 'absentee', 'exile', 'expatriate']
senticnet['defeat'] = [-0.86, 0, -0.997, 0, '#sad', '#scared', -0.619, 'lose_battle', 'surrender', 'beaten', 'military_action', 'lose_war']
senticnet['defeat_enemy'] = [0.827, 0, 0, 0.868, '#joyful', '#admirable', 0.565, 'keep_peace', 'conquer_enemy', 'gain_territory', 'protect_country', 'settle_disagreement']
senticnet['defeated'] = [-0.707, 0, 0.786, 0, '#sad', '#angry', -0.498, 'disappointed', 'defeatism', 'thwarted', 'frustrated', 'foiled']
senticnet['defeatism'] = [-0.901, 0, 0.773, 0, '#sad', '#angry', -0.558, 'disappointed', 'thwarted', 'frustrated', 'foiled', 'discomfited']
senticnet['defeatist'] = [-0.527, 0, 0.95, -0.788, '#angry', '#disgusting', -0.755, 'skeptic', 'sceptic', 'doubter', 'pessimist', 'negativist']
senticnet['defecate'] = [-0.046, 0, -0.072, -0.097, '#scared', '#disgusting', -0.072, 'go_toilet', 'go_bathroom', 'go_pee', 'read_bedtime_story', 'quiet_cry_baby']
senticnet['defecation'] = [-0.412, 0.081, -0.415, 0.155, '#sad', '#scared', -0.197, 'hard_to_define', 'bad', 'harmful_human', 'stool', 'chair']
senticnet['defecation_reflex'] = [-0.65, 0, 0.983, -0.914, '#angry', '#disgusting', -0.849, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['defect'] = [-0.538, 0, 0.626, -0.863, '#angry', '#disgusting', -0.676, 'imperfection', 'imperfectness', 'myelatelia', 'birth_defect', 'congenital_anomaly']
senticnet['defect_of_speech'] = [-0.846, 0, 0.829, -0.546, '#sad', '#angry', -0.74, 'upset', 'dysarthria', 'dysphonia', 'disorder', 'lallation']
senticnet['defective'] = [-0.923, 0, 0.256, -0.986, '#sad', '#disgusting', -0.722, 'lousy', 'bad_quality', 'failure', 'poor_quality', 'low_quality']
senticnet['defectiveness'] = [0.789, -0.998, 0, 0.54, '#joyful', '#surprising', 0.776, 'imperfection', 'imperfectness', 'bugginess', 'lameness', 'sickness']
senticnet['defence'] = [-0.856, 0, 0, -0.758, '#sad', '#disgusting', -0.538, 'attack', 'raid', 'fight_against', 'conflict', 'opposition']
senticnet['defenceless'] = [-0.574, 0, 0.654, -0.986, '#angry', '#disgusting', -0.738, 'defenseless', 'unarmed', 'barehanded', 'clean', 'weaponless']
senticnet['defend'] = [0, 0.908, 0, 0.751, '#interesting', '#admirable', 0.553, 'watch_over', 'protect', 'protection', 'steal_money', 'stick_up']
senticnet['defend_oneself'] = [-0.119, -0.047, -0.077, -0.22, '#sad', '#disgusting', -0.123, 'death_destruction', 'kill', 'murder', 'get_rid_of_enemy', 'destroy_live']
senticnet['defendable'] = [0.631, -0.589, 0, 0.914, '#joyful', '#admirable', 0.711, 'invulnerable', 'defensible', 'impregnable', 'secure', 'bombproof']
senticnet['defendant'] = [0.705, 0.875, 0, 0, '#joyful', '#interesting', 0.527, 'witness', 'prosecutor', 'legal_process', 'lawyer', 'jury']
senticnet['defended'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'safety', 'absence_of_risk', 'guarded', 'secure', 'absence_of_danger']
senticnet['defender'] = [0.041, 0.086, 0.016, 0, '#joyful', '#interesting', 0.037, 'teamwork', 'team', 'game', 'basketball_game', 'score']
senticnet['defense'] = [-0.045, 0, -0.068, -0.061, '#scared', '#disgusting', -0.058, 'make_war', 'conquer_enemy', 'use_military', 'gain_territory', 'keep_peace']
senticnet['defenseless'] = [-0.574, 0, 0.654, -0.986, '#angry', '#disgusting', -0.738, 'unarmed', 'defenceless', 'barehanded', 'clean', 'weaponless']
senticnet['defensible'] = [0.631, -0.589, 0, 0.914, '#joyful', '#admirable', 0.711, 'defendable', 'invulnerable', 'impregnable', 'secure', 'bombproof']
senticnet['defensive'] = [0, 0.14, 0, 0.114, '#interesting', '#admirable', 0.085, 'medieval', 'rich_house', 'fortification', 'place_to_live', 'domestic_dwell']
senticnet['deference'] = [0.781, -0.732, 0, 0.786, '#joyful', '#admirable', 0.766, 'props', 'politeness', 'homage', 'civility', 'court']
senticnet['defervescence'] = [-0.539, 0, 0.608, -0.935, '#angry', '#disgusting', -0.694, 'reprieve', 'respite', 'hiatus', 'abatement', 'suspension']
senticnet['defiant'] = [-0.698, 0, 0.516, -0.941, '#sad', '#disgusting', -0.718, 'insubordinate', 'recalcitrant', 'obstreperous', 'resistant', 'resistive']
senticnet['deficiency'] = [-0.543, 0, 0.92, -0.843, '#angry', '#disgusting', -0.769, 'dearth', 'demand', 'mineral_deficiency', 'famine', 'need']
senticnet['deficiency_disease'] = [-0.712, 0, 0.74, -0.506, '#sad', '#angry', -0.653, 'kwashiorkor', 'marasmus', 'avitaminosis', 'hypovitaminosis', 'malnutrition']
senticnet['deficient'] = [-0.587, 0, 0.996, -0.848, '#angry', '#disgusting', -0.81, 'undermanned', 'understaffed', 'inadequate', 'lacking', 'wanting']
senticnet['defilement'] = [0.764, -0.619, 0, 0.878, '#joyful', '#admirable', 0.754, 'feculence', 'befoulment', 'dirtiness', 'dinginess', 'dinge']
senticnet['define'] = [-0.086, 0.199, -0.058, 0.205, '#interesting', '#admirable', 0.087, 'explanation', 'conclude', 'clarify', 'make_comparison', 'tell_why']
senticnet['definite'] = [0.078, 0.229, -0.115, 0.209, '#interesting', '#admirable', 0.134, 'misspell', 'record_information', 'use_pencil', 'documentation', 'think_idea']
senticnet['definiteness'] = [-0.571, 0, 0.713, -0.649, '#angry', '#disgusting', -0.644, 'sure_thing', 'foregone_conclusion', 'certainty', 'determinateness', 'predictability']
senticnet['definition'] = [0, 0.98, 0, 0.854, '#interesting', '#admirable', 0.611, 'vocabulary', 'read_material', 'book_genre', 'many_words', 'book_library']
senticnet['definitive'] = [0.501, -0.996, 0, 0.68, '#surprising', '#admirable', 0.726, 'stated', 'hardcore', 'declared', 'explicit', 'graphic']
senticnet['deflagration'] = [-0.904, 0, 0.825, -0.61, '#sad', '#angry', -0.78, 'flaming', 'combustion', 'fire', 'flame', 'internal_combustion']
senticnet['deflate'] = [-0.101, 0, 0, 0, '#sad', '#sad', -0.034, 'read_cover', 'spread_out', 'upgrade', 'look_behind', 'scan']
senticnet['deflection'] = [-0.859, 0, 0.936, -0.807, '#sad', '#angry', -0.867, 'abnormalcy', 'abnormality', 'aberrance', 'warp', 'chromosomal_aberration']
senticnet['deforestation'] = [0, -0.026, 0.085, -0.094, '#angry', '#disgusting', -0.051, 'tree_wood', 'forest', 'sideways', 'dead_tree', 'wood']
senticnet['deformation'] = [-0.977, 0, 0.521, -0.913, '#sad', '#disgusting', -0.804, 'warp', 'harm', 'impairment', 'damage', 'warping']
senticnet['deformed'] = [-0.737, 0, 0.904, -0.531, '#sad', '#angry', -0.724, 'acromegalic', 'shapeless', 'lumpy', 'unshapely', 'malformed']
senticnet['deformity'] = [-0.854, 0, 0.695, -0.658, '#sad', '#angry', -0.736, 'affliction', 'pigeon_breast', 'chicken_breast', 'clubfoot', 'talipes']
senticnet['defrauder'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'gouger', 'swindler', 'confidence_man', 'conman', 'fraud']
senticnet['defrock'] = [-0.956, 0, 0.673, -0.855, '#sad', '#disgusting', -0.828, 'discharge', 'free', 'dethrone', 'disinvest', 'unfrock']
senticnet['defrost'] = [-0.049, 0, -0.05, 0, '#sad', '#scared', -0.033, 'chop_vegetable', 'dissolve_in_water', 'prepare_breakfast', 'brown_hamburger', 'heat_meal']
senticnet['deftness'] = [0.805, -0.817, 0, 0.653, '#joyful', '#surprising', 0.758, 'skillfulness', 'touch', 'dexterity', 'manual_dexterity', 'sleight']
senticnet['defy'] = [-0.547, 0, 0.815, -0.835, '#angry', '#disgusting', -0.732, 'brave_out', 'endure', 'weather', 'withstand', 'stand_firm']
senticnet['degenerate'] = [0.789, -0.733, 0, 0.857, '#joyful', '#admirable', 0.793, 'fetishist', 'lecher', 'lech', 'letch', 'satyr']
senticnet['degeneration'] = [-0.829, 0, 0, -0.922, '#sad', '#disgusting', -0.584, 'deterioration', 'decline', 'decay', 'degradation', 'slide']
senticnet['degenerative_disorder'] = [-0.759, 0, 0.515, -0.93, '#sad', '#disgusting', -0.735, 'sclerosis', 'induration', 'disseminated_sclerosis', 'autoimmune_disease', 'autoimmune_disorder']
senticnet['degradation'] = [-0.832, 0, 0, -0.931, '#sad', '#disgusting', -0.588, 'popularization', 'profanation', 'demoralization', 'corruption', 'humiliation']
senticnet['degrade'] = [-0.958, 0, 0, -0.808, '#sad', '#disgusting', -0.589, 'take_down', 'dehumanize', 'demean', 'disgrace', 'put_down']
senticnet['degrading'] = [-0.918, 0, 0.907, -0.601, '#sad', '#angry', -0.809, 'opprobrious', 'debasing', 'disgraceful', 'dishonorable', 'inglorious']
senticnet['degree'] = [-0.756, 0, 0.589, -0.719, '#sad', '#disgusting', -0.688, 'lowness', 'grind', 'immoderation', 'immoderateness', 'amplitude_level']
senticnet['dehumanize'] = [-0.767, 0, 0, -0.754, '#sad', '#disgusting', -0.507, 'degrade', 'demean', 'disgrace', 'undignified', 'inglorious']
senticnet['dehydration'] = [-0.948, 0, 0, -0.988, '#sad', '#disgusting', -0.645, 'tired_leg', 'heavy_breathe', 'sweat', 'shin_splint', 'get_sweaty']
senticnet['deipnosophist'] = [0.727, -0.622, 0, 0.57, '#joyful', '#surprising', 0.64, 'utterer', 'conversationalist', 'interlocutor', 'conversational_partner', 'speaker']
senticnet['deity'] = [0, 0, 0, 0.844, '#admirable', '#admirable', 0.281, 'almighty', 'omniscient', 'jesus_christ', 'god', 'baron']
senticnet['deject'] = [-0.81, 0.239, -0.443, -0.064, '#sad', '#scared', -0.359, 'feel_down', 'cast_down', 'get_down', 'dispirit', 'demoralize']
senticnet['dejected'] = [-0.557, 0, 0.557, -0.703, '#sad', '#angry', -0.606, 'downhearted', 'down_in_mouth', 'dispirited', 'grim', 'glum']
senticnet['dejectedness'] = [-0.752, 0.288, -0.434, -0.058, '#sad', '#scared', -0.319, 'dispiritedness', 'low-spiritedness', 'lowness', 'downheartedness', 'cheerless']
senticnet['dejection'] = [-0.838, 0, 0.521, -0.713, '#sad', '#disgusting', -0.691, 'stool', 'droppings', 'chip', 'cow_chip', 'cow_dung']
senticnet['delay'] = [0, 0, 0.98, -0.889, '#angry', '#disgusting', -0.623, 'waste_time', 'get_angry', 'become_impatient', 'lose_temper', 'lose_sleep']
senticnet['delay_payment'] = [-0.04, 0, 0, -0.042, '#sad', '#disgusting', -0.027, 'make_sign', 'become_dull', 'write_paper', 'write', 'make_mark_paper']
senticnet['delayed'] = [0, 0, -0.804, -0.819, '#scared', '#disgusting', -0.541, 'detain', 'hold_up', 'stay', 'check', 'retard']
senticnet['delectable'] = [0.878, -0.765, 0, 0, '#joyful', '#surprising', 0.548, 'delicious', 'luscious', 'pleasant-tasting', 'scrumptious', 'toothsome']
senticnet['delegate'] = [-0.728, 0, 0.918, -0.546, '#sad', '#angry', -0.731, 'designate', 'depute', 'reduce', 'sideline', 'demote']
senticnet['delete'] = [-0.825, 0, 0.694, -0.712, '#sad', '#disgusting', -0.744, 'withdraw', 'strike', 'scratch', 'efface', 'take']
senticnet['deli_case'] = [0, 0, -0.047, -0.049, '#scared', '#disgusting', -0.032, 'food_fridge', 'food_display', 'cake', 'cafe', 'desert']
senticnet['deli_store'] = [0, 0, 0.016, -0.086, '#angry', '#disgusting', -0.034, 'dime_store', 'shop_arcade', 'vend_stand', 'bookshop', 'store']
senticnet['deliberate'] = [-0.32, 0.138, -0.259, 0.055, '#sad', '#scared', -0.129, 'bad_time', 'look_fact', 'make_decision', 'investigation', 'rational']
senticnet['deliberateness'] = [-0.689, 0, 0.82, -0.968, '#angry', '#disgusting', -0.826, 'dilatoriness', 'leisureliness', 'procrastination', 'rate', 'pace']
senticnet['delicacy'] = [0.708, -0.934, 0, 0.764, '#surprising', '#admirable', 0.802, 'dainty', 'jelly', 'treat', 'gelatin_dessert', 'aspic']
senticnet['delicate'] = [0.058, 0.141, 0, 0.207, '#interesting', '#admirable', 0.135, 'versatile', 'beautiful', 'light_colored', 'fragile', 'delicious']
senticnet['delicious'] = [0.075, 0.076, 0, 0.166, '#interesting', '#admirable', 0.106, 'yummy', 'tasty', 'good_eat', 'creamy', 'edible']
senticnet['delicious_food'] = [0.965, 0.936, 0, 0, '#joyful', '#interesting', 0.634, 'yum', 'hot_meal', 'good_food', 'fresh_produce', 'tasty_food']
senticnet['delicious_fruit'] = [0.05, 0, 0.047, 0.068, '#joyful', '#admirable', 0.024, 'tree_fruit', 'yellow_fruit', 'small_fruit', 'vine_fruit', 'red_fruit']
senticnet['delicious_meal'] = [0.028, -0.073, 0, 0, '#joyful', '#surprising', 0.034, 'casserole', 'meatloaf', 'hot_dog_bun', 'hamburger', 'hot_dog']
senticnet['delight'] = [0.709, 0.977, 0, 0.795, '#interesting', '#admirable', 0.827, 'happy', 'bring_happiness', 'happiness', 'good_feeling', 'feel_glad']
senticnet['delight_audience'] = [0.986, 0.924, 0, 0, '#joyful', '#interesting', 0.637, 'add_two_numbers', 'play', 'win_sport_event', 'play_cat', 'find_hardware_store']
senticnet['delight_child'] = [0.933, 0.85, 0, 0.966, '#joyful', '#admirable', 0.916, 'entertain_child', 'amuse', 'make_laugh', 'amuse_child', 'give_pleasure']
senticnet['delight_sense'] = [0.72, 0.753, 0, 0, '#joyful', '#interesting', 0.491, 'sound_good', 'great_joy', 'feel_refreshed', 'happiness', 'self_satisfaction']
senticnet['delighted'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['delineated'] = [0.716, -0.78, 0, 0.539, '#joyful', '#surprising', 0.678, 'depicted', 'pictured', 'portrayed', 'described', 'diagrammatic']
senticnet['delineation'] = [0, 0, -0.999, -0.848, '#scared', '#disgusting', -0.616, 'word_picture', 'picture', 'word-painting', 'depiction', 'characterization']
senticnet['delinquent'] = [-0.569, 0, 0.743, -0.777, '#angry', '#disgusting', -0.696, 'neglectful', 'derelict', 'inattentive', 'negligent', 'lax']
senticnet['delirious'] = [0, 0, -0.736, -0.83, '#scared', '#disgusting', -0.522, 'hallucinating', 'excited', 'frantic', 'mad', 'unrestrained']
senticnet['delirium'] = [-0.974, 0, 0.777, -0.537, '#sad', '#angry', -0.763, 'manic_disorder', 'mania', 'nympholepsy', 'mass_hysteria', 'epidemic_hysertia']
senticnet['deliver'] = [0, -0.778, 0, 0.911, '#surprising', '#admirable', 0.563, 'send', 'cope', 'give_out', 'express', 'permit']
senticnet['deliver_baby'] = [-0.037, 0, -0.082, 0, '#sad', '#scared', -0.04, 'baby', 'large_family', 'youth', 'small_child', 'birth']
senticnet['deliver_goods'] = [0.735, -0.516, 0, 0.66, '#joyful', '#admirable', 0.637, 'clear', 'pan_out', 'reach', 'bring_off', 'luck_out']
senticnet['deliverance'] = [0.825, -0.636, 0, 0.781, '#joyful', '#admirable', 0.747, 'salvage', 'lifesaving', 'redemption', 'salvation', 'recovery']
senticnet['delivery'] = [0, 0.893, 0, 0.788, '#interesting', '#admirable', 0.56, 'send', 'mail_delivery', 'mail', 'postal_service', 'package']
senticnet['deltoid'] = [0.934, -0.62, 0, 0.79, '#joyful', '#admirable', 0.781, 'voluntary_muscle', 'skeletal_muscle', 'pterygoid_muscle', 'abductor', 'abductor_muscle']
senticnet['delude'] = [-0.809, 0, 0.654, -0.742, '#sad', '#disgusting', -0.735, 'humbug', 'play_trick', 'fob', 'pull_fast_one_on', 'play_trick_on']
senticnet['deluge'] = [-0.567, 0, 0.944, -0.897, '#angry', '#disgusting', -0.803, 'mess', 'spate', 'stack', 'mass', 'plenty']
senticnet['delusion'] = [-0.502, 0, 0.641, -0.899, '#angry', '#disgusting', -0.681, 'delusions_of_persecution', 'hallucination', 'delusions_of_grandeur', 'nihilistic_delusion', 'nihilism']
senticnet['delusional'] = [-0.099, 0, -0.091, -0.095, '#sad', '#disgusting', -0.095, 'felon', 'freak', 'busy_person', 'bad_person', 'good_man']
senticnet['delusional_disorder'] = [-0.884, 0, 0.833, -0.668, '#sad', '#angry', -0.795, 'mental_disorder', 'mental_disturbance', 'psychological_disorder', 'folie', 'disturbance']
senticnet['delusions_of_grandeur'] = [-0.502, 0, 0.641, -0.899, '#angry', '#disgusting', -0.681, 'delusions_of_persecution', 'hallucination', 'delusion', 'nihilistic_delusion', 'nihilism']
senticnet['delusions_of_persecution'] = [-0.502, 0, 0.641, -0.899, '#angry', '#disgusting', -0.681, 'delusion', 'hallucination', 'delusions_of_grandeur', 'nihilistic_delusion', 'nihilism']
senticnet['delusive'] = [-0.93, 0, 0.94, -0.772, '#sad', '#angry', -0.881, 'unrealistic', 'phantasmagoric', 'phantasmagorical', 'surrealistic', 'wild']
senticnet['demagoguery'] = [0.68, -0.962, 0, 0.597, '#joyful', '#surprising', 0.746, 'flag_waving', 'jingoism', 'appeal', 'prayer', 'entreaty']
senticnet['demagogy'] = [0.996, -0.767, 0, 0.798, '#joyful', '#admirable', 0.854, 'flag_waving', 'jingoism', 'appeal', 'prayer', 'entreaty']
senticnet['demand'] = [0.716, 0, 0, 0.919, '#joyful', '#admirable', 0.545, 'obedience', 'must', 'requirement', 'permission', 'necessary']
senticnet['demand_feeding'] = [-0.802, 0, 0.724, -0.706, '#sad', '#angry', -0.744, 'nursing', 'schedule_feeding', 'infant_feeding', 'breast_feeding', 'feeding']
senticnet['demanding'] = [-0.756, 0, 0.982, -0.958, '#angry', '#disgusting', -0.899, 'needy', 'stringent', 'stern', 'exacting', 'exigent']
senticnet['demean'] = [-0.624, 0, 0.631, -0.679, '#angry', '#disgusting', -0.645, 'humiliate', 'humble', 'abase', 'mortify', 'reduce']
senticnet['demeaning'] = [-0.773, 0, 0.852, 0, '#sad', '#angry', -0.542, 'humbling', 'humbleness', 'humiliating', 'demeaningly', 'humiliatingly']
senticnet['demeaningly'] = [-0.997, 0, 0.746, 0, '#sad', '#angry', -0.581, 'humbling', 'demeaning', 'humbleness', 'humiliating', 'humiliatingly']
senticnet['dementedness'] = [-0.947, 0, 0.821, -0.756, '#sad', '#angry', -0.841, 'presenile_dementia', 'insanity', 'senile_dementia', 'senile_psychosis', 'alcoholic_dementia']
senticnet['dementia'] = [-0.601, 0, 0.634, -0.938, '#angry', '#disgusting', -0.724, 'presenile_dementia', 'insanity', 'senile_dementia', 'senile_psychosis', 'alcoholic_dementia']
senticnet['demesne'] = [0.975, -0.993, 0, 0.644, '#joyful', '#surprising', 0.871, 'entail', 'barony', 'seigneury', 'seigniory', 'immovable']
senticnet['demigod'] = [0.978, -0.88, 0, 0.785, '#joyful', '#surprising', 0.881, 'daemon', 'divinity', 'sea_god', 'sun_god', 'goddess']
senticnet['demo'] = [0, 0, 0.07, 0, '#angry', '#angry', -0.023, 'price_product', 'pottery', 'create_sound', 'music', 'create_new_idea']
senticnet['democracy'] = [0.044, 0.133, -0.086, 0.087, '#interesting', '#admirable', 0.059, 'republic', 'nation', 'democratic_country', 'free_country', 'nation_state']
senticnet['democrat'] = [0, 0.76, 0, 0.747, '#interesting', '#admirable', 0.502, 'detective', 'politician', 'government', 'voter', 'legal_person']
senticnet['democratic'] = [0.151, -0.094, 0, 0, '#joyful', '#surprising', 0.082, 'democratic_country', 'pledge_allegiance', 'nation_state', 'united_country', 'nation']
senticnet['democratic_country'] = [0.084, 0.122, -0.086, 0.137, '#interesting', '#admirable', 0.086, 'unite', 'pledge_allegiance', 'political_unit', 'state', 'free_country']
senticnet['democratic_process'] = [0, 0.261, -0.121, 0.322, '#interesting', '#admirable', 0.154, 'presidential', 'procedure', 'election', 'posture', 'select']
senticnet['demodulate'] = [-0.919, 0, 0.656, -0.813, '#sad', '#disgusting', -0.796, 'withdraw', 'squeeze_out', 'take', 'wring_out', 'rip_out']
senticnet['demoiselle'] = [-0.81, 0, 0.885, -0.923, '#angry', '#disgusting', -0.873, 'miss', 'girl', 'damsel', 'maiden', 'damoiselle']
senticnet['demolish'] = [-0.104, 0, -0.117, -0.047, '#sad', '#scared', -0.089, 'terminate', 'violent_action', 'destruction', 'eliminate', 'take_life']
senticnet['demolition'] = [-0.087, 0, -0.085, -0.147, '#sad', '#disgusting', -0.106, 'violence', 'assault', 'combat', 'siege', 'use_military']
senticnet['demon'] = [-0.09, 0.085, -0.085, -0.112, '#sad', '#disgusting', -0.067, 'hitler', 'treachery', 'good_man', 'cannibalism', 'sad_person']
senticnet['demoniac'] = [-0.823, 0, 0.635, -0.569, '#sad', '#angry', -0.676, 'fiend', 'ogre', 'demon', 'devil', 'monster']
senticnet['demonstrability'] = [0.776, -0.667, 0, 0.778, '#joyful', '#admirable', 0.74, 'indisputability', 'provability', 'positivity', 'positiveness', 'certainty']
senticnet['demonstrate'] = [-0.022, 0, 0, -0.116, '#sad', '#disgusting', -0.046, 'show_how', 'confirm', 'help_understand', 'misunderstand', 'hear_speech']
senticnet['demonstrate_knowledge'] = [-0.105, 0, 0, -0.112, '#sad', '#disgusting', -0.072, 'pass_exam', 'seek_understanding', 'learn_fact', 'teach_person', 'further_career']
senticnet['demonstrate_skill'] = [0.833, 0.906, 0, 0.893, '#interesting', '#admirable', 0.877, 'raise_self_esteem', 'kill_time', 'pastime', 'enjoy_oneself', 'stimulate_mind']
senticnet['demonstration'] = [-0.025, 0, -0.069, -0.047, '#scared', '#disgusting', -0.047, 'sport_stadium', 'marketplace', 'drive-in_movie', 'movie_theater', 'movie_studio']
senticnet['demonstrative_of'] = [0.9, -0.742, 0, 0.721, '#joyful', '#surprising', 0.788, 'accessary', 'supportive', 'encouraging', 'certificatory', 'supporting']
senticnet['demonstrator'] = [-0.934, 0, 0.86, -0.907, '#sad', '#disgusting', -0.9, 'dry', 'insurgent', 'militant', 'passive_resister', 'crusader']
senticnet['demoralization'] = [-0.833, 0.22, -0.462, -0.051, '#sad', '#scared', -0.375, 'disheartening', 'sadness', 'demoralizing', 'feel_down', 'dispiriting']
senticnet['demoralize'] = [-0.81, 0.239, -0.443, -0.064, '#sad', '#scared', -0.359, 'demoralized', 'deject', 'cast_down', 'get_down', 'dispirit']
senticnet['demoralized'] = [-0.73, 0.288, -0.367, -0.108, '#sad', '#scared', -0.306, 'feel_down', 'disheartened', 'despondently', 'despairingly', 'weepiness']
senticnet['demoralizing'] = [-0.833, 0.22, -0.462, -0.051, '#sad', '#scared', -0.375, 'disheartening', 'feel_down', 'demoralization', 'sadness', 'dispiriting']
senticnet['demote'] = [-0.728, 0, 0.918, -0.546, '#sad', '#angry', -0.731, 'designate', 'depute', 'reduce', 'sideline', 'delegate']
senticnet['demureness'] = [-0.562, 0, 0.757, -0.991, '#angry', '#disgusting', -0.77, 'unnaturalness', 'airs', 'pose', 'coyness', 'affectedness']
senticnet['den'] = [0.803, -0.893, 0, 0.94, '#surprising', '#admirable', 0.879, 'lurking_place', 'spot', 'drop', 'hideaway', 'hiding_place']
senticnet['denatured'] = [0.78, -0.799, 0, 0.954, '#surprising', '#admirable', 0.844, 'transformed', 'varied', 'exchanged', 'changed', 'denaturized']
senticnet['denatured_alcohol'] = [-0.915, 0, 0.65, -0.594, '#sad', '#angry', -0.72, 'absolute_alcohol', 'spirits_of_wine', 'ethyl_alcohol', 'alcohol', 'plant_product']
senticnet['denaturized'] = [0.78, -0.799, 0, 0.954, '#surprising', '#admirable', 0.844, 'transformed', 'varied', 'exchanged', 'denatured', 'changed']
senticnet['deniable'] = [0.906, -0.624, 0, 0.698, '#joyful', '#admirable', 0.743, 'disavowable', 'questionable', 'refutable', 'confutable', 'confutative']
senticnet['denial'] = [0, 0, 0.736, -0.995, '#angry', '#disgusting', -0.577, 'get_fired', 'unbelief', 'extreme_fear', 'psychoneurosis', 'death_love']
senticnet['denigrate'] = [0, 0, -0.83, -0.954, '#scared', '#disgusting', -0.595, 'minimize', 'slander', 'defame', 'derogate', 'belittle']
senticnet['denizen'] = [0.9, -0.513, 0, 0.836, '#joyful', '#admirable', 0.75, 'indweller', 'inhabitant', 'habitant', 'dweller', 'villager']
senticnet['denomination'] = [0, 0.261, 0.06, 0.182, '#interesting', '#admirable', 0.128, 'monetary_value', 'four_quarters', 'dollar_change', 'money_value', 'dollar_cent']
senticnet['denotative'] = [0.904, -0.588, 0, 0.736, '#joyful', '#admirable', 0.743, 'naming', 'appellative', 'designative', 'extensional', 'referent']
senticnet['denounce'] = [0, 0, -0.721, -0.707, '#scared', '#disgusting', -0.476, 'betray', 'stigmatize', 'tell_on', 'brand', 'mark']
senticnet['dense'] = [0.046, 0, 0.04, 0.109, '#joyful', '#admirable', 0.038, 'magnetic', 'heavy', 'hard_substance', 'hard_mineral', 'hard_rock']
senticnet['dense_air'] = [0.728, 0.977, 0, 0.939, '#interesting', '#admirable', 0.881, 'air_pressure', 'altitude', 'air_density', 'heavy_air', 'soft_metal']
senticnet['dense_water'] = [0.028, 0.138, -0.048, 0.215, '#interesting', '#admirable', 0.111, 'water', 'dense', 'thick', 'milk', 'cream']
senticnet['density'] = [0.728, 0.977, 0, 0.939, '#interesting', '#admirable', 0.881, 'air_pressure', 'altitude', 'air', 'heavy_air', 'air_density']
senticnet['dent'] = [-0.966, 0, 0.501, -0.927, '#sad', '#disgusting', -0.798, 'byproduct', 'wallop', 'side_effect', 'effect', 'fallout']
senticnet['dental'] = [-0.03, 0.079, 0.024, 0.091, '#interesting', '#admirable', 0.039, 'toothpaste', 'toothbrush', 'mouth', 'gel_toothpaste', 'tooth']
senticnet['dental_appliance'] = [-0.657, 0, 0.65, -0.981, '#sad', '#disgusting', -0.763, 'false_teeth', 'bridge', 'bridgework', 'partial_denture', 'dental_plate']
senticnet['dental_chair'] = [0, 0, -0.739, -0.827, '#scared', '#disgusting', -0.522, 'hospital', 'blow_dryer', 'acne_medication', 'medicine', 'x-ray_machine']
senticnet['dental_floss'] = [0, 0, -0.714, -0.705, '#scared', '#disgusting', -0.473, 'wax_dental_floss', 'tartar_control_toothpaste', 'toothpaste', 'gel_toothpaste', 'toothbrush']
senticnet['dental_office'] = [0.025, 0, -0.049, -0.123, '#scared', '#disgusting', -0.049, 'dentist_office', 'subway_station', 'office', 'registry_office', 'dentist']
senticnet['dental_plaque'] = [-0.81, 0, 0.741, -0.763, '#sad', '#disgusting', -0.771, 'spot', 'amyloid_plaque', 'dentist', 'arterial_plaque', 'plaque']
senticnet['dental_plate'] = [-0.657, 0, 0.65, -0.981, '#sad', '#disgusting', -0.763, 'false_teeth', 'bridge', 'bridgework', 'partial_denture', 'dental_appliance']
senticnet['dental_work'] = [-0.114, 0, -0.068, 0, '#sad', '#scared', -0.061, 'ninja', 'dry_oneself_off', 'cover_face', 'false_tooth', 'flowing_water']
senticnet['dentist'] = [0, 0, -0.131, -0.152, '#scared', '#disgusting', -0.094, 'dentist_office', 'doctor_office', 'hospital', 'clinic', 'medical_office']
senticnet['dentist_chair'] = [-0.877, 0, 0, -0.784, '#sad', '#disgusting', -0.554, 'magazine_rack', 'sofa', 'couch', 'sofa_bed', 'mattress']
senticnet['dentist_office'] = [0, 0, -0.08, -0.154, '#scared', '#disgusting', -0.078, 'dental_office', 'dentist', 'fear', 'remove_tooth', 'pain']
senticnet['dentist_work'] = [-0.023, -0.004, 0, -0.083, '#sad', '#disgusting', -0.034, 'pull_tooth', 'wait', 'carve_niche', 'wait_line', 'stand_queue']
senticnet['dentition'] = [-0.883, 0, 0.876, -0.844, '#sad', '#angry', -0.868, 'precocious_dentition', 'growth', 'growing', 'maturation', 'development']
senticnet['denture'] = [-0.697, 0, 0.678, -0.925, '#sad', '#disgusting', -0.767, 'false_teeth', 'bridge', 'bridgework', 'partial_denture', 'dental_appliance']
senticnet['denumerable'] = [0.983, -0.807, 0, 0.966, '#joyful', '#admirable', 0.919, 'estimable', 'computable', 'countable', 'calculable', 'enumerable']
senticnet['deny'] = [-0.279, -0.18, 0.02, -0.361, '#sad', '#disgusting', -0.16, 'interruption', 'criticism', 'anthrax', 'prohibit', 'lay_off']
senticnet['depart'] = [0, 0.152, -0.088, 0.208, '#interesting', '#admirable', 0.091, 'departure', 'leave', 'colored_green', 'green_color', 'make_big']
senticnet['departed'] = [-0.846, 0, 0.811, -0.75, '#sad', '#angry', -0.802, 'infernal', 'mortal', 'zombi', 'zombie', 'living_dead']
senticnet['department'] = [0.028, 0.146, 0, 0.105, '#interesting', '#admirable', 0.093, 'association', 'merchant', 'organization', 'retailer', 'company']
senticnet['department_head'] = [0, 0.089, 0, 0, '#interesting', '#interesting', 0.03, 'legislature', 'state_head', 'in_charge', 'reign', 'headquarters']
senticnet['department_store'] = [0, 0.081, 0, 0.071, '#interesting', '#admirable', 0.051, 'thrift_store', 'type_of_store', 'record_store', 'many_shops', 'clothes_store']
senticnet['departmental_highway'] = [0, 0, 0.714, -0.895, '#angry', '#disgusting', -0.536, 'busy_street', 'city_street', 'highway', 'donut_shop', 'roadblock']
senticnet['departure'] = [0, 0.153, -0.075, 0.245, '#interesting', '#admirable', 0.108, 'depart', 'arrival', 'action', 'movement', 'make_big']
senticnet['departure_tax'] = [-0.657, 0, 0.65, -0.981, '#sad', '#disgusting', -0.763, 'single_tax', 'income_tax', 'capital_gains_tax', 'capital_levy', 'taxation']
senticnet['depend'] = [0, 0.387, -0.232, 0.313, '#interesting', '#admirable', 0.156, 'intend', 'include', 'let', 'allow', 'determine']
senticnet['depend_on'] = [-0.046, 0.127, -0.121, 0.223, '#interesting', '#admirable', 0.061, 'ride', 'owe', 'build_on', 'depend_upon', 'turn_on']
senticnet['depend_upon'] = [-0.046, 0.127, -0.121, 0.223, '#interesting', '#admirable', 0.061, 'ride', 'owe', 'depend_on', 'build_on', 'turn_on']
senticnet['dependability'] = [0.512, -0.52, 0, 0.874, '#surprising', '#admirable', 0.635, 'responsibleness', 'reproducibility', 'duplicability', 'solidness', 'responsibility']
senticnet['dependable'] = [0.947, -0.793, 0, 0.7, '#joyful', '#surprising', 0.813, 'tested', 'tried', 'tried_and_true', 'sure', 'undeviating']
senticnet['dependableness'] = [0.584, -0.617, 0, 0.929, '#surprising', '#admirable', 0.71, 'responsibleness', 'reproducibility', 'duplicability', 'solidness', 'responsibility']
senticnet['dependance'] = [0.633, -0.634, 0, 0.507, '#joyful', '#surprising', 0.591, 'drug_addiction', 'white_plague', 'physical_condition', 'physiological_state', 'physiological_condition']
senticnet['dependence'] = [0.809, -0.588, 0, 0.702, '#joyful', '#admirable', 0.7, 'state', 'reliance', 'subordination', 'helplessness', 'contingency']
senticnet['dependency'] = [0.618, -0.754, 0, 0.902, '#surprising', '#admirable', 0.758, 'state', 'reliance', 'subordination', 'helplessness', 'contingency']
senticnet['dependent'] = [0, 0, -0.833, -0.923, '#scared', '#disgusting', -0.585, 'qualified', 'subordinate', 'pendant', 'subject', 'hooked']
senticnet['depersonalization'] = [-0.583, 0, 0.722, -0.516, '#sad', '#angry', -0.607, 'disorder', 'dissociative_disorder_neurosis', 'dissociative_disorder', 'mental_disorder', 'mental_disturbance']
senticnet['depersonalization_disorder'] = [-0.583, 0, 0.722, -0.516, '#sad', '#angry', -0.607, 'dissociative_disorder', 'depersonalization_neurosis', 'depersonalization', 'mental_disorder', 'mental_disturbance']
senticnet['depersonalization_neurosis'] = [-0.583, 0, 0.722, -0.516, '#sad', '#angry', -0.607, 'depersonalization_disorder', 'dissociative_disorder', 'depersonalization', 'mental_disorder', 'mental_disturbance']
senticnet['depicted'] = [0.716, -0.78, 0, 0.539, '#joyful', '#surprising', 0.678, 'delineated', 'pictured', 'portrayed', 'described', 'diagrammatic']
senticnet['depilous'] = [-0.587, 0, 0.66, -0.8, '#angry', '#disgusting', -0.682, 'bald', 'hairless', 'glabrescent', 'glabrous', 'balding']
senticnet['deplane'] = [0.861, -0.529, 0, 0.598, '#joyful', '#admirable', 0.663, 'exit', 'detrain', 'get_off', 'go_out', 'get_out']
senticnet['deplete'] = [0, 0, -0.921, -0.824, '#scared', '#disgusting', -0.582, 'consume', 'eat', 'use_up', 'eat_up', 'exhaust']
senticnet['depleted'] = [-0.767, 0, 0.927, -0.811, '#angry', '#disgusting', -0.835, 'inadequate', 'insufficient', 'poor', 'short', 'low']
senticnet['deplorable'] = [-0.906, 0.138, -0.63, 0.071, '#sad', '#scared', -0.442, 'woeful', 'execrable', 'woebegone', 'woefulness', 'plaintiveness']
senticnet['deplorably'] = [-0.883, 0.174, -0.597, 0, '#sad', '#scared', -0.435, 'lamentably', 'woefully', 'bereaved', 'bereft', 'grief-stricken']
senticnet['deplore'] = [-0.655, 0, 0.754, -0.937, '#angry', '#disgusting', -0.782, 'anathemize', 'pick_apart', 'execrate', 'criticize', 'accurse']
senticnet['depopulated'] = [-0.792, 0, 0.621, -0.502, '#sad', '#angry', -0.638, 'untenanted', 'unoccupied', 'derelict', 'deserted', 'uninhabited']
senticnet['deport'] = [0.835, -0.948, 0, 0.537, '#joyful', '#surprising', 0.773, 'fluster', 'hold', 'assert', 'bear', 'move']
senticnet['deportee'] = [-0.575, 0, 0.803, -0.772, '#angry', '#disgusting', -0.717, 'au_pair', 'exile', 'foreigner', 'gringo', 'import']
senticnet['deposit'] = [0, 0.306, -0.05, 0.134, '#interesting', '#admirable', 0.13, 'finance', 'account', 'bank_loan', 'dividend', 'savings_account']
senticnet['deposition'] = [0.942, -0.798, 0, 0.901, '#joyful', '#admirable', 0.88, 'backup', 'buildup', 'accretion', 'deposit', 'increase']
senticnet['depot'] = [0, 0.147, 0, 0.099, '#interesting', '#admirable', 0.082, 'train_station', 'railway_station', 'subway', 'airport_terminal', 'airport']
senticnet['deprave'] = [-0.95, 0, 0.636, -0.857, '#sad', '#disgusting', -0.814, 'suborn', 'modify', 'poison', 'lead_astray', 'alter']
senticnet['depravity'] = [0, 0, -0.715, -0.7, '#scared', '#disgusting', -0.472, 'turpitude', 'putrefaction', 'corruption', 'depravation', 'degeneracy']
senticnet['depreciate'] = [-0.822, 0, 0.835, -0.675, '#sad', '#angry', -0.777, 'disparage', 'belittle', 'deflate', 'puncture', 'pick_at']
senticnet['depreciating'] = [-0.983, 0, 0.962, -0.956, '#sad', '#angry', -0.967, 'depreciative', 'depreciatory', 'falling', 'decreasing', 'detractive']
senticnet['depreciative'] = [-0.983, 0, 0.962, -0.956, '#sad', '#angry', -0.967, 'decreasing', 'depreciatory', 'falling', 'depreciating', 'detractive']
senticnet['depreciator'] = [0.899, -0.775, 0, 0.866, '#joyful', '#admirable', 0.847, 'unpleasant_person', 'disagreeable_person', 'detractor', 'disparager', 'cynic']
senticnet['depreciatory'] = [-0.983, 0, 0.962, -0.956, '#sad', '#angry', -0.967, 'depreciative', 'decreasing', 'falling', 'depreciating', 'detractive']
senticnet['depress'] = [-0.845, 0, 0, -0.753, '#sad', '#disgusting', -0.533, 'miserable', 'melancholy', 'grim', 'guilty', 'dolefully']
senticnet['depress_person'] = [-0.099, -0.024, -0.088, -0.056, '#sad', '#scared', -0.073, 'use_illegal_drug', 'busy_person', 'delusional', 'human', 'cold_person']
senticnet['depressed'] = [-0.784, 0.266, -0.45, -0.052, '#sad', '#scared', -0.34, 'downhearted', 'low-spirited', 'down_in_mouth', 'dispirited', 'downcast']
senticnet['depressed_person'] = [-0.973, 0, 0.256, -0.988, '#sad', '#disgusting', -0.739, 'depression', 'have_problem', 'commit_suicide', 'ill_person', 'sick']
senticnet['depressing'] = [-0.759, 0.282, -0.429, -0.066, '#sad', '#scared', -0.324, 'uncheerful', 'cheerless', 'low-spiritedness', 'lowness', 'dispiritedness']
senticnet['depression'] = [-0.734, 0, 0, -0.812, '#sad', '#disgusting', -0.515, 'sadness', 'sad', 'grief', 'unhappiness', 'misery']
senticnet['depressive'] = [-0.645, 0, 0.854, -0.861, '#angry', '#disgusting', -0.787, 'melancholic', 'sick_person', 'diseased_person', 'sufferer', 'melancholiac']
senticnet['depressive_disorder'] = [-0.696, 0, 0.655, -0.862, '#sad', '#disgusting', -0.738, 'dysthymia', 'dysthymic_depression', 'affective_disorder', 'major_affective_disorder', 'emotional_disorder']
senticnet['deprivation'] = [-0.617, 0, 0.712, -0.861, '#angry', '#disgusting', -0.73, 'destitution', 'impoverishment', 'indigence', 'penury', 'pauperism']
senticnet['deprive'] = [-0.986, 0, 0.654, -0.847, '#sad', '#disgusting', -0.829, 'bereave', 'expropriate', 'disarm', 'unclothe', 'take']
senticnet['depth'] = [-0.065, 0.07, 0.03, 0.138, '#interesting', '#admirable', 0.038, 'along_beach', 'small_ocean', 'deep', 'oceanside', 'full_water']
senticnet['depute'] = [-0.728, 0, 0.918, -0.546, '#sad', '#angry', -0.731, 'designate', 'demote', 'reduce', 'sideline', 'delegate']
senticnet['deputize'] = [-0.812, 0, 0.854, -0.823, '#angry', '#disgusting', -0.83, 'replace', 'cover', 'supplant', 'supersede', 'supervene_upon']
senticnet['derailment'] = [-0.627, 0, 0.507, -0.727, '#sad', '#disgusting', -0.62, 'accident', 'misfortune', 'bad_luck', 'near_miss', 'misadventure']
senticnet['deregulate'] = [-0.713, 0, 0.602, -0.859, '#sad', '#disgusting', -0.725, 'spare', 'forgive', 'derestrict', 'exempt', 'dispense']
senticnet['derelict'] = [-0.753, 0, 0.68, -0.599, '#sad', '#angry', -0.677, 'battered', 'bedraggled', 'hurt', 'damaged', 'dilapidated']
senticnet['dereliction'] = [-0.691, 0, 0.516, -0.966, '#sad', '#disgusting', -0.724, 'criminal_negligence', 'culpable_negligence', 'evasion', 'negligence', 'contributory_negligence']
senticnet['derequisition'] = [-0.855, 0, 0.834, -0.861, '#sad', '#disgusting', -0.85, 'sacrifice', 'give', 'reach', 'hand', 'relinquish']
senticnet['derestrict'] = [-0.713, 0, 0.602, -0.859, '#sad', '#disgusting', -0.725, 'spare', 'forgive', 'exempt', 'deregulate', 'dispense']
senticnet['deride'] = [-0.555, 0, 0.947, -0.775, '#angry', '#disgusting', -0.759, 'blackguard', 'bemock', 'twit', 'tease', 'razz']
senticnet['derivation'] = [0, 0.178, 0, 0.133, '#interesting', '#admirable', 0.104, 'mathematical', 'complete', 'math_term', 'add', 'math_function']
senticnet['derivative_instrument'] = [0.868, -0.847, 0, 0.673, '#joyful', '#surprising', 0.796, 'instrument', 'option', 'futures_contract', 'legal_document', 'legal_instrument']
senticnet['dermatitis'] = [-0.726, 0, 0.778, -0.98, '#angry', '#disgusting', -0.828, 'actinic_dermatitis', 'hypericism', 'diaper_rash', 'diaper_dermatitis', 'seborrheic_dermatitis']
senticnet['dermatomyositis'] = [-0.873, 0, 0.531, -0.681, '#sad', '#disgusting', -0.695, 'rubor', 'redness', 'myositis', 'inclusion_body_myositis', 'inflammation']
senticnet['descend'] = [-0.536, 0, 0.752, -0.898, '#angry', '#disgusting', -0.729, 'fall', 'keel_over', 'topple', 'go_down', 'come_down']
senticnet['descendant'] = [0, 0.977, 0, 0.948, '#interesting', '#admirable', 0.642, 'female_child', 'father_mother', 'parent_child', 'human_offspring', 'family_relation']
senticnet['describe'] = [-0.038, 0.136, -0.11, 0.267, '#interesting', '#admirable', 0.085, 'explain', 'question_starter', 'tell_why', 'answer', 'respond']
senticnet['describe_how_to'] = [0.041, 0.16, 0, 0.3, '#interesting', '#admirable', 0.167, 'instruction', 'summary', 'same', 'know_how', 'description']
senticnet['described'] = [0.716, -0.78, 0, 0.539, '#joyful', '#surprising', 0.678, 'depicted', 'pictured', 'portrayed', 'delineated', 'diagrammatic']
senticnet['describer'] = [0, 0.19, -0.083, 0.275, '#interesting', '#admirable', 0.127, 'know_how', 'descriptive', 'description', 'green_red', 'teacher']
senticnet['description'] = [0.041, 0.16, 0, 0.3, '#interesting', '#admirable', 0.167, 'instruction', 'summary', 'same', 'know_how', 'describe_how_to']
senticnet['descriptive'] = [-0.058, 0.177, -0.054, 0.204, '#interesting', '#admirable', 0.09, 'description', 'delicate', 'red', 'red_green', 'spreadable']
senticnet['descriptive_term'] = [0, 0.199, -0.092, 0.283, '#interesting', '#admirable', 0.13, 'abstraction', 'term', 'reliable', 'bad', 'driven_person']
senticnet['descriptivism'] = [-0.843, 0, 0.814, -0.931, '#sad', '#disgusting', -0.863, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['desecrate'] = [0, 0, -0.701, -0.792, '#scared', '#disgusting', -0.498, 'profane', 'deconsecrate', 'outrage', 'unhallow', 'violate']
senticnet['desensitization_technique'] = [0.542, -0.63, 0, 0.912, '#surprising', '#admirable', 0.695, 'implosion_therapy', 'flooding', 'reciprocal_inhibition', 'aversion_therapy', 'behavior_modification']
senticnet['desensitize'] = [-0.585, 0, 0.703, -0.868, '#angry', '#disgusting', -0.719, 'numb', 'benumb', 'modify', 'deaf', 'bedaze']
senticnet['desert'] = [-0.848, 0, 0.777, -0.901, '#sad', '#disgusting', -0.842, 'biome', 'tract', 'piece_of_land', 'piece_of_ground', 'parcel_of_land']
senticnet['desert_land'] = [-0.98, 0, 0.441, -0.962, '#sad', '#disgusting', -0.794, 'barren_land', 'infertile', 'sand', 'barren', 'desert']
senticnet['desert_rheumatism'] = [-0.859, 0, 0.549, -0.938, '#sad', '#disgusting', -0.782, 'coccidioidomycosis', 'coccidiomycosis', 'valley_fever', 'mycosis', 'cryptococcosis']
senticnet['deserted'] = [-0.792, 0, 0.621, -0.502, '#sad', '#angry', -0.638, 'untenanted', 'unoccupied', 'derelict', 'uninhabited', 'depopulated']
senticnet['deserve'] = [0.991, 0, 0, 0.751, '#joyful', '#admirable', 0.581, 'noteworthy', 'valuable', 'applaudable', 'meritable', 'sacred']
senticnet['desex'] = [-0.785, 0, 0.91, -0.917, '#angry', '#disgusting', -0.871, 'castrate', 'neuter', 'alter', 'emasculate', 'spay']
senticnet['desiccated'] = [0.789, -0.58, 0, 0.715, '#joyful', '#admirable', 0.695, 'preserved', 'aged', 'lyophilized', 'cured', 'candied']
senticnet['desideratum'] = [0.847, -0.612, 0, 0.932, '#joyful', '#admirable', 0.797, 'necessity', 'requirement', 'essential', 'requisite', 'necessary']
senticnet['design'] = [0.041, 0.157, 0, 0.164, '#interesting', '#admirable', 0.121, 'craft', 'artwork', 'art', 'like_paint', 'floral']
senticnet['design_software'] = [0, 0.841, 0, 0.804, '#interesting', '#admirable', 0.548, 'fix_computer', 'write_program', 'add_up_column_number', 'program_computer', 'sell_new_book']
senticnet['design_wall'] = [0.046, 0.092, 0, 0.089, '#interesting', '#admirable', 0.076, 'creativity', 'creative', 'wall_decoration', 'decorate_room', 'decorate_wall']
senticnet['designate'] = [-0.728, 0, 0.918, -0.546, '#sad', '#angry', -0.731, 'demote', 'depute', 'reduce', 'sideline', 'delegate']
senticnet['designate_driver'] = [0, 0.081, 0, 0.071, '#interesting', '#admirable', 0.051, 'go_bar', 'valet', 'drink_a_lot_of_beer', 'go_party', 'drink_alcohol']
senticnet['designation'] = [0.128, 0.286, -0.236, 0.251, '#interesting', '#admirable', 0.143, 'status', 'social_rank', 'social_status', 'distinction', 'champion']
senticnet['designative'] = [0.904, -0.588, 0, 0.736, '#joyful', '#admirable', 0.743, 'naming', 'appellative', 'denotative', 'extensional', 'referent']
senticnet['designer'] = [0.128, 0.286, -0.236, 0.251, '#interesting', '#admirable', 0.143, 'fancy_clothes', 'design', 'clothes', 'style', 'fashion']
senticnet['desirable'] = [0.932, 0, 0, 0.869, '#joyful', '#admirable', 0.6, 'given', 'cease_fire', 'good_quality', 'set_goal', 'benefit']
senticnet['desire'] = [0.846, 0.995, 0, 0, '#joyful', '#interesting', 0.614, 'yearn', 'demand', 'want_badly', 'affection', 'need']
senticnet['desire_eat'] = [0.053, 0.145, -0.112, 0.124, '#interesting', '#admirable', 0.07, 'hunger_go_away', 'eat_tasty_food', 'cook_breakfast', 'hungry', 'eat_together']
senticnet['desire_education'] = [0.757, 0, 0, 0, '#joyful', '#joyful', 0.252, 'add_knowledge', 'learn_information', 'learn_knowledge', 'learn', 'become_intelligent']
senticnet['desire_entertain'] = [0, 0.07, -0.174, -0.111, '#scared', '#disgusting', -0.072, 'make_others_laugh', 'tell_others', 'laughter', 'good_feeling', 'become_excited']
senticnet['desire_entertainment'] = [0.128, 0.286, -0.236, 0.251, '#interesting', '#admirable', 0.143, 'good_feeling', 'desire', 'entertainment', 'entertain', 'desire_entertain']
senticnet['desire_help'] = [0, 0, 0, 0.768, '#admirable', '#admirable', 0.256, 'offer_help', 'meet_greet', 'reply_question', 'lower_expectation', 'erase_blackboard']
senticnet['desire_information'] = [0.924, 0.968, 0, 0.876, '#joyful', '#interesting', 0.923, 'listen', 'create_sound', 'interesting_topic', 'good_music', 'loose_track_time']
senticnet['desire_knowledge'] = [0, 0.945, 0, 0.795, '#interesting', '#admirable', 0.58, 'plan_trip', 'proselytize', 'curiosity', 'desire_social_interaction', 'travel_abroad']
senticnet['desire_learn'] = [0, 0.945, 0, 0.795, '#interesting', '#admirable', 0.58, 'desire', 'comprehension', 'desire_education', 'desire_knowledge', 'good_feeling']
senticnet['desire_live'] = [-0.994, 0, -0.944, 0, '#sad', '#scared', -0.646, 'form_sentence', 'die_only_once', 'need_companionship', 'wave_flag', 'hurt_animal']
senticnet['desire_money'] = [-0.061, 0, 0, -0.072, '#sad', '#disgusting', -0.044, 'need_earn_money', 'earn_money', 'support_family', 'want_money', 'make_money']
senticnet['desire_social_interaction'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'become_cultured', 'learn_current_event', 'interest_subject', 'learn', 'gain_knowledge']
senticnet['desire_succeed'] = [0.73, 0.726, 0, 0, '#joyful', '#interesting', 0.485, 'love', 'love_another_person', 'lust', 'passion', 'sexuality']
senticnet['desire_travel'] = [0.839, 0.705, 0, 0, '#joyful', '#interesting', 0.515, 'desire_social_interaction', 'become_cultured', 'desire', 'travel', 'plan_trip']
senticnet['desire_win'] = [0, 0.964, 0, 0.724, '#interesting', '#admirable', 0.563, 'rule_world', 'competitive', 'experience_life', 'want_to_win', 'enjoy_challenge']
senticnet['desirous'] = [0.919, -0.717, 0, 0.569, '#joyful', '#surprising', 0.735, 'appetent', 'avid', 'thirsty', 'devouring', 'envious']
senticnet['desk'] = [0, -0.124, 0, 0.105, '#surprising', '#admirable', 0.076, 'mail_package', 'hang_wall', 'stationery_store', 'postoffice', 'desk_drawer']
senticnet['desk_drawer'] = [0, -0.124, 0, 0.105, '#surprising', '#admirable', 0.076, 'mail_package', 'hang_wall', 'stationery_store', 'postoffice', 'desk']
senticnet['desk_tray'] = [0, -0.124, 0, 0.105, '#surprising', '#admirable', 0.076, 'blotter', 'drawer', 'file_box', 'card_case', 'letter_scale']
senticnet['desktop'] = [0, -0.821, 0, 0.902, '#surprising', '#admirable', 0.574, 'processor', 'browse_web', 'laptop', 'computer_type', 'language']
senticnet['desolate'] = [-0.887, 0, 0.693, -0.838, '#sad', '#disgusting', -0.806, 'maroon', 'strand', 'walk_out', 'expose', 'ditch']
senticnet['desolation'] = [-0.696, 0.32, -0.389, -0.089, '#sad', '#scared', -0.285, 'forlornly', 'forlornness', 'forlorn', 'weepiness', 'tearful']
senticnet['despair'] = [-0.984, 0, 0, -0.941, '#sad', '#disgusting', -0.642, 'humiliation', 'upset', 'shame', 'unhappiness', 'loneliness']
senticnet['despairing'] = [-0.838, 0, 0, -0.919, '#sad', '#disgusting', -0.586, 'dispiritedly', 'hopelessness', 'hopelessly', 'pessimism', 'pessimistically']
senticnet['despairingly'] = [-0.708, 0.304, -0.361, -0.108, '#sad', '#scared', -0.291, 'despondently', 'disheartened', 'feel_down', 'demoralized', 'forlorn']
senticnet['desperate'] = [-0.799, 0, 0.801, 0, '#sad', '#angry', -0.533, 'hysteria', 'anxious', 'terrible', 'concerned', 'humiliate']
senticnet['desperation'] = [-0.091, 0.088, -0.137, 0.061, '#sad', '#scared', -0.026, 'alcoholism', 'party', 'use_party', 'become_intoxicated', 'company_come']
senticnet['despisal'] = [-0.072, 0.187, 0.64, -0.64, '#angry', '#disgusting', -0.388, 'despising', 'misocainea', 'amok', 'amuck', 'murderously']
senticnet['despise'] = [-0.1, 0.158, 0.638, -0.668, '#angry', '#disgusting', -0.416, 'scorn', 'offense', 'disgust', 'loathe', 'offensive']
senticnet['despising'] = [-0.072, 0.187, 0.64, -0.64, '#angry', '#disgusting', -0.388, 'despisal', 'misocainea', 'amok', 'amuck', 'murderously']
senticnet['despite'] = [-0.115, 0.188, 0.608, -0.633, '#angry', '#disgusting', -0.389, 'contempt', 'disincline', 'disinclination', 'disinclined', 'indispose']
senticnet['despiteful'] = [-0.031, 0.157, 0.698, -0.661, '#angry', '#disgusting', -0.411, 'vengefulness', 'vindictively', 'vengefully', 'revengefully', 'vindictive']
senticnet['despondence'] = [-0.826, 0.226, -0.461, -0.051, '#sad', '#scared', -0.371, 'heartsickness', 'disconsolateness', 'heartsick', 'despondent', 'despondency']
senticnet['despondency'] = [-0.826, 0.226, -0.461, -0.051, '#sad', '#scared', -0.371, 'despondence', 'heartsickness', 'disconsolateness', 'heartsick', 'despondent']
senticnet['despondent'] = [-0.826, 0.226, -0.461, -0.051, '#sad', '#scared', -0.371, 'despondence', 'heartsickness', 'disconsolateness', 'heartsick', 'despondency']
senticnet['despondently'] = [-0.708, 0.304, -0.361, -0.108, '#sad', '#scared', -0.291, 'despairingly', 'disheartened', 'feel_down', 'demoralized', 'forlorn']
senticnet['despot'] = [0.029, 0.079, 0, 0.063, '#interesting', '#admirable', 0.057, 'king', 'duchess', 'sultan', 'royal_leader', 'emperor']
senticnet['despotic'] = [-0.551, 0, 0.931, -0.74, '#angry', '#disgusting', -0.741, 'totalitarian', 'authoritarian', 'dictatorial', 'undemocratic', 'monarchal']
senticnet['despotism'] = [-0.685, 0, 0.597, -0.848, '#sad', '#disgusting', -0.71, 'dominance', 'tyrant', 'despot', 'autocrat', 'dictator']
senticnet['dessert'] = [0.092, -0.051, 0, 0, '#joyful', '#surprising', 0.048, 'bake_treat', 'round_pastry', 'bake_good', 'bake_goods', 'sweet_food']
senticnet['destination'] = [0, 0.14, 0, 0.172, '#interesting', '#admirable', 0.104, 'last', 'go_on_trip', 'go_abroad', 'result_injury', 'elsewhere']
senticnet['destiny'] = [0, 0.793, 0, 0.932, '#interesting', '#admirable', 0.575, 'enter_contract', 'believe', 'give_help', 'karma', 'fate']
senticnet['destitution'] = [-0.617, 0, 0.712, -0.861, '#angry', '#disgusting', -0.73, 'impoverishment', 'deprivation', 'indigence', 'penury', 'pauperism']
senticnet['destroy'] = [-0.114, -0.011, -0.103, -0.111, '#sad', '#disgusting', -0.106, 'cause_injury', 'raze', 'hurt_person', 'stab', 'damage']
senticnet['destroy_build'] = [-0.133, -0.014, -0.087, -0.11, '#sad', '#disgusting', -0.105, 'destroy_live', 'death_destruction', 'suffocate', 'hurt_person', 'murder']
senticnet['destroy_building'] = [-0.856, 0, -0.723, 0, '#sad', '#scared', -0.526, 'destroy_city', 'destroy_target', 'kill', 'kill_pest', 'kill_life']
senticnet['destroy_city'] = [-0.839, 0, 0, -0.776, '#sad', '#disgusting', -0.538, 'destroy_target', 'kill_life', 'kill_pest', 'murder_another_person', 'kill']
senticnet['destroy_enemy'] = [0, 0, 0.854, -0.857, '#angry', '#disgusting', -0.57, 'fight_enemy', 'conquer_nation', 'bigotry', 'genocide', 'wage_war']
senticnet['destroy_evidence'] = [0, 0, 0.863, -0.756, '#angry', '#disgusting', -0.54, 'break_law', 'hide_evidence', 'take_life', 'commit_crime', 'feel_remorse']
senticnet['destroy_home'] = [-0.933, 0, 0, -0.718, '#sad', '#disgusting', -0.55, 'kill_life', 'destroy_city', 'destroy_target', 'kill_people', 'kill_pest']
senticnet['destroy_live'] = [-0.109, -0.058, -0.048, -0.206, '#sad', '#disgusting', -0.102, 'death_destruction', 'murder', 'get_rid_of_enemy', 'defend_oneself', 'parry']
senticnet['destroy_property'] = [-0.781, 0, 0, -0.798, '#sad', '#disgusting', -0.526, 'destroy_home', 'die_out', 'kill_life', 'cause_fire', 'destroy_city']
senticnet['destroy_target'] = [-0.939, 0, 0, -0.979, '#sad', '#disgusting', -0.639, 'destroy_city', 'kill', 'kill_pest', 'murder_another_person', 'make_someone_sick']
senticnet['destroy_thing'] = [-0.907, 0, 0.425, -0.907, '#sad', '#disgusting', -0.746, 'damage', 'smash', 'break_thing', 'break', 'destroy']
senticnet['destroy_village'] = [-0.912, 0, 0.045, -0.905, '#sad', '#disgusting', -0.621, 'fire', 'burn', 'heat', 'flame', 'destroy']
senticnet['destroyed'] = [-0.622, 0, 0.863, -0.991, '#angry', '#disgusting', -0.825, 'spoilt', 'wrecked', 'impoverished', 'blighted', 'extinguished']
senticnet['destroyed_city'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'destroyed_home', 'after_fire', 'burned_thing', 'mess', 'count_damage']
senticnet['destroyed_home'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'after_fire', 'destroyed_city', 'burned_thing', 'mess', 'count_damage']
senticnet['destroyer'] = [0, 0, -0.138, -0.132, '#scared', '#disgusting', -0.09, 'firebomb', 'nuclear_weapon', 'nuclear_bomb', 'bomb', 'aerial_bomb']
senticnet['destruction'] = [-0.142, -0.008, -0.122, -0.21, '#sad', '#disgusting', -0.155, 'torture', 'demolish', 'maim', 'terminate', 'hurt_person']
senticnet['destructive'] = [0, 0, 0.967, -0.959, '#angry', '#disgusting', -0.642, 'dangerous', 'funny_look', 'uncontrollable', 'violent', 'dangerous_health']
senticnet['detached'] = [-0.091, 0.156, 0.661, -0.656, '#angry', '#disgusting', -0.417, 'isolated', 'set-apart', 'separated', 'distasteful', 'loathly']
senticnet['detachment'] = [-0.9, 0, 0, 0, '#sad', '#sad', -0.3, 'withdrawal', 'indifferently', 'apathetic', 'indifferent', 'concerned']
senticnet['detail'] = [0, 0.136, 0, 0.196, '#interesting', '#admirable', 0.111, 'describe', 'explain', 'answer', 'description', 'example']
senticnet['detect'] = [-0.043, 0.128, -0.117, 0.191, '#interesting', '#admirable', 0.053, 'hear_noise', 'hear_voice', 'echo', 'vibration', 'ear_activity']
senticnet['detectable'] = [0.958, -0.838, 0, 0.81, '#joyful', '#surprising', 0.869, 'discernible', 'perceptible', 'evident', 'noticeable', 'observable']
senticnet['detective'] = [0, 0.114, 0, 0.083, '#interesting', '#admirable', 0.066, 'solicitor', 'attorney', 'legal_person', 'felon', 'liar']
senticnet['detention'] = [-0.914, 0, 0.931, -0.724, '#sad', '#angry', -0.856, 'get_arrested', 'custody', 'incarceration', 'quarantine', 'prisoner']
senticnet['deteriorate'] = [-0.519, 0, 0.965, -0.953, '#angry', '#disgusting', -0.812, 'go_to_pot', 'go_to_dogs', 'dilapidate', 'decay', 'wear']
senticnet['deterioration'] = [-0.972, 0, 0.752, -0.834, '#sad', '#disgusting', -0.853, 'decay', 'wear', 'corrosion', 'devastation', 'dilapidation']
senticnet['determinant'] = [-0.849, 0, 0.627, -0.768, '#sad', '#disgusting', -0.748, 'difficulty', 'inspiration', 'cognitive_factor', 'determinative', 'divine_guidance']
senticnet['determinateness'] = [-0.571, 0, 0.713, -0.649, '#angry', '#disgusting', -0.644, 'sure_thing', 'foregone_conclusion', 'certainty', 'predictability', 'definiteness']
senticnet['determination'] = [0.952, 0.995, 0, 0, '#joyful', '#interesting', 0.649, 'effort', 'concentration', 'persistence', 'preparation', 'set_goal']
senticnet['determinative'] = [-0.849, 0, 0.627, -0.768, '#sad', '#disgusting', -0.748, 'difficulty', 'inspiration', 'determinant', 'cognitive_factor', 'divine_guidance']
senticnet['determine'] = [-0.076, 0.331, -0.111, 0.275, '#interesting', '#admirable', 0.14, 'intend', 'let', 'right', 'classify', 'selection']
senticnet['determine_guilt'] = [-0.071, 0.148, -0.09, 0.094, '#interesting', '#admirable', 0.027, 'pass_judgment', 'judgment', 'trial', 'justice', 'punish_criminal']
senticnet['determine_guilt_innocence'] = [0, 0.969, 0, 0.71, '#interesting', '#admirable', 0.56, 'become_judge', 'consider_evidence', 'decide_guilt', 'become_lawyer', 'negotiator']
senticnet['determine_health'] = [-0.15, 0.078, -0.303, 0, '#sad', '#scared', -0.125, 'diagnose_illness', 'cure_illness', 'check_health', 'sickness', 'emergency']
senticnet['determine_need'] = [0, 0.889, 0, 0.806, '#interesting', '#admirable', 0.565, 'solve_problem', 'keep_work', 'know_how', 'eureka', 'understand_problem']
senticnet['determine_size'] = [-0.076, 0.13, 0.045, 0.149, '#interesting', '#admirable', 0.053, 'calculation', 'redo', 'addition', 'define', 'multiply']
senticnet['determine_truth'] = [0, -0.092, 0, 0.08, '#surprising', '#admirable', 0.057, 'examine', 'analyze', 'find_lost_item', 'influence_public_decision', 'find_truth']
senticnet['determined'] = [0, 0, -0.943, -0.877, '#scared', '#disgusting', -0.607, 'find', 'ascertain', 'shape', 'mold', 'influence']
senticnet['determining'] = [0.698, -0.988, 0, 0.651, '#joyful', '#surprising', 0.779, 'fateful', 'deciding', 'determinant', 'determinative', 'decisive']
senticnet['determinist'] = [-0.55, 0, 0.58, -0.982, '#angry', '#disgusting', -0.704, 'fatalist', 'necessitarian', 'predestinarian', 'predestinationist', 'philosopher']
senticnet['deterrent'] = [-0.964, 0, 0.581, -0.792, '#sad', '#disgusting', -0.779, 'straitjacket', 'handicap', 'balk', 'baulk', 'impediment']
senticnet['deterrent_example'] = [-0.662, 0, 0.809, -0.655, '#sad', '#angry', -0.709, 'example', 'word_of_advice', 'lesson', 'object_lesson', 'advice']
senticnet['detest'] = [-0.092, 0.213, 0.596, -0.619, '#angry', '#disgusting', -0.365, 'hatefully', 'hateful', 'misanthropy', 'misopedia', 'misology']
senticnet['detestable'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repulsive', 'repugnant', 'detestably', 'abominably', 'odiously']
senticnet['detestably'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repulsive', 'repugnant', 'abominably', 'odiously', 'detestable']
senticnet['detestation'] = [-0.063, 0.183, 0.651, -0.642, '#angry', '#disgusting', -0.391, 'abhorrence', 'abomination', 'execration', 'loathing', 'odium']
senticnet['dethrone'] = [-0.956, 0, 0.673, -0.855, '#sad', '#disgusting', -0.828, 'discharge', 'free', 'disinvest', 'defrock', 'unfrock']
senticnet['detonate'] = [-0.968, 0, 0.394, -0.908, '#sad', '#disgusting', -0.757, 'explosion', 'get_hurt', 'blow_up', 'get_bomb', 'squib_bomb']
senticnet['detonation'] = [-0.846, 0, 0, -0.872, '#sad', '#disgusting', -0.573, 'inferno', 'forest_fire', 'fire_light', 'dismissal', 'wash_mouth_soap']
senticnet['detour'] = [-0.098, 0, 0.03, -0.04, '#sad', '#disgusting', -0.056, 'efficient', 'browser', 'find_computer', 'go_on-line', 'internet_connection']
senticnet['detractive'] = [-0.983, 0, 0.962, -0.956, '#sad', '#angry', -0.967, 'depreciative', 'depreciatory', 'falling', 'depreciating', 'decreasing']
senticnet['detractor'] = [0.899, -0.775, 0, 0.866, '#joyful', '#admirable', 0.847, 'unpleasant_person', 'disagreeable_person', 'cynic', 'disparager', 'depreciator']
senticnet['detrain'] = [0.861, -0.529, 0, 0.598, '#joyful', '#admirable', 0.663, 'exit', 'get_off', 'deplane', 'go_out', 'get_out']
senticnet['detriment'] = [-0.641, 0, 0.731, -0.524, '#sad', '#angry', -0.632, 'hurt', 'impairment', 'deformation', 'distortion', 'modification']
senticnet['detrition'] = [-0.657, 0, 0.597, -0.842, '#sad', '#disgusting', -0.699, 'wearing', 'erosion', 'eroding', 'eating_away', 'wearing_away']
senticnet['detritus'] = [-0.125, 0, -0.103, -0.038, '#sad', '#scared', -0.089, 'dog_poop', 'picnic', 'hike_trail', 'compost', 'wildlife']
senticnet['deuce'] = [-0.958, 0, 0.644, -0.7, '#sad', '#disgusting', -0.767, 'ejaculation', 'interjection', 'devil', 'expostulation', 'exclaiming']
senticnet['devaluate'] = [-0.641, 0, 0.805, -0.579, '#sad', '#angry', -0.675, 'worsen', 'aggravate', 'exacerbate', 'devalue', 'cheapen']
senticnet['devalue'] = [-0.641, 0, 0.805, -0.579, '#sad', '#angry', -0.675, 'worsen', 'aggravate', 'exacerbate', 'cheapen', 'devaluate']
senticnet['devastating'] = [-0.732, 0, 0.857, 0, '#sad', '#angry', -0.53, 'annihilating', 'undeferential', 'disrespectful', 'insolent', 'undutiful']
senticnet['devastation'] = [-0.874, 0, 0.889, -0.621, '#sad', '#angry', -0.795, 'ruination', 'ruin', 'deterioration', 'blight', 'impairment']
senticnet['develop'] = [0, 0.276, -0.121, 0.317, '#interesting', '#admirable', 0.157, 'make', 'manufacture', 'intend', 'correct', 'design']
senticnet['develop_city'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'traffic_rule', 'new_buildings', 'bicycle_area', 'good_transportation', 'control_road']
senticnet['develop_skill'] = [0.739, 0.825, 0, 0.782, '#interesting', '#admirable', 0.782, 'entertain_audience', 'gain_skill', 'entertain_others', 'personal_enjoyment', 'learn_play']
senticnet['develop_talent'] = [0.984, 0.979, 0, 0.812, '#joyful', '#interesting', 0.925, 'strong_relationship', 'complement', 'much_need', 'interest_job', 'good_sense_of_humor']
senticnet['developer'] = [-0.046, 0.121, 0, 0.178, '#interesting', '#admirable', 0.084, 'programming_bug', 'bug', 'code', 'uppercase_bug', 'bad']
senticnet['developing'] = [0.783, -0.606, 0, 0.512, '#joyful', '#surprising', 0.634, 'refinement', 'blowing', 'data_processing', 'development', 'processing']
senticnet['development'] = [0, 0.965, 0, 0.798, '#interesting', '#admirable', 0.588, 'enlarge', 'flourish', 'growth', 'get_large', 'get_big']
senticnet['deviance'] = [0.72, -0.59, 0, 0.619, '#joyful', '#admirable', 0.643, 'abnormalcy', 'abnormality', 'deflection', 'warp', 'chromosomal_aberration']
senticnet['deviant'] = [0.855, -0.522, 0, 0.978, '#joyful', '#admirable', 0.785, 'fetishist', 'lecher', 'lech', 'letch', 'satyr']
senticnet['deviate'] = [0, 0, 0.708, -0.747, '#angry', '#disgusting', -0.485, 'diverge', 'digress', 'drift', 'stray', 'slew']
senticnet['deviation'] = [-0.76, 0, 0.969, -0.554, '#sad', '#angry', -0.761, 'variant', 'flection', 'flexion', 'discrepancy', 'variation']
senticnet['device'] = [0.028, 0, 0, 0.131, '#joyful', '#admirable', 0.053, 'mechanical_complex_machine', 'mechanism', 'human_invention', 'machine', 'complex_machine']
senticnet['device_measure_time'] = [-0.022, -0.01, 0.058, 0, '#sad', '#angry', -0.023, 'time_tracker', 'show_time', 'timekeeper', 'timekeep', 'tell_time']
senticnet['devil'] = [0, 0, -0.733, -0.872, '#scared', '#disgusting', -0.535, 'aggravated', 'exacerbate', 'exasperation', 'aggravate', 'provoked']
senticnet['devilment'] = [-0.704, 0, 0.621, -0.546, '#sad', '#angry', -0.624, 'misbehavior', 'misdeed', 'hell', 'vandalism', 'hooliganism']
senticnet['devilry'] = [-0.522, 0, 0.621, -0.919, '#angry', '#disgusting', -0.687, 'deviltry', 'iniquity', 'irreverence', 'foul_play', 'sexual_immorality']
senticnet['deviltry'] = [-0.595, 0, 0.567, -0.959, '#sad', '#disgusting', -0.707, 'devilment', 'roguery', 'mischief', 'shenanigan', 'hooliganism']
senticnet['deviousness'] = [-0.629, 0, 0.69, -0.765, '#angry', '#disgusting', -0.695, 'indirectness', 'mediacy', 'mediateness', 'characteristic', 'allusiveness']
senticnet['devisee'] = [-0.653, 0, 0.808, -0.699, '#angry', '#disgusting', -0.72, 'pensionary', 'pensioner', 'beneficiary', 'legatee', 'recipient']
senticnet['devolution'] = [0.596, -0.66, 0, 0.663, '#surprising', '#admirable', 0.64, 'macular_degeneration', 'attack', 'obsolescence', 'process', 'physical_process']
senticnet['devote'] = [0.684, -0.811, 0, 0.957, '#surprising', '#admirable', 0.817, 'vow', 'consecrate', 'apply', 'rededicate', 'use']
senticnet['devoted'] = [0.521, 0.677, -0.276, 0.273, '#joyful', '#interesting', 0.398, 'devotedness', 'puppy_love', 'calf_love', 'infatuation', 'amorous']
senticnet['devotedness'] = [0.521, 0.677, -0.276, 0.273, '#joyful', '#interesting', 0.398, 'devoted', 'puppy_love', 'calf_love', 'infatuation', 'amorous']
senticnet['devotion'] = [0, 0, 0, 0.797, '#admirable', '#admirable', 0.266, 'optimism', 'adoration', 'positive', 'sympathetic', 'preference']
senticnet['devoured'] = [0, 0, -0.9, -0.84, '#scared', '#disgusting', -0.58, 'consume', 'guttle', 'go_through', 'down', 'raven']
senticnet['devourer'] = [0.826, -0.655, 0, 0.587, '#joyful', '#surprising', 0.689, 'scoffer', 'vegetarian', 'eater', 'diner', 'dunker']
senticnet['devouring'] = [0.919, -0.717, 0, 0.569, '#joyful', '#surprising', 0.735, 'appetent', 'avid', 'thirsty', 'desirous', 'envious']
senticnet['devout'] = [0, 0.917, 0, 0.833, '#interesting', '#admirable', 0.583, 'seriously', 'earnestness', 'earnestly', 'seriousness', 'in_earnest']
senticnet['devoutness'] = [0.674, -0.798, 0, 0.981, '#surprising', '#admirable', 0.818, 'piety', 'piousness', 'pietism', 'religiosity', 'religionism']
senticnet['dew'] = [0.025, -0.06, -0.056, 0.161, '#surprising', '#admirable', 0.063, 'cloudy', 'up_high', 'weather_condition', 'carry_water', 'hazy']
senticnet['dewberry'] = [-0.922, 0, 0.912, -0.942, '#sad', '#disgusting', -0.925, 'true_blackberry', 'sand_blackberry', 'blackberry_bush', 'blackberry', 'running_blackberry']
senticnet['dewberry_bush'] = [-0.922, 0, 0.912, -0.942, '#sad', '#disgusting', -0.925, 'true_blackberry', 'sand_blackberry', 'dewberry', 'blackberry_bush', 'running_blackberry']
senticnet['dexterity'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'use_finger', 'manual_dexterity', 'use_hand', 'coordination', 'bend_over']
senticnet['dextroglucose'] = [0.677, -0.545, 0, 0.587, '#joyful', '#admirable', 0.603, 'glucosamine', 'corn_sugar', 'dextrose', 'glucose', 'grape_sugar']
senticnet['dextrose'] = [0.677, -0.545, 0, 0.587, '#joyful', '#admirable', 0.603, 'glucosamine', 'corn_sugar', 'glucose', 'dextroglucose', 'grape_sugar']
senticnet['diabetes'] = [-0.385, -0.129, -0.066, -0.376, '#sad', '#disgusting', -0.233, 'chicken_pox', 'influenza', 'disability', 'brain_tumor', 'lyme_disease']
senticnet['diabetes_medicine'] = [-0.903, 0, 0.143, -0.903, '#sad', '#disgusting', -0.65, 'disease', 'sickness', 'illness', 'diabetes', 'diabetes_mellitus']
senticnet['diabetes_mellitus'] = [-0.903, 0, 0.143, -0.903, '#sad', '#disgusting', -0.65, 'disease', 'sickness', 'illness', 'diabetes', 'diabetes_medicine']
senticnet['diacetylmorphine'] = [-0.7, 0, 0.698, -0.578, '#sad', '#angry', -0.659, 'smack', 'hell_dust', 'nose_drops', 'thunder', 'skag']
senticnet['diacritic'] = [0.902, -0.855, 0, 0.898, '#joyful', '#admirable', 0.885, 'discerning', 'discriminating', 'discriminatingal', 'discriminative', 'selective']
senticnet['diacritical'] = [0.902, -0.855, 0, 0.898, '#joyful', '#admirable', 0.885, 'discerning', 'diacritic', 'discriminating', 'discriminative', 'selective']
senticnet['diadem'] = [-0.626, 0, 0.961, -0.544, '#sad', '#angry', -0.71, 'crown', 'jeweled_headdress', 'tiara', 'headdress', 'headgear']
senticnet['diagnosable'] = [0.935, -0.958, 0, 0.949, '#surprising', '#admirable', 0.947, 'acknowledgeable', 'specifiable', 'recognizable', 'identifiable', 'classifiable']
senticnet['diagnose'] = [0.722, -0.872, 0, 0.9, '#surprising', '#admirable', 0.831, 'study', 'explore', 'analyze', 'examine', 'canvass']
senticnet['diagnose_illness'] = [0, 0, -0.862, -0.731, '#scared', '#disgusting', -0.531, 'check_health', 'determine_health', 'stay_well', 'maintain_health', 'eat_well']
senticnet['diagnosis'] = [0.818, -0.696, 0, 0.657, '#joyful', '#surprising', 0.724, 'medical_diagnosis', 'blood_typing', 'check_up', 'hospital', 'designation']
senticnet['diagnostic_assay'] = [0.747, -0.581, 0, 0.92, '#joyful', '#admirable', 0.749, 'assay', 'biopsy', 'cloze_procedure', 'cloze_test', 'fecal_occult_test']
senticnet['diagnostic_test'] = [0.909, -0.815, 0, 0.781, '#joyful', '#surprising', 0.835, 'assay', 'biopsy', 'cloze_procedure', 'cloze_test', 'fecal_occult_test']
senticnet['diagonal'] = [0.023, 0.113, 0.053, 0.153, '#interesting', '#admirable', 0.079, 'high', 'high_land', 'incline_plane', 'top', 'altitude']
senticnet['diagram'] = [0, 0.15, 0.067, 0.118, '#interesting', '#admirable', 0.067, 'representation', 'outline', 'arithmetic', 'click', 'list_number']
senticnet['diagrammatic'] = [0.716, -0.78, 0, 0.539, '#joyful', '#surprising', 0.678, 'depicted', 'pictured', 'portrayed', 'described', 'delineated']
senticnet['dial'] = [0, 0.899, 0, 0.828, '#interesting', '#admirable', 0.576, 'find_phone_number', 'dial_phone_number', 'pick_up_telephone_receiver', 'keypad', 'dial_telephone']
senticnet['dial_number'] = [0, 0.777, 0, 0.973, '#interesting', '#admirable', 0.583, 'communicate', 'telephone', 'make_contact', 'attention', 'ask_question']
senticnet['dial_phone'] = [0.027, 0, 0.01, 0.142, '#joyful', '#admirable', 0.053, 'dial_telephone', 'phone_conversation', 'speak_loudly', 'telephone_ring', 'use_phone']
senticnet['dial_phone_number'] = [0, 0.736, 0, 0.797, '#interesting', '#admirable', 0.511, 'find_phone_number', 'dial', 'pick_up_telephone_receiver', 'keypad', 'dial_telephone']
senticnet['dial_telephone'] = [0.027, 0, 0.01, 0.142, '#joyful', '#admirable', 0.053, 'dial_phone', 'phone_conversation', 'speak_loudly', 'telephone_ring', 'use_phone']
senticnet['dialogue'] = [0.117, 0.066, 0, 0.239, '#joyful', '#admirable', 0.141, 'verbal', 'orate', 'discourse', 'talkative', 'verbalize']
senticnet['diamond'] = [0.021, 0, 0, 0.054, '#joyful', '#admirable', 0.025, 'gold', 'gem', 'manganese', 'potassium', 'silver']
senticnet['diamond_ring'] = [0, -0.885, 0, 0.972, '#surprising', '#admirable', 0.619, 'wedding_band', 'bell_sound', 'piece_of_jewelry', 'engage', 'engagement']
senticnet['diapason'] = [0.939, -0.717, 0, 0.775, '#joyful', '#admirable', 0.81, 'vox_angelica', 'voix_celeste', 'dulciana', 'pipe', 'organ_stop']
senticnet['diaper_dermatitis'] = [-0.726, 0, 0.778, -0.98, '#angry', '#disgusting', -0.828, 'actinic_dermatitis', 'hypericism', 'diaper_rash', 'dermatitis', 'seborrheic_dermatitis']
senticnet['diaper_rash'] = [-0.726, 0, 0.778, -0.98, '#angry', '#disgusting', -0.828, 'actinic_dermatitis', 'hypericism', 'dermatitis', 'diaper_dermatitis', 'seborrheic_dermatitis']
senticnet['diaphanous'] = [0, 0, -0.994, -0.974, '#scared', '#disgusting', -0.656, 'gauze-like', 'filmy', 'gauzy', 'gossamer', 'see-through']
senticnet['diaphoresis'] = [-0.584, 0, 0.773, -0.797, '#angry', '#disgusting', -0.718, 'perspiration', 'sweating', 'polyhidrosis', 'sudation', 'hidrosis']
senticnet['diaphragm'] = [0.021, 0, 0, 0.054, '#joyful', '#admirable', 0.025, 'nerve', 'liver', 'groin', 'scrotum', 'pancreas']
senticnet['diarrheal'] = [-0.994, 0, 0.859, -0.626, '#sad', '#angry', -0.826, 'lax', 'loose', 'unconstipated', 'diarrhoeal', 'diarrhetic']
senticnet['diarrhetic'] = [-0.994, 0, 0.859, -0.626, '#sad', '#angry', -0.826, 'lax', 'loose', 'diarrheal', 'diarrhoeal', 'unconstipated']
senticnet['diarrhoea'] = [-0.357, -0.135, -0.056, -0.384, '#sad', '#disgusting', -0.221, 'flab', 'toothache', 'brain_tumor', 'suffer_fool', 'bad_hair_day']
senticnet['diarrhoeal'] = [-0.994, 0, 0.859, -0.626, '#sad', '#angry', -0.826, 'lax', 'loose', 'diarrheal', 'unconstipated', 'diarrhetic']
senticnet['diary'] = [0, -0.948, 0, 0.705, '#surprising', '#admirable', 0.551, 'calendar_book', 'program', 'database', 'schedule', 'timetable']
senticnet['diathesis'] = [0.98, -0.614, 0, 0.598, '#joyful', '#surprising', 0.731, 'predisposition', 'hypersensitivity', 'susceptibility', 'susceptibleness', 'habitus']
senticnet['diatom'] = [-0.659, 0, 0.523, -0.739, '#sad', '#disgusting', -0.64, 'confervoid_algae', 'seaweed', 'golden_algae', 'alga', 'brown_algae']
senticnet['dice'] = [0, -0.753, 0, 0.859, '#surprising', '#admirable', 0.537, 'cube', 'block', 'ping_pong_paddle', 'ball_player', 'trapezoid']
senticnet['dick'] = [-0.357, -0.135, -0.056, -0.384, '#sad', '#disgusting', -0.221, 'bastard', 'idiot', 'asshole', 'fuck', 'motherfucker']
senticnet['dickey'] = [-0.968, 0, 0.624, -0.99, '#sad', '#disgusting', -0.861, 'vitiated', 'dicky', 'impaired', 'lessened', 'diminished']
senticnet['dickhead'] = [-0.667, 0, 0.595, -0.837, '#sad', '#disgusting', -0.7, 'bastard', 'disagreeable_person', 'mother_fucker', 'motherfucker', 'son_of_bitch']
senticnet['dicky'] = [-0.968, 0, 0.624, -0.99, '#sad', '#disgusting', -0.861, 'vitiated', 'impaired', 'dickey', 'lessened', 'diminished']
senticnet['dictation'] = [0.022, 0, 0, 0.171, '#joyful', '#admirable', 0.064, 'communicate', 'call', 'answer_back', 'retort', 'say']
senticnet['dictator'] = [-0.765, 0, -0.783, 0, '#sad', '#scared', -0.516, 'royal_leader', 'despot', 'emperor', 'monarch', 'king']
senticnet['dictatorial'] = [-0.551, 0, 0.931, -0.74, '#angry', '#disgusting', -0.741, 'totalitarian', 'authoritarian', 'undemocratic', 'despotic', 'monarchal']
senticnet['dictatorship'] = [0, 0, -0.776, -0.731, '#scared', '#disgusting', -0.502, 'dictator', 'submission', 'fear', 'boss', 'leadership']
senticnet['diction'] = [-0.611, 0, 0.73, -0.858, '#angry', '#disgusting', -0.733, 'verbalization', 'phrasing', 'verbiage', 'wording', 'phraseology']
senticnet['dictionary'] = [0, 0, -0.088, 0, '#scared', '#scared', -0.029, 'fable', 'story', 'fairy_story', 'saga', 'mythical']
senticnet['dicussion'] = [0, 0, 0.933, -0.887, '#angry', '#disgusting', -0.607, 'opinioned', 'let_heard', 'conquer_opponent', 'debate_politics', 'debate']
senticnet['didactics'] = [0.702, -0.607, 0, 0.784, '#joyful', '#admirable', 0.698, 'continuing_education', 'activity', 'course', 'extracurricular_activity', 'coeducation']
senticnet['die'] = [-0.332, -0.039, -0.268, -0.143, '#sad', '#scared', -0.235, 'capital_punishment', 'get_killed', 'death', 'take_life', 'seek_revenge']
senticnet['die_away'] = [-0.927, 0, 0.757, -0.905, '#sad', '#disgusting', -0.863, 'let_up', 'far', 'slack_off', 'abate', 'die']
senticnet['die_in_war'] = [0.046, 0.117, 0.772, -0.676, '#angry', '#disgusting', -0.428, 'die', 'lose_blood', 'lose_war', 'get_hit', 'kamikaze']
senticnet['die_like_caesar'] = [-0.743, 0, 0.755, 0, '#sad', '#angry', -0.499, 'kill_person', 'commit_murder', 'cause_heart_disease', 'kill', 'murder']
senticnet['die_only_once'] = [-0.094, 0.078, -0.091, 0, '#sad', '#scared', -0.036, 'fight_other', 'kill_specific_group', 'hurt_animal', 'dig_grave', 'eat_animal']
senticnet['die_out'] = [0, 0, -0.885, -0.928, '#scared', '#disgusting', -0.604, 'burn_house', 'destroy_home', 'kill_life', 'extinguish', 'warm_hand']
senticnet['die_painfully'] = [-0.723, 0, -0.848, -0.863, '#scared', '#disgusting', -0.811, 'end_life', 'death_penalty', 'arrest_police', 'feel_anger', 'stab_knife']
senticnet['die_person'] = [-0.973, 0, 0.061, -0.908, '#sad', '#disgusting', -0.647, 'end_of_life', 'pass_away', 'death', 'stop_living', 'lose_life']
senticnet['die_young'] = [-0.229, 0, -0.095, -0.165, '#sad', '#disgusting', -0.163, 'lower_standard', 'box_ear', 'go_scuba_dive', 'feel_stupid', 'hurt_animal']
senticnet['diesel'] = [0, 0, -0.08, 0, '#scared', '#scared', -0.027, 'petrol', 'butane', 'kerosene', 'fuel', 'gasoline']
senticnet['diet'] = [-0.637, 0, 0.819, -0.997, '#angry', '#disgusting', -0.818, 'light_diet', 'soft_diet', 'spoon_food', 'bland_diet', 'ulcer_diet']
senticnet['diet_coke'] = [0.704, -0.983, 0, 0, '#joyful', '#surprising', 0.562, 'carbonated_drink', 'sugar_free', 'coke', 'coke_zero', 'beverage']
senticnet['dieter'] = [-0.774, 0, 0.641, -0.659, '#sad', '#disgusting', -0.691, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['differ'] = [0.673, -0.598, 0, 0.594, '#joyful', '#surprising', 0.622, 'deviate', 'counterpoint', 'depart', 'contrast', 'diverge']
senticnet['difference'] = [-0.229, 0, -0.095, -0.165, '#sad', '#disgusting', -0.163, 'inequality', 'reject', 'discard', 'divergency', 'gap']
senticnet['difference_of_opinion'] = [-0.903, 0, 0.699, -0.931, '#sad', '#disgusting', -0.844, 'wrangle', 'dustup', 'quarrel', 'collision', 'row']
senticnet['different'] = [-0.047, 0.082, 0, 0.077, '#interesting', '#admirable', 0.037, 'small_flower', 'uneducated', 'beautiful', 'garden_plant', 'consider_beautiful']
senticnet['different_color'] = [0.03, 0.085, 0, 0, '#joyful', '#interesting', 0.038, 'favorite_color', 'colourful', 'rainbow', 'pink', 'happy']
senticnet['different_day'] = [0, 0, -0.904, -0.717, '#scared', '#disgusting', -0.54, 'get_out_of_bed', 'find_job', 'hard_work', 'work_oneself', 'start_new_day']
senticnet['different_shape'] = [0.029, 0.112, 0.013, 0.15, '#interesting', '#admirable', 0.093, 'part_of_body', 'human_organ', 'human_part', 'body_organ', 'body_type']
senticnet['different_type'] = [-0.044, 0, 0.041, 0, '#sad', '#angry', -0.028, 'water', 'atmosphere', 'water_spill', 'cool_water', 'still_water']
senticnet['differential'] = [-0.716, 0, 0.871, -0.75, '#angry', '#disgusting', -0.779, 'partial', 'curvature', 'partial_derivative', 'calculation', 'computation']
senticnet['differentiate'] = [-0.989, 0, 0.737, -0.922, '#sad', '#disgusting', -0.883, 'separate', 'severalize', 'contrast', 'decouple', 'dissociate']
senticnet['difficult'] = [0, 0, -0.747, -0.864, '#scared', '#disgusting', -0.537, 'tough', 'difficulty', 'impossible', 'scientific_term', 'scientific_method']
senticnet['difficult_concept'] = [0, 0, 0.837, -0.87, '#angry', '#disgusting', -0.569, 'difficult', 'problematic', 'hard_to_understand', 'tough', 'hard']
senticnet['difficult_play'] = [0.887, 0, 0, 0, '#joyful', '#joyful', 0.296, 'fun', 'like_sport', 'enjoy_sport', 'creepy', 'competition']
senticnet['difficult_problem'] = [-0.197, -0.157, -0.175, 0.113, '#sad', '#scared', -0.034, 'difficult_situation', 'electric_current', 'medical_condition', 'big_problem', 'static_electricity']
senticnet['difficult_situation'] = [-0.392, -0.279, -0.314, 0.264, '#sad', '#scared', -0.054, 'difficulty', 'difficult_problem', 'problem', 'unwanted_outcome', 'bad_behavior']
senticnet['difficultness'] = [-0.895, 0, 0.712, -0.804, '#sad', '#disgusting', -0.804, 'inconvenience', 'severity', 'severeness', 'troublesomeness', 'worriment']
senticnet['difficulty'] = [-0.407, -0.062, -0.238, 0.063, '#sad', '#scared', -0.173, 'difficult_situation', 'problem', 'cant', 'unsafe', 'bad_behavior']
senticnet['diffidence'] = [-0.702, 0, -0.961, 0, '#sad', '#scared', -0.554, 'diffidently', 'self-distrust', 'self-doubt', 'shyness', 'hardheartedness']
senticnet['diffident'] = [-0.968, 0, -0.732, 0, '#sad', '#scared', -0.567, 'shyness', 'timid', 'self-distrust', 'diffidence', 'diffidently']
senticnet['diffidently'] = [-0.883, 0, -0.769, 0, '#sad', '#scared', -0.551, 'self-distrust', 'self-doubt', 'diffidence', 'shyness', 'hardheartedness']
senticnet['diffuse'] = [0.968, -0.767, 0, 0.583, '#joyful', '#surprising', 0.773, 'riddle', 'spiritize', 'permeate', 'pervade', 'penetrate']
senticnet['diffusion'] = [0.223, -0.092, 0, 0.165, '#joyful', '#admirable', 0.16, 'dance', 'hook_up', 'go_club', 'old_dance', 'slow_dance']
senticnet['dig'] = [-0.18, 0, -0.107, 0, '#sad', '#scared', -0.096, 'dig_hole', 'plant_yard', 'cut_grass', 'hang_ceiling', 'plant_tree']
senticnet['dig_dirt'] = [-0.087, 0, 0, 0, '#sad', '#sad', -0.029, 'plant_garden', 'plant_flower', 'plant_seed', 'plant_yard', 'cut_grass']
senticnet['dig_gold'] = [-0.119, 0.068, -0.108, 0, '#sad', '#scared', -0.053, 'close_together', 'mine_gold', 'smoke_joint', 'feel_heat', 'bridge_difference']
senticnet['dig_grave'] = [-0.132, 0.082, -0.09, 0, '#sad', '#scared', -0.047, 'mine_diamond', 'bicycle_across_town', 'kill_specific_group', 'age_gracefully', 'hurt_animal']
senticnet['dig_ground'] = [-0.091, 0, -0.056, 0, '#sad', '#scared', -0.049, 'dig', 'work', 'hard_work', 'settle', 'job']
senticnet['dig_hole'] = [-0.249, 0, -0.185, -0.075, '#sad', '#scared', -0.17, 'dig_grave', 'eat_animal', 'say_prayer', 'hurt_animal', 'wear_skirt']
senticnet['dig_out'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'find_out', 'unmask', 'unearth', 'become_aware', 'dish_out']
senticnet['dig_tunnel'] = [0, 0, 0.862, -0.794, '#angry', '#disgusting', -0.552, 'social_insect', 'big_mouse', 'rodent', 'small_animal', 'vermin']
senticnet['dig_up'] = [-0.081, 0.072, -0.121, 0, '#sad', '#scared', -0.043, 'burn_up', 'shine_light', 'dig_gold', 'light_up', 'shine_car']
senticnet['digest'] = [0.951, -0.806, 0, 0.501, '#joyful', '#surprising', 0.753, 'understand', 'twig', 'apprehend', 'tumble', 'intuit']
senticnet['digestion'] = [0.755, -0.713, 0, 0.972, '#joyful', '#admirable', 0.813, 'digest', 'metabolism', 'grow_up', 'grow_healthy', 'healthy_lifestyle']
senticnet['digestive_system'] = [0, 0, 0, 0.968, '#admirable', '#admirable', 0.323, 'belly', 'nervous_system', 'human_body', 'stomach', 'tummy']
senticnet['digestive_tract'] = [0, 0, -0.929, -0.914, '#scared', '#disgusting', -0.614, 'alimentary_canal', 'alimentary_tract', 'digestive_tube', 'enteron', 'gastrointestinal_tract']
senticnet['digestive_tube'] = [0, 0, -0.856, -0.864, '#scared', '#disgusting', -0.573, 'alimentary_canal', 'alimentary_tract', 'enteron', 'digestive_tract', 'gastrointestinal_tract']
senticnet['digit'] = [0, 0, 0, 0.968, '#admirable', '#admirable', 0.323, 'figure', 'number', 'numeral', 'cipher', 'amount']
senticnet['digitalization'] = [-0.628, 0, 0.987, -0.742, '#angry', '#disgusting', -0.786, 'disinfection', 'treatment', 'hospice', 'medical_aid', 'bloodletting']
senticnet['digitate_date'] = [0.463, 0.561, -0.294, 0.281, '#joyful', '#interesting', 0.337, 'write_date', 'impress_date', 'use_computer', 'use_pen', 'date']
senticnet['dignified'] = [0.898, -0.562, 0, 0.513, '#joyful', '#surprising', 0.658, 'stately', 'imposing', 'courtly', 'distinguished', 'grand']
senticnet['dignity'] = [0, 0, 0, 0.968, '#admirable', '#admirable', 0.323, 'world_peace', 'compliment', 'honor', 'prefer', 'kindness']
senticnet['digress'] = [0, 0, -0.734, -0.873, '#scared', '#disgusting', -0.536, 'sidetrack', 'depart', 'wander', 'divagate', 'stray']
senticnet['dilapidate'] = [-0.519, 0, 0.965, -0.953, '#angry', '#disgusting', -0.812, 'go_to_pot', 'go_to_dogs', 'deteriorate', 'decay', 'wear']
senticnet['dilapidated'] = [-0.753, 0, 0.68, -0.599, '#sad', '#angry', -0.677, 'battered', 'bedraggled', 'hurt', 'derelict', 'damaged']
senticnet['dilapidation'] = [-0.972, 0, 0.752, -0.834, '#sad', '#disgusting', -0.853, 'decay', 'wear', 'corrosion', 'devastation', 'deterioration']
senticnet['dilatation'] = [0.777, -0.895, 0, 0.508, '#joyful', '#surprising', 0.727, 'stretching', 'enlarge', 'enlargement', 'get_bigger', 'distension']
senticnet['dilatoriness'] = [-0.689, 0, 0.82, -0.968, '#angry', '#disgusting', -0.826, 'deliberateness', 'leisureliness', 'procrastination', 'rate', 'pace']
senticnet['dilemma'] = [-0.118, 0, -0.052, 0, '#sad', '#scared', -0.057, 'bad_situation', 'anxiety', 'difficult_situation', 'predicament', 'difficulty']
senticnet['dilettante'] = [-0.982, 0, 0.937, -0.689, '#sad', '#angry', -0.869, 'sciolist', 'dabbler', 'mortal', 'amateur', 'bird_watcher']
senticnet['diligence'] = [0.215, 0.194, -0.204, 0.279, '#joyful', '#admirable', 0.161, 'use_match', 'gather_kindle', 'combustible_material', 'rub_two_stick_together', 'lighter']
senticnet['diligent'] = [0.877, -0.922, 0, 0.795, '#joyful', '#surprising', 0.865, 'study_material', 'study_lot', 'study_language', 'go_class', 'good_boy']
senticnet['dill_pickle'] = [0, 0, -0.812, -0.744, '#scared', '#disgusting', -0.519, 'caper', 'gherkin', 'relish', 'pickle', 'sweet_pickle']
senticnet['dilute'] = [-0.854, 0, 0.684, -0.798, '#sad', '#disgusting', -0.779, 'debase', 'adulterate', 'doctor_up', 'stretch', 'load']
senticnet['diluted'] = [-0.952, 0, 0.669, -0.978, '#sad', '#disgusting', -0.866, 'weakened', 'weak', 'white', 'washy', 'cut']
senticnet['dim'] = [-0.109, 0, -0.058, 0, '#sad', '#scared', -0.056, 'after_sundown', 'no_light', 'without_light', 'darkness', 'sun_down']
senticnet['dime'] = [0, 0.704, 0, 0.943, '#interesting', '#admirable', 0.549, 'franc', 'cent', 'dollar', 'shilling', 'banknote']
senticnet['dime_store'] = [0, 0, 0.012, -0.063, '#angry', '#disgusting', -0.025, 'shop_arcade', 'large_supermarket', 'large_food_store', 'health_food_store', 'vend_stand']
senticnet['dimension'] = [0, 0.822, 0, 0.92, '#interesting', '#admirable', 0.581, 'width', 'size', 'mass_measure', 'measure', 'gauge']
senticnet['dimensional'] = [-0.025, 0.091, 0, 0.152, '#interesting', '#admirable', 0.073, 'latex', 'wall_cover', 'two-dimensional', 'thick_liquid', 'cover_wall']
senticnet['dimethyl_ketone'] = [-0.046, 0.127, -0.121, 0.223, '#interesting', '#admirable', 0.061, 'medium', 'acetone', 'propanone', 'dissolvent', 'chlorobenzene']
senticnet['diminish'] = [0, 0, 0.728, -0.861, '#angry', '#disgusting', -0.53, 'remit', 'taper', 'drop_off', 'contract', 'break']
senticnet['diminish_own_hunger'] = [0, 0, 0, 0.867, '#admirable', '#admirable', 0.289, 'eat_like_pig', 'eat_cookie', 'eat_breakfast_in_bed', 'eat_breakfast', 'sate_hunger']
senticnet['diminished'] = [-0.978, 0, 0.584, -0.789, '#sad', '#disgusting', -0.784, 'remittent', 'decreased', 'weakened', 'faded', 'small']
senticnet['diminution'] = [-0.129, -0.058, 0, -0.134, '#sad', '#disgusting', -0.068, 'decrement', 'reduction', 'decrease', 'inferior', 'reduce']
senticnet['dimness'] = [0.906, -0.601, 0, 0.653, '#joyful', '#admirable', 0.72, 'opaqueness', 'faintness', 'blurriness', 'opacity', 'vagueness']
senticnet['dimple'] = [0, -0.026, 0.033, -0.089, '#angry', '#disgusting', -0.032, 'tooth', 'teeth', 'cliche', 'mouth', 'jaw']
senticnet['dine'] = [0.135, 0.065, 0, 0.082, '#joyful', '#admirable', 0.094, 'breakfast', 'delicious_food', 'dinner_meal', 'sandwich', 'burger_king']
senticnet['dine_room'] = [0.146, 0.095, -0.046, 0, '#joyful', '#interesting', 0.065, 'paper_menu', 'diner', 'cafe', 'restaurant', 'menu']
senticnet['dine_room_table'] = [0.054, -0.077, 0.025, 0, '#joyful', '#surprising', 0.035, 'table', 'cutlery', 'dine_table', 'restaurant', 'cafe']
senticnet['dine_table'] = [0.054, -0.077, 0.025, 0, '#joyful', '#surprising', 0.035, 'table', 'glass_front_cupboard', 'gate_leg_table', 'sideboard', 'dine_room_table']
senticnet['diner'] = [0.146, 0.095, -0.046, 0, '#joyful', '#interesting', 0.065, 'paper_menu', 'dine_room', 'cafe', 'restaurant', 'menu']
senticnet['dinge'] = [0.764, -0.619, 0, 0.878, '#joyful', '#admirable', 0.754, 'feculence', 'befoulment', 'defilement', 'dinginess', 'dirtiness']
senticnet['dinginess'] = [0.764, -0.619, 0, 0.878, '#joyful', '#admirable', 0.754, 'feculence', 'befoulment', 'defilement', 'dirtiness', 'dinge']
senticnet['dingy'] = [-0.798, 0.257, -0.471, -0.036, '#sad', '#scared', -0.349, 'gloomful', 'glooming', 'darkness', 'somberness', 'gloominess']
senticnet['dinner'] = [0.044, 0.08, 0, -0.03, '#joyful', '#interesting', 0.031, 'cook', 'festival', 'bake_pan', 'restaurant', 'food']
senticnet['dinner_meal'] = [0.937, 0, 0, 0.828, '#joyful', '#admirable', 0.588, 'prepare_ingredient', 'measure_ingredient', 'appetizer', 'meal_time', 'delicious_food']
senticnet['dinner_party'] = [0.098, -0.062, 0, -0.052, '#joyful', '#surprising', 0.036, 'family_activity', 'big_home', 'anarchy', 'play_sport', 'birthday_party']
senticnet['dinner_table'] = [0.052, -0.041, 0.024, 0, '#joyful', '#surprising', 0.023, 'table_set', 'meal_time', 'dinner', 'serve_dish', 'table']
senticnet['dinoflagellate'] = [0.807, -0.868, 0, 0.611, '#joyful', '#surprising', 0.762, 'costia', 'zoomastigote', 'zooflagellate', 'flagellate', 'hypermastigote']
senticnet['dip'] = [0.077, 0, 0, 0, '#joyful', '#joyful', 0.026, 'ginger', 'garlic', 'oat', 'savory', 'rye']
senticnet['diploma'] = [0, 0.155, 0, 0, '#interesting', '#interesting', 0.052, 'certificate', 'celsius', 'qualification', 'temperature_measure', 'temperature_measurement']
senticnet['diplomacy'] = [0, 0.098, 0, 0.08, '#interesting', '#admirable', 0.059, 'talk_person', 'get_word_out', 'talk_another_person', 'remember_name', 'greet_person']
senticnet['diplomatic_immunity'] = [0.73, -0.569, 0, 0.621, '#joyful', '#admirable', 0.64, 'amnesty', 'unsusceptibility', 'exemption', 'indemnity', 'impunity']
senticnet['dipsomaniac'] = [0.556, -0.791, 0, 0.755, '#surprising', '#admirable', 0.701, 'lush', 'alcoholic', 'alky', 'rummy', 'boozer']
senticnet['dire'] = [-0.744, 0, -0.831, 0, '#sad', '#scared', -0.525, 'fearsome', 'dreaded', 'direful', 'frightening', 'horrendous']
senticnet['direct'] = [0.05, 0.166, -0.071, 0.152, '#interesting', '#admirable', 0.099, 'halt', 'red_light', 'director', 'finish', 'direction']
senticnet['direct_person'] = [0.05, 0.166, -0.071, 0.152, '#interesting', '#admirable', 0.099, 'direct', 'person', 'outspoken', 'frank', 'candid']
senticnet['direct_play'] = [0, 0.769, 0, 0, '#interesting', '#interesting', 0.256, 'directing_music', 'quiet_child', 'face_music', 'correct_mistake', 'give_signal']
senticnet['direct_tide'] = [0.632, -0.613, 0, 0.525, '#joyful', '#surprising', 0.59, 'neap_tide', 'neap', 'springtide', 'high_tide', 'tide']
senticnet['direct_traffic'] = [0, 0.769, 0, 0, '#interesting', '#interesting', 0.256, 'stop_suspect', 'traffic_police', 'traffic_jam', 'stop_crime', 'fine_violator']
senticnet['directing_music'] = [0, 0.769, 0, 0, '#interesting', '#interesting', 0.256, 'direct_play', 'opera', 'face_music', 'correct_mistake', 'give_signal']
senticnet['direction'] = [0, 0.175, 0, 0.231, '#interesting', '#admirable', 0.135, 'compass_direction', 'go_straight', 'end_point', 'eight_sides', 'red_light']
senticnet['directionality'] = [-0.596, 0, 0.6, -0.519, '#sad', '#angry', -0.572, 'asymmetry', 'dissymmetry', 'imbalance', 'directivity', 'radial_asymmetry']
senticnet['directionless'] = [-0.997, 0, 0.658, -0.736, '#sad', '#disgusting', -0.797, 'adrift', 'afloat', 'aimless', 'purposeless', 'planless']
senticnet['directions'] = [0.078, 0.134, 0.011, 0.108, '#interesting', '#admirable', 0.103, 'find_house', 'home', 'house', 'find_car', 'find_building']
senticnet['directivity'] = [-0.596, 0, 0.6, -0.519, '#sad', '#angry', -0.572, 'asymmetry', 'dissymmetry', 'imbalance', 'radial_asymmetry', 'directionality']
senticnet['directness'] = [0.772, -0.953, 0, 0.89, '#surprising', '#admirable', 0.872, 'downrightness', 'straightforwardness', 'characteristic', 'immediacy', 'immediateness']
senticnet['director'] = [-0.043, 0.189, 0, 0.066, '#interesting', '#admirable', 0.071, 'label', 'percentage', 'rate', 'money_relate', 'boss']
senticnet['director_chair'] = [0.934, 0, 0, 0.818, '#joyful', '#admirable', 0.584, 'director', 'shooting_movie', 'actor', 'important_person', 'movie']
senticnet['directory'] = [0, 0.175, 0, 0.231, '#interesting', '#admirable', 0.135, 'list', 'schedule', 'index', 'agenda', 'register']
senticnet['direful'] = [-0.983, 0, -0.923, 0, '#sad', '#scared', -0.635, 'dire', 'fearsome', 'dreaded', 'frightening', 'horrendous']
senticnet['dirigible'] = [0.5, -0.9, 0, 0.525, '#surprising', '#admirable', 0.642, 'administrable', 'controllable', 'governable', 'steerable', 'manageable']
senticnet['dirndl'] = [-0.531, 0, 0.569, -0.776, '#angry', '#disgusting', -0.625, 'pinafore', 'pinny', 'dress', 'gown', 'muumuu']
senticnet['dirt'] = [-0.039, -0.01, 0.026, -0.042, '#sad', '#disgusting', -0.032, 'soil', 'ground', 'mud', 'ground_cover', 'footprint']
senticnet['dirt_floor'] = [-0.037, -0.008, 0.066, 0, '#sad', '#angry', -0.032, 'dirt', 'allergy', 'dust', 'wet_floor', 'insect']
senticnet['dirt_soil'] = [-0.056, 0.076, 0, 0.107, '#interesting', '#admirable', 0.042, 'cold_night', 'terrain', 'soil', 'underfoot', 'earth']
senticnet['dirtiness'] = [0.764, -0.619, 0, 0.878, '#joyful', '#admirable', 0.754, 'feculence', 'befoulment', 'defilement', 'dinginess', 'dinge']
senticnet['dirty'] = [0, 0, 0.943, -0.8, '#angry', '#disgusting', -0.581, 'fight_fire', 'soapy', 'feel_dirty', 'smell_clean', 'filthy']
senticnet['dirty_animal'] = [-0.997, 0, 0.612, -0.99, '#sad', '#disgusting', -0.866, 'dog_flea', 'flea', 'dirty_cat', 'dirty_pet', 'dirty_dog']
senticnet['dirty_cat'] = [-0.997, 0, 0.612, -0.99, '#sad', '#disgusting', -0.866, 'dirty_animal', 'flea', 'dog_flea', 'dirty_pet', 'dirty_dog']
senticnet['dirty_clothes'] = [0, 0, 0.94, -0.875, '#angry', '#disgusting', -0.605, 'sort_clothes', 'lock_front_door', 'dress_occasion', 'basket_laundry', 'laundry']
senticnet['dirty_dish'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'faucet_overflow', 'hot_faucet', 'hot_tap', 'faucet', 'washcloth']
senticnet['dirty_dog'] = [-0.997, 0, 0.612, -0.99, '#sad', '#disgusting', -0.866, 'dirty_animal', 'flea', 'dirty_cat', 'dirty_pet', 'dog_flea']
senticnet['dirty_floor'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'flat', 'bucket_overflow', 'spill_over', 'float', 'spoil_wood_floor']
senticnet['dirty_house'] = [0, 0, 0.933, -0.866, '#angry', '#disgusting', -0.6, 'mess', 'disgusting', 'inability_host', 'dirty_kitchen', 'dirty_stuff']
senticnet['dirty_joke'] = [0.628, -0.533, 0, 0.782, '#joyful', '#admirable', 0.648, 'joke', 'jape', 'jest', 'gag', 'laugh']
senticnet['dirty_kitchen'] = [0, 0, 0.933, -0.866, '#angry', '#disgusting', -0.6, 'mess', 'trap', 'snake_belly', 'dirty_house', 'cornfield']
senticnet['dirty_laundry'] = [-0.045, 0, -0.08, -0.078, '#scared', '#disgusting', -0.068, 'wheelchair', 'old_photograph', 'wife', 'hot_chick', 'mommy']
senticnet['dirty_magazine'] = [0, -0.064, 0.097, -0.098, '#angry', '#disgusting', -0.044, 'slipper', 'old_sock', 'storage_item', 'dirty_sock', 'gay_person']
senticnet['dirty_pet'] = [-0.997, 0, 0.612, -0.99, '#sad', '#disgusting', -0.866, 'dirty_animal', 'flea', 'dirty_cat', 'dog_flea', 'dirty_dog']
senticnet['dirty_pool'] = [-0.726, 0, 0.778, -0.98, '#angry', '#disgusting', -0.828, 'dirty_tricks', 'activity', 'easiness', 'aggression', 'doings']
senticnet['dirty_sock'] = [0, 0, 0, -0.924, '#disgusting', '#disgusting', -0.308, 'dirty_magazine', 'dust_mite', 'cookie_crumb', 'old_sock', 'storage_box']
senticnet['dirty_story'] = [0.611, -0.732, 0, 0.572, '#joyful', '#surprising', 0.638, 'joke', 'jape', 'jest', 'gag', 'laugh']
senticnet['dirty_stuff'] = [0, 0, 0.933, -0.866, '#angry', '#disgusting', -0.6, 'mess', 'disgusting', 'dirty', 'dirty_kitchen', 'dirty_house']
senticnet['dirty_trick'] = [0.9, -0.802, 0, 0.568, '#joyful', '#surprising', 0.757, 'joke', 'antic', 'prank', 'trick', 'caper']
senticnet['dirty_tricks'] = [-0.726, 0, 0.778, -0.98, '#angry', '#disgusting', -0.828, 'doings', 'activity', 'easiness', 'aggression', 'dirty_pool']
senticnet['dirty_water'] = [-0.726, 0, 0.778, -0.98, '#angry', '#disgusting', -0.828, 'squirt', 'puddle', 'mud', 'slosh', 'sludge']
senticnet['dirty_word'] = [-0.9, 0, 0.987, -0.534, '#sad', '#angry', -0.807, 'filth', 'smut', 'vulgarism', 'scatology', 'obscenity']
senticnet['disability'] = [-0.774, 0, 0, -0.792, '#sad', '#disgusting', -0.522, 'chicken_pox', 'diabetes', 'lyme_disease', 'brain_tumor', 'suffer_fool']
senticnet['disability_check'] = [0.529, -0.844, 0, 0.559, '#surprising', '#admirable', 0.644, 'pay', 'regular_payment', 'disability_payment', 'wage', 'earnings']
senticnet['disability_payment'] = [0.529, -0.844, 0, 0.559, '#surprising', '#admirable', 0.644, 'pay', 'disability_check', 'regular_payment', 'wage', 'earnings']
senticnet['disable'] = [-0.952, 0, 0.647, -0.523, '#sad', '#angry', -0.707, 'lay_up', 'modify', 'nobble', 'alter', 'change']
senticnet['disabled'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'walking_stick', 'sunglasses', 'blind_person', 'poor_visual_perception', 'vision_loss']
senticnet['disablement'] = [-0.756, 0, 0.504, -0.772, '#sad', '#disgusting', -0.677, 'astasia', 'anorgasmia', 'hearing_impairment', 'hearing_disorder', 'bow_legs']
senticnet['disadvantage'] = [-0.621, 0, 0.708, -0.619, '#sad', '#angry', -0.649, 'unfavorableness', 'unfavourableness', 'unfavorable_position', 'unprofitableness', 'unprofitability']
senticnet['disaffect'] = [-0.106, 0.176, 0.629, -0.642, '#angry', '#disgusting', -0.4, 'alienated', 'alienation', 'disaffection', 'estrange', 'alienate']
senticnet['disaffected'] = [-0.88, 0, 0.718, -0.923, '#sad', '#disgusting', -0.84, 'ungratified', 'discontented', 'malcontent', 'unsatisfied', 'restless']
senticnet['disaffection'] = [-0.106, 0.176, 0.629, -0.642, '#angry', '#disgusting', -0.4, 'alienated', 'alienation', 'estrange', 'alienate', 'disoriented']
senticnet['disagree'] = [-0.722, 0, 0, -0.933, '#sad', '#disgusting', -0.552, 'piss_pant', 'find_another_person', 'argue', 'make_statement', 'become_politician']
senticnet['disagreeable'] = [-0.861, 0, 0.547, -0.671, '#sad', '#disgusting', -0.693, 'dreadful', 'vexing', 'harsh', 'stressful', 'trying']
senticnet['disagreeable_person'] = [-0.667, 0, 0.595, -0.837, '#sad', '#disgusting', -0.7, 'bastard', 'dickhead', 'mother_fucker', 'motherfucker', 'son_of_bitch']
senticnet['disagreeable_woman'] = [-0.598, 0, 0.573, -0.56, '#sad', '#angry', -0.577, 'termagant', 'old_bag', 'shrew', 'frump', 'hellcat']
senticnet['disagreeableness'] = [-0.687, 0, 0.994, -0.549, '#sad', '#angry', -0.743, 'acridity', 'acridness', 'unpleasantness', 'unpalatability', 'unpalatableness']
senticnet['disagreement'] = [-0.921, 0, 0, -0.739, '#sad', '#disgusting', -0.553, 'argue', 'rival', 'antagonist', 'opposition', 'anti']
senticnet['disappear'] = [-0.882, 0, 0.682, -0.603, '#sad', '#angry', -0.722, 'absent', 'fall_away', 'evanesce', 'blow_over', 'pass_off']
senticnet['disappoint'] = [-0.978, 0, 0.971, -0.849, '#sad', '#angry', -0.933, 'fail', 'betray', 'queer', 'cross', 'disillusion']
senticnet['disappointed'] = [-0.725, 0, 0.78, 0, '#sad', '#angry', -0.502, 'defeatism', 'thwarted', 'frustrated', 'foiled', 'discomfited']
senticnet['disappointing'] = [-0.751, 0, 0.785, -0.7, '#sad', '#angry', -0.745, 'unsatisfactory', 'dissatisfactory', 'unsatisfying', 'off', 'unacceptable']
senticnet['disappointment'] = [-0.78, 0, 0.983, 0, '#sad', '#angry', -0.588, 'sadness', 'disappoint', 'embarrassment', 'silliness', 'anger']
senticnet['disapproval'] = [-0.712, 0, 0, -0.914, '#sad', '#disgusting', -0.542, 'disapprove', 'disapproving', 'unfriendly', 'unfriendliness', 'inimical']
senticnet['disapprove'] = [-0.126, 0.192, 0.596, -0.628, '#angry', '#disgusting', -0.386, 'disapproval', 'disapproving', 'unfriendly', 'unfriendliness', 'inimical']
senticnet['disapproving'] = [-0.126, 0.192, 0.596, -0.628, '#angry', '#disgusting', -0.386, 'disapproval', 'disapprove', 'unfriendly', 'unfriendliness', 'inimical']
senticnet['disarm'] = [-0.986, 0, 0.654, -0.847, '#sad', '#disgusting', -0.829, 'bereave', 'expropriate', 'deprive', 'unclothe', 'take']
senticnet['disarray'] = [0, 0, 0.74, -0.836, '#angry', '#disgusting', -0.525, 'disorder', 'messy', 'worst', 'mess_up', 'undress']
senticnet['disaster'] = [-0.171, 0, -0.25, -0.135, '#sad', '#scared', -0.185, 'destruction', 'bigot', 'kidnap', 'torture', 'censorship']
senticnet['disavowable'] = [0.906, -0.624, 0, 0.698, '#joyful', '#admirable', 0.743, 'deniable', 'questionable', 'refutable', 'confutable', 'confutative']
senticnet['disbelief'] = [-0.972, 0, 0.759, 0, '#sad', '#angry', -0.577, 'feel_hurt', 'startle', 'feel_angry', 'become_sad', 'electric_current']
senticnet['disbelieve'] = [-0.807, 0, 0.517, -0.758, '#sad', '#disgusting', -0.694, 'suspect', 'reject', 'doubt', 'distrust', 'mistrust']
senticnet['disbud'] = [0.919, -0.64, 0, 0.648, '#joyful', '#admirable', 0.736, 'dress', 'trim', 'cut_back', 'prune', 'snip']
senticnet['disc'] = [0, -0.767, 0, 0.761, '#surprising', '#admirable', 0.509, 'cassette', 'cd-rom', 'music_storage', 'store_music', 'compact_disc']
senticnet['discard'] = [-0.229, 0, -0.095, -0.165, '#sad', '#disgusting', -0.163, 'inequality', 'reject', 'difference', 'divergency', 'gap']
senticnet['disceptation'] = [0.591, -0.81, 0, 0.589, '#joyful', '#surprising', 0.663, 'firestorm', 'dispute', 'fight', 'conflict', 'polemic']
senticnet['discern'] = [0, 0, -0.919, -0.847, '#scared', '#disgusting', -0.589, 'spot', 'make_out', 'distinguish', 'pick_out', 'recognize']
senticnet['discernability'] = [0.805, -0.62, 0, 0.86, '#joyful', '#admirable', 0.762, 'clearness', 'clarity', 'distinctness', 'uncloudedness', 'legibility']
senticnet['discernible'] = [0.958, -0.838, 0, 0.81, '#joyful', '#surprising', 0.869, 'noticeable', 'perceptible', 'evident', 'detectable', 'observable']
senticnet['discerning'] = [0.902, -0.855, 0, 0.898, '#joyful', '#admirable', 0.885, 'discriminating', 'diacritic', 'diacritical', 'discriminative', 'selective']
senticnet['discernment'] = [0.795, -0.672, 0, 0.934, '#joyful', '#admirable', 0.8, 'appreciation', 'grasp', 'comprehension', 'brainstorm', 'hold']
senticnet['discharge'] = [-0.714, 0, 0, -0.709, '#sad', '#disgusting', -0.474, 'exhaust', 'unloading', 'drainage', 'waste', 'refuse']
senticnet['discipline'] = [0, 0, 0, 0.766, '#admirable', '#admirable', 0.255, 'effort', 'determination', 'a_lot_of_energy', 'good_condition', 'stamina']
senticnet['disciplined'] = [0.858, -0.933, 0, 0.58, '#joyful', '#surprising', 0.79, 'regimented', 'obsessed', 'possessed', 'controlled', 'dominated']
senticnet['disclose'] = [0.58, -0.821, 0, 0.77, '#surprising', '#admirable', 0.724, 'show', 'expose', 'trot_out', 'unfold', 'bring_out']
senticnet['disclosure'] = [-0.026, 0.175, -0.115, 0.148, '#interesting', '#admirable', 0.061, 'tolerant', 'phrase', 'inquiry', 'explain', 'question']
senticnet['disco'] = [0.799, 0.88, 0, 0, '#joyful', '#interesting', 0.56, 'dance_club', 'nightclub', 'club', 'ballroom', 'pub']
senticnet['discoloration'] = [-0.518, 0, 0.937, -0.926, '#angry', '#disgusting', -0.794, 'bloodstain', 'mud_stain', 'iron_mold', 'iron_mould', 'oil_stain']
senticnet['discolouration'] = [-0.951, 0, 0.714, -0.779, '#sad', '#disgusting', -0.815, 'bloodstain', 'mud_stain', 'iron_mold', 'iron_mould', 'oil_stain']
senticnet['discombobulate'] = [-0.63, 0, 0.712, -0.766, '#angry', '#disgusting', -0.703, 'upset', 'disconcert', 'discompose', 'discomfit', 'untune']
senticnet['discombobulation'] = [-0.863, 0, 0, -0.724, '#sad', '#disgusting', -0.529, 'put_off', 'confusedly', 'disordered', 'confused', 'confusing']
senticnet['discomfit'] = [-0.779, 0, 0, -0.744, '#sad', '#disgusting', -0.508, 'disconcertion', 'untune', 'disconcertment', 'discomfiture', 'discompose']
senticnet['discomfited'] = [-0.908, 0, 0.893, 0, '#sad', '#angry', -0.6, 'disappointed', 'defeatism', 'thwarted', 'frustrated', 'foiled']
senticnet['discomfiture'] = [-0.835, 0, 0.811, 0, '#sad', '#angry', -0.549, 'disconcertion', 'untune', 'disconcertment', 'discomfit', 'discompose']
senticnet['discomfort'] = [-0.25, -0.033, -0.157, -0.287, '#sad', '#disgusting', -0.22, 'stomach_pain', 'find_out_healthy', 'severe_pain', 'learn_disease', 'feel_bad']
senticnet['discommode'] = [-0.642, 0, 0.961, -0.502, '#sad', '#angry', -0.702, 'distress', 'straiten', 'impact', 'bear_on', 'touch']
senticnet['discompose'] = [-0.762, 0, 0.77, 0, '#sad', '#angry', -0.511, 'disconcertion', 'untune', 'disconcertment', 'discomfiture', 'discomfit']
senticnet['discomposed'] = [-0.992, 0, 0.858, -0.597, '#sad', '#angry', -0.816, 'embarrassed', 'abashed', 'chagrined', 'blushing', 'bothered']
senticnet['discomposure'] = [-0.774, 0, 0.779, 0, '#sad', '#angry', -0.518, 'disconcertion', 'untune', 'disconcertment', 'discomfiture', 'discomfit']
senticnet['disconcert'] = [-0.796, 0, 0, -0.857, '#sad', '#disgusting', -0.551, 'chagrined', 'abashed', 'chagrin', 'abash', 'embarrassingly']
senticnet['disconcertion'] = [-0.745, 0, 0.889, 0, '#sad', '#angry', -0.545, 'untune', 'disconcertment', 'discomfiture', 'discomfit', 'discompose']
senticnet['disconcertment'] = [-0.98, 0, 0.807, 0, '#sad', '#angry', -0.596, 'disconcertion', 'untune', 'discomfiture', 'discomfit', 'discompose']
senticnet['disconnected'] = [0, 0, 0.798, -0.902, '#angry', '#disgusting', -0.567, 'fall_asleep', 'doze_off', 'boring_talk', 'sleepy', 'distracted']
senticnet['disconnection'] = [-0.081, 0, -0.114, 0, '#sad', '#scared', -0.065, 'mediocrity', 'effect', 'suspicion', 'exclusion', 'pugilist']
senticnet['disconsolate'] = [-0.798, 0.257, -0.471, -0.036, '#sad', '#scared', -0.349, 'gloomful', 'glooming', 'darkness', 'somberness', 'gloominess']
senticnet['disconsolateness'] = [-0.826, 0.226, -0.461, -0.051, '#sad', '#scared', -0.371, 'despondence', 'heartsickness', 'heartsick', 'despondent', 'despondency']
senticnet['discontent'] = [-0.813, 0, 0, -0.981, '#sad', '#disgusting', -0.598, 'dissatisfaction', 'disgruntlement', 'dysphoria', 'resentment', 'envy']
senticnet['discontented'] = [-0.88, 0, 0.718, -0.923, '#sad', '#disgusting', -0.84, 'ungratified', 'disaffected', 'malcontent', 'unsatisfied', 'restless']
senticnet['discontentedness'] = [0.885, -0.676, 0, 0.645, '#joyful', '#surprising', 0.735, 'dissatisfaction', 'disgruntlement', 'dysphoria', 'longing', 'yearning']
senticnet['discontentment'] = [0.997, -0.786, 0, 0.504, '#joyful', '#surprising', 0.762, 'dissatisfaction', 'disgruntlement', 'dysphoria', 'longing', 'yearning']
senticnet['discord'] = [-0.844, 0, 0.7, -0.927, '#sad', '#disgusting', -0.824, 'quarrel', 'fight', 'conflict', 'dispute', 'bloodshed']
senticnet['discordant'] = [-0.935, 0, 0.515, -0.786, '#sad', '#disgusting', -0.745, 'discrepant', 'at_variance', 'dissentious', 'divisive', 'factious']
senticnet['discorporate'] = [-0.53, 0, 0.637, -0.925, '#angry', '#disgusting', -0.697, 'incorporeal', 'unembodied', 'disembodied', 'bodiless', 'unbodied']
senticnet['discotheque'] = [0.966, 0.921, 0, 0.892, '#joyful', '#interesting', 0.926, 'disco', 'nightclub', 'shop_complex', 'dance_club', 'fast_food_restaurant']
senticnet['discount'] = [0.95, 0.937, 0, 0, '#joyful', '#interesting', 0.629, 'good_price', 'cheap_price', 'bargain', 'charge_money', 'good_buy']
senticnet['discount_store'] = [0.057, -0.038, 0, 0, '#joyful', '#surprising', 0.032, 'cheap_stuff', 'save_money', 'less_quality', 'occasions', 'poor_people']
senticnet['discourage'] = [-0.825, 0, 0, -0.761, '#sad', '#disgusting', -0.529, 'disheartenment', 'discouragement', 'mortify', 'abase', 'self-hatred']
senticnet['discouraged'] = [-0.563, 0.269, 0.048, -0.379, '#sad', '#disgusting', -0.24, 'beset', 'provoke', 'molest', 'chivvy', 'harass']
senticnet['discouragement'] = [-0.908, 0, 0, -0.827, '#sad', '#disgusting', -0.578, 'disheartenment', 'discourage', 'mortify', 'abase', 'self-hatred']
senticnet['discouraging'] = [-0.304, 0.294, 0.311, -0.497, '#angry', '#disgusting', -0.273, 'misanthropical', 'misanthropic', 'horrific', 'outrageous', 'horrid']
senticnet['discourse'] = [0, 0.858, 0, 0.969, '#interesting', '#admirable', 0.609, 'orate', 'verbalize', 'verbal', 'talkative', 'speech']
senticnet['discourteous'] = [0.694, -0.554, 0, 0.894, '#joyful', '#admirable', 0.714, 'curt', 'brusque', 'brusk', 'abrupt', 'unceremonious']
senticnet['discourtesy'] = [-0.712, 0, 0.83, -0.847, '#angry', '#disgusting', -0.796, 'scorn', 'abuse', 'vilification', 'contempt', 'insult']
senticnet['discover'] = [0.756, 0.955, 0, 0, '#joyful', '#interesting', 0.57, 'discovery', 'search', 'review', 'investigation', 'realize']
senticnet['discover_fact'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'ask_expert', 'study_history', 'read_book_subject', 'absorb_information', 'use_telescope']
senticnet['discover_new'] = [0.802, 0.795, 0, 0.839, '#joyful', '#admirable', 0.812, 'absorb_information', 'increase_intelligence', 'become_wise', 'improve_performance', 'open_mind']
senticnet['discover_new_culture'] = [0.9, -0.742, 0, 0.721, '#joyful', '#surprising', 0.788, 'study', 'language', 'read_english_book', 'wanderlust', 'study_language']
senticnet['discover_new_place'] = [0, 0, -0.859, -0.941, '#scared', '#disgusting', -0.6, 'turn_steer_wheel', 'drive_destination', 'honk_horn', 'carry_luggage', 'shift_gear']
senticnet['discover_truth'] = [0, -0.039, 0, 0.097, '#surprising', '#admirable', 0.045, 'analyze', 'examine', 'find_truth', 'determine_truth', 'real_fact']
senticnet['discover_universe'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'explore_universe', 'universe', 'another_planet', 'astrology', 'alien']
senticnet['discover_world'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'holiday', 'new_life', 'new_experience', 'foreign_country', 'travel']
senticnet['discovery'] = [0.774, -0.634, 0, 0.567, '#joyful', '#surprising', 0.658, 'catching', 'breakthrough', 'spying', 'determination', 'tracing']
senticnet['discredit'] = [-0.854, 0, 0.954, -0.863, '#angry', '#disgusting', -0.89, 'refuse_value', 'refuse_dogma', 'disbelieve', 'refuse_religion', 'distrust']
senticnet['discreditable'] = [0.725, -0.886, 0, 0.508, '#joyful', '#surprising', 0.706, 'louche', 'seedy', 'discredited', 'sleazy', 'disreputable']
senticnet['discreditably'] = [-0.968, 0, 0.775, 0, '#sad', '#angry', -0.581, 'disgrace', 'shameful', 'dishonorably', 'inglorious', 'dishonored']
senticnet['discredited'] = [-0.748, 0, 0.822, 0, '#sad', '#angry', -0.523, 'disgrace', 'shameful', 'dishonorably', 'inglorious', 'dishonored']
senticnet['discreet'] = [0.625, -0.88, 0, 0.782, '#surprising', '#admirable', 0.762, 'judicious', 'prudent', 'prudential', 'heady', 'circumspect']
senticnet['discreetness'] = [-0.529, 0, 0.604, -0.825, '#angry', '#disgusting', -0.653, 'discernment', 'sagacity', 'sagaciousness', 'confidentiality', 'judgment']
senticnet['discrepancy'] = [-0.529, 0, 0.561, -0.908, '#angry', '#disgusting', -0.666, 'difference', 'tolerance', 'allowance', 'leeway', 'margin']
senticnet['discrepant'] = [-0.935, 0, 0.515, -0.786, '#sad', '#disgusting', -0.745, 'discordant', 'at_variance', 'dissentious', 'divisive', 'factious']
senticnet['discretion'] = [0, 0.769, 0, 0.985, '#interesting', '#admirable', 0.585, 'prudence', 'frugality', 'frugalness', 'discernment', 'natural_virtue']
senticnet['discriminating'] = [0.902, -0.855, 0, 0.898, '#joyful', '#admirable', 0.885, 'discerning', 'diacritic', 'diacritical', 'discriminative', 'selective']
senticnet['discrimination'] = [0, 0, -0.747, -0.753, '#scared', '#disgusting', -0.5, 'disgust', 'military_force', 'military_division', 'opposition', 'anti']
senticnet['discriminative'] = [0.902, -0.855, 0, 0.898, '#joyful', '#admirable', 0.885, 'discerning', 'diacritic', 'diacritical', 'discriminating', 'selective']
senticnet['discriminatory'] = [-0.949, 0, 0, -0.753, '#sad', '#disgusting', -0.567, 'homophobic', 'racist', 'jaundiced', 'antiblack', 'invidious']
senticnet['discuss'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'autograph', 'communication', 'communicate_person', 'talk_another_person', 'autographion']
senticnet['discuss_friend'] = [-0.094, 0, 0, -0.047, '#sad', '#disgusting', -0.047, 'want_understand', 'solution_to_problem', 'say_eureka', 'trivia', 'come_conclusion']
senticnet['discuss_issue'] = [0.128, 0.128, -0.053, 0.174, '#joyful', '#interesting', 0.126, 'receive_gift', 'talk_oneself', 'stay_touch_friend', 'draw_diagram', 'avoid_pain']
senticnet['discussion'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'discuss', 'communication', 'communicate_person', 'talk_another_person', 'autograph']
senticnet['disdain'] = [-0.101, 0.188, 0.62, -0.636, '#angry', '#disgusting', -0.39, 'contemn', 'contempt', 'despite', 'alienated', 'estranged']
senticnet['disease'] = [-0.109, 0, -0.167, -0.232, '#scared', '#disgusting', -0.169, 'contagious_disease', 'infectious_disease', 'polio', 'sickness', 'malady']
senticnet['disease_of_skin'] = [-0.898, 0, 0.998, -0.898, '#sad', '#angry', -0.931, 'erythema', 'flare', 'skin_disease', 'erythroderma', 'skin_disorder']
senticnet['diseased'] = [-0.793, 0, -0.714, -0.714, '#sad', '#scared', -0.74, 'suffer_fool', 'disrespect', 'schizophrenia', 'influenza', 'disability']
senticnet['diseased_person'] = [-0.74, 0, 0.991, -0.641, '#sad', '#angry', -0.791, 'unfortunate', 'dyspeptic', 'invalid', 'psychoneurotic', 'psychotic']
senticnet['disembarrass'] = [0.939, -0.501, 0, 0.733, '#joyful', '#admirable', 0.724, 'smooth_out', 'clear', 'relieve', 'smooth', 'disembody']
senticnet['disembarrassment'] = [0.772, -0.923, 0, 0.524, '#joyful', '#surprising', 0.74, 'change', 'modification', 'easing', 'breath_of_fresh_air', 'alteration']
senticnet['disembodied'] = [-0.53, 0, 0.637, -0.925, '#angry', '#disgusting', -0.697, 'discorporate', 'unembodied', 'incorporeal', 'bodiless', 'unbodied']
senticnet['disembody'] = [0.939, -0.501, 0, 0.733, '#joyful', '#admirable', 0.724, 'smooth_out', 'clear', 'relieve', 'smooth', 'disembarrass']
senticnet['disenable'] = [-0.982, 0, 0.849, -0.542, '#sad', '#angry', -0.791, 'lay_up', 'modify', 'nobble', 'alter', 'change']
senticnet['disengage'] = [0.693, -0.526, 0, 0.992, '#joyful', '#admirable', 0.737, 'release', 'unlock', 'let_go', 'relinquish', 'let_go_of']
senticnet['disfigure'] = [-0.552, 0, 0.81, -0.712, '#angry', '#disgusting', -0.691, 'vitiate', 'mar', 'maul', 'mangle', 'impair']
senticnet['disgrace'] = [-0.913, 0, -0.729, -0.882, '#sad', '#disgusting', -0.841, 'death_love', 'bad_feeling', 'anguish', 'consequence_war', 'feel_stressed']
senticnet['disgraced'] = [-0.87, 0, 0.888, 0, '#sad', '#angry', -0.586, 'disgraceful', 'shameful', 'disgrace', 'inglorious', 'dishonored']
senticnet['disgraceful'] = [-0.838, 0, 0.767, 0, '#sad', '#angry', -0.535, 'shameful', 'dishonorably', 'inglorious', 'dishonored', 'woebegone']
senticnet['disgracefully'] = [-0.928, 0, 0.987, 0, '#sad', '#angry', -0.638, 'disgraceful', 'shameful', 'dishonorably', 'inglorious', 'disgrace']
senticnet['disgruntled'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'discontent', 'malcontent', 'dissatisfied', 'displeased', 'grouchy']
senticnet['disgruntlement'] = [0.938, -0.552, 0, 0.7, '#joyful', '#admirable', 0.73, 'dissatisfaction', 'discontent', 'dysphoria', 'longing', 'yearning']
senticnet['disgust'] = [0, 0, 0, -0.6, '#disgusting', '#disgusting', -0.2, 'huffish', 'despise', 'maleficence', 'malign', 'malefic']
senticnet['disgusted'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['disgustedly'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'revolting', 'disgusting', 'fed_up', 'sick_of', 'disgustful']
senticnet['disgustful'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['disgusting'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'fed_up', 'sick_of', 'disgustful']
senticnet['disgustingly'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['disgustingness'] = [-0.522, 0, 0.703, -0.718, '#angry', '#disgusting', -0.648, 'distastefulness', 'taste_property', 'unpalatability', 'unsavoriness', 'nauseatingness']
senticnet['dish'] = [0, 0, 0.066, -0.077, '#angry', '#disgusting', -0.048, 'container_cup', 'cup', 'grease_trap', 'open_container', 'salad_bowl']
senticnet['dish_out'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'find_out', 'unmask', 'unearth', 'become_aware', 'dig_out']
senticnet['disharmonious'] = [-0.527, 0, 0.902, -0.735, '#angry', '#disgusting', -0.721, 'discordant', 'dissonant', 'unresolved', 'false', 'inharmonious']
senticnet['disheartened'] = [-0.73, 0.288, -0.367, -0.108, '#sad', '#scared', -0.306, 'feel_down', 'demoralized', 'despondently', 'despairingly', 'weepiness']
senticnet['disheartening'] = [-0.833, 0.22, -0.462, -0.051, '#sad', '#scared', -0.375, 'feel_down', 'demoralizing', 'demoralization', 'sadness', 'dispiriting']
senticnet['disheartenment'] = [-0.986, 0, 0.894, 0, '#sad', '#angry', -0.627, 'discouragement', 'discourage', 'mortify', 'abase', 'self-hatred']
senticnet['disheveled'] = [-0.852, 0, 0.985, -0.71, '#sad', '#angry', -0.849, 'messy', 'mussy', 'untidy', 'dirty', 'frowzled']
senticnet['dishonest'] = [-0.981, 0, 0.886, -0.985, '#sad', '#disgusting', -0.951, 'against_law', 'false', 'bad_action', 'consequence', 'judge_decision']
senticnet['dishonesty'] = [-0.92, 0, 0.862, -0.903, '#sad', '#disgusting', -0.895, 'untruth', 'falsehood', 'fallacy', 'deceit', 'slumber']
senticnet['dishonor'] = [-0.938, 0, 0.936, -0.881, '#sad', '#angry', -0.918, 'lose_team', 'cause_suffer', 'leave_out', 'loathing', 'lyme_disease']
senticnet['dishonorable'] = [-0.918, 0, 0.907, -0.601, '#sad', '#angry', -0.809, 'opprobrious', 'debasing', 'disgraceful', 'degrading', 'inglorious']
senticnet['dishonorableness'] = [-0.774, 0, 0.748, -0.606, '#sad', '#angry', -0.709, 'ignobleness', 'ignobility', 'sleaziness', 'unrespectability', 'disreputability']
senticnet['dishonorably'] = [-0.779, 0, 0.929, 0, '#sad', '#angry', -0.569, 'disgraceful', 'shameful', 'inglorious', 'dishonored', 'shame']
senticnet['dishonored'] = [-0.79, 0, 0.744, 0, '#sad', '#angry', -0.511, 'disgraceful', 'shameful', 'dishonorably', 'inglorious', 'shame']
senticnet['dishonourableness'] = [-0.654, 0, 0.751, -0.8, '#angry', '#disgusting', -0.735, 'ignobleness', 'ignobility', 'sleaziness', 'unrespectability', 'disreputability']
senticnet['dishwasher'] = [0, -0.068, 0, 0, '#surprising', '#surprising', 0.023, 'kitchen_cabinet', 'kitchen_cupboard', 'kitchen', 'cupboard', 'own_kitchen']
senticnet['disillusion'] = [-0.978, 0, 0.971, -0.849, '#sad', '#angry', -0.933, 'fail', 'betray', 'queer', 'cross', 'disappoint']
senticnet['disinclination'] = [-0.118, 0.19, 0.604, -0.63, '#angry', '#disgusting', -0.387, 'indispose', 'disinclined', 'disincline', 'unfriendly', 'inimical']
senticnet['disincline'] = [-0.118, 0.19, 0.604, -0.63, '#angry', '#disgusting', -0.387, 'indispose', 'disinclination', 'disinclined', 'unfriendly', 'inimical']
senticnet['disinclined'] = [-0.118, 0.19, 0.604, -0.63, '#angry', '#disgusting', -0.387, 'indispose', 'disinclination', 'disincline', 'unfriendly', 'inimical']
senticnet['disinfect'] = [0.038, 0, 0, 0.09, '#joyful', '#admirable', 0.043, 'get_rid_of_dirt', 'wash_away_dirt', 'cleanliness', 'keep_clean', 'hygiene']
senticnet['disinfectant'] = [0, -0.015, -0.056, -0.111, '#scared', '#disgusting', -0.051, 'fluoride_mouthwash', 'faucet_overflow', 'mouthwash', 'hot_faucet', 'shampoo']
senticnet['disinfection'] = [-0.628, 0, 0.987, -0.742, '#angry', '#disgusting', -0.786, 'medical_aid', 'treatment', 'hospice', 'digitalization', 'bloodletting']
senticnet['disingenuousness'] = [-0.837, 0, 0.802, -0.521, '#sad', '#angry', -0.72, 'dishonesty', 'deceitfulness', 'craftiness', 'guile', 'artfulness']
senticnet['disinherited'] = [-0.859, 0, 0.655, -0.672, '#sad', '#disgusting', -0.729, 'lovelorn', 'unbeloved', 'bereft', 'estranged', 'unloved']
senticnet['disinterested'] = [-0.955, 0, 0.961, 0, '#sad', '#angry', -0.639, 'dispassionate', 'indifferent', 'unbiased', 'unprejudiced', 'neutral']
senticnet['disinvest'] = [-0.956, 0, 0.673, -0.855, '#sad', '#disgusting', -0.828, 'discharge', 'free', 'dethrone', 'defrock', 'unfrock']
senticnet['disjunctive'] = [-0.668, 0, 0.502, -0.796, '#sad', '#disgusting', -0.655, 'adversative', 'oppositive', 'contrastive', 'alternative', 'separative']
senticnet['disk'] = [0, 0, 0.866, -0.869, '#angry', '#disgusting', -0.578, 'software_crash', 'old_computer', 'seventy', 'music_storage', 'old_technology']
senticnet['diskette'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'slot', 'box', 'load_dock', 'safe_deposit_box', 'emporium']
senticnet['dislike'] = [-0.858, 0, 0.919, -0.963, '#angry', '#disgusting', -0.913, 'disapproval', 'aversion', 'distaste', 'antipathy', 'prejudice']
senticnet['dislike_person'] = [-0.136, 0, -0.179, -0.207, '#scared', '#disgusting', -0.174, 'medical_person', 'hate', 'nurse', 'doctor', 'stressful_job']
senticnet['dislikeable'] = [-0.858, 0, 0.919, -0.963, '#angry', '#disgusting', -0.913, 'hideous', 'aversion', 'distaste', 'antipathy', 'disapproval']
senticnet['dislocate'] = [-0.883, 0.174, -0.597, 0, '#sad', '#scared', -0.435, 'transplant', 'move', 'move_away', 'bump', 'displace']
senticnet['dislocation'] = [-0.097, -0.041, -0.066, -0.186, '#sad', '#disgusting', -0.103, 'ache', 'pain', 'hurt', 'cut_skin', 'ouch']
senticnet['disloyal'] = [-0.927, 0, 0.784, -0.912, '#sad', '#disgusting', -0.874, 'enemy', 'bad_customer', 'competitor', 'steal_client', 'buy_cheaper']
senticnet['disloyalty'] = [-0.792, 0, 0, -0.848, '#sad', '#disgusting', -0.547, 'perfidiousness', 'traitorousness', 'perfidy', 'treachery', 'betrayal']
senticnet['dismal'] = [-0.798, 0.257, -0.471, -0.036, '#sad', '#scared', -0.349, 'gloomful', 'glooming', 'darkness', 'somberness', 'gloominess']
senticnet['dismay'] = [-0.746, 0, 0.958, 0, '#sad', '#angry', -0.568, 'distressed', 'shamefacedly', 'sheepishness', 'shamefacedness', 'confusedly']
senticnet['dismiss'] = [-0.863, 0, 0.897, -0.813, '#sad', '#angry', -0.858, 'disregard', 'ignore', 'brush_off', 'push_aside', 'flout']
senticnet['dismissal'] = [-0.846, 0, 0, -0.872, '#sad', '#disgusting', -0.573, 'inferno', 'forest_fire', 'fire_light', 'detonation', 'wash_mouth_soap']
senticnet['dismissive'] = [-0.612, 0, 0.764, -0.97, '#angry', '#disgusting', -0.782, 'apathetic', 'benumbed', 'indifferent', 'uninterested', 'dulled']
senticnet['disney'] = [0.053, 0.073, -0.065, 0.104, '#interesting', '#admirable', 0.055, 'mermaid', 'autumn_leaf', 'horizon', 'aquatic_life', 'fisherman']
senticnet['disney_cartoon'] = [0, -0.171, -0.046, 0.091, '#surprising', '#admirable', 0.072, 'child_book', 'child_movie', 'children_story', 'funny_moment', 'childhood']
senticnet['disneyland'] = [0.957, 0.7, 0, 0, '#joyful', '#interesting', 0.552, 'ballpark', 'coven', 'carnival', 'hockey_game', 'symposium']
senticnet['disobedient'] = [-0.778, 0, 0.886, -0.584, '#sad', '#angry', -0.749, 'refractory', 'obstinate', 'recalcitrant', 'froward', 'headstrong']
senticnet['disobey'] = [-0.717, 0, 0.932, -0.505, '#sad', '#angry', -0.718, 'refuse', 'subvert', 'decline', 'balk', 'baulk']
senticnet['disoblige'] = [-0.537, 0, 0.549, -0.888, '#angry', '#disgusting', -0.658, 'distress', 'straiten', 'impact', 'bear_on', 'touch']
senticnet['disorder'] = [0, 0, 0.817, -0.779, '#angry', '#disgusting', -0.532, 'suffer_fool', 'diabetes', 'influenza', 'lyme_disease', 'brain_tumor']
senticnet['disordered'] = [-0.978, 0, -0.798, 0, '#sad', '#scared', -0.592, 'put_off', 'confusedly', 'discombobulation', 'confused', 'confusing']
senticnet['disorderliness'] = [-0.787, 0, 0.854, -0.9, '#angry', '#disgusting', -0.847, 'muss', 'untidiness', 'mess', 'muddle', 'messiness']
senticnet['disorderly'] = [-0.642, 0, 0.941, -0.664, '#angry', '#disgusting', -0.749, 'rowdy', 'boisterous', 'unruly', 'rambunctious', 'robustious']
senticnet['disorganize'] = [0, 0, 0.814, -0.772, '#angry', '#disgusting', -0.529, 'office', 'messy', 'workplace', 'business_organization', 'large_business']
senticnet['disorganized'] = [-0.988, 0, 0.811, -0.958, '#sad', '#disgusting', -0.919, 'unmethodical', 'upset', 'confused', 'scrambled', 'undone']
senticnet['disorient'] = [-0.502, 0, 0.638, -0.715, '#angry', '#disgusting', -0.618, 'befuddle', 'confound', 'discombobulate', 'bedevil', 'confuse']
senticnet['disorientate'] = [-0.891, 0, 0.873, -0.569, '#sad', '#angry', -0.778, 'befuddle', 'confound', 'discombobulate', 'bedevil', 'confuse']
senticnet['disorientation'] = [0, 0, 0.945, -0.778, '#angry', '#disgusting', -0.574, 'become_drunk', 'slur_word', 'act_stupid', 'forgetfulness', 'hangover']
senticnet['disoriented'] = [-0.106, 0.176, 0.629, -0.642, '#angry', '#disgusting', -0.4, 'alienated', 'alienation', 'disaffection', 'estrange', 'alienate']
senticnet['disown'] = [-0.962, 0, 0.885, -0.75, '#sad', '#angry', -0.866, 'controvert', 'answer', 'rebut', 'renounce', 'repudiate']
senticnet['disparage'] = [-0.768, 0, 0.798, -0.581, '#sad', '#angry', -0.716, 'disgrace', 'pick_apart', 'depreciate', 'criticize', 'belittle']
senticnet['disparager'] = [0.899, -0.775, 0, 0.866, '#joyful', '#admirable', 0.847, 'unpleasant_person', 'disagreeable_person', 'detractor', 'cynic', 'depreciator']
senticnet['disparateness'] = [-0.545, 0, 0.979, -0.858, '#angry', '#disgusting', -0.794, 'unlikeness', 'dissimilitude', 'difference', 'heterology', 'dissimilarity']
senticnet['disparity'] = [0.855, -0.845, 0, 0.632, '#joyful', '#surprising', 0.777, 'disproportion', 'gap', 'spread', 'gulf', 'disconnection']
senticnet['dispassionate'] = [0.837, -0.996, 0, 0.559, '#joyful', '#surprising', 0.797, 'disinterested', 'impartial', 'indifferent', 'unbiased', 'fair']
senticnet['dispatch'] = [0, 0.827, 0, 0.935, '#interesting', '#admirable', 0.587, 'mission', 'consignment', 'delivery', 'shipment', 'expedition']
senticnet['dispel'] = [0.838, -0.845, 0, 0.791, '#joyful', '#surprising', 0.825, 'move', 'displace', 'clear_air', 'fire', 'banish']
senticnet['dispense'] = [-0.067, 0, 0.023, 0, '#sad', '#angry', -0.03, 'circulate_blood', 'grind_grain', 'fail_work', 'cremate', 'dry_wet_hair']
senticnet['dispense_water'] = [-0.074, 0, 0.026, 0, '#sad', '#angry', -0.033, 'soap_up', 'turn_water', 'fill_bathtub', 'run_bath', 'launder']
senticnet['dispersion'] = [0.849, -0.547, 0, 0.543, '#joyful', '#surprising', 0.646, 'diffusion', 'spread', 'scattering', 'invasion', 'irradiation']
senticnet['dispirit'] = [-0.81, 0.239, -0.443, -0.064, '#sad', '#scared', -0.359, 'feel_down', 'deject', 'cast_down', 'get_down', 'demoralize']
senticnet['dispirited'] = [-0.784, 0.266, -0.45, -0.052, '#sad', '#scared', -0.34, 'downhearted', 'low-spirited', 'depressed', 'down_in_mouth', 'downcast']
senticnet['dispiritedly'] = [-0.798, 0, 0.962, 0, '#sad', '#angry', -0.587, 'hopelessness', 'hopelessly', 'despairing', 'pessimistically', 'pessimistic']
senticnet['dispiritedness'] = [-0.752, 0.288, -0.434, -0.058, '#sad', '#scared', -0.319, 'dejectedness', 'low-spiritedness', 'lowness', 'downheartedness', 'cheerless']
senticnet['dispiriting'] = [-0.833, 0.22, -0.462, -0.051, '#sad', '#scared', -0.375, 'disheartening', 'feel_down', 'demoralizing', 'demoralization', 'sadness']
senticnet['displace'] = [-0.883, 0.174, -0.597, 0, '#sad', '#scared', -0.435, 'transplant', 'move', 'move_away', 'bump', 'dislocate']
senticnet['display'] = [0.044, 0.08, 0, -0.03, '#joyful', '#interesting', 0.031, 'screen', 'pixel', 'visual_information', 'image', 'computer_monitor']
senticnet['display_image'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'send_email', 'post_message', 'access_internet', 'prepare_report', 'enter_data']
senticnet['display_information'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'display', 'sharpen', 'paint_picture', 'letter_sign', 'turner']
senticnet['display_item'] = [-0.048, 0.151, -0.094, 0.187, '#interesting', '#admirable', 0.065, 'store_dry_goods', 'hold_small_item', 'store_stuff', 'hold_stuff', 'carry_stuff']
senticnet['display_wealth'] = [0.03, 0, 0, 0.119, '#joyful', '#admirable', 0.05, 'decorate_oneself', 'propose_marriage', 'shoe_lace', 'time_tracker', 'use_finger']
senticnet['displease'] = [-0.123, 0.072, 0.699, -0.67, '#angry', '#disgusting', -0.473, 'displeasingly', 'displeasing', 'displeasure', 'displeased', 'aggravated']
senticnet['displeased'] = [-0.123, 0.072, 0.699, -0.67, '#angry', '#disgusting', -0.473, 'displeasingly', 'displeasing', 'displeasure', 'displease', 'aggravated']
senticnet['displeasing'] = [-0.123, 0.072, 0.699, -0.67, '#angry', '#disgusting', -0.473, 'displeasingly', 'displeasure', 'displease', 'displeased', 'aggravated']
senticnet['displeasingly'] = [-0.123, 0.072, 0.699, -0.67, '#angry', '#disgusting', -0.473, 'displeasing', 'displeasure', 'displease', 'displeased', 'aggravated']
senticnet['displeasure'] = [-0.123, 0.072, 0.699, -0.67, '#angry', '#disgusting', -0.473, 'displeasingly', 'displeasing', 'displease', 'displeased', 'aggravated']
senticnet['disposable_razor'] = [-0.08, 0.232, 0, 0.099, '#interesting', '#admirable', 0.084, 'wax_dental_floss', 'fluoride_toothpaste', 'toilet_paper', 'dental_floss', 'tartar_control_toothpaste']
senticnet['disposal'] = [-0.14, -0.055, -0.068, -0.171, '#sad', '#disgusting', -0.108, 'blown_up', 'kill', 'blow_up', 'death_destruction', 'violent_person']
senticnet['dispose'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'throw_out', 'discard', 'get_rid', 'ditch', 'abandon']
senticnet['dispose_waste'] = [-0.049, 0, -0.076, -0.084, '#scared', '#disgusting', -0.07, 'put_garbage', 'throw_away_garbage', 'hold_trash', 'barf', 'radioactive']
senticnet['disposed'] = [0.946, -0.728, 0, 0.843, '#joyful', '#admirable', 0.839, 'fond', 'tending', 'inclined', 'partial', 'given']
senticnet['disposition'] = [-0.58, 0, 0.925, -0.632, '#angry', '#disgusting', -0.712, 'ill_nature', 'disagreeableness', 'unfriendliness', 'bloodthirstiness', 'aloneness']
senticnet['dispossession'] = [-0.873, 0, 0.765, -0.828, '#sad', '#disgusting', -0.822, 'due_process', 'due_process_of_law', 'ouster', 'retaliatory_eviction', 'actual_eviction']
senticnet['disproportion'] = [0.855, -0.845, 0, 0.632, '#joyful', '#surprising', 0.777, 'disparity', 'gap', 'spread', 'gulf', 'disconnection']
senticnet['disprove'] = [-0.597, 0, 0.824, -0.815, '#angry', '#disgusting', -0.745, 'controvert', 'refute', 'rebut', 'falsify', 'negate']
senticnet['disputable'] = [0, 0, 0.967, -0.711, '#angry', '#disgusting', -0.559, 'shakable', 'shakeable', 'challengeable', 'contestable', 'debatable']
senticnet['disputant'] = [0.644, -0.864, 0, 0.58, '#joyful', '#surprising', 0.696, 'hairsplitter', 'quarreler', 'fight', 'obstructor', 'obstructer']
senticnet['disputatious'] = [0.702, -0.515, 0, 0.658, '#joyful', '#admirable', 0.625, 'contentious', 'argumentative', 'disputative', 'eristic', 'eristical']
senticnet['disputative'] = [0.702, -0.515, 0, 0.658, '#joyful', '#admirable', 0.625, 'contentious', 'disputatious', 'argumentative', 'eristic', 'eristical']
senticnet['dispute'] = [0, 0, 0.733, -0.915, '#angry', '#disgusting', -0.549, 'quarrel', 'big_fight', 'fight', 'conflict', 'combat']
senticnet['disputed'] = [-0.856, 0, 0.749, -0.998, '#sad', '#disgusting', -0.868, 'arguable', 'contentious', 'disputable', 'controversial', 'polemic']
senticnet['disqualified'] = [-0.608, 0, 0.832, -0.537, '#sad', '#angry', -0.659, 'unsuitable', 'undesirable', 'unqualified', 'ineligible', 'unentitled']
senticnet['disquiet'] = [-0.826, 0, -0.777, 0, '#sad', '#scared', -0.534, 'hysteria', 'fearful', 'dreadful', 'uneasiness', 'anxious']
senticnet['disquieted'] = [-0.9, 0, -0.776, 0, '#sad', '#scared', -0.559, 'distressing', 'disturbing', 'perturbing', 'troubling', 'worrisome']
senticnet['disquietude'] = [-0.843, 0, 0, -0.962, '#sad', '#disgusting', -0.602, 'inquietude', 'edginess', 'edgy', 'uptight', 'restive']
senticnet['disquisition'] = [-0.702, 0, 0.767, -0.935, '#angry', '#disgusting', -0.801, 'report', 'composition', 'paper', 'theme', 'essay']
senticnet['disregard'] = [-0.863, 0, 0.897, -0.813, '#sad', '#angry', -0.858, 'flout', 'ignore', 'brush_off', 'push_aside', 'dismiss']
senticnet['disreputability'] = [-0.774, 0, 0.748, -0.606, '#sad', '#angry', -0.709, 'ignobleness', 'ignobility', 'sleaziness', 'unrespectability', 'dishonorableness']
senticnet['disreputable'] = [0.725, -0.886, 0, 0.508, '#joyful', '#surprising', 0.706, 'louche', 'seedy', 'discredited', 'sleazy', 'discreditable']
senticnet['disrespect'] = [0, 0, 0.761, -0.726, '#angry', '#disgusting', -0.496, 'cause_suffer', 'lose_team', 'suffer_fool', 'brain_tumor', 'lyme_disease']
senticnet['disrespectful'] = [0, 0, 0.931, -0.73, '#angry', '#disgusting', -0.554, 'annihilating', 'undeferential', 'devastating', 'insolent', 'undutiful']
senticnet['disrobe'] = [-0.044, 0, -0.055, 0, '#sad', '#scared', -0.033, 'fill_bathtub', 'fill_bathtub_water', 'run_bath', 'turn_water', 'take_clothes_off']
senticnet['disrupt'] = [-0.928, 0, 0.722, -0.555, '#sad', '#angry', -0.735, 'block', 'barge_in', 'jam', 'interject', 'throw_in']
senticnet['disruption'] = [-0.551, 0, 0.965, -0.993, '#angry', '#disgusting', -0.836, 'interjection', 'delay', 'insert', 'interposition', 'interpolation']
senticnet['diss'] = [-0.574, 0, 0.551, -0.62, '#sad', '#disgusting', -0.582, 'spite', 'wound', 'injure', 'hurt', 'offend']
senticnet['dissatisfaction'] = [-0.831, 0, 0.912, -0.679, '#sad', '#angry', -0.807, 'letdown', 'displeasure', 'disappointment', 'boredom', 'ennui']
senticnet['dissatisfactory'] = [-0.751, 0, 0.785, -0.7, '#sad', '#angry', -0.745, 'disappointing', 'unsatisfactory', 'unsatisfying', 'off', 'unacceptable']
senticnet['dissatisfied'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'discontent', 'malcontent', 'disgruntled', 'displeased', 'grouchy']
senticnet['dissection'] = [-0.05, 0, -0.115, 0, '#sad', '#scared', -0.055, 'medical_procedure', 'operation', 'spasm', 'cure', 'medical_exam']
senticnet['dissemble'] = [-0.786, 0, 0.679, -0.824, '#sad', '#disgusting', -0.763, 'talk_through_one_hat', 'bullshit', 'take_dive', 'fake', 'misrepresent']
senticnet['dissembler'] = [0.85, -0.716, 0, 0.617, '#joyful', '#surprising', 0.728, 'pretender', 'phony', 'phoney', 'hypocrite', 'charmer']
senticnet['dissembling'] = [-0.813, 0, 0.595, -0.88, '#sad', '#disgusting', -0.763, 'deceit', 'deception', 'misrepresentation', 'pretext', 'bluff']
senticnet['disseminated_sclerosis'] = [-0.759, 0, 0.515, -0.93, '#sad', '#disgusting', -0.735, 'sclerosis', 'induration', 'degenerative_disorder', 'autoimmune_disease', 'autoimmune_disorder']
senticnet['disseminating'] = [0, 0, -0.779, -0.979, '#scared', '#disgusting', -0.586, 'propagate', 'disseminate', 'spread', 'circulate', 'distribute']
senticnet['dissenter'] = [-0.931, 0, 0.688, -0.631, '#sad', '#angry', -0.75, 'dissident', 'nimby', 'protester', 'objector', 'contestant']
senticnet['dissentious'] = [-0.935, 0, 0.515, -0.786, '#sad', '#disgusting', -0.745, 'discrepant', 'at_variance', 'discordant', 'divisive', 'factious']
senticnet['dissertation'] = [0, 0, -0.074, 0, '#scared', '#scared', -0.025, 'typeface', 'print_word', 'grammatical_term', 'hold_information', 'continue_story']
senticnet['dissident'] = [-0.931, 0, 0.688, -0.631, '#sad', '#angry', -0.75, 'nimby', 'dissenter', 'protester', 'objector', 'contestant']
senticnet['dissimilarity'] = [-0.545, 0, 0.979, -0.858, '#angry', '#disgusting', -0.794, 'unlikeness', 'dissimilitude', 'difference', 'heterology', 'disparateness']
senticnet['dissimilitude'] = [-0.545, 0, 0.979, -0.858, '#angry', '#disgusting', -0.794, 'unlikeness', 'dissimilarity', 'difference', 'heterology', 'disparateness']
senticnet['dissimulation'] = [-0.67, 0, 0.505, -0.933, '#sad', '#disgusting', -0.703, 'shenanigan', 'pretence', 'cheating', 'misrepresentation', 'feigning']
senticnet['dissimulative'] = [-0.527, 0, 0.651, -0.542, '#angry', '#disgusting', -0.573, 'feigned', 'insincere', 'specious', 'hypocritical', 'fulsome']
senticnet['dissociable'] = [0.998, -0.635, 0, 0.574, '#joyful', '#surprising', 0.736, 'cleavable', 'divisible', 'separable', 'severable', 'dissociative']
senticnet['dissociate'] = [0.804, -0.951, 0, 0.813, '#surprising', '#admirable', 0.856, 'break', 'split', 'separate', 'part', 'split_up']
senticnet['dissociative'] = [0.998, -0.635, 0, 0.574, '#joyful', '#surprising', 0.736, 'cleavable', 'dissociable', 'separable', 'severable', 'divisible']
senticnet['dissociative_disorder'] = [-0.583, 0, 0.722, -0.516, '#sad', '#angry', -0.607, 'depersonalization_disorder', 'depersonalization_neurosis', 'depersonalization', 'mental_disorder', 'mental_disturbance']
senticnet['dissoluteness'] = [-0.832, 0, 0.531, -0.595, '#sad', '#disgusting', -0.653, 'indulgence', 'incontinence', 'trait', 'indiscipline', 'unrestraint']
senticnet['dissolve'] = [0.957, -0.926, 0, 0.577, '#joyful', '#surprising', 0.82, 'behave', 'lose_it', 'die', 'fall_apart', 'go_to_pieces']
senticnet['dissolve_in_water'] = [-0.049, 0, -0.05, 0, '#sad', '#scared', -0.033, 'chop_vegetable', 'defrost', 'prepare_breakfast', 'brown_hamburger', 'heat_meal']
senticnet['dissolvent'] = [0.843, -0.958, 0, 0.648, '#joyful', '#surprising', 0.816, 'medium', 'acetone', 'propanone', 'dimethyl_ketone', 'chlorobenzene']
senticnet['dissolver'] = [0.656, -0.798, 0, 0.676, '#surprising', '#admirable', 0.71, 'medium', 'acetone', 'propanone', 'dimethyl_ketone', 'chlorobenzene']
senticnet['dissolving_agent'] = [0.641, -0.772, 0, 0.728, '#surprising', '#admirable', 0.714, 'medium', 'acetone', 'propanone', 'dimethyl_ketone', 'chlorobenzene']
senticnet['dissonant'] = [-0.527, 0, 0.902, -0.735, '#angry', '#disgusting', -0.721, 'discordant', 'inharmonious', 'unresolved', 'false', 'disharmonious']
senticnet['dissymmetry'] = [-0.975, 0, 0.831, -0.87, '#sad', '#disgusting', -0.892, 'geometrical_irregularity', 'radial_asymmetry', 'lopsidedness', 'skewness', 'irregularity']
senticnet['distal_muscular_dystrophy'] = [-0.586, 0, 0.724, -0.757, '#angry', '#disgusting', -0.689, 'myotonic_muscular_dystrophy', 'myotonic_dystrophy', 'myotonia_atrophica', 'dystrophy', 'genetic_disease']
senticnet['distance'] = [-0.705, 0, 0, -0.878, '#sad', '#disgusting', -0.528, 'far', 'distant', 'mile', 'distance_measure', 'kilometer']
senticnet['distance_measure'] = [0.045, 0.092, 0.06, 0.22, '#interesting', '#admirable', 0.099, 'how_far', 'distance', 'space_between', 'length_measurement', 'measurement_unit']
senticnet['distance_measurement'] = [0, 0.784, 0, 0.959, '#interesting', '#admirable', 0.581, 'distance_measure', 'length_measurement', 'meter', 'kilometer', 'imperial_measurement']
senticnet['distant'] = [-0.844, 0, 0.7, -0.927, '#sad', '#disgusting', -0.824, 'long_distance', 'long_distance_relationship', 'far_from_each_other', 'length_measurement', 'kilometer']
senticnet['distaste'] = [-0.127, 0.193, 0.593, -0.627, '#angry', '#disgusting', -0.385, 'antipathy', 'aversion', 'disapproval', 'disapprove', 'disapproving']
senticnet['distasteful'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['distastefully'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['distastefulness'] = [-0.516, 0, 0.607, -0.769, '#angry', '#disgusting', -0.631, 'offensiveness', 'odiousness', 'blatancy', 'patency', 'obviousness']
senticnet['distemper'] = [-0.892, 0, 0.943, -0.561, '#sad', '#angry', -0.799, 'ill_humor', 'crossness', 'pet', 'testiness', 'touchiness']
senticnet['distension'] = [0.777, -0.895, 0, 0.508, '#joyful', '#surprising', 0.727, 'stretching', 'enlarge', 'dilatation', 'get_bigger', 'enlargement']
senticnet['distinct'] = [0.891, 0.987, 0, 0, '#joyful', '#interesting', 0.626, 'distinguishable', 'discrete', 'decided', 'clear-cut', 'trenchant']
senticnet['distinction'] = [0.026, 0.152, -0.093, 0.164, '#interesting', '#admirable', 0.083, 'school_division', 'group_student', 'freshman', 'grade', 'college_course']
senticnet['distinctive_smell'] = [0, 0, 0.912, -0.705, '#angry', '#disgusting', -0.539, 'gymnast', 'bikini', 'underwear', 'basketball_hoop', 'dirty_sock']
senticnet['distinctiveness'] = [0.664, -0.903, 0, 0.788, '#surprising', '#admirable', 0.785, 'individualism', 'individuality', 'individuation', 'idiosyncrasy', 'foible']
senticnet['distinctness'] = [0.805, -0.62, 0, 0.86, '#joyful', '#admirable', 0.762, 'clearness', 'clarity', 'discernability', 'uncloudedness', 'legibility']
senticnet['distinguish'] = [0.051, 0.34, -0.204, 0.357, '#interesting', '#admirable', 0.181, 'gentleman', 'plea', 'honor', 'truthful', 'compare']
senticnet['distinguished'] = [0.898, -0.562, 0, 0.513, '#joyful', '#surprising', 0.658, 'stately', 'imposing', 'courtly', 'dignified', 'grand']
senticnet['distinguished_service_cross'] = [0.586, -0.651, 0, 0.503, '#joyful', '#surprising', 0.58, 'decoration', 'laurel_wreath', 'medal', 'medallion', 'palm']
senticnet['distortable'] = [0.896, -0.663, 0, 0.667, '#joyful', '#admirable', 0.742, 'mutable', 'changeful', 'reversible', 'adjustable', 'unstable']
senticnet['distorted'] = [0, 0, -0.785, -0.786, '#scared', '#disgusting', -0.524, 'falsify', 'garble', 'warp', 'twist', 'deform']
senticnet['distorted_perception'] = [-0.646, 0, 0.911, -0.709, '#angry', '#disgusting', -0.755, 'headache', 'see_dragon', 'illusion', 'distorted_vision', 'hallucinogen']
senticnet['distorted_shape'] = [0.697, -0.507, 0, 0.792, '#joyful', '#admirable', 0.665, 'tortuousness', 'gnarl', 'warp', 'tortuosity', 'torsion']
senticnet['distorted_vision'] = [-0.646, 0, 0.911, -0.709, '#angry', '#disgusting', -0.755, 'headache', 'see_dragon', 'illusion', 'hallucinogen', 'distorted_perception']
senticnet['distortion'] = [-0.642, 0, 0.815, -0.729, '#angry', '#disgusting', -0.729, 'warp', 'harm', 'impairment', 'damage', 'warping']
senticnet['distract'] = [0, 0, -0.929, -0.828, '#scared', '#disgusting', -0.586, 'neglect_chore', 'find_out_new', 'see_ad', 'look_picture', 'eye_strain']
senticnet['distracted'] = [0, 0, -0.854, -0.701, '#scared', '#disgusting', -0.518, 'fall_asleep', 'doze_off', 'disconnected', 'sleepy', 'boring_talk']
senticnet['distraction'] = [0, 0, 0.725, -0.806, '#angry', '#disgusting', -0.51, 'complication', 'confusion', 'disturbance', 'interference', 'interruption']
senticnet['distrait'] = [-0.714, 0, 0.906, -0.934, '#angry', '#disgusting', -0.851, 'absent', 'forgetful', 'distracted', 'inattentive', 'scatty']
senticnet['distress'] = [-0.611, 0.262, -0.386, -0.223, '#sad', '#scared', -0.319, 'humiliation', 'shame', 'misery', 'fright', 'upset']
senticnet['distressed'] = [-0.971, 0, 0.746, 0, '#sad', '#angry', -0.572, 'dismay', 'shamefacedly', 'shamefacedness', 'sheepishness', 'dysphoric']
senticnet['distressful'] = [-0.797, 0, -0.815, 0, '#sad', '#scared', -0.537, 'disquieted', 'distressing', 'disturbing', 'perturbing', 'troubling']
senticnet['distressfully'] = [-0.854, 0, -0.821, 0, '#sad', '#scared', -0.558, 'disquieted', 'distressing', 'disturbing', 'perturbing', 'troubling']
senticnet['distressfulness'] = [-0.534, 0, 0.733, -0.618, '#angry', '#disgusting', -0.628, 'severeness', 'intensiveness', 'intensity', 'foulness', 'seriousness']
senticnet['distressing'] = [-0.926, 0, -0.82, 0, '#sad', '#scared', -0.582, 'disquieted', 'disturbing', 'perturbing', 'troubling', 'worrisome']
senticnet['distressingly'] = [-0.854, 0, -0.934, 0, '#sad', '#scared', -0.596, 'disquieted', 'distressing', 'disturbing', 'perturbing', 'troubling']
senticnet['distressingly_bad'] = [-0.923, 0, 0.095, -0.91, '#sad', '#disgusting', -0.643, 'mess', 'terrible_loss', 'terrible_crime', 'bad_influence', 'awful_event']
senticnet['distribute'] = [-0.051, 0.224, -0.194, 0.335, '#interesting', '#admirable', 0.105, 'hand_over', 'donate', 'take', 'wedding_vow', 'limit_time']
senticnet['distribute_information'] = [-0.051, 0.224, -0.194, 0.335, '#interesting', '#admirable', 0.105, 'communicate_with_others', 'exchange_idea', 'exchange_information', 'communicate_family', 'communicate_idea']
senticnet['distribution'] = [0.948, -0.992, 0, 0.549, '#joyful', '#surprising', 0.83, 'sampling', 'equidistribution', 'frequency_distribution', 'normal_distribution', 'sample_distribution']
senticnet['distribution_law'] = [0.463, 0.561, -0.294, 0.281, '#joyful', '#interesting', 0.337, 'law_of_effect', 'principle', 'rule', 'law_of_diminishing_returns', 'law_of_nature']
senticnet['district'] = [0.858, -0.891, 0, 0.719, '#joyful', '#surprising', 0.823, 'mandatory', 'administrative_district', 'administrative_division', 'territorial_division', 'borderland']
senticnet['distrust'] = [-0.408, 0, -0.431, -0.061, '#sad', '#scared', -0.3, 'deceive', 'calamity', 'big_monster', 'unsafe', 'deception']
senticnet['distrustful'] = [0, 0, -0.969, -0.908, '#scared', '#disgusting', -0.626, 'doubting', 'wary', 'sceptical', 'skeptical', 'overjealous']
senticnet['disturb'] = [-0.111, -0.083, 0.058, -0.179, '#sad', '#disgusting', -0.088, 'loud_cry', 'hear_voice', 'scream', 'freak_out', 'groan']
senticnet['disturbance'] = [-0.748, 0, 0.982, -0.506, '#sad', '#angry', -0.745, 'bother', 'trouble', 'fuss', 'hassle', 'activity']
senticnet['disturbed'] = [-0.706, 0, -0.735, 0, '#sad', '#scared', -0.48, 'disquieted', 'distressing', 'disturbing', 'perturbing', 'troubling']
senticnet['disturber'] = [-0.651, 0, 0.716, -0.942, '#angry', '#disgusting', -0.77, 'bad_hat', 'provoker', 'inciter', 'instigant', 'hellhound']
senticnet['disturbing'] = [-0.854, 0, 0.872, -0.946, '#angry', '#disgusting', -0.891, 'disquieted', 'distressing', 'perturbing', 'troubling', 'worrisome']
senticnet['disunify'] = [-0.811, 0, 0.74, -0.778, '#sad', '#disgusting', -0.776, 'separate', 'split', 'break', 'part', 'split_up']
senticnet['disuse'] = [-0.632, 0, 0.663, -0.828, '#angry', '#disgusting', -0.708, 'wreck', 'twilight', 'neglect', 'declination', 'condition']
senticnet['disused'] = [-0.909, 0, 0.517, -0.92, '#sad', '#disgusting', -0.782, 'outdated', 'obsolescent', 'noncurrent', 'obsolete', 'superannuated']
senticnet['ditch'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'throw_out', 'discard', 'get_rid', 'dispose', 'abandon']
senticnet['dither'] = [-0.692, 0, 0.768, -0.671, '#sad', '#angry', -0.71, 'niggle', 'pother', 'worry', 'flap', 'scruple']
senticnet['diuretic'] = [0.045, 0, -0.052, -0.08, '#scared', '#disgusting', -0.029, 'healthy_drink', 'cola', 'popular_soda', 'beverage', 'soft_drink']
senticnet['dive'] = [-0.901, 0, 0.848, -0.944, '#sad', '#disgusting', -0.898, 'cabaret', 'nightclub', 'night_club', 'club', 'nightspot']
senticnet['diverge'] = [-0.866, 0, 0.511, -0.764, '#sad', '#disgusting', -0.714, 'separate', 'move', 'branch', 'ramify', 'fork']
senticnet['divergence'] = [-0.836, 0, 0.546, -0.88, '#sad', '#disgusting', -0.754, 'difference', 'allomerism', 'deviation', 'variation', 'departure']
senticnet['divergency'] = [-0.229, 0, -0.095, -0.165, '#sad', '#disgusting', -0.163, 'inequality', 'reject', 'discard', 'difference', 'gap']
senticnet['divergent_strabismus'] = [-0.898, 0, 0.709, -0.641, '#sad', '#angry', -0.749, 'squint', 'exotropia', 'walleye', 'abnormality', 'abnormalcy']
senticnet['diverse'] = [0.057, 0, 0, 0.153, '#joyful', '#admirable', 0.07, 'multiple', 'cute', 'driven_person', 'hairy', 'large_breadbox']
senticnet['diverseness'] = [-0.646, 0, 0.773, -0.686, '#angry', '#disgusting', -0.702, 'heterogeneity', 'multifariousness', 'diversity', 'variety', 'nonuniformity']
senticnet['diversion'] = [0.097, -0.173, 0.072, -0.079, '#joyful', '#surprising', 0.04, 'pastime', 'have_fun', 'fun_activity', 'amusement', 'fun_time']
senticnet['diversionist'] = [-0.583, 0, 0.714, -0.612, '#angry', '#disgusting', -0.636, 'waster', 'sleeper', 'destroyer', 'ruiner', 'undoer']
senticnet['diversity'] = [0, 0.961, 0, 0.931, '#interesting', '#admirable', 0.631, 'prosper', 'desirable', 'cherish', 'a_lot_of_sex', 'whatever']
senticnet['diverticulitis'] = [-0.998, 0, 0.964, -0.704, '#sad', '#angry', -0.889, 'blepharitis', 'inflammation', 'epiglottitis', 'orchitis', 'prostatitis']
senticnet['divest'] = [-0.702, 0, 0.631, -0.563, '#sad', '#angry', -0.632, 'bereave', 'expropriate', 'disarm', 'unclothe', 'take']
senticnet['divide'] = [-0.024, 0.114, 0, 0.204, '#interesting', '#admirable', 0.098, 'mimic', 'halve', 'separate', 'copy', 'make_copy']
senticnet['divide_country'] = [-0.117, 0, 0, 0, '#sad', '#sad', -0.039, 'enter_door', 'hang_picture', 'turn_knob', 'shut_door', 'bicycle_store']
senticnet['divide_nation'] = [-0.4, -0.121, 0.062, -0.193, '#sad', '#disgusting', -0.178, 'lie_court', 'receive_punishment', 'commit_crime', 'lie', 'tell_lie']
senticnet['divide_person'] = [0, 0, 0, 0.095, '#admirable', '#admirable', 0.032, 'reach_impasse', 'change_society', 'take_oath', 'divide', 'institute_civil_action']
senticnet['divide_property'] = [0, -0.015, 0, 0.07, '#surprising', '#admirable', 0.028, 'drive_upon', 'fast_travel', 'travel_car', 'drive_quickly', 'drive_somewhere']
senticnet['dividend'] = [0, 0.747, 0, 0.784, '#interesting', '#admirable', 0.51, 'account', 'banker', 'piggy_bank', 'bank_loan', 'deposit']
senticnet['divination'] = [0.861, -0.559, 0, 0.578, '#joyful', '#admirable', 0.666, 'conjecture', 'speculation', 'guess', 'surmisal', 'supposition']
senticnet['divine'] = [0.128, 0.152, -0.091, 0.264, '#interesting', '#admirable', 0.151, 'environment', 'beautiful', 'live_environment', 'really_big', 'important_man']
senticnet['divine_guidance'] = [0.9, -0.742, 0, 0.721, '#joyful', '#surprising', 0.788, 'difficulty', 'inspiration', 'determinant', 'determinative', 'cognitive_factor']
senticnet['diviner'] = [0.703, -0.612, 0, 0.637, '#joyful', '#admirable', 0.651, 'oracle', 'necromancer', 'illusionist', 'visionary', 'geomancer']
senticnet['divinity'] = [0.978, -0.88, 0, 0.785, '#joyful', '#surprising', 0.881, 'daemon', 'demigod', 'sea_god', 'sun_god', 'goddess']
senticnet['divisible'] = [0.998, -0.635, 0, 0.574, '#joyful', '#surprising', 0.736, 'cleavable', 'dissociable', 'separable', 'severable', 'dissociative']
senticnet['division'] = [0, 0.119, 0, 0.106, '#interesting', '#admirable', 0.075, 'divide', 'factor', 'subtraction', 'math_action', 'fraction']
senticnet['divisive'] = [-0.935, 0, 0.515, -0.786, '#sad', '#disgusting', -0.745, 'discrepant', 'at_variance', 'dissentious', 'discordant', 'factious']
senticnet['divorce'] = [-0.744, 0, 0, -0.72, '#sad', '#disgusting', -0.488, 'get_divorce', 'stop_marry', 'break_up', 'institute_civil_action', 'serve_justice']
senticnet['divorce_money'] = [0, 0.369, -0.163, 0.226, '#interesting', '#admirable', 0.144, 'payment', 'owe', 'tax', 'bribe', 'afford']
senticnet['divorced'] = [-0.73, 0, 0.729, -0.981, '#sad', '#disgusting', -0.813, 'unwed', 'unwedded', 'unmarried', 'mateless', 'widowed']
senticnet['dizen'] = [-0.888, 0, 0.896, -0.796, '#sad', '#angry', -0.86, 'overdress', 'attire', 'dress_up', 'prink', 'fig_out']
senticnet['dizziness'] = [-0.113, -0.101, 0.153, -0.234, '#angry', '#disgusting', -0.133, 'get_tired', 'see_neighbor', 'sore_leg', 'dog_bark', 'exhaustion']
senticnet['dizzy'] = [0, 0, -0.739, -0.792, '#scared', '#disgusting', -0.51, 'hard_see', 'rain_fall', 'dew', 'rain', 'mist']
senticnet['djembe'] = [0, -0.027, 0.055, -0.057, '#angry', '#disgusting', -0.028, 'percussion', 'make_musicr', 'use_jazz_music', 'tune_instrument', 'drummer']
senticnet['do_again'] = [-0.031, 0.213, 0, 0.268, '#interesting', '#admirable', 0.15, 'again_and_again', 'one_more', 'redo', 'done', 'inclusion']
senticnet['do_anything'] = [0, 0.769, 0, 0, '#interesting', '#interesting', 0.256, 'direct_play', 'face_music', 'shade_eye', 'give_signal', 'take_ticket']
senticnet['do_drug'] = [-0.834, 0.214, -0.391, -0.108, '#sad', '#scared', -0.373, 'use_drug', 'ecstasy_pill', 'drug_use', 'drug', 'addiction']
senticnet['do_exercise'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'go_jogging', 'eat_well', 'stay_healthy', 'check_health', 'maintain_good_health']
senticnet['do_groceries'] = [0.463, 0.561, -0.294, 0.281, '#joyful', '#interesting', 0.337, 'buy_grocery', 'buy_bread', 'buy_milk', 'buy_pizza', 'buy_pasta']
senticnet['do_homework'] = [0, -0.989, 0, 0.849, '#surprising', '#admirable', 0.613, 'study', 'math_homework', 'student', 'attend_class', 'write']
senticnet['do_it'] = [0.963, -0.656, 0, 0.755, '#joyful', '#admirable', 0.791, 'have', 'pair', 'take', 'couple', 'fornicate']
senticnet['do_it_now'] = [0.463, 0.561, -0.294, 0.281, '#joyful', '#interesting', 0.337, 'execute', 'act', 'perform', 'fulfill', 'carry_out']
senticnet['do_it_yourself'] = [-0.028, 0.103, 0.069, 0.151, '#interesting', '#admirable', 0.052, 'single', 'unit_of_measurement', 'two_halves', 'enumeration', 'alone']
senticnet['do_shopping'] = [0.463, 0.561, -0.294, 0.281, '#joyful', '#interesting', 0.337, 'buy_grocery', 'buy_cheese', 'go_supermarket', 'buy_food', 'buy_ingredient']
senticnet['do_something'] = [-0.042, 0.131, -0.055, 0.186, '#interesting', '#admirable', 0.073, 'react', 'posture', 'take_action', 'behave', 'take_initiative']
senticnet['docile'] = [0.625, -0.501, 0, 0.822, '#joyful', '#admirable', 0.649, 'meek', 'tame', 'yielding', 'sheeplike', 'sheepish']
senticnet['docility'] = [0.637, -0.911, 0, 0.757, '#surprising', '#admirable', 0.768, 'manageability', 'manageableness', 'tractability', 'obedience', 'amenability']
senticnet['dock'] = [-0.023, -0.012, 0.045, -0.051, '#angry', '#disgusting', -0.036, 'haddryad', 'pier', 'ferry', 'dryad', 'shallow']
senticnet['doctor'] = [-0.045, 0, -0.163, -0.123, '#scared', '#disgusting', -0.11, 'nurse', 'cure', 'doctor_office', 'doctor_surgery', 'merlin']
senticnet['doctor_appointment'] = [-0.042, 0.131, -0.055, 0.186, '#interesting', '#admirable', 0.073, 'call_doctor', 'doctor', 'make_doctor_appointment', 'find_doctor', 'appointment']
senticnet['doctor_examination_room'] = [0, 0, -0.136, -0.182, '#scared', '#disgusting', -0.106, 'doctor_office', 'therapist', 'nurse', 'syringe', 'emergency_ward']
senticnet['doctor_office'] = [-0.028, 0, -0.151, -0.148, '#scared', '#disgusting', -0.109, 'hospital', 'medical_office', 'clinic', 'doctor', 'dentist_office']
senticnet['doctor_patient'] = [-0.742, 0, -0.79, 0, '#sad', '#scared', -0.511, 'medical_person', 'medical', 'doctor_surgery', 'cure', 'medical_procedure']
senticnet['doctor_surgery'] = [-0.154, 0.074, -0.256, -0.088, '#sad', '#scared', -0.141, 'doctor', 'nurse', 'cure', 'medical_procedure', 'doctor_office']
senticnet['doctor_tool'] = [-0.089, 0, -0.056, 0, '#sad', '#scared', -0.048, 'sew_term', 'use_needle', 'mend', 'needle_thread', 'sewn']
senticnet['doctor_up'] = [-0.854, 0, 0.684, -0.798, '#sad', '#disgusting', -0.779, 'debase', 'adulterate', 'dilute', 'stretch', 'load']
senticnet['doctor_visit'] = [-0.737, 0, -0.971, 0, '#sad', '#scared', -0.569, 'pain', 'ouch', 'hurt', 'ache', 'dislocation']
senticnet['doctor_work'] = [-0.094, 0, -0.132, -0.082, '#sad', '#scared', -0.103, 'medical_procedure', 'doctor_surgery', 'operation', 'cure', 'treatment']
senticnet['doctrinaire'] = [0.633, -0.922, 0, 0.869, '#surprising', '#admirable', 0.808, 'advocate', 'bigot', 'dogmatist', 'partisan', 'advocator']
senticnet['doctrine'] = [0.95, -0.772, 0, 0.578, '#joyful', '#surprising', 0.767, 'philosophy', 'amoralism', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['document'] = [0, 0.077, 0, 0.068, '#interesting', '#admirable', 0.048, 'make_book', 'file', 'paper_write', 'readable', 'newspaper_write']
senticnet['document_type'] = [-0.042, 0.131, -0.055, 0.186, '#interesting', '#admirable', 0.073, 'print_word', 'paragraph', 'typeface', 'hold_information', 'print']
senticnet['documentary'] = [0, 0.762, 0, 0, '#interesting', '#interesting', 0.254, 'encyclopaedia', 'tropical_rainforest', 'learn_new_information', 'tropical_forest', 'children_story']
senticnet['documentation'] = [-0.078, 0.142, 0, 0.095, '#interesting', '#admirable', 0.053, 'written_down', 'document', 'record_information', 'misspell', 'use_pencil']
senticnet['documented'] = [-0.642, 0, 0.852, -0.803, '#angry', '#disgusting', -0.766, 'unquestionable', 'echt', 'veritable', 'attested', 'authenticated']
senticnet['doddle'] = [0.746, -0.678, 0, 0.529, '#joyful', '#surprising', 0.651, 'labor', 'cinch', 'undertaking', 'project', 'task']
senticnet['dodge'] = [0.847, 0, 0, 0.858, '#joyful', '#admirable', 0.568, 'displace', 'swing', 'snowshoe', 'shuttle', 'bang']
senticnet['dodger'] = [-0.97, 0, 0.549, -0.805, '#sad', '#disgusting', -0.775, 'beguiler', 'slicker', 'deceiver', 'cheat', 'cheater']
senticnet['dodging'] = [-0.771, 0, 0.504, -0.914, '#sad', '#disgusting', -0.73, 'carelessness', 'negligence', 'neglect', 'soldiering', 'escape_mechanism']
senticnet['doe'] = [0, 0.73, 0, 0.889, '#interesting', '#admirable', 0.54, 'widow', 'nickname', 'pretty_woman', 'sophisticated', 'woman']
senticnet['doer'] = [0.991, -0.733, 0, 0.668, '#joyful', '#surprising', 0.797, 'goffer', 'gopher', 'actor', 'busy_bee', 'worker']
senticnet['dog'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'pet', 'best_friend', 'cur', 'domestic_animal', 'domesticated_animal']
senticnet['dog_bark'] = [-0.135, -0.116, 0.046, -0.184, '#sad', '#disgusting', -0.083, 'breaheavily', 'run_out_breath', 'get_exhausted', 'exhaustion', 'blister_foot']
senticnet['dog_bite'] = [0, 0, -0.808, -0.833, '#scared', '#disgusting', -0.547, 'leg_hurt', 'strike_ball', 'get_injured', 'become_exhausted', 'broken_leg']
senticnet['dog_cat'] = [0.731, 0, 0, 0.843, '#joyful', '#admirable', 0.525, 'pet', 'loyal', 'smart_dog', 'faithful', 'big_dog']
senticnet['dog_chase'] = [0, 0, -0.996, -0.997, '#scared', '#disgusting', -0.664, 'get_out_breath', 'sore_leg', 'become_wind', 'see_neighbor', 'dog_bark']
senticnet['dog_die'] = [-0.79, 0, -0.912, 0, '#sad', '#scared', -0.567, 'step_dog_poop', 'broken_window', 'step_dog_shit', 'broken_wrist', 'run_over_car']
senticnet['dog_fennel'] = [0.833, 0.919, 0, 0, '#joyful', '#interesting', 0.584, 'mayweed', 'stinking_mayweed', 'stinking_chamomile', 'composite_plant', 'oxeye_daisy']
senticnet['dog_fetch'] = [0, -0.069, 0.046, 0.09, '#surprising', '#admirable', 0.038, 'piece_of_wood', 'dog', 'adhere', 'long_wood', 'fetch']
senticnet['dog_flea'] = [-0.997, 0, 0.612, -0.99, '#sad', '#disgusting', -0.866, 'dirty_animal', 'flea', 'dirty_cat', 'dirty_pet', 'dirty_dog']
senticnet['dog_food'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'attract_dog', 'food', 'dog', 'cat_food', 'pet_food']
senticnet['dog_fur'] = [0, 0, 0.073, 0, '#angry', '#angry', -0.024, 'animal_hair', 'dog_hair', 'animal_fur', 'dog_cat', 'bite_dog']
senticnet['dog_hair'] = [-0.032, -0.003, 0.087, -0.057, '#angry', '#disgusting', -0.058, 'dog_fur', 'dog_cat', 'kitty', 'pet', 'animal_hair']
senticnet['dog_howl'] = [-0.366, -0.046, -0.415, -0.11, '#sad', '#scared', -0.282, 'sadness', 'lament', 'deep_sadness', 'depression', 'shed_tear']
senticnet['dog_like'] = [0.033, 0.076, 0, 0.066, '#interesting', '#admirable', 0.058, 'baby_dog', 'most_dogs', 'puppet', 'dog', 'boyfriend']
senticnet['dog_pet'] = [0.902, 0.772, 0, 0, '#joyful', '#interesting', 0.558, 'paw', 'two_ears', 'abdomen', 'two_arms', 'breast']
senticnet['dog_poop'] = [0, 0, 0.735, -0.708, '#angry', '#disgusting', -0.481, 'crap', 'dung', 'shit', 'noise_pollution', 'compost']
senticnet['dog_show'] = [0, -0.069, 0.046, 0.09, '#surprising', '#admirable', 0.038, 'discipline', 'take_care_of_pet', 'circus', 'training', 'animal']
senticnet['dog_tag'] = [-0.052, 0.072, 0.012, 0.066, '#interesting', '#admirable', 0.025, 'pet', 'leash', 'animal', 'bell_cat', 'dog']
senticnet['dog_toy'] = [0, 0, 0, 0.072, '#admirable', '#admirable', 0.024, 'dog_treat', 'structural_support', 'human_part', 'human_shape', 'inside_body']
senticnet['dog_treat'] = [0, 0, 0, 0.072, '#admirable', '#admirable', 0.024, 'dog_toy', 'structural_support', 'human_part', 'human_shape', 'inside_body']
senticnet['dog_wag_tail'] = [0.927, 0, 0, 0.93, '#joyful', '#admirable', 0.619, 'workaholic', 'lonely_person', 'shed_tear', 'laugh', 'friendly_fire']
senticnet['dogged'] = [-0.964, 0, 0.858, -0.876, '#sad', '#disgusting', -0.899, 'contrarious', 'unregenerate', 'pertinacious', 'cantankerous', 'bolshy']
senticnet['dogging'] = [-0.605, 0, 0.509, -0.674, '#sad', '#disgusting', -0.596, 'continuous', 'persisting', 'sustained', 'consecutive', 'perpetual']
senticnet['doghouse'] = [-0.024, 0, -0.067, -0.037, '#scared', '#disgusting', -0.043, 'alleyway', 'animal_shelter', 'vet_office', 'home', 'vet']
senticnet['dogma'] = [0.99, 0, 0, 0.982, '#joyful', '#admirable', 0.657, 'god', 'spiritual', 'saint', 'prayer', 'angel']
senticnet['dogmatist'] = [0.633, -0.922, 0, 0.869, '#surprising', '#admirable', 0.808, 'advocate', 'bigot', 'partisan', 'doctrinaire', 'advocator']
senticnet['dogshit'] = [-0.894, 0, 0.739, -0.972, '#sad', '#disgusting', -0.868, 'rot', 'bunk', 'bunkum', 'buncombe', 'guff']
senticnet['dogwood'] = [0.958, -0.821, 0, 0.924, '#joyful', '#admirable', 0.901, 'bunchberry', 'dwarf_cornel', 'crackerberry', 'pudding_berry', 'common_white_dogwood']
senticnet['dogwood_tree'] = [0.506, -0.772, 0, 0.543, '#surprising', '#admirable', 0.607, 'bunchberry', 'dwarf_cornel', 'crackerberry', 'pudding_berry', 'common_white_dogwood']
senticnet['doings'] = [0.577, -0.825, 0, 0.841, '#surprising', '#admirable', 0.748, 'dirty_tricks', 'activity', 'easiness', 'aggression', 'dirty_pool']
senticnet['dolby_surround'] = [0.049, 0.167, -0.053, 0.295, '#interesting', '#admirable', 0.153, 'four_sides', 'sound_system', 'bass', 'movie', 'surround']
senticnet['doleful'] = [-0.855, 0.207, -0.561, 0, '#sad', '#scared', -0.403, 'sorrowfully', 'sadly', 'dolefully', 'ruefulness', 'regretful']
senticnet['dolefully'] = [-0.844, 0.22, -0.549, 0, '#sad', '#scared', -0.391, 'wretched', 'sorrowfully', 'doleful', 'sadly', 'ruefulness']
senticnet['dolefulness'] = [-0.755, 0.286, -0.449, -0.053, '#sad', '#scared', -0.324, 'joyless', 'joylessly', 'joylessness', 'depressing', 'cheerless']
senticnet['doll'] = [0, -0.087, 0, 0, '#surprising', '#surprising', 0.029, 'toy', 'stuff_animal', 'dummy', 'mannequin', 'action_figure']
senticnet['doll_up'] = [-0.052, 0.072, 0.012, 0.066, '#interesting', '#admirable', 0.025, 'night_dress', 'dress', 'make_up', 'fashionable', 'dress_up']
senticnet['dollar'] = [0, 0.192, 0.019, 0.058, '#interesting', '#admirable', 0.077, 'franc', 'euro', 'cent', 'dollar_bill', 'banknote']
senticnet['dollar_bill'] = [0, 0.949, 0, 0.713, '#interesting', '#admirable', 0.554, 'cash_bill', 'banknote', 'check', 'euro', 'paper_bill']
senticnet['dollar_cent'] = [0, 0.27, 0.014, 0.133, '#interesting', '#admirable', 0.13, 'dollar_sign', 'money_amount', 'value_amount', 'payment_amount', 'money_value']
senticnet['dollar_change'] = [0, 0.207, 0.063, 0.131, '#interesting', '#admirable', 0.092, 'small_change', 'currency_unit', 'american_money', 'money_unit', 'euro']
senticnet['dollar_sign'] = [0, 0.264, 0.009, 0.144, '#interesting', '#admirable', 0.133, 'value_amount', 'dollar_cent', 'money_amount', 'sticker', 'payment_amount']
senticnet['dolor'] = [-0.902, 0.147, -0.625, 0.064, '#sad', '#scared', -0.439, 'feel_pain', 'plaintive', 'plaintiveness', 'plaintively', 'woebegone']
senticnet['dolorous'] = [-0.71, 0.312, -0.4, -0.08, '#sad', '#scared', -0.293, 'lachrymose', 'tearful', 'weeping', 'tearfulness', 'weepiness']
senticnet['dolphin'] = [0.024, 0.102, -0.068, 0.074, '#interesting', '#admirable', 0.044, 'marine_mammal', 'large_mammal', 'pack_animal', 'mammal', 'smart_creature']
senticnet['dolt'] = [-0.791, 0, 0, -0.953, '#sad', '#disgusting', -0.581, 'idiot', 'douchebag', 'dumb', 'little_minded', 'stupid']
senticnet['domain'] = [0, 0.079, 0, 0.124, '#interesting', '#admirable', 0.068, 'roman', 'region', 'political_entity', 'political_division', 'united_country']
senticnet['dome'] = [0, 0.077, 0.039, 0.154, '#interesting', '#admirable', 0.064, 'marbles', 'round_figure', 'almond', 'round_ball', 'sphere']
senticnet['dome_arch'] = [0.048, 0.18, -0.049, 0.169, '#interesting', '#admirable', 0.116, 'minister', 'pope', 'contradiction', 'preist', 'evangelist']
senticnet['domestic_animal'] = [0.109, 0.066, 0, 0, '#joyful', '#interesting', 0.058, 'social_animal', 'home_animal', 'household_animal', 'pet', 'herd_sheep']
senticnet['domestic_dog'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'dog', 'feist', 'fice', 'pariah_dog', 'cur']
senticnet['domestic_dwell'] = [0.037, 0.106, 0, 0.14, '#interesting', '#admirable', 0.094, 'dwell_place', 'live_place', 'place_to_live', 'live_quarter', 'place_where_people_live']
senticnet['domestic_llama'] = [0.553, 0.658, -0.251, 0.271, '#joyful', '#interesting', 0.41, 'guanaco', 'llama', 'alpaca', 'artiodactyl', 'artiodactyl_mammal']
senticnet['domestic_pet'] = [0.057, 0, 0.023, 0.124, '#joyful', '#admirable', 0.053, 'hairy', 'cute', 'furry', 'pet', 'animal_furry']
senticnet['domesticate'] = [0.053, 0.094, 0, 0.136, '#interesting', '#admirable', 0.094, 'poisonous_human', 'barn_animal', 'stand_field', 'neigh', 'alive']
senticnet['domesticate_animal'] = [0.03, 0.068, -0.044, 0.093, '#interesting', '#admirable', 0.049, 'cultivated', 'tamed', 'live_creature', 'furry_creature', 'farm']
senticnet['domesticate_cat'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'family_dog', 'domesticate_pet', 'animal', 'domesticate_dog', 'dog']
senticnet['domesticate_dog'] = [0.056, 0.157, 0, 0.154, '#interesting', '#admirable', 0.122, 'family_dog', 'domesticate_pet', 'animal', 'domesticate_cat', 'dog']
senticnet['domesticate_pet'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'family_dog', 'domesticate_dog', 'animal', 'domesticate_cat', 'dog']
senticnet['domesticate_plant'] = [0.057, 0, 0.038, 0.073, '#joyful', '#admirable', 0.031, 'delicious_fruit', 'small_fruit', 'tree_fruit', 'vine_fruit', 'yellow_fruit']
senticnet['domesticated'] = [0.778, -0.795, 0, 0.665, '#joyful', '#surprising', 0.746, 'gentle', 'docile', 'tame', 'sweet', 'tamed']
senticnet['domesticated_animal'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'dog', 'animal', 'animate_being', 'pet', 'creature']
senticnet['domestication'] = [0.735, -0.714, 0, 0.566, '#joyful', '#surprising', 0.672, 'improvement', 'betterment', 'habituation', 'adjustment', 'shakedown']
senticnet['domesticize'] = [0.849, -0.573, 0, 0.815, '#joyful', '#admirable', 0.746, 'break', 'change', 'alter', 'modify', 'break_in']
senticnet['domicile'] = [0, 0.078, -0.063, 0.096, '#interesting', '#admirable', 0.037, 'dwell_place', 'abide', 'residence', 'domestic_dwell', 'live_place']
senticnet['dominance'] = [-0.837, 0, 0.858, -0.795, '#sad', '#angry', -0.83, 'absolutism', 'ascendance', 'autocracy', 'ascendancy', 'tirant']
senticnet['dominant'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'role', 'alpha_male', 'dominant_role', 'master_and_commander', 'sergeant']
senticnet['dominant_role'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'role', 'alpha_male', 'dominant', 'master_and_commander', 'sergeant']
senticnet['dominate'] = [-0.92, 0, 0.876, 0, '#sad', '#angry', -0.599, 'rule', 'govern', 'direct', 'control', 'influence']
senticnet['dominated'] = [0.858, -0.933, 0, 0.58, '#joyful', '#surprising', 0.79, 'regimented', 'obsessed', 'possessed', 'disciplined', 'controlled']
senticnet['domination'] = [0, 0.886, 0, 0.728, '#interesting', '#admirable', 0.538, 'authority', 'control', 'supervisor', 'chief', 'president']
senticnet['domineering'] = [-0.91, 0, 0.521, -0.811, '#sad', '#disgusting', -0.747, 'bullying', 'peremptory', 'blustery', 'roughshod', 'cavalier']
senticnet['domineeringness'] = [0.968, -0.88, 0, 0.831, '#joyful', '#surprising', 0.893, 'superiority', 'pride', 'superbia', 'imperiousness', 'haughtiness']
senticnet['dominion'] = [0.94, -0.636, 0, 0.772, '#joyful', '#admirable', 0.783, 'paramountcy', 'raj', 'reign', 'sovereignty', 'suzerainty']
senticnet['don'] = [0.745, -0.713, 0, 0.709, '#joyful', '#surprising', 0.722, 'try_on', 'put_on', 'wear', 'assume', 'get_into']
senticnet['donate'] = [0.809, 0, 0, 0.704, '#joyful', '#admirable', 0.504, 'hand_over', 'distribute', 'hand_out', 'give', 'spread_love']
senticnet['donate_charity'] = [0, 0.106, -0.086, 0.115, '#interesting', '#admirable', 0.045, 'donate', 'give', 'help_less_fortunate', 'purchase_food', 'help']
senticnet['donation'] = [0, 0.264, -0.244, 0.34, '#interesting', '#admirable', 0.12, 'help_out', 'given', 'come_back', 'alms', 'lend']
senticnet['done'] = [-0.042, 0.202, -0.086, 0.211, '#interesting', '#admirable', 0.095, 'end_point', 'finish_complete', 'end', 'conclusion', 'conclude']
senticnet['done_person'] = [0.23, -0.07, 0.068, -0.029, '#joyful', '#surprising', 0.068, 'relate_music', 'move_rhythm_music', 'ballroom_dance', 'waltz', 'tap_foot']
senticnet['donee'] = [-0.943, 0, 0.871, -0.725, '#sad', '#angry', -0.846, 'pensionary', 'pensioner', 'devisee', 'legatee', 'recipient']
senticnet['donkey'] = [0, -0.021, 0, 0.06, '#surprising', '#admirable', 0.027, 'male_cow', 'baby_cow', 'little_horse', 'hoof_animal', 'animal']
senticnet['donnish'] = [0.71, -0.811, 0, 0.937, '#surprising', '#admirable', 0.819, 'erudite', 'scholarly', 'pedantic', 'learned', 'bookish']
senticnet['donor'] = [-0.053, 0, -0.153, -0.122, '#scared', '#disgusting', -0.109, 'drop_blood', 'blood', 'disease', 'contagious_disease', 'sick']
senticnet['donut'] = [0.051, -0.106, 0, 0, '#joyful', '#surprising', 0.052, 'cookie', 'pie', 'doughnut', 'muffin', 'custard']
senticnet['donut_shop'] = [0, 0, 0, -0.077, '#disgusting', '#disgusting', -0.026, 'car_dealership', 'truck_stop', 'railway_station', 'city_street', 'donut']
senticnet['doodle'] = [-0.029, 0.111, 0, 0.05, '#interesting', '#admirable', 0.044, 'sketch', 'use_crayon', 'draw', 'make_sketch', 'pencil_art']
senticnet['door'] = [0, 0, 0, 0.077, '#admirable', '#admirable', 0.026, 'glass_front', 'gate', 'doorway', 'use_farm', 'entranceway']
senticnet['door_handle'] = [0, -0.012, 0, 0.072, '#surprising', '#admirable', 0.028, 'door', 'glass_front', 'gate', 'use_farm', 'doorway']
senticnet['door_knob'] = [0, 0, 0, 0.096, '#admirable', '#admirable', 0.032, 'doorknob', 'knob', 'handle', 'lock', 'latch']
senticnet['door_lock'] = [0.033, 0, 0, 0.081, '#joyful', '#admirable', 0.038, 'door', 'frame', 'window_door', 'wall', 'doorway']
senticnet['door_open'] = [-0.102, 0, 0, 0, '#sad', '#sad', -0.034, 'sell_car', 'unlock_door', 'own_car', 'shine_car', 'shoulder_burden']
senticnet['door_opener'] = [0, 0, 0, 0.109, '#admirable', '#admirable', 0.036, 'knob', 'door_knob', 'door_handle', 'handle', 'hinge']
senticnet['doorbell'] = [0, 0, 0, 0.208, '#admirable', '#admirable', 0.069, 'knob', 'mailman', 'door_knob', 'doorknob', 'hinge']
senticnet['doorkeeper'] = [0.546, -0.768, 0, 0.74, '#surprising', '#admirable', 0.685, 'exorcist', 'deacon', 'acolyte', 'anagnost', 'holy_order']
senticnet['doorknob'] = [0, 0, 0, 0.096, '#admirable', '#admirable', 0.032, 'door_knob', 'knob', 'handle', 'lock', 'latch']
senticnet['doormat'] = [-0.918, 0, 0.681, -0.818, '#sad', '#disgusting', -0.806, 'chicken', 'softy', 'softie', 'crybaby', 'wimp']
senticnet['doorway'] = [0, 0, 0, 0.128, '#admirable', '#admirable', 0.043, 'vestibule', 'door', 'central_passage', 'gate', 'door_handle']
senticnet['doped'] = [-0.739, 0, 0.641, -0.748, '#sad', '#disgusting', -0.709, 'burnt', 'burned', 'proofed', 'treated', 'activated']
senticnet['dopey'] = [0, 0, 0.746, -0.914, '#angry', '#disgusting', -0.553, 'anserine', 'dopy', 'foolish', 'goosy', 'jerky']
senticnet['doppelganger'] = [0.849, -0.503, 0, 0.845, '#joyful', '#admirable', 0.732, 'mythical_monster', 'mythical_creature', 'abominable_snowman', 'yeti', 'legendary_creature']
senticnet['dork'] = [-0.032, -0.098, 0.112, -0.157, '#angry', '#disgusting', -0.068, 'remember_childhood', 'make_easy', 'play_tune', 'play_song', 'perform_of_music']
senticnet['dormancy'] = [-0.758, 0, 0.512, -0.758, '#sad', '#disgusting', -0.676, 'inactivity', 'inactiveness', 'slumber', 'inaction', 'hibernation']
senticnet['dormitory'] = [0, 0, 0.012, -0.063, '#angry', '#disgusting', -0.025, 'shack', 'cabin', 'hostel', 'college_dorm', 'student_home']
senticnet['dose'] = [-0.611, 0, 0.899, -0.622, '#angry', '#disgusting', -0.711, 'venereal_disease', 'venereal_infection', 'social_disease', 'sexually_transmitted_disease', 'gonorrhoea']
senticnet['dosser'] = [-0.817, 0, 0.747, -0.886, '#sad', '#disgusting', -0.817, 'vagrant', 'drifter', 'floater', 'vagabond', 'hobo']
senticnet['dot'] = [0.044, 0, 0.029, 0.064, '#joyful', '#admirable', 0.026, 'full_stop', 'sentence_end', 'period', 'clock_face', 'point']
senticnet['dotage'] = [-0.796, 0, 0.802, -0.549, '#sad', '#angry', -0.716, 'age', 'old_age', 'years', 'eld', 'geezerhood']
senticnet['dote'] = [0.568, -0.796, 0, 0.804, '#surprising', '#admirable', 0.723, 'age', 'get_on', 'senesce', 'mature', 'maturate']
senticnet['doting'] = [0, -0.714, 0, 0.984, '#surprising', '#admirable', 0.566, 'stud', 'constellate', 'disperse', 'adoring', 'fond']
senticnet['double'] = [0.963, -0.847, 0, 0.947, '#joyful', '#admirable', 0.919, 'match', 'reliever', 'equal', 'alternate', 'stunt_man']
senticnet['double_check'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'review', 'check_spelling', 'spelling', 'correct_homework', 'mark_exam']
senticnet['double_edge_razor'] = [0, 0, -0.951, -0.789, '#scared', '#disgusting', -0.58, 'scissor', 'razor', 'pair_of_scissors', 'haircut_scissor', 'clipper']
senticnet['double_entendre'] = [0.752, -0.752, 0, 0, '#joyful', '#surprising', 0.501, 'ambiguity', 'loophole', 'amphibology', 'amphiboly', 'parisology']
senticnet['double_happiness'] = [0.044, 0.142, -0.079, 0.084, '#interesting', '#admirable', 0.064, 'many_people', 'relate_person', 'human_group', 'happy_together', 'parent_child']
senticnet['double_money'] = [0.807, 0, 0, 0, '#joyful', '#joyful', 0.269, 'buy_stock', 'play_video_game', 'try_win_game', 'lose_money', 'desire_win']
senticnet['double_nature'] = [0.042, -0.036, 0, 0.112, '#joyful', '#admirable', 0.063, 'hybrid', 'clean', 'highway_road', 'go_green', 'car_drive']
senticnet['double_talk'] = [-0.614, 0, 0.738, -0.803, '#angry', '#disgusting', -0.718, 'babbling', 'gibber', 'mumbo_jumbo', 'babble', 'lallation']
senticnet['double_trouble'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'danger', 'dangerous', 'trouble', 'put_at_stake', 'problem']
senticnet['doubt'] = [-0.337, 0.111, -0.321, 0, '#sad', '#scared', -0.182, 'direct_play', 'care_child', 'keep_promise', 'quiet_child', 'tell_lie']
senticnet['doubter'] = [-0.527, 0, 0.95, -0.788, '#angry', '#disgusting', -0.755, 'skeptic', 'sceptic', 'pessimist', 'defeatist', 'negativist']
senticnet['doubtfulness'] = [0.795, -0.987, 0, 0.793, '#joyful', '#surprising', 0.858, 'incredulity', 'mental_rejection', 'skepticism', 'mistrust', 'distrust']
senticnet['doubting'] = [0.766, -0.648, 0, 0.526, '#joyful', '#surprising', 0.647, 'distrustful', 'wary', 'sceptical', 'skeptical', 'overjealous']
senticnet['douche'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'scumbag', 'bastard', 'asshole', 'motherfucker', 'dick']
senticnet['douchebag'] = [-0.791, 0, 0, -0.953, '#sad', '#disgusting', -0.581, 'idiot', 'dolt', 'dumb', 'little_minded', 'stupid']
senticnet['dough'] = [0.033, 0, 0.013, 0.064, '#joyful', '#admirable', 0.028, 'yeast', 'flour', 'crust', 'sweetness', 'staple_food']
senticnet['doughnut'] = [0.027, -0.081, 0, 0, '#joyful', '#surprising', 0.036, 'cookie', 'mousse', 'custard', 'cake', 'brownie']
senticnet['douse'] = [-0.809, 0, 0.962, -0.553, '#sad', '#angry', -0.775, 'sop', 'bedraggle', 'dowse', 'drench', 'soak']
senticnet['dove'] = [-0.03, -0.029, 0.027, -0.109, '#sad', '#disgusting', -0.046, 'crow', 'bird_type', 'water_bird', 'bird_prey', 'raven']
senticnet['down'] = [-0.749, 0.241, -0.427, 0, '#sad', '#scared', -0.312, 'low', 'grim', 'sorry', 'gloominess', 'gloomily']
senticnet['down_drain'] = [0, 0, 0.016, -0.09, '#angry', '#disgusting', -0.035, 'drain', 'skate_rink', 'septic_tank', 'beach', 'swimming_pool']
senticnet['down_feather'] = [0.814, -0.539, 0, 0.624, '#joyful', '#admirable', 0.659, 'feather', 'plume', 'duck_down', 'goose_down', 'swan_down']
senticnet['down_in_mouth'] = [-0.784, 0.266, -0.45, -0.052, '#sad', '#scared', -0.34, 'downhearted', 'low-spirited', 'depressed', 'dispirited', 'downcast']
senticnet['down_knee'] = [-0.087, 0.187, -0.057, 0.108, '#interesting', '#admirable', 0.05, 'pray', 'trust_god', 'believe_god', 'kneel', 'belief_god']
senticnet['down_payment'] = [0.973, 0.707, 0, 0, '#joyful', '#interesting', 0.56, 'money', 'wealthy', 'much_money', 'slogan', 'take_out_loan']
senticnet['down_syndrome'] = [-0.827, 0, 0.582, -0.741, '#sad', '#disgusting', -0.717, 'trisomy', 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder']
senticnet['downcast'] = [-0.784, 0.266, -0.45, -0.052, '#sad', '#scared', -0.34, 'downhearted', 'low-spirited', 'depressed', 'down_in_mouth', 'dispirited']
senticnet['downfall'] = [-0.78, 0, 0.764, -0.886, '#sad', '#disgusting', -0.81, 'withering', 'weakening', 'atrophy', 'fading', 'attenuation']
senticnet['downgrade'] = [-0.375, 0.11, -0.218, -0.068, '#sad', '#scared', -0.184, 'military_retreat', 'retreat', 'lose_battle', 'lose_war', 'retrocede']
senticnet['downhearted'] = [-0.784, 0.266, -0.45, -0.052, '#sad', '#scared', -0.34, 'low-spirited', 'depressed', 'down_in_mouth', 'dispirited', 'downcast']
senticnet['downheartedness'] = [-0.752, 0.288, -0.434, -0.058, '#sad', '#scared', -0.319, 'dejectedness', 'dispiritedness', 'low-spiritedness', 'lowness', 'cheerless']
senticnet['downhill_ski'] = [0, -0.074, 0, 0, '#surprising', '#surprising', 0.025, 'door', 'gate', 'doorway', 'glass_front', 'use_farm']
senticnet['downright'] = [0, 0, -0.915, -0.718, '#scared', '#disgusting', -0.544, 'absolute', 'out-and-out', 'rank', 'right-down', 'sheer']
senticnet['downrightness'] = [0.772, -0.953, 0, 0.89, '#surprising', '#admirable', 0.872, 'directness', 'straightforwardness', 'characteristic', 'immediacy', 'immediateness']
senticnet['downsize'] = [0.887, -0.737, 0, 0.603, '#joyful', '#surprising', 0.742, 'inflate', 'thin', 'trim_back', 'subtract', 'knock_off']
senticnet['downsizing'] = [0.953, -0.65, 0, 0.866, '#joyful', '#admirable', 0.823, 'economy_of_scale', 'retrenchment', 'curtailment', 'saving', 'action']
senticnet['downstairs'] = [0, 0, 0, -0.07, '#disgusting', '#disgusting', -0.023, 'motel_room', 'appliance_store', 'apartment', 'shack', 'neighbor_house']
senticnet['downtown'] = [0.043, 0.14, 0.01, 0.245, '#interesting', '#admirable', 0.139, 'in_between', 'middle', 'in_middle', 'center', 'placement']
senticnet['downtrodden'] = [-0.834, 0.214, -0.391, -0.108, '#sad', '#scared', -0.373, 'oppressiveness', 'tyrannical', 'oppressive', 'tyrannous', 'laden']
senticnet['downward'] = [-0.752, 0.288, -0.434, -0.058, '#sad', '#scared', -0.319, 'decline', 'height', 'gravity', 'slant', 'steep']
senticnet['dowry'] = [0.029, 0.23, -0.105, 0.196, '#interesting', '#admirable', 0.117, 'reward', 'bribe', 'welfare', 'remittance', 'owe']
senticnet['dowse'] = [-0.809, 0, 0.962, -0.553, '#sad', '#angry', -0.775, 'sop', 'douse', 'bedraggle', 'drench', 'soak']
senticnet['doze'] = [0.051, 0.074, -0.05, 0.084, '#interesting', '#admirable', 0.053, 'rest_night', 'lie_down', 'shut_eye', 'lay_down', 'count_sheep']
senticnet['doze_off'] = [-0.806, 0, 0, -0.864, '#sad', '#disgusting', -0.557, 'fall_asleep', 'bed_time', 'become_bored', 'drowsiness', 'turn_off_television']
senticnet['dozen'] = [0, -0.003, 0.063, -0.037, '#angry', '#disgusting', -0.032, 'thirty', 'hundred_year', 'twelve', 'day_month', 'time_measurement']
senticnet['drab'] = [0, 0, 0, -0.729, '#disgusting', '#disgusting', -0.243, 'dreary', 'gloominess', 'darkness', 'gloomful', 'gloomily']
senticnet['draft'] = [0.051, 0.074, -0.05, 0.084, '#interesting', '#admirable', 0.053, 'sketch', 'scheme', 'compose_draft', 'draw_draft', 'draftsman']
senticnet['draftsman'] = [0.051, 0.074, -0.05, 0.084, '#interesting', '#admirable', 0.053, 'sketch', 'scheme', 'compose_draft', 'draw_draft', 'draft']
senticnet['drafty'] = [-0.617, 0, 0.732, -0.591, '#sad', '#angry', -0.647, 'leaky', 'draughty', 'porous', 'drippy', 'oozing']
senticnet['drag'] = [0, 0, 0, -0.729, '#disgusting', '#disgusting', -0.243, 'impediment', 'obstacle', 'obstruction', 'hindrance', 'annoyance']
senticnet['drag_race'] = [-0.896, 0, 0, -0.731, '#sad', '#disgusting', -0.542, 'dilemma', 'another_planet', 'death_row', 'loose_end', 'funeral_home']
senticnet['drag_up'] = [-0.978, 0, 0.692, -0.641, '#sad', '#angry', -0.77, 'name', 'bring_up', 'mention', 'advert', 'cite']
senticnet['draggle'] = [-0.849, 0, 0.827, -0.815, '#sad', '#angry', -0.83, 'sop', 'douse', 'dowse', 'drench', 'soak']
senticnet['draggled'] = [-0.717, 0, 0.839, -0.762, '#angry', '#disgusting', -0.773, 'soiled', 'befouled', 'filthy', 'nasty', 'scummy']
senticnet['dragon'] = [-0.94, 0, 0.785, 0, '#sad', '#angry', -0.575, 'hound', 'cage_animal', 'kind_animal', 'hunter', 'animal']
senticnet['drain'] = [-0.025, 0, 0, -0.062, '#sad', '#disgusting', -0.029, 'down_drain', 'septic_tank', 'water_fountain', 'sink', 'flea_market']
senticnet['drainage'] = [0.837, -0.93, 0, 0, '#joyful', '#surprising', 0.589, 'exhaust', 'unloading', 'discharge', 'waste', 'refuse']
senticnet['draining'] = [-0.829, 0, 0, -0.965, '#sad', '#disgusting', -0.598, 'debilitating', 'exhausting', 'debilitative', 'enervating', 'enfeebling']
senticnet['drama'] = [0.734, -0.604, 0, 0.612, '#joyful', '#admirable', 0.65, 'theater_of_absurd', 'playlet', 'miracle_play', 'morality_play', 'mystery_play']
senticnet['drama_critic'] = [0.811, -0.63, 0, 0.959, '#joyful', '#admirable', 0.8, 'critic', 'theater_critic', 'professional', 'art_critic', 'literary_critic']
senticnet['drape'] = [0, 0.073, 0, 0.079, '#interesting', '#admirable', 0.051, 'shutter', 'window', 'window_cover', 'hang', 'drop']
senticnet['draughty'] = [-0.617, 0, 0.732, -0.591, '#sad', '#angry', -0.647, 'drafty', 'leaky', 'porous', 'drippy', 'oozing']
senticnet['draw'] = [0, 0, 0, 0.084, '#admirable', '#admirable', 0.028, 'sketch', 'use_crayon', 'pencil_art', 'make_sketch', 'create_image']
senticnet['draw_back'] = [-0.635, 0, 0.755, -0.657, '#angry', '#disgusting', -0.682, 'retreat', 'retrograde', 'back_up', 'move', 'give_up']
senticnet['draw_bead_on'] = [0.781, -0.719, 0, 0.595, '#joyful', '#surprising', 0.698, 'take', 'direct', 'aim', 'train', 'take_aim']
senticnet['draw_blood'] = [-0.121, -0.003, 0, -0.142, '#sad', '#disgusting', -0.087, 'cause_bleed', 'laceration', 'painful_injury', 'copy_paste', 'open_wind']
senticnet['draw_blueprint'] = [-0.034, 0.196, 0, 0.139, '#interesting', '#admirable', 0.1, 'blueprint', 'plan', 'skill', 'create_form', 'outline']
senticnet['draw_diagram'] = [0, 0.983, 0, 0, '#interesting', '#interesting', 0.328, 'explain_detail', 'write_friend', 'reply_question', 'fact_right', 'receive_letter']
senticnet['draw_draft'] = [0.838, 0.923, 0, 0, '#joyful', '#interesting', 0.587, 'sketch', 'scheme', 'compose_draft', 'draft', 'draftsman']
senticnet['draw_picture'] = [0, 0.983, 0, 0, '#interesting', '#interesting', 0.328, 'art', 'draw', 'picture', 'drawer', 'explanation']
senticnet['draw_water'] = [0.047, 0.148, 0, 0.107, '#interesting', '#admirable', 0.101, 'turn_water', 'water', 'take_clothes_off', 'find_shower', 'well']
senticnet['drawer'] = [0, 0.983, 0, 0, '#interesting', '#interesting', 0.328, 'artist', 'designer', 'draftsman', 'draw', 'draw_picture']
senticnet['drawers'] = [0.069, 0.112, 0, 0.167, '#interesting', '#admirable', 0.116, 'cupboard', 'hangers', 'compartment', 'jeans', 'clothes_shelf']
senticnet['drawing'] = [0.043, 0.112, 0, 0, '#joyful', '#interesting', 0.052, 'art_object', 'collage', 'artwork', 'gallery', 'sculpture']
senticnet['drawing_card'] = [0.54, -0.64, 0, 0.566, '#surprising', '#admirable', 0.582, 'pleaser', 'bombshell', 'mortal', 'busker', 'entertainer']
senticnet['drawn'] = [-0.036, 0.086, 0, 0.19, '#interesting', '#admirable', 0.08, 'visual', 'wall_hang', 'like_paint', 'pencil_art', 'wall_decoration']
senticnet['dread'] = [0, 0, -0.799, -0.795, '#scared', '#disgusting', -0.531, 'uneasiness', 'disquiet', 'hysteria', 'fright', 'terrible']
senticnet['dreaded'] = [-0.751, 0, -0.897, 0, '#sad', '#scared', -0.549, 'dire', 'fearsome', 'direful', 'frightening', 'horrendous']
senticnet['dreadful'] = [0, 0, -0.869, 0, '#scared', '#scared', -0.29, 'fearful', 'scary', 'hysteria', 'scare_away', 'scare_off']
senticnet['dreadfully'] = [-0.983, 0, -0.702, 0, '#sad', '#scared', -0.562, 'horrifying', 'atrocious', 'horrifyingly', 'horrified', 'horribly']
senticnet['dream'] = [0.863, 0.71, 0, 0, '#joyful', '#interesting', 0.524, 'hallucinate', 'fall_out_bed', 'lucid_dream', 'asleep', 'rest_dream']
senticnet['dream_job'] = [0.263, 0, 0.047, 0.193, '#joyful', '#admirable', 0.136, 'know_everything', 'control_weather', 'sleep_master_bedroom', 'live_ocean', 'travel_fast_light']
senticnet['dream_victory'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'expectation', 'optimism', 'win_game', 'hope_win', 'wish_success']
senticnet['dream_with_eyes_open'] = [0.921, 0.713, 0, 0, '#joyful', '#interesting', 0.545, 'excrete', 'die_only_once', 'form_sentence', 'desire_live', 'eat_animal']
senticnet['dreamer'] = [-0.644, 0, 0.524, -0.598, '#sad', '#disgusting', -0.589, 'bum', 'daydreamer', 'stargazer', 'escapist', 'wishful_thinker']
senticnet['dreaminess'] = [0.636, 0.638, -0.249, 0.305, '#joyful', '#interesting', 0.443, 'allay', 'relieve', 'easiness', 'peaceable', 'ataraxis']
senticnet['dreaming'] = [0.846, -0.928, 0, 0.504, '#joyful', '#surprising', 0.759, 'woolgathering', 'revery', 'daydream', 'reverie', 'daydreaming']
senticnet['dreamless'] = [-0.591, 0, 0.799, -0.698, '#angry', '#disgusting', -0.696, 'untroubled', 'undisturbed', 'unmolested', 'unworried', 'unconcerned']
senticnet['dreamy'] = [0.509, 0.65, -0.251, 0.255, '#joyful', '#interesting', 0.388, 'languorous', 'languid', 'lackadaisical', 'languor', 'languorously']
senticnet['drear'] = [-0.798, 0.257, -0.471, -0.036, '#sad', '#scared', -0.349, 'gloomful', 'glooming', 'darkness', 'somberness', 'gloominess']
senticnet['dreary'] = [-0.882, 0, 0, -0.758, '#sad', '#disgusting', -0.547, 'drab', 'grim', 'glooming', 'gloomily', 'gloominess']
senticnet['dredge_up'] = [-0.768, 0, 0.736, -0.706, '#sad', '#angry', -0.737, 'name', 'bring_up', 'mention', 'advert', 'cite']
senticnet['dreg'] = [-0.63, 0, 0.791, -0.681, '#angry', '#disgusting', -0.701, 'little', 'pinch', 'modicum', 'small_indefinite_amount', 'indefinite_quantity']
senticnet['drench'] = [-0.809, 0, 0.962, -0.553, '#sad', '#angry', -0.775, 'sop', 'douse', 'dowse', 'bedraggle', 'soak']
senticnet['dress'] = [-0.531, 0, 0.569, -0.776, '#angry', '#disgusting', -0.625, 'pinafore', 'pinny', 'dirndl', 'gown', 'muumuu']
senticnet['dress_appropriately'] = [-0.032, -0.056, 0.099, -0.059, '#angry', '#disgusting', -0.045, 'dress_occasion', 'leave_house', 'dress_up', 'go_outdoors', 'put_walking_shoes']
senticnet['dress_doll'] = [-0.139, 0, 0, -0.084, '#sad', '#disgusting', -0.074, 'gather_flower', 'follow_mother', 'wear_dress', 'bicycle_school', 'roll_ball']
senticnet['dress_down'] = [-0.725, 0, 0.56, -0.89, '#sad', '#disgusting', -0.725, 'castigate', 'tell_off', 'brush_down', 'chasten', 'objurgate']
senticnet['dress_nice'] = [0.028, -0.015, 0, 0.087, '#joyful', '#admirable', 0.043, 'improve_image', 'look_better', 'get_latest_hairstyle', 'change_appearance', 'groom']
senticnet['dress_nicely'] = [0.577, -0.502, 0, 0.901, '#joyful', '#admirable', 0.66, 'show_ticket', 'dating', 'dinner', 'find_place_to_sit', 'restaurant']
senticnet['dress_occasion'] = [-0.041, -0.039, 0.05, -0.064, '#angry', '#disgusting', -0.039, 'put_clothes', 'lock_front_door', 'dress_appropriately', 'dress_up', 'try_new_clothes']
senticnet['dress_oneself'] = [-0.117, 0, 0, -0.043, '#sad', '#disgusting', -0.053, 'dress', 'fill_bottle', 'shoulder_responsibility', 'speak_english', 'drink_espresso']
senticnet['dress_room'] = [0.811, -0.975, 0, 0, '#joyful', '#surprising', 0.595, 'try_clothes', 'fitting_room', 'changing_room', 'jeans', 'clothes_shelf']
senticnet['dress_success'] = [0, 0.093, 0, 0.07, '#interesting', '#admirable', 0.054, 'listen_advice', 'become_better_person', 'build_strength', 'new_experience', 'sign_up']
senticnet['dress_uniform'] = [-0.765, 0, 0, -0.889, '#sad', '#disgusting', -0.551, 'uniform', 'battle_dress', 'military_uniform', 'fatigues', 'khakis']
senticnet['dress_up'] = [0, 0.093, 0, 0.07, '#interesting', '#admirable', 0.054, 'occasion_dress', 'dress', 'dress_appropriately', 'go_outdoors', 'doll_up']
senticnet['dressing'] = [0.87, -0.856, 0, 0.94, '#joyful', '#admirable', 0.889, 'mincemeat', 'stuffing', 'concoction', 'roux', 'batter']
senticnet['dressing_down'] = [-0.91, 0, 0.677, -0.7, '#sad', '#disgusting', -0.762, 'reprimand', 'rebuke', 'reproof', 'reproval', 'reprehension']
senticnet['dribble'] = [0, 0.093, 0, 0.07, '#interesting', '#admirable', 0.054, 'play_football', 'football', 'play_team', 'play_game', 'play']
senticnet['drifter'] = [-0.943, 0, 0.839, -0.539, '#sad', '#angry', -0.774, 'hobo', 'tramp', 'beachcomber', 'bum', 'sundowner']
senticnet['driftwood'] = [0, 0, 0.021, -0.053, '#angry', '#disgusting', -0.025, 'dead_fish', 'tidal_wave', 'seashell', 'titanic', 'jelly_fish']
senticnet['drill'] = [0.884, -0.772, 0, 0, '#joyful', '#surprising', 0.552, 'power_drill', 'drill_bite', 'air_pump', 'adjustable_wrench', 'screwdriver']
senticnet['drill_bite'] = [-0.852, 0, 0, -0.953, '#sad', '#disgusting', -0.602, 'air_pump', 'chisel', 'power_drill', 'adjustable_wrench', 'screwdriver']
senticnet['drill_hole'] = [-0.069, 0, 0, 0, '#sad', '#sad', -0.023, 'throw_party', 'screwdriver', 'start_business', 'take_over_world', 'find_build']
senticnet['drink'] = [0.032, -0.022, -0.045, -0.087, '#scared', '#disgusting', -0.026, 'liquid', 'sparkling_water', 'sweet', 'soda', 'carbonate_drink']
senticnet['drink_a_lot_of_alcohol'] = [0, 0, -0.933, -0.748, '#scared', '#disgusting', -0.56, 'make_potato', 'drink_a_lot_of_booze', 'get_drunk', 'drink_much', 'drunk']
senticnet['drink_a_lot_of_beer'] = [0.967, 0.871, 0, 0, '#joyful', '#interesting', 0.613, 'go_bar', 'celebrate', 'designate_driver', 'go_party', 'drink_alcohol']
senticnet['drink_a_lot_of_booze'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'open_bottle', 'drink_excess', 'consume_alcohol', 'drink_a_lot_of_alcohol', 'buy_alcohol']
senticnet['drink_a_lot_of_water'] = [-0.035, 0.086, 0, 0.076, '#interesting', '#admirable', 0.042, 'drink_water', 'stamina', 'eat_properly', 'limber_up', 'yoga']
senticnet['drink_alcohol'] = [0.081, -0.058, 0, -0.032, '#joyful', '#surprising', 0.036, 'meet_woman', 'consume_alcoholic_beverage', 'drink_much', 'go_party', 'drink_liquor']
senticnet['drink_and_drive'] = [-0.924, 0, 0.448, -0.91, '#sad', '#disgusting', -0.761, 'accident', 'illegal', 'death', 'unsafe', 'commit_suicide']
senticnet['drink_beer'] = [0, 0, 0.827, -0.885, '#angry', '#disgusting', -0.571, 'drunk', 'become_drunk', 'intoxication', 'get_wasted', 'drunkenness']
senticnet['drink_beverage'] = [0.081, -0.058, 0, -0.032, '#joyful', '#surprising', 0.036, 'cut_food', 'drink_beer', 'serve_drink', 'drink_much', 'pry_open']
senticnet['drink_blood'] = [-0.232, 0, -0.144, -0.116, '#sad', '#scared', -0.164, 'bite_dog', 'maim', 'pull_trigger', 'feel_remorse', 'stab']
senticnet['drink_booze'] = [-0.043, 0, -0.097, -0.124, '#scared', '#disgusting', -0.088, 'drunkenness', 'become_drunk', 'drunk', 'act_stupid', 'intoxication']
senticnet['drink_cocktail'] = [0.074, 0, 0, 0, '#joyful', '#joyful', 0.025, 'alcoholic_drink', 'alcoholic_beverage', 'adult_drink', 'strong_drink', 'ferment_beverage']
senticnet['drink_coffee'] = [-0.061, -0.038, 0.013, -0.159, '#sad', '#disgusting', -0.065, 'drink_cup_coffee', 'drink_tea', 'check_oneself_mirror', 'look_out_window', 'drink_soda']
senticnet['drink_coke'] = [0.906, -0.944, 0, 0, '#joyful', '#surprising', 0.617, 'laugh_out_loud', 'change_channel', 'drink_soda', 'sit_sofa', 'read_credit']
senticnet['drink_container'] = [0, 0.071, 0, 0.128, '#interesting', '#admirable', 0.066, 'drink_holder', 'recyclable', 'type_of_container', 'liquid_container', 'storage_container']
senticnet['drink_cup'] = [-0.994, 0, 0.714, 0, '#sad', '#angry', -0.569, 'drink_container', 'liquid_container', 'drink_holder', 'glass_container', 'type_of_container']
senticnet['drink_cup_coffee'] = [-0.701, 0, 0, -0.846, '#sad', '#disgusting', -0.516, 'drink_coffee', 'put_feet_up', 'cafe', 'drink_soda', 'fall_asleep']
senticnet['drink_cup_tea'] = [-0.866, 0, 0, -0.827, '#sad', '#disgusting', -0.564, 'eye_strain', 'see_ad', 'new_perspective', 'time_waste', 'change_opinion']
senticnet['drink_drive'] = [-0.921, 0, 0.833, -0.973, '#sad', '#disgusting', -0.909, 'escape_prison', 'drive_fast', 'car_accident', 'cross_red_light', 'break_rule']
senticnet['drink_espresso'] = [-0.114, 0, -0.057, 0, '#sad', '#scared', -0.057, 'deal_card_player', 'speak_english', 'wind_watch', 'forward_email', 'explain_everything']
senticnet['drink_excess'] = [0, 0, 0.827, -0.885, '#angry', '#disgusting', -0.571, 'drink_a_lot_of_booze', 'open_bottle', 'consume_alcohol', 'drink_a_lot_of_alcohol', 'drunk']
senticnet['drink_fluid'] = [0.108, 0.145, -0.091, 0, '#joyful', '#interesting', 0.054, 'drink_wine', 'choke_food', 'serve_coffee', 'drink_tea', 'serve_drink']
senticnet['drink_glass'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'quench_thirst', 'appear_beautiful', 'forward_email', 'mind_store', 'speak_english']
senticnet['drink_holder'] = [0.958, 0.934, 0, 0, '#joyful', '#interesting', 0.631, 'drink_container', 'liquid_container', 'drink_cup', 'glass_container', 'type_of_container']
senticnet['drink_hot_chocolate'] = [0.903, 0.753, 0, 0, '#joyful', '#interesting', 0.552, 'drink_water', 'drink_espresso', 'drink', 'drink_coffee', 'drink_milk']
senticnet['drink_juice'] = [-0.081, 0, 0, -0.045, '#sad', '#disgusting', -0.042, 'serve_beer', 'raise_hell', 'chill_drink', 'pay_tab', 'drink_much_beer']
senticnet['drink_liquid'] = [0, 0.091, -0.06, 0.114, '#interesting', '#admirable', 0.048, 'chill_drink', 'put_liquid', 'hold_coffee', 'serve_beer', 'quench_thirst']
senticnet['drink_liquor'] = [0.081, -0.058, 0, -0.032, '#joyful', '#surprising', 0.036, 'drink_alcohol', 'consume_alcoholic_beverage', 'drink_much', 'hit_bottle', 'meet_woman']
senticnet['drink_lot'] = [-0.068, -0.004, -0.085, -0.114, '#scared', '#disgusting', -0.088, 'find_toilet', 'find_restroom', 'full_bladder', 'serve_beer', 'refreshment']
senticnet['drink_milk'] = [-0.035, 0.086, 0, 0.076, '#interesting', '#admirable', 0.042, 'drink_water', 'drink_espresso', 'drink', 'drink_coffee', 'drink_hot_chocolate']
senticnet['drink_much'] = [0.081, -0.058, 0, -0.032, '#joyful', '#surprising', 0.036, 'drink_alcohol', 'consume_alcoholic_beverage', 'meet_woman', 'hit_bottle', 'drink_liquor']
senticnet['drink_much_alcohol'] = [-0.779, 0, 0, -0.957, '#sad', '#disgusting', -0.579, 'drunk', 'drink_much', 'make_potato', 'drink_a_lot_of_alcohol', 'act_stupid']
senticnet['drink_much_beer'] = [-0.063, 0, 0, -0.035, '#sad', '#disgusting', -0.033, 'eat_salad', 'burp', 'go_restroom', 'serve_beer', 'spill_food_clothes']
senticnet['drink_orange_juice'] = [-0.791, 0, 0, -0.734, '#sad', '#disgusting', -0.508, 'spill_milk', 'read_paper', 'drop_food', 'smell_food', 'choke']
senticnet['drink_plenty_water'] = [-0.028, 0, 0.052, 0, '#sad', '#angry', -0.027, 'exercise', 'exercise_regularly', 'physical_exercise', 'moderation', 'antioxidant']
senticnet['drink_poison'] = [0, 0, -0.721, -0.946, '#scared', '#disgusting', -0.556, 'cripple', 'influenza', 'anger', 'overpay', 'meanness']
senticnet['drink_sea_water'] = [0, 0, 0, -0.764, '#disgusting', '#disgusting', -0.255, 'travel_fast_light', 'live_ocean', 'unhealthy', 'like_play', 'eat_dog']
senticnet['drink_soda'] = [-0.941, 0, 0, -0.826, '#sad', '#disgusting', -0.589, 'become_bored', 'turn_off', 'drink', 'get_bored', 'use_electricity']
senticnet['drink_soup'] = [0.097, 0, 0, 0, '#joyful', '#joyful', 0.032, 'serve_liquid', 'eat_liquid', 'swallow', 'consume_food', 'fill_up']
senticnet['drink_tea'] = [-0.069, 0, 0, -0.042, '#sad', '#disgusting', -0.037, 'choke_food', 'spill_food_clothes', 'wind_watch', 'talk_other', 'eat_salad']
senticnet['drink_too_much'] = [-0.852, 0, -0.788, 0, '#sad', '#scared', -0.547, 'faint', 'blood_pressure', 'feel_sick', 'low_blood_pressure', 'fear']
senticnet['drink_water'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'drink_lot', 'drink_beer', 'refreshment', 'healthy', 'wipe_mouth_napkin']
senticnet['drink_wine'] = [0.108, 0.145, -0.091, 0, '#joyful', '#interesting', 0.054, 'steak', 'dinner', 'special_occasion', 'decanter', 'wine_opener']
senticnet['drinkable'] = [0.937, 0, 0, 0, '#joyful', '#joyful', 0.312, 'serve_hot', 'tasty', 'liquid_food', 'hearty', 'porridge']
senticnet['drinking'] = [0.987, -0.744, 0, 0.695, '#joyful', '#surprising', 0.809, 'vice', 'drink', 'intemperateness', 'boozing', 'drunkenness']
senticnet['drinking_place'] = [-0.89, 0, 0.811, 0, '#sad', '#angry', -0.567, 'metal_stick', 'tavern', 'place_to_drink', 'water_hole', 'long_tube']
senticnet['drinking_water'] = [0.728, -0.517, 0, 0.811, '#joyful', '#admirable', 0.685, 'beverage', 'drinkable', 'potable', 'bottled_water', 'sugar_water']
senticnet['drip'] = [0.781, -0.965, 0, 0, '#joyful', '#surprising', 0.582, 'fallen', 'water_drip', 'falling_water', 'feel_cold', 'rain_water']
senticnet['drippy'] = [-0.617, 0, 0.732, -0.591, '#sad', '#angry', -0.647, 'drafty', 'draughty', 'porous', 'leaky', 'oozing']
senticnet['drive'] = [0.825, 0, 0, 0.703, '#joyful', '#admirable', 0.509, 'pay_toll', 'get_fast', 'access', 'fast_travel', 'access_quickly']
senticnet['drive-in_movie'] = [-0.032, -0.012, -0.11, -0.031, '#sad', '#scared', -0.054, 'movie_theater', 'theater', 'cinema', 'movie', 'cctv']
senticnet['drive_around'] = [-0.943, 0, -0.879, 0, '#sad', '#scared', -0.607, 'drive_destination', 'find_direction', 'travel_by_airplane', 'near_destination', 'board_boat']
senticnet['drive_away'] = [0.693, -0.544, 0, 0.814, '#joyful', '#admirable', 0.684, 'move', 'displace', 'clear_air', 'fire', 'banish']
senticnet['drive_car'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'out_car', 'avoid_fall', 'move_car', 'take_car_drive', 'go_drive']
senticnet['drive_crazy'] = [-0.087, -0.018, 0, -0.077, '#sad', '#disgusting', -0.049, 'laugh_clown', 'throw_fit', 'watch_d', 'sun_oneself', 'roll_ball']
senticnet['drive_destination'] = [0, 0.86, 0, 0, '#interesting', '#interesting', 0.287, 'travel_by_airplane', 'board_boat', 'discover_new_place', 'near_destination', 'sleep_late']
senticnet['drive_down_street'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'appear_suddenly', 'gain_speed', 'travel_road', 'corner_well', 'get_accident']
senticnet['drive_fast'] = [-0.036, -0.023, -0.066, -0.044, '#scared', '#disgusting', -0.041, 'travel_fast', 'drive_quickly', 'get_fast', 'travel_car', 'pay_toll']
senticnet['drive_highway'] = [-0.084, 0.092, -0.073, 0.15, '#interesting', '#admirable', 0.028, 'leave_place', 'push_limit', 'steer_car', 'turn_leave', 'break_down']
senticnet['drive_home'] = [0, 0.169, -0.066, 0.077, '#interesting', '#admirable', 0.06, 'buy_condom', 'wear_protection', 'wrap_present', 'spend_much_money', 'use_credit_card']
senticnet['drive_license'] = [0.099, 0, 0, 0.168, '#joyful', '#admirable', 0.089, 'find_car_key', 'start_car_engine', 'know_how_drive', 'good_vision', 'license']
senticnet['drive_off'] = [0.509, -0.642, 0, 0.942, '#surprising', '#admirable', 0.698, 'move', 'displace', 'clear_air', 'fire', 'banish']
senticnet['drive_out'] = [0.576, -0.863, 0, 0.531, '#joyful', '#surprising', 0.657, 'move', 'displace', 'clear_air', 'fire', 'banish']
senticnet['drive_quickly'] = [0.946, 0, 0, 0.77, '#joyful', '#admirable', 0.572, 'shade', 'aviator', 'drive', 'drive_somewhere', 'fast_travel']
senticnet['drive_recklessly'] = [0, 0, -0.807, -0.882, '#scared', '#disgusting', -0.563, 'future_robot', 'type_of_dog', 'dog', 'dangerous', 'drive']
senticnet['drive_safe'] = [0.822, 0.86, 0, 0.751, '#joyful', '#interesting', 0.811, 'prevent_accident', 'take_nap', 'go_slow', 'feel_little_tired', 'rest_dream']
senticnet['drive_safely'] = [0.822, 0.86, 0, 0.751, '#joyful', '#interesting', 0.811, 'keep_safe', 'avoid_accident', 'avoid_problem', 'just_in_time', 'good_break']
senticnet['drive_somewhere'] = [0.946, 0, 0, 0.77, '#joyful', '#admirable', 0.572, 'shade', 'drive_quickly', 'drive', 'aviator', 'fast_travel']
senticnet['drive_theater'] = [-0.068, 0, 0, -0.051, '#sad', '#disgusting', -0.04, 'find_out_play', 'go_cinema', 'go_to_theater', 'go_movie_theater', 'buy_ticket']
senticnet['drive_to_store'] = [-0.033, 0, 0.042, 0, '#sad', '#angry', -0.025, 'go_department_store', 'go_to_shopping_mall', 'find_merchant', 'charge_card', 'go_shopping']
senticnet['drive_to_work'] = [-0.047, -0.014, 0, -0.062, '#sad', '#disgusting', -0.032, 'commute', 'transportation', 'go_to_work', 'drive', 'drive_car']
senticnet['drive_train'] = [0.046, 0.087, 0, 0.153, '#interesting', '#admirable', 0.095, 'quit_work', 'finish_work', 'work_home', 'accomplish', 'move_furniture']
senticnet['drive_upon'] = [0, -0.008, 0, 0.088, '#surprising', '#admirable', 0.032, 'fast_travel', 'pay_toll', 'travel_car', 'divide_property', 'drive_quickly']
senticnet['drive_vehicle'] = [0.026, -0.036, 0, 0.091, '#surprising', '#admirable', 0.051, 'drive_fast', 'travel_car', 'divide_property', 'turn_leave', 'drive_quickly']
senticnet['drivel'] = [0.739, -0.899, 0, 0.702, '#joyful', '#surprising', 0.78, 'pap', 'content', 'pablum', 'folderol', 'codswallop']
senticnet['driven'] = [-0.072, 0.109, 0, 0.095, '#interesting', '#admirable', 0.044, 'car_path', 'drive', 'pave', 'pathway', 'controled']
senticnet['driven_person'] = [0, 0.072, 0.045, 0.125, '#interesting', '#admirable', 0.051, 'large_breadbox', 'hairy', 'cute', 'nocturnal', 'huge_animal']
senticnet['driver'] = [0, 0.352, -0.234, 0.307, '#interesting', '#admirable', 0.142, 'operator', 'specialist', 'employee', 'agent', 'surgeon']
senticnet['driver_licence'] = [0.673, -0.664, 0, 0.921, '#joyful', '#admirable', 0.753, 'instrument', 'building_permit', 'driver_license', 'license', 'driving_license']
senticnet['driver_license'] = [0.673, -0.664, 0, 0.921, '#joyful', '#admirable', 0.753, 'instrument', 'building_permit', 'license', 'driver_licence', 'driving_license']
senticnet['driving'] = [-0.1, 0, -0.11, 0, '#sad', '#scared', -0.07, 'change_tire', 'fix_flat_tire', 'lie_floor', 'workshop', 'car']
senticnet['driving_license'] = [0.673, -0.664, 0, 0.921, '#joyful', '#admirable', 0.753, 'instrument', 'building_permit', 'driver_license', 'driver_licence', 'license']
senticnet['drizzle'] = [0.085, -0.063, 0, 0, '#joyful', '#surprising', 0.049, 'soap', 'foam', 'bubbly', 'solid_water', 'ivory']
senticnet['drone'] = [-0.648, 0, 0.879, -0.98, '#angry', '#disgusting', -0.836, 'straggler', 'poke', 'dawdler', 'laggard', 'lagger']
senticnet['drool'] = [-0.037, -0.037, -0.059, -0.145, '#scared', '#disgusting', -0.068, 'wet_oneself', 'start_laugh', 'vomit', 'say_excuse', 'pee_pants']
senticnet['drooping'] = [-0.783, 0, 0.95, -0.731, '#sad', '#angry', -0.821, 'unerect', 'crooked', 'weeping', 'prone', 'supine']
senticnet['drop'] = [0.985, -0.901, 0, 0, '#joyful', '#surprising', 0.629, 'tumble', 'dew', 'hailstone', 'rain', 'snowflake']
senticnet['drop_airplane'] = [-0.074, -0.063, 0, -0.181, '#sad', '#disgusting', -0.064, 'kill_enemy', 'sink_ship', 'protect_country', 'make_war', 'settle_disagreement']
senticnet['drop_arch'] = [0.641, -0.569, 0, 0.748, '#joyful', '#admirable', 0.653, 'trefoil_arch', 'ogee_arch', 'keel_arch', 'pointed_arch', 'arch']
senticnet['drop_away'] = [-0.743, 0, 0.749, -0.828, '#angry', '#disgusting', -0.773, 'inflame', 'worsen', 'lose', 'fall_away', 'deteriorate']
senticnet['drop_ball'] = [-0.646, 0, 0.913, -0.863, '#angry', '#disgusting', -0.807, 'offend', 'violate', 'go_against', 'break', 'lose_game']
senticnet['drop_blood'] = [-0.053, 0, -0.153, -0.122, '#scared', '#disgusting', -0.109, 'donor', 'blood', 'disease', 'contagious_disease', 'sick']
senticnet['drop_bomb'] = [-0.062, -0.029, 0.034, -0.115, '#sad', '#disgusting', -0.061, 'land_plane', 'fly_helicopter', 'glide', 'bus_person', 'journey_far']
senticnet['drop_down'] = [-0.085, 0, 0, 0, '#sad', '#sad', -0.028, 'fallen', 'stumble', 'tumble', 'before_fall', 'go_down']
senticnet['drop_food'] = [-0.075, -0.011, -0.061, -0.138, '#sad', '#disgusting', -0.088, 'spill_food_clothes', 'acid_indigestion', 'eat_salad', 'drink_much_beer', 'hunger_go_away']
senticnet['drop_off'] = [-0.026, 0.141, -0.093, 0.22, '#interesting', '#admirable', 0.081, 'take', 'distribute', 'pull_car', 'tote', 'bring']
senticnet['droplet'] = [0.095, 0, -0.045, 0.062, '#joyful', '#admirable', 0.037, 'liquid_water', 'water_spray', 'moisture', 'rise_water', 'photographer']
senticnet['dropper'] = [-0.06, -0.006, 0, -0.051, '#sad', '#disgusting', -0.035, 'find_out_truth', 'zoology', 'fall', 'prove_theory', 'discovery']
senticnet['droppings'] = [-0.838, 0, 0.521, -0.713, '#sad', '#disgusting', -0.691, 'stool', 'dejection', 'chip', 'cow_chip', 'cow_dung']
senticnet['dropsy'] = [-0.998, 0, 0.605, -0.764, '#sad', '#disgusting', -0.789, 'angioedema', 'atrophedema', 'giant_hives', 'periodic_edema', 'lymphedema']
senticnet['dross'] = [0.526, -0.78, 0, 0.869, '#surprising', '#admirable', 0.725, 'impurity', 'waste_material', 'exhaust', 'garbage', 'material']
senticnet['drought'] = [-0.985, 0, -0.796, 0, '#sad', '#scared', -0.594, 'no_rain', 'lose_team', 'leave_out', 'disrespect', 'cause_suffer']
senticnet['drown'] = [-0.799, 0, 0, -0.954, '#sad', '#disgusting', -0.584, 'water_ear', 'wet_hair', 'get_killed', 'get_wet', 'slip_fall']
senticnet['drowsiness'] = [0.951, -0.947, 0, 0, '#joyful', '#surprising', 0.633, 'fall_asleep', 'sleepy', 'bed_time', 'drink_cup_tea', 'listen_classical_music']
senticnet['drub'] = [0.893, -0.564, 0, 0.537, '#joyful', '#surprising', 0.665, 'vanquish', 'beat', 'beat_out', 'trounce', 'crush']
senticnet['drudgery'] = [-0.302, 0.089, -0.106, -0.032, '#sad', '#scared', -0.117, 'hardship', 'office_job', 'work_much', 'day_job', 'toil']
senticnet['drug'] = [0, 0, 0.868, -0.89, '#angry', '#disgusting', -0.586, 'analgesic', 'phenobarbital', 'trip_acid', 'ibuprofen', 'codeine']
senticnet['drug_abuse'] = [-0.514, 0, 0.97, -0.626, '#angry', '#disgusting', -0.703, 'abuse', 'misuse', 'alcohol_abuse', 'alcoholic_abuse', 'alcoholism_abuse']
senticnet['drug_addict'] = [0, 0, 0.821, -0.954, '#angry', '#disgusting', -0.592, 'student', 'serious_student', 'addiction', 'graduate_student', 'hard_worker']
senticnet['drug_addicted'] = [-0.921, 0, 0.833, -0.973, '#sad', '#disgusting', -0.909, 'ambulance', 'prosthesis', 'old_lady', 'junkie', 'elderly_person']
senticnet['drug_addiction'] = [-0.093, -0.067, -0.102, -0.176, '#scared', '#disgusting', -0.101, 'eat_poison', 'execute', 'apnea', 'drunk_drive', 'old_age']
senticnet['drug_dealer'] = [-0.914, 0, 0.129, -0.968, '#sad', '#disgusting', -0.67, 'drug', 'drug_peddler', 'drug_trafficker', 'break_law', 'harmful']
senticnet['drug_peddler'] = [-0.914, 0, 0.129, -0.968, '#sad', '#disgusting', -0.67, 'drug', 'drug_dealer', 'drug_trafficker', 'break_law', 'harmful']
senticnet['drug_trafficker'] = [-0.914, 0, 0.129, -0.968, '#sad', '#disgusting', -0.67, 'drug', 'drug_peddler', 'drug_dealer', 'break_law', 'harmful']
senticnet['drug_use'] = [-0.834, 0.214, -0.391, -0.108, '#sad', '#scared', -0.373, 'use_drug', 'ecstasy_pill', 'do_drug', 'drug', 'addiction']
senticnet['druggist'] = [0.654, -0.579, 0, 0.685, '#joyful', '#admirable', 0.639, 'pharmacologist', 'pharmaceutical_chemist', 'health_professional', 'primary_care_provider', 'health_care_provider']
senticnet['druggy'] = [0, 0, 0, -0.875, '#disgusting', '#disgusting', -0.292, 'convict_crime', 'steal', 'hurt_else', 'get_away_crime', 'obstruct_justice']
senticnet['drugstore'] = [0.959, 0.96, 0, 0, '#joyful', '#interesting', 0.64, 'pharmacy', 'walmart', 'bathroom_cabinet', 'shop', 'medicine_cabinet']
senticnet['drum_set'] = [0.946, 0, 0, 0.77, '#joyful', '#admirable', 0.572, 'high_school_band', 'kit', 'string_quartet', 'music_shop', 'battery']
senticnet['drumhead'] = [-0.904, 0, 0.569, -0.967, '#sad', '#disgusting', -0.813, 'unauthorized', 'wildcat', 'informal', 'loose', 'unofficial']
senticnet['drummer'] = [0, -0.027, 0.055, -0.057, '#angry', '#disgusting', -0.028, 'djembe', 'make_musicr', 'use_jazz_music', 'tune_instrument', 'percussion']
senticnet['drunk'] = [0, 0, -0.933, -0.748, '#scared', '#disgusting', -0.56, 'make_potato', 'drink_a_lot_of_booze', 'get_drunk', 'drink_much', 'drink_a_lot_of_alcohol']
senticnet['drunk_drive'] = [-0.963, 0, 0, -0.788, '#sad', '#disgusting', -0.584, 'cut_oneself', 'eat_poison', 'terrorism', 'commit_suicide', 'kill_man']
senticnet['drunk_person'] = [0.141, -0.064, 0, -0.03, '#joyful', '#surprising', 0.058, 'drunkard', 'alcohol', 'booze', 'whisky', 'alcoholic_beverage']
senticnet['drunkard'] = [0, 0, 0.733, -0.91, '#angry', '#disgusting', -0.548, 'drunk_person', 'bartender', 'whisky', 'alcohol', 'guinness']
senticnet['drunkenness'] = [0, 0, 0.827, -0.885, '#angry', '#disgusting', -0.571, 'drunk', 'become_drunk', 'intoxication', 'get_wasted', 'drink_beer']
senticnet['dry'] = [0, -0.048, 0, 0.053, '#surprising', '#admirable', 0.034, 'coat_surface', 'dune', 'desert', 'no_water', 'dry_paint']
senticnet['dry_cereal'] = [-0.78, 0, 0.684, -0.551, '#sad', '#angry', -0.672, 'puffed_rice', 'granola', 'raisin_bran', 'corn_flake', 'bran_flake']
senticnet['dry_clean'] = [0.702, 0, 0, 0.962, '#joyful', '#admirable', 0.555, 'soft_fabric', 'fabric_type', 'clothes_fabric', 'cloth_material', 'cloth_fabric']
senticnet['dry_cleaner'] = [0, 0.081, 0, 0.134, '#interesting', '#admirable', 0.072, 'washing_machine', 'clean', 'dry', 'clothes', 'piece_of_clothing']
senticnet['dry_clothes'] = [-0.069, 0, 0, 0, '#sad', '#sad', -0.023, 'wash_window', 'sweep_floor', 'wash_dog', 'mop_floor', 'bind_book']
senticnet['dry_fruit'] = [0.911, 0.894, 0, 0, '#joyful', '#interesting', 0.602, 'coupon', 'box_cereal', 'carton_milk', 'bottle_water', 'pasta']
senticnet['dry_gangrene'] = [-0.682, 0, 0.916, -0.912, '#angry', '#disgusting', -0.837, 'slough', 'cold_gangrene', 'mumification_necrosis', 'mummification', 'pathology']
senticnet['dry_hair'] = [-0.083, 0, -0.05, 0, '#sad', '#scared', -0.044, 'absorb_moisture', 'sit_on_beach', 'shine_shoes', 'bind_book', 'dry_paint']
senticnet['dry_land'] = [-0.682, 0, 0.916, -0.912, '#angry', '#disgusting', -0.837, 'land', 'wonderland', 'earth', 'ground', 'solid_ground']
senticnet['dry_mouth'] = [-0.079, -0.051, 0.095, -0.181, '#angry', '#disgusting', -0.101, 'misunderstanding', 'move_tongue', 'persuade', 'look_eye', 'exchange_idea']
senticnet['dry_off'] = [0, 0.078, 0, 0.065, '#interesting', '#admirable', 0.048, 'towel_off', 'dry_oneself', 'hang_up_towel', 'make_bow', 'dry_off_towel']
senticnet['dry_off_towel'] = [0, 0.078, 0, 0.065, '#interesting', '#admirable', 0.048, 'towel_off', 'dry_oneself', 'hang_up_towel', 'make_bow', 'dry_off']
senticnet['dry_oneself'] = [0, 0.123, 0, 0.116, '#interesting', '#admirable', 0.08, 'dry_off', 'hang_up_towel', 'towel_off', 'masturbate', 'fuck']
senticnet['dry_oneself_off'] = [-0.063, 0.073, 0, 0.074, '#interesting', '#admirable', 0.028, 'pour_water', 'buy_wash_powder', 'remove_clothes', 'take_clothes_off', 'get_naked']
senticnet['dry_paint'] = [-0.052, 0, 0.019, 0, '#sad', '#angry', -0.024, 'dry_hair', 'remove_paint', 'bind_book', 'paint_nail', 'dry_clothes']
senticnet['dry_skin'] = [0.048, -0.006, 0.011, 0.064, '#joyful', '#admirable', 0.036, 'become_wet', 'wash_away_dirt', 'run_out_soap', 'cleanliness', 'clean_skin']
senticnet['dry_towel'] = [0.151, 0, 0, 0.055, '#joyful', '#admirable', 0.069, 'dry_off_towel', 'lock_front_door', 'try_clothes_before_buy', 'protect_body', 'put_clothes']
senticnet['dry_wall'] = [0.514, -0.979, 0, 0.899, '#surprising', '#admirable', 0.797, 'board', 'beaver_board', 'fiberboard', 'furniture', 'particle_board']
senticnet['dry_wet_clothes'] = [-0.089, 0, -0.115, -0.109, '#scared', '#disgusting', -0.104, 'warm_hand', 'make_drunk', 'warm_room', 'warm_house', 'age_skin']
senticnet['dry_wet_hair'] = [-0.068, 0, -0.059, 0, '#sad', '#scared', -0.042, 'even_odds', 'dry_hair', 'cremate', 'thrust', 'dispense']
senticnet['dryad'] = [-0.023, -0.012, 0.045, -0.051, '#angry', '#disgusting', -0.036, 'haddock', 'pier', 'ferry', 'dock', 'shallow']
senticnet['dryness'] = [-0.738, 0, 0.931, -0.821, '#angry', '#disgusting', -0.83, 'aridness', 'thirstiness', 'xerostomia', 'dry_mouth', 'sereness']
senticnet['dual'] = [0, 0, 0.713, -0.99, '#angry', '#disgusting', -0.568, 'double', 'twofold', 'treble', 'threefold', 'three-fold']
senticnet['dualism'] = [0.651, -0.576, 0, 0.592, '#joyful', '#admirable', 0.606, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['dubiety'] = [0.939, -0.868, 0, 0.618, '#joyful', '#surprising', 0.808, 'incredulity', 'mental_rejection', 'skepticism', 'mistrust', 'distrust']
senticnet['dubiousness'] = [0.536, -0.713, 0, 0.533, '#joyful', '#surprising', 0.594, 'incredulity', 'mental_rejection', 'skepticism', 'mistrust', 'distrust']
senticnet['duchess'] = [0.057, 0.096, 0, 0.104, '#interesting', '#admirable', 0.086, 'king', 'royal_leader', 'noble', 'lord', 'despot']
senticnet['duck'] = [-0.502, 0, 0.764, -0.618, '#angry', '#disgusting', -0.628, 'doctor', 'mountebank', 'charlatan', 'quack', 'physician']
senticnet['duck_down'] = [0.814, -0.539, 0, 0.624, '#joyful', '#admirable', 0.659, 'feather', 'plume', 'down_feather', 'goose_down', 'swan_down']
senticnet['duck_sauce'] = [0.641, -0.569, 0, 0.748, '#joyful', '#admirable', 0.653, 'taco_sauce', 'chili_sauce', 'steak_sauce', 'condiment', 'hoisin_sauce']
senticnet['duck_soup'] = [0.804, -0.574, 0, 0.572, '#joyful', '#surprising', 0.65, 'labor', 'doddle', 'undertaking', 'project', 'task']
senticnet['ductile'] = [0.841, -0.576, 0, 0.891, '#joyful', '#admirable', 0.769, 'tamable', 'tameable', 'manipulable', 'malleable', 'docile']
senticnet['dud'] = [-0.816, 0, 0.849, -0.532, '#sad', '#angry', -0.732, 'equipment_failure', 'fault', 'failure', 'brake_failure', 'engine_failure']
senticnet['dude'] = [0.805, 0, 0, 0.95, '#joyful', '#admirable', 0.585, 'bloke', 'male', 'male_person', 'man_child', 'boys']
senticnet['dudgeon'] = [-0.127, 0.13, 0.647, -0.647, '#angry', '#disgusting', -0.43, 'high_dudgeon', 'infuriating', 'exasperating', 'maddening', 'infuriate']
senticnet['due'] = [0.74, 0.907, 0, 0, '#joyful', '#interesting', 0.549, 'payment', 'tax', 'expense', 'owe', 'cost']
senticnet['due_date'] = [-0.102, 0, 0, 0, '#sad', '#sad', -0.034, 'day', 'maturity', 'maturity_date', 'date', 'birthday']
senticnet['due_process'] = [-0.751, 0, 0.735, -0.872, '#sad', '#disgusting', -0.786, 'eviction', 'defense', 'plea', 'dispossession', 'proceeding']
senticnet['due_process_of_law'] = [-0.897, 0, 0.791, -0.545, '#sad', '#angry', -0.744, 'eviction', 'defense', 'plea', 'dispossession', 'proceeding']
senticnet['duel'] = [0, -0.01, -0.082, -0.162, '#scared', '#disgusting', -0.078, 'siege', 'big_fight', 'battle', 'declare_war', 'conflict']
senticnet['duffer'] = [-0.713, 0, 0.845, -0.691, '#sad', '#angry', -0.75, 'lump', 'goon', 'mortal', 'clumsy_person', 'butterfingers']
senticnet['dugout'] = [0.972, 0.944, 0, 0, '#joyful', '#interesting', 0.639, 'cave', 'subway', 'bus_stop', 'cemetery', 'train_station']
senticnet['duh'] = [0, 0.1, 0, 0.117, '#interesting', '#admirable', 0.072, 'cute', 'small_human', 'diverse', 'small_person', 'tiny_animal']
senticnet['duke'] = [0.033, 0.088, -0.061, 0.068, '#interesting', '#admirable', 0.043, 'earl', 'noble', 'king', 'sultan', 'royal_title']
senticnet['dulcet'] = [0.704, -0.502, 0, 0.923, '#joyful', '#admirable', 0.71, 'mellifluous', 'mellisonant', 'melodic', 'lyrical', 'honeyed']
senticnet['dulciana'] = [0.939, -0.717, 0, 0.775, '#joyful', '#admirable', 0.81, 'vox_angelica', 'voix_celeste', 'organ_stop', 'pipe', 'diapason']
senticnet['dulcify'] = [0.744, -0.77, 0, 0.661, '#joyful', '#surprising', 0.725, 'sugarcoat', 'honey', 'glaze', 'change_taste', 'sugar']
senticnet['dulcorate'] = [0.99, -0.829, 0, 0.691, '#joyful', '#surprising', 0.837, 'sugarcoat', 'honey', 'glaze', 'change_taste', 'sugar']
senticnet['dull'] = [0, 0, 0.781, -0.891, '#angry', '#disgusting', -0.557, 'passive', 'team_lose', 'foolish', 'fun', 'creepy']
senticnet['dullard'] = [-0.997, 0, 0.732, -0.887, '#sad', '#disgusting', -0.872, 'dunce', 'dunderhead', 'numskull', 'blockhead', 'bonehead']
senticnet['dulled'] = [-0.612, 0, 0.764, -0.97, '#angry', '#disgusting', -0.782, 'apathetic', 'benumbed', 'indifferent', 'dismissive', 'uninterested']
senticnet['dullness'] = [0, 0, 0.919, -0.746, '#angry', '#disgusting', -0.555, 'knife_sharp', 'decline', 'dart', 'unpleasantness', 'rim']
senticnet['dumb'] = [0, 0, 0.919, -0.746, '#angry', '#disgusting', -0.555, 'stupid', 'silly', 'goofy', 'mindless', 'foolish']
senticnet['dumbass'] = [-0.958, 0, 0.67, -0.633, '#sad', '#angry', -0.754, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['dumbbell'] = [0, 0.142, 0, 0.125, '#interesting', '#admirable', 0.089, 'gym_equipment', 'weight_machine', 'pulley', 'plumber', 'exercise_equipment']
senticnet['dumbfound'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'astonished', 'baffle', 'stupefy', 'surprise', 'stupefaction']
senticnet['dumbfounded'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'surprise', 'baffle', 'stupefy', 'stupefaction', 'dumfounded']
senticnet['dumbstricken'] = [-0.038, -0.546, -0.058, 0.306, '#surprising', '#admirable', 0.252, 'stun', 'stunned', 'stupefied', 'stupefy', 'dazed']
senticnet['dumbstruck'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'surprise', 'baffle', 'stupefy', 'dumbfound', 'stupefaction']
senticnet['dumfounded'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'surprise', 'baffle', 'stupefy', 'stupefaction', 'dumbfounded']
senticnet['dummy'] = [0, -0.087, 0, 0, '#surprising', '#surprising', 0.029, 'toy', 'stuff_animal', 'doll', 'mannequin', 'action_figure']
senticnet['dump'] = [0, 0, 0, -0.082, '#disgusting', '#disgusting', -0.027, 'trashcan', 'dumpster', 'trash_bin', 'incinerator', 'garbage_dump']
senticnet['dump_truck'] = [0.65, -0.634, 0, 0.629, '#joyful', '#surprising', 0.638, 'camion', 'rig', 'wrecker', 'motortruck', 'dumper']
senticnet['dumper'] = [0.65, -0.634, 0, 0.629, '#joyful', '#surprising', 0.638, 'camion', 'rig', 'wrecker', 'dump_truck', 'motortruck']
senticnet['dumpling'] = [0.711, 0, 0, 0, '#joyful', '#joyful', 0.237, 'noodles', 'chicken_rice', 'chinese_food', 'porridge', 'rice']
senticnet['dumpster'] = [0, 0, 0, -0.082, '#disgusting', '#disgusting', -0.027, 'trashcan', 'dump', 'trash_bin', 'incinerator', 'garbage_dump']
senticnet['dumpster_dive'] = [-0.055, 0.157, 0, 0.168, '#interesting', '#admirable', 0.09, 'know_want', 'make_selection', 'buy_diamond_ring', 'search_item', 'go_shopping']
senticnet['dun'] = [-0.132, 0.071, 0.694, -0.674, '#angry', '#disgusting', -0.476, 'bedevil', 'crucify', 'frustrating', 'aggravate', 'exasperation']
senticnet['dunce'] = [-0.84, 0, 0.732, -0.912, '#sad', '#disgusting', -0.828, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['dunderhead'] = [-0.92, 0, 0.566, -0.726, '#sad', '#disgusting', -0.737, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['dune'] = [0, -0.048, 0, 0.053, '#surprising', '#admirable', 0.034, 'coat_surface', 'dry', 'desert', 'no_water', 'dry_paint']
senticnet['dung'] = [-0.768, 0, 0.883, -0.597, '#sad', '#angry', -0.749, 'stool', 'dejection', 'chip', 'cow_chip', 'cow_dung']
senticnet['dunghill'] = [-0.687, 0, 0.529, -0.694, '#sad', '#disgusting', -0.637, 'nastiness', 'filth', 'filthiness', 'unsanitariness', 'sanitary_condition']
senticnet['dunk'] = [0, 0, 0.079, 0, '#angry', '#angry', -0.026, 'play_game_basketball', 'judo', 'athletics', 'football', 'hockey']
senticnet['dunker'] = [0.826, -0.655, 0, 0.587, '#joyful', '#surprising', 0.689, 'scoffer', 'vegetarian', 'devourer', 'diner', 'eater']
senticnet['dupe'] = [-0.539, 0, 0.591, -0.593, '#angry', '#disgusting', -0.574, 'mug', 'sitting_duck', 'easy_mark', 'stooge', 'mortal']
senticnet['dupery'] = [-0.86, 0, 0.675, -0.841, '#sad', '#disgusting', -0.792, 'shenanigan', 'chicanery', 'wile', 'goldbrick', 'trickery']
senticnet['duplex'] = [0, 0.106, 0, 0, '#interesting', '#interesting', 0.035, 'brownstone', 'high_rise', 'rent_apartment', 'row_house', 'twin']
senticnet['duplicability'] = [0.512, -0.52, 0, 0.874, '#surprising', '#admirable', 0.635, 'responsibleness', 'reproducibility', 'dependability', 'solidness', 'responsibility']
senticnet['duplicate'] = [0, 0.143, 0, 0.264, '#interesting', '#admirable', 0.136, 'replicate', 'imitation', 'clone', 'jot', 'make_copy']
senticnet['duplication'] = [-0.916, 0, 0.866, -0.55, '#sad', '#angry', -0.777, 'backup', 'similitude', 'copy', 'twin', 'match']
senticnet['durability'] = [0.8, -0.908, 0, 0.675, '#joyful', '#surprising', 0.794, 'indestructibility', 'tensile_strength', 'continuity', 'persistence', 'changelessness']
senticnet['durable'] = [-0.023, 0.078, 0, 0.08, '#interesting', '#admirable', 0.045, 'rigid', 'fragile', 'opaque', 'delicate', 'versatile']
senticnet['duration'] = [0.066, 0.079, 0, 0.142, '#interesting', '#admirable', 0.096, 'never_end', 'time_reference', 'metaphor', 'calendar_event', 'general_time']
senticnet['durian'] = [0, 0, 0.83, -0.939, '#angry', '#disgusting', -0.59, 'nasty', 'smelly', 'dirty_sock', 'stinky', 'bad_smell']
senticnet['dusk'] = [-0.083, 0, -0.045, 0, '#sad', '#scared', -0.043, 'get_dark', 'night_time', 'day_end', 'sundown', 'dark_outside']
senticnet['dust'] = [-0.955, 0, 0.738, -0.584, '#sad', '#angry', -0.759, 'fallout', 'chalk_dust', 'radioactive_dust', 'particulate', 'particulate_matter']
senticnet['dust_furniture'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'cleanness', 'sweep', 'clean_floor', 'vacuum_floor', 'clean']
senticnet['dust_mite'] = [0, -0.018, 0.067, -0.066, '#angry', '#disgusting', -0.038, 'cookie_crumb', 'storage_box', 'dirty_sock', 'dust', 'louse']
senticnet['dust_particle'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'small_piece', 'spangle', 'stripe', 'particle', 'oxide']
senticnet['dustbin'] = [0.991, -0.861, 0, 0, '#joyful', '#surprising', 0.617, 'trash', 'trash_container', 'trash_can', 'coffee_cup', 'trash_receptacle']
senticnet['duster'] = [-0.675, 0, 0.688, -0.899, '#angry', '#disgusting', -0.754, 'protective_garment', 'boilersuit', 'boilers_suit', 'overall', 'coverall']
senticnet['dustup'] = [-0.824, 0, 0.852, -0.749, '#sad', '#angry', -0.808, 'altercation', 'fracas', 'difference', 'affray', 'bickering']
senticnet['dusty'] = [0, 0, 0.943, -0.8, '#angry', '#disgusting', -0.581, 'feel_dirty', 'unclean', 'dirty', 'yucky', 'filthy']
senticnet['dutifulness'] = [0.681, -0.686, 0, 0.938, '#surprising', '#admirable', 0.768, 'righteousness', 'godliness', 'piety', 'devoutness', 'religiousness']
senticnet['duty'] = [0, 0.952, 0, 0.878, '#interesting', '#admirable', 0.61, 'management', 'policeman', 'authority', 'ambasjoyfulor', 'construction_worker']
senticnet['duvet'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'pillowcase', 'bed', 'comforter', 'bed_sheet', 'duvet_cover']
senticnet['duvet_cover'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'pillowcase', 'bed', 'comforter', 'bed_sheet', 'duvet']
senticnet['dvd'] = [0, 0, 0, 0.07, '#admirable', '#admirable', 0.023, 'source_code', 'computer', 'browser', 'buffoon', 'clown']
senticnet['dvd_player'] = [0.09, -0.032, 0.015, 0, '#joyful', '#surprising', 0.036, 'tape_player', 'light_fixture', 'tv_set', 'sit_at_theater', 'technician']
senticnet['dwarf'] = [0, -0.032, -0.057, -0.121, '#scared', '#disgusting', -0.049, 'gnome', 'elf', 'goblin', 'undersized', 'small_person']
senticnet['dwarf_buckeye'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'sweet_buckeye', 'horse_chestnut', 'bottlebrush_buckeye', 'red_buckeye', 'particolored_buckeye']
senticnet['dwarf_cornel'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'bunchberry', 'cornel', 'crackerberry', 'pudding_berry', 'common_white_dogwood']
senticnet['dwarf_planet'] = [0.829, 0, 0, 0.81, '#joyful', '#admirable', 0.546, 'galaxy', 'universe', 'planetary', 'sun', 'moon']
senticnet['dwarfism'] = [-0.871, 0, 0.873, -0.621, '#sad', '#angry', -0.788, 'pycnodysostosis', 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect']
senticnet['dwell_on'] = [-0.102, 0, 0, 0, '#sad', '#sad', -0.034, 'falter', 'waver', 'linger', 'boggle', 'hesitate']
senticnet['dwell_place'] = [0, 0.096, -0.053, 0.131, '#interesting', '#admirable', 0.058, 'domestic_dwell', 'live_place', 'place_to_live', 'live_quarter', 'domicile']
senticnet['dweller'] = [0.9, -0.513, 0, 0.836, '#joyful', '#admirable', 0.75, 'invillager', 'inhabitant', 'habitant', 'villager', 'denizen']
senticnet['dwelling'] = [-0.059, 0.116, -0.044, 0.102, '#interesting', '#admirable', 0.038, 'house', 'lease', 'multi-story_build', 'rent_out', 'large_house']
senticnet['dybbuk'] = [-0.793, 0, 0.92, -0.752, '#sad', '#angry', -0.822, 'evil_spirit', 'incubus', 'succubus', 'succuba', 'daemon']
senticnet['dye'] = [0, 0, 0, 0.098, '#admirable', '#admirable', 0.033, 'wall_cover', 'two-dimensional', 'cover_wall', 'pigment', 'latex']
senticnet['dye_hair'] = [0.05, -0.029, 0, 0.111, '#joyful', '#admirable', 0.063, 'change_hair', 'makeover', 'change_hairstyle', 'salon', 'get_haircut']
senticnet['dynamic'] = [0, 0.144, -0.091, 0.196, '#interesting', '#admirable', 0.083, 'capable', 'like_electricity', 'alter', 'pocket_money', 'change_money']
senticnet['dynamical'] = [0.74, -0.755, 0, 0.815, '#surprising', '#admirable', 0.77, 'propellant', 'propellent', 'propelling', 'changing', 'propulsive']
senticnet['dynamite'] = [0, 0, -0.942, -0.769, '#scared', '#disgusting', -0.57, 'bomb', 'explosive', 'nuclear_bomb', 'projectile', 'aerial_bomb']
senticnet['dynamite_explosion'] = [0, -0.032, -0.057, -0.121, '#scared', '#disgusting', -0.049, 'firework', 'bright_flash', 'nuclear_weapon', 'earthquake', 'nuclear_bomb']
senticnet['dynamo'] = [-0.058, -0.01, -0.053, -0.069, '#sad', '#disgusting', -0.057, 'crank', 'air_vent', 'emergency_brake', 'brake_pedal', 'grunt']
senticnet['dynasty'] = [0.761, 0.734, 0, 0, '#joyful', '#interesting', 0.498, 'kingdom', 'rule_government', 'aboriginal', 'queen_of_england', 'imperial']
senticnet['dyne'] = [-0.641, 0, 0.678, -0.705, '#angry', '#disgusting', -0.675, 'pound', 'force_unit', 'newton', 'sthene', 'poundal']
senticnet['dysarthria'] = [-0.846, 0, 0.829, -0.546, '#sad', '#angry', -0.74, 'upset', 'defect_of_speech', 'dysphonia', 'disorder', 'lallation']
senticnet['dyscalculia'] = [0.89, -0.703, 0, 0.643, '#joyful', '#surprising', 0.745, 'dyslexia', 'learning_disability', 'dysgraphia', 'disorder', 'upset']
senticnet['dysentery'] = [-0.892, 0, 0.702, -0.671, '#sad', '#angry', -0.755, 'amebic_dysentery', 'amoebic_dysentery', 'shigellosis', 'bacillary_dysentery', 'infectious_disease']
senticnet['dysgenesis'] = [-0.738, 0, 0.634, -0.856, '#sad', '#disgusting', -0.743, 'cacogenesis', 'impotence', 'impotency', 'barrenness', 'infertility']
senticnet['dysgraphia'] = [0.89, -0.703, 0, 0.643, '#joyful', '#surprising', 0.745, 'dyslexia', 'dyscalculia', 'learning_disability', 'disorder', 'upset']
senticnet['dyslexia'] = [0.89, -0.703, 0, 0.643, '#joyful', '#surprising', 0.745, 'learning_disability', 'dyscalculia', 'dysgraphia', 'disorder', 'upset']
senticnet['dyslexic'] = [-0.634, 0, 0.996, -0.539, '#sad', '#angry', -0.723, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['dysmenorrhea'] = [-0.735, 0, 0.555, -0.908, '#sad', '#disgusting', -0.733, 'aching', 'hurting', 'labor_pain', 'neuralgia', 'neuralgy']
senticnet['dyspeptic'] = [-0.74, 0, 0.991, -0.641, '#sad', '#angry', -0.791, 'unfortunate', 'diseased_person', 'invalid', 'psychoneurotic', 'psychotic']
senticnet['dysphemism'] = [-0.991, 0, 0.597, -0.547, '#sad', '#angry', -0.712, 'jalopy', 'car', 'auto', 'automobile', 'machine']
senticnet['dysphonia'] = [-0.846, 0, 0.829, -0.546, '#sad', '#angry', -0.74, 'upset', 'dysarthria', 'defect_of_speech', 'disorder', 'lallation']
senticnet['dysphoria'] = [-0.803, 0.247, -0.44, -0.066, '#sad', '#scared', -0.354, 'helplessness', 'feel_down', 'demoralize', 'dispirit', 'get_down']
senticnet['dysphoric'] = [-0.692, 0.32, -0.351, -0.118, '#sad', '#scared', -0.28, 'despairingly', 'despondently', 'forlornly', 'forlornness', 'desolation']
senticnet['dyspneal'] = [-0.534, 0, 0.886, -0.918, '#angry', '#disgusting', -0.779, 'dyspneic', 'dyspnoeic', 'asphyxiating', 'dyspnoeal', 'breathless']
senticnet['dyspneic'] = [-0.534, 0, 0.886, -0.918, '#angry', '#disgusting', -0.779, 'asphyxiating', 'dyspnoeic', 'dyspneal', 'dyspnoeal', 'breathless']
senticnet['dyspnoeal'] = [-0.534, 0, 0.886, -0.918, '#angry', '#disgusting', -0.779, 'dyspneic', 'dyspnoeic', 'dyspneal', 'asphyxiating', 'breathless']
senticnet['dyspnoeic'] = [-0.534, 0, 0.886, -0.918, '#angry', '#disgusting', -0.779, 'dyspneic', 'asphyxiating', 'dyspneal', 'dyspnoeal', 'breathless']
senticnet['dysthymia'] = [-0.997, 0, 0.982, -0.62, '#sad', '#angry', -0.866, 'clinical_depression', 'dysthymic_depression', 'affective_disorder', 'major_affective_disorder', 'emotional_disorder']
senticnet['dysthymic_depression'] = [-0.997, 0, 0.982, -0.62, '#sad', '#angry', -0.866, 'dysthymia', 'clinical_depression', 'affective_disorder', 'major_affective_disorder', 'emotional_disorder']
senticnet['dystrophy'] = [-0.586, 0, 0.724, -0.757, '#angry', '#disgusting', -0.689, 'myotonic_muscular_dystrophy', 'myotonic_dystrophy', 'myotonia_atrophica', 'distal_muscular_dystrophy', 'genetic_disease']
senticnet['eager'] = [0.911, 0, 0, 0.978, '#joyful', '#admirable', 0.63, 'eagerly', 'eagerlyness', 'avidity', 'thirstily', 'avidness']
senticnet['eager_beaver'] = [0.691, -0.729, 0, 0.673, '#joyful', '#surprising', 0.698, 'goffer', 'gopher', 'actor', 'doer', 'worker']
senticnet['eagerly'] = [0.85, 0.986, 0, 0, '#joyful', '#interesting', 0.612, 'eager', 'eagerness', 'thirstily', 'impatient', 'hot']
senticnet['eagerness'] = [0.933, 0, 0, 0.739, '#joyful', '#admirable', 0.557, 'eagerly', 'avidity', 'thirstily', 'avidness', 'zest']
senticnet['eagle'] = [0, 0.105, 0, 0, '#interesting', '#interesting', 0.035, 'beak', 'many_feathers', 'big_eye', 'bird', 'bird_mouth']
senticnet['ear'] = [0.785, -0.995, 0, 0.981, '#surprising', '#admirable', 0.92, 'audition', 'absolute_pitch', 'perfect_pitch', 'modality', 'sense_modality']
senticnet['ear_activity'] = [0.022, 0.098, 0, 0.202, '#interesting', '#admirable', 0.107, 'use_ear', 'ear_work', 'audible', 'vibration', 'audio']
senticnet['ear_money'] = [0.65, -0.634, 0, 0.629, '#joyful', '#surprising', 0.638, 'entertain_crowd', 'performance', 'give_pleasure', 'entertainment', 'use_talent']
senticnet['ear_pad'] = [0.9, 0.898, 0, 0, '#joyful', '#interesting', 0.599, 'ear', 'enjoy_music', 'sing_along', 'hear_song', 'earring']
senticnet['ear_splitting'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'deafening', 'roaring', 'hear_loud_sound', 'rowdy', 'noisy']
senticnet['ear_work'] = [0.043, 0.107, 0, 0.183, '#interesting', '#admirable', 0.111, 'use_ear', 'ear_activity', 'hear', 'audible', 'ability_hear']
senticnet['earache'] = [0, 0, -0.745, -0.715, '#scared', '#disgusting', -0.487, 'bad_knee', 'physical_pain', 'schizophrenia', 'poor_health', 'poke_pin']
senticnet['earful'] = [-0.709, 0, 0.965, -0.535, '#sad', '#angry', -0.736, 'scuttlebutt', 'malicious_gossip', 'talk_of_town', 'talk', 'scandal']
senticnet['earl'] = [0.044, 0.111, 0, 0.102, '#interesting', '#admirable', 0.086, 'duke', 'noble', 'king', 'despot', 'royal_leader']
senticnet['early'] = [0, 0.071, 0, 0, '#interesting', '#interesting', 0.024, 'soon', 'light_in_sky', 'sunrise', 'day_part', 'part_of_day']
senticnet['earmark'] = [0.519, -0.991, 0, 0.741, '#surprising', '#admirable', 0.75, 'allot', 'appropriate', 'set_aside', 'reserve', 'reserve_table']
senticnet['earn'] = [0, 0.893, 0, 0, '#interesting', '#interesting', 0.298, 'salary', 'wage', 'send_money', 'earnings', 'pay']
senticnet['earn_a_lot_of_money'] = [0.112, 0.178, -0.055, 0.143, '#interesting', '#admirable', 0.126, 'run_business', 'challenge_oneself', 'prove_fitness', 'enjoy_competition', 'support_cause']
senticnet['earn_degree'] = [0, 0.893, 0, 0, '#interesting', '#interesting', 0.298, 'go_college', 'pass_test', 'study_hard', 'discipline', 'degree']
senticnet['earn_income'] = [-0.039, 0.307, -0.106, 0.181, '#interesting', '#admirable', 0.114, 'give_money', 'compensation', 'send_money', 'settle_bill', 'earnings']
senticnet['earn_knowledge'] = [0.65, -0.634, 0, 0.629, '#joyful', '#surprising', 0.638, 'store', 'knowledge', 'gain_information', 'study', 'store_knowledge']
senticnet['earn_live'] = [0.05, -0.029, 0, 0.111, '#joyful', '#admirable', 0.063, 'go_work_to_earn_money', 'get_paycheck', 'responsible', 'earn_money', 'earn_paycheck']
senticnet['earn_money'] = [0.832, 0, 0, 0, '#joyful', '#joyful', 0.277, 'gain_wealth', 'make_money', 'become_rich', 'become_wealthy', 'entrepreneur']
senticnet['earn_paycheck'] = [0.832, 0, 0, 0, '#joyful', '#joyful', 0.277, 'earn_money', 'receive_paycheck', 'earn', 'paycheck', 'finish_work']
senticnet['earn_respect'] = [0.788, 0.716, 0, 0.884, '#joyful', '#admirable', 0.796, 'ego_boost', 'increase_self-confidence', 'improve_look', 'feel_good_oneself', 'look_different']
senticnet['earn_wage'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'cash', 'high_salary', 'productive', 'earn_money', 'support_family']
senticnet['earnest'] = [0, 0, 0, 0.994, '#admirable', '#admirable', 0.331, 'seriousness', 'in_earnest', 'heartfelt', 'devout', 'earnestly']
senticnet['earnestly'] = [0.934, 0.889, 0, 0, '#joyful', '#interesting', 0.608, 'seriously', 'devout', 'earnestness', 'seriousness', 'in_earnest']
senticnet['earnestness'] = [0.847, 0.992, 0, 0, '#joyful', '#interesting', 0.613, 'seriously', 'devout', 'earnestly', 'seriousness', 'in_earnest']
senticnet['earnings'] = [0.939, 0.789, 0, 0.755, '#joyful', '#interesting', 0.828, 'money', 'income', 'money_pay', 'compensation', 'repay']
senticnet['earplug'] = [0.735, 0.931, 0, 0, '#joyful', '#interesting', 0.555, 'go_to_theater', 'see_play', 'buy_concert_ticket', 'buy_ticket', 'buy_ticket_theater']
senticnet['earring'] = [0.918, 0.981, 0, 0, '#joyful', '#interesting', 0.633, 'ear', 'enjoy_music', 'sing_along', 'hear_song', 'ear_pad']
senticnet['earth'] = [-0.056, 0.076, 0, 0.107, '#interesting', '#admirable', 0.042, 'cold_night', 'terrain', 'soil', 'underfoot', 'dirt_soil']
senticnet['earth_day'] = [0.926, 0, 0, 0.709, '#joyful', '#admirable', 0.545, 'holiday', 'present', 'incident', 'birthday_gift', 'earth']
senticnet['earth_movement'] = [0.864, 0, 0, 0.87, '#joyful', '#admirable', 0.578, 'tremor', 'shake', 'movement', 'vibration', 'earthquake']
senticnet['earthquake'] = [-0.941, -0.913, -0.971, -0.813, '#sad', '#scared', -0.604, 'explosion', 'dynamite_explosion', 'bright_flash', 'disaster', 'rumble']
senticnet['earthworm'] = [0.852, -0.726, 0, 0, '#joyful', '#surprising', 0.526, 'bacterium', 'microorganism', 'germ', 'bug', 'cutworm']
senticnet['earthy'] = [-0.505, 0, 0.625, -0.84, '#angry', '#disgusting', -0.657, 'realistic', 'hardheaded', 'real', 'practical', 'graphic']
senticnet['earwig'] = [0, -0.093, 0.119, -0.119, '#angry', '#disgusting', -0.048, 'japanese_beetle', 'mole_cricket', 'gypsy_moth', 'mosquito', 'cucumber_beetle']
senticnet['ease'] = [0.984, 0, 0, 0, '#joyful', '#joyful', 0.328, 'peacefulness', 'serenity', 'serene', 'tranquility', 'joy']
senticnet['ease_pain'] = [0.857, 0, 0, 0, '#joyful', '#joyful', 0.286, 'need_companionship', 'trade_stock', 'voice_concern', 'avoid_pain', 'experience_life']
senticnet['eased'] = [0.91, 0, 0, 0.901, '#joyful', '#admirable', 0.604, 'alleviated', 'mitigated', 'relieved', 'lessened', 'quenched']
senticnet['easel'] = [0.036, 0.099, -0.055, 0.118, '#interesting', '#admirable', 0.066, 'wall_hang', 'like_paint', 'artwork', 'portrait', 'painting']
senticnet['easement'] = [0.621, -0.603, 0, 0.545, '#joyful', '#surprising', 0.59, 'privilege', 'perquisite', 'public_easement', 'right_of_way', 'prerogative']
senticnet['easily'] = [0.943, 0, 0, 0, '#joyful', '#joyful', 0.314, 'easiness', 'relieve', 'allay', 'dreaminess', 'pacifically']
senticnet['easiness'] = [0.615, 0.643, -0.247, 0.29, '#joyful', '#interesting', 0.434, 'allay', 'relieve', 'pacifically', 'peaceable', 'repose']
senticnet['easing'] = [0.772, -0.923, 0, 0.524, '#joyful', '#surprising', 0.74, 'change', 'modification', 'disembarrassment', 'breath_of_fresh_air', 'alteration']
senticnet['east'] = [0, 0.157, 0, 0.094, '#interesting', '#admirable', 0.084, 'north', 'sunrise', 'sunset', 'limit', 'dawn']
senticnet['easter_bunny'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'holiday', 'stay_with_family', 'eat_delicious_food', 'day_off', 'relax']
senticnet['eastern_brown_snake'] = [-0.028, -0.008, -0.052, -0.08, '#scared', '#disgusting', -0.051, 'red-bellied_black_snake', 'poisonous_snake', 'lizard', 'snake', 'shark']
senticnet['easy'] = [0.806, 0, 0, 0, '#joyful', '#joyful', 0.269, 'serene', 'togetherness', 'easily', 'tranquility', 'dreaminess']
senticnet['easy_break'] = [0, 0, 0, 0.131, '#admirable', '#admirable', 0.044, 'frustrate_person', 'breakable', 'opaque', 'eaten_raw', 'round_white']
senticnet['easy_going'] = [0.859, -0.611, 0, 0.721, '#joyful', '#admirable', 0.73, 'forward_motion', 'onward_motion', 'progression', 'procession', 'progress']
senticnet['easy_mark'] = [-0.539, 0, 0.591, -0.593, '#angry', '#disgusting', -0.574, 'mug', 'sitting_duck', 'dupe', 'stooge', 'mortal']
senticnet['easy_tear'] = [-0.896, 0, 0.809, 0, '#sad', '#angry', -0.568, 'spherical', 'seen_night_sky', 'fill_with_sand', 'round_shape', 'light_colored']
senticnet['easy_to_break'] = [-0.682, 0, 0.916, -0.912, '#angry', '#disgusting', -0.837, 'poor', 'bad', 'dirt', 'terrible', 'bad_quality']
senticnet['easy_use'] = [0.093, -0.042, 0.031, 0.153, '#joyful', '#admirable', 0.086, 'hard_use', 'power_electricity', 'just_fun', 'dangerous_drive', 'fun_play']
senticnet['easygoing'] = [0.753, 0, 0, 0.911, '#joyful', '#admirable', 0.555, 'leisurely', 'unhurried', 'easy', 'equable', 'placid']
senticnet['eat'] = [0, 0.148, 0, 0.148, '#interesting', '#admirable', 0.099, 'status', 'basic', 'mandatory', 'basic_need', 'classification']
senticnet['eat_action'] = [0.048, 0.093, 0.014, 0.18, '#interesting', '#admirable', 0.102, 'mouth_activity', 'ingest', 'mouth_action', 'consume', 'like_food']
senticnet['eat_animal'] = [-0.099, 0, -0.08, -0.035, '#sad', '#scared', -0.071, 'die_only_once', 'hurt_animal', 'kill_specific_group', 'dig_grave', 'form_sentence']
senticnet['eat_apple'] = [0.896, 0.839, 0, 0, '#joyful', '#interesting', 0.578, 'healthy_snack', 'healthy_food', 'quick_snack', 'sate_hunger', 'eat_quickly']
senticnet['eat_bad_food'] = [0, 0, -0.746, -0.954, '#scared', '#disgusting', -0.567, 'lose_team', 'cause_suffer', 'leave_out', 'disrespect', 'fall_sick']
senticnet['eat_balance_diet'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'visit_doctor', 'blood_test', 'go_gym', 'workout', 'eat_healthy_food']
senticnet['eat_banana'] = [-0.099, 0, -0.052, 0, '#sad', '#scared', -0.05, 'sell_vegetable', 'miss_bus', 'eat_fruit', 'try_again', 'pick_berry']
senticnet['eat_bean'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'eat_pasta', 'eat_something', 'look_closely', 'schoolchild', 'eat_food']
senticnet['eat_beef'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'eat_meat', 'eat_delicious_food', 'sate_hunger', 'eat_steak', 'eat_hamburger']
senticnet['eat_better'] = [0.896, 0, 0, 0.809, '#joyful', '#admirable', 0.568, 'get_fat', 'eat', 'feel_satisfied', 'obesity', 'decrease_hunger']
senticnet['eat_bread'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'breakfast', 'eat_egg', 'drink_milk', 'drink_coffee', 'eat_cookie']
senticnet['eat_breakfast'] = [0.974, 0.789, 0, 0.828, '#joyful', '#admirable', 0.864, 'eat_lunch', 'eat_hamburger', 'sate_hunger', 'lunch', 'eat_apple']
senticnet['eat_breakfast_in_bed'] = [0, 0, 0, 0.867, '#admirable', '#admirable', 0.289, 'eat_like_pig', 'eat_cookie', 'diminish_own_hunger', 'eat_breakfast', 'sate_hunger']
senticnet['eat_brunch'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'eat_dinner', 'eat_breakfast', 'eat_lunch', 'eat_meal', 'eat_food']
senticnet['eat_burger'] = [0.863, 0.875, 0, 0.935, '#interesting', '#admirable', 0.891, 'eat_delicious_food', 'sate_hunger', 'eat_hamburger', 'eat_steak', 'eat_meat']
senticnet['eat_cake'] = [0.95, 0, 0, 0, '#joyful', '#joyful', 0.317, 'celebrate_special_occasion', 'celebration', 'celebrate_birthday', 'social_occasion', 'special_occasion']
senticnet['eat_candy'] = [0.898, 0, 0, 0, '#joyful', '#joyful', 0.299, 'see_funny', 'laugh_out_loud', 'laugh', 'laughter', 'entertain']
senticnet['eat_cat_food'] = [0, 0, 0, -0.744, '#disgusting', '#disgusting', -0.248, 'excrete', 'dream_with_eyes_open', 'sleep_long_time', 'miss_appointment', 'eat_animal']
senticnet['eat_cereal'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'eat_food', 'eat_pudding', 'stir_coffee', 'satisfy_appetite', 'able_eat']
senticnet['eat_cheese'] = [-0.052, 0.072, 0.012, 0.066, '#interesting', '#admirable', 0.025, 'sink_water', 'open_mailbox', 'bell_cat', 'eat', 'shoulder_burden']
senticnet['eat_cheeseburger'] = [0.08, 0.152, 0, 0.124, '#interesting', '#admirable', 0.119, 'ingest', 'eat_liquid', 'consumable', 'better_cold', 'gulp']
senticnet['eat_chicken'] = [0.744, 0, 0, 0, '#joyful', '#joyful', 0.248, 'dig_hole', 'sharpen_knife', 'recycle_paper', 'eat_animal', 'travel_space']
senticnet['eat_chip'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'feed_person', 'eat_food', 'eat_meal', 'feed_child', 'eat_much_food']
senticnet['eat_chocolate'] = [0.7, 0, 0, 0, '#joyful', '#joyful', 0.233, 'unprotect_sex', 'make_love', 'find_partner', 'copulate', 'procreate']
senticnet['eat_cookie'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'breakfast', 'eat_egg', 'drink_milk', 'drink_coffee', 'eat_bread']
senticnet['eat_delicious_food'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'holiday', 'stay_with_family', 'easter_bunny', 'day_off', 'relax']
senticnet['eat_dessert'] = [0.786, 0, 0, 0, '#joyful', '#joyful', 0.262, 'wash_dog', 'wash_dish', 'clean_object', 'camp_out', 'mop_floor']
senticnet['eat_dinner'] = [0.026, 0.069, 0, 0, '#joyful', '#interesting', 0.032, 'eat_food', 'eat_beef', 'chew_food', 'espresso', 'eat_much']
senticnet['eat_dog'] = [0.971, 0, 0, 0, '#joyful', '#joyful', 0.324, 'like_play', 'eat', 'live_forever', 'drink_sea_water', 'travel_fast_light']
senticnet['eat_drink'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'satisfy_hunger', 'satisfy_crave', 'eat_pie', 'celebrate_wedding', 'fill_stomach']
senticnet['eat_egg'] = [-0.098, -0.02, 0, -0.083, '#sad', '#disgusting', -0.054, 'eat_sushi', 'eat', 'sell_vegetable', 'eat_healthy_diet', 'feel_grateful']
senticnet['eat_establishment'] = [-0.847, 0, 0.816, 0, '#sad', '#angry', -0.554, 'fast_food', 'old_west', 'tavern', 'liquor_store', 'diner']
senticnet['eat_excessively'] = [-0.611, 0.262, -0.386, -0.223, '#sad', '#scared', -0.319, 'eat_too_much', 'overeat', 'eat_quickly', 'eat_breakfast', 'eat_apple']
senticnet['eat_expired_food'] = [-0.927, 0, 0.784, -0.912, '#sad', '#disgusting', -0.874, 'eat_fast_food', 'eat_snack', 'eat_unhealthy_food', 'bad_meal', 'eat_quickly']
senticnet['eat_fast_food'] = [-0.927, 0, 0.784, -0.912, '#sad', '#disgusting', -0.874, 'bad_meal', 'eat_snack', 'eat_unhealthy_food', 'eat_expired_food', 'eat_quickly']
senticnet['eat_fish'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'eat_soup', 'eat_delicious_food', 'sate_hunger', 'eat_salmon', 'eat_sushi']
senticnet['eat_food'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'eat_pasta', 'eat_something', 'eat_beef', 'satisfy_appetite', 'eat_steak']
senticnet['eat_food_fast'] = [-0.927, 0, 0.784, -0.912, '#sad', '#disgusting', -0.874, 'fast_food', 'meal', 'fast_food_restaurant', 'burger_king', 'eat_burger']
senticnet['eat_food_off'] = [0.863, 0, 0, 0, '#joyful', '#joyful', 0.288, 'serve_meal', 'eat_pudding', 'sit_around', 'eat_food', 'munch']
senticnet['eat_food_off_plate'] = [0.863, 0, 0, 0, '#joyful', '#joyful', 0.288, 'serve_meal', 'eat_pudding', 'sit_around', 'eat_food', 'munch']
senticnet['eat_french_fries'] = [-0.971, 0, -0.844, 0, '#sad', '#scared', -0.605, 'use_restroom', 'order_french_fries', 'get_front', 'watch_other_person', 'become_full']
senticnet['eat_fruit'] = [0.738, 0, 0, 0, '#joyful', '#joyful', 0.246, 'eat_healthy_diet', 'live_good_life', 'accomplish_goal', 'practice_yoga', 'eat_banana']
senticnet['eat_good_food'] = [0, 0.755, 0, 0, '#interesting', '#interesting', 0.252, 'eat_well', 'welcome_guest', 'meet_other_person', 'enjoy_meal', 'healthy_food']
senticnet['eat_hamburger'] = [0.863, 0.875, 0, 0.935, '#interesting', '#admirable', 0.891, 'eat_delicious_food', 'sate_hunger', 'eat_burger', 'eat_steak', 'eat_meat']
senticnet['eat_healthily'] = [0.84, 0.76, 0, 0.894, '#joyful', '#admirable', 0.831, 'keep_skin_healthy', 'stay_healthy', 'stay_fit', 'maintain_good_health', 'maintain_muscle_strength']
senticnet['eat_healthy'] = [0.863, 0.875, 0, 0.935, '#interesting', '#admirable', 0.891, 'live_healthy_lifestyle', 'live_long_life', 'take_vitamin_food', 'good_nutrition', 'eat_well']
senticnet['eat_healthy_diet'] = [0.722, 0, 0, 0, '#joyful', '#joyful', 0.241, 'exercise_much', 'eat_well', 'healthy', 'eat_healthy_food', 'practice_yoga']
senticnet['eat_healthy_food'] = [0.84, 0.76, 0, 0.894, '#joyful', '#admirable', 0.831, 'eat_well', 'good_nutrition', 'eat_healthy', 'eat_healthily', 'take_vitamin_food']
senticnet['eat_hot_dog'] = [0.804, 0, 0, 0, '#joyful', '#joyful', 0.268, 'cheer_team', 'good_time', 'watch_game', 'want_join', 'enjoy_play']
senticnet['eat_ice_cream'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'relax', 'eat_food', 'eat_snack', 'eat_sweet', 'childhood']
senticnet['eat_insect'] = [-0.03, 0, 0.112, -0.037, '#angry', '#disgusting', -0.06, 'bug', 'pest', 'insect', 'annoy_bug', 'big_rat']
senticnet['eat_into'] = [-0.569, 0, 0.712, -0.708, '#angry', '#disgusting', -0.663, 'nettle', 'bother', 'devil', 'chafe', 'rag']
senticnet['eat_like_pig'] = [-0.927, 0, 0.784, -0.912, '#sad', '#disgusting', -0.874, 'get_excited', 'eat_breakfast_in_bed', 'inebriate', 'become_inebriated', 'eat_quickly']
senticnet['eat_liquid'] = [0.08, 0.068, 0, 0.077, '#joyful', '#admirable', 0.075, 'potable_liquid', 'better_cold', 'ingest', 'gulp', 'like_eat']
senticnet['eat_little'] = [0, 0, 0.814, -0.931, '#angry', '#disgusting', -0.582, 'hungry', 'need_money', 'poor_people', 'ill', 'fast_meal']
senticnet['eat_live'] = [0.919, 0.904, 0, 0, '#joyful', '#interesting', 0.608, 'sense_environment', 'fight_other', 'battle_cancer', 'trip_person', 'die_only_once']
senticnet['eat_lot'] = [-0.055, -0.01, -0.078, -0.069, '#scared', '#disgusting', -0.064, 'flatulence', 'indigestion', 'stomach_ache', 'eat_food', 'fat']
senticnet['eat_lunch'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'eat_meal', 'eat_hamburger', 'sate_hunger', 'lunch', 'eat_apple']
senticnet['eat_meal'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'eat_dinner', 'eat_breakfast', 'eat_lunch', 'eat_brunch', 'eat_food']
senticnet['eat_meat'] = [0, 0, -0.068, 0, '#scared', '#scared', -0.023, 'fee_child', 'eat_pudding', 'eat_food_off_plate', 'serve_meal', 'need_food']
senticnet['eat_much'] = [0, 0, 0.814, -0.931, '#angry', '#disgusting', -0.582, 'eat_food', 'indigestion', 'stomach_ache', 'eat_lot', 'fat']
senticnet['eat_much_food'] = [0, 0, 0.814, -0.931, '#angry', '#disgusting', -0.582, 'eat_much', 'eat_food', 'eat_lot', 'fat', 'indigestion']
senticnet['eat_muffin'] = [0.761, 0, 0, 0, '#joyful', '#joyful', 0.254, 'need_food', 'eat', 'sell_vegetable', 'order_food', 'eat_cake']
senticnet['eat_off'] = [-0.16, 0, -0.184, -0.239, '#scared', '#disgusting', -0.194, 'erode', 'remove', 'diminish', 'decrease', 'reduce']
senticnet['eat_orange'] = [0.025, 0, -0.07, -0.062, '#scared', '#disgusting', -0.036, 'light_cigarette', 'create_fire', 'burn_finger', 'strike_match', 'start_fire']
senticnet['eat_out'] = [0.751, 0.987, 0, 0, '#joyful', '#interesting', 0.579, 'meet_friend', 'meal_served', 'enjoy_food', 'give_party', 'satisfy_hunger']
senticnet['eat_outdoors'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'cook_meat', 'cook_hamburger', 'cook_food', 'baker', 'brown_meat']
senticnet['eat_pasta'] = [-0.097, 0, -0.052, 0, '#sad', '#scared', -0.05, 'forward_email', 'deal_card_player', 'stand_alone', 'speak_english', 'explain_everything']
senticnet['eat_peach'] = [-0.079, 0, -0.08, 0, '#sad', '#scared', -0.053, 'shovel_snow', 'smoke_joint', 'fly_around', 'blow_away', 'sit_floor']
senticnet['eat_peanut'] = [-0.04, 0, -0.054, -0.095, '#scared', '#disgusting', -0.063, 'stagger', 'smoke_cigar', 'deal_card', 'smell_smoke', 'lower_standard']
senticnet['eat_peanut_butter'] = [0.129, 0.092, 0, 0.167, '#joyful', '#admirable', 0.129, 'eat_cereal', 'eat_fish', 'eat_pudding', 'meet_friend_for_lunch', 'stir_coffee']
senticnet['eat_pie'] = [0.81, 0, 0, 0, '#joyful', '#joyful', 0.27, 'eat_steak', 'eat_food', 'feed_person', 'eat_out', 'eat']
senticnet['eat_pizza'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'eat_steak', 'eat_food', 'eat_meal', 'feed_child', 'feed_person']
senticnet['eat_pizzaf'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'eat_steak', 'eat_food', 'eat_meal', 'feed_child', 'feed_person']
senticnet['eat_poison'] = [0, 0, -0.973, 0, '#scared', '#scared', -0.324, 'apnea', 'drug_addiction', 'drunk_drive', 'execute', 'commit_suicide']
senticnet['eat_popcorn'] = [0.744, 0, 0, 0, '#joyful', '#joyful', 0.248, 'cinema', 'eat', 'entertain', 'kill_brain_cell', 'enjoy_show']
senticnet['eat_potato'] = [0.96, 0, 0, 0, '#joyful', '#joyful', 0.32, 'drink_espresso', 'honor_parent', 'eat_pasta', 'shoulder_responsibility', 'battle_illness']
senticnet['eat_potato_chip'] = [-0.035, -0.051, 0.086, -0.168, '#angry', '#disgusting', -0.079, 'stuff_face', 'munch', 'able_eat', 'eat', 'eat_out']
senticnet['eat_properly'] = [0, 0.073, 0, 0, '#interesting', '#interesting', 0.024, 'exercise', 'eat_right', 'go_gym', 'workout', 'work_out']
senticnet['eat_pudding'] = [0.823, 0, 0, 0, '#joyful', '#joyful', 0.274, 'serve_meal', 'eat_food_off_plate', 'munch', 'transport_food', 'eat_food']
senticnet['eat_pussy'] = [0.983, 0, 0, 0, '#joyful', '#joyful', 0.328, 'sex', 'watch_porn', 'spray_paint_grafitti', 'masturbation', 'beat_off']
senticnet['eat_quickly'] = [0, 0, -0.106, 0, '#scared', '#scared', -0.035, 'eat_fast_food', 'eat_snack', 'eat_burger', 'sate_hunger', 'bad_meal']
senticnet['eat_rat'] = [0, 0, 0, -0.873, '#disgusting', '#disgusting', -0.291, 'domestic_pet', 'furry', 'common_pet', 'fierce', 'eat']
senticnet['eat_raw_fish'] = [0.991, 0, 0, 0, '#joyful', '#joyful', 0.33, 'spice_life', 'good_parent', 'run_business', 'enough_food', 'good_sense_of_humor']
senticnet['eat_rice'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'eat_food', 'sate_hunger', 'eat_meal', 'eat_meat', 'eat_fish']
senticnet['eat_right'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'eat_little', 'exercise', 'work_out', 'take_vitamin', 'go_gym']
senticnet['eat_salad'] = [0.853, 0, 0, 0, '#joyful', '#joyful', 0.284, 'drink_much_beer', 'spill_food_clothes', 'drink_tea', 'burp', 'read_paper']
senticnet['eat_salmon'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'eat_soup', 'eat_delicious_food', 'sate_hunger', 'eat_fish', 'eat_sushi']
senticnet['eat_sandwich'] = [-0.048, 0, 0, -0.052, '#sad', '#disgusting', -0.033, 'chew_food', 'stop_hungry', 'eat_meal', 'put_food_mouth', 'feed_child']
senticnet['eat_shit'] = [0, 0, 0, -0.786, '#disgusting', '#disgusting', -0.262, 'learn_add', 'add_number_together', 'get_total', 'learn_math', 'make_error']
senticnet['eat_snack'] = [0.831, 0, 0, 0, '#joyful', '#joyful', 0.277, 'see_commercial', 'change_channel', 'sit_sofa', 'channel_surf', 'drink_coke']
senticnet['eat_something'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'eat_pasta', 'eat_bean', 'look_closely', 'schoolchild', 'eat_food']
senticnet['eat_soup'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'eat_food', 'sate_hunger', 'eat_meal', 'eat_rice', 'eat_fish']
senticnet['eat_spaghetti'] = [0.98, 0.788, 0, 0, '#joyful', '#interesting', 0.589, 'date_woman', 'marry_man', 'die_only_once', 'service_car', 'fight_other']
senticnet['eat_steak'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'eat_meat', 'eat_delicious_food', 'sate_hunger', 'eat_beef', 'eat_hamburger']
senticnet['eat_sushi'] = [0.935, 0, 0, 0, '#joyful', '#joyful', 0.312, 'eat_egg', 'clean_up_kitchen', 'make_dinner', 'eat_pudding', 'enjoy_meal']
senticnet['eat_sweet'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'feed_child', 'eat_much', 'eat_meal', 'eat_ice_cream', 'play_card_game']
senticnet['eat_table'] = [-0.056, 0, 0, -0.046, '#sad', '#disgusting', -0.034, 'fish_food', 'machine_part', 'sleep_bed', 'eat_animal', 'hurt_animal']
senticnet['eat_tasty_food'] = [0.053, 0.145, -0.112, 0.124, '#interesting', '#admirable', 0.07, 'find_woman', 'desire_eat', 'cook_breakfast', 'change_diaper', 'eat_together']
senticnet['eat_together'] = [0.793, 0, 0, 0, '#joyful', '#joyful', 0.264, 'experience_life', 'breakfast_bed', 'watch_sunset', 'masturbate', 'meet_famous_person']
senticnet['eat_too_much'] = [-0.976, 0, 0.502, -0.971, '#sad', '#disgusting', -0.816, 'nightmare', 'bad_dream', 'stress', 'anxiety', 'bad_rest']
senticnet['eat_unhealthy_food'] = [-0.927, 0, 0.784, -0.912, '#sad', '#disgusting', -0.874, 'eat_fast_food', 'eat_snack', 'bad_meal', 'eat_expired_food', 'eat_quickly']
senticnet['eat_well'] = [0.991, 0, 0, 0, '#joyful', '#joyful', 0.33, 'practice_yoga', 'eat_healthy', 'eat_healthy_diet', 'exercise_much', 'exercise_regularly']
senticnet['eat_worm'] = [0, 0, -0.818, -0.716, '#scared', '#disgusting', -0.511, 'mistreat', 'attempt_fly', 'pick_berry', 'jump_air', 'white_bird']
senticnet['eatable'] = [0.052, 0, 0.038, 0.095, '#joyful', '#admirable', 0.036, 'bake_product', 'bake_good', 'sweet_food', 'yummy', 'morning_food']
senticnet['eaten'] = [0.036, -0.06, 0.037, 0.05, '#surprising', '#admirable', 0.036, 'bake', 'make_grain', 'make_flour', 'pot_roast', 'bake_food']
senticnet['eaten_raw'] = [0.054, 0.066, 0.021, 0.128, '#interesting', '#admirable', 0.076, 'good_eat', 'delicious', 'edible', 'tasty', 'fresh']
senticnet['eaten_shark'] = [-0.358, -0.172, 0.024, -0.377, '#sad', '#disgusting', -0.196, 'brain_tumor', 'lyme_disease', 'lose_team', 'cause_suffer', 'smelly_foot']
senticnet['eater'] = [0.826, -0.655, 0, 0.587, '#joyful', '#surprising', 0.689, 'scoffer', 'vegetarian', 'devourer', 'diner', 'dunker']
senticnet['eatery'] = [0.094, 0.084, 0.024, 0.062, '#joyful', '#interesting', 0.072, 'good_reastaurant', 'cafe', 'place_eat', 'good_place_eat', 'pub']
senticnet['eating_away'] = [-0.88, 0, 0.907, -0.522, '#sad', '#angry', -0.77, 'wearing', 'erosion', 'eroding', 'corrasion', 'wearing_away']
senticnet['eating_disorder'] = [-0.525, 0, 0.786, -0.927, '#angry', '#disgusting', -0.746, 'upset', 'bulimarexia', 'bulima_nervosa', 'bulimia', 'disorder']
senticnet['eavesdrop'] = [-0.536, 0, 0.884, -0.724, '#angry', '#disgusting', -0.715, 'bug', 'tap', 'wiretap', 'intercept', 'listen']
senticnet['eavesdropper'] = [-0.832, 0, 0.665, -0.512, '#sad', '#angry', -0.67, 'percipient', 'auditor', 'perceiver', 'observer', 'beholder']
senticnet['ebb'] = [0.989, 0, 0, 0.766, '#joyful', '#admirable', 0.585, 'movement_of_water', 'water_movement', 'water_motion', 'fast_water', 'water_flow']
senticnet['ebullience'] = [0.609, -0.615, 0, 0.592, '#joyful', '#surprising', 0.605, 'spirit', 'rabidity', 'rabidness', 'sprightliness', 'lyricism']
senticnet['ebulliently'] = [0.512, 0.658, -0.254, 0.256, '#joyful', '#interesting', 0.391, 'exuberantly', 'riotously', 'expansively', 'zestfulness', 'gusto']
senticnet['ebullition'] = [0.565, -0.792, 0, 0.959, '#surprising', '#admirable', 0.772, 'manifestation', 'cry', 'reflection', 'acting_out', 'explosion']
senticnet['eccentric'] = [0.716, 0.9, 0, 0, '#joyful', '#interesting', 0.539, 'cool', 'fashionable', 'fancy_dress', 'fancy_car', 'extravagant']
senticnet['echo'] = [0.838, 0, 0, 0.976, '#joyful', '#admirable', 0.605, 'loudness', 'vibration', 'loud_yell', 'detect', 'decibel']
senticnet['echt'] = [-0.642, 0, 0.852, -0.803, '#angry', '#disgusting', -0.766, 'unquestionable', 'documented', 'veritable', 'attested', 'authenticated']
senticnet['eclat'] = [0.639, -0.701, 0, 0.507, '#joyful', '#surprising', 0.616, 'tastefulness', 'daintiness', 'elegance', 'breeding', 'genteelness']
senticnet['eclectic'] = [0.032, 0.092, 0, 0.075, '#interesting', '#admirable', 0.066, 'rock_group', 'music_player', 'make_musicr', 'musical_group', 'guitar_player']
senticnet['eco_system'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'compel', 'cause_change', 'change_life', 'extinction', 'cascade_effect']
senticnet['economic'] = [0.913, -0.635, 0, 0.961, '#joyful', '#admirable', 0.836, 'materialistic', 'mercenary', 'mundane', 'material', 'worldly']
senticnet['economic_activity'] = [0, 0.226, -0.098, 0.26, '#interesting', '#admirable', 0.129, 'business', 'corporate', 'negotiate_contract', 'economics', 'enterprise']
senticnet['economic_aid'] = [0.547, -0.982, 0, 0.977, '#surprising', '#admirable', 0.835, 'grant', 'gift', 'social_welfare', 'public_assistance', 'philanthropy']
senticnet['economic_crisis'] = [-0.996, 0, 0.691, -0.655, '#sad', '#angry', -0.781, 'depression', 'crisis', 'exigency', 'slump', 'juncture']
senticnet['economic_libertarian'] = [0.677, -0.529, 0, 0.714, '#joyful', '#admirable', 0.64, 'libertarian', 'civil_libertarian', 'advocate', 'advocator', 'proponent']
senticnet['economical'] = [0.722, -0.744, 0, 0.554, '#joyful', '#surprising', 0.673, 'saving', 'thrifty', 'scotch', 'frugal', 'sparing']
senticnet['economics'] = [0, 0.219, 0, 0.208, '#interesting', '#admirable', 0.142, 'commerce', 'transaction', 'make_profit', 'exchange_money', 'economic_activity']
senticnet['economy'] = [0.067, 0.172, 0, 0.121, '#interesting', '#admirable', 0.12, 'economic_activity', 'business', 'support_family', 'work_done', 'earn_money']
senticnet['economy_of_scale'] = [0.953, -0.65, 0, 0.866, '#joyful', '#admirable', 0.823, 'saving', 'retrenchment', 'curtailment', 'downsizing', 'action']
senticnet['ecosystem'] = [0, 0.066, 0.048, 0.08, '#interesting', '#admirable', 0.033, 'many_yards', 'measure_distance', 'distance_measurement', 'mow', 'length']
senticnet['ecstasy'] = [1, 0, 0, 0, '#joyful', '#joyful', 0.333, 'pleasantness', 'joy', 'mood', 'strong_emotion', 'emotion']
senticnet['ecstasy_pill'] = [-0.834, 0.214, -0.391, -0.108, '#sad', '#scared', -0.373, 'use_drug', 'do_drug', 'drug_use', 'drug', 'addiction']
senticnet['ecstatic'] = [0.504, 0.156, -0.176, 0.193, '#joyful', '#admirable', 0.226, 'good_emotion', 'happy', 'happy_emotion', 'happy_feeling', 'pleasant_emotion']
senticnet['ectopic_gestation'] = [-0.752, 0, 0.715, -0.725, '#sad', '#disgusting', -0.731, 'abdominal_pregnancy', 'ovarian_pregnancy', 'tubal_pregnancy', 'pregnancy', 'gestation']
senticnet['ectopic_pregnancy'] = [-0.553, 0, 0.678, -0.649, '#angry', '#disgusting', -0.627, 'abdominal_pregnancy', 'ovarian_pregnancy', 'tubal_pregnancy', 'pregnancy', 'gestation']
senticnet['edacity'] = [0.768, -0.723, 0, 0.838, '#joyful', '#admirable', 0.776, 'gluttony', 'esurience', 'voracity', 'voraciousness', 'rapaciousness']
senticnet['edema'] = [-0.998, 0, 0.734, -0.915, '#sad', '#disgusting', -0.882, 'angioedema', 'atrophedema', 'giant_hives', 'periodic_edema', 'lymphedema']
senticnet['eden'] = [0, 0.085, 0, 0.146, '#interesting', '#admirable', 0.077, 'adam_and_eve', 'garden', 'apple', 'eve', 'outdoor']
senticnet['edge'] = [0.062, 0.1, 0.074, 0.117, '#interesting', '#admirable', 0.068, 'angle', 'semicircle', 'facet', 'apex', 'altitude']
senticnet['edgeless'] = [-0.043, -0.04, -0.049, -0.046, '#scared', '#disgusting', -0.033, 'blunted', 'dull', 'unsharpened', 'insensitive', 'blunt']
senticnet['edginess'] = [-0.932, 0, -0.75, 0, '#sad', '#scared', -0.561, 'disquietude', 'inquietude', 'edgy', 'uptight', 'restive']
senticnet['edgy'] = [0.739, 0.79, 0, 0, '#joyful', '#interesting', 0.51, 'high-strung', 'uptight', 'restive', 'overstrung', 'nervy']
senticnet['edible'] = [0.046, 0, 0.041, 0.102, '#joyful', '#admirable', 0.036, 'good_eat', 'delicious', 'yummy', 'tasty', 'cook_before_eaten']
senticnet['edible_grain'] = [0, 0.074, 0.035, 0.071, '#interesting', '#admirable', 0.037, 'farm_food', 'grown_food', 'cereal_crop', 'farm_plant', 'farm_crop']
senticnet['edible_human'] = [0.04, 0.065, 0.049, 0.126, '#interesting', '#admirable', 0.061, 'juicy', 'peelable', 'round_fruit', 'orange_color', 'bright_red']
senticnet['edible_nut'] = [0.677, -0.529, 0, 0.714, '#joyful', '#admirable', 0.64, 'palm_nut', 'palm_kernel', 'nut', 'cembra_nut', 'cedar_nut']
senticnet['edible_plant'] = [0, 0.083, 0.039, 0.074, '#interesting', '#admirable', 0.039, 'farm_plant', 'plant_food', 'plant_field', 'grown_food', 'wheat_rice']
senticnet['edict'] = [0.028, 0.177, 0, 0.167, '#interesting', '#admirable', 0.124, 'march_rear', 'law', 'regulation', 'legislation', 'legal']
senticnet['edifice'] = [0.026, 0.219, 0, 0.16, '#interesting', '#admirable', 0.135, 'large_build', 'palace', 'high_rise', 'structure', 'fortification']
senticnet['edit'] = [0.935, 0.947, 0, 0, '#joyful', '#interesting', 0.627, 'move_mouse', 'reboot', 'type_of_keyboard', 'enter_address', 'keep_track_appointment']
senticnet['edited'] = [-0.623, 0, 0.657, -0.955, '#angry', '#disgusting', -0.745, 'paraphrastic', 'adjusted', 'changed', 'emended', 'altered']
senticnet['edition'] = [0.786, 0, 0, 0.783, '#joyful', '#admirable', 0.523, 'font', 'headline', 'many_words', 'print', 'false_statement']
senticnet['editorial'] = [-0.052, -0.197, -0.179, 0.219, '#surprising', '#admirable', 0.062, 'riddle', 'mystery', 'obituary', 'enigma', 'book_genre']
senticnet['educate'] = [0.971, 0.735, 0, 0, '#joyful', '#interesting', 0.569, 'education', 'expand_knowledge', 'get_knowledge', 'get_education', 'gain_information']
senticnet['educate_guess'] = [-0.072, 0.189, -0.076, 0.171, '#interesting', '#admirable', 0.071, 'hypothetical', 'supposition', 'scientific_statement', 'theory', 'hypothesis']
senticnet['educate_oneself'] = [0.743, 0, 0, 0.717, '#joyful', '#admirable', 0.487, 'learn', 'gather_information', 'gain_knowledge', 'learn_much', 'increase_knowledge']
senticnet['educate_others'] = [0.936, 0, 0, 0.96, '#joyful', '#admirable', 0.632, 'understand_idea', 'seek_understanding', 'teacher', 'time_test', 'share_knowledge']
senticnet['educated'] = [0.786, -0.527, 0, 0.848, '#joyful', '#admirable', 0.72, 'learned', 'semiliterate', 'knowledgeable', 'lettered', 'literate']
senticnet['education'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'educate', 'get_knowledge', 'new_knowledge', 'expand_knowledge', 'find_out_world']
senticnet['educational_activity'] = [0.758, -0.988, 0, 0.859, '#surprising', '#admirable', 0.868, 'continuing_education', 'activity', 'course', 'extracurricular_activity', 'coeducation']
senticnet['educational_facility'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'educational_institution', 'education', 'educational_place', 'school', 'facility']
senticnet['educational_institution'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'educational_place', 'bachelor_degree', 'educational_facility', 'student_place', 'institution']
senticnet['educational_place'] = [0, -0.024, 0.053, -0.057, '#angry', '#disgusting', -0.029, 'place_learn', 'student_study', 'educational_facility', 'student_place', 'educational_institution']
senticnet['edulcorate'] = [0.868, -0.594, 0, 0.915, '#joyful', '#admirable', 0.792, 'sugarcoat', 'honey', 'glaze', 'change_taste', 'sugar']
senticnet['eff'] = [0.652, -0.801, 0, 0.746, '#surprising', '#admirable', 0.733, 'have', 'pair', 'take', 'couple', 'fornicate']
senticnet['efface'] = [-0.825, 0, 0.694, -0.712, '#sad', '#disgusting', -0.744, 'withdraw', 'strike', 'scratch', 'delete', 'take']
senticnet['effect'] = [-0.966, 0, 0.501, -0.927, '#sad', '#disgusting', -0.798, 'byproduct', 'wallop', 'side_effect', 'dent', 'fallout']
senticnet['effective'] = [0.982, -0.67, 0, 0.682, '#joyful', '#admirable', 0.778, 'workmanlike', 'competent', 'efficient', 'able', 'capable']
senticnet['effectiveness'] = [0.632, -0.804, 0, 0.537, '#joyful', '#surprising', 0.658, 'incisiveness', 'trenchancy', 'efficacy', 'efficaciousness', 'power']
senticnet['effectivity'] = [0.929, -0.711, 0, 0.605, '#joyful', '#surprising', 0.748, 'incisiveness', 'trenchancy', 'efficacy', 'efficaciousness', 'power']
senticnet['effectual'] = [0.622, -0.721, 0, 0.799, '#surprising', '#admirable', 0.714, 'sound', 'logical', 'validated', 'valid', 'legitimate']
senticnet['effectuality'] = [0.807, -0.939, 0, 0.621, '#joyful', '#surprising', 0.789, 'incisiveness', 'trenchancy', 'efficacy', 'efficaciousness', 'power']
senticnet['effectualness'] = [0.779, -0.986, 0, 0.793, '#surprising', '#admirable', 0.853, 'incisiveness', 'trenchancy', 'efficacy', 'efficaciousness', 'power']
senticnet['effeminate'] = [-0.63, 0, 0.986, -0.946, '#angry', '#disgusting', -0.854, 'womanish', 'unmanful', 'emasculate', 'cissy', 'sissified']
senticnet['effete'] = [-0.941, 0, 0.987, -0.643, '#sad', '#angry', -0.857, 'unable', 'ineffectual', 'ineffective', 'impuissant', 'impotent']
senticnet['efficaciousness'] = [0.632, -0.804, 0, 0.537, '#joyful', '#surprising', 0.658, 'incisiveness', 'trenchancy', 'efficacy', 'effectiveness', 'power']
senticnet['efficacy'] = [0.632, -0.804, 0, 0.537, '#joyful', '#surprising', 0.658, 'incisiveness', 'trenchancy', 'effectiveness', 'efficaciousness', 'power']
senticnet['efficiency'] = [0.7, 0, 0, 0.979, '#joyful', '#admirable', 0.56, 'efficient', 'clean_sink', 'maintenance', 'kill_spider', 'mow_grass']
senticnet['efficient'] = [0.024, 0.089, 0.042, 0.066, '#interesting', '#admirable', 0.046, 'browser', 'telephone_computer', 'computer', 'modem', 'internet_connection']
senticnet['efflorescence'] = [-0.963, 0, 0.615, -0.734, '#sad', '#disgusting', -0.771, 'flush', 'blossom', 'prime', 'peak', 'golden_age']
senticnet['effort'] = [-0.109, 0.196, -0.102, 0.162, '#interesting', '#admirable', 0.049, 'motivation', 'determination', 'persistence', 'dedication', 'prepare']
senticnet['effortful'] = [-0.825, 0, 0.58, -0.539, '#sad', '#angry', -0.648, 'tiring', 'wearing', 'wearying', 'hard', 'arduous']
senticnet['effortfulness'] = [-0.646, 0, 0.928, -0.703, '#angry', '#disgusting', -0.759, 'difficulty', 'arduousness', 'strenuousness', 'laboriousness', 'operoseness']
senticnet['effortlessness'] = [-0.568, 0, 0.507, -0.891, '#sad', '#disgusting', -0.655, 'smoothness', 'ease', 'easiness', 'readiness', 'facility']
senticnet['effulgence'] = [0.65, -0.618, 0, 0.703, '#joyful', '#admirable', 0.657, 'gleaming', 'luster', 'polish', 'glow', 'burnish']
senticnet['effusion'] = [0.759, -0.727, 0, 0.893, '#joyful', '#admirable', 0.793, 'manifestation', 'cry', 'reflection', 'acting_out', 'explosion']
senticnet['egalitarian'] = [0.703, 0.913, 0, 0.701, '#joyful', '#interesting', 0.772, 'discovery', 'adventurer', 'pioneer', 'correspondent', 'humankind']
senticnet['egalitarian_society'] = [0, 0, 0, 0.744, '#admirable', '#admirable', 0.248, 'committee', 'association', 'colony', 'organization', 'population']
senticnet['egalitarianism'] = [0.025, 0.287, 0, 0.237, '#interesting', '#admirable', 0.183, 'unity', 'roman', 'count_person', 'average', 'median']
senticnet['egalite'] = [0.942, -0.826, 0, 0.828, '#joyful', '#admirable', 0.865, 'egality', 'equivalence', 'tie', 'status', 'position']
senticnet['egality'] = [0.942, -0.826, 0, 0.828, '#joyful', '#admirable', 0.865, 'equivalence', 'egalite', 'tie', 'status', 'position']
senticnet['egg'] = [0, 0.067, 0, 0.07, '#interesting', '#admirable', 0.046, 'peck', 'embryo', 'chicken_bushel', 'ovum', 'bushel']
senticnet['egg_shell'] = [0.895, -0.737, 0, 0, '#joyful', '#surprising', 0.544, 'old_paper', 'food_scrap', 'mind_child', 'moldy_food', 'old_newspaper']
senticnet['ego'] = [0.638, -0.996, 0, 0.631, '#joyful', '#surprising', 0.755, 'awareness', 'consciousness', 'state_of_mind', 'conscious', 'aesthesia']
senticnet['ego_boost'] = [0.102, 0, 0, 0, '#joyful', '#joyful', 0.034, 'spread_idea', 'make_world_better_place', 'make_money', 'help_others', 'accomplish_task']
senticnet['egotism'] = [0, 0, 0, -0.957, '#disgusting', '#disgusting', -0.319, 'self-importance', 'amour_propre', 'conceit', 'self-love', 'self-pride']
senticnet['egregious'] = [0, 0, 0.88, -0.916, '#angry', '#disgusting', -0.599, 'flagrant', 'crying', 'glaring', 'gross', 'rank']
senticnet['egress'] = [0.836, -0.832, 0, 0.511, '#joyful', '#surprising', 0.726, 'issue', 'start', 'casus_belli', 'emergence', 'beginning']
senticnet['egret'] = [0, 0.098, -0.064, 0.118, '#interesting', '#admirable', 0.051, 'broad', 'tall_man', 'wide', 'wood_structure', 'large']
senticnet['eiffel_tower'] = [0, 0.111, 0, 0.07, '#interesting', '#admirable', 0.06, 'beautiful_view', 'tourist_attraction', 'iconic_place', 'piece_of_story', 'monument']
senticnet['eight_legs'] = [-0.05, -0.029, 0.062, -0.094, '#angry', '#disgusting', -0.059, 'bite_dog', 'tic', 'small_fly', 'itch', 'parasite']
senticnet['eight_sides'] = [0, 0.171, -0.074, 0.284, '#interesting', '#admirable', 0.127, 'red_light', 'direction', 'halt', 'change_direction', 'go_around']
senticnet['eightpenny'] = [0.753, -0.945, 0, 0.965, '#surprising', '#admirable', 0.888, 'threepenny', 'size', 'sized', 'fourpenny', 'ninepenny']
senticnet['eismowe'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'glaucous_gull', 'dove', 'egret', 'white_swan', 'white_bird']
senticnet['ejaculate'] = [0.032, 0.261, -0.157, 0.198, '#interesting', '#admirable', 0.111, 'carry_baby', 'baby_born', 'herpes', 'cum', 'change_diaper']
senticnet['ejaculation'] = [-0.99, 0, -0.853, 0, '#sad', '#scared', -0.614, 'ejaculate', 'pass_gene', 'ecstasy', 'lower_standard_live', 'survival_species']
senticnet['eject'] = [-0.711, 0, 0.954, -0.563, '#sad', '#angry', -0.743, 'evict', 'chuck_out', 'exclude', 'turf_out', 'boot_out']
senticnet['elaborate'] = [-0.067, 0.108, -0.086, 0.233, '#interesting', '#admirable', 0.063, 'response', 'write_back', 'question_answer', 'retort', 'give_answer']
senticnet['elaborateness'] = [0.632, -0.62, 0, 0.923, '#joyful', '#admirable', 0.725, 'quality', 'intricacy', 'complexity', 'tapestry', 'complicatedness']
senticnet['elan'] = [0.559, 0.656, -0.261, 0.285, '#joyful', '#interesting', 0.413, 'zealous', 'avidity', 'eagerness', 'avidness', 'thirstily']
senticnet['elapid'] = [-0.517, 0, 0.582, -0.976, '#angry', '#disgusting', -0.692, 'death_adder', 'ophidian', 'serpent', 'krait', 'taipan']
senticnet['elapid_snake'] = [-0.949, 0, 0.786, -0.897, '#sad', '#disgusting', -0.877, 'death_adder', 'ophidian', 'serpent', 'krait', 'taipan']
senticnet['elasmobranch'] = [-0.54, 0, 0.983, -0.911, '#angry', '#disgusting', -0.811, 'shark', 'selachian', 'hammerhead', 'cow_shark', 'mackerel_shark']
senticnet['elastic'] = [0.808, 0, 0, 0.943, '#joyful', '#admirable', 0.584, 'a_lot_of_practice', 'flexibility', 'take_lesson', 'coordination', 'air_tank']
senticnet['elasticity'] = [-0.055, 0.112, 0, 0.189, '#interesting', '#admirable', 0.082, 'grow_long', 'flexibility', 'elongate', 'reach_out', 'extend']
senticnet['elate'] = [0.643, 0.64, -0.24, 0.3, '#joyful', '#interesting', 0.448, 'high_spirits', 'elating', 'exhilarating', 'elated', 'cheerful']
senticnet['elated'] = [0.628, 0.642, -0.239, 0.291, '#joyful', '#interesting', 0.441, 'gleeful', 'gladden', 'elating', 'elate', 'high_spirits']
senticnet['elating'] = [0.643, 0.64, -0.24, 0.3, '#joyful', '#interesting', 0.448, 'elate', 'high_spirits', 'exhilarating', 'elated', 'cheerful']
senticnet['elation'] = [0.933, 0.883, 0, 0.87, '#joyful', '#interesting', 0.895, 'contentment', 'euphoria', 'cheer', 'joy', 'jubilation']
senticnet['elbow'] = [0, 0, -0.066, -0.071, '#scared', '#disgusting', -0.046, 'bandit', 'arm', 'wrist', 'five_fingers', 'bendable']
senticnet['elbow_grease'] = [0.707, 0.969, 0, 0, '#joyful', '#interesting', 0.559, 'chore', 'make_happen', 'pick_up_trash', 'intuition', 'stop_procrastinate']
senticnet['eld'] = [-0.796, 0, 0.802, -0.549, '#sad', '#angry', -0.716, 'age', 'old_age', 'years', 'dotage', 'geezerhood']
senticnet['elder'] = [0, 0, 0, 0.79, '#admirable', '#admirable', 0.263, 'greatness', 'absolute', 'sec', 'respectful', 'sentence_end']
senticnet['elder_statesman'] = [0.838, -0.589, 0, 0.945, '#joyful', '#admirable', 0.791, 'national_leader', 'stateswoman', 'politician', 'politico', 'pol']
senticnet['elderly'] = [0, 0, 0, 0.7, '#admirable', '#admirable', 0.233, 'old', 'years', 'many_years', 'teen', 'annual']
senticnet['elderly_person'] = [0, 0.067, -0.177, -0.092, '#scared', '#disgusting', -0.067, 'sick_person', 'nurse', 'doctor', 'doctor_office', 'physician']
senticnet['elect'] = [0, 0.75, 0, 0, '#interesting', '#interesting', 0.25, 'vote', 'ballot', 'presidential', 'nominate', 'elect_president']
senticnet['elect_office'] = [0.02, 0.105, 0, 0.064, '#interesting', '#admirable', 0.063, 'elect_official', 'prime_minister', 'personal_groom', 'country_leader', 'officer']
senticnet['elect_official'] = [0.025, 0.127, -0.054, 0.076, '#interesting', '#admirable', 0.058, 'prime_minister', 'country_leader', 'president_united_states', 'ceo', 'officer']
senticnet['elect_person'] = [0, 0.257, -0.091, 0.193, '#interesting', '#admirable', 0.12, 'lose_election', 'country_leader', 'elect_official', 'political_figure', 'prime_minister']
senticnet['elect_president'] = [0.053, 0.365, -0.206, 0.29, '#interesting', '#admirable', 0.167, 'presidential', 'obedience', 'selection', 'demand', 'decide']
senticnet['elected_official'] = [0.984, -0.933, 0, 0.927, '#joyful', '#surprising', 0.948, 'lame_duck', 'lieutenant_governor', 'selectman', 'selectwoman', 'official']
senticnet['election'] = [0, 0.156, -0.153, 0.179, '#interesting', '#admirable', 0.061, 'candidate', 'presidential', 'vote', 'elect', 'appoint']
senticnet['electioneering'] = [-0.797, 0, 0.525, -0.635, '#sad', '#disgusting', -0.652, 'campaigning', 'candidacy', 'candidature', 'whispering_campaign', 'political_campaign']
senticnet['electric'] = [0.764, 0, 0, 0.75, '#joyful', '#admirable', 0.505, 'electrical', 'power_plant', 'static_electricity', 'electric_current', 'electrical_unit']
senticnet['electric_bill'] = [-0.071, -0.037, -0.112, 0, '#sad', '#scared', -0.049, 'sign_agreement', 'parcel', 'receive_email', 'receipt', 'phone_bill']
senticnet['electric_car'] = [0.086, 0, 0, 0.13, '#joyful', '#admirable', 0.072, 'gas_electric', 'go_green', 'technologic_car', 'large_automobile', 'large_car']
senticnet['electric_current'] = [-0.856, 0, -0.782, 0, '#sad', '#scared', -0.546, 'static_electricity', 'shock', 'medical_condition', 'sometimes_painful', 'sudden']
senticnet['electric_fan'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'smart_technology', 'cool_moment', 'relax', 'refreshing', 'wind']
senticnet['electric_guitar'] = [0, 0, 0.048, -0.035, '#angry', '#disgusting', -0.028, 'music_play', 'use_party', 'orchestra_play', 'party', 'howler']
senticnet['electric_motor'] = [0.67, -0.912, 0, 0.805, '#surprising', '#admirable', 0.796, 'motor', 'engine', 'stepper', 'stepping_motor', 'machine']
senticnet['electric_pencil_sharpener'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'smart_technology', 'pencil_sharpener', 'office_stuff', 'school_stuff', 'pencil']
senticnet['electric_power'] = [0.704, 0, 0, 0.741, '#joyful', '#admirable', 0.482, 'forceful', 'power_source', 'electrical', 'gas_oil', 'kinetic_energy']
senticnet['electric_razor'] = [0.822, -0.88, 0, 0, '#joyful', '#surprising', 0.567, 'double_edge_razor', 'shampoo_conditioner', 'moistener', 'gel_toothpaste', 'tartar_control_toothpaste']
senticnet['electric_shaver'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'smart_technology', 'electric_toothbrush', 'hair_dryer', 'stay_healthy', 'wash_tooth']
senticnet['electric_shock'] = [-0.987, 0, 0.741, 0, '#sad', '#angry', -0.576, 'tremor', 'thunder', 'tropical_storm', 'hurricane', 'broken_computer']
senticnet['electric_toothbrush'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'smart_technology', 'electric_shaver', 'hair_dryer', 'stay_healthy', 'wash_tooth']
senticnet['electrical'] = [0.88, 0, 0, 0.808, '#joyful', '#admirable', 0.563, 'electric', 'electricity', 'power_source', 'watt', 'volt']
senticnet['electrical_circuit'] = [0.06, 0, 0, 0.059, '#joyful', '#admirable', 0.04, 'traffic_signal', 'mailbox', 'parking_lot', 'hand_luggage', 'message_board']
senticnet['electrical_connection'] = [-0.924, 0, -0.921, 0, '#sad', '#scared', -0.615, 'circuit', 'electricity', 'board', 'glue', 'connection']
senticnet['electrical_phenomenon'] = [-0.828, 0, 0.948, -0.855, '#angry', '#disgusting', -0.877, 'resistance', 'potential', 'reluctance', 'distortion', 'capacity']
senticnet['electrical_unit'] = [-0.769, 0, -0.98, 0, '#sad', '#scared', -0.583, 'electricity', 'ampere', 'up_date', 'relevant', 'contemporary']
senticnet['electricity'] = [0.73, 0, 0, 0.709, '#joyful', '#admirable', 0.48, 'potential_energy', 'watt', 'electrical', 'power_source', 'volt']
senticnet['electrification'] = [0.547, -0.692, 0, 0.52, '#joyful', '#surprising', 0.586, 'vivification', 'invigoration', 'activity', 'animation', 'activating']
senticnet['electrify'] = [0.781, -0.588, 0, 0.721, '#joyful', '#admirable', 0.697, 'turn_on', 'rouse', 'charge', 'agitate', 'excite']
senticnet['electrifying'] = [0.727, 0.774, 0, 0, '#joyful', '#interesting', 0.5, 'thrilling', 'scandalmongering', 'sensationalistic', 'sensational', 'sensationally']
senticnet['electrocution'] = [0, 0, -0.73, -0.779, '#scared', '#disgusting', -0.503, 'electric_current', 'startle', 'make_angry', 'sadness', 'disappointment']
senticnet['electromagnetic_radiation'] = [-0.873, -0.794, 0.729, -0.976, '#sad', '#disgusting', -0.595, 'radiation', 'cancer', 'sickness', 'potential_danger', 'x_ray']
senticnet['electromagnetic_wave'] = [0.023, 0, 0, 0.119, '#joyful', '#admirable', 0.047, 'decibel', 'vibration', 'loudness', 'electromagnetic_radiation', 'audio']
senticnet['electron'] = [0, 0, 0, 0.101, '#admirable', '#admirable', 0.034, 'elementary_particle', 'neutron', 'proton_neutron', 'subatomic_particle', 'proton']
senticnet['electron_radiation'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'alpha_radiation', 'alpha_ray', 'beta_radiation', 'beta_ray', 'ionizing_radiation']
senticnet['electronics'] = [0.101, 0.099, 0, 0.169, '#joyful', '#admirable', 0.123, 'family_home', 'apartment', 'renovation', 'kitchen', 'appliance_store']
senticnet['electronics_device'] = [0.67, -0.912, 0, 0.805, '#surprising', '#admirable', 0.796, 'sightsee', 'camera', 'charge_battery', 'see_countryside', 'go_to_another_place']
senticnet['electropositive'] = [0.626, -0.603, 0, 0.769, '#joyful', '#admirable', 0.666, 'positive', 'charged', 'positively_charged', 'live', 'polar']
senticnet['elegance'] = [0.639, -0.701, 0, 0.507, '#joyful', '#surprising', 0.616, 'tastefulness', 'daintiness', 'eclat', 'breeding', 'genteelness']
senticnet['elegant'] = [0.927, 0, 0, 0, '#joyful', '#joyful', 0.309, 'pretty', 'beautiful', 'sophisticated', 'nice_look', 'lovely']
senticnet['elegist'] = [0.836, -0.602, 0, 0.845, '#joyful', '#admirable', 0.761, 'poetess', 'bard', 'poet', 'odist', 'poet_laureate']
senticnet['element'] = [0, 0, -0.973, 0, '#scared', '#scared', -0.324, 'iodine', 'lithium', 'uranium', 'arsenic', 'manganese']
senticnet['elementary'] = [0.769, 0.98, 0, 0, '#joyful', '#interesting', 0.583, 'simple', 'uncomplicated', 'unproblematic', 'basic', 'primary']
senticnet['elementary_particle'] = [0, 0, 0, 0.122, '#admirable', '#admirable', 0.041, 'lepton', 'subatomic_particle', 'electron', 'neutron', 'particle']
senticnet['elementary_school'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'laboratory', 'student_place', 'science_class', 'educational_institution', 'professor_office']
senticnet['elements'] = [0.03, 0, 0.021, 0.065, '#joyful', '#admirable', 0.025, 'hard_rock', 'strong_material', 'silver', 'magnetic', 'tin_aluminium']
senticnet['elephant_sit_chest'] = [-0.044, 0, -0.066, -0.063, '#scared', '#disgusting', -0.058, 'kill_people', 'suffocate', 'stab', 'destroy_live', 'parry']
senticnet['elevate'] = [0, 0.773, 0, 0, '#interesting', '#interesting', 0.258, 'pull_up', 'go_up', 'move_upward', 'rise_up', 'move_up']
senticnet['elevation'] = [0.039, 0.152, 0, 0.157, '#interesting', '#admirable', 0.116, 'up_hill', 'up_mountain', 'steep', 'downward', 'knoll']
senticnet['elevator'] = [0.064, 0.07, 0, 0, '#joyful', '#interesting', 0.045, 'top_floor', 'front_desk', 'concierge', 'exit', 'ground_floor']
senticnet['elf'] = [0, -0.032, -0.057, -0.121, '#scared', '#disgusting', -0.049, 'gnome', 'dwarf', 'goblin', 'undersized', 'small_person']
senticnet['elfish'] = [0.582, -0.783, 0, 0.795, '#surprising', '#admirable', 0.72, 'playful', 'elvish', 'kittenish', 'frisky', 'sportive']
senticnet['elicit'] = [0.722, -0.764, 0, 0.946, '#surprising', '#admirable', 0.811, 'arouse', 'ask_for', 'enkindle', 'kindle', 'evoke']
senticnet['eligible'] = [0.866, -0.528, 0, 0.529, '#joyful', '#admirable', 0.641, 'worthy', 'desirable', 'suitable', 'bailable', 'entitled']
senticnet['eliminate'] = [-0.104, 0, -0.117, -0.047, '#sad', '#scared', -0.089, 'terminate', 'violent_action', 'destruction', 'demolish', 'take_life']
senticnet['eliminate_garbage'] = [0.67, -0.912, 0, 0.805, '#surprising', '#admirable', 0.796, 'burn_garbage', 'incinerator', 'incinerate_waste', 'dump', 'garbage_dump']
senticnet['elimination'] = [0.992, -0.808, 0, 0.584, '#joyful', '#surprising', 0.795, 'enuresis', 'urinary_incontinence', 'incontinence', 'evacuation', 'excretion']
senticnet['elisir'] = [0.107, 0.11, -0.084, 0.21, '#interesting', '#admirable', 0.114, 'live_healthy_life', 'forever_young', 'live_forever', 'live_long', 'live_good_life']
senticnet['elite'] = [0.594, -0.735, 0, 0.909, '#surprising', '#admirable', 0.746, 'intelligentsia', 'clerisy', 'nobility', 'elect', 'aristocracy']
senticnet['elite_group'] = [0.936, -0.753, 0, 0.538, '#joyful', '#surprising', 0.742, 'intelligentsia', 'clerisy', 'nobility', 'elect', 'aristocracy']
senticnet['elitist'] = [0.922, -0.949, 0, 0.965, '#surprising', '#admirable', 0.945, 'utilitarian', 'egalitarian', 'equalitarian', 'moralist', 'philosopher']
senticnet['elixir'] = [-0.552, 0, 0.5, -0.554, '#sad', '#disgusting', -0.535, 'remedy', 'cure', 'catholicon', 'therapeutic', 'curative']
senticnet['ell'] = [-0.027, 0.163, -0.1, 0.138, '#interesting', '#admirable', 0.058, 'eternal', 'no_end', 'hot_weather', 'general_time', 'common_practice']
senticnet['elliptic_leaf'] = [-0.803, 0, 0, -0.981, '#sad', '#disgusting', -0.595, 'lyrate_leaf', 'needle', 'simple_leaf', 'hastate_leaf', 'obovate_leaf']
senticnet['elliptical'] = [0, 0, -0.929, -0.823, '#scared', '#disgusting', -0.584, 'egg-shaped', 'oval', 'ovate', 'ovoid', 'prolate']
senticnet['elm'] = [0.034, 0, 0, 0.067, '#joyful', '#admirable', 0.034, 'cedar', 'willow', 'tree', 'oak', 'pine']
senticnet['elocute'] = [0.584, -0.938, 0, 0.927, '#surprising', '#admirable', 0.816, 'declaim', 'scan', 'execute', 'perorate', 'perform']
senticnet['elongate'] = [-0.036, 0.152, 0, 0.23, '#interesting', '#admirable', 0.115, 'elongation', 'grow_long', 'elasticity', 'widen', 'rubbery']
senticnet['elongation'] = [-0.034, 0.169, -0.071, 0.218, '#interesting', '#admirable', 0.094, 'elongate', 'elasticity', 'extension', 'grow_long', 'widen']
senticnet['eloquent'] = [0, 0, -0.712, -0.751, '#scared', '#disgusting', -0.488, 'facile', 'silver', 'smooth-spoken', 'fluent', 'silver-tongued']
senticnet['elsewhere'] = [0.031, 0.149, 0, 0.137, '#interesting', '#admirable', 0.106, 'holiday', 'overseas', 'destination', 'location', 'abroad']
senticnet['elucidate'] = [0.548, -0.867, 0, 0.938, '#surprising', '#admirable', 0.784, 'elaborate', 'clear', 'crystallize', 'clear_up', 'make_clear']
senticnet['elusive'] = [0.273, 0.226, -0.139, 0.332, '#joyful', '#admirable', 0.231, 'morality', 'good', 'uncommon', 'like_candy', 'capitalize']
senticnet['elusiveness'] = [-0.587, 0, 0.871, -0.705, '#angry', '#disgusting', -0.721, 'unclearness', 'inexplicitness', 'ambiguity', 'equivocalness', 'vagueness']
senticnet['elvish'] = [0.582, -0.783, 0, 0.795, '#surprising', '#admirable', 0.72, 'elfish', 'playful', 'kittenish', 'frisky', 'sportive']
senticnet['emac'] = [0, 0, 0, 0.091, '#admirable', '#admirable', 0.03, 'door', 'glass_front', 'doorway', 'entranceway', 'gate']
senticnet['emaciated'] = [0, 0, -0.733, -0.729, '#scared', '#disgusting', -0.487, 'bony', 'gaunt', 'waste', 'macerate', 'cadaverous']
senticnet['email'] = [0, 0.179, 0, 0.283, '#interesting', '#admirable', 0.154, 'retort', 'answer_back', 'write_back', 'feedback', 'response']
senticnet['email_program'] = [-0.056, 0.16, -0.045, 0.276, '#interesting', '#admirable', 0.112, 'swap', 'give_take', 'barter', 'exchange_goods', 'transaction']
senticnet['emancipation'] = [0.929, 0.909, 0, 0, '#joyful', '#interesting', 0.613, 'servant', 'accomplice', 'honor', 'alchemist', 'noble']
senticnet['emasculate'] = [-0.785, 0, 0.91, -0.917, '#angry', '#disgusting', -0.871, 'castrate', 'neuter', 'alter', 'desex', 'spay']
senticnet['emasculated'] = [0.945, -0.861, 0, 0.802, '#joyful', '#surprising', 0.869, 'cut', 'altered', 'neutered', 'castrated', 'gelded']
senticnet['embarass'] = [-0.964, 0, 0, -0.715, '#sad', '#disgusting', -0.56, 'become_red', 'uncomfortable_situation', 'bad_experience', 'embarrass_oneself', 'provocative_discussion']
senticnet['embarassament'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'embarrass', 'embarrassed', 'embarrassing', 'embarrassingly', 'blush']
senticnet['embarrass'] = [-0.769, 0, 0.923, -0.968, '#angry', '#disgusting', -0.887, 'uneasiness', 'distressed', 'confused', 'discombobulation', 'confusing']
senticnet['embarrass_oneself'] = [-0.964, 0, 0, -0.715, '#sad', '#disgusting', -0.56, 'become_red', 'uncomfortable_situation', 'bad_experience', 'embarass', 'provocative_discussion']
senticnet['embarrassed'] = [-0.754, 0, -0.748, 0, '#sad', '#scared', -0.501, 'chagrin', 'abase', 'mortify', 'chagrined', 'abashed']
senticnet['embarrassing'] = [-0.779, 0, -0.888, 0, '#sad', '#scared', -0.556, 'awkward', 'abash', 'unenviable', 'embarrassingly', 'sheepish']
senticnet['embarrassingly'] = [-0.886, 0, -0.771, 0, '#sad', '#scared', -0.552, 'awkward', 'abash', 'unenviable', 'embarrassing', 'sheepish']
senticnet['embarrassment'] = [-0.562, 0.288, -0.319, -0.242, '#sad', '#scared', -0.278, 'nervousness', 'shame', 'angst', 'upset', 'nervous']
senticnet['embassy'] = [0.054, 0.07, 0, 0.09, '#interesting', '#admirable', 0.071, 'lawyer_office', 'office', 'government_agency', 'workplace', 'desk']
senticnet['embattled'] = [0.801, -0.575, 0, 0.947, '#joyful', '#admirable', 0.774, 'precooked', 'equipped', 'fitted_out', 'prepared', 'fortified']
senticnet['embed'] = [0.867, -0.846, 0, 0.876, '#joyful', '#admirable', 0.863, 'meet', 'team', 'team_up', 'aggroup', 'gang']
senticnet['embellish'] = [0.921, -0.904, 0, 0.608, '#joyful', '#surprising', 0.811, 'overstate', 'hyperbolize', 'glorify', 'exaggerate', 'overdraw']
senticnet['embellished'] = [0, 0, 0.869, -0.917, '#angry', '#disgusting', -0.595, 'embroider', 'pad', 'lard', 'aggrandize', 'blow_up']
senticnet['embezzlement'] = [-0.518, 0, 0.717, -0.758, '#angry', '#disgusting', -0.664, 'raid', 'thieving', 'plunderage', 'larceny', 'theft']
senticnet['emblem'] = [0, 0.077, 0, 0.091, '#interesting', '#admirable', 0.056, 'banner', 'infrastructure', 'star_stripe', 'logo', 'symbol']
senticnet['embodiment'] = [0.693, -0.529, 0, 0.82, '#joyful', '#admirable', 0.681, 'concrete_representation', 'shape', 'representation', 'mental_representation', 'internal_representation']
senticnet['embolden'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerfully', 'cheerful', 'jolly_up', 'hearten', 'chirk_up']
senticnet['embonpoint'] = [-0.728, 0, 0.973, -0.579, '#sad', '#angry', -0.76, 'exogenous_obesity', 'blubber', 'fat', 'corpulency', 'stoutness']
senticnet['embrace'] = [0.755, 0.972, 0, 0.775, '#interesting', '#admirable', 0.834, 'grasp', 'grab', 'hold', 'sensual', 'grip']
senticnet['embracement'] = [0.995, -0.698, 0, 0.528, '#joyful', '#surprising', 0.74, 'grasp', 'hug', 'nestle', 'snuggle', 'grip']
senticnet['embracing'] = [0.828, -0.966, 0, 0.644, '#joyful', '#surprising', 0.813, 'grasp', 'hug', 'nestle', 'snuggle', 'grip']
senticnet['embroider'] = [0.785, -0.57, 0, 0.911, '#joyful', '#admirable', 0.755, 'beautify', 'embellish', 'decorate', 'adorn', 'grace']
senticnet['embroidery'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'use_needle', 'seam', 'needlework', 'needle_thread', 'mend']
senticnet['embryo'] = [0, 0.067, 0, 0.07, '#interesting', '#admirable', 0.046, 'peck', 'bushel', 'chicken_egg', 'ovum', 'egg']
senticnet['emended'] = [-0.623, 0, 0.657, -0.955, '#angry', '#disgusting', -0.745, 'paraphrastic', 'adjusted', 'changed', 'altered', 'edited']
senticnet['emerald'] = [0.418, 0.103, 0, 0.373, '#joyful', '#admirable', 0.298, 'bloodstone', 'turquoise', 'sapphire', 'ruby', 'jade']
senticnet['emerge'] = [0, 0, -0.96, -0.998, '#scared', '#disgusting', -0.653, 'egress', 'go_forth', 'issue', 'come_out', 'come_forth']
senticnet['emergence'] = [0.836, -0.832, 0, 0.511, '#joyful', '#surprising', 0.726, 'issue', 'start', 'casus_belli', 'beginning', 'egress']
senticnet['emergency'] = [0, 0, -0.823, 0, '#scared', '#scared', -0.274, 'sickness', 'polio', 'malady', 'ailment', 'treatment']
senticnet['emergency_brake'] = [0, -0.057, 0, 0.05, '#surprising', '#admirable', 0.036, 'fan_belt', 'brake_pedal', 'air_vent', 'headlight', 'dynamo']
senticnet['emergency_procedure'] = [0.67, -0.912, 0, 0.805, '#surprising', '#admirable', 0.796, 'artificial_respiration', 'emergency', 'external_respiration', 'respiration', 'ventilation']
senticnet['emergency_room'] = [0, 0, -0.73, 0, '#scared', '#scared', -0.243, 'clinic', 'emergency_ward', 'hospital', 'dentist_office', 'medical_office']
senticnet['emergency_situation'] = [-0.891, 0.168, -0.609, 0.05, '#sad', '#scared', -0.427, 'emergency', 'urgency', 'urgent', 'needful', 'alarm']
senticnet['emergency_ward'] = [-0.027, 0.066, -0.15, -0.143, '#scared', '#disgusting', -0.085, 'emergency_room', 'dentist_office', 'clinic', 'therapist', 'doctor_examination_room']
senticnet['emetic'] = [-0.62, 0, 0.983, -0.897, '#angry', '#disgusting', -0.833, 'remedy', 'cure', 'therapeutic', 'curative', 'ipecac']
senticnet['eminence'] = [0.594, -0.688, 0, 0.957, '#surprising', '#admirable', 0.746, 'prehigh_status', 'high_status', 'senior_status', 'higher_status', 'higher_rank']
senticnet['emission'] = [-0.027, -0.051, -0.058, -0.055, '#scared', '#disgusting', -0.03, 'motor_oil', 'make_toy', 'engine', 'castor', 'bristle']
senticnet['emit_light'] = [0, -0.028, -0.061, -0.093, '#scared', '#disgusting', -0.042, 'burn_house', 'die_out', 'extinguish', 'warm_house', 'find_campsite']
senticnet['emollient'] = [0, 0, -0.79, -0.951, '#scared', '#disgusting', -0.58, 'ointment', 'demulcent', 'softening', 'salving', 'cream']
senticnet['emote'] = [0.765, 0, 0, 0.721, '#joyful', '#admirable', 0.495, 'act', 'do_something', 'stage_play', 'play_role', 'part_of_play']
senticnet['emotion'] = [0.708, -0.608, 0, 0.661, '#joyful', '#admirable', 0.659, 'love', 'conditioned_emotional_response', 'conditioned_emotion', 'fright', 'reverence']
senticnet['emotional'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'emotional_response', 'emotional_reaction', 'sentimental', 'sensitive', 'passionate']
senticnet['emotional_arousal'] = [0.705, -0.933, 0, 0.89, '#surprising', '#admirable', 0.843, 'fervor', 'excitation', 'excitement', 'arousal', 'anger']
senticnet['emotional_disorder'] = [-0.905, 0, 0.546, -0.757, '#sad', '#disgusting', -0.736, 'manic_disorder', 'bipolar_disorder', 'manic_depression', 'manic_depressive_illness', 'depression']
senticnet['emotional_distress'] = [-0.71, 0, -0.759, -0.907, '#scared', '#disgusting', -0.792, 'convent', 'monastery', 'capital_build', 'confession', 'synagogue']
senticnet['emotional_disturbance'] = [-0.892, 0, 0.669, -0.726, '#sad', '#disgusting', -0.762, 'manic_disorder', 'bipolar_disorder', 'manic_depression', 'manic_depressive_illness', 'depression']
senticnet['emotional_guy'] = [-0.102, 0, 0, 0, '#sad', '#sad', -0.034, 'sensitive_skin', 'sensitive_teeth', 'weak', 'sensitive', 'sensitivity']
senticnet['emotional_pain'] = [-0.221, -0.003, -0.216, -0.262, '#sad', '#disgusting', -0.232, 'embarrassment', 'feel_hurt', 'feel_sad', 'cry', 'psychoneurosis']
senticnet['emotional_person'] = [0.853, -0.876, 0, 0.973, '#surprising', '#admirable', 0.901, 'captive', 'mortal', 'spitfire', 'person', 'individual']
senticnet['emotional_reaction'] = [0, -0.064, -0.142, -0.143, '#scared', '#disgusting', -0.074, 'laughter', 'emotional_response', 'cry', 'make_others_laugh', 'giggle']
senticnet['emotional_response'] = [-0.056, 0, -0.135, -0.051, '#sad', '#scared', -0.081, 'emotional_reaction', 'hear_joke', 'blank_stare', 'illogical', 'see_funny']
senticnet['emotionalism'] = [0.783, -0.536, 0, 0.937, '#joyful', '#admirable', 0.752, 'passion', 'affectionateness', 'drama', 'lovingness', 'fondness']
senticnet['emotionality'] = [0.681, -0.665, 0, 0.858, '#joyful', '#admirable', 0.735, 'passion', 'affectionateness', 'drama', 'lovingness', 'fondness']
senticnet['emotionless'] = [-0.612, 0, 0.572, -0.839, '#sad', '#disgusting', -0.674, 'numb', 'benumbed', 'anesthetic', 'insensible', 'asleep']
senticnet['emotionlessness'] = [-0.773, 0, -0.727, 0, '#sad', '#scared', -0.5, 'impassiveness', 'impassivity', 'apathetically', 'unemotionality', 'stolidity']
senticnet['emotive'] = [0.461, 0.674, -0.262, 0.247, '#joyful', '#interesting', 0.373, 'affectionateness', 'warmness', 'philia', 'affectional', 'affective']
senticnet['empathetic'] = [0.881, 0.759, 0, 0, '#joyful', '#interesting', 0.547, 'empathic', 'sympathetically', 'empathetically', 'kindhearted', 'empathy']
senticnet['empathetically'] = [0.724, 0.974, 0, 0, '#joyful', '#interesting', 0.566, 'sympathetically', 'empathic', 'empathetic', 'kind', 'kindheartedness']
senticnet['empathic'] = [0.96, 0.835, 0, 0, '#joyful', '#interesting', 0.598, 'empathetic', 'sympathetically', 'empathetically', 'kindhearted', 'kind']
senticnet['empathize'] = [0.8, 0.779, 0, 0, '#joyful', '#interesting', 0.526, 'empathy', 'end_conversation', 'find_out_wrong', 'cheer_up', 'share_feeling']
senticnet['empathy'] = [0.973, 0, 0, 0.866, '#joyful', '#admirable', 0.613, 'empathize', 'sympathy', 'end_conversation', 'want_badly', 'human_emotion']
senticnet['emperor'] = [0.054, 0.068, 0, 0.068, '#interesting', '#admirable', 0.063, 'royal_leader', 'monarch', 'king', 'duchess', 'despot']
senticnet['emphasize'] = [0.739, -0.764, 0, 0.977, '#surprising', '#admirable', 0.827, 'accent', 'stress', 'wave_off', 'play_down', 'punctuate']
senticnet['empire'] = [0, 0.173, -0.067, 0.126, '#interesting', '#admirable', 0.077, 'democracy', 'amendment', 'realm', 'unite', 'international']
senticnet['emplace'] = [0.619, -0.628, 0, 0.693, '#surprising', '#admirable', 0.647, 'set', 'pose', 'lay', 'put', 'place']
senticnet['employ'] = [0.926, 0.714, 0, 0, '#joyful', '#interesting', 0.547, 'police_work', 'career', 'task', 'employment', 'labor']
senticnet['employee'] = [0.046, 0.099, -0.054, 0.067, '#interesting', '#admirable', 0.053, 'vocation', 'secretary', 'public_servant', 'tradesman', 'worker']
senticnet['employer'] = [0.071, 0.151, 0, 0.16, '#interesting', '#admirable', 0.127, 'business_organization', 'large_business', 'partnership', 'business_firm', 'boss']
senticnet['employment'] = [0.85, 0, 0, 0, '#joyful', '#joyful', 0.283, 'task', 'labor', 'police_work', 'employ', 'career']
senticnet['emporium'] = [0.041, 0.098, 0, 0, '#joyful', '#interesting', 0.046, 'utopia', 'java', 'memorial', 'nowhere', 'coffee']
senticnet['empower'] = [0.558, -0.518, 0, 0.901, '#joyful', '#admirable', 0.659, 'gift', 'change', 'enable', 'invest', 'endow']
senticnet['emptiness'] = [-0.914, 0, -0.772, -0.757, '#sad', '#scared', -0.814, 'void', 'star_planet', 'nothingness', 'outer', 'around_earth']
senticnet['empty'] = [-0.026, -0.02, -0.08, 0, '#sad', '#scared', -0.029, 'empty_glass', 'empty_space', 'worthless', 'empty_stomach', 'universe']
senticnet['empty_bladder'] = [-0.035, 0, -0.087, 0, '#sad', '#scared', -0.041, 'urinate', 'pee', 'know_re_healthy', 'soak_hotspring', 'get_front_line']
senticnet['empty_bottle'] = [-0.873, -0.794, 0.729, -0.976, '#sad', '#disgusting', -0.595, 'empty', 'garbage', 'bottle', 'empty_glass', 'thirsty']
senticnet['empty_glass'] = [-0.614, 0, 0.738, -0.803, '#angry', '#disgusting', -0.718, 'empty', 'empty_space', 'a_lot_of_space', 'empty_stomach', 'universe']
senticnet['empty_house'] = [-0.614, 0, 0.738, -0.803, '#angry', '#disgusting', -0.718, 'empty_room', 'empty_space', 'empty', 'vacnat', 'aimless']
senticnet['empty_land'] = [-0.776, 0, 0, -0.759, '#sad', '#disgusting', -0.512, 'floss', 'station_wagon', 'land', 'plane_land', 'national']
senticnet['empty_place'] = [0, 0.086, 0.046, 0.133, '#interesting', '#admirable', 0.058, 'house_place', 'empty', 'house_location', 'inside_build', 'land_measurement']
senticnet['empty_pocket'] = [-0.873, -0.794, 0.729, -0.976, '#sad', '#disgusting', -0.595, 'bankruptcy', 'lost_money', 'cashless', 'hobo', 'debt']
senticnet['empty_room'] = [0, 0.09, 0, 0.066, '#interesting', '#admirable', 0.052, 'no_color', 'above_earth', 'without_light', 'limitless', 'outer']
senticnet['empty_space'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'empty_room', 'a_lot_of_space', 'empty', 'empty_house', 'universe']
senticnet['empty_stomach'] = [-0.614, 0, 0.738, -0.803, '#angry', '#disgusting', -0.718, 'empty_glass', 'empty_space', 'a_lot_of_space', 'empty', 'universe']
senticnet['empty_talk'] = [0.89, -0.734, 0, 0.877, '#joyful', '#admirable', 0.834, 'nonsense', 'meaninglessness', 'bunk', 'nonsensicality', 'hokum']
senticnet['empty_words'] = [0.55, -0.58, 0, 0.552, '#surprising', '#admirable', 0.561, 'nonsense', 'meaninglessness', 'bunk', 'nonsensicality', 'hokum']
senticnet['empyreal'] = [-0.838, 0, 0.896, -0.959, '#angry', '#disgusting', -0.898, 'storied', 'incandescent', 'historied', 'divine', 'glorious']
senticnet['emulator'] = [-0.836, 0, 0.584, -0.688, '#sad', '#disgusting', -0.703, 'epigone', 'epigon', 'parrot', 'mortal', 'person']
senticnet['enable'] = [0.558, -0.518, 0, 0.901, '#joyful', '#admirable', 0.659, 'gift', 'change', 'empower', 'invest', 'endow']
senticnet['enamor'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['enamoredness'] = [0.531, 0.673, -0.276, 0.275, '#joyful', '#interesting', 0.401, 'amorous', 'amorousness', 'amatory', 'amative', 'puppy_love']
senticnet['encephalopathy'] = [-0.738, 0, 0.955, -0.547, '#sad', '#angry', -0.747, 'visual_agnosia', 'auditory_agnosia', 'brain_disorder', 'agnosia', 'brain_disease']
senticnet['enchant'] = [0.894, 0, 0, 0.924, '#joyful', '#admirable', 0.606, 'nigh', 'belonging', 'comfortably', 'solace', 'comfortableness']
senticnet['enchanted'] = [0.998, -0.75, 0, 0.695, '#joyful', '#surprising', 0.814, 'bewitched', 'ensorcelled', 'fascinated', 'hypnotized', 'mesmerized']
senticnet['enchanter'] = [0.594, -0.549, 0, 0.518, '#joyful', '#surprising', 0.554, 'exorcist', 'necromancer', 'magus', 'sorceress', 'witch_doctor']
senticnet['enchanting'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['enchantment'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['enchondroma'] = [-0.704, 0, 0.639, -0.56, '#sad', '#angry', -0.634, 'fibroma', 'adenoma', 'chondroma', 'benign_tumor', 'myoma']
senticnet['enclose'] = [0.783, -0.936, 0, 0.585, '#joyful', '#surprising', 0.768, 'benight', 'engulf', 'hide', 'tube', 'capsule']
senticnet['enclothe'] = [-0.635, 0, 0.694, -0.997, '#angry', '#disgusting', -0.775, 'raiment', 'garb', 'dress', 'clothe', 'overclothe']
senticnet['encomiastic'] = [0.722, -0.981, 0, 0.832, '#surprising', '#admirable', 0.845, 'laudatory', 'praiseful', 'praising', 'complimentary', 'eulogistic']
senticnet['encompass'] = [0.077, 0.219, -0.074, 0.293, '#interesting', '#admirable', 0.172, 'include', 'comparative', 'totality', 'cover', 'inclusion']
senticnet['encopresis'] = [-0.525, 0, 0.839, -0.865, '#angry', '#disgusting', -0.743, 'folie', 'upset', 'psychosomatic_disorder', 'conversion_disorder', 'conversion_reaction']
senticnet['encore'] = [0.753, 0, 0, 0.749, '#joyful', '#admirable', 0.501, 'favorite', 'crowd', 'acclamation', 'bunch', 'large_crowd']
senticnet['encounter'] = [0.879, 0, 0, 0.868, '#joyful', '#admirable', 0.582, 'meeting', 'meet', 'match', 'bout', 'round']
senticnet['encourage'] = [0, 0.974, 0, 0.708, '#interesting', '#admirable', 0.561, 'grateful', 'exuberance', 'enthusiasm', 'thankful', 'joyful']
senticnet['encouraged'] = [0.485, 0.672, -0.261, 0.255, '#joyful', '#interesting', 0.384, 'bucked_up', 'encouragingly', 'encouraging', 'optimistic', 'optimistically']
senticnet['encouragement'] = [0.531, 0.658, -0.265, 0.346, '#joyful', '#interesting', 0.423, 'confident', 'fascinate', 'adoration', 'esteem', 'thankful']
senticnet['encouraging'] = [0.485, 0.672, -0.261, 0.255, '#joyful', '#interesting', 0.384, 'bucked_up', 'encouraged', 'encouragingly', 'optimistic', 'optimistically']
senticnet['encouragingly'] = [0.485, 0.672, -0.261, 0.255, '#joyful', '#interesting', 0.384, 'bucked_up', 'encouraged', 'encouraging', 'optimistic', 'optimistically']
senticnet['encroach_upon'] = [-0.935, 0, 0.77, -0.666, '#sad', '#angry', -0.79, 'raid', 'come_in', 'foray_into', 'enter', 'get_into']
senticnet['encroachment'] = [-0.698, 0, 0.752, -0.82, '#angry', '#disgusting', -0.757, 'usurpation', 'trespass', 'inroad', 'intrusion', 'violation']
senticnet['enculturation'] = [0.902, -0.5, 0, 0.716, '#joyful', '#admirable', 0.706, 'breeding', 'fostering', 'fosterage', 'cultivation', 'bringing_up']
senticnet['encumbrance'] = [-0.877, 0, 0.984, -0.779, '#sad', '#angry', -0.88, 'vexation', 'dead_weight', 'imposition', 'worry', 'concern']
senticnet['encyclopaedia'] = [0, -0.171, -0.046, 0.091, '#surprising', '#admirable', 0.072, 'comic_book', 'child_book', 'children_story', 'comic', 'disney_cartoon']
senticnet['end'] = [-0.055, 0.192, -0.113, 0.16, '#interesting', '#admirable', 0.061, 'finish_complete', 'end_point', 'conclusion', 'omega', 'reason_why']
senticnet['end_argument'] = [0.873, 0.942, 0, 0.907, '#interesting', '#admirable', 0.907, 'better_person', 'demand', 'give_help', 'part_of_way', 'feel_strongly']
senticnet['end_book'] = [-0.056, 0.084, 0, 0.062, '#interesting', '#admirable', 0.03, 'book_magazine', 'thesaurus', 'book_library', 'book_poetry', 'book_genre']
senticnet['end_class'] = [-0.097, 0, 0, 0, '#sad', '#sad', -0.032, 'get_qualification', 'prove_learn', 'prove_knowledge', 'complete_course', 'get_grade']
senticnet['end_conversation'] = [0.074, 0.187, -0.147, 0.195, '#interesting', '#admirable', 0.103, 'ask_name', 'empathize', 'make_eye_contact', 'empathy', 'attentive']
senticnet['end_day'] = [0.101, -0.237, 0.031, 0.105, '#surprising', '#admirable', 0.137, 'finish_work', 'go_home', 'relax_time', 'go_to_sleep', 'meet_family']
senticnet['end_game'] = [0.053, 0.264, -0.119, 0.23, '#interesting', '#admirable', 0.143, 'strategize', 'win', 'learn_rule', 'act_smart', 'follow_rule']
senticnet['end_happily'] = [-0.027, 0.118, -0.097, 0.207, '#interesting', '#admirable', 0.067, 'kiss', 'love_another', 'love_else', 'commit', 'flirt']
senticnet['end_life'] = [-0.965, 0, -0.9, -0.734, '#sad', '#scared', -0.866, 'religious_fundamentalist', 'death', 'get_killed', 'dead', 'kill_self']
senticnet['end_live'] = [-0.734, 0, -0.915, 0, '#sad', '#scared', -0.55, 'get_rid_of_enemy', 'hurt_others', 'murder', 'self_defense', 'death_destruction']
senticnet['end_marriage'] = [-0.472, 0.106, -0.324, -0.036, '#sad', '#scared', -0.242, 'go_jail', 'feel_guilty', 'end_relationship', 'arrest', 'correct_behavior']
senticnet['end_of_life'] = [-0.973, 0, 0.061, -0.908, '#sad', '#disgusting', -0.647, 'die_person', 'pass_away', 'death', 'stop_living', 'lose_life']
senticnet['end_point'] = [0, 0.221, -0.048, 0.223, '#interesting', '#admirable', 0.132, 'reason_why', 'finish_complete', 'commence', 'end', 'done']
senticnet['end_relationship'] = [-0.794, 0, -0.768, -0.977, '#sad', '#disgusting', -0.846, 'put_box', 'feel_bad', 'cry_help', 'feel_stupid', 'learn_lesson']
senticnet['end_semester'] = [0.034, 0.252, -0.137, 0.277, '#interesting', '#admirable', 0.142, 'scholar', 'professor', 'pupil', 'college_student', 'want_pass_class']
senticnet['end_sentence'] = [0, 0, 0, -0.07, '#disgusting', '#disgusting', -0.023, 'term', 'semester', 'period', 'stop_talking', 'second']
senticnet['end_soon'] = [0.101, -0.237, 0.031, 0.105, '#surprising', '#admirable', 0.137, 'temporary', 'end_day', 'finish_work', 'finish_stress_moment', 'end']
senticnet['end_war'] = [0.852, 0, 0, 0, '#joyful', '#joyful', 0.284, 'transmit_disease', 'sometimes_bad', 'gain_power', 'protect_family', 'rape']
senticnet['end_world'] = [-0.961, 0, -0.72, -0.849, '#sad', '#disgusting', -0.843, 'break_law', 'old_age', 'protect_family', 'protect_oneself', 'kill_man']
senticnet['endanger'] = [-0.798, 0, 0, -0.928, '#sad', '#disgusting', -0.575, 'bottle_without_cap', 'insure', 'hazard', 'type_of_credit_card', 'risky']
senticnet['endangered'] = [-0.104, -0.032, 0.057, -0.052, '#sad', '#angry', -0.06, 'animal_skin', 'striped', 'animal_hide', 'animal_fur', 'animal_pelt']
senticnet['endangered_species'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'panda', 'hunting', 'air_pollution', 'global_warming', 'sea_pollution']
senticnet['endangerment'] = [0.565, -0.766, 0, 0.982, '#surprising', '#admirable', 0.771, 'risk', 'hazard', 'jeopardy', 'health_hazard', 'peril']
senticnet['endearing'] = [0.936, -0.815, 0, 0.83, '#joyful', '#admirable', 0.86, 'cherubic', 'lovely', 'adorable', 'lovable', 'angelic']
senticnet['endearingly'] = [0.494, 0.673, -0.269, 0.25, '#joyful', '#interesting', 0.383, 'adorably', 'loving', 'lovingly', 'fondly', 'devotedness']
senticnet['endeavor'] = [0.842, -0.731, 0, 0.662, '#joyful', '#surprising', 0.745, 'labor', 'racket', 'forlorn_hope', 'fraudulent_scheme', 'business_activity']
senticnet['ended'] = [-0.933, 0, -0.971, 0, '#sad', '#scared', -0.635, 'complete_task', 'completed', 'finish_job', 'complete_job', 'wrapped_up']
senticnet['endemic_typhus'] = [-0.973, 0, 0.061, -0.908, '#sad', '#disgusting', -0.647, 'murine_typhus', 'rat_typhus', 'urban_typhus', 'typhus', 'rickettsial_disease']
senticnet['ending'] = [-0.848, 0, 0.744, -0.581, '#sad', '#angry', -0.724, 'subversion', 'subversive_activity', 'termination', 'overthrow', 'conclusion']
senticnet['endive'] = [0.636, -0.796, 0, 0.552, '#joyful', '#surprising', 0.661, 'lettuce', 'salad_green', 'green', 'curly_salad_green', 'food']
senticnet['endless'] = [0.921, 0.85, 0, 0, '#joyful', '#interesting', 0.59, 'unending', 'never_end', 'everlasting', 'absolute', 'previous']
senticnet['endocarditis'] = [-0.548, 0, 0.67, -0.926, '#angry', '#disgusting', -0.715, 'pericarditis', 'rubor', 'redness', 'carditis', 'inflammation']
senticnet['endocrine'] = [0.672, -0.552, 0, 0.992, '#joyful', '#admirable', 0.739, 'pressor', 'hormone', 'adrenalin', 'internal_secretion', 'catecholamine']
senticnet['endorse'] = [0.8, 0.759, 0, 0.957, '#joyful', '#admirable', 0.839, 'recommend', 'acclaim', 'stimulate_mind', 'acculturation', 'support']
senticnet['endorser'] = [0.814, -0.508, 0, 0.622, '#joyful', '#admirable', 0.648, 'friend', 'champion', 'supporter', 'protagonist', 'admirer']
senticnet['endoscope'] = [0.255, 0.182, -0.06, 0.314, '#joyful', '#admirable', 0.23, 'doctor_office', 'urethroscope', 'sigmoidoscope', 'hospital', 'check_health']
senticnet['endow'] = [0.558, -0.518, 0, 0.901, '#joyful', '#admirable', 0.659, 'gift', 'change', 'empower', 'invest', 'enable']
senticnet['endowment'] = [0.608, -0.55, 0, 0.726, '#joyful', '#admirable', 0.628, 'genius', 'raw_talent', 'flair', 'bent', 'knack']
senticnet['endurable'] = [0.525, -0.799, 0, 0.593, '#surprising', '#admirable', 0.639, 'tolerant', 'resistant', 'bearable', 'tolerable', 'sufferable']
senticnet['endurance'] = [0.989, -0.806, 0, 0.569, '#joyful', '#surprising', 0.788, 'strength', 'tolerance', 'stamina', 'staying_power', 'sufferance']
senticnet['endurance_exercise'] = [0.742, -0.965, 0, 0.58, '#joyful', '#surprising', 0.762, 'sport', 'win_marathon', 'champion', 'strong_endurance', 'competition']
senticnet['endure'] = [-0.068, -0.007, -0.08, 0, '#sad', '#scared', -0.047, 'storm_fortress', 'guard_bank', 'fight_war', 'wage_war', 'slow_traffic']
senticnet['enduring'] = [0.76, 0, 0, 0.871, '#joyful', '#admirable', 0.544, 'everlasting', 'standing', 'imperishable', 'lasting', 'aeonian']
senticnet['enduringness'] = [0.647, -0.539, 0, 0.934, '#joyful', '#admirable', 0.707, 'indestructibility', 'tensile_strength', 'continuity', 'persistence', 'changelessness']
senticnet['enema'] = [-0.176, -0.159, -0.082, -0.207, '#sad', '#disgusting', -0.102, 'acne', 'skate_rink', 'crush_ice', 'land_earth', 'thunderstorm']
senticnet['enemy'] = [-0.079, 0, -0.09, -0.237, '#scared', '#disgusting', -0.135, 'declare_war', 'conflict', 'arm_oneself', 'siege', 'battle']
senticnet['energetic'] = [0.73, 0, 0, 0, '#joyful', '#joyful', 0.243, 'set_example', 'improve', 'push_up', 'result_injury', 'important_good_health']
senticnet['energize'] = [0.599, -0.973, 0, 0.869, '#surprising', '#admirable', 0.814, 'reanimate', 'revivify', 'reinvigorate', 'recreate', 'renovate']
senticnet['energizing'] = [0.576, -0.934, 0, 0.847, '#surprising', '#admirable', 0.786, 'vivification', 'invigoration', 'activity', 'animation', 'electrification']
senticnet['energy'] = [-0.909, 0, 0.748, -0.904, '#sad', '#disgusting', -0.854, 'alternative_energy', 'activation_energy', 'energy_of_activation', 'atomic_energy', 'nuclear_energy']
senticnet['energy_drink'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'diet_coke', 'sugar_free', 'carbonated_drink', 'drink', 'beverage']
senticnet['energy_exhaustion'] = [-0.614, 0, 0.738, -0.803, '#angry', '#disgusting', -0.718, 'tired', 'feel_restless', 'need_rest', 'exhausted', 'lack_of_rest']
senticnet['energy_of_activation'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'alternative_energy', 'activation_energy', 'energy', 'atomic_energy', 'nuclear_energy']
senticnet['energy_source'] = [0.053, 0.264, -0.119, 0.23, '#interesting', '#admirable', 0.143, 'natural_resource', 'petroleum', 'fossil_fuel', 'carbon', 'potential_energy']
senticnet['energy_use'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'energy', 'use_fuel', 'switch_on', 'use_electricity', 'use_transport']
senticnet['enervate'] = [-0.756, 0, -0.708, 0, '#sad', '#scared', -0.488, 'untune', 'faze', 'unnerve', 'unsettle', 'dissolve']
senticnet['enervating'] = [0.753, -0.745, 0, 0.587, '#joyful', '#surprising', 0.695, 'draining', 'exhausting', 'debilitative', 'debilitating', 'enfeebling']
senticnet['enfant_terrible'] = [-0.614, 0, 0.738, -0.803, '#angry', '#disgusting', -0.718, 'dissident', 'beat', 'bohemian', 'maverick', 'recusant']
senticnet['enfeebling'] = [0.753, -0.745, 0, 0.587, '#joyful', '#surprising', 0.695, 'draining', 'exhausting', 'debilitative', 'enervating', 'debilitating']
senticnet['enforce'] = [-0.886, 0, 0.977, -0.815, '#sad', '#angry', -0.893, 'execute', 'run', 'compel', 'oblige', 'obligate']
senticnet['engage'] = [0.717, 0, 0, 0.957, '#joyful', '#admirable', 0.558, 'engagement', 'wedding_vow', 'proposal', 'hand_over', 'decorate_oneself']
senticnet['engage_conversation'] = [-0.073, 0, 0.026, -0.038, '#sad', '#disgusting', -0.046, 'discuss', 'misunderstanding', 'communicate_other_person', 'chit_chat', 'conversation']
senticnet['engage_sport'] = [0.877, 0.832, 0, 0.791, '#joyful', '#interesting', 0.833, 'enjoy_challenge', 'win_competition', 'enjoy_game', 'leader', 'training_body']
senticnet['engaged'] = [-0.075, -0.028, 0.034, 0, '#sad', '#angry', -0.027, 'call_back', 'busy', 'cut_off', 'busy_signal', 'hang_up']
senticnet['engagement'] = [0.716, 0, 0, 0.727, '#joyful', '#admirable', 0.481, 'wedding_band', 'bell_sound', 'piece_of_jewelry', 'engage', 'diamond_ring']
senticnet['engender'] = [0, 0, -0.839, -0.829, '#scared', '#disgusting', -0.556, 'breed', 'beget', 'get', 'father', 'spawn']
senticnet['engendering'] = [0, 0, -0.864, -0.712, '#scared', '#disgusting', -0.525, 'spawn', 'beget', 'get', 'breed', 'father']
senticnet['engine'] = [0.97, 0, 0, 0.972, '#joyful', '#admirable', 0.647, 'airplane_engine', 'hatchet', 'angle_grinder', 'knife', 'cannonball']
senticnet['engine_failure'] = [-0.816, 0, 0.849, -0.532, '#sad', '#angry', -0.732, 'dud', 'fault', 'failure', 'brake_failure', 'equipment_failure']
senticnet['engine_issue'] = [-0.816, 0, 0.849, -0.532, '#sad', '#angry', -0.732, 'broken_engine', 'broken_car', 'flat_tyre', 'broken_shelf', 'need_fix']
senticnet['engineer'] = [0.806, 0.789, 0, 0, '#joyful', '#interesting', 0.532, 'vocation', 'finish_school', 'architect', 'reporter', 'profession']
senticnet['english'] = [0, 0, 0, 0.074, '#admirable', '#admirable', 0.025, 'write_message', 'grammar', 'codings', 'computer_language', 'program_language']
senticnet['engross'] = [0.619, -0.828, 0, 0.854, '#surprising', '#admirable', 0.767, 'focus', 'pore', 'rivet', 'concentrate', 'center']
senticnet['engrossing'] = [0.566, -0.912, 0, 0.599, '#surprising', '#admirable', 0.692, 'intriguing', 'absorbing', 'interesting', 'fascinating', 'gripping']
senticnet['engrossment'] = [0.927, -0.922, 0, 0.76, '#joyful', '#surprising', 0.87, 'diligence', 'industriousness', 'singleness', 'intentness', 'assiduity']
senticnet['engulf'] = [0.824, -0.586, 0, 0.868, '#joyful', '#admirable', 0.759, 'focus', 'pore', 'rivet', 'concentrate', 'center']
senticnet['enhance'] = [0.737, -0.808, 0, 0.611, '#joyful', '#surprising', 0.719, 'compound', 'intensify', 'deepen', 'potentiate', 'heighten']
senticnet['enhance_knowledge'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'find_information', 'scope_out_information', 'knowledge', 'find_out', 'information']
senticnet['enhancive'] = [0.596, -0.64, 0, 0.945, '#surprising', '#admirable', 0.727, 'cosmetic', 'painterly', 'sensuous', 'artistic', 'aesthetical']
senticnet['enigma'] = [-0.052, -0.197, -0.179, 0.219, '#surprising', '#admirable', 0.062, 'riddle', 'mystery', 'obituary', 'editorial', 'book_genre']
senticnet['enjoy'] = [0.905, 0.779, 0, 0.921, '#joyful', '#admirable', 0.868, 'excitement', 'happiness', 'a_lot_of_sex', 'have_fun', 'feel_good']
senticnet['enjoy_art'] = [0.973, 0.876, 0, 0, '#joyful', '#interesting', 0.616, 'see_oneself', 'masturbate', 'experience_emotion', 'understand_plot', 'experience_new']
senticnet['enjoy_beauty'] = [0.825, 0.923, 0, 0.934, '#interesting', '#admirable', 0.894, 'happy', 'beauty', 'pleasure', 'eye_stimulation', 'pleasant_experience']
senticnet['enjoy_challenge'] = [0.921, 0.754, 0, 0, '#joyful', '#interesting', 0.558, 'like_compete', 'fun', 'win_money', 'challenge', 'something_to_do']
senticnet['enjoy_club'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'enjoy_concert', 'free_ticket', 'ticket', 'free', 'enjoy_football_match']
senticnet['enjoy_cold'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'sit_in_shade', 'chill_out', 'turn_aircon_on', 'fresh', 'cool']
senticnet['enjoy_company'] = [0.746, 0, 0, 0.907, '#joyful', '#admirable', 0.551, 'share_time', 'friendship', 'new_friendship', 'start_conversation', 'meet_friend']
senticnet['enjoy_company_friend'] = [0.734, 0.849, 0, 0, '#joyful', '#interesting', 0.528, 'meet_girl', 'friend_over', 'laugh_joke', 'entertain_person', 'make_someone_laugh']
senticnet['enjoy_competition'] = [0.879, 0.83, 0, 0, '#joyful', '#interesting', 0.57, 'exercise', 'prove_fitness', 'win_marathon', 'challenge_oneself', 'relieve_stress']
senticnet['enjoy_concert'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'free_ticket', 'enjoy_club', 'ticket', 'free', 'enjoy_football_match']
senticnet['enjoy_day'] = [0.911, 0.813, 0, 0, '#joyful', '#interesting', 0.575, 'enjoy_company_friend', 'taste_sweet', 'laugh_joke', 'comfort_friend', 'entertain_person']
senticnet['enjoy_down_time'] = [0.833, -0.873, 0, 0, '#joyful', '#surprising', 0.569, 'set_mood', 'unwind', 'stress_reduction', 'distraction', 'relaxation']
senticnet['enjoy_eat'] = [0.8, 0.747, 0, 0, '#joyful', '#interesting', 0.516, 'fill_stomach', 'satisfy_hunger', 'sustenance', 'relieve_hunger', 'reduce_hunger']
senticnet['enjoy_entertainment'] = [0.77, -0.862, 0, 0, '#joyful', '#surprising', 0.544, 'waste_time', 'see_new_place', 'recommend', 'expand_horizon', 'stimulate_mind']
senticnet['enjoy_film'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'see_favorite_show', 'watch_film', 'watch_movie', 'see_movie', 'take_film']
senticnet['enjoy_food'] = [0.825, 0.923, 0, 0.934, '#interesting', '#admirable', 0.894, 'food', 'delicious_food', 'give_party', 'eat_out', 'meet_friend']
senticnet['enjoy_football_match'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'enjoy_concert', 'enjoy_club', 'ticket', 'free', 'free_ticket']
senticnet['enjoy_fresh_air'] = [0.899, 0.726, 0, 0, '#joyful', '#interesting', 0.542, 'air', 'fresh_air', 'turn_on_fan', 'turn_on_air_conditioner', 'cool_air']
senticnet['enjoy_game'] = [0.877, 0.832, 0, 0.791, '#joyful', '#interesting', 0.833, 'enjoy_challenge', 'engage_sport', 'win_competition', 'game', 'play_team_sport']
senticnet['enjoy_life'] = [0.899, 0.726, 0, 0, '#joyful', '#interesting', 0.542, 'companionship', 'stimulation', 'feel_good', 'foreplay', 'lift_spirit']
senticnet['enjoy_meal'] = [0.899, 0.726, 0, 0, '#joyful', '#interesting', 0.542, 'serve_meal', 'make_dinner', 'eat_food', 'prepare_meal', 'eat']
senticnet['enjoy_moment'] = [0.899, 0.726, 0, 0, '#joyful', '#interesting', 0.542, 'funny_moment', 'enjoy', 'laugh', 'enjoy_movie', 'enjoy_game']
senticnet['enjoy_movie'] = [0.993, 0.727, 0, 0, '#joyful', '#interesting', 0.573, 'like_movie', 'want_entertain', 'watch_show', 'mindless_entertainment', 'go_date']
senticnet['enjoy_music'] = [0.708, 0.831, 0, 0, '#joyful', '#interesting', 0.513, 'sing_along', 'deafness', 'hear_loss', 'earring', 'set_mood']
senticnet['enjoy_nature'] = [0.993, 0.727, 0, 0, '#joyful', '#interesting', 0.573, 'nature', 'enjoy_view', 'relax_moment', 'nice_walk', 'enjoy_life']
senticnet['enjoy_oneself'] = [0.802, 0.978, 0, 0, '#joyful', '#interesting', 0.593, 'enjoyment', 'pleasure', 'entertainment', 'have_fun', 'social_bond']
senticnet['enjoy_outdoors'] = [0.953, 0.989, 0, 0.955, '#interesting', '#admirable', 0.966, 'exercise', 'get_fresh_air', 'relieve_stress', 'keep_shape', 'fun']
senticnet['enjoy_performance'] = [0.817, 0.78, 0, 0.971, '#joyful', '#admirable', 0.856, 'feel_happy', 'laugh_lot', 'enjoy_show', 'performance', 'experience_pleasure']
senticnet['enjoy_person'] = [0.897, 0.959, 0, 0, '#joyful', '#interesting', 0.619, 'spend_time_with_friend', 'show_off', 'break_work', 'have_fun', 'forget_trouble']
senticnet['enjoy_play'] = [0.897, 0.959, 0, 0, '#joyful', '#interesting', 0.619, 'enjoy', 'enjoyment', 'fun', 'enjoy_game', 'play']
senticnet['enjoy_salary'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'get_job_done', 'receive_paycheck', 'earn_paycheck', 'support_family', 'increase_net_worth']
senticnet['enjoy_scenery'] = [0.877, 0.832, 0, 0.791, '#joyful', '#interesting', 0.833, 'beautiful_view', 'scenery', 'enjoy_nature', 'relax', 'enjoy_outdoors']
senticnet['enjoy_sex'] = [0.846, 0.976, 0, 0.766, '#joyful', '#interesting', 0.863, 'have_fun', 'ecstasy', 'masturbate', 'watch_sunset', 'need_companionship']
senticnet['enjoy_show'] = [0.823, 0.812, 0, 0, '#joyful', '#interesting', 0.545, 'eat_popcorn', 'entertain', 'go_symphony', 'feel_happy', 'catch_up_news']
senticnet['enjoy_sport'] = [0.902, 0.864, 0, 0, '#joyful', '#interesting', 0.589, 'fun', 'difficult_play', 'help_team', 'like_sport', 'competitive']
senticnet['enjoy_story'] = [0.868, 0.99, 0, 0, '#joyful', '#interesting', 0.619, 'acculturation', 'stimulate_mind', 'get_news', 'appreciate_art', 'get_informed']
senticnet['enjoy_taste'] = [0.712, 0.935, 0, 0.968, '#interesting', '#admirable', 0.872, 'delicious_food', 'enjoy_food', 'eat_ice_cream', 'eat_cake', 'enjoy_meal']
senticnet['enjoy_time'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'child', 'adolescence', 'youth', 'smile_child', 'open_mind']
senticnet['enjoy_time_together'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'free_sex', 'meet_girl', 'fall_in_love', 'kiss', 'infatuation']
senticnet['enjoy_together'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'make_someone_laugh', 'entertain_person', 'enjoy_company_friend', 'make_love_spouse', 'laugh_joke']
senticnet['enjoy_view'] = [0.718, -0.937, 0, 0, '#joyful', '#surprising', 0.552, 'stop_traffic_light', 'flat_tire', 'crash_tree', 'hit_tree', 'stop_stop_sign']
senticnet['enjoyable'] = [0.7, 0.972, 0, 0, '#joyful', '#interesting', 0.557, 'fun', 'just_fun', 'competitive', 'taboo', 'creepy']
senticnet['enjoyable_activity'] = [0.919, 0.74, 0, 0, '#joyful', '#interesting', 0.553, 'recreational', 'competitive', 'fun_play', 'good_sport', 'winter_sport']
senticnet['enjoyment'] = [0.902, 0.995, 0, 0, '#joyful', '#interesting', 0.632, 'joy', 'entertainment', 'enjoy_oneself', 'entertain_oneself', 'pastime']
senticnet['enkindle'] = [0.722, -0.764, 0, 0.946, '#surprising', '#admirable', 0.811, 'arouse', 'elicit', 'ask_for', 'kindle', 'evoke']
senticnet['enlarge'] = [0, 0.174, -0.082, 0.302, '#interesting', '#admirable', 0.131, 'make_big', 'flourish', 'get_large', 'get_big', 'expand']
senticnet['enlarged'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'fat', 'heavy_dinner', 'bloated', 'expanded', 'bulging']
senticnet['enlargement'] = [0.777, -0.895, 0, 0.508, '#joyful', '#surprising', 0.727, 'stretching', 'enlarge', 'dilatation', 'get_bigger', 'distension']
senticnet['enlighten'] = [0.853, -0.719, 0, 0.92, '#joyful', '#admirable', 0.831, 'find_desk', 'learn_information', 'become_educated', 'learn', 'listen_teacher']
senticnet['enlightened'] = [0.61, -0.983, 0, 0.795, '#surprising', '#admirable', 0.796, 'informed', 'conversant', 'hep', 'hip', 'hip_to']
senticnet['enlightenment'] = [0.85, 0.776, 0, 0.893, '#joyful', '#admirable', 0.84, 'expand_mind', 'expand_knowledge', 'gain_knowledge', 'learn_current_event', 'eye_strain']
senticnet['enlist'] = [-0.035, 0.197, -0.137, 0.158, '#interesting', '#admirable', 0.061, 'inclusion', 'list', 'band_together', 'commence', 'use_board_game']
senticnet['enlistee'] = [0.824, -0.973, 0, 0.833, '#surprising', '#admirable', 0.877, 'recruit', 'fledgeling', 'novice', 'beginner', 'tyro']
senticnet['enliven'] = [0.858, -0.886, 0, 0.508, '#joyful', '#surprising', 0.751, 'encourage', 'stir', 'shake', 'excite', 'shake_up']
senticnet['enlivened'] = [0.689, -0.544, 0, 0.511, '#joyful', '#surprising', 0.581, 'lively', 'animated', 'spirited', 'reanimated', 'vital']
senticnet['enlivening'] = [0.843, -0.818, 0, 0.624, '#joyful', '#surprising', 0.762, 'exhilarating', 'animating', 'invigorating', 'refreshing', 'restorative']
senticnet['enmeshed'] = [0.59, -0.967, 0, 0.785, '#surprising', '#admirable', 0.781, 'tangled', 'intermeshed', 'rootbound', 'matted', 'knotty']
senticnet['enmity'] = [0, 0.161, 0.7, -0.657, '#angry', '#disgusting', -0.399, 'ill_will', 'hostile', 'vindictive', 'despiteful', 'vindictively']
senticnet['ennoble'] = [0.586, -0.967, 0, 0.9, '#surprising', '#admirable', 0.818, 'kick_upstairs', 'gentle', 'prefer', 'spot_promote', 'favor']
senticnet['ennui'] = [-0.831, 0, 0.912, -0.679, '#sad', '#angry', -0.807, 'letdown', 'displeasure', 'disappointment', 'boredom', 'dissatisfaction']
senticnet['enophile'] = [0.753, -0.641, 0, 0.606, '#joyful', '#surprising', 0.667, 'enthusiast', 'appreciator', 'lover', 'person', 'individual']
senticnet['enormous'] = [0.944, 0, 0, 0.723, '#joyful', '#admirable', 0.556, 'star_planet', 'emptiness', 'void', 'nothingness', 'outer']
senticnet['enough_eat'] = [0.873, 0.772, 0, 0, '#joyful', '#interesting', 0.548, 'taken_seriously', 'knowledgeable', 'pay_work', 'complement', 'much_need']
senticnet['enough_food'] = [0.852, 0.888, 0, 0, '#joyful', '#interesting', 0.58, 'fresh_produce', 'sweet_fruit', 'spice_life', 'taken_seriously', 'much_need']
senticnet['enough_money'] = [0.719, 0.757, 0, 0, '#joyful', '#interesting', 0.492, 'out_wallet', 'money_credit', 'use_money', 'good_credit', 'find_merchant']
senticnet['enough_rest'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'feel_refreshed', 'reinvigorated', 'cure', 'after_shower', 'take_nap']
senticnet['enough_sleep'] = [0.225, 0.114, 0, 0.177, '#joyful', '#admirable', 0.172, 'plenty_sleep', 'qualify', 'enroll_school', 'dedication', 'intelligence']
senticnet['enounce'] = [0.982, -0.701, 0, 0.527, '#joyful', '#surprising', 0.737, 'sound', 'lilt', 'accent', 'round', 'sibilate']
senticnet['enquirer'] = [-0.623, 0, 0.632, -0.783, '#angry', '#disgusting', -0.679, 'inquirer', 'inquisitor', 'questioner', 'querier', 'asker']
senticnet['enquiries'] = [0, 0.084, 0, 0, '#interesting', '#interesting', 0.028, 'call_restaurant', 'reservation', 'reserve', 'dinner', 'reserved']
senticnet['enraged'] = [-0.137, 0.145, 0.624, -0.638, '#angry', '#disgusting', -0.418, 'furious', 'infuriated', 'maddened', 'angered', 'indignantly']
senticnet['enragement'] = [-0.125, 0.127, 0.651, -0.649, '#angry', '#disgusting', -0.433, 'infuriation', 'high_dudgeon', 'dudgeon', 'furiously', 'infuriate']
senticnet['enraptured'] = [0.986, 0, 0, 0.838, '#joyful', '#admirable', 0.608, 'joyful', 'ecstatic', 'joyous', 'rapturous', 'rapt']
senticnet['enrich'] = [0.881, -0.869, 0, 0.688, '#joyful', '#surprising', 0.813, 'better', 'improve', 'make_look_better', 'meliorate', 'amend']
senticnet['enroll'] = [0.719, 0.757, 0, 0, '#joyful', '#interesting', 0.492, 'matriculate', 'enroll_class', 'enroll_school', 'inscribe', 'register']
senticnet['enroll_class'] = [0.719, 0.757, 0, 0, '#joyful', '#interesting', 0.492, 'matriculate', 'enroll', 'enroll_school', 'inscribe', 'register']
senticnet['enroll_school'] = [0.719, 0.757, 0, 0, '#joyful', '#interesting', 0.492, 'enroll_class', 'enroll', 'matriculate', 'inscribe', 'register']
senticnet['ensconce'] = [0.725, -0.665, 0, 0.906, '#joyful', '#admirable', 0.765, 'set', 'pose', 'lay', 'put', 'place']
senticnet['ensemble'] = [-0.507, 0, 0.902, -0.548, '#angry', '#disgusting', -0.652, 'gamelan', 'jug_band', 'pop_group', 'mariachi', 'skiffle_group']
senticnet['ensky'] = [0.79, -0.973, 0, 0.689, '#joyful', '#surprising', 0.817, 'laud', 'extol', 'exalt', 'glorify', 'proclaim']
senticnet['enslave_person'] = [-0.113, 0, -0.174, -0.14, '#scared', '#disgusting', -0.142, 'protect_country', 'kill_another_person', 'kill_enemy', 'conquer_enemy', 'make_war']
senticnet['enslavement'] = [-0.99, 0, 0, -0.932, '#sad', '#disgusting', -0.641, 'oppression', 'caged_lion', 'slave', 'captivity', 'misery']
senticnet['ensorcelled'] = [0.998, -0.75, 0, 0.695, '#joyful', '#surprising', 0.814, 'bewitched', 'enchanted', 'fascinated', 'hypnotized', 'mesmerized']
senticnet['ensuing'] = [-0.643, 0, 0.684, -0.717, '#angry', '#disgusting', -0.681, 'consecutive', 'postmortem', 'succeeding', 'following', 'undermentioned']
senticnet['ensure_proper_hygiene'] = [0.078, 0, 0, 0.074, '#joyful', '#admirable', 0.051, 'remove_dirt_body', 'smell_better', 'feel_clean', 'smell_nice', 'prevent_disease']
senticnet['entail'] = [0.975, -0.993, 0, 0.644, '#joyful', '#surprising', 0.871, 'demesne', 'barony', 'seigneury', 'seigniory', 'immovable']
senticnet['enter'] = [-0.022, 0.176, -0.103, 0.287, '#interesting', '#admirable', 0.113, 'go_build', 'go_inside', 'hang_door', 'enter_area', 'control_access']
senticnet['enter_address'] = [-0.071, 0, 0.053, -0.057, '#sad', '#disgusting', -0.06, 'type_of_keyboard', 'move_mouse', 'start_computer', 'gather_data', 'log_off']
senticnet['enter_area'] = [-0.056, 0.179, -0.096, 0.294, '#interesting', '#admirable', 0.107, 'go_through', 'go_build', 'hang_door', 'enter', 'drag']
senticnet['enter_build'] = [-0.073, 0.146, -0.078, 0.197, '#interesting', '#admirable', 0.064, 'enter_area', 'go_through', 'hang_door', 'go_build', 'leave_build']
senticnet['enter_classroom'] = [-0.14, 0, 0, -0.038, '#sad', '#disgusting', -0.059, 'question_teacher', 'study_biology', 'school_student', 'guess_answer', 'study_library']
senticnet['enter_contest'] = [0.141, -0.073, 0, -0.06, '#joyful', '#surprising', 0.051, 'dance_well', 'dance', 'old_dance', 'slow_dance', 'adjust_volume']
senticnet['enter_contract'] = [0, 0.419, -0.262, 0.444, '#interesting', '#admirable', 0.2, 'believe', 'trust_god', 'wish', 'give_help', 'believe_god']
senticnet['enter_courtroom'] = [-0.045, 0.092, 0, 0.062, '#interesting', '#admirable', 0.036, 'call_witness', 'listen_witness', 'hold_trial', 'go_courtroom', 'question_witness']
senticnet['enter_data'] = [-0.998, 0, 0.871, 0, '#sad', '#angry', -0.623, 'post_message', 'send_mail', 'print_printer', 'use_computer', 'send_email']
senticnet['enter_data_computer'] = [-0.114, 0, 0, 0, '#sad', '#sad', -0.038, 'type_of_keyboard', 'type_of_letter', 'write_computer_program', 'write_novel', 'wedge_door_open']
senticnet['enter_door'] = [-0.867, 0, -0.976, 0, '#sad', '#scared', -0.614, 'bicycle_store', 'shut_door', 'carry_suitcase', 'grunt', 'enter_home']
senticnet['enter_exit'] = [0.993, 0, 0, 0.86, '#joyful', '#admirable', 0.618, 'entry', 'home_entrance', 'next_door', 'house_front', 'next_house']
senticnet['enter_home'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'bicycle_store', 'shut_door', 'carry_suitcase', 'grunt', 'enter_door']
senticnet['enter_information'] = [-0.736, 0, -0.927, 0, '#sad', '#scared', -0.554, 'enter', 'information', 'enter_address', 'start_computer', 'enter_data_computer']
senticnet['enter_marathon'] = [-0.049, -0.033, 0.066, 0, '#sad', '#angry', -0.027, 'train_hard', 'jump_jack', 'fitter', 'strain_muscle', 'expend_energy']
senticnet['enter_place'] = [-0.93, 0, -0.924, 0, '#sad', '#scared', -0.618, 'find_garden', 'walk_down', 'walk', 'walk_through', 'progress']
senticnet['enter_room'] = [0, 0.075, 0, 0.199, '#interesting', '#admirable', 0.091, 'separate_room', 'hang_door', 'go_build', 'go_through', 'control_access']
senticnet['enter_store'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'pay_cashier', 'go_town', 'live_simply', 'complete_job', 'count_money']
senticnet['enter_theater'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'show_movie', 'watch_movie', 'like_movie', 'see_film', 'record_movie']
senticnet['entering'] = [-0.506, 0, 0.975, -0.865, '#angry', '#disgusting', -0.782, 'entrance', 'irruption', 'entry', 'ingress', 'incoming']
senticnet['enteron'] = [-0.823, 0, 0.67, -0.848, '#sad', '#disgusting', -0.78, 'alimentary_canal', 'alimentary_tract', 'digestive_tube', 'digestive_tract', 'gastrointestinal_tract']
senticnet['enterostenosis'] = [-0.815, 0, 0.684, -0.813, '#sad', '#disgusting', -0.771, 'rhinostenosis', 'stenosis', 'laryngostenosis', 'aortic_stenosis', 'mitral_stenosis']
senticnet['enterprise'] = [0.059, 0.212, 0, 0.143, '#interesting', '#admirable', 0.138, 'business', 'corporation', 'money_maker', 'company', 'business_organization']
senticnet['entertain'] = [0.875, 0, 0, 0.761, '#joyful', '#admirable', 0.545, 'mindless_entertainment', 'want_entertain', 'see_actor', 'enjoy', 'relieve_boredom']
senticnet['entertain_audience'] = [0.875, 0.71, 0, 0, '#joyful', '#interesting', 0.528, 'develop_skill', 'sound_good', 'entertain_others', 'appreciate_music', 'use_talent']
senticnet['entertain_child'] = [0.738, 0.961, 0, 0, '#joyful', '#interesting', 0.566, 'amuse_child', 'keep_child_occupy', 'alleviate_boredom', 'play_fun', 'entertain_kid']
senticnet['entertain_company'] = [0.196, 0.077, 0, 0.064, '#joyful', '#interesting', 0.112, 'company', 'give_pleasure', 'use_talent', 'performance', 'entertainment']
senticnet['entertain_crowd'] = [0.802, 0.794, 0, 0, '#joyful', '#interesting', 0.532, 'ear_money', 'performance', 'give_pleasure', 'entertainment', 'use_talent']
senticnet['entertain_friend'] = [0.036, 0.232, -0.057, 0.192, '#interesting', '#admirable', 0.134, 'give_pleasure', 'friend', 'performance', 'sociable', 'use_talent']
senticnet['entertain_kid'] = [0.738, 0.961, 0, 0, '#joyful', '#interesting', 0.566, 'amuse_child', 'keep_child_occupy', 'alleviate_boredom', 'play_fun', 'entertain_child']
senticnet['entertain_oneself'] = [0.927, 0, 0, 0.761, '#joyful', '#admirable', 0.563, 'pastime', 'entertainment', 'film_critic', 'enjoyment', 'wish_entertain']
senticnet['entertain_other_person'] = [0.924, 0.968, 0, 0.876, '#joyful', '#interesting', 0.923, 'entertain_others', 'listen', 'sing_song', 'perform_on_stage', 'sing_dance']
senticnet['entertain_others'] = [0.971, 0, 0, 0, '#joyful', '#joyful', 0.324, 'gain_skill', 'listen', 'entertain_other_person', 'sound_good', 'appreciate_music']
senticnet['entertain_person'] = [0, 0, 0, 0.852, '#admirable', '#admirable', 0.284, 'make_someone_laugh', 'enjoy_together', 'enjoy_company_friend', 'make_love_spouse', 'laugh_joke']
senticnet['entertainer'] = [0.54, -0.64, 0, 0.566, '#surprising', '#admirable', 0.582, 'pleaser', 'bombshell', 'mortal', 'busker', 'drawing_card']
senticnet['entertainment'] = [0.951, 0, 0, 0.731, '#joyful', '#admirable', 0.561, 'pastime', 'enjoyment', 'entertain_oneself', 'enjoy', 'get_entertain']
senticnet['entertainment_education'] = [0.797, 0.928, 0, 0, '#joyful', '#interesting', 0.575, 'cultural_experience', 'acculturation', 'zone_out', 'entertain_oneself', 'entertainment_learn']
senticnet['entertainment_learn'] = [0.945, 0.996, 0, 0.737, '#joyful', '#interesting', 0.893, 'escape_reality', 'acculturation', 'enjoy_story', 'stimulate_mind', 'cultural_experience']
senticnet['enthralling'] = [0.846, 0, 0, 0.939, '#joyful', '#admirable', 0.595, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['enthrallment'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'captivated', 'charmed', 'captivate', 'bewitch', 'beguile']
senticnet['enthusiam'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'prosper', 'succeed', 'realize', 'fly_high', 'thrive']
senticnet['enthusiasm'] = [0.887, 0, 0, 0, '#joyful', '#joyful', 0.296, 'thankful', 'openhearted', 'good-hearted', 'kindly', 'benevolent']
senticnet['enthusiast'] = [0.935, -0.722, 0, 0.747, '#joyful', '#admirable', 0.801, 'friend', 'sports_fan', 'rooter', 'fan', 'nut']
senticnet['enthusiastic'] = [0.481, 0.659, -0.249, 0.236, '#joyful', '#interesting', 0.376, 'exciting', 'enthusiastically', 'unfearing', 'intrepid', 'dauntlessly']
senticnet['enthusiastically'] = [0.481, 0.659, -0.249, 0.236, '#joyful', '#interesting', 0.376, 'enthusiastic', 'exciting', 'unfearing', 'intrepid', 'dauntlessly']
senticnet['entice'] = [0.942, 0.756, 0, 0, '#joyful', '#interesting', 0.566, 'investment_return', 'reinforce_concrete', 'fish_lake', 'land_fish', 'catch_fish']
senticnet['enticement'] = [0.854, -0.955, 0, 0.554, '#joyful', '#surprising', 0.788, 'forbidden_fruit', 'allurement', 'hook', 'sweetener', 'influence']
senticnet['enticing'] = [0.969, -0.848, 0, 0.837, '#joyful', '#surprising', 0.885, 'alluring', 'seductive', 'tempting', 'beguiling', 'corrupting']
senticnet['entire'] = [0.799, 0, 0, 0.932, '#joyful', '#admirable', 0.577, 'all_of_it', 'total', 'whole', 'complete', 'integral']
senticnet['entireness'] = [0.639, -0.827, 0, 0.997, '#surprising', '#admirable', 0.821, 'completeness', 'work', 'whole_shebang', 'whole_kit_and_caboodle', 'kit_and_caboodle']
senticnet['entirety'] = [0.595, -0.615, 0, 0.826, '#surprising', '#admirable', 0.679, 'completeness', 'work', 'whole_shebang', 'whole_kit_and_caboodle', 'kit_and_caboodle']
senticnet['entitled'] = [0.866, -0.528, 0, 0.529, '#joyful', '#admirable', 0.641, 'worthy', 'desirable', 'suitable', 'bailable', 'eligible']
senticnet['entity'] = [0, 0.093, 0, 0.205, '#interesting', '#admirable', 0.099, 'form', 'body_type', 'figure', 'hexagon', 'shape']
senticnet['entrance'] = [0.191, 0.227, -0.098, 0.195, '#interesting', '#admirable', 0.172, 'entranceway', 'doorway', 'corridor', 'use_farm', 'door']
senticnet['entrance_room'] = [-0.894, 0, 0.989, 0, '#sad', '#angry', -0.628, 'connect_room', 'home_entrance', 'entry', 'house_front', 'wood_panel']
senticnet['entranced'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['entranceway'] = [0.028, 0, 0, 0.075, '#joyful', '#admirable', 0.034, 'doorway', 'door', 'entryway', 'gate', 'corridor']
senticnet['entrancing'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['entreaty'] = [0.68, -0.962, 0, 0.597, '#joyful', '#surprising', 0.746, 'flag_waving', 'jingoism', 'appeal', 'prayer', 'demagoguery']
senticnet['entree'] = [0.084, -0.054, 0, -0.044, '#joyful', '#surprising', 0.031, 'feast', 'mash_potato', 'satiation', 'breakfast', 'supper']
senticnet['entrepreneur'] = [0.078, 0.142, 0, 0, '#joyful', '#interesting', 0.073, 'make_money', 'earn_money', 'need_earn_money', 'bind_agreement', 'make_live']
senticnet['entropy'] = [-0.927, 0, 0, -0.959, '#sad', '#disgusting', -0.629, 'become_fat', 'flatulence', 'feel_rejuvenated', 'tan_skin', 'make_angry']
senticnet['entrust'] = [0.62, -0.993, 0, 0.621, '#surprising', '#admirable', 0.745, 'hand', 'commend', 'reach', 'charge', 'give']
senticnet['entry'] = [0, 0.066, 0, 0.154, '#interesting', '#admirable', 0.073, 'home_entrance', 'house_front', 'build_open', 'hinge', 'next_door']
senticnet['entryway'] = [0.028, 0, 0, 0.051, '#joyful', '#admirable', 0.026, 'entranceway', 'doorway', 'entrance', 'main_entrance', 'corridor']
senticnet['enucleation'] = [0.947, -0.866, 0, 0.852, '#joyful', '#surprising', 0.888, 'operation', 'surgery', 'surgical_operation', 'surgical_procedure', 'surgical_process']
senticnet['enumerable'] = [0.983, -0.807, 0, 0.966, '#joyful', '#admirable', 0.919, 'estimable', 'computable', 'countable', 'dcalculable', 'calculable']
senticnet['enumerate'] = [0.033, 0.122, 0.051, 0.158, '#interesting', '#admirable', 0.087, 'number_person', 'count_person', 'small_group', 'twice', 'count']
senticnet['enumeration'] = [0.023, 0.139, 0.089, 0.206, '#interesting', '#admirable', 0.093, 'numerical', 'count', 'number', 'ordinal', 'list']
senticnet['enunciate'] = [0.536, -0.533, 0, 0.761, '#joyful', '#admirable', 0.61, 'sound', 'lilt', 'accent', 'round', 'sibilate']
senticnet['enunciation'] = [0.941, 0, 0, 0.757, '#joyful', '#admirable', 0.566, 'speech', 'say', 'idiom', 'language', 'answer_back']
senticnet['enured'] = [0.641, -0.577, 0, 0.707, '#joyful', '#admirable', 0.642, 'toughened', 'inured', 'thickened', 'calloused', 'callous']
senticnet['enuresis'] = [-0.776, 0, 0.966, -0.518, '#sad', '#angry', -0.753, 'overflow_incontinence', 'incontinency', 'incontinence', 'stress_incontinence', 'urge_incontinence']
senticnet['envelop'] = [0.063, 0, 0, 0.094, '#joyful', '#admirable', 0.052, 'envelope', 'letter_slot', 'mail', 'postage_stamp', 'bulletin']
senticnet['envelope'] = [0.058, -0.049, 0, 0, '#joyful', '#surprising', 0.036, 'letter_slot', 'address_label', 'pamphlet', 'mailman', 'postage_stamp']
senticnet['enviable'] = [0.733, 0, 0, 0.728, '#joyful', '#admirable', 0.487, 'enviousness', 'enviably', 'preferred', 'lovable', 'desired']
senticnet['enviably'] = [0.816, 0, 0, 0.872, '#joyful', '#admirable', 0.563, 'delectable', 'preferred', 'lovable', 'desired', 'plummy']
senticnet['envious'] = [0.087, 0.091, 0.809, -0.681, '#angry', '#disgusting', -0.437, 'enviously', 'covetously', 'jealously', 'covetous', 'overjealous']
senticnet['enviously'] = [0.087, 0.091, 0.809, -0.681, '#angry', '#disgusting', -0.437, 'envious', 'covetously', 'jealously', 'covetous', 'overjealous']
senticnet['enviousness'] = [0.067, 0.104, 0.791, -0.679, '#angry', '#disgusting', -0.433, 'enviably', 'grudging', 'enviable', 'begrudge', 'sulkiness']
senticnet['environ'] = [0.826, -0.607, 0, 0.598, '#joyful', '#surprising', 0.677, 'hedge', 'surround', 'hem_in', 'ring', 'skirt']
senticnet['environment'] = [0.028, 0.138, -0.114, 0.166, '#interesting', '#admirable', 0.073, 'live_environment', 'divine', 'alive', 'beautiful', 'live_object']
senticnet['environmentalism'] = [-0.973, 0, 0.885, -0.976, '#sad', '#disgusting', -0.945, 'protection', 'conservation', 'preservation', 'reservation', 'immobilization']
senticnet['environmentalist'] = [0.214, 0.258, -0.09, 0.2, '#joyful', '#interesting', 0.194, 'gather_evidence', 'testify', 'contact_police', 'give_testimony', 'environment']
senticnet['envisage'] = [-0.774, 0, 0.835, -0.843, '#angry', '#disgusting', -0.817, 'fancy', 'foresee', 'fantasy', 'daydream', 'woolgather']
senticnet['envy'] = [-0.951, 0, -0.854, 0, '#sad', '#scared', -0.602, 'jealousy', 'grudge', 'bitterness', 'jealous', 'resentment']
senticnet['eosinophil'] = [0.602, -0.736, 0, 0.942, '#surprising', '#admirable', 0.76, 'leukocyte', 'leucocyte', 'white_blood_cell', 'white_cell', 'white_blood_corpuscle']
senticnet['eosinophile'] = [0.795, -0.535, 0, 0.527, '#joyful', '#surprising', 0.619, 'leukocyte', 'leucocyte', 'white_blood_cell', 'white_cell', 'white_blood_corpuscle']
senticnet['eparchy'] = [0.8, -0.843, 0, 0.868, '#surprising', '#admirable', 0.837, 'commonwealth', 'province', 'administrative_district', 'administrative_division', 'territorial_division']
senticnet['ephemeral'] = [0.064, -0.06, 0, 0.076, '#joyful', '#admirable', 0.067, 'have_fun', 'fun_pastime', 'enjoyable_activity', 'scrabble', 'diversion']
senticnet['epic'] = [0.089, -0.017, 0.033, 0.082, '#joyful', '#admirable', 0.052, 'informative', 'informational', 'ephemeral', 'fun_read', 'ads']
senticnet['epicondylitis'] = [-0.98, 0, 0.678, -0.956, '#sad', '#disgusting', -0.871, 'rubor', 'redness', 'inflammation', 'tennis_elbow', 'lateral_epicondylitis']
senticnet['epicure'] = [0.897, -0.961, 0, 0.785, '#joyful', '#surprising', 0.881, 'erotic', 'voluptuary', 'sensualist', 'gourmet', 'gastronome']
senticnet['epidemic'] = [-0.379, 0, -0.342, -0.156, '#sad', '#scared', -0.292, 'malady', 'ailment', 'polio', 'emergency', 'illiteracy']
senticnet['epidemic_encephalitis'] = [-0.757, 0, 0.69, -0.695, '#sad', '#disgusting', -0.714, 'rubor', 'redness', 'sleeping_sickness', 'sleepy_sickness', 'cephalitis']
senticnet['epidemic_hysertia'] = [-0.974, 0, 0.777, -0.537, '#sad', '#angry', -0.763, 'manic_disorder', 'mania', 'nympholepsy', 'mass_hysteria', 'delirium']
senticnet['epidemic_meningitis'] = [-0.773, 0, 0.871, -0.64, '#sad', '#angry', -0.761, 'leptomeningitis', 'cerebrospinal_meningitis', 'meningitis', 'brain_fever', 'cerebrospinal_fever']
senticnet['epidemiologist'] = [0.904, -0.93, 0, 0.639, '#joyful', '#surprising', 0.824, 'toxicologist', 'medical_scientist', 'immunologist', 'serologist', 'scientist']
senticnet['epiglottitis'] = [-0.998, 0, 0.964, -0.704, '#sad', '#angry', -0.889, 'blepharitis', 'diverticulitis', 'inflammation', 'orchitis', 'prostatitis']
senticnet['epigon'] = [-0.627, 0, 0.667, -0.853, '#angry', '#disgusting', -0.716, 'copycat', 'emulator', 'aper', 'imitator', 'ape']
senticnet['epigone'] = [-0.867, 0, 0.991, -0.673, '#sad', '#angry', -0.844, 'copycat', 'emulator', 'aper', 'imitator', 'ape']
senticnet['epilepsy'] = [-0.528, 0, 0.785, -0.617, '#angry', '#disgusting', -0.643, 'disease', 'feel_sick', 'brain_disease', 'eye_failure', 'brain_failure']
senticnet['epilepsy_attack'] = [-0.97, 0, 0.332, -0.999, '#sad', '#disgusting', -0.767, 'have_epilepsy', 'crowd', 'humanity', 'epilepsy', 'sickness']
senticnet['epileptic_fit'] = [-0.249, 0, -0.047, -0.121, '#sad', '#disgusting', -0.139, 'sickness', 'disease', 'heart_attack', 'convulsion', 'tremor']
senticnet['epileptic_seizures'] = [-0.97, 0, 0.332, -0.999, '#sad', '#disgusting', -0.767, 'feel_out_of_breath', 'muscle_cramp', 'throat_injury', 'run_too_fast', 'breath_difficulty']
senticnet['epinephrin'] = [0.783, -0.695, 0, 0.827, '#joyful', '#admirable', 0.768, 'pressor', 'hormone', 'endocrine', 'internal_secretion', 'catecholamine']
senticnet['epinephrine'] = [0.934, -0.632, 0, 0.815, '#joyful', '#admirable', 0.794, 'pressor', 'hormone', 'endocrine', 'internal_secretion', 'catecholamine']
senticnet['epiphany'] = [0.963, 0.606, 0, 0.955, '#joyful', '#admirable', 0.841, 'revelation', 'think_past', 'resolve_problem', 'arrive_conclusion', 'lifestyle_change']
senticnet['epiphenomenon'] = [-0.58, 0, 0.535, -0.72, '#sad', '#disgusting', -0.612, 'byproduct', 'effect', 'issue', 'consequence', 'outcome']
senticnet['episode'] = [0.916, 0, 0, 0.988, '#joyful', '#admirable', 0.635, 'encounter', 'reveal', 'programme', 'lose', 'sequel']
senticnet['epitaph'] = [0, 0.171, -0.046, 0.105, '#interesting', '#admirable', 0.077, 'poetry', 'ancient_rome', 'funeral', 'every_town', 'poet']
senticnet['equal'] = [0.059, 0.171, 0.045, 0.234, '#interesting', '#admirable', 0.14, 'add', 'average', 'tally', 'multiplication', 'count']
senticnet['equal_to'] = [0.889, -0.904, 0, 0.559, '#joyful', '#surprising', 0.784, 'competent', 'up_to', 'adequate_to', 'adequate', 'capable']
senticnet['equalitarian'] = [0.922, -0.949, 0, 0.965, '#surprising', '#admirable', 0.945, 'utilitarian', 'egalitarian', 'moralist', 'elitist', 'philosopher']
senticnet['equality'] = [0.182, 0.253, -0.066, 0.322, '#interesting', '#admirable', 0.23, 'same', 'equal', 'absolute', 'fair', 'good']
senticnet['equality_everyone'] = [0.949, 0.848, 0, 0, '#joyful', '#interesting', 0.599, 'freedom', 'rebel', 'glory', 'new_law', 'political']
senticnet['equanimity'] = [0.595, -0.655, 0, 0.89, '#surprising', '#admirable', 0.713, 'tranquility', 'serenity', 'disposition', 'repose', 'placidity']
senticnet['equestrian_sport'] = [-0.024, -0.051, 0, 0.069, '#surprising', '#admirable', 0.032, 'polo', 'soccer', 'game', 'type_of_sport', 'expensive_sport']
senticnet['equidistribution'] = [0.948, -0.992, 0, 0.549, '#joyful', '#surprising', 0.83, 'sampling', 'distribution', 'frequency_distribution', 'normal_distribution', 'sample_distribution']
senticnet['equine'] = [0.03, 0.068, -0.044, 0.093, '#interesting', '#admirable', 0.049, 'critter', 'beast', 'live_creature', 'furry_creature', 'domesticate_animal']
senticnet['equinoctial_storm'] = [-0.872, 0, 0.91, -0.78, '#sad', '#angry', -0.854, 'storm', 'thundershower', 'rain', 'line_storm', 'rainstorm']
senticnet['equipment'] = [-0.024, -0.051, 0, 0.069, '#surprising', '#admirable', 0.032, 'fixture', 'endowment', 'material', 'stuff', 'kit']
senticnet['equipment_failure'] = [-0.816, 0, 0.849, -0.532, '#sad', '#angry', -0.732, 'dud', 'fault', 'failure', 'brake_failure', 'engine_failure']
senticnet['equipped'] = [0.84, -0.973, 0, 0.517, '#joyful', '#surprising', 0.777, 'prepared', 'visored', 'armored', 'outfitted', 'helmeted']
senticnet['equipt'] = [0.61, -0.889, 0, 0.83, '#surprising', '#admirable', 0.776, 'prepared', 'visored', 'armored', 'outfitted', 'helmeted']
senticnet['equity'] = [0, 0.101, -0.05, 0.059, '#interesting', '#admirable', 0.037, 'make_toy', 'frame_picture', 'smoke_alarm', 'buy_paint_brush', 'buy_paint']
senticnet['equivalence'] = [0.942, -0.826, 0, 0.828, '#joyful', '#admirable', 0.865, 'egality', 'egalite', 'tie', 'status', 'position']
senticnet['equivocal'] = [-0.642, 0, 0.576, -0.83, '#sad', '#disgusting', -0.683, 'nisi', 'indeterminate', 'inconclusive', 'neck_and_neck', 'nip_and_tuck']
senticnet['equivocalness'] = [0.738, -0.855, 0, 0.89, '#surprising', '#admirable', 0.828, 'evasiveness', 'twilight_zone', 'prevarication', 'no_man_land', 'unclearness']
senticnet['equivocation'] = [-0.89, 0, 0.669, -0.766, '#sad', '#disgusting', -0.775, 'deceit', 'deception', 'misrepresentation', 'indirect_expression', 'circumlocution']
senticnet['era'] = [0, 0.104, 0, 0.124, '#interesting', '#admirable', 0.076, 'good_trait', 'constant', 'time_increment', 'time_designation', 'time_length']
senticnet['erase'] = [0.292, 0.328, -0.098, 0.262, '#joyful', '#interesting', 0.261, 'fold_up', 'turn_knob', 'fill_ink', 'hold_hand', 'shut_door']
senticnet['erase_blackboard'] = [-0.127, 0, -0.051, 0, '#sad', '#scared', -0.059, 'lower_expectation', 'speak_english', 'master_skill', 'stand_alone', 'laugh_oneself']
senticnet['erase_pencil_mark'] = [-0.103, 0, 0, 0, '#sad', '#sad', -0.034, 'knock_door', 'smoke_cigar', 'pick_nose', 'make_card', 'cross_bridge']
senticnet['eraser'] = [0.853, -0.992, 0, 0, '#joyful', '#surprising', 0.615, 'stick_eraser', 'ballpoint_pen', 'intern', 'paper_clip', 'eraser_holder']
senticnet['eraser_holder'] = [0.038, 0, 0.01, 0.059, '#joyful', '#admirable', 0.029, 'paper_clip', 'computer_desk', 'pencil_box', 'electric_pencil_sharpener', 'folder']
senticnet['erect'] = [-0.101, 0.14, 0, 0.105, '#interesting', '#admirable', 0.048, 'build_house', 'put_up_construction', 'set_up', 'construct_skyscraper', 'put_up']
senticnet['erectile'] = [-0.986, 0, 0.702, -0.704, '#sad', '#disgusting', -0.797, 'expandable', 'expandible', 'expansible', 'expansive', 'cavernous']
senticnet['erection'] = [0.024, -0.031, -0.056, -0.216, '#scared', '#disgusting', -0.072, 'orgasm', 'wet_oneself', 'arousal', 'kill_brain_cell', 'feel_relieved']
senticnet['eremitic'] = [-0.948, 0, 0.779, -0.858, '#sad', '#disgusting', -0.862, 'unworldly', 'unworldlyal', 'cloistered', 'anchoritic', 'hermitic']
senticnet['eremitical'] = [-0.948, 0, 0.779, -0.858, '#sad', '#disgusting', -0.862, 'eremitic', 'unworldly', 'cloistered', 'anchoritic', 'hermitic']
senticnet['ergonomic_chair'] = [0.036, 0.232, -0.057, 0.192, '#interesting', '#admirable', 0.134, 'well_deigned', 'comfortable', 'useful', 'prevent_stress', 'ergonomic_pillow']
senticnet['ergonomic_pillow'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'well_deigned', 'comfortable', 'useful', 'prevent_stress', 'ergonomic_chair']
senticnet['ergotism'] = [-0.72, 0, 0.884, -0.758, '#angry', '#disgusting', -0.787, 'poisoning', 'paraquat_poisoning', 'alkali_poisoning', 'caffeinism', 'caffeine_intoxication']
senticnet['eristic'] = [0.655, -0.878, 0, 0.595, '#joyful', '#surprising', 0.709, 'hairsplitter', 'quarreler', 'fight', 'obstructor', 'obstructer']
senticnet['eristical'] = [0.702, -0.515, 0, 0.658, '#joyful', '#admirable', 0.625, 'contentious', 'disputatious', 'disputative', 'eristic', 'argumentative']
senticnet['erode'] = [-0.16, 0, -0.184, -0.239, '#scared', '#disgusting', -0.194, 'eat_off', 'remove', 'diminish', 'decrease', 'reduce']
senticnet['eroding'] = [-0.88, 0, 0.907, -0.522, '#sad', '#angry', -0.77, 'wearing', 'erosion', 'corrasion', 'eating_away', 'wearing_away']
senticnet['erosion'] = [-0.88, 0, 0.907, -0.522, '#sad', '#angry', -0.77, 'wearing', 'corrasion', 'eroding', 'eating_away', 'wearing_away']
senticnet['erotic'] = [0.229, 0.127, 0, 0, '#joyful', '#interesting', 0.119, 'sense_peace', 'feel_good', 'think_sex', 'feel_relieved', 'alter_state_consciousness']
senticnet['eroticism'] = [0.509, -0.863, 0, 0.691, '#surprising', '#admirable', 0.688, 'amorousness', 'sexiness', 'amativeness', 'carnality', 'erotism']
senticnet['erotism'] = [0.509, -0.863, 0, 0.691, '#surprising', '#admirable', 0.688, 'amorousness', 'sexiness', 'amativeness', 'eroticism', 'carnality']
senticnet['err'] = [-0.775, 0, 0.981, -0.522, '#sad', '#angry', -0.759, 'trip_up', 'stumble', 'misjudge', 'misremember', 'fall_for']
senticnet['errant'] = [-0.831, 0, 0.962, -0.627, '#sad', '#angry', -0.807, 'unreliable', 'undependable', 'weak', 'fallible', 'erring']
senticnet['erratic'] = [0, 0, -0.895, -0.942, '#scared', '#disgusting', -0.612, 'fickle', 'wandering', 'planetary', 'quicksilver', 'mercurial']
senticnet['erring'] = [-0.831, 0, 0.962, -0.627, '#sad', '#angry', -0.807, 'unreliable', 'undependable', 'weak', 'errant', 'fallible']
senticnet['erroneous_belief'] = [-0.701, 0, 0.533, -0.627, '#sad', '#disgusting', -0.62, 'misconception', 'error', 'misunderstanding', 'hallucination', 'fancy']
senticnet['error'] = [0, 0, 0, -0.821, '#disgusting', '#disgusting', -0.274, 'retribution', 'put_in_jail', 'sleepless_night', 'mistake', 'go_to_jail']
senticnet['erudite'] = [0.71, -0.811, 0, 0.937, '#surprising', '#admirable', 0.819, 'scholarly', 'donnish', 'pedantic', 'learned', 'bookish']
senticnet['erudition'] = [0.758, 0, 0, 0.939, '#joyful', '#admirable', 0.566, 'encyclopedism', 'learning', 'scholarship', 'learnedness', 'eruditeness']
senticnet['erythema'] = [-0.859, 0, 0.676, -0.827, '#sad', '#disgusting', -0.787, 'erythroderma', 'erythema_nodosum', 'erythema_multiforme', 'windburn', 'hickey']
senticnet['erythema_multiforme'] = [-0.859, 0, 0.676, -0.827, '#sad', '#disgusting', -0.787, 'erythroderma', 'erythema_nodosum', 'erythema', 'windburn', 'hickey']
senticnet['erythema_nodosum'] = [-0.859, 0, 0.676, -0.827, '#sad', '#disgusting', -0.787, 'erythroderma', 'erythema', 'erythema_multiforme', 'windburn', 'hickey']
senticnet['erythroderma'] = [-0.898, 0, 0.998, -0.898, '#sad', '#angry', -0.931, 'erythema', 'flare', 'skin_disease', 'disease_of_skin', 'skin_disorder']
senticnet['esaminatore'] = [0.711, 0, 0, 0, '#joyful', '#joyful', 0.237, 'analyst', 'expert', 'scientist', 'chemist', 'physicist']
senticnet['escape'] = [-0.691, 0, 0.998, -0.84, '#angry', '#disgusting', -0.843, 'evasion', 'lam', 'break', 'skedaddle', 'hegira']
senticnet['escape_expert'] = [0.9, -0.882, 0, 0.687, '#joyful', '#surprising', 0.823, 'escapologist', 'conjurer', 'mind_reader', 'telepathist', 'performer']
senticnet['escape_fire'] = [-0.049, 0, -0.076, -0.095, '#scared', '#disgusting', -0.073, 'get_floor_another', 'go_up_down', 'climb_up', 'go_upstairs', 'move_between_floor_build']
senticnet['escape_justice'] = [-0.931, 0, 0.945, -0.932, '#angry', '#disgusting', -0.936, 'prison_breaker', 'escape_prison', 'illegal', 'break_rule', 'stole_goods']
senticnet['escape_mechanism'] = [-0.102, 0, 0, 0, '#sad', '#sad', -0.034, 'carelessness', 'negligence', 'neglect', 'soldiering', 'dodging']
senticnet['escape_prison'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'prison_breaker', 'break_rule', 'illegal', 'escape_justice', 'prisoner']
senticnet['escape_reality'] = [0.845, 0, 0, 0, '#joyful', '#joyful', 0.282, 'acculturation', 'entertainment_learn', 'cultural_experience', 'enjoy_story', 'pastime']
senticnet['escape_situation'] = [-0.126, 0, 0, -0.036, '#sad', '#disgusting', -0.054, 'escape', 'bail_out', 'cancel_meeting', 'absent', 'cancel_appointment']
senticnet['escapist'] = [-0.644, 0, 0.524, -0.598, '#sad', '#disgusting', -0.589, 'bum', 'dreamer', 'stargazer', 'daydreamer', 'wishful_thinker']
senticnet['escapologist'] = [0.9, -0.882, 0, 0.687, '#joyful', '#surprising', 0.823, 'conjurer', 'escape_expert', 'mind_reader', 'telepathist', 'performer']
senticnet['escort'] = [-0.743, 0, 0.512, -0.668, '#sad', '#disgusting', -0.641, 'yeoman', 'outrider', 'yeoman_of_guard', 'beefeater', 'defender']
senticnet['escrow_funds'] = [0.534, -0.868, 0, 0.736, '#surprising', '#admirable', 0.713, 'funds', 'finances', 'monetary_resource', 'cash_in_hand', 'pecuniary_resource']
senticnet['eskimo'] = [0, 0.102, 0, 0, '#interesting', '#interesting', 0.034, 'frostbite', 'mountain_goat', 'weather_event', 'glacier', 'coldness']
senticnet['esp'] = [0.832, 0.861, 0, 0.848, '#interesting', '#admirable', 0.847, 'extrasensory_perception', 'psychic_phenomenon', 'parapsychology', 'precognition', 'foreknowledge']
senticnet['espouse'] = [0, 0, -0.823, -0.948, '#scared', '#disgusting', -0.59, 'wed', 'adopt', 'follow', 'marry', 'get_married']
senticnet['espresso'] = [0.832, 0.861, 0, 0.848, '#interesting', '#admirable', 0.847, 'drink_espresso', 'go_cafe', 'drink_coffee', 'eat_dinner', 'coffee']
senticnet['essay'] = [-0.702, 0, 0.767, -0.935, '#angry', '#disgusting', -0.801, 'report', 'composition', 'paper', 'theme', 'disquisition']
senticnet['essence'] = [0.645, -0.766, 0, 0.961, '#surprising', '#admirable', 0.791, 'content', 'quintessence', 'stuff', 'bare_bones', 'hypostasis']
senticnet['essential'] = [0.851, 0, 0, 0.931, '#joyful', '#admirable', 0.594, 'strong_desire', 'needful', 'necessary', 'compel', 'requirement']
senticnet['essential_condition'] = [0.695, -0.856, 0, 0.501, '#joyful', '#surprising', 0.684, 'prerequisite', 'sine_qua_non', 'responsibility', 'precondition', 'academic_requirement']
senticnet['essential_human_life'] = [0, 0.078, -0.077, 0.147, '#interesting', '#admirable', 0.049, 'essential_life', 'necessary_life', 'watery', 'liquid', 'fluid']
senticnet['essential_life'] = [0.047, 0.123, -0.056, 0.157, '#interesting', '#admirable', 0.09, 'essential_human_life', 'use_cook', 'translucent', 'liquid_substance', 'transparent']
senticnet['establish'] = [0.075, 0.177, 0, 0.076, '#interesting', '#admirable', 0.109, 'institution', 'wonderful_place_visit', 'institute', 'corporation', 'establishment']
senticnet['establish_credit'] = [0.036, 0.232, -0.057, 0.192, '#interesting', '#admirable', 0.134, 'money_spend', 'credit', 'purchase', 'pay_goods', 'pay_debt']
senticnet['establishment'] = [0.075, 0.177, 0, 0.076, '#interesting', '#admirable', 0.109, 'institution', 'wonderful_place_visit', 'institute', 'corporation', 'establish']
senticnet['estate'] = [0, 0.179, -0.055, 0.162, '#interesting', '#admirable', 0.095, 'house_land', 'real_estate', 'acreage', 'house_place', 'good_investment']
senticnet['estate_car'] = [0.695, -0.856, 0, 0.501, '#joyful', '#surprising', 0.684, 'beach_wagon', 'station_wagon', 'wagon', 'shooting_brake', 'beach_waggon']
senticnet['esteem'] = [0.859, 0.725, 0, 0.76, '#joyful', '#admirable', 0.781, 'confident', 'adoration', 'encouragement', 'hero_worship', 'look_up_to']
senticnet['esteemed'] = [0.991, -0.989, 0, 0.588, '#joyful', '#surprising', 0.856, 'estimable', 'respected', 'reputable', 'honored', 'prestigious']
senticnet['esthesis'] = [-0.802, 0, 0.885, -0.533, '#sad', '#angry', -0.74, 'masking', 'taste', 'threshold', 'perception', 'limen']
senticnet['esthetic'] = [0.737, -0.854, 0, 0.623, '#joyful', '#surprising', 0.738, 'understated', 'tasteful', 'atasteful', 'artistic', 'unostentatious']
senticnet['esthetical'] = [0.679, -0.794, 0, 0.66, '#joyful', '#surprising', 0.711, 'cosmetic', 'painterly', 'sensuous', 'artistic', 'enhancive']
senticnet['estimable'] = [0.983, -0.807, 0, 0.966, '#joyful', '#admirable', 0.919, 'calculable', 'computable', 'countable', 'denumerable', 'enumerable']
senticnet['estimate'] = [-0.023, 0.248, 0, 0.31, '#interesting', '#admirable', 0.178, 'assurance', 'total', 'quality', 'importance', 'amount']
senticnet['estimation'] = [0.83, -0.835, 0, 0.872, '#surprising', '#admirable', 0.846, 'overappraisal', 'overvaluation', 'overestimate', 'overestimation', 'commercial_document']
senticnet['estrange'] = [-0.542, 0, 0.706, -0.626, '#angry', '#disgusting', -0.625, 'alienated', 'alienation', 'disaffection', 'alienate', 'disoriented']
senticnet['estranged'] = [-0.106, 0.176, 0.629, -0.642, '#angry', '#disgusting', -0.4, 'alienated', 'alienation', 'disaffection', 'estrange', 'alienate']
senticnet['estrangement'] = [-0.106, 0.176, 0.629, -0.642, '#angry', '#disgusting', -0.4, 'alienated', 'alienation', 'disaffection', 'estrange', 'alienate']
senticnet['esurience'] = [0.768, -0.723, 0, 0.838, '#joyful', '#admirable', 0.776, 'edacity', 'gluttony', 'voracity', 'voraciousness', 'rapaciousness']
senticnet['esurient'] = [-0.713, 0, 0.692, -0.818, '#sad', '#disgusting', -0.741, 'famished', 'starved', 'ravenous', 'hungry', 'peckish']
senticnet['eternal'] = [0.051, 0.207, -0.181, 0.264, '#interesting', '#admirable', 0.114, 'everlasting', 'forever', 'unending', 'endless', 'eternity']
senticnet['eternal_life'] = [0.695, -0.856, 0, 0.501, '#joyful', '#surprising', 0.684, 'immortality', 'live_forever', 'never_die', 'immortal', 'everlasting_life']
senticnet['eternity'] = [0, 0.106, -0.055, 0.116, '#interesting', '#admirable', 0.056, 'never_end', 'endless', 'live_forever', 'soon', 'general_time']
senticnet['ethanol'] = [0.832, 0.8, 0, 0, '#joyful', '#interesting', 0.544, 'part_of_dinner', 'cola', 'liquid_beverage', 'juice', 'soft_drink']
senticnet['ethereal'] = [-0.961, 0, 0.939, -0.605, '#sad', '#angry', -0.835, 'airy', 'shadowy', 'stringy', 'wraithlike', 'insubstantial']
senticnet['ethic'] = [0.897, 0, 0, 0.892, '#joyful', '#admirable', 0.596, 'punctual', 'truth', 'certain', 'trait', 'good_character']
senticnet['ethical_code'] = [0.661, -0.666, 0, 0.685, '#surprising', '#admirable', 0.671, 'system_of_rules', 'theosophy', 'anthroposophy', 'logic', 'method']
senticnet['ethical_motive'] = [-0.826, 0, 0.599, -0.727, '#sad', '#disgusting', -0.717, 'motive', 'need', 'motivation', 'conscience', 'scruple']
senticnet['ethicism'] = [-0.986, 0, 0.968, -0.626, '#sad', '#angry', -0.86, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['ethnicity'] = [0.969, 0, 0, 0.962, '#joyful', '#admirable', 0.644, 'clean_shoes', 'black_stuff', 'paint_nail', 'nationality', 'black_goo']
senticnet['ethyl_alcohol'] = [-0.915, 0, 0.65, -0.594, '#sad', '#angry', -0.72, 'absolute_alcohol', 'spirits_of_wine', 'denatured_alcohol', 'alcohol', 'plant_product']
senticnet['etiquette'] = [0, 0, 0, 0.99, '#admirable', '#admirable', 0.33, 'politeness', 'good_behavior', 'good_etiquette', 'manner', 'hint']
senticnet['eubacteria'] = [-0.908, 0, 0.908, -0.538, '#sad', '#angry', -0.785, 'tubercle_bacillus', 'leprosy_bacillus', 'mycobacteria', 'eubacterium', 'true_bacteria']
senticnet['eubacterium'] = [-0.908, 0, 0.908, -0.538, '#sad', '#angry', -0.785, 'tubercle_bacillus', 'leprosy_bacillus', 'eubacteria', 'mycobacteria', 'true_bacteria']
senticnet['eudaemon'] = [0.612, -0.653, 0, 0.941, '#surprising', '#admirable', 0.735, 'eudemon', 'guardian_spirit', 'good_spirit', 'genius_loci', 'angel']
senticnet['eudaimonia'] = [0.971, -0.717, 0, 0.656, '#joyful', '#surprising', 0.781, 'wellbeing', 'human_flourishing', 'successfulness', 'upbeat', 'strength']
senticnet['eudemon'] = [0.673, -0.64, 0, 0.669, '#joyful', '#admirable', 0.661, 'guardian_angel', 'white_angel', 'good_spirit', 'genius_loci', 'angel']
senticnet['eudemonism'] = [0.601, -0.846, 0, 0.872, '#surprising', '#admirable', 0.773, 'bioethics', 'hedonism', 'philosophy', 'casuistry', 'moral_philosophy']
senticnet['eukaryote'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'flora', 'carbon_monoxide', 'endangered_species', 'rodent', 'tree_animal']
senticnet['eulogistic'] = [0.722, -0.981, 0, 0.832, '#surprising', '#admirable', 0.845, 'laudatory', 'praiseful', 'praising', 'encomiastic', 'complimentary']
senticnet['eulogy'] = [0, 0, -0.857, -0.991, '#scared', '#disgusting', -0.616, 'paean', 'eulogium', 'encomium', 'pean', 'panegyric']
senticnet['euphoria'] = [0.973, 0, 0, 0.729, '#joyful', '#admirable', 0.567, 'cheer', 'contentment', 'elation', 'jubilation', 'glee']
senticnet['euphoriant'] = [0.672, 0.632, -0.239, 0.312, '#joyful', '#interesting', 0.459, 'euphoria', 'buoyancy', 'perkiness', 'jubilance', 'ecstasy']
senticnet['euphoric'] = [0.663, 0.634, -0.241, 0.303, '#joyful', '#interesting', 0.453, 'euphoria', 'euphoriant', 'mirthfully', 'merrily', 'happily']
senticnet['eureka'] = [-0.063, 0.21, 0, 0.076, '#interesting', '#admirable', 0.074, 'new_think', 'figure_out', 'brain_activity', 'idea', 'come_up_idea']
senticnet['eurhythmics'] = [0.536, -0.569, 0, 0.567, '#surprising', '#admirable', 0.557, 'recreation', 'diversion', 'move', 'motility', 'movement']
senticnet['eurhythmy'] = [0.964, -0.861, 0, 0.957, '#joyful', '#admirable', 0.927, 'recreation', 'diversion', 'move', 'motility', 'movement']
senticnet['euro'] = [0.91, 0.817, 0, 0, '#joyful', '#interesting', 0.576, 'dollar_bill', 'franc', 'banknote', 'dollar', 'cent']
senticnet['euronithopod'] = [-0.927, 0, 0.64, -0.529, '#sad', '#angry', -0.699, 'perching_bird', 'percher', 'thyreophoran', 'marginocephalian', 'animal_order']
senticnet['eurythmics'] = [0.556, -0.868, 0, 0.846, '#surprising', '#admirable', 0.757, 'recreation', 'diversion', 'move', 'motility', 'movement']
senticnet['eurythmy'] = [0.96, -0.858, 0, 0.934, '#joyful', '#admirable', 0.917, 'recreation', 'diversion', 'move', 'motility', 'movement']
senticnet['evacuation'] = [-0.792, 0, -1.0, 0, '#sad', '#scared', -0.597, 'escape', 'creeper', 'substitute', 'leave', 'fuse']
senticnet['evaluate'] = [0.916, 0.991, 0, 0, '#joyful', '#interesting', 0.636, 'get_result', 'classify', 'evaluation', 'seek_understanding', 'learn_fact']
senticnet['evaluation'] = [-0.066, 0.18, 0, 0.143, '#interesting', '#admirable', 0.086, 'grade', 'multiple_choices', 'final', 'final_exam', 'school_grade']
senticnet['evanesce'] = [-0.882, 0, 0.682, -0.603, '#sad', '#angry', -0.722, 'absent', 'fall_away', 'disappear', 'blow_over', 'pass_off']
senticnet['evangelist'] = [0, 0.256, -0.057, 0.206, '#interesting', '#admirable', 0.135, 'minister', 'pope', 'rector', 'saint', 'church_head']
senticnet['evaporate'] = [0, 0.073, -0.052, 0.093, '#interesting', '#admirable', 0.038, 'vapor', 'water_vapor', 'condense_water', 'gaseous', 'bubble']
senticnet['evasion'] = [-0.513, 0, 0.848, -0.964, '#angry', '#disgusting', -0.775, 'deceit', 'deception', 'misrepresentation', 'indirect_expression', 'circumlocution']
senticnet['evasiveness'] = [0.738, -0.855, 0, 0.89, '#surprising', '#admirable', 0.828, 'equivocalness', 'twilight_zone', 'prevarication', 'no_man_land', 'unclearness']
senticnet['eve'] = [0, 0.085, 0, 0.146, '#interesting', '#admirable', 0.077, 'adam_and_eden', 'garden', 'apple', 'eden', 'outdoor']
senticnet['even'] = [0, 0, -0.837, -0.998, '#scared', '#disgusting', -0.612, 'flush', 'level', 'fifty-fifty', 'regular', 'tied']
senticnet['even_odds'] = [-0.129, 0, -0.081, -0.067, '#sad', '#scared', -0.092, 'hunt_game', 'kill_other_person', 'arm_bomb', 'corner_prey', 'warm_hand']
senticnet['even_out'] = [-0.73, 0, 0, -0.89, '#sad', '#disgusting', -0.54, 'revenge', 'experience_emotion', 'take_revenge', 'vengeful', 'waste_time']
senticnet['even_score'] = [-0.147, 0, -0.1, 0, '#sad', '#scared', -0.082, 'draw', 'even_odds', 'raise_flag', 'like_boy', 'kill_other_person']
senticnet['event'] = [0.911, 0, 0, 0.745, '#joyful', '#admirable', 0.552, 'special_time', 'occasion', 'happen', 'incident', 'occurrence']
senticnet['event_type'] = [-0.949, 0, -0.923, 0, '#sad', '#scared', -0.624, 'special_event', 'type', 'birthday_party', 'event', 'bachelor_party']
senticnet['evergreen'] = [0.945, -0.849, 0, 0, '#joyful', '#surprising', 0.598, 'stem', 'leaf', 'moss', 'branch', 'leaf_tree']
senticnet['evergreen_christmas_tree'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'christmas_tree', 'tree', 'big_christmas_tree', 'christmas_holiday', 'christmas']
senticnet['evergreen_tree'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'tree', 'big_tree', 'christmas_tree', 'evergreen_christmas_tree', 'christmas']
senticnet['everlasting'] = [0.938, 0, 0, 0.997, '#joyful', '#admirable', 0.645, 'forever', 'eternal', 'unending', 'eternity', 'never_end']
senticnet['everlasting_flower'] = [-0.934, 0, 0.691, -0.971, '#sad', '#disgusting', -0.865, 'cudweed', 'strawflower', 'composite', 'composite_plant', 'pink_paper_daisy']
senticnet['everlasting_life'] = [0.661, -0.666, 0, 0.685, '#surprising', '#admirable', 0.671, 'immortality', 'live_forever', 'never_die', 'eternal_life', 'immortal']
senticnet['every_day'] = [0, 0.142, -0.067, 0.173, '#interesting', '#admirable', 0.083, 'common', 'usual', 'circumstance', 'wake_up', 'daily']
senticnet['every_home'] = [0, -0.069, 0, 0, '#surprising', '#surprising', 0.023, 'appliance_store', 'apartment', 'relative_house', 'kitchen', 'coffee_shop']
senticnet['every_town'] = [-0.033, 0.099, 0.017, 0.102, '#interesting', '#admirable', 0.05, 'city_center', 'downtown', 'monument', 'cathedral', 'town_center']
senticnet['everyday'] = [-0.073, 0.173, -0.168, 0.275, '#interesting', '#admirable', 0.069, 'typical', 'usual_ordinary', 'common', 'repeat', 'normal']
senticnet['everydayness'] = [0.563, -0.994, 0, 0.779, '#surprising', '#admirable', 0.779, 'mundaneness', 'mundanity', 'prosiness', 'prosaicness', 'ordinariness']
senticnet['everyone_know'] = [-0.995, 0, -0.717, 0, '#sad', '#scared', -0.571, 'well_known', 'newscaster', 'famous', 'tell_everyone', 'advise']
senticnet['everything'] = [0.056, 0.174, -0.081, 0.247, '#interesting', '#admirable', 0.132, 'encompass', 'infinite', 'unlimited', 'comparative', 'totality']
senticnet['everywhere'] = [0, 0.093, 0, 0.053, '#interesting', '#admirable', 0.049, 'underground', 'under_ground', 'environment', 'outpost', 'dark_place']
senticnet['evict'] = [-0.711, 0, 0.954, -0.563, '#sad', '#angry', -0.743, 'eject', 'chuck_out', 'exclude', 'turf_out', 'boot_out']
senticnet['eviction'] = [-0.751, 0, 0.735, -0.872, '#sad', '#disgusting', -0.786, 'due_process', 'defense', 'plea', 'dispossession', 'proceeding']
senticnet['evidence'] = [0.059, 0.219, -0.082, 0.15, '#interesting', '#admirable', 0.115, 'proof', 'counsel', 'fairness', 'selection', 'confirmation']
senticnet['evident'] = [0.958, -0.838, 0, 0.81, '#joyful', '#surprising', 0.869, 'discernible', 'perceptible', 'noticeable', 'detectable', 'observable']
senticnet['evil'] = [0, 0, -0.706, -0.825, '#scared', '#disgusting', -0.51, 'hatred', 'hate', 'aggression', 'angry', 'aggressive']
senticnet['evil_deed'] = [-0.966, 0, 0.313, -0.934, '#sad', '#disgusting', -0.738, 'bad', 'bad_person', 'sin', 'crime', 'evil_man']
senticnet['evil_dude'] = [0, 0, -0.808, -0.718, '#scared', '#disgusting', -0.509, 'get_rid_of_enemy', 'kill_another_person', 'cause_death', 'murder', 'defend_oneself']
senticnet['evil_eye'] = [-0.995, 0, 0.522, -0.982, '#sad', '#disgusting', -0.833, 'evil', 'bad_person', 'evil_man', 'kill_somebody', 'fight_somebody']
senticnet['evil_man'] = [-0.941, 0, 0.105, -0.967, '#sad', '#disgusting', -0.671, 'bad_person', 'bad', 'bad_character', 'evil_eye', 'bad_action']
senticnet['evil_person'] = [-0.915, 0, 0.228, -0.944, '#sad', '#disgusting', -0.696, 'evil_man', 'evil_eye', 'kill_person', 'evil', 'bad_person']
senticnet['evil_spirit'] = [-0.678, 0, 0.752, -0.898, '#angry', '#disgusting', -0.776, 'bad_fairy', 'fiend', 'demon', 'devil', 'daimon']
senticnet['evilness'] = [-0.53, 0, 0.835, -0.648, '#angry', '#disgusting', -0.671, 'malevolence', 'malevolency', 'malice', 'malignity', 'mischief']
senticnet['eviscerate'] = [-0.639, 0, 0.503, -0.736, '#sad', '#disgusting', -0.626, 'wounded', 'mangled', 'torn', 'hurt', 'injured']
senticnet['evocative'] = [0.709, -0.613, 0, 0.762, '#joyful', '#admirable', 0.695, 'careful', 'heedful', 'resonant', 'mindful', 'redolent']
senticnet['evoke'] = [0.722, -0.764, 0, 0.946, '#surprising', '#admirable', 0.811, 'arouse', 'elicit', 'enkindle', 'kindle', 'ask_for']
senticnet['evoke_emotion'] = [0.047, -0.063, 0, -0.032, '#joyful', '#surprising', 0.026, 'convey_information', 'tell_story', 'express_idea', 'recite_poem', 'share_thought']
senticnet['evolution'] = [0, 0.248, -0.066, 0.222, '#interesting', '#admirable', 0.135, 'conjecture', 'scientific_statement', 'hypothetical', 'logical', 'theory']
senticnet['evolve'] = [-0.031, 0.128, -0.092, 0.255, '#interesting', '#admirable', 0.087, 'live_simply', 'transition', 'change_life', 'backup', 'go_forward']
senticnet['ewe'] = [0, -0.036, 0.057, -0.089, '#angry', '#disgusting', -0.037, 'lamb_meat', 'bandage', 'shear', 'mutton', 'seam']
senticnet['exacerbate'] = [-0.121, 0.069, 0.703, -0.673, '#angry', '#disgusting', -0.476, 'aggravate', 'provoked', 'aggravated', 'exasperation', 'displeased']
senticnet['exacerbating'] = [0.652, -0.649, 0, 0.953, '#joyful', '#admirable', 0.751, 'heightening', 'thickening', 'aggravating', 'intensifying', 'deepening']
senticnet['exact'] = [0, 0.112, 0, 0.097, '#interesting', '#admirable', 0.07, 'math_relate', 'math_subject', 'school_study', 'median', 'method']
senticnet['exacting'] = [-0.756, 0, 0.982, -0.958, '#angry', '#disgusting', -0.899, 'needy', 'stringent', 'stern', 'demanding', 'exigent']
senticnet['exaction'] = [-0.089, 0, -0.153, -0.206, '#scared', '#disgusting', -0.149, 'ask_money', 'extortion', 'wringing', 'intimidate', 'psychological_pressure']
senticnet['exactitude'] = [0.567, -0.56, 0, 0.724, '#joyful', '#admirable', 0.617, 'truth', 'accuracy', 'preciseness', 'trueness', 'precision']
senticnet['exactness'] = [0.707, -0.741, 0, 0.832, '#surprising', '#admirable', 0.76, 'truth', 'accuracy', 'preciseness', 'trueness', 'precision']
senticnet['exaggerate'] = [-0.946, 0, 0, -0.774, '#sad', '#disgusting', -0.573, 'receive_applause', 'wave_arm', 'show_off', 'laugh', 'applause']
senticnet['exalt'] = [0.645, 0.637, -0.239, 0.299, '#joyful', '#interesting', 0.447, 'gladdened', 'stimulating', 'tickle_pink', 'inebriate', 'beatify']
senticnet['exalted'] = [0, -0.985, 0, 0.783, '#surprising', '#admirable', 0.589, 'laud', 'extol', 'glorify', 'proclaim', 'exhilarate']
senticnet['exam'] = [-0.874, 0, 0.867, -0.771, '#sad', '#angry', -0.837, 'inquiry', 'interrogation', 'detention', 'prison', 'thief']
senticnet['exam_failed'] = [-0.966, 0, 0.414, -0.94, '#sad', '#disgusting', -0.773, 'bad_feeling', 'feel_terrible', 'job_interview_failed', 'trouble', 'problem']
senticnet['exam_table'] = [-0.983, 0, 0, -0.946, '#sad', '#disgusting', -0.643, 'classroom_chair', 'lead_pencil', 'eraser_holder', 'atheist', 'text_book']
senticnet['examination'] = [-0.075, 0, -0.133, 0, '#sad', '#scared', -0.069, 'know_healthy', 'nervous_breakdown', 'physical_exam', 'check_vital_sign', 'epileptic_fit']
senticnet['examination_table'] = [-0.039, 0, -0.107, -0.152, '#scared', '#disgusting', -0.099, 'latex_glove', 'medical_record', 'syringe', 'wait_room', 'doctor_examination_room']
senticnet['examine'] = [0.056, -0.035, 0, 0.054, '#joyful', '#admirable', 0.048, 'analyze', 'stargazing', 'influence_public_decision', 'question_everything', 'see_artifact']
senticnet['examine_evidence'] = [0, 0.923, 0, 0, '#interesting', '#interesting', 0.308, 'resolve_conflict', 'consider_evidence', 'decide_guilt', 'resolve_case', 'judgment']
senticnet['example'] = [0, 0.142, -0.082, 0.258, '#interesting', '#admirable', 0.106, 'description', 'show_sample', 'show_how', 'sample', 'teach']
senticnet['exasperate'] = [-0.125, 0.107, 0.668, -0.658, '#angry', '#disgusting', -0.448, 'lividity', 'livid', 'lividly', 'wrathfully', 'wrothful']
senticnet['exasperated'] = [0, 0, -0.969, -0.903, '#scared', '#disgusting', -0.624, 'incense', 'worsen', 'infuriate', 'exacerbate', 'aggravate']
senticnet['exasperating'] = [-0.127, 0.13, 0.647, -0.648, '#angry', '#disgusting', -0.431, 'infuriate', 'infuriating', 'maddening', 'furiously', 'dudgeon']
senticnet['exasperation'] = [-0.121, 0.069, 0.703, -0.673, '#angry', '#disgusting', -0.476, 'aggravate', 'exacerbate', 'provoked', 'aggravated', 'displeased']
senticnet['excavate'] = [0, 0, 0.042, -0.047, '#angry', '#disgusting', -0.03, 'dig', 'hollow', 'cavity', 'hollow_out', 'hole']
senticnet['excavation'] = [0, 0.11, 0, 0.077, '#interesting', '#admirable', 0.062, 'mountain', 'skier', 'mound', 'pyramid', 'snake']
senticnet['exceed'] = [0.849, 0, 0, 0.908, '#joyful', '#admirable', 0.586, 'outrank', 'shine_at', 'excel_at', 'surpass', 'excel']
senticnet['excel'] = [0.905, 0, 0, 0.815, '#joyful', '#admirable', 0.573, 'really_good', 'high_quality', 'well_done', 'best', 'compliment']
senticnet['excel_at'] = [0.661, -0.666, 0, 0.685, '#surprising', '#admirable', 0.671, 'rank', 'outrank', 'shine_at', 'surpass', 'exceed']
senticnet['excellence'] = [0.835, 0, 0, 0.71, '#joyful', '#admirable', 0.515, 'high_standard', 'superlative', 'well_done', 'really_good', 'high_quality']
senticnet['excellent'] = [0.781, 0, 0, 0.706, '#joyful', '#admirable', 0.496, 'goodness', 'best', 'quality', 'great', 'well_done']
senticnet['except'] = [-0.25, 0, -0.174, -0.082, '#sad', '#scared', -0.169, 'social_exclusion', 'exclusion_zone', 'isolation', 'unless', 'exclusion']
senticnet['exception'] = [-0.045, 0.234, -0.101, 0.263, '#interesting', '#admirable', 0.117, 'different', 'alternative', 'unusual', 'rear_end', 'outlier']
senticnet['exceptional'] = [0.065, -0.186, -0.179, 0.538, '#surprising', '#admirable', 0.203, 'better_good', 'most_good', 'really_good', 'high_quality', 'well_done']
senticnet['excercise'] = [-0.045, -0.045, 0.056, -0.1, '#angry', '#disgusting', -0.052, 'exercise', 'exercise_regularly', 'need_fresh_air', 'car_repair', 'strong_muscle']
senticnet['excess'] = [-0.501, 0, 0.89, -0.786, '#angry', '#disgusting', -0.726, 'immoderateness', 'degree', 'grade', 'level', 'immoderatenessiveness']
senticnet['excessive'] = [-0.364, -0.179, -0.205, 0.062, '#sad', '#scared', -0.109, 'intense', 'extreme', 'nervous', 'tense', 'intense_heat']
senticnet['excessive_heat'] = [0, 0, 0.897, -0.835, '#angry', '#disgusting', -0.577, 'burn_finger', 'burn_down_house', 'create_flame', 'gather_wood', 'get_burnt']
senticnet['excessiveness'] = [-0.501, 0, 0.89, -0.786, '#angry', '#disgusting', -0.726, 'excess', 'degree', 'grade', 'level', 'immoderateness']
senticnet['exchange'] = [-0.055, 0.299, -0.106, 0.252, '#interesting', '#admirable', 0.13, 'trade', 'business_deal', 'bargain', 'deal', 'good_buy']
senticnet['exchange_gift'] = [0.123, 0.29, -0.192, 0.278, '#interesting', '#admirable', 0.166, 'christmas', 'demand', 'courteous', 'yearn', 'need']
senticnet['exchange_goods'] = [-0.035, 0.238, 0, 0.228, '#interesting', '#admirable', 0.144, 'swap', 'give_take', 'transaction', 'barter', 'commerce']
senticnet['exchange_idea'] = [0.851, 0, 0, 0.806, '#joyful', '#admirable', 0.552, 'exchange_information', 'share_idea', 'misunderstanding', 'persuade', 'express_opinion']
senticnet['exchange_information'] = [0.849, 0, 0, 0.861, '#joyful', '#admirable', 0.57, 'exchange_idea', 'social_life', 'keep_in_touch', 'give_information', 'communicate_person']
senticnet['exchange_knowledge'] = [0.661, -0.666, 0, 0.685, '#surprising', '#admirable', 0.671, 'share_idea', 'knowledge', 'transfer_knowledge', 'exchange_idea', 'share_knowledge']
senticnet['exchange_money'] = [-0.044, 0.125, 0, 0.093, '#interesting', '#admirable', 0.058, 'sell', 'make_rich', 'purchase', 'bankruptcy', 'pay_service']
senticnet['exchange_opinion'] = [0.875, 0, 0, 0.802, '#joyful', '#admirable', 0.559, 'meeting', 'attend_conference', 'attend_event', 'attend_meeting', 'exchange_information']
senticnet['exchangeability'] = [0.912, -0.757, 0, 0.512, '#joyful', '#surprising', 0.727, 'transferability', 'convertibility', 'changeableness', 'changeability', 'permutability']
senticnet['exchangeable'] = [0.552, -0.585, 0, 0.762, '#surprising', '#admirable', 0.633, 'transposable', 'permutable', 'fungible', 'commutable', 'substitutable']
senticnet['exchanged'] = [0.78, -0.799, 0, 0.954, '#surprising', '#admirable', 0.844, 'transformed', 'varied', 'changed', 'denatured', 'denaturized']
senticnet['excise'] = [-0.085, 0.358, -0.202, 0.237, '#interesting', '#admirable', 0.103, 'extortion', 'money_due', 'afford', 'bribe', 'owe']
senticnet['excitability'] = [0.698, -0.614, 0, 0.619, '#joyful', '#admirable', 0.644, 'sensitivity', 'sensitiveness', 'irritability', 'sensibility', 'reactivity']
senticnet['excitable'] = [0.963, -0.987, 0, 0.514, '#joyful', '#surprising', 0.821, 'warm', 'flighty', 'nervous', 'skittish', 'spooky']
senticnet['excitant'] = [0.95, -0.951, 0, 0.769, '#joyful', '#surprising', 0.89, 'adrenocorticotropic', 'adrenocorticotrophic', 'stimulant', 'stimulating', 'stimulative']
senticnet['excitation'] = [0.705, -0.933, 0, 0.89, '#surprising', '#admirable', 0.843, 'fervor', 'emotional_arousal', 'excitement', 'arousal', 'anger']
senticnet['excite'] = [0.847, 0.936, 0, 0, '#joyful', '#interesting', 0.594, 'enjoy', 'excitement', 'feel_different', 'joy', 'funny']
senticnet['excite_game'] = [0.077, -0.097, 0.035, 0, '#joyful', '#surprising', 0.046, 'sport_play', 'rough_game', 'ball_sport', 'team_sport', 'fun_game']
senticnet['excited'] = [0.766, -0.875, 0, 0.666, '#joyful', '#surprising', 0.769, 'oxidizable', 'unstable', 'labile', 'activated', 'reactive']
senticnet['excitement'] = [0.772, 0.742, 0, 0, '#joyful', '#interesting', 0.505, 'enjoy', 'satisfaction', 'happiness', 'become_excited', 'joy']
senticnet['exciting'] = [0.481, 0.659, -0.249, 0.236, '#joyful', '#interesting', 0.376, 'enthusiastic', 'enthusiastically', 'unfearing', 'intrepid', 'dauntlessly']
senticnet['exclaim'] = [-0.735, 0, 0.852, -0.872, '#angry', '#disgusting', -0.82, 'express', 'utter', 'gee', 'ooh', 'aah']
senticnet['exclaiming'] = [-0.958, 0, 0.644, -0.7, '#sad', '#disgusting', -0.767, 'ejaculation', 'interjection', 'devil', 'expostulation', 'deuce']
senticnet['exclamation'] = [0, 0.158, -0.123, 0.359, '#interesting', '#admirable', 0.131, 'statement', 'affirmation', 'proclamation', 'clam', 'proposition']
senticnet['exclude'] = [-0.211, -0.083, 0.018, -0.166, '#sad', '#disgusting', -0.104, 'leave_out', 'ridiculous', 'pollute_air', 'kick_out', 'reprimand']
senticnet['exclusion'] = [-0.25, 0, -0.174, -0.082, '#sad', '#scared', -0.169, 'social_exclusion', 'exclusion_zone', 'isolation', 'unless', 'except']
senticnet['exclusion_zone'] = [-0.966, 0, 0.414, -0.94, '#sad', '#disgusting', -0.773, 'social_exclusion', 'exclusion', 'isolation', 'unless', 'except']
senticnet['exclusive'] = [-0.77, 0, 0.577, -0.782, '#sad', '#disgusting', -0.71, 'undivided', 'unshared', 'sole', 'individual', 'single']
senticnet['exclusiveness'] = [-0.948, 0, 0.687, -0.75, '#sad', '#disgusting', -0.795, 'clannishness', 'cliquishness', 'snobbery', 'arrogance', 'haughtiness']
senticnet['excogitation'] = [0.768, -0.509, 0, 0.624, '#joyful', '#admirable', 0.634, 'thinking', 'thought', 'thought_process', 'cerebration', 'intellection']
senticnet['excoriate'] = [-0.992, 0, 0.869, -0.604, '#sad', '#angry', -0.822, 'abrade', 'chafe', 'rasp', 'wear_away', 'wear_off']
senticnet['excrete'] = [-0.078, 0, -0.049, -0.102, '#sad', '#disgusting', -0.076, 'dream_with_eyes_open', 'die_only_once', 'form_sentence', 'eat_animal', 'eat_cat_food']
senticnet['excretion'] = [0.992, -0.808, 0, 0.584, '#joyful', '#surprising', 0.795, 'enuresis', 'urinary_incontinence', 'elimination', 'evacuation', 'incontinence']
senticnet['excruciate'] = [-0.25, 0, -0.174, -0.082, '#sad', '#scared', -0.169, 'ouch', 'ache', 'cause_bleed', 'cut_skin', 'pain']
senticnet['exculpate'] = [0.773, -0.64, 0, 0.78, '#joyful', '#admirable', 0.731, 'pronounce', 'purge', 'whitewash', 'vindicate', 'label']
senticnet['exculpated'] = [0.913, -0.745, 0, 0.703, '#joyful', '#surprising', 0.787, 'absolved', 'guiltless', 'exonerated', 'vindicated', 'clear']
senticnet['exculpation'] = [-0.798, 0, 0.651, -0.757, '#sad', '#disgusting', -0.735, 'defense', 'vindication', 'extenuation', 'mitigation', 'defence']
senticnet['exculpatory'] = [0.579, -0.541, 0, 0.784, '#joyful', '#admirable', 0.635, 'forgiving', 'vindicatory', 'absolvitory', 'exonerative', 'extenuating']
senticnet['excursionist'] = [-0.653, 0, 0.943, -0.756, '#angry', '#disgusting', -0.784, 'rubberneck', 'sightseer', 'holidaymaker', 'tripper', 'traveler']
senticnet['excusable'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'forgive', 'forgivable', 'mercifully', 'merciful', 'mercifulness']
senticnet['excuse'] = [-0.322, 0.224, -0.255, 0.135, '#sad', '#scared', -0.073, 'reason', 'conclusion', 'wrong_answer', 'explanation', 'solution']
senticnet['excuse_oneself'] = [-0.025, 0.087, 0, 0.107, '#interesting', '#admirable', 0.056, 'say_good_bye', 'step_aside', 'step_out', 'walk_away', 'open_mailbox']
senticnet['excuser'] = [-0.767, 0, 0.587, -0.576, '#sad', '#angry', -0.643, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['execrable'] = [-0.906, 0.138, -0.63, 0.071, '#sad', '#scared', -0.442, 'woeful', 'deplorable', 'woebegone', 'woefulness', 'plaintiveness']
senticnet['execrate'] = [-0.063, 0.183, 0.651, -0.642, '#angry', '#disgusting', -0.391, 'abhorrence', 'abomination', 'detestation', 'execration', 'loathing']
senticnet['execration'] = [-0.063, 0.183, 0.651, -0.642, '#angry', '#disgusting', -0.391, 'abhorrence', 'abomination', 'detestation', 'loathing', 'odium']
senticnet['executability'] = [0.515, -0.544, 0, 0.579, '#surprising', '#admirable', 0.546, 'capability', 'ability', 'associability', 'associableness', 'strength']
senticnet['execute'] = [-0.025, 0.087, 0, 0.107, '#interesting', '#admirable', 0.056, 'do_it_now', 'act', 'perform', 'fulfill', 'carry_out']
senticnet['execution'] = [-0.164, 0.158, -0.172, -0.041, '#sad', '#scared', -0.073, 'revenge', 'send_to_jail', 'incarceration', 'death_penalty', 'capital_punishment']
senticnet['executioner'] = [-0.628, 0, 0.94, -0.998, '#angry', '#disgusting', -0.855, 'poisoner', 'choker', 'mortal', 'slayer', 'public_slayer']
senticnet['executive'] = [0.703, -0.598, 0, 0.842, '#joyful', '#admirable', 0.714, 'rainmaker', 'minister', 'administrator', 'corporate_executive', 'business_executive']
senticnet['executive_director'] = [0.674, -0.721, 0, 0.821, '#surprising', '#admirable', 0.739, 'rainmaker', 'minister', 'administrator', 'corporate_executive', 'business_executive']
senticnet['exemplar'] = [0.986, -0.609, 0, 0.568, '#joyful', '#surprising', 0.721, 'beaut', 'ideal', 'beauty', 'pattern', 'pacesetter']
senticnet['exemplary'] = [0, 0, -0.828, -0.831, '#scared', '#disgusting', -0.553, 'model', 'emblematic', 'typic', 'admonitory', 'cautionary']
senticnet['exemplary_damages'] = [-0.622, 0, 0.546, -0.626, '#sad', '#disgusting', -0.598, 'amends', 'damages', 'indemnification', 'redress', 'restitution']
senticnet['exempt'] = [-0.713, 0, 0.602, -0.859, '#sad', '#disgusting', -0.725, 'spare', 'forgive', 'derestrict', 'deregulate', 'dispense']
senticnet['exemption'] = [0.73, -0.569, 0, 0.621, '#joyful', '#admirable', 0.64, 'amnesty', 'unsusceptibility', 'diplomatic_immunity', 'indemnity', 'impunity']
senticnet['exercise'] = [0.051, -0.036, 0.014, 0, '#joyful', '#surprising', 0.024, 'physical_fitness', 'keep_shape', 'strengthen_heart', 'keep_fit', 'exercise_dog']
senticnet['exercise_daily'] = [-0.077, 0, 0.011, -0.065, '#sad', '#disgusting', -0.051, 'take_hike', 'climb_stair', 'go_gym', 'lift_weight', 'join_gym']
senticnet['exercise_dog'] = [0.056, 0.157, 0, 0.154, '#interesting', '#admirable', 0.122, 'enjoy_outdoors', 'domesticate_dog', 'animal', 'enjoy_nature', 'dog']
senticnet['exercise_entertainment'] = [0.056, 0.157, 0, 0.154, '#interesting', '#admirable', 0.122, 'enjoy_outdoors', 'competition', 'learn_teamwork', 'funny_friend', 'entertainment']
senticnet['exercise_equipment'] = [0, 0.142, 0, 0.125, '#interesting', '#admirable', 0.089, 'gym_equipment', 'weight_machine', 'pulley', 'plumber', 'dumbbell']
senticnet['exercise_mind'] = [0, 0.142, 0, 0.125, '#interesting', '#admirable', 0.089, 'intellectual_stimulation', 'exercise', 'mind', 'exercise_muscle', 'occupy_mind']
senticnet['exercise_much'] = [0.792, 0, 0, 0.763, '#joyful', '#admirable', 0.518, 'exercise_regularly', 'eat_healthy_diet', 'feel_powerful', 'healthy_lifestyle', 'exercise_often']
senticnet['exercise_muscle'] = [0.056, 0.157, 0, 0.154, '#interesting', '#admirable', 0.122, 'increased_heart_rate', 'exercise', 'eat_properly', 'workout', 'strong_muscle']
senticnet['exercise_often'] = [0.884, 0.942, 0, 0.743, '#joyful', '#interesting', 0.856, 'long_happy_life', 'live_good_life', 'healthy_lifestyle', 'increase_stamina', 'exercise']
senticnet['exercise_regularly'] = [0.928, 0, 0, 0.774, '#joyful', '#admirable', 0.567, 'exercise', 'strong_muscle', 'healthy_lifestyle', 'exercise_often', 'increase_stamina']
senticnet['exercising_weight'] = [0.52, -0.972, 0, 0.916, '#surprising', '#admirable', 0.803, 'sporting_goods', 'weight', 'mat', 'free_weight', 'sports_equipment']
senticnet['exertion'] = [-0.056, -0.023, 0.036, -0.03, '#sad', '#angry', -0.033, 'hard_work', 'dig_ground', 'work_hard', 'prepare_event', 'effort']
senticnet['exhalation'] = [0, 0.098, -0.094, 0.115, '#interesting', '#admirable', 0.04, 'push_wind', 'breath', 'breaout', 'body_reaction', 'mouth_action']
senticnet['exhale'] = [0.94, 0.934, 0, 0, '#joyful', '#interesting', 0.625, 'inhale', 'cough', 'respiration', 'involuntary', 'smell_odor']
senticnet['exhaust'] = [0.957, -0.92, 0, 0, '#joyful', '#surprising', 0.626, 'discharge', 'unloading', 'drainage', 'waste', 'refuse']
senticnet['exhaust_fan'] = [0.628, -0.967, 0, 0.682, '#surprising', '#admirable', 0.759, 'electric_fan', 'blower', 'fan', 'punkah', 'device']
senticnet['exhaust_pipe'] = [0, -0.039, 0, 0.052, '#surprising', '#admirable', 0.03, 'emergency_brake', 'air_vent', 'brake_pedal', 'fan_belt', 'back_seat']
senticnet['exhausted'] = [0, 0, 0.933, -0.863, '#angry', '#disgusting', -0.599, 'tired', 'energy_exhaustion', 'need_rest', 'dead_tired', 'lack_of_rest']
senticnet['exhausting'] = [0.753, -0.745, 0, 0.587, '#joyful', '#surprising', 0.695, 'draining', 'debilitating', 'debilitative', 'enervating', 'enfeebling']
senticnet['exhaustion'] = [-0.921, 0, 0, -0.902, '#sad', '#disgusting', -0.608, 'tiredness', 'fatigue', 'become_tired', 'breaheavily', 'lack_energy']
senticnet['exhibit'] = [0.935, -0.661, 0, 0.93, '#joyful', '#admirable', 0.842, 'demo', 'show', 'demonstrate', 'bring_home', 'present']
senticnet['exhibition'] = [0.058, 0, 0, 0.088, '#joyful', '#admirable', 0.049, 'school_yard', 'fashion_show', 'art', 'football_stadium', 'sport_arena']
senticnet['exhibitionism'] = [-0.622, 0, 0.515, -0.638, '#sad', '#disgusting', -0.592, 'immodesty', 'perversion', 'paraphilia', 'sexual_perversion', 'fetishism']
senticnet['exhilarate'] = [0.859, 0.76, 0, 0.883, '#joyful', '#admirable', 0.834, 'stimulating', 'exalt', 'tickle_pink', 'exhilarated', 'beatify']
senticnet['exhilarated'] = [0.645, 0.637, -0.239, 0.299, '#joyful', '#interesting', 0.447, 'gladdened', 'stimulating', 'tickle_pink', 'inebriate', 'exalt']
senticnet['exhilarating'] = [0.644, 0.639, -0.239, 0.299, '#joyful', '#interesting', 0.448, 'stimulating', 'exhilarated', 'gladdened', 'tickle_pink', 'inebriate']
senticnet['exhilaration'] = [0.767, 0.702, 0, 0.878, '#joyful', '#admirable', 0.782, 'exhilarate', 'joyful', 'triumph', 'inebriate', 'stimulating']
senticnet['exhort'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerfully', 'cheerful', 'jolly_up', 'hearten', 'chirk_up']
senticnet['exigency'] = [-0.996, 0, 0.691, -0.655, '#sad', '#angry', -0.781, 'depression', 'economic_crisis', 'crisis', 'slump', 'juncture']
senticnet['exigent'] = [-0.756, 0, 0.982, -0.958, '#angry', '#disgusting', -0.899, 'needy', 'stringent', 'stern', 'exacting', 'demanding']
senticnet['exiguity'] = [-0.826, 0, 0.899, -0.921, '#angry', '#disgusting', -0.882, 'insufficiency', 'sparseness', 'sparsity', 'abstemiousness', 'little']
senticnet['exiguous'] = [-0.693, 0, 0.957, -0.926, '#angry', '#disgusting', -0.859, 'meager', 'meagre', 'meagerly', 'scrimpy', 'stingy']
senticnet['exile'] = [-0.514, 0, 0.63, -0.842, '#angry', '#disgusting', -0.662, 'hooky_player', 'truant', 'defaulter', 'absentee', 'expatriate']
senticnet['exist'] = [0.802, 0.862, 0, 0, '#joyful', '#interesting', 0.555, 'live', 'let', 'allow', 'heap', 'opportunity']
senticnet['existence'] = [0.959, 0, 0, 0.872, '#joyful', '#admirable', 0.61, 'live', 'strong_desire', 'live_life', 'cogito_ergo_sum', 'essential']
senticnet['exit'] = [0.094, 0, 0, 0, '#joyful', '#joyful', 0.031, 'hooker', 'registry_office', 'restaurant_entrance', 'elevator', 'treadmill']
senticnet['exit_build'] = [-0.025, 0.104, -0.057, 0.162, '#interesting', '#admirable', 0.061, 'walk_up', 'get_floor_another', 'walk_through', 'go_up_down', 'walk_down']
senticnet['exit_sign'] = [0, 0, -0.092, 0, '#scared', '#scared', -0.031, 'usher', 'type_of_car', 'theater_box', 'stage_entrance', 'row_seat']
senticnet['exogenous_obesity'] = [-0.728, 0, 0.973, -0.579, '#sad', '#angry', -0.76, 'corpulency', 'blubber', 'fat', 'embonpoint', 'stoutness']
senticnet['exonerate'] = [0.994, -0.86, 0, 0.965, '#joyful', '#admirable', 0.94, 'pronounce', 'purge', 'whitewash', 'vindicate', 'label']
senticnet['exonerated'] = [0.913, -0.745, 0, 0.703, '#joyful', '#surprising', 0.787, 'absolved', 'exculpated', 'guiltless', 'vindicated', 'clear']
senticnet['exonerates'] = [0, -0.787, 0, 0.997, '#surprising', '#admirable', 0.595, 'clear', 'discharge', 'acquit', 'assoil', 'exculpate']
senticnet['exonerative'] = [0.579, -0.541, 0, 0.784, '#joyful', '#admirable', 0.635, 'forgiving', 'vindicatory', 'absolvitory', 'exculpatory', 'extenuating']
senticnet['exophthalmic_goiter'] = [-0.533, 0, 0.667, -0.556, '#angry', '#disgusting', -0.585, 'thyrotoxicosis', 'glandular_disease', 'gland_disease', 'glandular_disorder', 'adenosis']
senticnet['exorbitant'] = [-0.891, 0, 0.6, -0.925, '#sad', '#disgusting', -0.805, 'outrageous', 'immoderate', 'extortionate', 'usurious', 'abnormal']
senticnet['exorcism'] = [-0.983, 0, 0.891, -0.607, '#sad', '#angry', -0.827, 'supernaturalism', 'dispossession', 'magic', 'thaumaturgy', 'belief']
senticnet['exorcist'] = [0.546, -0.768, 0, 0.74, '#surprising', '#admirable', 0.685, 'holy_order', 'deacon', 'acolyte', 'anagnost', 'doorkeeper']
senticnet['exorcize'] = [-0.787, 0, 0.74, -0.949, '#sad', '#disgusting', -0.825, 'eject', 'chuck_out', 'exclude', 'turf_out', 'boot_out']
senticnet['exoskeleton'] = [0.891, -0.825, 0, 0, '#joyful', '#surprising', 0.572, 'lymph', 'breast_pocket', 'forehead', 'toward', 'squint']
senticnet['exotic'] = [0.816, 0.756, 0, 0.747, '#joyful', '#interesting', 0.773, 'attractive', 'become_extinct', 'beautiful_creature', 'nocturnal', 'unique_animal']
senticnet['exoticism'] = [-0.864, 0, 0.941, -0.622, '#sad', '#angry', -0.809, 'alienage', 'alienism', 'foreignness', 'exoticness', 'exotism']
senticnet['exoticness'] = [-0.864, 0, 0.941, -0.622, '#sad', '#angry', -0.809, 'alienage', 'alienism', 'exoticism', 'foreignness', 'exotism']
senticnet['exotism'] = [-0.864, 0, 0.941, -0.622, '#sad', '#angry', -0.809, 'alienage', 'alienism', 'exoticism', 'exoticness', 'foreignness']
senticnet['exotropia'] = [-0.898, 0, 0.709, -0.641, '#sad', '#angry', -0.749, 'divergent_strabismus', 'squint', 'walleye', 'abnormality', 'abnormalcy']
senticnet['expand'] = [-0.036, 0.136, 0, 0.195, '#interesting', '#admirable', 0.098, 'make_big', 'enlarge', 'widen', 'grow_large', 'expansion']
senticnet['expand_horizon'] = [0.868, 0.99, 0, 0, '#joyful', '#interesting', 0.619, 'get_informed', 'stimulate_mind', 'get_news', 'acculturation', 'cultural_experience']
senticnet['expand_knowledge'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'take_up_time', 'get_knowledge', 'expand_mind', 'understand_current_event', 'broaden_horizon']
senticnet['expand_mind'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'gain_knowledge', 'take_up_time', 'learn', 'expand_knowledge', 'become_smart']
senticnet['expandable'] = [-0.986, 0, 0.702, -0.704, '#sad', '#disgusting', -0.797, 'expansive', 'expandible', 'expansible', 'erectile', 'cavernous']
senticnet['expanded'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'fat', 'heavy_dinner', 'enlarged', 'bloated', 'bulging']
senticnet['expandible'] = [-0.986, 0, 0.702, -0.704, '#sad', '#disgusting', -0.797, 'expandable', 'expansive', 'expansible', 'erectile', 'cavernous']
senticnet['expanse'] = [0.685, -0.673, 0, 0.822, '#joyful', '#admirable', 0.727, 'reach', 'range', 'compass', 'scope', 'orbit']
senticnet['expansible'] = [-0.986, 0, 0.702, -0.704, '#sad', '#disgusting', -0.797, 'expandable', 'expandible', 'expansive', 'erectile', 'cavernous']
senticnet['expansion'] = [0, 0.229, -0.099, 0.187, '#interesting', '#admirable', 0.106, 'increase', 'make_big', 'get_large', 'grow', 'expand']
senticnet['expansive'] = [0.732, -0.829, 0, 0, '#joyful', '#surprising', 0.52, 'extensive', 'sweeping', 'rolling', 'spacious', 'open']
senticnet['expansively'] = [0.512, 0.658, -0.254, 0.256, '#joyful', '#interesting', 0.391, 'exuberantly', 'riotously', 'ebulliently', 'zestfulness', 'gusto']
senticnet['expansiveness'] = [-0.539, 0, 0.993, -0.886, '#angry', '#disgusting', -0.806, 'impressiveness', 'expansivity', 'stateliness', 'loftiness', 'excellence']
senticnet['expansivity'] = [-0.539, 0, 0.993, -0.886, '#angry', '#disgusting', -0.806, 'expansiveness', 'impressiveness', 'stateliness', 'loftiness', 'excellence']
senticnet['expat'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'far_from_home', 'immigrant', 'live_abroad', 'connoisseur', 'work_abroad']
senticnet['expatiate'] = [0.777, -0.663, 0, 0.839, '#joyful', '#admirable', 0.76, 'elaborate', 'lucubrate', 'illustrate', 'exposit', 'enlarge']
senticnet['expatriate'] = [-0.514, 0, 0.63, -0.842, '#angry', '#disgusting', -0.662, 'hooky_player', 'truant', 'defaulter', 'exile', 'absentee']
senticnet['expect'] = [-0.711, 0, -0.992, 0, '#sad', '#scared', -0.568, 'regard', 'expectation', 'admire', 'desire', 'affection']
senticnet['expect_guest'] = [0, 0, 0, 0.113, '#admirable', '#admirable', 0.038, 'personal_cleanliness', 'clean', 'clean_floor', 'cleanness', 'tidy_up']
senticnet['expectancy'] = [0.43, 0.657, -0.285, 0.244, '#joyful', '#interesting', 0.349, 'expectation', 'look_for', 'amour_propre', 'self-love', 'conceit']
senticnet['expectant'] = [0.947, 0.822, 0, 0, '#joyful', '#interesting', 0.59, 'expectantly', 'anticipant', 'anticipative', 'fevered', 'hectic']
senticnet['expectantly'] = [-0.932, 0, -0.845, 0, '#sad', '#scared', -0.592, 'expectant', 'anticipant', 'anticipative', 'fevered', 'hectic']
senticnet['expectation'] = [0.735, 0.78, 0, 0, '#joyful', '#interesting', 0.505, 'sincerity', 'buck_fever', 'fevered', 'hectic', 'feverish']
senticnet['expectedness'] = [0.798, -0.517, 0, 0.519, '#joyful', '#admirable', 0.611, 'averageness', 'commonness', 'normalcy', 'typicality', 'condition']
senticnet['expectorator'] = [0.795, -0.676, 0, 0.545, '#joyful', '#surprising', 0.672, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['expedience'] = [-0.813, 0, 0.886, -0.656, '#sad', '#angry', -0.785, 'opportunism', 'greediness', 'rapaciousness', 'voraciousness', 'selfishness']
senticnet['expedient'] = [-0.973, 0, 0.84, -0.528, '#sad', '#angry', -0.78, 'pis_aller', 'last_resort', 'temporary_expedient', 'makeshift', 'stopgap']
senticnet['expedition'] = [0.883, 0.743, 0, 0, '#joyful', '#interesting', 0.542, 'mission', 'consignment', 'delivery', 'shipment', 'dispatch']
senticnet['expel'] = [-0.88, 0, 0.903, -0.504, '#sad', '#angry', -0.762, 'send_down', 'rusticate', 'debar', 'throw_out', 'kick_out']
senticnet['expend'] = [0.52, -0.9, 0, 0.767, '#surprising', '#admirable', 0.729, 'occupy', 'waste', 'pervert', 'squander', 'take']
senticnet['expend_energy'] = [-0.059, -0.033, 0.061, 0, '#sad', '#angry', -0.029, 'lose_energy', 'physical_exertion', 'strain_muscle', 'sweaty', 'expend']
senticnet['expenditure'] = [-0.915, 0, -0.769, 0, '#sad', '#scared', -0.561, 'price_high', 'money_payment', 'money_owe', 'amount_owe', 'money_due']
senticnet['expense'] = [-0.031, 0.269, -0.063, 0.136, '#interesting', '#admirable', 0.104, 'cost', 'money_payment', 'debit', 'price', 'money_charge']
senticnet['expensive'] = [-0.785, 0, -0.945, 0, '#sad', '#scared', -0.577, 'high_cost', 'spend_money', 'waste_money', 'high_price', 'unaffordable']
senticnet['expensive_car'] = [0.992, 0.728, 0, 0.834, '#joyful', '#admirable', 0.851, 'famous_brand', 'car', 'high_class', 'beautiful_car', 'limousine']
senticnet['expensive_clothe'] = [-0.948, 0, 0.937, -0.915, '#sad', '#angry', -0.933, 'expensive', 'waste_money', 'become_poor', 'need_money', 'expensive_car']
senticnet['expensive_dress'] = [0.796, 0.851, 0, 0, '#joyful', '#interesting', 0.549, 'fancy_dress', 'dress', 'fashion', 'gala', 'red_carpet']
senticnet['expensive_food'] = [0.061, 0.07, -0.056, 0.073, '#interesting', '#admirable', 0.049, 'italian_food', 'eat_food', 'fine_dining', 'caviar', 'lobster']
senticnet['expensive_hobby'] = [-0.713, 0, 0.82, 0, '#sad', '#angry', -0.511, 'type_of_game', 'dangerous_sport', 'type_of_sport', 'contact_sport', 'olympic_sport']
senticnet['expensive_house'] = [-0.25, 0, -0.174, -0.082, '#sad', '#scared', -0.169, 'expensive', 'price', 'high', 'extremely_expensive', 'expensive_car']
senticnet['expensive_item'] = [0.796, 0.851, 0, 0, '#joyful', '#interesting', 0.549, 'expensive', 'bankruptcy', 'homeless', 'poor', 'expensive_now']
senticnet['expensive_now'] = [0, 0, 0.883, -0.767, '#angry', '#disgusting', -0.55, 'expensive', 'bankruptcy', 'homeless', 'poor', 'expensive_item']
senticnet['expensive_sport'] = [0, -0.079, 0, 0.072, '#surprising', '#admirable', 0.05, 'rough_sport', 'type_of_sport', 'popular_sport_america', 'team_sport', 'popular_game']
senticnet['expensive_stone'] = [-0.741, 0, 0.945, 0, '#sad', '#angry', -0.562, 'precious_gem', 'gem_stone', 'precious_stone', 'jewel', 'gem']
senticnet['expensiveness'] = [0.902, -0.726, 0, 0.919, '#joyful', '#admirable', 0.849, 'preciousness', 'costliness', 'dearness', 'cost', 'lavishness']
senticnet['experience'] = [0.995, 0.801, 0, 0.968, '#joyful', '#admirable', 0.921, 'wisdom', 'know_how', 'know_world', 'find_out_truth', 'smart']
senticnet['experience_different_culture'] = [0.868, 0.99, 0, 0, '#joyful', '#interesting', 0.619, 'zone_out', 'acculturation', 'cultural_experience', 'entertain_oneself', 'see_actor']
senticnet['experience_emotion'] = [0.993, 0, 0, 0, '#joyful', '#joyful', 0.331, 'see_oneself', 'enjoy_art', 'experience', 'emotion', 'good_feeling']
senticnet['experience_fear'] = [0, 0, -0.868, 0, '#scared', '#scared', -0.289, 'plan_party', 'act_up', 'exhibition', 'drive_crazy', 'follow_mother']
senticnet['experience_joy'] = [0.993, 0, 0, 0, '#joyful', '#joyful', 0.331, 'experience_pleasure', 'listen_rock_music', 'trade_stock', 'think_funny', 'try_forget']
senticnet['experience_life'] = [0.118, 0.142, -0.119, 0.13, '#interesting', '#admirable', 0.09, 'avoid_pain', 'ease_pain', 'need_companionship', 'live_apartment', 'die_only_once']
senticnet['experience_new'] = [0.891, 0.721, 0, 0.921, '#joyful', '#admirable', 0.844, 'gain_knowledge', 'learn_art', 'expand_mind', 'learn_new_fact', 'eye_strain']
senticnet['experience_pain'] = [-0.88, 0, -0.735, -0.728, '#sad', '#scared', -0.781, 'poor_health', 'fall_down_flight_stair', 'feel_pain', 'cause_someone_to_die', 'take_aspirin']
senticnet['experience_pleasure'] = [0.94, 0.898, 0, 0.945, '#joyful', '#admirable', 0.928, 'listen_music', 'enjoy_performance', 'listen_story', 'feel_emotion', 'dance_music']
senticnet['experienced'] = [0.822, -0.863, 0, 0.818, '#joyful', '#surprising', 0.834, 'practiced', 'veteran', 'older', 'seasoned', 'knowledgeable']
senticnet['experient'] = [0.795, -0.895, 0, 0.624, '#joyful', '#surprising', 0.771, 'practiced', 'veteran', 'older', 'seasoned', 'knowledgeable']
senticnet['experiment'] = [-0.037, 0.081, -0.061, 0.086, '#interesting', '#admirable', 0.023, 'hypothesis', 'prove_theory', 'scientific_method', 'science', 'test_hypothesis']
senticnet['experimenter'] = [0.846, -0.755, 0, 0.69, '#joyful', '#surprising', 0.764, 'investigator', 'boffin', 'fieldworker', 'postdoc', 'post_doc']
senticnet['experimenter_bias'] = [0.628, -0.967, 0, 0.682, '#surprising', '#admirable', 0.759, 'taboo', 'tabu', 'tendentiousness', 'irrational_hostility', 'bias']
senticnet['expert'] = [0.891, 0.721, 0, 0.921, '#joyful', '#admirable', 0.844, 'inventor', 'connoisseur', 'medical_doctor', 'teacher', 'judge']
senticnet['expert_report'] = [0.628, -0.967, 0, 0.682, '#surprising', '#admirable', 0.759, 'find_problem', 'analyze', 'expertise', 'examination', 'check']
senticnet['expertise'] = [0, 0.983, 0, 0, '#interesting', '#interesting', 0.328, 'find_problem', 'analyze', 'expert_report', 'examination', 'check']
senticnet['expertness'] = [0.668, -0.87, 0, 0.606, '#joyful', '#surprising', 0.715, 'adeptness', 'adroitness', 'deftness', 'quickness', 'skillfulness']
senticnet['expiable'] = [0.768, -0.868, 0, 0.67, '#joyful', '#surprising', 0.769, 'pardonable', 'excusable', 'forgivable', 'venial', 'minor']
senticnet['expiation'] = [-0.724, 0, 0.932, -0.534, '#sad', '#angry', -0.73, 'amends', 'damages', 'indemnification', 'redress', 'restitution']
senticnet['expire'] = [-0.138, 0.134, -0.239, 0, '#sad', '#scared', -0.081, 'kill_self', 'end_life', 'die', 'capital_punishment', 'religious_fundamentalist']
senticnet['expired'] = [-0.931, 0, 0.238, -0.904, '#sad', '#disgusting', -0.691, 'bad_egg', 'poisoning', 'bad_taste', 'spoil', 'bad_egg_food']
senticnet['expired_beef'] = [-0.981, 0, 0.802, -0.902, '#sad', '#disgusting', -0.895, 'unhealthy', 'expired_egg', 'expired_food', 'unhealthy_food', 'expired_milk']
senticnet['expired_egg'] = [-0.981, 0, 0.802, -0.902, '#sad', '#disgusting', -0.895, 'unhealthy', 'unhealthy_food', 'expired_food', 'expired_beef', 'expired_milk']
senticnet['expired_food'] = [-0.931, 0, 0.238, -0.904, '#sad', '#disgusting', -0.691, 'expired', 'poisoning', 'bad_taste', 'spoil', 'bad_egg']
senticnet['expired_milk'] = [-0.981, 0, 0.802, -0.902, '#sad', '#disgusting', -0.895, 'unhealthy', 'expired_egg', 'expired_food', 'expired_beef', 'unhealthy_food']
senticnet['explain'] = [-0.081, 0.155, -0.133, 0.217, '#interesting', '#admirable', 0.053, 'respond', 'response', 'inquire', 'interrogation', 'elaborate']
senticnet['explain_detail'] = [0, 0.983, 0, 0, '#interesting', '#interesting', 0.328, 'draw_diagram', 'elaborate', 'reply_question', 'give_answer', 'detail']
senticnet['explain_everything'] = [-0.113, 0, -0.06, 0, '#sad', '#scared', -0.058, 'deal_card_player', 'stand_alone', 'forward_email', 'bridge_difference', 'mind_store']
senticnet['explain_idea'] = [0.712, 0.845, 0, 0, '#joyful', '#interesting', 0.519, 'spread_idea', 'buy_stock', 'complete_task', 'complete_job', 'introspection']
senticnet['explain_problem'] = [-0.079, -0.033, -0.048, -0.092, '#sad', '#disgusting', -0.062, 'further_knowledge', 'sell_book', 'read_human', 'pick_tooth', 'find_library']
senticnet['explain_subject'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'teach_student', 'prepare_lesson', 'presentation', 'make_presentation', 'use_computer']
senticnet['explanation'] = [-0.112, 0.283, -0.167, 0.331, '#interesting', '#admirable', 0.112, 'conclude', 'question_answering', 'solution', 'yes_no', 'question_starter']
senticnet['expletive'] = [-0.806, 0, 0.899, -0.524, '#sad', '#angry', -0.743, 'filth', 'smut', 'profanity', 'curse_word', 'swearword']
senticnet['explicate'] = [0.506, -0.599, 0, 0.896, '#surprising', '#admirable', 0.667, 'naturalize', 'clarify', 'clear_up', 'elucidate', 'rede']
senticnet['explication_de_texte'] = [0.587, -0.948, 0, 0.659, '#surprising', '#admirable', 0.731, 'critique', 'review', 'literary_criticism', 'textual_criticism', 'new_criticism']
senticnet['explicit'] = [0.501, -0.996, 0, 0.68, '#surprising', '#admirable', 0.726, 'stated', 'hardcore', 'declared', 'definitive', 'graphic']
senticnet['explicitness'] = [0.867, -0.632, 0, 0.505, '#joyful', '#surprising', 0.668, 'lucidness', 'clarity', 'clearness', 'lucidity', 'pellucidity']
senticnet['explode'] = [-0.152, -0.054, -0.076, -0.16, '#sad', '#disgusting', -0.111, 'warm_hand', 'die_out', 'die_painfully', 'destroy_home', 'get_hurt']
senticnet['exploit'] = [-0.884, 0, 0, -0.734, '#sad', '#disgusting', -0.539, 'avail', 'use', 'harness', 'utilise', 'overexploit']
senticnet['exploration'] = [0.117, -0.007, 0, 0, '#joyful', '#surprising', 0.041, 'leisure_activity', 'web_surf', 'hobby', 'pastime', 'explore']
senticnet['explore'] = [0.117, -0.007, 0, 0, '#joyful', '#surprising', 0.041, 'leisure_activity', 'web_surf', 'hobby', 'pastime', 'exploration']
senticnet['explore_idea'] = [0.035, 0.134, 0, 0, '#joyful', '#interesting', 0.056, 'become_distracted', 'find_solution', 'new_information', 'change_attitude', 'solve_problem']
senticnet['explore_nature'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'read_book', 'study_animal', 'study', 'read_science_book', 'watch_animal_documentary']
senticnet['explore_underwater'] = [0.751, 0, 0, 0, '#joyful', '#joyful', 0.25, 'sea', 'fun', 'underwater', 'lake', 'enjoy_nature']
senticnet['explore_universe'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'discover_universe', 'universe', 'another_planet', 'astrology', 'alien']
senticnet['explorer'] = [0.069, 0.07, 0, 0.116, '#interesting', '#admirable', 0.085, 'passenger', 'tourist', 'travel', 'traveller', 'adventurer']
senticnet['explosion'] = [0, 0, -0.098, -0.139, '#scared', '#disgusting', -0.079, 'fire_light', 'earthquake', 'burn_down_house', 'arson', 'inferno']
senticnet['explosive'] = [0, 0, -0.743, -0.888, '#scared', '#disgusting', -0.544, 'bomb', 'nuclear_bomb', 'grenade', 'nuclear_weapon', 'atomic_bomb']
senticnet['explosive_compound'] = [-0.585, 0, 0.661, -0.954, '#angry', '#disgusting', -0.733, 'explosive', 'cordite', 'dynamite', 'plastic_explosive', 'plastique']
senticnet['explosive_device'] = [-0.141, -0.004, -0.119, -0.132, '#sad', '#disgusting', -0.129, 'big_gun', 'weapon', 'firearm', 'grenade', 'bomb']
senticnet['expose'] = [0, 0, 0.701, -0.779, '#angry', '#disgusting', -0.493, 'color', 'treat', 'bear_upon', 'influence', 'uncover']
senticnet['expose_skin_sun'] = [0, 0, -0.084, -0.12, '#scared', '#disgusting', -0.068, 'burn_skin', 'cancer', 'ultraviolet', 'erythema', 'sunstroke']
senticnet['exposed'] = [-0.924, 0, 0.969, -0.911, '#sad', '#angry', -0.935, 'unprotected', 'defenseless', 'open', 'naked', 'unshielded']
senticnet['exposit'] = [0.777, -0.663, 0, 0.839, '#joyful', '#admirable', 0.76, 'elaborate', 'lucubrate', 'expatiate', 'illustrate', 'enlarge']
senticnet['expostulation'] = [-0.958, 0, 0.644, -0.7, '#sad', '#disgusting', -0.767, 'ejaculation', 'interjection', 'devil', 'exclaiming', 'deuce']
senticnet['express'] = [0, 0.161, -0.085, 0.219, '#interesting', '#admirable', 0.098, 'deliver', 'send', 'mention', 'reply', 'remark']
senticnet['express_anger'] = [-0.747, 0, 0, -0.967, '#sad', '#disgusting', -0.571, 'become_angry', 'argument', 'start_fight', 'argue', 'lose_temper']
senticnet['express_appreciation'] = [0.774, 0.777, 0, 0, '#joyful', '#interesting', 0.517, 'get_close', 'show_care', 'celebrate_special_occasion', 'hospitable', 'express_love']
senticnet['express_emotion'] = [0.706, 0, 0, 0.792, '#joyful', '#admirable', 0.499, 'express', 'emotion', 'express_feeling', 'express_appreciation', 'happiness']
senticnet['express_feeling'] = [0.839, 0.981, 0, 0, '#joyful', '#interesting', 0.607, 'express_emotion', 'entertain_others', 'sound_good', 'listen', 'entertain_other_person']
senticnet['express_good_emotion'] = [0.706, 0, 0, 0.792, '#joyful', '#admirable', 0.499, 'entertain_others', 'emotion', 'cry', 'express_feeling', 'laugh']
senticnet['express_gratitude'] = [0.942, 0, 0, 0.984, '#joyful', '#admirable', 0.642, 'kindness', 'cherish', 'world_peace', 'show_love', 'express_love']
senticnet['express_how_funny'] = [0.701, 0.921, 0, 0, '#joyful', '#interesting', 0.541, 'tickle', 'howl_laughter', 'laugh_joke', 'make_someone_laugh', 'explain']
senticnet['express_idea'] = [0.747, 0.845, 0, 0, '#joyful', '#interesting', 0.531, 'share_thought', 'convey_information', 'convey_idea', 'transfer_information', 'know_story']
senticnet['express_individuality'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'make_beautiful', 'get_tanned', 'good_mental_health', 'personal_fulfillment', 'express_opinion']
senticnet['express_information'] = [0.889, -0.893, 0, 0, '#joyful', '#surprising', 0.594, 'communicate', 'information', 'help', 'reply_question', 'give_answer']
senticnet['express_joy'] = [0.793, 0, 0, 0, '#joyful', '#joyful', 0.264, 'give_pleasure', 'pleasure', 'spread_happiness', 'like_compete', 'funny_friend']
senticnet['express_love'] = [0.734, 0, 0, 0.892, '#joyful', '#admirable', 0.542, 'show_affection', 'make_happy', 'show_love', 'express_appreciation', 'show_care']
senticnet['express_oneself'] = [0.858, -0.972, 0, 0, '#joyful', '#surprising', 0.61, 'tell_story', 'tell_many_person', 'reach_tentative_agreement', 'express_information', 'illustrate_point']
senticnet['express_opinion'] = [0.903, 0.684, 0, 0.791, '#joyful', '#admirable', 0.793, 'exchange_idea', 'share_knowledge', 'share_information', 'exchange_information', 'opinion']
senticnet['express_sadness'] = [-0.714, 0, 0, 0, '#sad', '#sad', -0.238, 'emotional_response', 'emotional_reaction', 'tear_eye', 'funny', 'sadness']
senticnet['expression'] = [0.969, 0, 0, 0.939, '#joyful', '#admirable', 0.636, 'show_tooth', 'facial_expression', 'subjective', 'guffaw', 'flattery']
senticnet['expressive'] = [0.299, 0.2, 0.01, 0.309, '#joyful', '#admirable', 0.266, 'talent', 'taken_seriously', 'creative', 'good_fortune', 'simple_life']
senticnet['expressway'] = [0.579, -0.891, 0, 0.878, '#surprising', '#admirable', 0.783, 'autobahn', 'autostrada', 'turnpike', 'toll_road', 'highway']
senticnet['expropriate'] = [-0.986, 0, 0.654, -0.847, '#sad', '#disgusting', -0.829, 'bereave', 'deprive', 'disarm', 'unclothe', 'take']
senticnet['extemporaneous'] = [-0.674, 0, 0.936, -0.555, '#sad', '#angry', -0.722, 'unprepared', 'extemporary', 'extempore', 'impromptu', 'unrehearsed']
senticnet['extemporary'] = [-0.674, 0, 0.936, -0.555, '#sad', '#angry', -0.722, 'extemporaneous', 'unprepared', 'extempore', 'impromptu', 'unrehearsed']
senticnet['extempore'] = [-0.674, 0, 0.936, -0.555, '#sad', '#angry', -0.722, 'extemporaneous', 'extemporary', 'unprepared', 'impromptu', 'unrehearsed']
senticnet['extend'] = [-0.04, 0.153, -0.126, 0.232, '#interesting', '#admirable', 0.073, 'reach', 'elasticity', 'grow_long', 'extend_arm', 'tow']
senticnet['extend_arm'] = [0.968, 0, 0, 0.915, '#joyful', '#admirable', 0.628, 'grab', 'reach_out', 'grasp', 'reach', 'physical_contact']
senticnet['extension'] = [0, 0.111, 0, 0.211, '#interesting', '#admirable', 0.107, 'elongation', 'limp', 'elongate', 'reach_out', 'walk_part']
senticnet['extensional'] = [0.904, -0.588, 0, 0.736, '#joyful', '#admirable', 0.743, 'naming', 'appellative', 'designative', 'denotative', 'referent']
senticnet['extent'] = [0.021, 0.167, 0, 0.207, '#interesting', '#admirable', 0.132, 'size_up', 'measure_length', 'math_term', 'distant', 'extension']
senticnet['extenuating'] = [0.579, -0.541, 0, 0.784, '#joyful', '#admirable', 0.635, 'forgiving', 'vindicatory', 'absolvitory', 'exonerative', 'exculpatory']
senticnet['extenuation'] = [-0.798, 0, 0.651, -0.757, '#sad', '#disgusting', -0.735, 'defense', 'vindication', 'exculpation', 'mitigation', 'defence']
senticnet['exterior'] = [0.152, 0, 0.046, 0.128, '#joyful', '#admirable', 0.078, 'roof', 'foundation', 'find_outside', 'umbrella', 'vane']
senticnet['extermination'] = [-0.089, 0, -0.153, -0.206, '#scared', '#disgusting', -0.149, 'casualty', 'reaper', 'wound', 'cause_death', 'gunshot']
senticnet['external'] = [-0.521, 0, 0.783, -0.975, '#angry', '#disgusting', -0.76, 'international', 'abroad', 'overseas', 'foreign', 'outside']
senticnet['external_jugular_vein'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'anterior_jugular_vein', 'jugular', 'internal_jugular_vein', 'vein', 'vena']
senticnet['external_respiration'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'respiration', 'inhale_oxygen', 'exhale_oxygen', 'inhaler_technique', 'ventilation']
senticnet['extinct'] = [-0.089, 0, -0.153, -0.206, '#scared', '#disgusting', -0.149, 'extinguish', 'extinguished', 'deceased', 'dead', 'archaic']
senticnet['extinction'] = [-0.88, 0, -0.948, 0, '#sad', '#scared', -0.609, 'compel', 'cause_change', 'change_life', 'cascade_effect', 'eco_system']
senticnet['extinguish'] = [0, -0.035, -0.055, -0.069, '#scared', '#disgusting', -0.03, 'find_campsite', 'burn_house', 'cause_fire', 'die_out', 'find_wood']
senticnet['extinguish_fire'] = [0, -0.072, 0, 0, '#surprising', '#surprising', 0.024, 'put_out_fire', 'make_ice', 'bake_bread', 'feed_baby', 'bake_cookie']
senticnet['extinguished'] = [-0.622, 0, 0.863, -0.991, '#angry', '#disgusting', -0.825, 'spoilt', 'wrecked', 'impoverished', 'blighted', 'destroyed']
senticnet['extinguisher'] = [0.759, -0.774, 0, 0, '#joyful', '#surprising', 0.511, 'fire_hydrant', 'stair_rail', 'christian_fundamentalist', 'fire_extinguisher', 'reception_desk']
senticnet['extirpate'] = [0, 0, -0.963, -0.721, '#scared', '#disgusting', -0.561, 'eradicate', 'deracinate', 'root_out', 'exterminate', 'uproot']
senticnet['extol'] = [0.79, -0.973, 0, 0.689, '#joyful', '#surprising', 0.817, 'laud', 'ensky', 'exalt', 'glorify', 'proclaim']
senticnet['extolment'] = [0.655, -0.827, 0, 0.956, '#surprising', '#admirable', 0.813, 'superlative', 'compliment', 'testimonial', 'good_word', 'approval']
senticnet['extortion'] = [-0.089, 0, -0.153, -0.206, '#scared', '#disgusting', -0.149, 'ask_money', 'exaction', 'wringing', 'intimidate', 'psychological_pressure']
senticnet['extortionate'] = [-0.891, 0, 0.6, -0.925, '#sad', '#disgusting', -0.805, 'outrageous', 'exorbitant', 'immoderate', 'usurious', 'abnormal']
senticnet['extra'] = [-0.073, 0.207, -0.059, 0.228, '#interesting', '#admirable', 0.101, 'free', 'gift', 'abundance', 'plus', 'plentiful']
senticnet['extra_money'] = [0.831, 0, 0, 0, '#joyful', '#joyful', 0.277, 'money_earn', 'investment_return', 'wealth', 'increase_money', 'financial_gain']
senticnet['extra_tyre'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'boot', 'put_groceries', 'car_trunk', 'store', 'storage_place']
senticnet['extractor'] = [0.96, -0.714, 0, 0.529, '#joyful', '#surprising', 0.734, 'medical_instrument', 'optical_instrument', 'scientific_instrument', 'instrument', 'whip']
senticnet['extracurricular_activity'] = [-0.827, 0, 0.956, -0.585, '#sad', '#angry', -0.789, 'instruction', 'teaching', 'pedagogy', 'education', 'didactics']
senticnet['extramarital_sex'] = [-0.985, 0, 0.662, -0.738, '#sad', '#disgusting', -0.795, 'fornication', 'unlawful_carnal_knowledge', 'criminal_congress', 'adultery', 'criminal_conversation']
senticnet['extraneous'] = [-0.732, 0, 0.899, -0.765, '#angry', '#disgusting', -0.799, 'extrinsic', 'alien', 'adventitious', 'foreign', 'adscititious']
senticnet['extraordinary'] = [0.728, -0.727, 0, 0.881, '#joyful', '#admirable', 0.779, 'howling', 'wonderful', 'wondrous', 'bonzer', 'rattling']
senticnet['extrasensory_perception'] = [0.728, -0.727, 0, 0.881, '#joyful', '#admirable', 0.779, 'predict_future', 'psychic_phenomenon', 'parapsychology', 'precognition', 'foreknowledge']
senticnet['extraterrestrial'] = [-0.654, 0, 0.859, -0.639, '#sad', '#angry', -0.717, 'alien', 'hypothetical_creature_being', 'hypothetical_creature', 'imaginary_being', 'imaginary_creature']
senticnet['extraterrestrial_being'] = [-0.654, 0, 0.859, -0.639, '#sad', '#angry', -0.717, 'alien', 'hypothetical_creature', 'extraterrestrial', 'imaginary_being', 'imaginary_creature']
senticnet['extrauterine_gestation'] = [-0.965, 0, 0.528, -0.898, '#sad', '#disgusting', -0.797, 'abdominal_pregnancy', 'ovarian_pregnancy', 'tubal_pregnancy', 'pregnancy', 'gestation']
senticnet['extrauterine_pregnancy'] = [-0.957, 0, 0.793, -0.623, '#sad', '#angry', -0.791, 'abdominal_pregnancy', 'ovarian_pregnancy', 'tubal_pregnancy', 'pregnancy', 'gestation']
senticnet['extravagant'] = [0, 0, 0.845, -0.919, '#angry', '#disgusting', -0.588, 'overweening', 'excessive', 'wasteful', 'exuberant', 'prodigal']
senticnet['extraversion'] = [-0.648, 0, 0.574, -0.89, '#sad', '#disgusting', -0.704, 'gregariousness', 'ambiversion', 'openness', 'nakedness', 'sociability']
senticnet['extreme'] = [0, 0, 0, -0.864, '#disgusting', '#disgusting', -0.288, 'extreme_boredom', 'extreme_fear', 'severe', 'extreme_sport', 'dangerous']
senticnet['extreme_boredom'] = [0, 0, 0, -0.864, '#disgusting', '#disgusting', -0.288, 'boredom', 'time_waste', 'eye_strain', 'become_bored', 'see_ad']
senticnet['extreme_elation'] = [-0.778, 0, -0.791, 0, '#sad', '#scared', -0.523, 'health_improve', 'stare', 'heart_beat_fast', 'win_game', 'minor_injury']
senticnet['extreme_fear'] = [0, 0, -0.809, 0, '#scared', '#scared', -0.27, 'fight', 'death', 'get_fired', 'imprisonment', 'mental_disorder']
senticnet['extreme_sport'] = [0, 0.109, -0.102, 0.235, '#interesting', '#admirable', 0.081, 'sport', 'sports_expert', 'adrenaline', 'extreme', 'skydiving']
senticnet['extremely_expensive'] = [-0.955, 0, 0.766, -0.965, '#sad', '#disgusting', -0.895, 'expensive', 'price', 'high', 'expensive_house', 'expensive_car']
senticnet['extremist'] = [-0.911, 0, 0.794, -0.934, '#sad', '#disgusting', -0.88, 'fanatic', 'fundamentalist', 'obsession', 'stubborn', 'violent']
senticnet['extremity'] = [0.11, 0.209, 0, 0.238, '#interesting', '#admirable', 0.186, 'upper_hand', 'hand', 'human_appendage', 'arm_part', 'body_limb']
senticnet['extremum'] = [-0.956, 0, 0.781, -0.732, '#sad', '#angry', -0.823, 'small_indefinite_quantity', 'small_indefinite_amount', 'peak', 'skeleton', 'lower_limit']
senticnet['extrinsic'] = [-0.732, 0, 0.899, -0.765, '#angry', '#disgusting', -0.799, 'extraneous', 'alien', 'adventitious', 'foreign', 'adscititious']
senticnet['extrovert'] = [0.33, 0.254, -0.183, 0.198, '#joyful', '#interesting', 0.2, 'celebrity', 'individual', 'medical_professional', 'personal_identification', 'multiple_people']
senticnet['extroverted'] = [0, 0, -0.852, -0.891, '#scared', '#disgusting', -0.581, 'extrospective', 'forthcoming', 'outgoing', 'extravert', 'extrovertive']
senticnet['exuberance'] = [0.546, 0.64, -0.265, 0.28, '#joyful', '#interesting', 0.4, 'gleefully', 'joyously', 'joyfully', 'joyousness', 'joyfulness']
senticnet['exuberant'] = [0.701, 0.624, -0.226, 0.311, '#joyful', '#interesting', 0.47, 'jubilant', 'contented', 'jubilate', 'wallow', 'exult']
senticnet['exuberantly'] = [0.512, 0.658, -0.254, 0.256, '#joyful', '#interesting', 0.391, 'riotously', 'expansively', 'ebulliently', 'zestfulness', 'gusto']
senticnet['exult'] = [0.689, 0.627, -0.232, 0.315, '#joyful', '#interesting', 0.466, 'jubilate', 'exuberant', 'carefree', 'lightsomeness', 'carefreeness']
senticnet['exultant'] = [0.732, 0.614, -0.224, 0.329, '#joyful', '#interesting', 0.484, 'exulting', 'prideful', 'triumphal', 'triumphant', 'rejoicing']
senticnet['exultantly'] = [0.673, 0.631, -0.233, 0.309, '#joyful', '#interesting', 0.46, 'exultingly', 'on_cloud_nine', 'exultation', 'jubilance', 'happiness']
senticnet['exultation'] = [0.673, 0.631, -0.233, 0.309, '#joyful', '#interesting', 0.46, 'exultingly', 'on_cloud_nine', 'cheer_up', 'jubilance', 'walk_on_air']
senticnet['exulting'] = [0.732, 0.614, -0.224, 0.329, '#joyful', '#interesting', 0.484, 'prideful', 'triumphal', 'exultant', 'triumphant', 'rejoicing']
senticnet['exultingly'] = [0.673, 0.631, -0.233, 0.309, '#joyful', '#interesting', 0.46, 'on_cloud_nine', 'exultation', 'jubilance', 'happiness', 'walk_on_air']
senticnet['eye'] = [0.753, -0.647, 0, 0.556, '#joyful', '#surprising', 0.652, 'oculus_dexter', 'stemma', 'naked_eye', 'peeper', 'oculus_sinister']
senticnet['eye-popping'] = [0.045, -0.12, -0.062, 0.065, '#surprising', '#admirable', 0.056, 'surprise', 'fulgurant', 'astonishing', 'dazzling', 'surprising']
senticnet['eye_beholder'] = [0.333, 0.331, -0.18, 0.245, '#joyful', '#interesting', 0.243, 'collage', 'belle', 'pretty_woman', 'nice_look', 'gorgeous']
senticnet['eye_close'] = [0.045, -0.12, -0.062, 0.065, '#surprising', '#admirable', 0.056, 'father_child', 'kinship', 'maintain_balance', 'mother_father', 'hold_baby']
senticnet['eye_contact'] = [0.086, 0, 0, 0.081, '#joyful', '#admirable', 0.056, 'communicate_person', 'talk_person', 'find_person', 'start_conversation', 'remember_name']
senticnet['eye_disease'] = [0.621, -0.68, 0, 0.63, '#surprising', '#admirable', 0.644, 'eye_problem', 'bad_eyesight', 'macular_degeneration', 'retinopathy', 'disease']
senticnet['eye_failure'] = [-0.528, 0, 0.785, -0.617, '#angry', '#disgusting', -0.643, 'disease', 'feel_sick', 'brain_disease', 'epilepsy', 'brain_failure']
senticnet['eye_function'] = [0, -0.023, 0, 0.162, '#surprising', '#admirable', 0.062, 'eye_sense', 'sight', 'like_see', 'vision', 'blink_eye']
senticnet['eye_nose'] = [0, 0.076, 0, 0.052, '#interesting', '#admirable', 0.043, 'hold_brain', 'face', 'skull', 'top_face', 'nose_mouth']
senticnet['eye_open'] = [0.806, 0, 0, 0, '#joyful', '#joyful', 0.269, 'rend_movie', 'wear_glass', 'go_cinema', 'go_movie_theater', 'eye_opener']
senticnet['eye_opener'] = [0.806, 0, 0, 0, '#joyful', '#joyful', 0.269, 'rend_movie', 'wear_glass', 'go_cinema', 'go_movie_theater', 'eye_open']
senticnet['eye_problem'] = [-0.528, 0, 0.785, -0.617, '#angry', '#disgusting', -0.643, 'eye_disease', 'bad_eyesight', 'macular_degeneration', 'retinopathy', 'disease']
senticnet['eye_sense'] = [0, -0.042, 0, 0.18, '#surprising', '#admirable', 0.074, 'eye_function', 'like_see', 'sight', 'vision', 'see_ability']
senticnet['eye_stimulation'] = [0.825, 0.923, 0, 0.934, '#interesting', '#admirable', 0.894, 'happy', 'beauty', 'pleasure', 'enjoy_beauty', 'pleasant_experience']
senticnet['eye_strain'] = [-0.936, 0, -0.966, -0.794, '#sad', '#scared', -0.899, 'see_ad', 'time_waste', 'learn_current_event', 'eye', 'change_opinion']
senticnet['eye_tear'] = [-0.741, 0, -0.784, -0.932, '#scared', '#disgusting', -0.819, 'shed_tear', 'bawl', 'water_eye', 'whine', 'weep']
senticnet['eye_up_down'] = [0, 0, 0, -0.73, '#disgusting', '#disgusting', -0.243, 'live_ocean', 'travel_fast_light', 'control_weather', 'live_forever', 'breaunderwater']
senticnet['eyeball'] = [-0.039, 0.078, 0, 0.109, '#interesting', '#admirable', 0.049, 'vision', 'sight', 'eye_function', 'eye_sense', 'see_ability']
senticnet['eyeglass'] = [0, -0.028, 0.048, -0.058, '#angry', '#disgusting', -0.026, 'telescope', 'read_glass', 'binoculars', 'camera', 'monocle']
senticnet['eyeglass_case'] = [0, -0.004, 0.051, -0.057, '#angry', '#disgusting', -0.035, 'satchel_bag', 'checkbook_holder', 'tote_bag', 'lip_balm', 'checkbook_cover']
senticnet['eyelid'] = [-0.79, 0, 0.769, -0.798, '#sad', '#disgusting', -0.786, 'flap', 'protective_fold', 'lid', 'palpebra', 'nictitating_membrane']
senticnet['eyes'] = [0.961, -0.996, 0, 0.645, '#joyful', '#surprising', 0.867, 'view', 'thought', 'persuasion', 'sentiment', 'opinion']
senticnet['eyesight'] = [-0.071, 0, 0, 0, '#sad', '#sad', -0.024, 'near_tv', 'wear_glass', 'switch_tv', 'turn_on_tv', 'blur_vision']
senticnet['eyesight_obscure'] = [-0.916, 0, 0.594, -0.927, '#sad', '#disgusting', -0.812, 'mist', 'blind', 'heavy_rain', 'dark', 'fog']
senticnet['eyesore'] = [-0.874, 0, 0.584, -0.711, '#sad', '#disgusting', -0.723, 'unsightliness', 'ugliness', 'hideousness', 'unattractiveness', 'garishness']
senticnet['eyestrain'] = [-0.732, 0, 0.596, -0.773, '#sad', '#disgusting', -0.7, 'exhaustion', 'loss_of_strength', 'logginess', 'weariness', 'asthenopia']
senticnet['fable'] = [0.1, 0.085, 0, 0.093, '#joyful', '#admirable', 0.093, 'narrative', 'bedtime', 'bed_time', 'long_story', 'saga']
senticnet['fabled'] = [-0.677, 0, 0.716, -0.897, '#angry', '#disgusting', -0.763, 'imaginary', 'notional', 'unreal', 'hallucinatory', 'illusional']
senticnet['fabric'] = [0, 0.081, 0.015, 0.052, '#interesting', '#admirable', 0.039, 'white_cotton', 'sheepskin_material', 'woven_sheepskin', 'sheepskin', 'clothes_type']
senticnet['fabric_material'] = [0, 0.081, 0.015, 0.052, '#interesting', '#admirable', 0.039, 'white_cotton', 'sheepskin', 'woven_fabric', 'fabric', 'clothes_type']
senticnet['fabric_shop'] = [0, -0.062, 0.082, -0.067, '#angry', '#disgusting', -0.029, 'warm_clothes', 'sweater', 'garment', 'clothes', 'winter_clothes']
senticnet['fabric_store'] = [0.961, -0.776, 0, 0, '#joyful', '#surprising', 0.579, 'wear_clothes', 'fabric_shop', 'clothes', 'sweater', 'shirt']
senticnet['fabric_type'] = [0.069, 0.112, 0, 0.167, '#interesting', '#admirable', 0.116, 'type_of_material', 'material_type', 'soft_white', 'cloth_fabric', 'cloth_material']
senticnet['fabricate'] = [-0.034, 0.182, -0.046, 0.239, '#interesting', '#admirable', 0.114, 'make', 'create_form', 'creation', 'make_stuff', 'factory_output']
senticnet['fabricated'] = [0, 0, 0.941, -0.8, '#angry', '#disgusting', -0.58, 'manufacture', 'cook_up', 'make_up', 'construct', 'invent']
senticnet['fabulous'] = [0.903, 0.684, 0, 0.791, '#joyful', '#admirable', 0.793, 'house', 'expensive_house', 'villa', 'fancy_house', 'vip']
senticnet['face'] = [0.719, -0.58, 0, 0.739, '#joyful', '#admirable', 0.679, 'poker_countenance', 'look', 'countenance', 'expression', 'aspect']
senticnet['face_feature'] = [0.057, 0.111, 0, 0.143, '#interesting', '#admirable', 0.104, 'part_of_face', 'facial_organ', 'facial', 'facial_part', 'near_nose']
senticnet['face_music'] = [0.861, 0.929, 0, 0.879, '#interesting', '#admirable', 0.89, 'wait_forever', 'state_obvious', 'direct_play', 'correct_mistake', 'keep_word']
senticnet['face_other'] = [-0.087, 0, -0.047, 0, '#sad', '#scared', -0.045, 'annoy_other_person', 'open_close_mouth', 'tell_secret', 'forget_name', 'reply_question']
senticnet['face_pack'] = [0.825, 0.923, 0, 0.934, '#interesting', '#admirable', 0.894, 'pack', 'corrective', 'pickup', 'prosthesis', 'prosthetic_device']
senticnet['face_paint'] = [0.85, 0.725, 0, 0, '#joyful', '#interesting', 0.525, 'face', 'paint', 'fun', 'enjoy_moment', 'carnival']
senticnet['face_part'] = [0, 0.093, 0, 0.113, '#interesting', '#admirable', 0.069, 'top_face', 'facial_part', 'near_nose', 'face_feature', 'feature']
senticnet['face_recognition'] = [0.1, 0.216, -0.185, 0.22, '#interesting', '#admirable', 0.117, 'contrast', 'perception', 'seeing', 'object_recognition', 'visual_space']
senticnet['face_time'] = [0.769, -0.614, 0, 0.746, '#joyful', '#admirable', 0.71, 'day', 'period', 'hours', 'work_time', 'workweek']
senticnet['face_to_face'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'cooperate', 'help_each_other', 'connect', 'interact', 'interaction']
senticnet['face_towel'] = [0.024, 0.157, 0.018, 0.145, '#interesting', '#admirable', 0.103, 'toilet_paper', 'beach_towel', 'towel', 'hand_towel', 'tissue']
senticnet['face_up'] = [-0.885, 0, 0.854, -0.668, '#sad', '#angry', -0.802, 'approach', 'undertake', 'tackle', 'take_on', 'set_about']
senticnet['face_value'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'pretence', 'pretense', 'pretext', 'simulacrum', 'semblance']
senticnet['facet'] = [0.026, 0.086, 0.017, 0.181, '#interesting', '#admirable', 0.092, 'angle', 'octagon', 'face', 'apex', 'left_right']
senticnet['facetime'] = [0.769, -0.614, 0, 0.746, '#joyful', '#admirable', 0.71, 'day', 'period', 'hours', 'work_time', 'workweek']
senticnet['facial'] = [0.057, 0.111, 0, 0.143, '#interesting', '#admirable', 0.104, 'part_of_face', 'facial_organ', 'face_feature', 'facial_part', 'near_nose']
senticnet['facial_expression'] = [-0.889, 0, -0.742, 0, '#sad', '#scared', -0.544, 'mouth_movement', 'leer', 'show_tooth', 'expression', 'mouth']
senticnet['facial_expression_movement'] = [-0.76, 0, -0.978, 0, '#sad', '#scared', -0.579, 'mouth', 'kiss', 'show_tooth', 'expression', 'facial_expression']
senticnet['facial_feature'] = [0, 0.066, 0.01, 0.083, '#interesting', '#admirable', 0.046, 'face_part', 'facial_part', 'facial_organ', 'near_mouth', 'part_of_face']
senticnet['facial_hair'] = [0.036, 0, 0.094, -0.055, '#angry', '#disgusting', -0.038, 'unaesthetic', 'need_shave', 'need_beauty_center', 'long_beard', 'carelessness']
senticnet['facial_organ'] = [0, 0.067, 0.024, 0.1, '#interesting', '#admirable', 0.048, 'facial_part', 'face_feature', 'part_of_face', 'face_part', 'face']
senticnet['facial_part'] = [0.057, 0.111, 0, 0.143, '#interesting', '#admirable', 0.104, 'mouth', 'facial_organ', 'face_feature', 'facial', 'nose']
senticnet['facial_tissue'] = [0.057, 0.111, 0, 0.143, '#interesting', '#admirable', 0.104, 'hankie', 'kleenex', 'hanky', 'handkerchief', 'tissue']
senticnet['facile'] = [-0.631, 0, 0.857, -0.711, '#angry', '#disgusting', -0.733, 'shallow', 'superficial', 'ostensible', 'sounding', 'looking']
senticnet['facility'] = [0.704, -0.687, 0, 0.795, '#joyful', '#admirable', 0.729, 'range', 'utility', 'course', 'airfield', 'landing_field']
senticnet['fact'] = [0.968, 0.732, 0, 0, '#joyful', '#interesting', 0.567, 'data', 'scientific_statement', 'report', 'educate_guess', 'hypothesis']
senticnet['fact_right'] = [0.86, 0.982, 0, 0, '#joyful', '#interesting', 0.614, 'convey_information', 'organize_thought', 'ability_communicate', 'write_word', 'draw_picture']
senticnet['fact_straight'] = [0.94, 0.836, 0, 0, '#joyful', '#interesting', 0.592, 'know_language', 'ability_communicate', 'know_talk', 'use_language', 'find_another_person']
senticnet['faction'] = [-0.502, 0, 0.989, -0.917, '#angry', '#disgusting', -0.803, 'camp', 'pack', 'clique', 'coterie', 'ingroup']
senticnet['factious'] = [-0.935, 0, 0.515, -0.786, '#sad', '#disgusting', -0.745, 'discrepant', 'at_variance', 'dissentious', 'divisive', 'discordant']
senticnet['factor'] = [0.812, 0, 0, 0.774, '#joyful', '#admirable', 0.529, 'divide', 'division', 'add', 'subtraction', 'math_action']
senticnet['factory'] = [0.05, 0.184, 0, 0.13, '#interesting', '#admirable', 0.121, 'industry', 'assembly_line', 'create_product', 'manufacturer', 'corporation']
senticnet['factory_output'] = [0, 0.184, -0.065, 0.235, '#interesting', '#admirable', 0.118, 'creation', 'manufacture', 'make_stuff', 'make', 'make_product']
senticnet['faculty'] = [0.577, -0.596, 0, 0.675, '#surprising', '#admirable', 0.616, 'understanding', 'intellect', 'ability', 'retentiveness', 'retentivity']
senticnet['fad'] = [0.027, -0.059, 0, 0.051, '#surprising', '#admirable', 0.046, 'frill', 'fashion', 'puppet', 'glamour', 'girly']
senticnet['faded'] = [-0.978, 0, 0.584, -0.789, '#sad', '#disgusting', -0.784, 'remittent', 'diminished', 'weakened', 'decreased', 'small']
senticnet['fading'] = [-0.78, 0, 0.764, -0.886, '#sad', '#disgusting', -0.81, 'withering', 'downfall', 'atrophy', 'weakening', 'attenuation']
senticnet['faerie'] = [0.865, -0.757, 0, 0.717, '#joyful', '#surprising', 0.78, 'fairy_godmother', 'imp', 'gnome', 'elf', 'hob']
senticnet['faery'] = [0.815, -0.616, 0, 0.827, '#joyful', '#admirable', 0.753, 'fairy_godmother', 'imp', 'gnome', 'elf', 'hob']
senticnet['fag'] = [0.537, -0.514, 0, 0.807, '#joyful', '#admirable', 0.619, 'lesbian', 'fairy', 'homoot', 'homogot', 'homo']
senticnet['fag_out'] = [0.84, -0.725, 0, 0.796, '#joyful', '#admirable', 0.787, 'tucker', 'tucker_out', 'exhaust', 'beat', 'overtire']
senticnet['faggot'] = [0.537, -0.514, 0, 0.807, '#joyful', '#admirable', 0.619, 'lesbian', 'fairy', 'fagot', 'homo', 'fag']
senticnet['faggot_up'] = [-0.882, 0, 0.682, -0.603, '#sad', '#angry', -0.722, 'hold', 'faggot', 'fagot', 'chain_up', 'tie_down']
senticnet['fagot'] = [0.537, -0.514, 0, 0.807, '#joyful', '#admirable', 0.619, 'lesbian', 'fairy', 'homo', 'faggot', 'fag']
senticnet['fail'] = [-0.96, 0, -0.811, -0.855, '#sad', '#disgusting', -0.875, 'further_goal', 'flunk', 'pass_fail', 'pass', 'cheat']
senticnet['fail_class'] = [-0.891, 0, -0.943, -0.726, '#sad', '#scared', -0.853, 'fail_exam', 'fail_test', 'question_teacher', 'brush_off', 'study_biology']
senticnet['fail_exam'] = [-0.986, 0, 0.854, -0.732, '#sad', '#angry', -0.857, 'fail_class', 'fail_test', 'question_teacher', 'find_out_healthy', 'study_biology']
senticnet['fail_test'] = [-0.875, 0, -0.717, -0.961, '#sad', '#disgusting', -0.851, 'guess_answer', 'question_teacher', 'solve_equation', 'succeed_school', 'master_new_skill']
senticnet['fail_work'] = [-0.079, -0.005, 0.028, 0, '#sad', '#angry', -0.034, 'dispense', 'cremate', 'destroy_city', 'kill_life', 'corner_prey']
senticnet['failing'] = [-0.668, 0, 0.662, -0.779, '#sad', '#disgusting', -0.703, 'insufficiency', 'fatigue', 'inadequacy', 'flaw', 'imperfection']
senticnet['failure'] = [-0.289, -0.036, -0.196, -0.09, '#sad', '#scared', -0.18, 'flunk', 'cancel', 'a_lot_of_stress', 'loss', 'bad_grade']
senticnet['faineance'] = [-0.664, 0, 0.749, -0.549, '#sad', '#angry', -0.654, 'inertia', 'inactiveness', 'inactivity', 'indolence', 'idleness']
senticnet['faint'] = [-0.065, -0.048, 0, -0.113, '#sad', '#disgusting', -0.043, 'fall_over', 'lose_balance', 'fall', 'fall_down', 'fall_ground']
senticnet['faint_suddenly'] = [-0.051, 0, -0.128, 0, '#sad', '#scared', -0.06, 'fall_ground', 'fall_dead', 'fall_over', 'fall_floor', 'loss_ofawareness']
senticnet['faintness'] = [0.906, -0.601, 0, 0.653, '#joyful', '#admirable', 0.72, 'opaqueness', 'blurriness', 'dimness', 'opacity', 'vagueness']
senticnet['fair'] = [0.715, 0, 0, 0.796, '#joyful', '#admirable', 0.504, 'carnival', 'circus', 'fairground', 'rodeo', 'disneyland']
senticnet['fair_judgment'] = [0.828, -0.904, 0, 0.874, '#surprising', '#admirable', 0.869, 'perspicacity', 'judgment', 'fair', 'sound_judgment', 'objectiveness']
senticnet['fairground'] = [0.788, 0, 0, 0.901, '#joyful', '#admirable', 0.563, 'carnival', 'circus', 'fair', 'rodeo', 'disneyland']
senticnet['fairness'] = [0.041, 0.17, -0.045, 0.125, '#interesting', '#admirable', 0.097, 'judge_jury', 'justice', 'trial', 'judicial_system', 'become_judge']
senticnet['fairy'] = [0.713, 0.977, 0, 0, '#joyful', '#interesting', 0.563, 'centerfold', 'genus', 'honey_bee', 'infant', 'dove']
senticnet['fairy_godmother'] = [0.865, -0.757, 0, 0.717, '#joyful', '#surprising', 0.78, 'faerie', 'imp', 'gnome', 'elf', 'hob']
senticnet['fairy_story'] = [0, 0, -0.088, 0, '#scared', '#scared', -0.029, 'fable', 'story', 'dictionary', 'saga', 'mythical']
senticnet['fairy_tale'] = [0, 0.091, 0, 0.101, '#interesting', '#admirable', 0.064, 'mythical', 'tale', 'dictionary', 'magic', 'perfect_world']
senticnet['fairytale'] = [-0.934, 0, 0.739, -0.969, '#sad', '#disgusting', -0.881, 'prevarication', 'fib', 'fairy_tale', 'fairy_story', 'song_and_dance']
senticnet['faith'] = [0.914, 0, 0, 0.954, '#joyful', '#admirable', 0.623, 'spiritual', 'religious', 'religious_purpose', 'religion', 'prayer']
senticnet['faith_god'] = [0.912, 0, 0, 0.966, '#joyful', '#admirable', 0.626, 'pray', 'kiss', 'get_help', 'pray_god', 'propose_woman']
senticnet['faithful'] = [0.731, 0, 0, 0.843, '#joyful', '#admirable', 0.525, 'faith', 'loyal', 'smart_dog', 'dog_cat', 'big_dog']
senticnet['faithfulness'] = [0.956, 0, 0, 0.864, '#joyful', '#admirable', 0.607, 'dog_like', 'wear_around_neck', 'type_of_dog', 'future_robot', 'trust']
senticnet['faithlessness'] = [0.667, -0.719, 0, 0.775, '#surprising', '#admirable', 0.72, 'quality', 'disloyalty', 'inconstancy', 'falseness', 'unfaithfulness']
senticnet['fake'] = [-0.091, 0.156, 0.661, -0.656, '#angry', '#disgusting', -0.417, 'phony', 'deception', 'false', 'against_law', 'trick']
senticnet['fake_certificate'] = [-0.882, 0, 0.682, -0.603, '#sad', '#angry', -0.722, 'false', 'statement', 'fake_document', 'tell_lie', 'false_statement']
senticnet['fake_document'] = [-0.882, 0, 0.682, -0.603, '#sad', '#angry', -0.722, 'false', 'statement', 'false_statement', 'tell_lie', 'fake_certificate']
senticnet['fake_love'] = [-0.975, 0, 0.893, -0.993, '#sad', '#disgusting', -0.954, 'heart_broken', 'wrong_person', 'bad_couple', 'bad_person', 'bad_marriage']
senticnet['fake_tooth'] = [0, -0.039, -0.095, -0.053, '#scared', '#disgusting', -0.036, 'play_in_theater', 'film', 'motion_picture', 'tooth', 'movie']
senticnet['faker'] = [-0.97, 0, 0.728, -0.785, '#sad', '#disgusting', -0.828, 'beguiler', 'slicker', 'name_dropper', 'ringer', 'deceiver']
senticnet['falcon'] = [0.933, -0.863, 0, 0, '#joyful', '#surprising', 0.599, 'butterfly', 'moth', 'parrot', 'beetle', 'wasp']
senticnet['fall'] = [-0.091, 0.156, 0.661, -0.656, '#angry', '#disgusting', -0.417, 'fall_down', 'fall_ground', 'break_neck', 'fall_over', 'stumble']
senticnet['fall_apart'] = [-0.796, 0, -0.749, -0.838, '#sad', '#disgusting', -0.794, 'fall_down_flight_stair', 'collide', 'install_window', 'accident', 'wreck']
senticnet['fall_asleep'] = [0.902, -0.944, 0, 0, '#joyful', '#surprising', 0.615, 'boring_talk', 'doze_off', 'drowsiness', 'sleepy', 'tired']
senticnet['fall_away'] = [-0.882, 0, 0.682, -0.603, '#sad', '#angry', -0.722, 'absent', 'disappear', 'evanesce', 'blow_over', 'pass_off']
senticnet['fall_back'] = [-0.771, 0, 0.785, -0.727, '#sad', '#angry', -0.761, 'recede', 'worsen', 'decline', 'drop_off', 'retrogress']
senticnet['fall_butt'] = [-0.771, 0, 0, -0.757, '#sad', '#disgusting', -0.509, 'fall_over', 'slippery', 'hit_tree', 'break_bone', 'crash_tree']
senticnet['fall_dead'] = [-0.105, 0, -0.085, -0.092, '#sad', '#disgusting', -0.094, 'fall_ground', 'loss_ofawareness', 'break_leg', 'loss_ofbreath', 'memory_loss']
senticnet['fall_down'] = [-0.76, 0, 0, -0.767, '#sad', '#disgusting', -0.509, 'lose_balance', 'trip_fall', 'fall_over', 'breafast', 'fall']
senticnet['fall_down_flight_stair'] = [-0.82, 0, -0.812, 0, '#sad', '#scared', -0.544, 'experience_pain', 'punch_face', 'go_insane', 'hit_car', 'feel_stupid']
senticnet['fall_downhill'] = [-0.074, -0.022, -0.046, 0, '#sad', '#scared', -0.033, 'bounce_ball', 'spring_up', 'fall_down', 'roll_downhill', 'float_through_air']
senticnet['fall_floor'] = [-0.07, 0, -0.07, -0.09, '#sad', '#scared', -0.077, 'stagger', 'fall_ground', 'fall_dead', 'run_out_booze', 'hit_oneself_head']
senticnet['fall_for'] = [-0.775, 0, 0.981, -0.522, '#sad', '#angry', -0.759, 'trip_up', 'stumble', 'misjudge', 'misremember', 'err']
senticnet['fall_from_grace'] = [-0.815, 0, 0.964, -0.621, '#sad', '#angry', -0.8, 'act_up', 'move', 'misdemean', 'carry_on', 'act']
senticnet['fall_from_tree'] = [-0.943, 0, 0.421, -0.963, '#sad', '#disgusting', -0.776, 'fall_headlong', 'hit', 'strike', 'beat', 'fall']
senticnet['fall_ground'] = [-0.076, -0.052, -0.055, -0.136, '#sad', '#disgusting', -0.072, 'fall_dead', 'fall_over', 'loss_ofawareness', 'loss_ofbreath', 'fall']
senticnet['fall_head'] = [-0.943, 0, 0.421, -0.963, '#sad', '#disgusting', -0.776, 'tired', 'sleepy', 'fall_asleep', 'drowsiness', 'faint']
senticnet['fall_headlong'] = [-0.918, 0, 0.469, -0.982, '#sad', '#disgusting', -0.79, 'hit', 'strike', 'beat', 'fall', 'bang']
senticnet['fall_ice'] = [-0.049, -0.02, 0.062, -0.1, '#angry', '#disgusting', -0.064, 'slippery', 'fall_down', 'lose_balance', 'fall', 'ice']
senticnet['fall_in_love'] = [0.738, -0.537, 0, 0.856, '#joyful', '#admirable', 0.71, 'enjoy_time_together', 'meet_girl', 'free_sex', 'kiss', 'infatuation']
senticnet['fall_love'] = [0.865, 0, 0, 0.977, '#joyful', '#admirable', 0.614, 'kiss_other', 'find_love', 'become_pregnant', 'make_love', 'care_deeply']
senticnet['fall_mud'] = [-0.066, 0, 0, -0.052, '#sad', '#disgusting', -0.039, 'fight_fire', 'get_dirty', 'become_dirty', 'feel_dirty', 'dirty']
senticnet['fall_off'] = [-0.774, 0, -0.823, 0, '#sad', '#scared', -0.532, 'use_brake', 'fall_down', 'peddle', 'trip_fall', 'fall_over']
senticnet['fall_off_chair'] = [-0.042, -0.01, -0.053, -0.092, '#scared', '#disgusting', -0.059, 'roll_over', 'lift_leg', 'blow_up_balloon', 'travel_through_space', 'fly_around']
senticnet['fall_on_butt'] = [0, 0, -0.744, 0, '#scared', '#scared', -0.248, 'accident', 'fall_over', 'butt', 'fall', 'break_bone']
senticnet['fall_out'] = [0.653, -0.959, 0, 0.8, '#surprising', '#admirable', 0.804, 'argufy', 'altercate', 'dispute', 'scrap', 'quarrel']
senticnet['fall_out_bed'] = [-0.065, 0, 0, -0.061, '#sad', '#disgusting', -0.042, 'cover_oneself_with_blanket', 'sleepwalk', 'close_eye', 'take_nap', 'shut_off_alarm_clock']
senticnet['fall_out_of_window'] = [-0.965, 0, 0.637, -0.97, '#sad', '#disgusting', -0.857, 'fall_down', 'damage_body', 'injury', 'physical_pain', 'commit_suicide']
senticnet['fall_over'] = [-0.926, 0, 0, -0.824, '#sad', '#disgusting', -0.583, 'lose_balance', 'fall_down', 'fall', 'skid', 'use_brake']
senticnet['fall_overboard'] = [-0.744, 0, -0.822, 0, '#sad', '#scared', -0.522, 'go_underwater', 'swim', 'scuba_dive', 'dive', 'pool_party']
senticnet['fall_sick'] = [-0.815, 0, 0.964, -0.621, '#sad', '#angry', -0.8, 'lose_team', 'cause_suffer', 'leave_out', 'disrespect', 'eat_bad_food']
senticnet['fall_sky'] = [0, -0.02, -0.069, -0.171, '#scared', '#disgusting', -0.073, 'forest_fire', 'fire_light', 'dynamite_explosion', 'firebomb', 'killer']
senticnet['fall_spring'] = [0.093, 0, 0, 0, '#joyful', '#joyful', 0.031, 'snowy', 'season_year', 'summer_winter', 'chilly', 'winter']
senticnet['fall_tree'] = [-0.21, -0.076, 0, -0.23, '#sad', '#disgusting', -0.121, 'cut_finger', 'open_wind', 'draw_blood', 'laceration', 'cause_bleed']
senticnet['fall_unconscious'] = [-0.994, 0, 0.26, -0.986, '#sad', '#disgusting', -0.747, 'lose_consciousness', 'fall', 'faint', 'death', 'sleep']
senticnet['fall_well'] = [-0.108, 0, -0.048, 0, '#sad', '#scared', -0.052, 'fly_around', 'shovel_snow', 'blow_up_balloon', 'smoke_joint', 'blow_away']
senticnet['fallaciousness'] = [-0.551, 0, 0.741, -0.768, '#angry', '#disgusting', -0.687, 'illogicality', 'illogicalness', 'illogic', 'inconsequence', 'invalidity']
senticnet['fallacy'] = [-0.777, 0, 0.885, -0.738, '#sad', '#angry', -0.8, 'pathetic_fallacy', 'misconception', 'paralogism', 'logical_fallacy', 'pseudoscience']
senticnet['fallen'] = [0, 0, -0.978, 0, '#scared', '#scared', -0.326, 'water_drip', 'little_water', 'rain_water', 'drop_down', 'before_fall']
senticnet['fallen_angel'] = [0.992, 0, 0, 0.797, '#joyful', '#admirable', 0.596, 'goddess', 'god', 'saint', 'evangelist', 'monk']
senticnet['fallen_leaf'] = [-0.976, 0, 0, -0.983, '#sad', '#disgusting', -0.653, 'grass_clipping', 'homeless_people', 'litter', 'streetlight', 'traffic_light']
senticnet['fallen_tree'] = [-0.174, -0.074, 0, -0.175, '#sad', '#disgusting', -0.092, 'rotten_fruit', 'strong_wind', 'compost_pile', 'dangerous', 'bad_weather']
senticnet['fallibility'] = [-0.922, 0, 0.546, -0.523, '#sad', '#angry', -0.664, 'irresponsibility', 'irresponsibleness', 'instability', 'irreproducibility', 'undependability']
senticnet['fallible'] = [-0.831, 0, 0.962, -0.627, '#sad', '#angry', -0.807, 'unreliable', 'undependable', 'weak', 'errant', 'erring']
senticnet['falling'] = [-0.983, 0, 0.962, -0.956, '#sad', '#angry', -0.967, 'depreciative', 'depreciatory', 'decreasing', 'depreciating', 'detractive']
senticnet['falling_off'] = [-0.952, 0, 0.862, -0.973, '#sad', '#disgusting', -0.929, 'decline', 'slack', 'slump', 'falloff', 'decline_in_quality']
senticnet['falling_water'] = [0.828, -0.74, 0, 0, '#joyful', '#surprising', 0.523, 'water_fall', 'come_down', 'water_drop', 'rain_water', 'water']
senticnet['falloff'] = [-0.952, 0, 0.862, -0.973, '#sad', '#disgusting', -0.929, 'decline', 'slack', 'slump', 'decline_in_quality', 'falling_off']
senticnet['fallout'] = [-0.955, 0, 0.738, -0.584, '#sad', '#angry', -0.759, 'dust', 'chalk_dust', 'radioactive_dust', 'particulate', 'particulate_matter']
senticnet['fallow'] = [-0.769, 0, 0.695, -0.785, '#sad', '#disgusting', -0.75, 'cultivated_land', 'farmland', 'plowland', 'ploughland', 'tilled_land']
senticnet['false'] = [-0.244, 0.147, -0.25, 0.215, '#sad', '#scared', -0.044, 'dishonest', 'against_law', 'falsehood', 'deceit', 'deception']
senticnet['false_accusation'] = [-0.9, 0, 0.009, -0.935, '#sad', '#disgusting', -0.615, 'tell_lie', 'lie', 'make_false_accusation', 'tell_untruth', 'dishonesty']
senticnet['false_belief'] = [-0.755, 0, 0.624, -0.988, '#sad', '#disgusting', -0.789, 'pathetic_fallacy', 'misconception', 'paralogism', 'logical_fallacy', 'pseudoscience']
senticnet['false_gavial'] = [-0.853, 0, 0.685, -0.838, '#sad', '#disgusting', -0.792, 'alligator', 'crocodile', 'crocodilian', 'gator', 'caiman']
senticnet['false_statement'] = [0, 0, 0, -0.959, '#disgusting', '#disgusting', -0.32, 'false', 'statement', 'fake_document', 'tell_lie', 'fake_certificate']
senticnet['false_teeth'] = [-0.657, 0, 0.65, -0.981, '#sad', '#disgusting', -0.763, 'dental_plate', 'bridge', 'bridgework', 'partial_denture', 'dental_appliance']
senticnet['false_tooth'] = [0, 0, 0, -0.801, '#disgusting', '#disgusting', -0.267, 'hairball', 'clog', 'waste_water', 'stench', 'many_species']
senticnet['false_witness'] = [-0.633, 0, 0.88, -0.941, '#angry', '#disgusting', -0.818, 'beguiler', 'slicker', 'perjurer', 'prevaricator', 'storyteller']
senticnet['falsehood'] = [-0.931, 0, -0.712, 0, '#sad', '#scared', -0.548, 'fallacy', 'dishonesty', 'deceit', 'untruth', 'lie']
senticnet['falseness'] = [-0.947, 0, 0.925, -0.979, '#sad', '#disgusting', -0.95, 'nonexistence', 'nonentity', 'cloud', 'irreality', 'falsity']
senticnet['falsify'] = [-0.593, 0, 0.537, -0.532, '#sad', '#angry', -0.554, 'murder', 'mutilate', 'mangle', 'misrepresent', 'belie']
senticnet['falsity'] = [-0.569, 0, 0.593, -0.595, '#angry', '#disgusting', -0.586, 'antinomy', 'paradox', 'falsehood', 'contradiction_in_terms', 'untruth']
senticnet['falter'] = [-0.885, 0, 0.925, -0.556, '#sad', '#angry', -0.789, 'hesitate', 'waver', 'linger', 'boggle', 'dwell_on']
senticnet['falters'] = [0, 0, 0.793, -0.837, '#angry', '#disgusting', -0.543, 'stumble', 'waver', 'hesitation', 'bumble', 'faltering']
senticnet['fame'] = [0.874, 0.845, 0, 0.962, '#joyful', '#admirable', 0.894, 'improve_world', 'accolade', 'alms', 'self_confidence', 'consistency']
senticnet['familial_relationship'] = [0.903, 0.684, 0, 0.791, '#joyful', '#admirable', 0.793, 'relative', 'family_member', 'relationship', 'family', 'mother']
senticnet['familiar'] = [0.726, 0.896, 0, 0.757, '#interesting', '#admirable', 0.793, 'aunt_uncle', 'happy_together', 'relate_person', 'kin', 'relation']
senticnet['familiarity'] = [0.02, 0.209, -0.148, 0.202, '#interesting', '#admirable', 0.094, 'familiar', 'mum', 'aunt_uncle', 'care_giver', 'aunt']
senticnet['family'] = [0, 0.269, -0.17, 0.182, '#interesting', '#admirable', 0.094, 'kinship', 'siblings', 'elder', 'big_brother', 'best_friend']
senticnet['family_activity'] = [0.046, -0.035, 0, 0, '#joyful', '#surprising', 0.027, 'anarchy', 'play_marble', 'dinner_party', 'spray_paint_grafitti', 'horseback_ride']
senticnet['family_doctor'] = [0.738, -0.537, 0, 0.856, '#joyful', '#admirable', 0.71, 'doctor', 'country_doctor', 'general_practitioner', 'doctor_office', 'physician']
senticnet['family_dog'] = [0.056, 0.157, 0, 0.154, '#interesting', '#admirable', 0.122, 'domesticate_dog', 'domesticate_pet', 'animal', 'domesticate_cat', 'dog']
senticnet['family_fun'] = [0.755, 0.702, 0, 0, '#joyful', '#interesting', 0.486, 'party', 'pool_party', 'play_together', 'family_reunion', 'fun']
senticnet['family_gathering'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'christmas_tree', 'christmas_gift', 'family_time', 'christmas_holiday', 'christmas']
senticnet['family_history'] = [0.966, 0.83, 0, 0, '#joyful', '#interesting', 0.599, 'headstone', 'graveyard', 'show_how', 'family', 'death_place']
senticnet['family_home'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'small_home', 'residence', 'home_build', 'domicile', 'dwell_place']
senticnet['family_live'] = [0.09, 0.197, -0.133, 0.242, '#interesting', '#admirable', 0.132, 'live_life', 'live_area', 'domestic_dwell', 'live_space', 'live_place']
senticnet['family_member'] = [0.986, 0.931, 0, 0, '#joyful', '#interesting', 0.639, 'relative', 'familial_relationship', 'sibling', 'mother_brother', 'female_relative']
senticnet['family_nest'] = [-0.104, 0.235, -0.127, 0.246, '#interesting', '#admirable', 0.083, 'love', 'settle_down', 'home_sweet_home', 'family', 'happy_family']
senticnet['family_photo'] = [0.754, 0.739, 0, 0, '#joyful', '#interesting', 0.498, 'aunt_uncle', 'picture_of_family', 'aunt', 'grandmother', 'relative']
senticnet['family_picture'] = [0.073, 0, 0, 0, '#joyful', '#joyful', 0.024, 'light_fixture', 'tv_set', 'side_chair', 'dvd_player', 'old_photograph']
senticnet['family_relation'] = [0.997, 0.882, 0, 0, '#joyful', '#interesting', 0.626, 'familial_relationship', 'sibling', 'father_offspring', 'mother_brother', 'kin']
senticnet['family_relationship_term'] = [0.773, 0.78, 0, 0, '#joyful', '#interesting', 0.518, 'family_member', 'relative', 'male_parent', 'male_relative', 'mother_brother']
senticnet['family_reunion'] = [0.161, 0.155, -0.081, 0.223, '#joyful', '#admirable', 0.153, 'family', 'happy_moment', 'aunt_uncle', 'brother_sister', 'relation']
senticnet['family_time'] = [0.756, 0.91, 0, 0, '#joyful', '#interesting', 0.555, 'buy_flower', 'give_present', 'buy_ring', 'warm_feeling', 'love']
senticnet['family_tree'] = [0.995, 0.977, 0, 0, '#joyful', '#interesting', 0.657, 'informal', 'family', 'lullaby', 'play_together', 'old_grandchild']
senticnet['famine'] = [-0.792, 0, -0.924, -0.708, '#sad', '#scared', -0.808, 'make_breakfast', 'feel_hunger', 'need_grocery', 'order_lunch', 'fix_dinner']
senticnet['famished'] = [-0.713, 0, 0.692, -0.818, '#sad', '#disgusting', -0.741, 'hungry', 'starved', 'ravenous', 'esurient', 'peckish']
senticnet['famous'] = [0.772, 0.812, 0, 0.727, '#joyful', '#interesting', 0.77, 'well_known', 'collection', 'favorite', 'majority', 'get_excited']
senticnet['famous_brand'] = [0.992, 0.728, 0, 0.834, '#joyful', '#admirable', 0.851, 'beautiful_car', 'car', 'high_class', 'expensive_car', 'limousine']
senticnet['famous_person'] = [0.161, 0.155, -0.081, 0.223, '#joyful', '#admirable', 0.153, 'vip', 'celebrity', 'powerful_man', 'royalty', 'princess']
senticnet['fan'] = [0.628, -0.967, 0, 0.682, '#surprising', '#admirable', 0.759, 'electric_fan', 'blower', 'exhaust_fan', 'punkah', 'device']
senticnet['fan_belt'] = [0, -0.057, 0, 0.05, '#surprising', '#admirable', 0.036, 'emergency_brake', 'brake_pedal', 'air_vent', 'headlight', 'dynamo']
senticnet['fan_dance'] = [0.993, -0.967, 0, 0.917, '#joyful', '#surprising', 0.959, 'strip', 'nude_dancing', 'striptease', 'strip_show', 'bubble_dance']
senticnet['fan_palm'] = [0.557, -0.534, 0, 0.704, '#joyful', '#admirable', 0.598, 'carnauba_palm', 'carnauba', 'wax_palm', 'palmetto', 'palmyra']
senticnet['fanatic'] = [-0.911, 0, 0.794, -0.934, '#sad', '#disgusting', -0.88, 'fundamentalist', 'extremist', 'obsession', 'stubborn', 'violent']
senticnet['fancier'] = [0.967, 0, 0, 0.776, '#joyful', '#admirable', 0.581, 'enthusiast', 'horseman', 'horse_animal_fancier', 'animal_fancier', 'lover']
senticnet['fancify'] = [0.501, -0.905, 0, 0.881, '#surprising', '#admirable', 0.762, 'suit', 'better', 'improve', 'fancy', 'meliorate']
senticnet['fancy'] = [0.727, 0.947, 0, 0.701, '#joyful', '#interesting', 0.792, 'romantic', 'style', 'smooth', 'vanity', 'cool']
senticnet['fancy_car'] = [0.755, 0.702, 0, 0, '#joyful', '#interesting', 0.486, 'high_class', 'expensive_car', 'ferrari', 'lamborghini', 'sports_car']
senticnet['fancy_clothes'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'clothes_style', 'style', 'glamour', 'model', 'formal_clothes']
senticnet['fancy_dress'] = [0.796, 0.851, 0, 0, '#joyful', '#interesting', 0.549, 'expensive_dress', 'dress', 'fashion', 'gala', 'red_carpet']
senticnet['fancy_girl'] = [-0.126, 0, -0.057, 0, '#sad', '#scared', -0.061, 'wedge_door', 'kiss_girl', 'part_of_hair', 'steal_store', 'trade_baseball_card']
senticnet['fancy_house'] = [0.903, 0.684, 0, 0.791, '#joyful', '#admirable', 0.793, 'house', 'expensive_house', 'villa', 'fabulous', 'vip']
senticnet['fancy_woman'] = [0.7, -0.628, 0, 0.58, '#joyful', '#surprising', 0.636, 'slattern', 'camp_follower', 'call_girl', 'comfort_woman', 'ianfu']
senticnet['fang'] = [0, -0.01, 0.041, -0.065, '#angry', '#disgusting', -0.032, 'long_tooth', 'big_tooth', 'long_tail', 'sharp_tooth', 'animal_part']
senticnet['fantasize'] = [-0.025, -0.048, 0.071, -0.208, '#angry', '#disgusting', -0.085, 'learn_new_word', 'solve', 'see_oneself', 'inspiration', 'use_imagination']
senticnet['fantastic'] = [0.88, 0.86, 0, 0, '#joyful', '#interesting', 0.58, 'amaze', 'grand', 'wonderful', 'pose', 'howling']
senticnet['fantasy'] = [0.713, 0.856, 0, 0, '#joyful', '#interesting', 0.523, 'night_vision', 'mystery', 'plot', 'imagine', 'myth']
senticnet['far'] = [0, 0, 0.828, 0, '#angry', '#angry', -0.276, 'distance', 'mile', 'long_distance_relationship', 'length', 'long_distance']
senticnet['far_away'] = [-0.952, 0, 0, -0.722, '#sad', '#disgusting', -0.558, 'outer', 'radiant', 'around_earth', 'nothingness', 'heavenly_body']
senticnet['far_from'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'long_distance', 'long_travel', 'further', 'far', 'isolated']
senticnet['far_from_each_other'] = [-0.844, 0, 0.7, -0.927, '#sad', '#disgusting', -0.824, 'long_distance', 'long_distance_relationship', 'distant', 'length_measurement', 'kilometer']
senticnet['far_from_home'] = [0, 0, 0, -0.959, '#disgusting', '#disgusting', -0.32, 'immigrant', 'expat', 'live_abroad', 'connoisseur', 'work_abroad']
senticnet['far_west'] = [0.705, 0, 0, 0.999, '#joyful', '#admirable', 0.568, 'from_here', 'red_indian', 'live_place', 'family_live', 'original']
senticnet['farandole'] = [-0.744, 0, 0.501, -0.99, '#sad', '#disgusting', -0.745, 'folk_dance', 'mazurka', 'polka', 'morris_dance', 'morris_dancing']
senticnet['fare'] = [-0.035, 0.29, -0.128, 0.203, '#interesting', '#admirable', 0.11, 'excise', 'severance', 'wage', 'afford', 'revenue']
senticnet['farecard'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'thruway', 'national_interstate_highway', 'round_trip_ticket', 'traffic_artery', 'move_sidewalk']
senticnet['farewell'] = [0.037, 0.161, -0.154, 0.203, '#interesting', '#admirable', 0.082, 'wave', 'flow', 'salute', 'multiple_purposes', 'wave_wind']
senticnet['farfetched'] = [-0.926, 0, 0, -0.899, '#sad', '#disgusting', -0.608, 'implausible', 'unbelievable', 'cockamamie', 'dubious', 'unlikely']
senticnet['farm'] = [0.053, 0.094, 0, 0.136, '#interesting', '#admirable', 0.094, 'barn_animal', 'domesticate', 'stand_field', 'sheep', 'cow']
senticnet['farm_animal'] = [0.038, 0.079, 0.03, 0.083, '#interesting', '#admirable', 0.057, 'country_side', 'farm_house', 'large_area', 'rural_area', 'farm_area']
senticnet['farm_area'] = [0.038, 0.079, 0.03, 0.083, '#interesting', '#admirable', 0.057, 'farm', 'countryside', 'farm_animal', 'cow', 'fresh_milk']
senticnet['farm_bird'] = [0.041, 0, 0, 0.058, '#joyful', '#admirable', 0.033, 'bird', 'bird_animal', 'biped', 'barnyard_animal', 'hen_baby']
senticnet['farm_crop'] = [0, 0.074, 0.035, 0.071, '#interesting', '#admirable', 0.037, 'farm_food', 'grown_food', 'cereal_crop', 'farm_plant', 'edible_grain']
senticnet['farm_food'] = [0, 0.083, 0.023, 0.074, '#interesting', '#admirable', 0.045, 'grown_food', 'farm_vegetable', 'farm_crop', 'farm_plant', 'plant_food']
senticnet['farm_girl'] = [0.738, -0.537, 0, 0.856, '#joyful', '#admirable', 0.71, 'little_girl', 'flower_girl', 'moppet', 'schoolgirl', 'female']
senticnet['farm_house'] = [0.038, 0.079, 0.03, 0.083, '#interesting', '#admirable', 0.057, 'farm_animal', 'country_side', 'large_area', 'rural_area', 'farm_area']
senticnet['farm_land'] = [-0.03, 0.12, 0, 0.078, '#interesting', '#admirable', 0.056, 'grow_stuff', 'grow_food', 'crop_place', 'cow_home', 'water_crop']
senticnet['farm_plant'] = [0, 0.092, 0.038, 0.083, '#interesting', '#admirable', 0.046, 'plant_food', 'wheat_rice', 'grown_food', 'wheat_corn', 'farm_vegetable']
senticnet['farm_vegetable'] = [0, 0.099, 0.012, 0.067, '#interesting', '#admirable', 0.051, 'farm_food', 'farm_plant', 'plant_food', 'grown_food', 'wheat_corn']
senticnet['farmer'] = [-0.088, 0, -0.145, 0, '#sad', '#scared', -0.078, 'serf', 'peasant', 'servant', 'poor', 'villein']
senticnet['farmer_market'] = [0, 0.071, 0.009, 0.104, '#interesting', '#admirable', 0.055, 'retail_store', 'supermarket', 'product', 'market', 'fresh_food']
senticnet['farmland'] = [-0.769, 0, 0.695, -0.785, '#sad', '#disgusting', -0.75, 'cultivated_land', 'fallow', 'plowland', 'ploughland', 'tilled_land']
senticnet['farmyard'] = [0.034, 0, 0, 0.064, '#joyful', '#admirable', 0.033, 'barn', 'graze_field', 'field', 'stable', 'barn_field']
senticnet['farrier'] = [0, 0.115, 0, 0.105, '#interesting', '#admirable', 0.073, 'blacksmith', 'miner', 'horseshoer', 'locksmith', 'smith']
senticnet['farseeing'] = [0.545, -0.599, 0, 0.865, '#surprising', '#admirable', 0.67, 'farsighted', 'longsighted', 'telescopic', 'hyperopic', 'hypermetropic']
senticnet['farsighted'] = [0.545, -0.599, 0, 0.865, '#surprising', '#admirable', 0.67, 'farseeing', 'longsighted', 'telescopic', 'hyperopic', 'hypermetropic']
senticnet['farsightedness'] = [0.7, -0.628, 0, 0.58, '#joyful', '#surprising', 0.636, 'see_far', 'hyperopia', 'hypermetropia', 'hypermetropy', 'longsightedness']
senticnet['fart'] = [0, 0, 0, -0.765, '#disgusting', '#disgusting', -0.255, 'burp', 'rude', 'bad_manners', 'shame', 'get_angry']
senticnet['fascinate'] = [0.842, 0.792, 0, 0.977, '#joyful', '#admirable', 0.87, 'confident', 'easiness', 'relieve', 'allay', 'repose']
senticnet['fascinated'] = [0.998, -0.75, 0, 0.695, '#joyful', '#surprising', 0.814, 'bewitched', 'ensorcelled', 'enchanted', 'hypnotized', 'mesmerized']
senticnet['fascinating'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['fascination'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'captivated', 'charmed', 'captivate', 'bewitch', 'enthrallment']
senticnet['fascism'] = [-0.819, -0.715, 0.843, -0.726, '#sad', '#angry', -0.558, 'lack_of_rules', 'anarchism', 'despot', 'tyrant', 'nazism']
senticnet['fashion'] = [0.068, 0, 0.014, 0.055, '#joyful', '#admirable', 0.036, 'frill', 'blouse', 'frock', 'outfit', 'wear']
senticnet['fashion_cloth'] = [0.738, -0.537, 0, 0.856, '#joyful', '#admirable', 0.71, 'event', 'exhibition', 'model', 'fashion_designer', 'fashion_show']
senticnet['fashion_designer'] = [0.738, -0.537, 0, 0.856, '#joyful', '#admirable', 0.71, 'event', 'exhibition', 'model', 'fashion_show', 'fashion_cloth']
senticnet['fashion_event'] = [0.058, 0, 0, 0.088, '#joyful', '#admirable', 0.049, 'school_hall', 'exhibition', 'art', 'football_stadium', 'sport_arena']
senticnet['fashion_show'] = [0.058, 0, 0, 0.088, '#joyful', '#admirable', 0.049, 'event', 'exhibition', 'model', 'fashion_designer', 'fashion_cloth']
senticnet['fashion_style'] = [0.738, -0.537, 0, 0.856, '#joyful', '#admirable', 0.71, 'write_book', 'artist', 'publish_book', 'life_style', 'write_with_style']
senticnet['fashionable'] = [0.952, 0.844, 0, 0.96, '#joyful', '#admirable', 0.919, 'fashion', 'demand', 'kindness', 'better_person', 'warm_feeling']
senticnet['fast'] = [0, 0.107, 0, 0.184, '#interesting', '#admirable', 0.097, 'quick', 'speedy', 'flee', 'quickness', 'quick_motion']
senticnet['fast_and_furious'] = [0.258, 0.357, -0.088, 0.351, '#interesting', '#admirable', 0.293, 'speed', 'fast', 'velocity', 'speedy', 'fleet']
senticnet['fast_buck'] = [0.685, -0.58, 0, 0.56, '#joyful', '#surprising', 0.608, 'profit', 'net_income', 'net', 'net_profit', 'lucre']
senticnet['fast_car'] = [0.181, 0, 0.034, 0.203, '#joyful', '#admirable', 0.117, 'mode_transportation', 'form_of_transportation', 'means_of_transportation', 'machine_transportation', 'car_model']
senticnet['fast_computer'] = [0.128, 0.075, 0.052, 0.083, '#joyful', '#admirable', 0.078, 'computer', 'browser', 'efficient', 'telephone_computer', 'modem']
senticnet['fast_day'] = [0.886, 0.888, 0, 0, '#joyful', '#interesting', 0.591, 'diet', 'lack_of_energy', 'sacrifice', 'religious', 'avoid_food']
senticnet['fast_food'] = [0.06, -0.012, 0, 0, '#joyful', '#surprising', 0.024, 'eat_food', 'restaurant', 'meal', 'fast', 'mc_donald']
senticnet['fast_food_restaurant'] = [0.966, 0.921, 0, 0.892, '#joyful', '#interesting', 0.926, 'fast_food', 'meal', 'eat_food_fast', 'burger_king', 'eat_burger']
senticnet['fast_meal'] = [-0.633, 0, 0.88, -0.941, '#angry', '#disgusting', -0.818, 'hungry', 'need_money', 'poor_people', 'ill', 'eat_little']
senticnet['fast_movement'] = [0.711, 0, 0, 0.765, '#joyful', '#admirable', 0.492, 'vigorous_activity', 'body_movement', 'human_movement', 'foot_movement', 'human_action']
senticnet['fast_pace'] = [-0.633, 0, 0.88, -0.941, '#angry', '#disgusting', -0.818, 'pressure', 'busy', 'system', 'big_city_life', 'subway']
senticnet['fast_person'] = [-0.025, 0, 0.044, 0, '#sad', '#angry', -0.023, 'large_cat', 'carnivore', 'household_pet', 'big_cat', 'good_pet']
senticnet['fast_sport'] = [0.047, -0.08, 0.018, 0.07, '#surprising', '#admirable', 0.06, 'violent_sport', 'team_sport', 'contact_sport', 'type_of_sport', 'rough_game']
senticnet['fast_travel'] = [0.946, 0, 0, 0.77, '#joyful', '#admirable', 0.572, 'game', 'travel_world', 'fun', 'travel_map', 'location']
senticnet['fast_walk'] = [0.921, 0, 0, 0.862, '#joyful', '#admirable', 0.594, 'walk_fast', 'like_run', 'walk_quickly', 'run_slowly', 'human_movement']
senticnet['fast_water'] = [-0.916, 0, -0.83, 0, '#sad', '#scared', -0.582, 'ocean_movement', 'sea_movement', 'water_movement', 'ebb', 'water_flow']
senticnet['fasten'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'keep_paper_together', 'bind', 'frighten_person', 'carry_paper', 'beatles_song']
senticnet['fasten_paper_together'] = [0.026, 0.077, 0, 0.05, '#interesting', '#admirable', 0.051, 'keep_paper_together', 'store_document', 'bind_paper_together', 'carry_paper', 'organize_document']
senticnet['fasten_seat_belt'] = [-0.084, 0, 0, 0, '#sad', '#sad', -0.028, 'turn_key', 'plan_route', 'open_car_door', 'book_flight', 'turn_car_off']
senticnet['fasten_seatbelt'] = [0.026, 0.077, 0, 0.05, '#interesting', '#admirable', 0.051, 'adjust_seat', 'check_mirror', 'turn_engine', 'safety', 'put_key_ignition']
senticnet['fasten_two_objects_together'] = [-0.756, 0, 0.955, 0, '#sad', '#angry', -0.57, 'bind_together', 'construct', 'hold_together', 'build_bridge', 'find_suburb']
senticnet['fastener'] = [0.836, 0, 0, 0.897, '#joyful', '#admirable', 0.578, 'bell_sound', 'bell_noise', 'piece_of_jewelry', 'syllable', 'jab']
senticnet['fastener_binder'] = [-0.829, 0, -0.809, 0, '#sad', '#scared', -0.546, 'fix', 'glue', 'super_glue', 'stick_together', 'repair']
senticnet['faster'] = [0.729, 0.974, 0, 0, '#joyful', '#interesting', 0.568, 'travel', 'fast', 'travel_fast', 'take_airplane', 'drive_fast']
senticnet['fastidious'] = [0.682, -0.525, 0, 0.613, '#joyful', '#admirable', 0.607, 'meticulous', 'pernickety', 'choosy', 'fussy', 'dainty']
senticnet['fat'] = [-0.082, 0.202, 0.615, -0.627, '#angry', '#disgusting', -0.374, 'flatulence', 'indigestion', 'stomach_ache', 'enjoy_taste', 'eat_lot']
senticnet['fat_guy'] = [-0.061, 0, -0.06, 0, '#sad', '#scared', -0.04, 'high_cholesterol', 'fat', 'lazy', 'lack_of_exercise', 'round']
senticnet['fat_person'] = [-0.969, 0, 0.212, -0.926, '#sad', '#disgusting', -0.702, 'unhealthy_food', 'eat_too_much', 'greasy_food', 'fast_food', 'no_exercise']
senticnet['fatal'] = [-0.159, -0.005, -0.122, -0.135, '#sad', '#disgusting', -0.137, 'painful', 'hurtful', 'harm', 'inflict_pain', 'bloody']
senticnet['fatal_accident'] = [-0.716, 0, 0.748, -0.55, '#sad', '#angry', -0.671, 'casualty', 'fatality', 'killing', 'violent_death', 'death']
senticnet['fatalist'] = [-0.55, 0, 0.58, -0.982, '#angry', '#disgusting', -0.704, 'necessitarian', 'determinist', 'predestinarian', 'predestinationist', 'philosopher']
senticnet['fatality'] = [-0.716, 0, 0.748, -0.55, '#sad', '#angry', -0.671, 'casualty', 'fatal_accident', 'killing', 'violent_death', 'death']
senticnet['fate'] = [0.947, 0, 0, 0.835, '#joyful', '#admirable', 0.594, 'enter_contract', 'believe', 'give_help', 'karma', 'destiny']
senticnet['fateful'] = [0.698, -0.988, 0, 0.651, '#joyful', '#surprising', 0.779, 'decisive', 'deciding', 'determinant', 'determinative', 'determining']
senticnet['father'] = [0.108, -0.044, 0.043, 0.065, '#joyful', '#admirable', 0.058, 'family', 'love_back', 'mother', 'carry_baby', 'change_diaper']
senticnet['father_child'] = [0.973, 0, 0, 0.774, '#joyful', '#admirable', 0.582, 'mother_child', 'father_offspring', 'father_son', 'kinship', 'take_out_trash']
senticnet['father_mother'] = [0.767, 0, 0, 0.781, '#joyful', '#admirable', 0.516, 'mom_dad', 'family_relation', 'parent_child', 'human_offspring', 'brother_sister']
senticnet['father_offspring'] = [0.919, 0.865, 0, 0, '#joyful', '#interesting', 0.595, 'familial_relationship', 'sibling', 'family_relation', 'mother_brother', 'kin']
senticnet['father_son'] = [0.793, 0, 0, 0.845, '#joyful', '#admirable', 0.546, 'mommy', 'father_child', 'mother_child', 'kinship', 'adopt_child']
senticnet['fatherliness'] = [0.585, -0.885, 0, 0.615, '#surprising', '#admirable', 0.695, 'motherliness', 'maternal_quality', 'quality', 'maternalism', 'parental_quality']
senticnet['fathomable'] = [0.744, -0.766, 0, 0.669, '#joyful', '#surprising', 0.726, 'accessible', 'comprehendible', 'approachable', 'perceivable', 'intelligible']
senticnet['fatigue'] = [-0.857, 0, 0, 0, '#sad', '#sad', -0.286, 'tiredness', 'become_tired', 'exhaustion', 'get_tired_leg', 'heavy_breathe']
senticnet['fatigues'] = [-0.798, 0, 0.599, -0.938, '#sad', '#disgusting', -0.778, 'uniform', 'battle_dress', 'dress_uniform', 'military_uniform', 'khakis']
senticnet['fats'] = [-0.972, 0, 0.7, -0.964, '#sad', '#disgusting', -0.879, 'kill_person', 'blocked_artery', 'unhealthy_food', 'kill', 'cause_heart_disease']
senticnet['fattening_food'] = [-0.98, 0, 0.594, -0.988, '#sad', '#disgusting', -0.854, 'fast_food', 'deep_fried', 'unhealthy_food', 'reuse_oil', 'junk_food']
senticnet['fatty'] = [0, 0, -0.98, -0.978, '#scared', '#disgusting', -0.653, 'fat', 'obese', 'worse', 'health_issue', 'clinical_problem']
senticnet['fatty_liver'] = [-0.98, 0, 0.594, -0.988, '#sad', '#disgusting', -0.854, 'disease', 'liver_disease', 'hepatitis', 'liver_cancer', 'cancer_of_liver']
senticnet['fatuity'] = [0.702, -0.527, 0, 0.981, '#joyful', '#admirable', 0.737, 'injudiciousness', 'asininity', 'silliness', 'foolishness', 'fatuousness']
senticnet['fatuousness'] = [0.702, -0.527, 0, 0.981, '#joyful', '#admirable', 0.737, 'injudiciousness', 'asininity', 'silliness', 'fatuity', 'foolishness']
senticnet['faucet'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'dirty_dish_overflow', 'hot_dirty_dish', 'hot_tap', 'dirty_dish', 'washcloth']
senticnet['faucet_overflow'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'dirty_dish', 'hot_faucet', 'hot_tap', 'faucet', 'washcloth']
senticnet['fault'] = [0, 0, 0.869, -0.924, '#angry', '#disgusting', -0.598, 'accuser', 'fall_down', 'fall_off', 'collapse', 'sore_knee']
senticnet['faultfinding'] = [-0.543, 0, 0.884, -0.714, '#angry', '#disgusting', -0.714, 'reprimand', 'static', 'stricture', 'disapproval', 'unfavorable_judgment']
senticnet['faultiness'] = [0.552, -0.669, 0, 0.845, '#surprising', '#admirable', 0.689, 'imperfection', 'imperfectness', 'bugginess', 'lameness', 'sickness']
senticnet['faulty'] = [-0.515, 0, 0.502, -0.58, '#sad', '#disgusting', -0.532, 'wrong', 'incorrect', 'wide_of_mark', 'unfaithful', 'inaccurate']
senticnet['fauna'] = [0, 0.089, 0, 0.105, '#interesting', '#admirable', 0.065, 'life', 'live_organism', 'animal', 'usual_green', 'leafy']
senticnet['favor'] = [0.63, 0.622, -0.29, 0.365, '#joyful', '#interesting', 0.442, 'joyful', 'favorable', 'favorably', 'agree', 'jubilantly']
senticnet['favorable'] = [0.596, 0.65, -0.269, 0.32, '#joyful', '#interesting', 0.432, 'approbative', 'sanctioned', 'approving', 'affirmative', 'approbatory']
senticnet['favorable_position'] = [0.761, -0.502, 0, 0.896, '#joyful', '#admirable', 0.72, 'advantage', 'vantage', 'upper_hand', 'whip_hand', 'edge']
senticnet['favorableness'] = [0.854, -0.794, 0, 0.977, '#joyful', '#admirable', 0.875, 'profitableness', 'auspiciousness', 'favourableness', 'advantageousness', 'positivity']
senticnet['favorably'] = [0, 0, 0, 0.751, '#admirable', '#admirable', 0.25, 'enchant', 'favorable', 'charm', 'charmy', 'comfortableness']
senticnet['favorite'] = [0.77, 0, 0, 0.96, '#joyful', '#admirable', 0.577, 'picket_sign', 'everyone_know', 'several_people', 'well_known', 'activist']
senticnet['favorite_color'] = [0.756, 0.798, 0, 0, '#joyful', '#interesting', 0.518, 'bird_pet', 'indigo', 'cyan', 'aqua', 'violet']
senticnet['favorite_singer'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'enjoy_music', 'relax', 'enjoy_fresh_air', 'listen_music', 'listen_music_headphones']
senticnet['favourable'] = [0.585, -0.574, 0, 0.558, '#joyful', '#surprising', 0.572, 'approving', 'approbative', 'approbatory', 'plausive', 'affirmative']
senticnet['favourable_position'] = [0.729, -0.799, 0, 0.929, '#surprising', '#admirable', 0.819, 'advantage', 'vantage', 'upper_hand', 'whip_hand', 'edge']
senticnet['favourableness'] = [0.854, -0.794, 0, 0.977, '#joyful', '#admirable', 0.875, 'profitableness', 'favorableness', 'auspiciousness', 'advantageousness', 'positivity']
senticnet['favourite'] = [0.872, -0.912, 0, 0.745, '#joyful', '#surprising', 0.843, 'rival', 'competition', 'challenger', 'competitor', 'contender']
senticnet['fawn'] = [0, 0, -0.919, -0.903, '#scared', '#disgusting', -0.607, 'crawl', 'dun', 'toady', 'creep', 'grovel']
senticnet['fawner'] = [-0.558, 0, 0.588, -0.65, '#angry', '#disgusting', -0.599, 'apple_polisher', 'bootlicker', 'crawler', 'web', 'groveler']
senticnet['fax'] = [0.089, -0.017, 0, 0.117, '#joyful', '#admirable', 0.074, 'email', 'telephone_kiosk', 'phone', 'telegraph', 'handset']
senticnet['fay'] = [0.809, -0.695, 0, 0.95, '#joyful', '#admirable', 0.818, 'faery', 'faerie', 'fairy', 'gnome', 'sprite']
senticnet['faze'] = [0, 0, 0.85, -0.714, '#angry', '#disgusting', -0.521, 'untune', 'discompose', 'discomfit', 'disconcert', 'upset']
senticnet['fear'] = [0, 0, -0.6, 0, '#scared', '#scared', -0.2, 'phobia', 'scare', 'panic', 'humiliation', 'terror']
senticnet['fear_death'] = [0, 0, -0.963, 0, '#scared', '#scared', -0.321, 'battle_cancer', 'trade_stock', 'ease_pain', 'go_scuba_dive', 'lower_standard']
senticnet['fear_to_die'] = [-0.969, 0, 0.172, -0.997, '#sad', '#disgusting', -0.713, 'cold_winter', 'cold', 'hypothermia', 'possibility_to_die', 'severe_cold']
senticnet['fearful'] = [0, 0, -0.852, 0, '#scared', '#scared', -0.284, 'dreadful', 'scary', 'scare_off', 'daunt', 'frighten_off']
senticnet['fearfully'] = [-0.804, 0, 0, -0.815, '#sad', '#disgusting', -0.54, 'fearfulness', 'hysterically', 'hysterical', 'despairing', 'self-depreciation']
senticnet['fearfulness'] = [-0.797, 0, -0.7, 0, '#sad', '#scared', -0.499, 'fearfully', 'hysterically', 'hysterical', 'despairing', 'self-depreciation']
senticnet['fearless'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'intrepidly', 'hardy', 'fearlessness', 'fearlessly', 'unafraid']
senticnet['fearlessly'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'intrepidly', 'hardy', 'fearlessness', 'unafraid', 'unfearing']
senticnet['fearlessness'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'intrepidly', 'hardy', 'fearlessly', 'unafraid', 'unfearing']
senticnet['fearsome'] = [0.887, 0.734, 0, 0, '#joyful', '#interesting', 0.54, 'dire', 'dreaded', 'direful', 'frightening', 'horrendous']
senticnet['feast'] = [0.084, -0.054, 0, -0.044, '#joyful', '#surprising', 0.031, 'entree', 'mash_potato', 'satiation', 'breakfast', 'supper']
senticnet['feat'] = [0.912, 0, 0, 0.868, '#joyful', '#admirable', 0.593, 'high_class', 'citation', 'suspicion', 'goodness', 'prosperity']
senticnet['feather'] = [0.041, 0, 0, 0.058, '#joyful', '#admirable', 0.033, 'bird_animal', 'wings', 'farm_bird', 'barnyard_animal', 'hen_baby']
senticnet['feather_palm'] = [0.635, -0.847, 0, 0.85, '#surprising', '#admirable', 0.777, 'oil_palm', 'babassu', 'babassu_palm', 'coco_de_macao', 'wax_palm']
senticnet['featherbrained'] = [-0.799, 0, 0.904, -0.652, '#sad', '#angry', -0.785, 'dizzy', 'giddy', 'idle', 'airheaded', 'frivolous']
senticnet['featherless'] = [0, 0.081, 0.03, 0.126, '#interesting', '#admirable', 0.059, 'bird', 'old', 'predator', 'bald_eagle', 'prey']
senticnet['feature'] = [0, 0.093, 0, 0.113, '#interesting', '#admirable', 0.069, 'top_face', 'facial_part', 'near_nose', 'face_feature', 'face_part']
senticnet['fecal_matter'] = [-0.699, 0, 0.936, -0.875, '#angry', '#disgusting', -0.837, 'stool', 'dejection', 'shite', 'shit', 'feces']
senticnet['fecal_occult_test'] = [-0.699, 0, 0.936, -0.875, '#angry', '#disgusting', -0.837, 'assay', 'biopsy', 'cloze_procedure', 'cloze_test', 'diagnostic_assay']
senticnet['fece'] = [-0.154, -0.087, 0, -0.238, '#sad', '#disgusting', -0.102, 'mad_cow_disease', 'bad_drug', 'diarrhoea', 'hiccup', 'toothache']
senticnet['feces'] = [0, -0.01, 0.041, -0.065, '#angry', '#disgusting', -0.032, 'bad_luck', 'nature', 'slate', 'bird_droppings', 'unhealthy']
senticnet['feculence'] = [0.764, -0.619, 0, 0.878, '#joyful', '#admirable', 0.754, 'dirtiness', 'befoulment', 'defilement', 'dinginess', 'dinge']
senticnet['fecund'] = [0.702, -0.95, 0, 0.997, '#surprising', '#admirable', 0.883, 'fertilizable', 'fertile', 'conceptive', 'impregnable', 'rank']
senticnet['fecundity'] = [0.703, -0.593, 0, 0.739, '#joyful', '#admirable', 0.678, 'fruitfulness', 'genius', 'creative_thinking', 'ability', 'wizardry']
senticnet['fed_up'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'sick_of', 'disgustful']
senticnet['federal'] = [-0.075, 0.288, -0.049, 0.153, '#interesting', '#admirable', 0.106, 'percentage', 'money_payment', 'expense', 'payment_amount', 'money_relate']
senticnet['federal_agency'] = [0.685, -0.849, 0, 0.903, '#surprising', '#admirable', 0.812, 'agency', 'bureau_of_diplomatic_security', 'government_agency', 'bureau', 'office']
senticnet['fee'] = [-0.753, 0, -0.797, 0, '#sad', '#scared', -0.517, 'payment', 'owe', 'tax', 'debit', 'expense']
senticnet['fee_animal'] = [-0.105, 0, 0, -0.048, '#sad', '#disgusting', -0.051, 'stop_bleed', 'check_oneself_mirror', 'look_out_window', 'page_through_book', 'scratch_itch']
senticnet['fee_cat'] = [-0.116, 0, -0.059, 0, '#sad', '#scared', -0.058, 'visit_grandmother', 'forward_email', 'stand_alone', 'explain_everything', 'speak_english']
senticnet['fee_child'] = [-0.076, 0, 0, -0.102, '#sad', '#disgusting', -0.059, 'read_menu', 'use_restroom', 'place_order', 'order_dinner', 'look_menu']
senticnet['fee_oneself'] = [0.034, 0, -0.053, -0.097, '#scared', '#disgusting', -0.039, 'use_solar_oven', 'hungry', 'need_grocery', 'hunger', 'fee']
senticnet['feeble'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'bad_quality', 'cheap', 'fragile', 'short', 'last_little']
senticnet['feeblemindedness'] = [-0.505, 0, 0.912, -0.65, '#angry', '#disgusting', -0.689, 'mental_defectiveness', 'slowness', 'mental_retardation', 'backwardness', 'subnormality']
senticnet['feed'] = [0.147, 0.167, -0.123, 0.183, '#interesting', '#admirable', 0.125, 'nourishment', 'ingest_food', 'sustenance', 'enjoy_eat', 'satisfy_appetite']
senticnet['feed_animal'] = [0.147, 0.167, -0.123, 0.183, '#interesting', '#admirable', 0.125, 'give_food', 'feed', 'animal', 'domesticate_animal', 'give_attention']
senticnet['feed_baby'] = [0, -0.072, 0, 0, '#surprising', '#surprising', 0.024, 'feed', 'spoon_feed', 'bake_bread', 'make_ice', 'bake_cookie']
senticnet['feed_child'] = [0.745, 0, 0, 0.809, '#joyful', '#admirable', 0.518, 'eat_meal', 'eat_chip', 'eat_much_food', 'nostalgia', 'eat_much']
senticnet['feed_in'] = [-0.69, 0, 0.883, -0.912, '#angry', '#disgusting', -0.828, 'stick_in', 'enclose', 'insert', 'inclose', 'put_in']
senticnet['feed_oneself'] = [0.843, 0, 0, 0.747, '#joyful', '#admirable', 0.53, 'sustenance', 'eat', 'nourishment', 'transport_food', 'satisfy_hunger']
senticnet['feed_person'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'eat_steak', 'eat_food', 'eat_meal', 'feed_child', 'eat_pizzaf']
senticnet['feedback'] = [-0.058, 0.138, -0.065, 0.259, '#interesting', '#admirable', 0.091, 'retort', 'write_back', 'answer_back', 'question_answer', 'elaborate']
senticnet['feeding'] = [-0.802, 0, 0.724, -0.706, '#sad', '#angry', -0.744, 'nursing', 'schedule_infant_feeding', 'demand_infant_feeding', 'breast_infant_feeding', 'infant_feeding']
senticnet['feel'] = [0.657, -0.88, 0, 0.631, '#joyful', '#surprising', 0.723, 'cognisance', 'knowingness', 'awareness', 'cognizance', 'consciousness']
senticnet['feel_a_lot_of_remorse'] = [-0.773, 0, 0, -0.734, '#sad', '#disgusting', -0.502, 'feel_guilt', 'feel_anger', 'stab_knife', 'seek_revenge', 'imprison']
senticnet['feel_accomplishment'] = [0.733, 0.927, 0, 0, '#joyful', '#interesting', 0.553, 'face_paint', 'self_satisfaction', 'make_paint', 'frame_picture', 'learn_paint']
senticnet['feel_action'] = [0.978, 0, 0, 0.898, '#joyful', '#admirable', 0.625, 'sensual', 'hand_action', 'hand_movement', 'make_contact', 'hand_motion']
senticnet['feel_afraid'] = [-0.192, -0.146, -0.201, -0.044, '#sad', '#scared', -0.097, 'feel_ashamed', 'cry_help', 'feel_stupid', 'feel_hurt', 'break_leg']
senticnet['feel_alone'] = [-0.364, -0.213, -0.16, -0.349, '#sad', '#disgusting', -0.22, 'hospitalize', 'disability', 'toothache', 'influenza', 'gonorrhea']
senticnet['feel_alright'] = [0.685, -0.849, 0, 0.903, '#surprising', '#admirable', 0.812, 'feel_ok', 'steady', 'harmony', 'peaceful', 'feel_fine']
senticnet['feel_amazed'] = [0.709, 0.977, 0, 0.795, '#interesting', '#admirable', 0.827, 'feel_happy', 'astonished', 'good_feeling', 'happiness', 'mind_blowing']
senticnet['feel_anger'] = [-0.296, -0.035, -0.237, -0.225, '#sad', '#scared', -0.241, 'arrest_police', 'feel_remorse', 'end_life', 'seek_revenge', 'call_help']
senticnet['feel_angry'] = [0, 0, 0.798, 0, '#angry', '#angry', -0.266, 'form_opinion', 'blank_stare', 'get_angry', 'feel_sad', 'tell_lie']
senticnet['feel_ashamed'] = [-0.294, -0.009, -0.109, -0.18, '#sad', '#disgusting', -0.191, 'feel_stupid', 'die_young', 'go_insane', 'cry_help', 'go_scuba_dive']
senticnet['feel_awake'] = [0, 0, -0.983, -0.901, '#scared', '#disgusting', -0.628, 'rest_up', 'need_break', 'need_to_rest', 'catch_breath', 'go_bed_early']
senticnet['feel_awe'] = [0.707, -0.915, 0, 0, '#joyful', '#surprising', 0.541, 'feel_amazed', 'astonished', 'wonder', 'perplex', 'marvel']
senticnet['feel_bad'] = [-0.559, 0, -0.441, -0.15, '#sad', '#scared', -0.383, 'feel_remorse', 'imprison', 'go_to_prison', 'jail_time', 'imprisonment']
senticnet['feel_better'] = [0.908, 0.846, 0, 0.914, '#joyful', '#admirable', 0.889, 'lower_blood_pressure', 'feel_better_oneself', 'feel_good', 'feel_good_oneself', 'increase_energy']
senticnet['feel_better_oneself'] = [0.986, 0, 0, 0.801, '#joyful', '#admirable', 0.596, 'feel_good_oneself', 'improve_self-image', 'look_attractive', 'think_clearly', 'feel_better']
senticnet['feel_blue'] = [-0.849, 0.205, -0.484, -0.035, '#sad', '#scared', -0.388, 'depressed', 'sadness', 'blues', 'megrim', 'demoralization']
senticnet['feel_bored'] = [0, 0, 0, -0.801, '#disgusting', '#disgusting', -0.267, 'act_bored', 'think_dog', 'check_time', 'get_bored', 'start_computer']
senticnet['feel_clean'] = [0.059, -0.018, 0, 0, '#joyful', '#surprising', 0.026, 'smell_clean', 'smell_nice', 'feel_fresh', 'ensure_proper_hygiene', 'remove_dirt_body']
senticnet['feel_cold'] = [-0.971, 0, 0.853, -0.96, '#sad', '#disgusting', -0.928, 'get_wet', 'bad_feeling', 'cold_winter', 'hypothermia', 'cold']
senticnet['feel_comfort'] = [0.483, 0.171, -0.077, 0.275, '#joyful', '#admirable', 0.284, 'good_friend', 'companionship', 'happiness', 'amiable', 'strong_relationship']
senticnet['feel_comfortable'] = [0.723, 0, 0, 0.762, '#joyful', '#admirable', 0.495, 'wet_oneself', 'sense_peace', 'good_feeling', 'feel_relief', 'feel_good']
senticnet['feel_confident'] = [0.688, 0.825, 0, 0.623, '#joyful', '#interesting', 0.712, 'crazy', 'play_dead', 'feel_ashamed', 'better_person', 'need_help']
senticnet['feel_content'] = [0.707, 0.839, 0, 0, '#joyful', '#interesting', 0.515, 'replenish_energy', 'satisfy_sweet_tooth', 'entertain_friend', 'sociable', 'get_energy']
senticnet['feel_deeply_hurt'] = [-0.915, 0, 0.866, -0.923, '#sad', '#disgusting', -0.901, 'feel_bad', 'become_angry', 'feel_sad', 'hurt_feeling', 'emotional_pain']
senticnet['feel_dejected'] = [-0.849, 0.205, -0.484, -0.035, '#sad', '#scared', -0.388, 'depressed', 'sadness', 'bothering', 'feeling_low', 'blue_monday']
senticnet['feel_depressed'] = [-0.226, 0, -0.187, -0.095, '#sad', '#scared', -0.169, 'great_relief', 'clean_up_mess', 'sadness', 'rainy_day', 'erection']
senticnet['feel_different'] = [0.909, 0.716, 0, 0, '#joyful', '#interesting', 0.542, 'pleasure', 'laugh', 'spread_happiness', 'enjoy_oneself', 'change']
senticnet['feel_dirty'] = [0, 0, 0.943, -0.8, '#angry', '#disgusting', -0.581, 'dusty', 'unclean', 'dirty', 'yucky', 'filthy']
senticnet['feel_dizzy'] = [-0.852, 0, -0.788, 0, '#sad', '#scared', -0.547, 'faint', 'headache', 'feel_sick', 'low_blood_pressure', 'giddy']
senticnet['feel_down'] = [-0.708, 0.304, -0.361, -0.108, '#sad', '#scared', -0.291, 'despondently', 'disheartened', 'despairingly', 'demoralized', 'forlorn']
senticnet['feel_embarrassed'] = [-0.906, 0, 0.3, -0.952, '#sad', '#disgusting', -0.719, 'get_drunk', 'helpless', 'make_fool_of_yourself', 'shameful', 'disreputable']
senticnet['feel_emotion'] = [0.884, 0.942, 0, 0.743, '#joyful', '#interesting', 0.856, 'experience_pleasure', 'dance_music', 'watch_sunset', 'win_contest', 'listen_rock_music']
senticnet['feel_energetic'] = [0.884, 0, 0, 0, '#joyful', '#joyful', 0.295, 'feel_good', 'active', 'up_and_coming', 'full_of_energy', 'power']
senticnet['feel_energized'] = [0.772, 0.909, 0, 0, '#joyful', '#interesting', 0.56, 'increase_energy', 'keep_body_healthy', 'improve_self-image', 'lower_blood_pressure', 'build_muscle']
senticnet['feel_euphoria'] = [0.749, 0.732, 0, 0, '#joyful', '#interesting', 0.494, 'change_mood', 'hear_song', 'sing_along', 'enjoy_music', 'earring']
senticnet['feel_excited'] = [0.774, 0.803, 0, 0, '#joyful', '#interesting', 0.526, 'enjoy_music', 'listen_pleasure', 'hear_loss', 'set_mood', 'laugh_lot']
senticnet['feel_exhausted'] = [-0.115, -0.049, 0.01, -0.149, '#sad', '#disgusting', -0.075, 'exhaustion', 'fatigue', 'become_tired', 'get_tired', 'leg_cramp']
senticnet['feel_faint'] = [0, 0.074, 0, 0, '#interesting', '#interesting', 0.025, 'exercise_much', 'exercise_regularly', 'faint', 'eat_healthy_diet', 'feel_great']
senticnet['feel_fine'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'feel_alright', 'steady', 'harmony', 'peaceful', 'feel_ok']
senticnet['feel_fit'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'increase_metabolism', 'big_muscle', 'become_healthy', 'attract_dog', 'weight_loss']
senticnet['feel_for'] = [0.999, 0.941, 0, 0, '#joyful', '#interesting', 0.647, 'sympathize_with', 'compassionateness', 'condole_with', 'sympathize', 'commiserate']
senticnet['feel_fresh'] = [0.884, 0, 0, 0, '#joyful', '#joyful', 0.295, 'smell_nice', 'fresh_air', 'feel_amazed', 'good_feeling', 'awesome']
senticnet['feel_fresher'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'feel_rejuvenated', 'become_younger', 'feel_more_lively', 'recover', 'feel_regenerate']
senticnet['feel_full'] = [0.757, 0, 0, 0, '#joyful', '#joyful', 0.252, 'delicious_food', 'hunger_go_away', 'feel_satisfied', 'full_stomach', 'finish-meal']
senticnet['feel_glad'] = [0.709, 0.977, 0, 0.795, '#interesting', '#admirable', 0.827, 'happy', 'bring_happiness', 'happiness', 'good_feeling', 'delight']
senticnet['feel_good'] = [0.719, 0.757, 0, 0, '#joyful', '#interesting', 0.492, 'good_feeling', 'enjoy_oneself', 'feel_good_oneself', 'make_feel_better', 'self_satisfaction']
senticnet['feel_good_oneself'] = [0.928, 0, 0, 0.98, '#joyful', '#admirable', 0.636, 'feel_better_oneself', 'feel_good', 'feel_better', 'increase_energy', 'look_attractive']
senticnet['feel_grateful'] = [-0.041, 0, -0.063, -0.042, '#scared', '#disgusting', -0.049, 'butter_toast', 'taste_food', 'eat_animal', 'die_only_once', 'live_apartment']
senticnet['feel_great'] = [0.258, 0.357, -0.088, 0.351, '#interesting', '#admirable', 0.293, 'plenty', 'happy', 'serenity', 'sufficient', 'feel_satisfied']
senticnet['feel_guilt'] = [-0.585, 0, -0.391, -0.182, '#sad', '#scared', -0.386, 'anguish', 'feel_bad', 'bad_feeling', 'death_love', 'get_fired']
senticnet['feel_guilty'] = [-0.75, 0, 0, -0.862, '#sad', '#disgusting', -0.537, 'feel_bad', 'feeling_guilt', 'go_jail', 'anguish', 'go_to_prison']
senticnet['feel_happy'] = [0.965, 0.781, 0, 0, '#joyful', '#interesting', 0.582, 'receive_thank', 'good_feeling', 'feel_good', 'increase_self-esteem', 'express_love']
senticnet['feel_healthy'] = [0.097, 0.099, -0.098, 0.137, '#interesting', '#admirable', 0.078, 'live_long', 'long_life', 'live_healthy_lifestyle', 'increase_muscle_mass', 'longevity']
senticnet['feel_heat'] = [0, 0, 0, -0.8, '#disgusting', '#disgusting', -0.267, 'close_together', 'smoke_joint', 'fly_around', 'shovel_snow', 'amount_nothing']
senticnet['feel_hunger'] = [-0.792, 0, -0.924, -0.708, '#sad', '#scared', -0.808, 'feel_weak', 'famine', 'need_snacks', 'order_food', 'pain_in_stomach']
senticnet['feel_hungry'] = [-0.771, 0, 0.848, -0.806, '#angry', '#disgusting', -0.808, 'replenish_energy', 'satisfy_hunger', 'sustenance', 'increase_hunger', 'stop_hunger']
senticnet['feel_hurt'] = [-0.228, 0.083, -0.14, -0.269, '#sad', '#disgusting', -0.185, 'hurt_feeling', 'dislike', 'arrogance', 'gonorrhea', 'angry_emotion']
senticnet['feel_ill'] = [-0.166, -0.054, -0.069, -0.221, '#sad', '#disgusting', -0.134, 'ill', 'feel_sick', 'concern_health', 'sick', 'health_problem']
senticnet['feel_important'] = [0.908, 0.867, 0, 0.711, '#joyful', '#interesting', 0.829, 'good_sense_of_humor', 'feel_safe', 'complement', 'others_understand', 'knowledgeable']
senticnet['feel_inferior'] = [-0.918, 0, 0.653, -0.957, '#sad', '#disgusting', -0.843, 'feel_down', 'lack_of_confident', 'depress', 'unhappy', 'weak']
senticnet['feel_joy'] = [0.845, 0, 0, 0, '#joyful', '#joyful', 0.282, 'feel_happy', 'happiness', 'good_feeling', 'foreplay', 'feel_good']
senticnet['feel_like_new'] = [0, 0.076, -0.059, 0.082, '#interesting', '#admirable', 0.033, 'smell_better', 'remove_stain', 'clothes_clean', 'smell_nice', 'remove_dirt']
senticnet['feel_little_hungry'] = [-0.701, 0, 0, -0.715, '#sad', '#disgusting', -0.472, 'get_full', 'a_little_hungry', 'become_little_hungry', 'hunger_go_away', 'need_food']
senticnet['feel_little_tired'] = [-0.077, 0, -0.171, -0.059, '#sad', '#scared', -0.102, 'fall_asleep', 'doze_off', 'drowsiness', 'lack_of_sleep', 'need_rest']
senticnet['feel_lonely'] = [-0.882, 0, 0, -0.859, '#sad', '#disgusting', -0.58, 'make_new_friend', 'enjoy_company', 'get_know_better', 'terrible_misunderstand', 'share_time']
senticnet['feel_lousy'] = [-0.699, 0, 0.936, -0.875, '#angry', '#disgusting', -0.837, 'feel_faint', 'lack_of_water', 'much_exercise', 'weak', 'cause_dehydration']
senticnet['feel_love'] = [0.88, 0, 0, 0.972, '#joyful', '#admirable', 0.617, 'love_another_person', 'care_deeply', 'warm_feeling', 'lust', 'show_empathy']
senticnet['feel_low'] = [-0.849, 0.205, -0.484, -0.035, '#sad', '#scared', -0.388, 'depressed', 'sadness', 'bothering', 'blue_monday', 'feel_dejected']
senticnet['feel_more_lively'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'feel_rejuvenated', 'feel_fresher', 'become_younger', 'recover', 'feel_regenerate']
senticnet['feel_nervous'] = [-0.151, 0.109, -0.151, -0.059, '#sad', '#scared', -0.084, 'stress', 'finish_task', 'invigorate', 'buy_stock', 'a_lot_of_stress']
senticnet['feel_obligated'] = [-0.703, 0, -0.899, 0, '#sad', '#scared', -0.534, 'make_happy', 'get_present', 'make_oneself_feel_better', 'show_care', 'good_child']
senticnet['feel_ok'] = [0.258, 0.357, -0.088, 0.351, '#interesting', '#admirable', 0.293, 'feel_alright', 'steady', 'harmony', 'peaceful', 'feel_fine']
senticnet['feel_out_breath'] = [0, 0, 0.933, -0.863, '#angry', '#disgusting', -0.599, 'breath_difficulty', 'muscle_cramp', 'throat_injury', 'run_too_fast', 'epileptic_seizures']
senticnet['feel_out_of_breath'] = [-0.699, 0, 0.936, -0.875, '#angry', '#disgusting', -0.837, 'breath_difficulty', 'muscle_cramp', 'throat_injury', 'run_too_fast', 'epileptic_seizures']
senticnet['feel_pain'] = [-0.962, 0, 0.893, -0.73, '#sad', '#angry', -0.862, 'poor_health', 'cause_someone_to_die', 'experience_pain', 'severe_pain', 'take_aspirin']
senticnet['feel_pleasure'] = [0.798, 0.797, 0, 0.834, '#joyful', '#admirable', 0.81, 'have_fun', 'gain_respect', 'happiness', 'good_feeling', 'appreciate']
senticnet['feel_presence'] = [0.723, 0, 0, 0.762, '#joyful', '#admirable', 0.495, 'presence', 'feel_important', 'existence', 'feel_satisfied', 'attendance']
senticnet['feel_proud'] = [0.824, 0.793, 0, 0.868, '#joyful', '#admirable', 0.828, 'pride', 'increase_intelligence', 'happiness', 'gratification', 'get_good_job']
senticnet['feel_refreshed'] = [0, 0.877, 0, 0, '#interesting', '#interesting', 0.292, 'enough_rest', 'reinvigorated', 'cure', 'after_shower', 'take_nap']
senticnet['feel_regenerate'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'feel_rejuvenated', 'feel_fresher', 'feel_more_lively', 'recover', 'become_younger']
senticnet['feel_rejuvenated'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'become_younger', 'feel_fresher', 'feel_more_lively', 'recover', 'feel_regenerate']
senticnet['feel_relaxed'] = [0.997, 0.805, 0, 0.803, '#joyful', '#interesting', 0.868, 'relax', 'rejuvenate', 'relax_muscle', 'become_relaxed', 'relieve_tension']
senticnet['feel_released'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'relaxation', 'feel_relieved', 'feel_relief', 'pressure_go_away', 'more_easy_life']
senticnet['feel_relief'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'relaxation', 'feel_relieved', 'feel_released', 'pressure_go_away', 'more_easy_life']
senticnet['feel_relieved'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'ease_pain', 'feel_relief', 'trade_stock', 'need_companionship', 'desire_live']
senticnet['feel_remorse'] = [-0.92, 0, 0.554, -0.961, '#sad', '#disgusting', -0.812, 'revenge', 'remorse', 'bad_feeling', 'kill_someone', 'kill']
senticnet['feel_restless'] = [0, 0, 0.933, -0.863, '#angry', '#disgusting', -0.599, 'tired', 'energy_exhaustion', 'need_rest', 'exhausted', 'lack_of_rest']
senticnet['feel_sad'] = [-0.785, 0, 0, 0, '#sad', '#sad', -0.262, 'feel_hurt', 'emotional_pain', 'become_angry', 'embarrassment', 'feel_bad']
senticnet['feel_sad_about'] = [-0.152, 0.067, -0.144, -0.048, '#sad', '#scared', -0.092, 'collide', 'sit_floor', 'fly_around', 'amount_nothing', 'feel_heat']
senticnet['feel_safe'] = [0.36, 0.248, -0.082, 0.278, '#joyful', '#admirable', 0.268, 'feel_important', 'strong_relationship', 'eat_together', 'world_peace', 'express_gratitude']
senticnet['feel_satisfaction'] = [0.336, 0.183, -0.176, 0.077, '#joyful', '#interesting', 0.14, 'make_feel_better', 'satisfaction', 'feel_satisfied', 'tooth_hurt', 'happiness']
senticnet['feel_satisfied'] = [0.879, 0.979, 0, 0.992, '#interesting', '#admirable', 0.95, 'get_fat', 'feel_full', 'become_fat', 'eat_better', 'obesity']
senticnet['feel_scared'] = [0, 0, -0.907, 0, '#scared', '#scared', -0.302, 'mock', 'caution', 'phobia', 'severe_pain', 'unusual']
senticnet['feel_sense_accomplishment'] = [0.932, 0, 0, 0.832, '#joyful', '#admirable', 0.588, 'joy', 'get_excited', 'illogical', 'solve', 'mind_boggle']
senticnet['feel_sick'] = [-0.988, 0, -0.9, -0.906, '#sad', '#disgusting', -0.931, 'health_problem', 'concern_health', 'take_aspirin', 'sick', 'poor_health']
senticnet['feel_sleepy'] = [-0.077, 0, -0.171, -0.059, '#sad', '#scared', -0.102, 'night_shift', 'drowsiness', 'drink_coffee', 'need_rest', 'feel_little_tired']
senticnet['feel_small'] = [0, 0.107, 0.22, -0.196, '#angry', '#disgusting', -0.103, 'deceitful', 'crazy', 'tension', 'ponder', 'make_decision']
senticnet['feel_smart'] = [0.716, 0.928, 0, 0, '#joyful', '#interesting', 0.548, 'new_idea', 'forget_else', 'improve_performance', 'recognize_pattern', 'come_conclusion']
senticnet['feel_smug'] = [-0.545, 0.168, -0.608, 0.125, '#sad', '#scared', -0.287, 'feeling_guilt', 'feel_guilty', 'feel_sorry', 'stay_out_jail', 'injustice']
senticnet['feel_sorry'] = [-0.718, 0.086, -0.612, 0.086, '#sad', '#scared', -0.386, 'negative_feeling', 'deep_sadness', 'lament', 'bad_feeling', 'sadness']
senticnet['feel_strange'] = [-0.077, -0.035, -0.093, -0.056, '#sad', '#scared', -0.064, 'say_hello', 'shake_hand', 'whistle', 'look_eye', 'hump_leg']
senticnet['feel_stressed'] = [0, 0, 0, -0.948, '#disgusting', '#disgusting', -0.316, 'screw_up', 'bad_feeling', 'reprimand', 'stress', 'anguish']
senticnet['feel_strong'] = [0.698, -0.547, 0, 0.995, '#joyful', '#admirable', 0.747, 'increased_heart_rate', 'get_strong', 'live_long', 'feel_healthy', 'better_cardiovascular_health']
senticnet['feel_strongly'] = [0.888, 0, 0, 0.74, '#joyful', '#admirable', 0.543, 'end_argument', 'make_commitment', 'mutual_understand', 'kindness', 'courteous']
senticnet['feel_stupid'] = [-0.297, -0.032, -0.08, -0.222, '#sad', '#disgusting', -0.189, 'cry_help', 'go_insane', 'die_young', 'punch_face', 'feel_ashamed']
senticnet['feel_stylish'] = [0.034, 0, 0, 0.085, '#joyful', '#admirable', 0.04, 'new_style', 'hair_long', 'new_hair_style', 'haircut', 'change_hair_style']
senticnet['feel_terrible'] = [-0.966, 0, 0.414, -0.94, '#sad', '#disgusting', -0.773, 'bad_feeling', 'exam_failed', 'job_interview_failed', 'trouble', 'problem']
senticnet['feel_tired'] = [0, 0, 0, -0.89, '#disgusting', '#disgusting', -0.297, 'exhaustion', 'get_tired', 'tiredness', 'fatigue', 'breaheavily']
senticnet['feel_upset'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'sad', 'emotional', 'angry', 'agitated', 'worry']
senticnet['feel_very_cold'] = [0, 0, -0.894, -0.826, '#scared', '#disgusting', -0.573, 'hit_car', 'fall_ice', 'drip', 'slip_fall', 'get_cold']
senticnet['feel_warm'] = [0.337, 0, 0, 0.093, '#joyful', '#admirable', 0.143, 'feel_comfortable', 'put_coat', 'spread_germ', 'wear_sweater', 'light_cigar']
senticnet['feel_weak'] = [-0.792, 0, -0.924, -0.708, '#sad', '#scared', -0.808, 'feel_hunger', 'famine', 'need_snacks', 'order_food', 'pain_in_stomach']
senticnet['feel_well'] = [0.924, 0.941, 0, 0.895, '#joyful', '#interesting', 0.92, 'improve_self-image', 'own_benefit', 'prolong_life', 'feel_good_oneself', 'think_clearly']
senticnet['feeling'] = [0.865, 0.787, 0, 0, '#joyful', '#interesting', 0.551, 'hormone', '32_teeth', 'gone_moon', 'competitive_nature', 'two_ears']
senticnet['feeling_guilt'] = [-0.585, 0, -0.391, -0.182, '#sad', '#scared', -0.386, 'anguish', 'feel_bad', 'bad_feeling', 'death_love', 'get_fired']
senticnet['feeling_low'] = [-0.849, 0.205, -0.484, -0.035, '#sad', '#scared', -0.388, 'depressed', 'sadness', 'bothering', 'blue_monday', 'feel_dejected']
senticnet['feign'] = [-0.742, 0, 0.8, -0.872, '#angry', '#disgusting', -0.805, 'talk_through_one_hat', 'bullshit', 'take_dive', 'fake', 'misrepresent']
senticnet['feigned'] = [-0.527, 0, 0.651, -0.542, '#angry', '#disgusting', -0.573, 'insincere', 'dissimulative', 'specious', 'hypocritical', 'fulsome']
senticnet['feigning'] = [-0.7, 0, 0.663, -0.676, '#sad', '#disgusting', -0.68, 'deceit', 'deception', 'misrepresentation', 'pretext', 'bluff']
senticnet['feint'] = [-0.825, 0, 0.739, -0.509, '#sad', '#angry', -0.691, 'fake', 'juke', 'maneuver', 'manoeuvre', 'tactical_maneuver']
senticnet['feist'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'dog', 'cur', 'fice', 'pariah_dog', 'domestic_dog']
senticnet['feisty'] = [0, 0, -0.887, -0.891, '#scared', '#disgusting', -0.593, 'touchy', 'spunky', 'plucky', 'thin-skinned', 'huffy']
senticnet['felicitous'] = [0.943, -0.582, 0, 0.694, '#joyful', '#admirable', 0.74, 'better_off', 'happy', 'lucky', 'well', 'fortunate']
senticnet['feline'] = [0, 0, 0.022, -0.08, '#angry', '#disgusting', -0.034, 'kind_animal', 'wild_animal', 'predator', 'hound', 'fang']
senticnet['fell'] = [-0.795, 0, 0.691, -0.886, '#sad', '#disgusting', -0.791, 'cold', 'pitiless', 'cruel', 'inhumane', 'vicious']
senticnet['fellow_feeling'] = [0.557, 0.715, -0.532, 0.51, '#joyful', '#interesting', 0.417, 'kind', 'kindheartedness', 'empathy', 'kindhearted', 'compatibly']
senticnet['felon'] = [-0.796, 0, 0.997, -0.768, '#sad', '#angry', -0.854, 'toughie', 'accessory', 'highbinder', 'hoodlum', 'thug']
senticnet['felony'] = [-0.846, 0, 0.745, -0.776, '#sad', '#disgusting', -0.789, 'crime', 'against_law', 'revenge', 'vengeance', 'theft']
senticnet['female'] = [0.863, 0, 0, 0.753, '#joyful', '#admirable', 0.539, 'damsel_human', 'damsel_person', 'niece', 'damsel', 'woman']
senticnet['female_child'] = [-0.983, 0, -0.724, 0, '#sad', '#scared', -0.569, 'descendant', 'father_mother', 'parent_child', 'human_offspring', 'family_relation']
senticnet['female_cloth'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'woman_garment', 'skirt', 'woman_dress', 'frilly_design', 'robe']
senticnet['female_human'] = [0.754, 0, 0, 0.813, '#joyful', '#admirable', 0.522, 'female_person', 'woman_child', 'female', 'female_relative', 'hold_child']
senticnet['female_parent'] = [0.71, 0, 0, 0.745, '#joyful', '#admirable', 0.485, 'woman_child', 'female_relative', 'kin', 'familial_relationship', 'family_member']
senticnet['female_perfume'] = [0.066, 0.083, -0.064, 0.09, '#interesting', '#admirable', 0.058, 'aroma', 'perfume', 'fragrance', 'bad_odor', 'saliva']
senticnet['female_person'] = [0.995, 0, 0, 0.991, '#joyful', '#admirable', 0.662, 'female_human', 'female', 'woman_child', 'hold_child', 'female_relative']
senticnet['female_relative'] = [0.807, 0, 0, 0.95, '#joyful', '#admirable', 0.586, 'female_sibling', 'woman_child', 'parent', 'sibling', 'kin']
senticnet['female_sibling'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'family_member', 'relative', 'family_relation', 'sister', 'same_parent']
senticnet['female_slave'] = [-0.917, 0, 0.451, -0.987, '#sad', '#disgusting', -0.785, 'slave', 'psychological_aggression', 'physical_aggression', 'aggression', 'verbal_aggression']
senticnet['female_television_connector'] = [0, -0.028, 0, 0.052, '#surprising', '#admirable', 0.027, 'power_switch', 'channel_selector', 'speaker', 'tuner', 'handset']
senticnet['feminine'] = [0.84, 0, 0, 0.932, '#joyful', '#admirable', 0.591, 'sophisticated', 'lovely', 'elegant', 'contrary', 'common_man']
senticnet['femur'] = [0.023, 0.085, -0.045, 0.088, '#interesting', '#admirable', 0.05, 'thigh', 'above_leg', 'joint', 'hip', 'knee']
senticnet['fence_yard'] = [-0.902, 0, -0.917, 0, '#sad', '#scared', -0.606, 'seed_lawn', 'mine_gold', 'hurry_work', 'air_grievance', 'sail_around_world']
senticnet['fencer'] = [0.833, -0.974, 0, 0.91, '#surprising', '#admirable', 0.906, 'combatant', 'battler', 'belligerent', 'fighter', 'scrapper']
senticnet['fend'] = [-0.795, 0, 0.974, -0.839, '#angry', '#disgusting', -0.869, 'manage', 'make_out', 'cope', 'get_by', 'make_do']
senticnet['feral'] = [-0.632, 0, 0.991, -0.734, '#angry', '#disgusting', -0.786, 'undomesticated', 'untamed', 'ferine', 'savage', 'unbroken']
senticnet['ferine'] = [-0.632, 0, 0.991, -0.734, '#angry', '#disgusting', -0.786, 'undomesticated', 'feral', 'untamed', 'savage', 'unbroken']
senticnet['ferment'] = [0.041, 0, 0, 0.058, '#joyful', '#admirable', 0.033, 'liquid_beverage', 'fill_glass', 'cool_drink', 'orange_drink', 'cola']
senticnet['ferment_beverage'] = [0.948, 0.992, 0, 0.974, '#interesting', '#admirable', 0.971, 'liquid_drink', 'yogurt', 'fermented_juice', 'healthy_drink', 'alcoholic_drink']
senticnet['ferment_grape_juice'] = [0.948, 0.992, 0, 0.974, '#interesting', '#admirable', 0.971, 'fermented_beverage', 'yogurt', 'healthy_drink', 'fruit_drink', 'good_taste']
senticnet['fermentation'] = [0, 0.104, -0.093, 0.146, '#interesting', '#admirable', 0.052, 'thaw', 'slush', 'water_inside', 'give_water', 'obtain_water']
senticnet['fermentation_alcohol'] = [-0.624, 0, 0.708, -0.897, '#angry', '#disgusting', -0.743, 'absolute_alcohol', 'spirits_of_wine', 'denatured_alcohol', 'alcohol', 'plant_product']
senticnet['fermented_beverage'] = [0.948, 0.992, 0, 0.974, '#interesting', '#admirable', 0.971, 'ferment_grape_juice', 'yogurt', 'healthy_drink', 'fruit_drink', 'good_taste']
senticnet['fermented_juice'] = [0.948, 0.992, 0, 0.974, '#interesting', '#admirable', 0.971, 'liquid_drink', 'yogurt', 'ferment_beverage', 'healthy_drink', 'alcoholic_drink']
senticnet['ferocious'] = [0, 0, 0, 0.076, '#admirable', '#admirable', 0.025, 'fierce', 'woodland_creature', 'hairy_animal', 'huge_animal', 'brown_fur']
senticnet['ferociousness'] = [-0.874, 0, 0.53, -0.659, '#sad', '#disgusting', -0.688, 'malevolence', 'malevolency', 'malice', 'murderousness', 'cruelness']
senticnet['ferocity'] = [-0.63, 0, 0.921, -0.621, '#sad', '#angry', -0.724, 'fury', 'wildness', 'savagery', 'fierceness', 'furiousness']
senticnet['ferrari'] = [0.755, 0.702, 0, 0, '#joyful', '#interesting', 0.486, 'high_class', 'expensive_car', 'fancy_car', 'lamborghini', 'sports_car']
senticnet['ferret'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'apple_tree', 'rosebush', 'snake', 'fox', 'mormon']
senticnet['ferries'] = [0, 0, 0, 0.135, '#admirable', '#admirable', 0.045, 'kayak', 'boat_type', 'canoes', 'towboats', 'yachts']
senticnet['ferris_wheel'] = [0.086, -0.026, 0, 0, '#joyful', '#surprising', 0.037, 'roller-coaster', 'carnival_ride', 'carny', 'merry_go_round', 'fortune_teller']
senticnet['ferry'] = [-0.023, -0.012, 0.045, -0.051, '#angry', '#disgusting', -0.036, 'haddock', 'pier', 'dryad', 'dock', 'shallow']
senticnet['fertile'] = [0.702, -0.95, 0, 0.997, '#surprising', '#admirable', 0.883, 'fertilizable', 'fecund', 'conceptive', 'impregnable', 'rank']
senticnet['fertiliser'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'organic_matter', 'decompose', 'recycle', 'soil', 'compost_pile']
senticnet['fertility'] = [0.643, -0.803, 0, 0.681, '#surprising', '#admirable', 0.709, 'quality', 'richness', 'fruitfulness', 'prolificacy', 'productiveness']
senticnet['fertilizable'] = [0.702, -0.95, 0, 0.997, '#surprising', '#admirable', 0.883, 'fertile', 'fecund', 'conceptive', 'impregnable', 'rank']
senticnet['fervency'] = [0.505, -0.856, 0, 0.94, '#surprising', '#admirable', 0.767, 'infatuation', 'ardor', 'fervor', 'passion', 'fervidness']
senticnet['fervent'] = [0, 0, 0.959, -0.956, '#angry', '#disgusting', -0.638, 'impassioned', 'perfervid', 'fervid', 'ardent', 'fiery']
senticnet['fervid'] = [0, 0, 0.733, -0.929, '#angry', '#disgusting', -0.554, 'impassioned', 'fervent', 'fiery', 'ardent', 'torrid']
senticnet['fervidness'] = [0.505, -0.856, 0, 0.94, '#surprising', '#admirable', 0.767, 'infatuation', 'ardor', 'fervor', 'fervency', 'passion']
senticnet['fervor'] = [0.705, -0.933, 0, 0.89, '#surprising', '#admirable', 0.843, 'emotional_arousal', 'excitation', 'excitement', 'arousal', 'anger']
senticnet['festal'] = [0.918, 0.476, -0.197, 0.417, '#joyful', '#interesting', 0.538, 'merriment', 'cheery', 'gaiety', 'playfulness', 'pridefulness']
senticnet['festival'] = [0.838, 0.75, 0, 0.708, '#joyful', '#interesting', 0.765, 'big_event', 'party', 'banquet', 'marketplace', 'rock_concert']
senticnet['festive'] = [0.802, 0.996, 0, 0.882, '#interesting', '#admirable', 0.893, 'party_time', 'holiday', 'annual_celebration', 'happy_time', 'new_baby']
senticnet['festive_season'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'holiday', 'jingles', 'tree', 'big_christmas_tree', 'christmas']
senticnet['festivity'] = [0.147, -0.161, -0.088, 0, '#joyful', '#surprising', 0.073, 'occasion', 'cake_candle', 'celebration', 'special_moment', 'special_event']
senticnet['fetch'] = [0.054, 0.237, -0.152, 0.33, '#interesting', '#admirable', 0.156, 'retrieve', 'bring', 'tote', 'take', 'go_get']
senticnet['fetich'] = [0.667, -0.869, 0, 0.884, '#surprising', '#admirable', 0.807, 'fetish', 'juju', 'object', 'voodoo', 'good_luck_charm']
senticnet['fetid'] = [-0.868, 0, 0.644, -0.886, '#sad', '#disgusting', -0.799, 'frowsty', 'malodorous', 'foetid', 'smelly', 'stinking']
senticnet['fetidness'] = [-0.984, 0, 0.967, -0.606, '#sad', '#angry', -0.852, 'body_odor', 'aroma', 'scent', 'olfactory_property', 'smell']
senticnet['fetish'] = [0.667, -0.869, 0, 0.884, '#surprising', '#admirable', 0.807, 'good_luck_charm', 'juju', 'object', 'voodoo', 'fetich']
senticnet['fetishism'] = [-0.622, 0, 0.515, -0.638, '#sad', '#disgusting', -0.592, 'immodesty', 'perversion', 'exhibitionism', 'sexual_perversion', 'paraphilia']
senticnet['fetishist'] = [0.789, -0.733, 0, 0.857, '#joyful', '#admirable', 0.793, 'degenerate', 'lecher', 'lech', 'letch', 'satyr']
senticnet['fetor'] = [-0.512, 0, 0.986, -0.833, '#angry', '#disgusting', -0.777, 'niff', 'pong', 'smell', 'odor', 'olfactory_sensation']
senticnet['fetus'] = [0.581, -0.511, 0, 0.523, '#joyful', '#admirable', 0.538, 'teras', 'baby', 'monster', 'abortus', 'vertebrate']
senticnet['feud'] = [0.532, -0.8, 0, 0.826, '#surprising', '#admirable', 0.719, 'conflict', 'struggle', 'battle', 'vendetta', 'blood_feud']
senticnet['feudal_lord'] = [-0.808, 0, 0.826, -0.629, '#sad', '#angry', -0.754, 'liege', 'liege_lord', 'master', 'overlord', 'lord']
senticnet['feudal_lordship'] = [-0.739, 0, 0.812, -0.521, '#sad', '#angry', -0.691, 'liege', 'liege_lord', 'master', 'overlord', 'lord']
senticnet['feudalism'] = [0.038, 0.233, -0.112, 0.117, '#interesting', '#admirable', 0.092, 'socialism', 'democracy', 'empire', 'republic', 'citizen']
senticnet['fever'] = [-0.849, 0, -0.729, -0.883, '#sad', '#disgusting', -0.82, 'high_temperature', 'heat', 'disease', 'hot_temperature', 'feel_sick']
senticnet['fevered'] = [0, 0, 0, -0.761, '#disgusting', '#disgusting', -0.254, 'hectic', 'feverish', 'feverishly', 'buck_fever', 'expectantly']
senticnet['feverish'] = [-0.885, -0.788, -0.836, -0.718, '#sad', '#scared', -0.55, 'hectic', 'fevered', 'feverishly', 'buck_fever', 'expectantly']
senticnet['feverishly'] = [-0.812, 0, -0.857, 0, '#sad', '#scared', -0.556, 'hectic', 'fevered', 'feverish', 'buck_fever', 'expectantly']
senticnet['few'] = [-0.909, 0, 0.278, -0.999, '#sad', '#disgusting', -0.729, 'minus_sign', 'little', 'less', 'negative', 'minus']
senticnet['few_people'] = [0.082, -0.006, 0, 0, '#joyful', '#surprising', 0.029, 'empty_place', 'free_seat', 'farm', 'smooth_wood', 'serf']
senticnet['fewness'] = [-0.852, 0, 0.605, -0.739, '#sad', '#disgusting', -0.732, 'number', 'numerousness', 'numerosity', 'innumerableness', 'countlessness']
senticnet['fiance'] = [0.808, 0, 0, 0.802, '#joyful', '#admirable', 0.537, 'monkey', 'marmoset', 'lemur', 'beaver', 'koala']
senticnet['fiat'] = [0, 0.101, 0, 0.109, '#interesting', '#admirable', 0.07, 'machine_transportation', 'big_car', 'large_car', 'brand', 'long_car']
senticnet['fib'] = [-0.934, 0, 0.739, -0.969, '#sad', '#disgusting', -0.881, 'prevarication', 'fairytale', 'fairy_tale', 'fairy_story', 'song_and_dance']
senticnet['fiberboard'] = [0.514, -0.979, 0, 0.899, '#surprising', '#admirable', 0.797, 'board', 'beaver_board', 'dry_wall', 'furniture', 'particle_board']
senticnet['fiberglass'] = [0.977, 0.759, 0, 0, '#joyful', '#interesting', 0.579, 'soft_wood', 'wood', 'natural_gas', 'glass', 'franchise']
senticnet['fibrocartilage'] = [-0.536, 0, 0.982, -0.671, '#angry', '#disgusting', -0.73, 'meniscus', 'semilunar_cartilage', 'gristle', 'hyaline_cartilage', 'arytenoid']
senticnet['fibroid'] = [-0.882, 0, 0.774, -0.993, '#sad', '#disgusting', -0.883, 'fibroma_tumor', 'fibroma', 'benign_tumor', 'nonmalignant_tumor', 'nonmalignant_neoplasm']
senticnet['fibroid_tumor'] = [-0.882, 0, 0.774, -0.993, '#sad', '#disgusting', -0.883, 'fibroma', 'fibroid', 'benign_tumor', 'nonmalignant_tumor', 'nonmalignant_neoplasm']
senticnet['fibroma'] = [-0.882, 0, 0.774, -0.993, '#sad', '#disgusting', -0.883, 'fibroid_tumor', 'fibroid', 'benign_tumor', 'nonmalignant_tumor', 'nonmalignant_neoplasm']
senticnet['fice'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'dog', 'feist', 'cur', 'pariah_dog', 'domestic_dog']
senticnet['fickle'] = [-0.708, 0, 0.87, 0, '#sad', '#angry', -0.526, 'cute', 'hairy', 'fun_around', 'driven_person', 'changeable']
senticnet['fiction'] = [0.036, 0.219, 0, 0.19, '#interesting', '#admirable', 0.148, 'book_genre', 'literature', 'concoction', 'untruth', 'falsehood']
senticnet['fictional'] = [0, 0.951, 0, 0, '#interesting', '#interesting', 0.317, 'genre', 'movie_genre', 'action_movie', 'cinderella', 'fictious']
senticnet['fictitious_place'] = [-0.924, 0, 0.687, -0.75, '#sad', '#disgusting', -0.787, 'hellfire', 'red_region', 'imaginary_place', 'mythical_place', 'infernal_region']
senticnet['fiddle'] = [-0.564, 0, 0.917, -0.889, '#angry', '#disgusting', -0.79, 'troubleshoot', 'furbish_up', 'fill', 'darn', 'sole']
senticnet['fiddler'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'play_instrument', 'play_fiddle', 'rock_out', 'pluck', 'read_music']
senticnet['fiddler_crab'] = [-0.698, 0, 0.766, -0.826, '#angry', '#disgusting', -0.763, 'stone_crab', 'swimming_crab', 'rock_crab', 'crab', 'pea_crab']
senticnet['fidget'] = [-0.882, 0, -0.834, 0, '#sad', '#scared', -0.572, 'impatient', 'impatience', 'restlessness', 'nervous', 'humility']
senticnet['fidgetiness'] = [-0.92, 0, -0.876, 0, '#sad', '#scared', -0.599, 'fretful', 'antsy', 'fidgety', 'stewing', 'impatiently']
senticnet['fidgety'] = [-0.997, 0, -0.828, 0, '#sad', '#scared', -0.608, 'fretful', 'fidgetiness', 'antsy', 'stewing', 'impatiently']
senticnet['field'] = [-0.975, 0, 0.737, -0.979, '#sad', '#disgusting', -0.897, 'flare_path', 'airairstrip', 'landing_airstrip', 'flying_airstrip', 'airstrip']
senticnet['field_ball'] = [-0.149, 0, -0.049, 0, '#sad', '#scared', -0.066, 'roll_downhill', 'deal_card', 'state_obvious', 'throw_fit', 'watch_d']
senticnet['field_crop'] = [0, 0.099, 0.031, 0.115, '#interesting', '#admirable', 0.061, 'field_grow', 'grow_food', 'cow_home', 'grow_stuff', 'agriculture']
senticnet['field_glasses'] = [0.954, -0.668, 0, 0.958, '#joyful', '#admirable', 0.86, 'instrument', 'spectroscope', 'prism_spectroscope', 'binoculars', 'optical_instrument']
senticnet['field_grow'] = [0, 0.071, 0.033, 0.061, '#interesting', '#admirable', 0.033, 'field_crop', 'overall', 'grow_crop', 'grow_food', 'cultivation']
senticnet['field_mouse'] = [-0.55, 0, 0.955, -0.96, '#angry', '#disgusting', -0.822, 'house_mouse', 'harvest_mouse', 'mouse', 'fieldmouse', 'nude_mouse']
senticnet['field_of_honor'] = [0.954, -0.668, 0, 0.958, '#joyful', '#admirable', 0.86, 'dark', 'darkness', 'light', 'shadow', 'scene']
senticnet['field_question'] = [-0.14, 0, 0, -0.039, '#sad', '#disgusting', -0.06, 'transfer_knowledge', 'school_student', 'dry_mouth', 'learn_listen', 'annoy_other_person']
senticnet['field_scabious'] = [0.954, -0.668, 0, 0.958, '#joyful', '#admirable', 0.86, 'sweet_scabious', 'pincushion_flower', 'mournful_widow', 'scabiosa', 'flower']
senticnet['field_test'] = [0.928, -0.879, 0, 0.679, '#joyful', '#surprising', 0.829, 'field_trial', 'test', 'alpha_test', 'beta_test', 'road_test']
senticnet['field_trial'] = [0.928, -0.879, 0, 0.679, '#joyful', '#surprising', 0.829, 'test', 'field_test', 'alpha_test', 'beta_test', 'road_test']
senticnet['fielder'] = [0.089, -0.18, 0.037, -0.061, '#joyful', '#surprising', 0.057, 'balloon', 'luna_park', 'ballon', 'kite', 'blimp']
senticnet['fieldmouse'] = [-0.55, 0, 0.955, -0.96, '#angry', '#disgusting', -0.822, 'house_mouse', 'harvest_mouse', 'field_mouse', 'mouse', 'nude_mouse']
senticnet['fieldworker'] = [0.846, -0.755, 0, 0.69, '#joyful', '#surprising', 0.764, 'experimenter', 'boffin', 'investigator', 'postdoc', 'post_doc']
senticnet['fiend'] = [-0.823, 0, 0.635, -0.569, '#sad', '#angry', -0.676, 'demoniac', 'ogre', 'demon', 'devil', 'monster']
senticnet['fierce'] = [0, 0, 0, 0.076, '#admirable', '#admirable', 0.025, 'ferocious', 'woodland_creature', 'hairy_animal', 'huge_animal', 'brown_fur']
senticnet['fierceness'] = [-0.63, 0, 0.921, -0.621, '#sad', '#angry', -0.724, 'fury', 'wildness', 'ferocity', 'savagery', 'furiousness']
senticnet['fiery'] = [0.737, 0.845, 0, 0, '#joyful', '#interesting', 0.527, 'hot_temperature', 'high_temperature', 'hotness', 'heat', 'fire_product']
senticnet['fife'] = [0.821, -0.531, 0, 0.785, '#joyful', '#admirable', 0.712, 'flute', 'nose_flute', 'piccolo', 'woodwind', 'woodwind_instrument']
senticnet['fifth_sense'] = [0, 0.075, 0, 0.159, '#interesting', '#admirable', 0.078, 'eye_function', 'eye_sense', 'sight', 'vision', 'leer']
senticnet['fifth_wheel'] = [-0.775, 0, 0.9, -0.799, '#angry', '#disgusting', -0.825, 'embarrassment', 'redundance', 'deadwood', 'overplus', 'plethora']
senticnet['fig'] = [0.832, 0.983, 0, 0, '#joyful', '#interesting', 0.605, 'fruit_tree', 'baby_flower', 'carpel', 'strawberry', 'star_anise']
senticnet['fig_out'] = [-0.888, 0, 0.896, -0.796, '#sad', '#angry', -0.86, 'overdress', 'attire', 'dress_up', 'prink', 'dizen']
senticnet['fight'] = [0, 0, 0, -0.859, '#disgusting', '#disgusting', -0.286, 'combat', 'quarrel', 'opposition', 'conflict', 'big_fight']
senticnet['fight_against'] = [-0.904, 0, 0, -0.964, '#sad', '#disgusting', -0.623, 'combat', 'uprise', 'big_fight', 'opposition', 'violence']
senticnet['fight_back'] = [-0.68, 0, 0.765, -0.547, '#sad', '#angry', -0.664, 'fight', 'oppose', 'recalcitrate', 'fight_down', 'defend']
senticnet['fight_battle'] = [-0.126, 0, 0, -0.165, '#sad', '#disgusting', -0.097, 'start_war', 'guard_bank', 'commit_genocide', 'keep_peace', 'go_war']
senticnet['fight_boyfriend'] = [-0.835, 0, -0.828, -0.867, '#sad', '#disgusting', -0.843, 'bury_cat', 'stop_marry', 'bungee_jump_from_high_bridge', 'get_divorce', 'punch']
senticnet['fight_disease'] = [0, 0, -0.894, 0, '#scared', '#scared', -0.298, 'rescue', 'rejuvenate', 'bank_money', 'rejuvenation', 'efficiency']
senticnet['fight_down'] = [0.846, -0.574, 0, 0.864, '#joyful', '#admirable', 0.761, 'fight', 'withstand', 'stand_firm', 'struggle', 'recalcitrate']
senticnet['fight_enemy'] = [0, 0, 0.854, -0.857, '#angry', '#disgusting', -0.57, 'destroy_enemy', 'kill', 'fight_war', 'genocide', 'punch']
senticnet['fight_fire'] = [-0.063, -0.024, 0.042, 0, '#sad', '#angry', -0.027, 'dirty', 'feel_dirty', 'shrinkage', 'need_clean', 'fall_mud']
senticnet['fight_inflation'] = [-0.026, -0.101, 0, 0.078, '#surprising', '#admirable', 0.051, 'buy_present_for_others', 'gain_land', 'buy_love', 'buy_present', 'buy_christmas_present']
senticnet['fight_man'] = [-0.052, 0, -0.078, -0.165, '#scared', '#disgusting', -0.098, 'arm_oneself', 'soldier', 'armory', 'declare_war', 'civil_war']
senticnet['fight_other'] = [-0.977, 0, -0.991, 0, '#sad', '#scared', -0.656, 'die_only_once', 'trust_friend', 'hurt_animal', 'kill_specific_group', 'dig_grave']
senticnet['fight_somebody'] = [-0.995, 0, 0.522, -0.982, '#sad', '#disgusting', -0.833, 'evil', 'bad_person', 'evil_man', 'kill_somebody', 'evil_eye']
senticnet['fight_war'] = [0, 0, 0, -0.947, '#disgusting', '#disgusting', -0.316, 'conquer_nation', 'fight_enemy', 'destroy_enemy', 'kill', 'war']
senticnet['fighter'] = [0, 0, 0, -0.074, '#disgusting', '#disgusting', -0.025, 'army_man', 'army_person', 'sailor', 'man', 'workman']
senticnet['fighting_spirit'] = [0.827, 0.913, 0, 0.867, '#interesting', '#admirable', 0.869, 'good_habit', 'improve_oneself', 'competitive', 'competitive_nature', 'want_to_win']
senticnet['figure'] = [0.706, 0, 0, 0.994, '#joyful', '#admirable', 0.567, 'geometric_figure', 'polygon', 'form', 'parallelogram', 'hexagon']
senticnet['figure_out'] = [0.902, 0.903, 0, 0, '#joyful', '#interesting', 0.602, 'resolve_problem', 'arrive_conclusion', 'come_conclusion', 'come_up_idea', 'study_fact']
senticnet['figure_skate'] = [0.918, 0.769, 0, 0, '#joyful', '#interesting', 0.562, 'old_dance', 'dance', 'slow_dance', 'dance_type', 'enter_contest']
senticnet['filament'] = [-0.036, -0.044, 0.079, -0.092, '#angry', '#disgusting', -0.054, 'string', 'bandage', 'suture', 'thread', 'needle_thread']
senticnet['file'] = [0, 0.077, 0, 0.068, '#interesting', '#admirable', 0.048, 'make_book', 'document', 'paper_write', 'readable', 'newspaper_write']
senticnet['file_bill'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'bill', 'credit_check', 'get_salary', 'get_paid', 'bank']
senticnet['file_box'] = [0, 0.877, 0, 0, '#interesting', '#interesting', 0.292, 'box', 'home_sweet_home', 'home', 'change_life', 'clean_house']
senticnet['file_complaint'] = [0, 0, 0.701, -0.859, '#angry', '#disgusting', -0.52, 'obey_law', 'meet_greet', 'courageous', 'say_no', 'box_ear']
senticnet['file_drawer'] = [0, 0.877, 0, 0, '#interesting', '#interesting', 0.292, 'desk', 'office', 'folder', 'organiser', 'document']
senticnet['file_system'] = [-0.066, 0.119, 0, 0.096, '#interesting', '#admirable', 0.05, 'recollection', 'file', 'brain_function', 'rote', 'memory']
senticnet['filefish'] = [-0.545, 0, 0.829, -0.725, '#angry', '#disgusting', -0.7, 'puffer', 'pufferfish', 'blowfish', 'triggerfish', 'plectognath']
senticnet['fill'] = [0.024, 0.188, -0.147, 0.228, '#interesting', '#admirable', 0.098, 'heap', 'thwart', 'come', 'fill_up', 'tow']
senticnet['fill_air'] = [0.804, 0, 0, 0.795, '#joyful', '#admirable', 0.533, 'spherical_shape', 'use_sport', 'bouncy', 'three_dimensional', 'make_out_rubber']
senticnet['fill_bathtub'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'soap', 'relax', 'relax_time', 'bath', 'bathroom']
senticnet['fill_bathtub_water'] = [0, 0.877, 0, 0, '#interesting', '#interesting', 0.292, 'fill_bathtub', 'water', 'relax_time', 'relax', 'soap']
senticnet['fill_bill'] = [0.535, -0.806, 0, 0.577, '#surprising', '#admirable', 0.639, 'meet', 'satisfy', 'fulfill', 'conform_to', 'fill_in']
senticnet['fill_bottle'] = [-0.131, 0, 0, 0, '#sad', '#sad', -0.044, 'shoulder_responsibility', 'sun_oneself', 'throw_fit', 'watch_d', 'laugh_clown']
senticnet['fill_form'] = [0, 0, 0, -0.947, '#disgusting', '#disgusting', -0.316, 'boring', 'bureaucracy', 'annoying', 'form', 'fill_out_form']
senticnet['fill_gas_tank'] = [-0.1, 0, 0, 0, '#sad', '#sad', -0.033, 'open_car_door', 'turn_key', 'plan_route', 'put_key_ignition', 'adjust_seat']
senticnet['fill_glass'] = [0, 0.07, 0, 0.05, '#interesting', '#admirable', 0.04, 'gulp', 'better_cold', 'ferment', 'potable_liquid', 'sip']
senticnet['fill_helium'] = [-0.799, 0, 0.719, 0, '#sad', '#angry', -0.506, 'fill_air', 'spherical_shape', 'use_sport', 'stretchy', 'spherical']
senticnet['fill_in'] = [0.535, -0.806, 0, 0.577, '#surprising', '#admirable', 0.639, 'meet', 'satisfy', 'fulfill', 'conform_to', 'fill_bill']
senticnet['fill_in_glass'] = [-0.912, 0, -0.884, 0, '#sad', '#scared', -0.599, 'move_liquid', 'hand_hold', 'pour_liquid', 'pour', 'push']
senticnet['fill_ink'] = [0.292, 0.328, -0.098, 0.262, '#joyful', '#interesting', 0.261, 'fold_up', 'turn_knob', 'erase', 'hold_hand', 'shut_door']
senticnet['fill_out_application'] = [0, 0, 0, -0.947, '#disgusting', '#disgusting', -0.316, 'annoying', 'bureaucracy', 'boring', 'form', 'fill_form']
senticnet['fill_out_form'] = [0, 0, 0, -0.947, '#disgusting', '#disgusting', -0.316, 'boring', 'bureaucracy', 'annoying', 'form', 'fill_form']
senticnet['fill_stomach'] = [0.87, 0.758, 0, 0, '#joyful', '#interesting', 0.543, 'sustenance', 'enjoy_eat', 'satisfy_hunger', 'nourishment', 'eat_out']
senticnet['fill_up'] = [0.097, 0, 0, 0, '#joyful', '#joyful', 0.032, 'serve_liquid', 'eat_liquid', 'swallow', 'consume_food', 'drink_soup']
senticnet['fill_with_sand'] = [-0.968, 0, 0.767, 0, '#sad', '#angry', -0.578, 'circle_shape', 'ball_shape', 'round_shape', 'seen_night_sky', 'round']
senticnet['fillet'] = [-0.024, -0.022, 0.064, -0.071, '#angry', '#disgusting', -0.046, 'ocean_water', 'fillet_fish', 'chowder', 'port', 'underwater']
senticnet['fillet_fish'] = [0.027, 0.111, -0.055, 0.167, '#interesting', '#admirable', 0.083, 'price_product', 'food', 'fried_fillet', 'dinner', 'hungry']
senticnet['fillip'] = [0.588, -0.914, 0, 0.717, '#surprising', '#admirable', 0.74, 'positive_stimulus', 'joy', 'bonus', 'stimulant', 'delight']
senticnet['film'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'movie', 'entertainment', 'show', 'cinema', 'cctv']
senticnet['film_critic'] = [0.051, 0, 0, 0.072, '#joyful', '#admirable', 0.041, 'evaluate', 'wish_entertain', 'enjoyment', 'assess', 'entertainment']
senticnet['film_studio'] = [0, 0.07, 0, 0.071, '#interesting', '#admirable', 0.047, 'broadcast', 'tv_studio', 'cinema', 'theater', 'movie']
senticnet['filter'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'water_inside', 'water_spray', 'teapot', 'bodily_waste', 'different_type']
senticnet['filth'] = [0, 0, 0.928, -0.99, '#angry', '#disgusting', -0.639, 'smell_like_fish', 'spoil_food', 'sewer', 'decay', 'waste']
senticnet['filthiness'] = [-0.687, 0, 0.529, -0.694, '#sad', '#disgusting', -0.637, 'nastiness', 'filth', 'unsanitariness', 'dunghill', 'sanitary_condition']
senticnet['filthy'] = [0, 0, 0.928, -0.99, '#angry', '#disgusting', -0.639, 'filth', 'dirty', 'gross', 'unclean', 'feel_dirty']
senticnet['finagler'] = [-0.932, 0, 0.976, -0.541, '#sad', '#angry', -0.816, 'beguiler', 'slicker', 'deceiver', 'cheat', 'cheater']
senticnet['final'] = [-0.046, 0.182, -0.119, 0.167, '#interesting', '#admirable', 0.061, 'multiple_choices', 'final_exam', 'grade', 'evaluation', 'school_grade']
senticnet['final_exam'] = [-0.057, 0.141, -0.098, 0.132, '#interesting', '#admirable', 0.039, 'multiple_choices', 'pop_quiz', 'final', 'quiz', 'evaluation']
senticnet['finality'] = [-0.078, 0.191, -0.113, 0.147, '#interesting', '#admirable', 0.049, 'conclusion', 'end_point', 'omega', 'end', 'finish_complete']
senticnet['finalize'] = [0.033, 0.158, -0.069, 0.145, '#interesting', '#admirable', 0.089, 'finish', 'end', 'finish_complete', 'end_point', 'last']
senticnet['finance'] = [-0.026, 0.333, -0.057, 0.108, '#interesting', '#admirable', 0.119, 'deposit', 'bank', 'business', 'money', 'profit']
senticnet['finances'] = [0.534, -0.868, 0, 0.736, '#surprising', '#admirable', 0.713, 'funds', 'escrow_funds', 'monetary_resource', 'cash_in_hand', 'pecuniary_resource']
senticnet['financial'] = [0.033, 0.247, 0, 0.13, '#interesting', '#admirable', 0.137, 'accountant_office', 'deposit', 'account_department', 'checkbook', 'bank_loan']
senticnet['financial_aid'] = [0.815, -0.961, 0, 0.633, '#joyful', '#surprising', 0.803, 'grant', 'gift', 'social_welfare', 'public_assistance', 'philanthropy']
senticnet['financial_forecast'] = [0.993, -0.654, 0, 0.743, '#joyful', '#admirable', 0.797, 'weather_forecast', 'weather_outlook', 'prognosis', 'prediction', 'foretelling']
senticnet['financial_gain'] = [0.789, 0.94, 0, 0, '#joyful', '#interesting', 0.576, 'monetary_gain', 'earnings', 'money_earn', 'investment_return', 'income']
senticnet['financial_security'] = [0.932, 0.787, 0, 0, '#joyful', '#interesting', 0.573, 'self_respect', 'acquire_wealth', 'complement', 'pay_work', 'feel_important']
senticnet['financial_statement'] = [0.671, -0.574, 0, 0.879, '#joyful', '#admirable', 0.708, 'bank_statement', 'bill', 'account', 'invoice', 'accounting']
senticnet['financial_transaction'] = [-0.078, 0.302, -0.155, 0.241, '#interesting', '#admirable', 0.103, 'money_exchange', 'send_money', 'give_cash', 'business_deal', 'settle_bill']
senticnet['find'] = [-0.779, 0, 0.816, -0.85, '#angry', '#disgusting', -0.815, 'catch_out', 'detect', 'observe', 'discover', 'notice']
senticnet['find_address'] = [0.89, -0.616, 0, 0.757, '#joyful', '#admirable', 0.754, 'turn_computer_on', 'find_computer', 'buy_computer', 'go_online', 'internet_connection']
senticnet['find_airplane'] = [-0.042, 0.142, -0.083, 0.11, '#interesting', '#admirable', 0.042, 'find_out', 'use_garden', 'use_game_chess', 'prohibitionist_society', 'make_up_person']
senticnet['find_airport'] = [-0.059, -0.016, -0.079, -0.169, '#scared', '#disgusting', -0.097, 'use_military', 'siege', 'violence', 'battle', 'buy_gun']
senticnet['find_america'] = [-0.067, 0.131, 0, 0.081, '#interesting', '#admirable', 0.048, 'columbus', 'seek_out', 'eureka', 'find_out', 'aware']
senticnet['find_animal'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'lost_pet', 'wild_horse', 'animal', 'doghouse', 'find_dog']
senticnet['find_another_person'] = [-0.051, 0.144, -0.09, 0.092, '#interesting', '#admirable', 0.032, 'talk_another_person', 'fact_straight', 'know_language', 'nod_head', 'make_unusual_face']
senticnet['find_answer'] = [0.746, 0.871, 0, 0.928, '#interesting', '#admirable', 0.848, 'solve_mystery', 'come_conclusion', 'remember', 'resolve_problem', 'study_fact']
senticnet['find_balance'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'avoid_fall', 'agile', 'skip_rope', 'avoid_failure', 'good_balance']
senticnet['find_ball'] = [-0.09, -0.021, 0.071, 0, '#sad', '#angry', -0.047, 'wear_good_shoes', 'wear_running_shoes', 'use_leg', 'put_running_shoes', 'act_quickly']
senticnet['find_bank'] = [-0.176, -0.15, -0.214, -0.083, '#sad', '#scared', -0.108, 'find_subway_stop', 'kill_human_being', 'find_farm', 'slander', 'die']
senticnet['find_beach'] = [0.756, -0.98, 0, 0.744, '#joyful', '#surprising', 0.827, 'play', 'delight_audience', 'find_hardware_store', 'hamlet', 'play_cat']
senticnet['find_bedroom'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'find_motel', 'find_hospice', 'buy_bedroom', 'find_pillow', 'take_nap']
senticnet['find_book'] = [0.725, 0, 0, 0, '#joyful', '#joyful', 0.242, 'buy_book', 'open_book', 'choose_book', 'read_book', 'book']
senticnet['find_book_library'] = [0.823, 0.891, 0, 0.759, '#joyful', '#interesting', 0.824, 'find_book', 'book', 'read_book', 'choose_book', 'open_book']
senticnet['find_bug'] = [0.956, -0.823, 0, 0, '#joyful', '#surprising', 0.593, 'take_out_loan', 'down_payment', 'money', 'bring_wallet', 'know_like']
senticnet['find_build'] = [0.078, 0.134, 0.011, 0.108, '#interesting', '#admirable', 0.103, 'find_office', 'find_kitchen', 'find_hospice', 'find_car', 'find_house']
senticnet['find_building'] = [0.078, 0.134, 0.011, 0.108, '#interesting', '#admirable', 0.103, 'directions', 'home', 'house', 'find_car', 'find_house']
senticnet['find_campsite'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'campsite', 'find_motel', 'take_nap', 'find_hospice', 'find_hotel']
senticnet['find_car'] = [-0.024, 0.109, -0.055, 0.111, '#interesting', '#admirable', 0.047, 'find_library', 'read_human', 'make_paper', 'find_hotel', 'find_kitchen']
senticnet['find_car_key'] = [0, 0.757, 0, 0.811, '#interesting', '#admirable', 0.523, 'car_key', 'car', 'drive_license', 'start_car_engine', 'find_house_key']
senticnet['find_chair'] = [0.988, -0.795, 0, 0.65, '#joyful', '#surprising', 0.811, 'sit_place', 'sit_furniture', 'place_to_sit', 'bend_knee', 'chair']
senticnet['find_church'] = [0.719, 0, 0, 0.779, '#joyful', '#admirable', 0.499, 'open', 'control_access', 'cost_a_lot_of_money', 'restrict_access', 'keep_someone_out']
senticnet['find_computer'] = [0.89, -0.616, 0, 0.757, '#joyful', '#admirable', 0.754, 'turn_computer_on', 'send_message', 'buy_computer', 'go_online', 'internet_connection']
senticnet['find_country'] = [0.889, 0.95, 0, 0, '#joyful', '#interesting', 0.613, 'find', 'discover', 'find_new_culture', 'explore', 'travel']
senticnet['find_cure'] = [0.612, 0.99, 0, 0.713, '#interesting', '#admirable', 0.772, 'cure_disease', 'find_doctor', 'talk_to_an_expert', 'call_doctor', 'find']
senticnet['find_desk'] = [0.853, -0.719, 0, 0.92, '#joyful', '#admirable', 0.831, 'enlighten', 'learn_information', 'become_educated', 'learn', 'listen_teacher']
senticnet['find_direction'] = [0.853, -0.719, 0, 0.92, '#joyful', '#admirable', 0.831, 'point_out', 'use_compass', 'find', 'direction', 'use_map']
senticnet['find_doctor'] = [0.612, 0.99, 0, 0.713, '#interesting', '#admirable', 0.772, 'cure_disease', 'find_cure', 'talk_to_an_expert', 'call_doctor', 'find']
senticnet['find_dog'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'lost_pet', 'wild_horse', 'animal', 'doghouse', 'find_animal']
senticnet['find_downtown'] = [0.088, 0.149, 0, 0.107, '#interesting', '#admirable', 0.115, 'large_food_store', 'large_supermarket', 'shop_arcade', 'general_store', 'food_store']
senticnet['find_earth'] = [0.088, 0.149, 0, 0.107, '#interesting', '#admirable', 0.115, 'find_country', 'safety', 'salvation', 'find_food', 'find_direction']
senticnet['find_end_line'] = [0, 0.128, -0.049, 0.064, '#interesting', '#admirable', 0.048, 'line_up', 'civility', 'come_early', 'wait_in_line', 'wait_patiently']
senticnet['find_enemy'] = [-0.181, 0, -0.122, -0.229, '#sad', '#disgusting', -0.177, 'declare_war', 'buy_weapon', 'plan_attack', 'make_enemy', 'arm_oneself']
senticnet['find_fact'] = [0.901, -0.695, 0, 0.855, '#joyful', '#admirable', 0.817, 'look_fact', 'fact', 'register_vote', 'look_evidence', 'form_opinion']
senticnet['find_farm'] = [0.844, -0.721, 0, 0, '#joyful', '#surprising', 0.522, 'find_bank', 'find_subway_stop', 'cremate', 'kill_human_being', 'corner_prey']
senticnet['find_floor'] = [0.036, 0.067, 0.023, 0.144, '#interesting', '#admirable', 0.075, 'place', 'floor', 'location', 'address', 'big_place']
senticnet['find_flower'] = [0.737, 0.787, 0, 0.915, '#interesting', '#admirable', 0.813, 'plant_tree', 'pick_flower', 'flower', 'lie_on_grass', 'enjoy_nature']
senticnet['find_food'] = [0.759, 0, 0, 0.975, '#joyful', '#admirable', 0.578, 'food', 'prepare_meal', 'prepare_food', 'prepare_table', 'prepare_dinner']
senticnet['find_forest'] = [0.045, 0, 0, 0.051, '#joyful', '#admirable', 0.032, 'tree', 'forest', 'wood', 'carve', 'mass_production']
senticnet['find_friend'] = [0.754, -0.838, 0, 0.608, '#joyful', '#surprising', 0.733, 'get_together_friend', 'socialization', 'relay_information', 'find_out_information', 'nothing_better']
senticnet['find_friend_play'] = [0.737, 0.787, 0, 0.915, '#interesting', '#admirable', 0.813, 'find_play', 'friend', 'learn_game', 'find_other_player', 'join_team']
senticnet['find_funny'] = [0.759, 0, 0, 0.975, '#joyful', '#admirable', 0.578, 'tell_funny_joke', 'tell_joke', 'laugh', 'fun', 'good_joke']
senticnet['find_garden'] = [0, 0, 0, 0.084, '#admirable', '#admirable', 0.028, 'walk', 'nice_walk', 'find', 'garden', 'enjoy_nature']
senticnet['find_grocery_store'] = [0.974, -0.528, 0, 0.5, '#joyful', '#surprising', 0.667, 'buy_vegetable', 'buy_grocery', 'buy_food', 'stock_merchandise', 'grocery_store']
senticnet['find_ground'] = [0, 0, 0, 0.084, '#admirable', '#admirable', 0.028, 'use_tool', 'mould', 'award_winner', 'ground', 'frame_picture']
senticnet['find_guilty'] = [-0.234, 0.071, -0.062, -0.092, '#sad', '#disgusting', -0.106, 'close_case', 'punish_crime', 'question_witness', 'seek_justice', 'convict_criminal']
senticnet['find_hardware_store'] = [0.932, 0.931, 0, 0.78, '#joyful', '#interesting', 0.881, 'play', 'delight_audience', 'hamlet', 'play_cat', 'make_believe']
senticnet['find_help'] = [0.935, 0.703, 0, 0, '#joyful', '#interesting', 0.546, 'thoughtful', 'find_out_need', 'kindness', 'volunteer', 'lend_hand']
senticnet['find_home'] = [0, 0, 0, 0.086, '#admirable', '#admirable', 0.029, 'use_clean', 'clean_shoes', 'soapy', 'find_house', 'sanitary']
senticnet['find_hospice'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'find_motel', 'find_bedroom', 'find_car', 'cover_pillow', 'save_space']
senticnet['find_hotel'] = [0.759, 0, 0, 0.975, '#joyful', '#admirable', 0.578, 'find_campsite', 'find_motel', 'take_nap', 'find_hospice', 'hotel']
senticnet['find_house'] = [0.078, 0.134, 0.011, 0.108, '#interesting', '#admirable', 0.103, 'directions', 'home', 'house', 'find_car', 'find_building']
senticnet['find_house_key'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'car_key', 'car', 'drive_license', 'start_car_engine', 'find_car_key']
senticnet['find_information'] = [0.535, 0.531, 0, 0.858, '#joyful', '#admirable', 0.641, 'learn_subject', 'understand_better', 'research', 'gain_knowledge', 'go_online']
senticnet['find_interest'] = [0.814, 0.528, 0, 0.514, '#joyful', '#interesting', 0.619, 'web_surf', 'search_information', 'need_information', 'look_for_information', 'conduct_research']
senticnet['find_jar'] = [0.101, -0.248, -0.049, 0.212, '#surprising', '#admirable', 0.171, 'pleasant_experience', 'stick', 'rod', 'wax', 'mantle']
senticnet['find_job'] = [0.955, 0.945, 0, 0.835, '#joyful', '#interesting', 0.912, 'perform_service', 'provide_service', 'accomplish', 'pay_well', 'responsible']
senticnet['find_kitchen'] = [0, 0.085, 0, 0.059, '#interesting', '#admirable', 0.048, 'find_office', 'open', 'find_car', 'hang_clothes', 'find_build']
senticnet['find_lake'] = [0, 0.085, 0, 0.059, '#interesting', '#admirable', 0.048, 'find', 'lake', 'trekking', 'lost_in_nature', 'wear_shoes']
senticnet['find_library'] = [-0.051, -0.034, -0.051, 0, '#sad', '#scared', -0.023, 'read_human', 'read', 'make_paper', 'pick_tooth', 'illuminate_area']
senticnet['find_line'] = [0.883, 0.901, 0, 0, '#joyful', '#interesting', 0.595, 'find_end_line', 'come_early', 'line_up', 'take_number', 'wait_patiently']
senticnet['find_line_stand'] = [-0.152, 0, 0, -0.149, '#sad', '#disgusting', -0.1, 'start_over', 'wait_patiently', 'lose_place', 'queue', 'find_line']
senticnet['find_location'] = [0.881, -0.966, 0, 0.614, '#joyful', '#surprising', 0.82, 'lack_of_sleep', 'tired', 'try_best', 'lose', 'sore_knee']
senticnet['find_lost_item'] = [0, -0.039, 0, 0.097, '#surprising', '#admirable', 0.045, 'analyze', 'find_truth', 'discover_truth', 'determine_truth', 'examine']
senticnet['find_love'] = [0.739, 0, 0, 0.953, '#joyful', '#admirable', 0.564, 'kiss_other', 'fall_love', 'love', 'care_deeply', 'love_oneself']
senticnet['find_mall'] = [0.718, 0, 0, 0.987, '#joyful', '#admirable', 0.568, 'harvest_fall', 'mall', 'require_good_health', 'eaten', 'grown_soil']
senticnet['find_market'] = [0.783, 0.957, 0, 0, '#joyful', '#interesting', 0.58, 'go_department_store', 'buy_grocery', 'go_to_shopping_mall', 'find_food', 'fresh_food']
senticnet['find_match'] = [0.087, 0.113, -0.087, 0, '#joyful', '#interesting', 0.038, 'matchbox', 'strike_against', 'cigarette_lighter', 'match', 'use_lighter']
senticnet['find_matchbox'] = [0.087, 0.113, -0.087, 0, '#joyful', '#interesting', 0.038, 'match', 'light_cigarette', 'cigarette_lighter', 'matchbox', 'use_lighter']
senticnet['find_mate'] = [0.722, 0.929, 0, 0.854, '#interesting', '#admirable', 0.835, 'sexual_intercourse', 'become_aroused', 'find_partner', 'warm_fuzzy_feeling', 'make_love']
senticnet['find_mean'] = [0.717, 0.908, 0, 0, '#joyful', '#interesting', 0.542, 'come_conclusion', 'come_up_idea', 'resolve_problem', 'come_up_new_idea', 'figure_out']
senticnet['find_merchant'] = [0.719, 0.757, 0, 0, '#joyful', '#interesting', 0.492, 'go_department_store', 'go_to_shopping_mall', 'drive_to_store', 'find_market', 'go_shopping']
senticnet['find_money'] = [0.716, 0.948, 0, 0.973, '#interesting', '#admirable', 0.879, 'good_credit', 'money_credit', 'need_money', 'bring_wallet', 'use_money']
senticnet['find_motel'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'one_night_stand', 'find_bedroom', 'find_car', 'cover_pillow', 'bed']
senticnet['find_mountain'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'mountain', 'find', 'enjoy_nature', 'beautiful_view', 'enjoy_view']
senticnet['find_museum'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'pay_admission', 'tourist', 'dress_nicely', 'find_out', 'vacation']
senticnet['find_new'] = [0.876, -0.995, 0, 0.697, '#joyful', '#surprising', 0.856, 'become_educated', 'learn_new', 'get_degree', 'become_intelligent', 'know_stuff']
senticnet['find_new_culture'] = [0.786, 0.805, 0, 0, '#joyful', '#interesting', 0.53, 'find', 'discover', 'find_country', 'explore', 'travel']
senticnet['find_new_friend'] = [0, 0.827, 0, 0.84, '#interesting', '#admirable', 0.556, 'socialize', 'get_know', 'look_sexy', 'impress_person', 'visit_friend']
senticnet['find_newspaper'] = [0.088, -0.003, 0, 0, '#joyful', '#surprising', 0.03, 'look_up_information', 'news', 'headlines', 'enter_contest', 'latest_news']
senticnet['find_number'] = [0.769, 0.827, 0, 0, '#joyful', '#interesting', 0.532, 'get_sum', 'calculator', 'add_two_numbers_together', 'add_number_together', 'find_total']
senticnet['find_office'] = [0.029, 0.16, -0.054, 0.164, '#interesting', '#admirable', 0.1, 'find_kitchen', 'search', 'look', 'find_car', 'find_build']
senticnet['find_oneself'] = [0.7, -0.646, 0, 0.953, '#joyful', '#admirable', 0.766, 'find', 'ripen', 'maturate', 'grow_up', 'develop']
senticnet['find_other_player'] = [-0.044, -0.017, 0.063, 0, '#sad', '#angry', -0.03, 'find_someone_to_play_with', 'know_how_play_baseball', 'ball_player', 'join_team', 'gather_team']
senticnet['find_out'] = [0.707, -0.609, 0, 0.696, '#joyful', '#admirable', 0.671, 'know_how', 'interest_subject', 'go_meet', 'see_different', 'plan_time']
senticnet['find_out_fact'] = [0.877, 0.989, 0, 0, '#joyful', '#interesting', 0.622, 'sit_jury', 'look_evidence', 'examine_evidence', 'come_decision', 'consider_evidence']
senticnet['find_out_healthy'] = [0.956, 0.921, 0, 0.729, '#joyful', '#interesting', 0.869, 'learn_disease', 'psychoneurosis', 'severe_pain', 'discomfort', 'embarrassment']
senticnet['find_out_information'] = [0.822, 0.894, 0, 0.855, '#interesting', '#admirable', 0.857, 'get_information', 'learn_entertainment', 'keep_up_current_event', 'understand_current_event', 'understand_culture']
senticnet['find_out_need'] = [0.899, 0.861, 0, 0.859, '#joyful', '#interesting', 0.873, 'volunteer', 'lend_hand', 'tell_everyone', 'share_others', 'introspection']
senticnet['find_out_new'] = [0.901, -0.542, 0, 0.775, '#joyful', '#admirable', 0.739, 'see_ad', 'gain_knowledge', 'eye_strain', 'change_opinion', 'learn']
senticnet['find_out_play'] = [0.727, 0.836, 0, 0, '#joyful', '#interesting', 0.521, 'go_to_theater', 'buy_ticket', 'go_movie_theater', 'drive_theater', 'purchase_ticket']
senticnet['find_out_problem'] = [0.937, 0.881, 0, 0, '#joyful', '#interesting', 0.606, 'find_out_wrong', 'dial_number', 'make_eye_contact', 'attention', 'ask_question']
senticnet['find_out_truth'] = [0.648, -0.612, 0, 0.57, '#joyful', '#surprising', 0.61, 'know_world', 'wisdom', 'seek_answer', 'know', 'knowledge']
senticnet['find_out_want'] = [-0.023, 0.219, -0.094, 0.122, '#interesting', '#admirable', 0.075, 'shopping', 'determine_need', 'go_department_store', 'search_item', 'know_want']
senticnet['find_out_weather'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'understand_current_event', 'keep_up_current_event', 'appreciate_art', 'learn_entertainment', 'learn_news']
senticnet['find_out_world'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'find_out', 'understand_new_culture', 'discover', 'explore', 'learn']
senticnet['find_out_wrong'] = [0.762, 0.923, 0, 0, '#joyful', '#interesting', 0.562, 'empathize', 'end_conversation', 'find_out_problem', 'listen_problem', 'shake_hand']
senticnet['find_outside'] = [0.146, 0.114, -0.058, 0.129, '#joyful', '#admirable', 0.11, 'roof', 'foundation', 'exterior', 'umbrella', 'vane']
senticnet['find_own_place_in_world'] = [0, 0.098, 0.012, 0.276, '#interesting', '#admirable', 0.121, 'position', 'job', 'placement', 'character_trait', 'place']
senticnet['find_pantry'] = [-0.044, -0.009, 0.049, 0, '#sad', '#angry', -0.028, 'buy_many', 'buy_gum', 'shop_grocery', 'buy_clothes', 'pantry']
senticnet['find_paper'] = [0.788, 0.857, 0, 0, '#joyful', '#interesting', 0.548, 'learn_write', 'think_write', 'find_pen_and_paper', 'paper_plane', 'pen_and_paper']
senticnet['find_park_space'] = [0.747, 0.971, 0, 0.933, '#interesting', '#admirable', 0.884, 'purchase_grocery', 'buy_milk', 'park_space', 'spend_money', 'buy_goods']
senticnet['find_partner'] = [0.707, 0.84, 0, 0.914, '#interesting', '#admirable', 0.82, 'sex', 'give_hug', 'become_aroused', 'choose_game', 'find_mate']
senticnet['find_pawnshop'] = [0.841, -0.794, 0, 0, '#joyful', '#surprising', 0.545, 'watch', 'stopwatch', 'timepiece', 'wristwatch', 'clock']
senticnet['find_pen_and_paper'] = [0.808, 0.704, 0, 0, '#joyful', '#interesting', 0.504, 'find_paper', 'learn_write', 'write_poem', 'pen_and_paper', 'paper_plane']
senticnet['find_person'] = [0.086, 0, 0, 0.081, '#joyful', '#admirable', 0.056, 'communicate_person', 'talk_person', 'eye_contact', 'start_conversation', 'remember_name']
senticnet['find_phone_number'] = [0.035, -0.01, 0.027, 0.085, '#joyful', '#admirable', 0.034, 'telephone', 'cellphone', 'telephone_room', 'phone', 'use_telephone']
senticnet['find_pillow'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'find_motel', 'find_hospice', 'buy_bedroom', 'find_bedroom', 'take_nap']
senticnet['find_place_to_sit'] = [0.577, -0.502, 0, 0.901, '#joyful', '#admirable', 0.66, 'show_ticket', 'find_out_play', 'find_seat', 'dress_nicely', 'buy_ticket']
senticnet['find_plant'] = [0, 0.122, 0, 0.12, '#interesting', '#admirable', 0.081, 'judicial_system', 'negotiator', 'court_trial', 'member_jury', 'judge_jury']
senticnet['find_play'] = [0.946, -0.989, 0, 0, '#joyful', '#surprising', 0.645, 'find_friend_play', 'learn_rule', 'opponent', 'find_other_player', 'join_team']
senticnet['find_porn'] = [-0.949, 0, 0.881, 0, '#sad', '#angry', -0.61, 'look_for_information', 'need_information', 'learn_computer', 'check_email', 'search_information']
senticnet['find_problem'] = [-0.984, 0, 0.198, -0.962, '#sad', '#disgusting', -0.715, 'disease', 'stress', 'anxiety', 'trouble', 'problem']
senticnet['find_quiet_place'] = [0.911, 0, 0, 0, '#joyful', '#joyful', 0.304, 'relax', 'lucid', 'reflection', 'cup_coffee', 'peace_quiet']
senticnet['find_ranch'] = [-0.039, -0.04, 0.074, -0.054, '#angry', '#disgusting', -0.042, 'purchase_pharmacy', 'require_good_health', 'eaten', 'find_animal', 'ranch']
senticnet['find_recipe'] = [0.061, -0.049, 0, 0, '#joyful', '#surprising', 0.037, 'heat_element', 'stick_butter', 'bake_oven', 'grill', 'food_bake']
senticnet['find_restaurant'] = [0.854, 0.659, 0, 0.545, '#joyful', '#interesting', 0.686, 'decide_want_eat', 'obtain_food', 'bite_food', 'order_lunch', 'decide_eat']
senticnet['find_restroom'] = [0.907, 0.808, 0, 0, '#joyful', '#interesting', 0.572, 'find_toilet', 'unzip_pant', 'full_bladder', 'drink_liquid', 'quench_thirst']
senticnet['find_road'] = [0.807, 0.763, 0, 0, '#joyful', '#interesting', 0.523, 'broken', 'little_bite', 'need_eat_meal', 'small_bite', 'repair']
senticnet['find_school'] = [0.061, -0.049, 0, 0, '#joyful', '#surprising', 0.037, 'education', 'teach_to_read', 'study', 'teach_school', 'classes']
senticnet['find_sea'] = [0.998, 0, 0, 0.72, '#joyful', '#admirable', 0.573, 'port', 'mast', 'bay', 'ship_home', 'sea']
senticnet['find_seat'] = [0.914, -0.524, 0, 0.734, '#joyful', '#admirable', 0.724, 'take_seat', 'read_program', 'drink_coke', 'find_place_to_sit', 'label']
senticnet['find_shop'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'bring_cash', 'make_sure_money', 'find_wallet', 'go_supermarket', 'make_sure_enough_money']
senticnet['find_shower'] = [0.047, 0.148, 0, 0.107, '#interesting', '#admirable', 0.101, 'turn_water', 'shower', 'take_clothes_off', 'draw_water', 'water_soap']
senticnet['find_solution'] = [0.691, -0.505, 0, 0.882, '#joyful', '#admirable', 0.693, 'receive_information', 'learn_oneself', 'share_knowledge', 'exchange_idea', 'share_information']
senticnet['find_solution_to_problem'] = [0.527, 0.659, -0.249, 0.258, '#joyful', '#interesting', 0.398, 'expertise', 'aware', 'understand_problem', 'solve_problem', 'solution']
senticnet['find_someone_to_play_with'] = [0.611, -0.752, 0, 0.942, '#surprising', '#admirable', 0.768, 'find_other_player', 'bounce', 'know_how_play_baseball', 'throw', 'find_play']
senticnet['find_store'] = [0.061, -0.049, 0, 0, '#joyful', '#surprising', 0.037, 'go_supermarket', 'find_shop', 'go_burger_king', 'go_grocery_store', 'drive_to_store']
senticnet['find_suburb'] = [-0.038, 0.14, 0, 0.208, '#interesting', '#admirable', 0.103, 'make_building', 'construction', 'build_structure', 'build_process', 'construct']
senticnet['find_subway'] = [0.155, 0.135, -0.056, 0.156, '#joyful', '#admirable', 0.13, 'joy', 'inanimate', 'wow', 'made_out_of_plastic', 'make_paper']
senticnet['find_subway_stop'] = [0.946, -0.787, 0, 0, '#joyful', '#surprising', 0.578, 'find_bank', 'kill_human_being', 'find_farm', 'slander', 'cremate']
senticnet['find_table'] = [0.801, 0, 0, 0.573, '#joyful', '#admirable', 0.458, 'keep_eye_open', 'clear_table', 'bend_over', 'order_menu', 'place_order']
senticnet['find_tape'] = [0, 0.108, 0, 0.202, '#interesting', '#admirable', 0.103, 'source_electricity', 'read_instruction_manual', 'switch', 'turn_television_set', 'recording']
senticnet['find_teacher'] = [-0.078, 0, 0, 0, '#sad', '#sad', -0.026, 'take_music_lesson', 'take_lesson', 'learn_read_music', 'class', 'look_up_word_in_dictionary']
senticnet['find_toilet'] = [0.993, -0.695, 0, 0.715, '#joyful', '#admirable', 0.801, 'find_restroom', 'throw_away_trash', 'full_bladder', 'serve_beer', 'unzip_pant']
senticnet['find_total'] = [-0.753, 0, -0.883, 0, '#sad', '#scared', -0.545, 'get_sum', 'get_total', 'add_two_numbers_together', 'add_number_together', 'find_number']
senticnet['find_treasure'] = [0.64, -0.579, 0, 0.838, '#joyful', '#admirable', 0.686, 'sand', 'salt', 'grain_sand', 'silica', 'sand_rock']
senticnet['find_truth'] = [0, -0.092, 0, 0.08, '#surprising', '#admirable', 0.057, 'examine', 'analyze', 'discover_truth', 'determine_truth', 'influence_public_decision']
senticnet['find_tv'] = [0.787, -0.55, 0, 0.784, '#joyful', '#admirable', 0.707, 'turn_television_set', 'turn_television', 'switch_tv', 'near_tv', 'buy_tv']
senticnet['find_upstairs'] = [-0.745, 0, -0.811, 0, '#sad', '#scared', -0.519, 'master_bedroom', 'mattress', 'sofa', 'bet', 'berth']
senticnet['find_victim'] = [-0.078, -0.007, 0, -0.212, '#sad', '#disgusting', -0.094, 'buy_gun', 'dangerous_weapon', 'sharp_weapon', 'weapon', 'nuclear_weapon']
senticnet['find_wallet'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'bring_cash', 'money_bank', 'find_shop', 'go_supermarket', 'make_sure_enough_money']
senticnet['find_want'] = [-0.081, -0.022, -0.052, 0, '#sad', '#scared', -0.037, 'pay_toll', 'get_fast', 'travel_car', 'drive_quickly', 'access']
senticnet['find_way'] = [0.7, -0.646, 0, 0.953, '#joyful', '#admirable', 0.766, 'travel', 'compass', 'good_orientation', 'compass_direction', 'use_compass']
senticnet['find_woman'] = [-0.919, 0, -0.976, 0, '#sad', '#scared', -0.632, 'love_oneself', 'show_empathy', 'become_aroused', 'care_deeply', 'say_welcome']
senticnet['find_wood'] = [0, -0.035, -0.055, -0.069, '#scared', '#disgusting', -0.03, 'find_campsite', 'burn_house', 'cause_fire', 'die_out', 'extinguish']
senticnet['fine'] = [0.042, 0.338, -0.219, 0.232, '#interesting', '#admirable', 0.131, 'bribe', 'divorce_money', 'charity', 'reward', 'due']
senticnet['fine_art'] = [0.099, -0.073, -0.081, 0.195, '#joyful', '#admirable', 0.095, 'art', 'exhibit', 'craft', 'artefact', 'artwork']
senticnet['fine_dining'] = [0.7, -0.646, 0, 0.953, '#joyful', '#admirable', 0.766, 'ferment_grape_juice', 'chef_special', 'cuisine', 'bottle_wine', 'decanter']
senticnet['fine_grain'] = [-0.051, 0.07, 0, 0.062, '#interesting', '#admirable', 0.027, 'salty', 'grainy', 'powder', 'granulate', 'food_flavor']
senticnet['fine_person'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'close_case', 'arrest_criminal', 'tell_truth', 'question_witness', 'stop_crime']
senticnet['fine_violator'] = [-0.081, 0.179, -0.06, 0.096, '#interesting', '#admirable', 0.045, 'stop_suspect', 'traffic_police', 'traffic_jam', 'stop_crime', 'direct_traffic']
senticnet['fine_wine'] = [0.331, 0.119, 0.022, 0.229, '#joyful', '#admirable', 0.219, 'spice_life', 'red_light_district', 'fresh_produce', 'enough_food', 'knowledgeable']
senticnet['fineness'] = [0.757, -0.827, 0, 0.982, '#surprising', '#admirable', 0.855, 'first_class', 'choiceness', 'first_water', 'superiority', 'quality']
senticnet['finery'] = [-0.684, 0, 0.947, -0.951, '#angry', '#disgusting', -0.861, 'attire', 'sportswear', 'athletic_wear', 'activewear', 'costume']
senticnet['finesse'] = [0.594, -0.603, 0, 0.813, '#surprising', '#admirable', 0.67, 'considerateness', 'delicacy', 'thoughtfulness', 'consideration', 'tact']
senticnet['finger'] = [0.978, 0, 0, 0.721, '#joyful', '#admirable', 0.566, 'cylindrical_shape', 'cylindric', 'thumb', 'five_digits', 'cylinder']
senticnet['finger_action'] = [0, 0.149, 0.015, 0.194, '#interesting', '#admirable', 0.109, 'reason_why', 'punctuation', 'geometric_object', 'indicate', 'sport_score']
senticnet['finger_crossed'] = [-0.081, 0.179, -0.06, 0.096, '#interesting', '#admirable', 0.045, 'gamble', 'trying_luck', 'spend_money', 'hope', 'buy_lottery_ticket']
senticnet['finger_paint'] = [0.899, 0, 0, 0.952, '#joyful', '#admirable', 0.617, 'play_on_grass', 'become_adult', 'play_hide_seek', 'play_paint', 'like_boy']
senticnet['fingermark'] = [-0.877, 0, 0.5, -0.904, '#sad', '#disgusting', -0.76, 'smear', 'smudge', 'blot', 'daub', 'smirch']
senticnet['finish'] = [0, 0.202, -0.071, 0.169, '#interesting', '#admirable', 0.1, 'finish_complete', 'end', 'omega', 'end_point', 'last']
senticnet['finish-meal'] = [0.757, 0, 0, 0, '#joyful', '#joyful', 0.252, 'delicious_food', 'hunger_go_away', 'feel_satisfied', 'full_stomach', 'feel_full']
senticnet['finish_book'] = [0.331, 0.119, 0.022, 0.229, '#joyful', '#admirable', 0.219, 'finish', 'book', 'read_new_book', 'writer', 'finish_work']
senticnet['finish_college'] = [0.882, 0.768, 0, 0, '#joyful', '#interesting', 0.55, 'gain_qualification', 'get_high_education', 'serious_student', 'college_degree', 'college_student']
senticnet['finish_complete'] = [0.043, 0.219, -0.066, 0.238, '#interesting', '#admirable', 0.145, 'end', 'end_point', 'mission_accomplished', 'omega', 'finish']
senticnet['finish_job'] = [0.078, 0, 0, 0, '#joyful', '#joyful', 0.026, 'tip_waiter', 'put_food_table', 'eat_food', 'buy_food', 'buy_sandwich']
senticnet['finish_line'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'encounter', 'run_event', 'run_fast', 'gone', 'race']
senticnet['finish_school'] = [0.882, 0.768, 0, 0, '#joyful', '#interesting', 0.55, 'have_something_to_do', 'career_advancement', 'get_high_education', 'learn_skill', 'keep_job']
senticnet['finish_sleep'] = [-0.064, -0.041, 0.039, -0.063, '#sad', '#disgusting', -0.042, 'sleep_early', 'wake_up_early', 'go_bed_early', 'set_alarm_clock', 'shut_off_alarm_clock']
senticnet['finish_stress_moment'] = [0.101, -0.237, 0.031, 0.105, '#surprising', '#admirable', 0.137, 'temporary', 'end_day', 'finish_work', 'end_soon', 'end']
senticnet['finish_task'] = [0.979, 0.892, 0, 0, '#joyful', '#interesting', 0.624, 'arrive_work', 'make_offer', 'buy_stock', 'lose_sleep', 'get_work_done']
senticnet['finish_test'] = [-0.161, 0, 0, -0.079, '#sad', '#disgusting', -0.08, 'solve_equation', 'borrow_book_from_library', 'guess_answer', 'love_pet', 'master_skill']
senticnet['finish_work'] = [0.96, 0, 0, 0.915, '#joyful', '#admirable', 0.625, 'move_furniture', 'earn_paycheck', 'pay_child_support', 'work_hard', 'get_job_done']
senticnet['finished'] = [0, 0, 0, 0.819, '#admirable', '#admirable', 0.273, 'complete_task', 'complete_job', 'concluded', 'accomplished', 'completed']
senticnet['finisher'] = [-0.922, 0, 0.767, -0.85, '#sad', '#disgusting', -0.846, 'closer', 'relief_pitcher', 'pitcher', 'hurler', 'twirler']
senticnet['finite'] = [0.981, 0, 0, 0.758, '#joyful', '#admirable', 0.58, 'bounded', 'limited', 'finite_state_machine', 'wall', 'boundary']
senticnet['finite_state_machine'] = [0.964, 0, 0, 0.968, '#joyful', '#admirable', 0.644, 'computer', 'limited', 'finite', 'machine', 'mathematical_model']
senticnet['fink'] = [-0.672, 0, 0.546, -0.633, '#sad', '#disgusting', -0.617, 'betrayer', 'snitch', 'snitcher', 'sneak', 'stoolpigeon']
senticnet['fire'] = [0.038, 0, -0.079, -0.061, '#scared', '#disgusting', -0.034, 'huge_fire', 'rapid_oxidation', 'flame', 'cinder', 'heat_light']
senticnet['fire_blight'] = [-0.883, 0, 0.954, -0.875, '#sad', '#angry', -0.904, 'needle_blight', 'needle_cast', 'leaf_cast', 'blight', 'leaf_blight']
senticnet['fire_bullet'] = [-0.754, 0, 0, -0.912, '#sad', '#disgusting', -0.555, 'shoot', 'murder_weapon', 'kill', 'shoot_person', 'choose_victim']
senticnet['fire_burn'] = [0.849, 0.923, 0, 0, '#joyful', '#interesting', 0.591, 'burn_heat', 'really_hot', 'hot', 'ashes', 'flame']
senticnet['fire_employee'] = [-0.809, 0, 0, -0.965, '#sad', '#disgusting', -0.591, 'receive_punishment', 'market_product', 'ship_goods', 'turn_away', 'arm_oneself']
senticnet['fire_engine'] = [0, 0, 0.019, -0.086, '#angry', '#disgusting', -0.035, 'fire_truck', 'hardhat', 'stop_sign', 'maroon', 'tangerine']
senticnet['fire_extinguisher'] = [0.864, -0.983, 0, 0, '#joyful', '#surprising', 0.616, 'fire_hydrant', 'stair_rail', 'christian_fundamentalist', 'extinguisher', 'reception_desk']
senticnet['fire_gun'] = [-0.075, -0.029, -0.047, -0.179, '#sad', '#disgusting', -0.091, 'shoot_gun', 'shoot', 'fire_weapon', 'use_war', 'lethal']
senticnet['fire_hazard'] = [0.039, 0, 0, 0.052, '#joyful', '#admirable', 0.03, 'hot_air', 'liquid_gas', 'type_of_engine', 'warm_air', 'fire_starter']
senticnet['fire_hydrant'] = [0, 0, 0.027, -0.044, '#angry', '#disgusting', -0.024, 'fire_engine', 'stop_sign', 'street_sign', 'streetlight', 'fire_truck']
senticnet['fire_light'] = [0, -0.02, -0.069, -0.171, '#scared', '#disgusting', -0.073, 'forest_fire', 'fall_sky', 'dynamite_explosion', 'firebomb', 'killer']
senticnet['fire_product'] = [0, 0, -0.112, -0.124, '#scared', '#disgusting', -0.079, 'scald', 'inferno', 'bright_flash', 'arson', 'high_temperature']
senticnet['fire_shotgun'] = [-0.716, 0, 0, -0.941, '#sad', '#disgusting', -0.552, 'kill_person', 'stab_to_death', 'kill', 'kill_pest', 'socialist']
senticnet['fire_starter'] = [0, 0, 0, 0.073, '#admirable', '#admirable', 0.024, 'solid_fuel', 'organic_substance', 'renewable_resource', 'use_fuel', 'tree_product']
senticnet['fire_truck'] = [0, 0, 0.027, -0.044, '#angry', '#disgusting', -0.024, 'fire_engine', 'fire_hydrant', 'stop_fire', 'emergency', 'stop_sign']
senticnet['fire_up'] = [0.796, 0.769, 0, 0, '#joyful', '#interesting', 0.522, 'instigate', 'incite', 'inflame', 'stir_up', 'sensational']
senticnet['fire_up_grill'] = [0.073, 0.102, 0, 0.151, '#interesting', '#admirable', 0.109, 'nutritious', 'delicious', 'yummy', 'good_eat', 'tasty']
senticnet['fire_weapon'] = [-0.143, -0.046, -0.113, -0.219, '#sad', '#disgusting', -0.143, 'bloodshed', 'use_gun', 'plan_attack', 'use_weapon', 'fire_gun']
senticnet['firearm'] = [-0.761, 0, 0, -0.992, '#sad', '#disgusting', -0.584, 'handgun', 'rifle', 'weapon', 'pistol', 'gun']
senticnet['firebomb'] = [0, 0, -0.739, -0.715, '#scared', '#disgusting', -0.485, 'bomb', 'nuclear_weapon', 'explosive', 'nuclear_bomb', 'aerial_bomb']
senticnet['firebrick'] = [0.962, -0.703, 0, 0.522, '#joyful', '#surprising', 0.729, 'adobe', 'adobe_brick', 'clinker', 'clinker_brick', 'brick']
senticnet['firebug'] = [-0.894, 0, 0.672, -0.699, '#sad', '#disgusting', -0.755, 'criminal', 'outlaw', 'malefactor', 'felon', 'crook']
senticnet['fired'] = [-0.955, 0, 0.164, -0.975, '#sad', '#disgusting', -0.698, 'terminate_someone_employment', 'unemployed', 'become_poor', 'need_money', 'need_new_job']
senticnet['firefighter'] = [0.701, 0.874, 0, 0.752, '#interesting', '#admirable', 0.776, 'save_life', 'brave', 'fireman', 'strong', 'uniform']
senticnet['firefly'] = [0, 0, -0.872, 0, '#scared', '#scared', -0.291, 'beetle', 'many_insects', 'grasshopper', 'scorpion', 'mouse']
senticnet['fireman'] = [0.031, 0, -0.13, -0.081, '#scared', '#disgusting', -0.06, 'surgeon', 'connoisseur', 'physician', 'policeman', 'medical_doctor']
senticnet['fireplace'] = [0.091, 0, 0.034, 0.049, '#joyful', '#admirable', 0.035, 'furnace', 'flame', 'huge_fire', 'fire', 'heater']
senticnet['firestorm'] = [0.957, -0.788, 0, 0.658, '#joyful', '#surprising', 0.801, 'arguing', 'dispute', 'fight', 'conflict', 'polemic']
senticnet['firetruck'] = [0.073, 0.097, -0.059, -0.031, '#joyful', '#interesting', 0.027, 'newspaper_stand', 'jet_fuel', 'ticket_counter', 'aircraft_roadway', 'luggage_carrier']
senticnet['firewater'] = [0.679, -0.512, 0, 0.502, '#joyful', '#surprising', 0.564, 'liquor', 'spirits', 'booze', 'hard_drink', 'hard_liquor']
senticnet['firewood'] = [0.053, -0.093, 0, 0, '#joyful', '#surprising', 0.049, 'timber', 'mantle', 'stump', 'kindle', 'lumber']
senticnet['firework'] = [0.919, 0.758, 0, 0, '#joyful', '#interesting', 0.559, 'dynamite_explosion', 'nuclear_bomb', 'bomb', 'nuclear_weapon', 'atomic_bomb']
senticnet['firm'] = [0.978, 0, 0, 0.746, '#joyful', '#admirable', 0.575, 'large_business', 'business_firm', 'business_organization', 'business_group', 'partnership']
senticnet['firmness'] = [-0.975, 0, 0.549, -0.978, '#sad', '#disgusting', -0.834, 'adamance', 'resolve', 'resoluteness', 'adamance_of_purpose', 'resolution']
senticnet['firmness_of_purpose'] = [0.528, -0.542, 0, 0.956, '#surprising', '#admirable', 0.675, 'willpower', 'will_power', 'decisiveness', 'trait', 'steadiness']
senticnet['first'] = [0.082, 0.191, 0, 0.198, '#interesting', '#admirable', 0.157, 'both_word', 'imperial', 'greatness', 'nobleman', 'magnitude']
senticnet['first-aid_kit'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'first_aid_kit', 'medicine', 'medicine_chest', 'painkiller', 'surgeon']
senticnet['first_aid_kit'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'first-aid_kit', 'dentist_office', 'medicine_chest', 'painkiller', 'toothbrush']
senticnet['first_class'] = [0.721, 0.847, 0, 0, '#joyful', '#interesting', 0.523, 'cost_money', 'shopping', 'travel_across_world', 'spending', 'run_out_fuel']
senticnet['first_class_airplane_seat'] = [0.919, -0.845, 0, 0, '#joyful', '#surprising', 0.588, 'expensive', 'snack_bar', 'airplane_seat', 'sofa_bed', 'spend_money']
senticnet['first_class_train_seat'] = [0.953, -0.718, 0, 0, '#joyful', '#surprising', 0.557, 'expensive', 'snack_bar', 'train_seat', 'sofa_bed', 'spend_money']
senticnet['first_floor'] = [0.039, -0.033, 0, 0, '#joyful', '#surprising', 0.024, 'lower_floor', 'floor', 'ground_floor', 'hallway', 'level_one']
senticnet['first_rate'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'top', 'top_class', 'top_notch', 'premium', 'high_class']
senticnet['first_water'] = [0.757, -0.827, 0, 0.982, '#surprising', '#admirable', 0.855, 'first_class', 'choiceness', 'superiority', 'fineness', 'quality']
senticnet['fish'] = [-0.049, 0.184, -0.085, 0.172, '#interesting', '#admirable', 0.074, 'big_fish', 'animal', 'big_animal', 'big_cat', 'big']
senticnet['fish_boat'] = [-0.048, -0.01, 0, -0.068, '#sad', '#disgusting', -0.035, 'sailboat', 'sail_ship', 'battleship', 'oil_tanker', 'lifeboat']
senticnet['fish_bowl'] = [-0.519, 0, 0.562, -0.699, '#angry', '#disgusting', -0.593, 'fishbowl', 'bowl', 'goldbowl', 'jorum', 'mazer']
senticnet['fish_compliment'] = [-0.738, 0, -0.998, 0, '#sad', '#scared', -0.579, 'fish_trout', 'fish_stream', 'fish_lake', 'forward_email', 'deal_card_player']
senticnet['fish_equipment'] = [0.079, -0.107, 0.046, 0, '#joyful', '#surprising', 0.047, 'fish_rod', 'fish_hook', 'fish_pole', 'bait', 'coral']
senticnet['fish_farm'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'food', 'farm', 'milk_product', 'food_ingredient', 'food_production']
senticnet['fish_food'] = [-0.093, 0, -0.067, 0, '#sad', '#scared', -0.053, 'eat_peach', 'eat_table', 'machine_part', 'eat_pasta', 'bicycle_across_town']
senticnet['fish_hook'] = [0.079, -0.107, 0.046, 0, '#joyful', '#surprising', 0.047, 'fish_rod', 'fish_equipment', 'fish_pole', 'bait', 'coral']
senticnet['fish_lake'] = [0, 0, -0.86, -0.702, '#scared', '#disgusting', -0.521, 'fish_trout', 'catch_butterfly', 'sea_bass', 'fish_compliment', 'fish_stream']
senticnet['fish_market'] = [0, 0, -0.065, -0.036, '#scared', '#disgusting', -0.034, 'coral_reef', 'saltwater', 'tidal_pool', 'sushi_restaurant', 'reef']
senticnet['fish_pole'] = [0.079, -0.107, 0.046, 0, '#joyful', '#surprising', 0.047, 'fish_rod', 'fish_equipment', 'fish_hook', 'bait', 'coral']
senticnet['fish_rod'] = [0.079, -0.107, 0.046, 0, '#joyful', '#surprising', 0.047, 'fish_hook', 'fish_equipment', 'fish_pole', 'bait', 'coral']
senticnet['fish_species'] = [0.565, -0.697, 0, 0.787, '#surprising', '#admirable', 0.683, 'species', 'saratoga', 'spotted_barramundi', 'spotted_bonytongue', 'northern_barramundi']
senticnet['fish_stream'] = [0.079, -0.107, 0.046, 0, '#joyful', '#surprising', 0.047, 'fish_trout', 'catch_fish', 'fish', 'fish_compliment', 'fish_lake']
senticnet['fish_tackle'] = [-0.936, 0, -0.897, 0, '#sad', '#scared', -0.611, 'fish_lake', 'land_fish', 'catch_fish', 'fish', 'fish_rod']
senticnet['fish_trout'] = [-0.086, 0, -0.061, 0, '#sad', '#scared', -0.049, 'fish_compliment', 'fish_stream', 'fish_lake', 'catch_butterfly', 'sail_around_world']
senticnet['fishbowl'] = [-0.519, 0, 0.562, -0.699, '#angry', '#disgusting', -0.593, 'bowl', 'fish_bowl', 'goldfish_bowl', 'jorum', 'mazer']
senticnet['fisherman'] = [0.073, -0.022, 0, 0, '#joyful', '#surprising', 0.032, 'angler', 'informal_rod', 'archaic_fisher', 'rare_piscator', 'fishing_line']
senticnet['fishing'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'catch_fish_rod', 'catch_fish', 'patience', 'fish_lake', 'bait']
senticnet['fishing_line'] = [0.073, -0.022, 0, 0, '#joyful', '#surprising', 0.032, 'fisherman', 'informal_rod', 'archaic_fisher', 'rare_piscator', 'angler']
senticnet['fishing_rod'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'catch_fish', 'fishing', 'patience', 'fish_lake', 'bait']
senticnet['fission'] = [-0.778, 0, 0.764, -0.548, '#sad', '#angry', -0.697, 'pullulation', 'apomixis', 'blastogenesis', 'budding', 'asexual_reproduction']
senticnet['fist'] = [-0.066, 0.068, -0.089, -0.074, '#scared', '#disgusting', -0.054, 'oppose', 'whack', 'rudeness', 'make_oppose', 'hand']
senticnet['fit'] = [0.867, 0, 0, 0.88, '#joyful', '#admirable', 0.582, 'lose_weight', 'stay_fit', 'like_exercise', 'shape', 'weight_loss']
senticnet['fit_bill'] = [0.545, -0.509, 0, 0.591, '#joyful', '#admirable', 0.548, 'meet', 'satisfy', 'fulfill', 'conform_to', 'fitting']
senticnet['fit_clothes'] = [0.172, 0, 0.051, 0.175, '#joyful', '#admirable', 0.099, 'much_energy', 'look_good', 'look_attractive', 'live_healthy_life', 'improve_look']
senticnet['fit_person'] = [0, 0, 0, 0.97, '#admirable', '#admirable', 0.323, 'increase_strength', 'keep_fit', 'professional_athlete', 'exercise', 'strengthen_heart']
senticnet['fit_room'] = [0, 0.144, -0.091, 0.196, '#interesting', '#admirable', 0.083, 'changing_room', 'clothes_store_change_room', 'dress_room', 'clothes_shelf', 'garment_bag']
senticnet['fitfulness'] = [-0.897, 0, 0.972, -0.502, '#sad', '#angry', -0.79, 'unsteadiness', 'haphazardness', 'stochasticity', 'variability', 'unregularity']
senticnet['fitness'] = [0.603, -0.778, 0, 0.641, '#surprising', '#admirable', 0.674, 'suitability', 'suitableness', 'habitability', 'habitableness', 'qualification']
senticnet['fitted_out'] = [0.073, -0.022, 0, 0, '#joyful', '#surprising', 0.032, 'precooked', 'equipped', 'prepared', 'embattled', 'spread']
senticnet['fitter'] = [0.698, -0.547, 0, 0.995, '#joyful', '#admirable', 0.747, 'better_cardiovascular_health', 'increase_stamina', 'weight_loss', 'increased_heart_rate', 'become_fit']
senticnet['fitting'] = [0.509, -0.74, 0, 0.899, '#surprising', '#admirable', 0.716, 'improvement', 'betterment', 'habituation', 'domestication', 'shakedown']
senticnet['fitting_room'] = [0.031, -0.028, 0.048, -0.113, '#angry', '#disgusting', -0.034, 'changing_room', 'room', 'dress_room', 'shoulder_bag', 'neckwear']
senticnet['fittingness'] = [0.534, -0.866, 0, 0.676, '#surprising', '#admirable', 0.692, 'suitability', 'suitableness', 'habitability', 'habitableness', 'qualification']
senticnet['five_digits'] = [0, 0.763, 0, 0.892, '#interesting', '#admirable', 0.552, 'five_fingers', 'palm', 'arm_part', 'wear_glove', 'five_fingers_hand']
senticnet['five_fingers'] = [0.754, 0.903, 0, 0, '#joyful', '#interesting', 0.552, 'hand', 'two_hands', 'forearm', 'ten_fingers', 'wrist']
senticnet['five_fingers_hand'] = [0, 0.102, 0, 0, '#interesting', '#interesting', 0.034, 'two_arms', 'adam_apple', 'two_ears', 'belly_button', 'liver']
senticnet['five_senses'] = [0.028, 0.139, -0.075, 0.222, '#interesting', '#admirable', 0.105, 'human_sense', 'sense', 'humanity', 'bad_odor', 'sensory_input']
senticnet['fix'] = [-0.959, 0, 0.721, -0.75, '#sad', '#disgusting', -0.81, 'cook_up', 'ready', 'make', 'cook', 'prepare']
senticnet['fix_breakfast'] = [-0.081, -0.004, 0, -0.042, '#sad', '#disgusting', -0.04, 'love_animal', 'salt_food', 'prepare_breakfast', 'bone_chicken', 'set_table']
senticnet['fix_car'] = [0, 0, -0.078, 0, '#scared', '#scared', -0.026, 'spend_money', 'lorry', 'mechanic', 'engineer', 'repair_shop']
senticnet['fix_computer'] = [-0.025, -0.013, 0.062, 0, '#sad', '#angry', -0.025, 'design_software', 'write_program', 'sell_new_book', 'go_off_strike', 'begin_work']
senticnet['fix_dinner'] = [0.754, 0.903, 0, 0, '#joyful', '#interesting', 0.552, 'steak', 'feel_hunger', 'need_grocery', 'cook', 'famine']
senticnet['fix_flat_tire'] = [-0.1, 0, -0.11, 0, '#sad', '#scared', -0.07, 'change_tire', 'wear_sunglasses', 'tired', 'exhausting', 'flat_tire']
senticnet['fix_hair'] = [0.787, 0, 0, 0.904, '#joyful', '#admirable', 0.564, 'make_hair_look_nice', 'comb_hair', 'arrange_hair', 'groom_hair', 'style_hair']
senticnet['fix_panel'] = [0.073, -0.022, 0, 0, '#joyful', '#surprising', 0.032, 'garage', 'garbage_dump', 'bicycle_shop', 'tool', 'repair_shop']
senticnet['fix_problem'] = [0.84, 0.76, 0, 0.894, '#joyful', '#admirable', 0.831, 'keep_skin_healthy', 'stay_healthy', 'maintain_good_health', 'do_exercise', 'eat_healthily']
senticnet['fixed'] = [-0.905, 0, 0.653, -0.998, '#sad', '#disgusting', -0.852, 'unalterable', 'static', 'changeless', 'confirmed', 'unchangeable']
senticnet['fixed_phagocyte'] = [0.702, -0.524, 0, 0.958, '#joyful', '#admirable', 0.728, 'somatic_cell', 'vegetative_cell', 'phagocyte', 'macrophage', 'free_phagocyte']
senticnet['fixity'] = [-0.819, 0, 0.921, -0.803, '#sad', '#angry', -0.848, 'immovability', 'unchanging', 'lodgment', 'permanent', 'lodging']
senticnet['fixture'] = [0.079, 0.071, 0, 0.183, '#joyful', '#admirable', 0.111, 'house_open', 'computer_operative_system', 'aperture', 'rectangular_shape', 'open_close']
senticnet['fizzy'] = [0.071, 0, 0, 0, '#joyful', '#joyful', 0.024, 'alcoholic_drink', 'alcoholic_beverage', 'strong_drink', 'popular_soda', 'ferment_beverage']
senticnet['flab'] = [-0.427, -0.14, -0.069, -0.372, '#sad', '#disgusting', -0.243, 'brain_tumor', 'bad_hair_day', 'lyme_disease', 'diarrhoea', 'suffer_fool']
senticnet['flabbergasted'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'surprise', 'baffle', 'stupefy', 'dumbfound', 'stupefaction']
senticnet['flag'] = [0.053, 0.068, -0.052, 0.06, '#interesting', '#admirable', 0.043, 'linen', 'star_stripe', 'velvet', 'nation', 'burlap']
senticnet['flag_officer'] = [0.688, -0.908, 0, 0.877, '#surprising', '#admirable', 0.824, 'fleet_admiral', 'rear_admiral', 'admiral', 'full_admiral', 'vice_admiral']
senticnet['flag_smut_fungus'] = [-0.935, 0, 0.699, -0.91, '#sad', '#disgusting', -0.848, 'onion_smut', 'head_smut', 'stinking_smut', 'smut_fungus', 'covered_smut']
senticnet['flag_waving'] = [0.68, -0.962, 0, 0.597, '#joyful', '#surprising', 0.746, 'demagoguery', 'jingoism', 'appeal', 'prayer', 'entreaty']
senticnet['flagellate'] = [0.807, -0.868, 0, 0.611, '#joyful', '#surprising', 0.762, 'costia', 'zoomastigote', 'zooflagellate', 'dinoflagellate', 'hypermastigote']
senticnet['flagellate_protozoan'] = [0.995, -0.711, 0, 0.647, '#joyful', '#surprising', 0.784, 'costia', 'zoomastigote', 'zooflagellate', 'dinoflagellate', 'hypermastigote']
senticnet['flagellated_protozoan'] = [0.509, -0.9, 0, 0.507, '#joyful', '#surprising', 0.639, 'costia', 'zoomastigote', 'zooflagellate', 'dinoflagellate', 'hypermastigote']
senticnet['flagrant'] = [0, 0, 0.72, -0.985, '#angry', '#disgusting', -0.568, 'glaring', 'rank', 'egregious', 'crying', 'gross']
senticnet['flair'] = [0.608, -0.55, 0, 0.726, '#joyful', '#admirable', 0.628, 'genius', 'raw_talent', 'endowment', 'knack', 'talent']
senticnet['flaky'] = [0, -0.949, 0, 0.938, '#surprising', '#admirable', 0.629, 'freaky', 'outlandish', 'off-the-wall', 'bizarre', 'gonzo']
senticnet['flamboyant'] = [0, -1.0, 0, 0.766, '#surprising', '#admirable', 0.589, 'splashy', 'royal_poinciana', 'florid', 'showy', 'aureate']
senticnet['flame'] = [-0.925, 0, -0.843, 0, '#sad', '#scared', -0.589, 'huge_fire', 'rapid_oxidation', 'fire', 'cinder', 'heat_light']
senticnet['flaming'] = [-0.904, 0, 0.825, -0.61, '#sad', '#angry', -0.78, 'combustion', 'deflagration', 'fire', 'flame', 'internal_combustion']
senticnet['flammable'] = [-0.969, 0, -0.723, 0, '#sad', '#scared', -0.564, 'flame', 'combustible', 'dangerous', 'incendiary', 'heat']
senticnet['flap'] = [-0.585, 0, 0.715, -0.597, '#angry', '#disgusting', -0.632, 'fly', 'overlap', 'barndoor', 'coattail', 'codpiece']
senticnet['flap_wing'] = [-0.031, -0.02, 0.043, -0.042, '#angry', '#disgusting', -0.032, 'wing_insect', 'aviation', 'fly', 'wing_animal', 'wing_creature']
senticnet['flare'] = [0, 0, -0.769, -0.845, '#scared', '#disgusting', -0.538, 'sword', 'firebomb', 'nuclear_bomb', 'projectile', 'revolver']
senticnet['flare_path'] = [-0.975, 0, 0.737, -0.979, '#sad', '#disgusting', -0.897, 'airstrip', 'airfield', 'landing_field', 'flying_field', 'field']
senticnet['flash'] = [-0.663, 0, 0.616, -0.708, '#sad', '#disgusting', -0.662, 'flicker', 'coruscation', 'streak', 'glint', 'gleam']
senticnet['flash_card'] = [-0.031, 0.086, 0.01, 0.091, '#interesting', '#admirable', 0.045, 'write_term_paper', 'take_exam', 'take_final', 'take_examination', 'take_midterm']
senticnet['flash_light'] = [-0.034, -0.022, -0.113, -0.083, '#scared', '#disgusting', -0.069, 'firebomb', 'fire_light', 'master_control', 'flare', 'torch']
senticnet['flashlight'] = [0, -0.039, 0.043, -0.113, '#angry', '#disgusting', -0.039, 'torch', 'safety_pin', 'laser', 'flare', 'firebomb']
senticnet['flashy'] = [0, 0, 0.952, -0.775, '#angry', '#disgusting', -0.576, 'meretricious', 'showy', 'gaudy', 'tatty', 'brassy']
senticnet['flask'] = [0.619, -0.834, 0, 0.912, '#surprising', '#admirable', 0.788, 'hipflask', 'pocket_flask', 'ampulla', 'canteen', 'vacuum_flask']
senticnet['flat'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'bucket_overflow', 'dirty_floor', 'spill_over', 'float', 'spoil_wood_floor']
senticnet['flat_fish'] = [0.077, 0.097, 0, 0.116, '#interesting', '#admirable', 0.097, 'far_away', 'small_earth', 'location', 'fish', 'around_earth']
senticnet['flat_foot'] = [-0.512, 0, 0.781, -0.851, '#angry', '#disgusting', -0.715, 'swamp', 'boring', 'flat_tire', 'flatness', 'small_breast']
senticnet['flat_land'] = [0.022, 0.069, 0.027, 0.059, '#interesting', '#admirable', 0.041, 'open_land', 'grassy', 'terrain', 'open_space', 'land']
senticnet['flat_object'] = [0.022, 0.069, 0.027, 0.059, '#interesting', '#admirable', 0.041, 'perfect_surface', 'flat_land', 'flat_surface', 'crockery', 'plate']
senticnet['flat_surface'] = [0.022, 0.069, 0.027, 0.059, '#interesting', '#admirable', 0.041, 'perfect_surface', 'flat_object', 'flat_land', 'flat', 'floor']
senticnet['flat_thin'] = [0.053, 0, 0.025, 0.118, '#joyful', '#admirable', 0.049, 'paper_square', 'flat', 'part_of_book', 'floor', 'book_part']
senticnet['flat_tire'] = [-0.102, -0.072, 0.032, -0.153, '#sad', '#disgusting', -0.072, 'crash_tree', 'press_accelerator', 'stop_traffic_light', 'enjoy_view', 'get_to_another_place']
senticnet['flat_tyre'] = [-0.512, 0, 0.781, -0.851, '#angry', '#disgusting', -0.715, 'engine_issue', 'broken_car', 'broken_engine', 'broken_shelf', 'need_fix']
senticnet['flatness'] = [-0.797, 0, 0.715, 0, '#sad', '#angry', -0.504, 'swamp', 'boring', 'flat_tire', 'flat_foot', 'small_breast']
senticnet['flats'] = [0, -0.069, 0, 0, '#surprising', '#surprising', 0.023, 'rooms', 'home', 'furnitures', 'kitchen', 'apartment']
senticnet['flatter'] = [0.17, 0, 0.081, 0.184, '#joyful', '#admirable', 0.091, 'food_holder', 'food_server', 'flat_object', 'flattery', 'round_flat']
senticnet['flattery'] = [0.134, 0.1, -0.112, 0.246, '#joyful', '#admirable', 0.123, 'empathize', 'lovely', 'good_look', 'amiable', 'exchange_gift']
senticnet['flatulence'] = [-0.033, 0, -0.113, 0, '#sad', '#scared', -0.049, 'inhale_air', 'dig_up', 'breaair', 'pour_water', 'breathe']
senticnet['flatulent'] = [-0.774, 0, 0.671, -0.807, '#sad', '#disgusting', -0.751, 'indigestible', 'nondigestible', 'undigested', 'stodgy', 'heavy']
senticnet['flatworm'] = [0.688, -0.942, 0, 0.925, '#surprising', '#admirable', 0.852, 'trematode', 'platyhelminth', 'liver_fluke', 'schistosome', 'blood_fluke']
senticnet['flavor'] = [0.054, 0.068, 0, 0.074, '#interesting', '#admirable', 0.065, 'eat_food', 'sweetness', 'food_flavor', 'eatable', 'tasty']
senticnet['flavor_food'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'cook', 'food_item', 'flavor', 'food', 'good_food']
senticnet['flavorer'] = [-0.866, 0, 0.982, -0.867, '#angry', '#disgusting', -0.905, 'seasoned_salt', 'flavourer', 'flavoring', 'flavouring', 'seasoner']
senticnet['flavorful'] = [0.043, 0.091, 0, 0.113, '#interesting', '#admirable', 0.082, 'sweet_sour', 'food_item', 'yummy', 'popular_food', 'form_of_food']
senticnet['flavoring'] = [-0.866, 0, 0.982, -0.867, '#angry', '#disgusting', -0.905, 'flavorer', 'flavourer', 'seasoned_salt', 'flavouring', 'seasoner']
senticnet['flavorless'] = [-0.717, 0, 0.559, -0.957, '#sad', '#disgusting', -0.744, 'unseasoned', 'unsalted', 'tasteless', 'flavourless', 'savorless']
senticnet['flavorsomeness'] = [-0.797, 0, 0.992, -0.884, '#angry', '#disgusting', -0.891, 'appetizingness', 'flavoursomeness', 'savoriness', 'succulence', 'succulency']
senticnet['flavourer'] = [-0.866, 0, 0.982, -0.867, '#angry', '#disgusting', -0.905, 'flavorer', 'seasoned_salt', 'flavoring', 'flavouring', 'seasoner']
senticnet['flavouring'] = [-0.866, 0, 0.982, -0.867, '#angry', '#disgusting', -0.905, 'flavorer', 'flavourer', 'flavoring', 'seasoned_salt', 'seasoner']
senticnet['flavourless'] = [-0.717, 0, 0.559, -0.957, '#sad', '#disgusting', -0.744, 'unseasoned', 'unsalted', 'flavorless', 'tasteless', 'savorless']
senticnet['flavoursomeness'] = [-0.797, 0, 0.992, -0.884, '#angry', '#disgusting', -0.891, 'flavorsomeness', 'appetizingness', 'savoriness', 'succulence', 'succulency']
senticnet['flaw'] = [-0.076, 0.075, -0.179, 0, '#sad', '#scared', -0.06, 'protect_family', 'no_choice', 'protect_oneself', 'expire', 'kill_self']
senticnet['flawlessness'] = [-0.712, 0, 0.606, -0.793, '#sad', '#disgusting', -0.704, 'finish', 'culture', 'dream', 'state', 'cultivation']
senticnet['flax_rust'] = [-0.512, 0, 0.781, -0.851, '#angry', '#disgusting', -0.715, 'rust_fungus', 'rust', 'blister_rust', 'apple_rust', 'fungus']
senticnet['flax_rust_fungus'] = [-0.512, 0, 0.781, -0.851, '#angry', '#disgusting', -0.715, 'flax_rust', 'rust_fungus', 'blister_rust', 'apple_rust', 'fungus']
senticnet['flea'] = [0, -0.093, 0.131, -0.117, '#angry', '#disgusting', -0.052, 'gnat', 'mosquito', 'mole_cricket', 'gypsy_moth', 'cucumber_beetle']
senticnet['flea_bite'] = [-0.647, 0, 0.625, -0.882, '#sad', '#disgusting', -0.718, 'difficulty', 'awkwardness', 'troublesomeness', 'difficultness', 'cumbersomeness']
senticnet['flea_market'] = [0.06, 0.067, 0, -0.054, '#joyful', '#interesting', 0.024, 'water_fountain', 'winery', 'brewery', 'load_dock', 'wish_well']
senticnet['fleck'] = [-0.583, 0, 0.561, -0.622, '#sad', '#disgusting', -0.589, 'spot', 'speckle', 'dapple', 'patch', 'worn_spot']
senticnet['flection'] = [-0.76, 0, 0.969, -0.554, '#sad', '#angry', -0.761, 'variant', 'deviation', 'flexion', 'discrepancy', 'variation']
senticnet['fledgeling'] = [0.824, -0.973, 0, 0.833, '#surprising', '#admirable', 0.877, 'recruit', 'enlistee', 'novice', 'beginner', 'tyro']
senticnet['fledgling'] = [0.776, -0.554, 0, 0.883, '#joyful', '#admirable', 0.738, 'recruit', 'enlistee', 'novice', 'beginner', 'tyro']
senticnet['flee'] = [-0.055, 0.142, -0.065, 0.261, '#interesting', '#admirable', 0.094, 'movement', 'pace', 'quick_motion', 'fast', 'go_forward']
senticnet['fleece'] = [0.731, 0, 0, 0.974, '#joyful', '#admirable', 0.568, 'cotton', 'silk', 'wool', 'cotton_boll', 'plant']
senticnet['fleer'] = [-0.599, 0, 0.875, -0.941, '#angry', '#disgusting', -0.805, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['fleet'] = [0, 0.927, 0, 0.838, '#interesting', '#admirable', 0.588, 'military', 'ship', 'war', 'cannon', 'pirate']
senticnet['fleet_admiral'] = [0.688, -0.908, 0, 0.877, '#surprising', '#admirable', 0.824, 'flag_officer', 'rear_admiral', 'admiral', 'full_admiral', 'vice_admiral']
senticnet['flesh'] = [0, 0, -0.044, -0.045, '#scared', '#disgusting', -0.03, 'inside_body', 'dog_treat', 'body', 'live_meat', 'skeleton']
senticnet['fleshiness'] = [-0.847, 0, 0.707, -0.997, '#sad', '#disgusting', -0.85, 'exogenous_obesity', 'blubber', 'fat', 'embonpoint', 'stoutness']
senticnet['flexibility'] = [0, 0.838, 0, 0.863, '#interesting', '#admirable', 0.567, 'elasticity', 'elastic', 'stretch', 'touch_toe', 'elongate']
senticnet['flexible'] = [0, 0.066, 0.041, 0.109, '#interesting', '#admirable', 0.045, 'skin_cover', 'often_red', 'rigid', 'human_organ', 'different_shape']
senticnet['flexibleness'] = [0.64, -0.95, 0, 0.639, '#joyful', '#surprising', 0.743, 'pliability', 'whip', 'bendability', 'malleability', 'plasticity']
senticnet['flexion'] = [-0.76, 0, 0.969, -0.554, '#sad', '#angry', -0.761, 'variant', 'flection', 'deviation', 'discrepancy', 'variation']
senticnet['flexure'] = [0.601, -0.879, 0, 0.5, '#joyful', '#surprising', 0.66, 'fold', 'crease', 'plication', 'crimp', 'angular_shape']
senticnet['flibbertigibbet'] = [0.806, -0.708, 0, 0.687, '#joyful', '#surprising', 0.734, 'saphead', 'muggins', 'tomfool', 'fool', 'sap']
senticnet['flick'] = [-0.859, 0, 0.514, -0.739, '#sad', '#disgusting', -0.704, 'cinema_verite', 'movie', 'film', 'picture', 'moving_picture']
senticnet['flicker'] = [0.075, -0.187, -0.067, 0.138, '#surprising', '#admirable', 0.111, 'burn_heat', 'fire_burn', 'really_hot', 'char', 'hot']
senticnet['flickering'] = [0, 0, 0.78, -0.831, '#angry', '#disgusting', -0.537, 'aflicker', 'quiver', 'flitter', 'flutter', 'waver']
senticnet['flight'] = [0, 0.984, 0, 0.729, '#interesting', '#admirable', 0.571, 'atmosphere', 'wings', 'nest', 'feather', 'bird_fly']
senticnet['flight_accident'] = [-0.987, 0, 0.989, -0.933, '#sad', '#angry', -0.97, 'air_traffic', 'dangerous', 'danger', 'traffic', 'traffic_jam']
senticnet['flight_strip'] = [-0.571, 0, 0.575, -0.897, '#angry', '#disgusting', -0.681, 'flare_path', 'airfield', 'landing_field', 'flying_field', 'field']
senticnet['flight_terminal'] = [0, 0.977, 0, 0.726, '#interesting', '#admirable', 0.568, 'semi-truck', 'traffic_artery', 'aircraft_roadway', 'taxi', 'taxiway']
senticnet['flightless_bird'] = [-0.681, 0, 0.956, -0.909, '#angry', '#disgusting', -0.849, 'giant_moa', 'anomalopteryx', 'ratite', 'ratite_bird', 'moa']
senticnet['flighty'] = [0.963, -0.987, 0, 0.514, '#joyful', '#surprising', 0.821, 'warm', 'excitable', 'nervous', 'skittish', 'spooky']
senticnet['flimsy'] = [-0.083, 0, -0.111, 0, '#sad', '#scared', -0.065, 'fragile', 'brittle', 'frail', 'easy_to_break', 'breakable']
senticnet['flip'] = [-0.03, 0.11, 0, 0.128, '#interesting', '#admirable', 0.069, 'freestyle', 'take_leak', 'jump_air', 'backstroke', 'go_underwater']
senticnet['flip_coin'] = [-0.088, 0, 0, 0, '#sad', '#sad', -0.029, 'win_case', 'hire_attorney', 'win', 'judge_decide', 'try_win']
senticnet['flip_flop'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'shoe', 'moccasin', 'footwear', 'shoe_type', 'slipper']
senticnet['flipper'] = [-0.202, -0.108, 0.07, -0.245, '#sad', '#disgusting', -0.136, 'gill', 'sea_life', 'seafood', 'swim_animal', 'fillet']
senticnet['flipside'] = [-0.112, 0.184, -0.131, 0.157, '#interesting', '#admirable', 0.033, 'rear', 'go_backwards', 'rear_end', 'backside', 'exception']
senticnet['flirt'] = [0.03, -0.027, 0, 0.095, '#joyful', '#admirable', 0.051, 'love_another', 'meet_girl', 'love_else', 'comfort_friend', 'forgive']
senticnet['flirtation'] = [0.741, -0.898, 0, 0.509, '#joyful', '#surprising', 0.716, 'frolic', 'gambol', 'romp', 'play', 'caper']
senticnet['flirting'] = [0.755, -0.591, 0, 0.566, '#joyful', '#surprising', 0.637, 'frolic', 'gambol', 'romp', 'play', 'caper']
senticnet['flitch'] = [0.648, -0.539, 0, 0.94, '#joyful', '#admirable', 0.709, 'bacon_strip', 'bacon', 'side_of_bacon', 'gammon', 'cut_of_pork']
senticnet['float'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'flat', 'dirty_floor', 'spill_over', 'bucket_overflow', 'spoil_wood_floor']
senticnet['float_through_air'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'balloon', 'hot-air_balloon', 'air', 'float', 'luna_park']
senticnet['floater'] = [-0.817, 0, 0.747, -0.886, '#sad', '#disgusting', -0.817, 'vagrant', 'drifter', 'hobo', 'vagabond', 'dosser']
senticnet['floating'] = [-0.699, 0, 0.695, -0.716, '#sad', '#disgusting', -0.703, 'unfirm', 'unsteady', 'detached', 'free', 'unfixed']
senticnet['flogging'] = [-0.845, 0, 0.557, -0.796, '#sad', '#disgusting', -0.733, 'corporal_punishment', 'lashing', 'whipping', 'tanning', 'whacking']
senticnet['flood'] = [0, -0.754, -0.989, -0.887, '#scared', '#disgusting', -0.374, 'tornado', 'bright_flash', 'forest_fire', 'wash_mouth_soap', 'dynamite_explosion']
senticnet['flood_tide'] = [-0.905, 0, 0.05, -0.96, '#sad', '#disgusting', -0.638, 'destroy', 'break', 'ruin', 'kill_person', 'destroy_city']
senticnet['flooding'] = [0.542, -0.63, 0, 0.912, '#surprising', '#admirable', 0.695, 'implosion_therapy', 'behavior_modification', 'reciprocal_inhibition', 'aversion_therapy', 'desensitization_technique']
senticnet['floodlight'] = [-0.034, 0.133, -0.071, 0.214, '#interesting', '#admirable', 0.081, 'projector', 'spotlight', 'headlight', 'light', 'teach_lesson']
senticnet['floor'] = [0, 0.82, 0, 0.863, '#interesting', '#admirable', 0.561, 'rug', 'carpet', 'mat', 'thick_hair', 'floor_cover']
senticnet['floor_cover'] = [-0.037, -0.008, 0.066, 0, '#sad', '#angry', -0.032, 'cover_floor', 'dirt_floor', 'floor', 'mat', 'underfoot']
senticnet['floorboard'] = [0, -0.039, 0.076, -0.061, '#angry', '#disgusting', -0.033, 'old_sock', 'gay_person', 'dirty_magazine', 'bikini', 'storage_item']
senticnet['floppy'] = [0.78, 0.987, 0, 0, '#joyful', '#interesting', 0.589, 'small_round', 'sugary', 'delicious', 'eatable', 'creamy']
senticnet['floppy_disk'] = [0, 0.916, 0, 0.71, '#interesting', '#admirable', 0.542, 'rotary_file', 'cd-rom', 'database', 'business_card', 'calendar_book']
senticnet['flora'] = [-0.92, 0, 0.74, -0.762, '#sad', '#disgusting', -0.807, 'bush', 'browse', 'scrub', 'groundcover', 'ground_cover']
senticnet['floral'] = [0.06, 0.191, -0.069, 0.213, '#interesting', '#admirable', 0.132, 'design', 'create_form', 'wall_decoration', 'blueprint', 'craft']
senticnet['floss'] = [-0.056, 0, 0, -0.122, '#sad', '#disgusting', -0.059, 'plane_land', 'station_wagon', 'floss_tooth', 'ornament', 'wear_dress']
senticnet['floss_tooth'] = [-0.086, 0, -0.046, 0, '#sad', '#scared', -0.044, 'set_clock', 'read_bedtime_story', 'speak_english', 'sell_car', 'erase_blackboard']
senticnet['flour'] = [0.033, 0, 0.013, 0.064, '#joyful', '#admirable', 0.028, 'yeast', 'dough', 'crust', 'sweetness', 'staple_food']
senticnet['flour_water'] = [0, 0, -0.889, -0.771, '#scared', '#disgusting', -0.553, 'sticky_substance', 'slice', 'water', 'adhesive', 'goo']
senticnet['flourish'] = [0, 0.126, -0.049, 0.187, '#interesting', '#admirable', 0.088, 'get_big', 'enlarge', 'plant_big', 'get_large', 'make_big']
senticnet['flourishing'] = [0.98, -0.746, 0, 0.984, '#joyful', '#admirable', 0.903, 'prosperous', 'successful', 'palmy', 'prospering', 'thriving']
senticnet['flout'] = [-0.863, 0, 0.897, -0.813, '#sad', '#angry', -0.858, 'disregard', 'ignore', 'brush_off', 'push_aside', 'dismiss']
senticnet['flow'] = [0.037, 0.161, -0.154, 0.203, '#interesting', '#admirable', 0.082, 'wave', 'farewell', 'salute', 'multiple_purposes', 'wave_wind']
senticnet['flow_lake'] = [0, 0.068, 0, 0.142, '#interesting', '#admirable', 0.07, 'water_stream', 'water_formation', 'small_stream', 'water_flow', 'nile']
senticnet['flower'] = [0.027, 0.093, 0.025, 0.071, '#interesting', '#admirable', 0.055, 'a_lot_of_flowers', 'love', 'show_love', 'rose', 'give_a_lot_of_flowers']
senticnet['flower_arrangement'] = [0, 0.106, -0.051, 0.079, '#interesting', '#admirable', 0.045, 'ware', 'merchandise', 'capitalist', 'sell', 'gift_wrap']
senticnet['flower_bloom'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'flower', 'enjoy_nature', 'pick_flower', 'flower_plant', 'tree']
senticnet['flower_garden'] = [0.206, 0.093, 0.049, 0.143, '#joyful', '#admirable', 0.131, 'garden', 'flower', 'flower_bloom', 'enjoy_nature', 'flower_plant']
senticnet['flower_girl'] = [0.947, 0, 0, 0.773, '#joyful', '#admirable', 0.573, 'bride', 'girl', 'marry', 'wedding', 'propose']
senticnet['flower_people'] = [0.52, -0.911, 0, 0.65, '#surprising', '#admirable', 0.694, 'youth_subculture', 'hippies', 'hipsters', 'beat_generation', 'beats']
senticnet['flower_plant'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'flower', 'fruit_plant', 'garden', 'green_plant', 'flower_bloom']
senticnet['flower_shop'] = [0.206, 0.093, 0.049, 0.143, '#joyful', '#admirable', 0.131, 'buy_flower', 'flower', 'shop', 'flower_bloom', 'flower_plant']
senticnet['flower_spring'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'flower', 'spring', 'flower_bloom', 'flower_plant', 'pick_flower']
senticnet['flower_type'] = [0.087, 0.127, -0.076, 0.123, '#interesting', '#admirable', 0.087, 'sign_love', 'symbol_love', 'rise_plant', 'yellow_flower', 'flower']
senticnet['flowing'] = [-0.798, 0, 0.59, -0.567, '#sad', '#angry', -0.652, 'debris_surge', 'debris_storm', 'surge', 'onrush', 'flow']
senticnet['flowing_water'] = [0, 0.788, 0, 0.704, '#interesting', '#admirable', 0.497, 'water_flow', 'small_stream', 'water_stream', 'water_movement', 'water_passage']
senticnet['flu'] = [0, 0, -0.71, -0.722, '#scared', '#disgusting', -0.477, 'terminal_illness', 'high_fever', 'ill_health', 'influenza', 'ridiculous']
senticnet['flub'] = [-0.797, 0, 0.722, -0.897, '#sad', '#disgusting', -0.805, 'bobble', 'error', 'misstep', 'fumble', 'stumble']
senticnet['flue'] = [0.023, 0, -0.077, -0.087, '#scared', '#disgusting', -0.047, 'cinder', 'lighter', 'smoke_pipe', 'flame', 'fire']
senticnet['fluff'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'fluffy_white', 'white', 'pillow', 'mattress', 'silky']
senticnet['fluffy'] = [0.135, 0.122, 0, 0.089, '#joyful', '#interesting', 0.115, 'hot_sun', 'good_weather', 'striped', 'no_sun', 'sunny_day']
senticnet['fluffy_animal'] = [0.206, 0.093, 0.049, 0.143, '#joyful', '#admirable', 0.131, 'animal_hair', 'animal_skin', 'dog_fur', 'animal_fur', 'furry']
senticnet['fluffy_white'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'fluff', 'white', 'pillow', 'mattress', 'silky']
senticnet['fluid'] = [0.04, 0.088, 0, 0.091, '#interesting', '#admirable', 0.073, 'liquid', 'liquid_substance', 'potable_liquid', 'crystalline_solid', 'sip']
senticnet['flummox'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'confuse', 'baffle', 'stupefy', 'dumbfounded', 'stupefaction']
senticnet['flunk'] = [-0.222, -0.004, -0.096, -0.037, '#sad', '#scared', -0.117, 'failure', 'bad_grade', 'a_lot_of_stress', 'fail', 'further_goal']
senticnet['flunkey'] = [-0.851, 0, 0.938, -0.879, '#angry', '#disgusting', -0.889, 'menial', 'lackey', 'flunky', 'servant', 'familiar']
senticnet['flunky'] = [-0.851, 0, 0.938, -0.879, '#angry', '#disgusting', -0.889, 'menial', 'lackey', 'servant', 'flunkey', 'familiar']
senticnet['fluoride_mouthwash'] = [0.206, 0.093, 0.049, 0.143, '#joyful', '#admirable', 0.131, 'disinfectant', 'fluoride_toothpaste', 'mouthwash', 'toothpaste', 'dental_floss']
senticnet['fluoride_toothpaste'] = [0.206, 0.093, 0.049, 0.143, '#joyful', '#admirable', 0.131, 'fluoride_mouthwash', 'disinfectant', 'mouthwash', 'dental_floss', 'toothpaste']
senticnet['flurry'] = [-0.923, 0, 0, -0.929, '#sad', '#disgusting', -0.617, 'put_off', 'confusedly', 'disordered', 'discombobulation', 'confused']
senticnet['flush'] = [0.648, 0.618, -0.262, 0.332, '#joyful', '#interesting', 0.445, 'exhilarate', 'teased', 'titillating', 'titillate', 'titillation']
senticnet['flush_toilet'] = [0.778, -0.932, 0, 0.578, '#joyful', '#surprising', 0.763, 'flushless_toilet', 'commode', 'lavatory', 'potty_seat', 'potty_chair']
senticnet['flushless_toilet'] = [0.778, -0.932, 0, 0.578, '#joyful', '#surprising', 0.763, 'commode', 'flush_toilet', 'lavatory', 'potty_seat', 'potty_chair']
senticnet['fluster'] = [0, 0, 0.768, -0.962, '#angry', '#disgusting', -0.577, 'unsettle', 'discomfit', 'discompose', 'faze', 'upset']
senticnet['flute'] = [0.821, -0.531, 0, 0.785, '#joyful', '#admirable', 0.712, 'fife', 'nose_flute', 'piccolo', 'woodwind', 'woodwind_instrument']
senticnet['fly'] = [0, -0.095, 0.107, -0.1, '#angry', '#disgusting', -0.037, 'six_legs', 'mosquito', 'japanese_beetle', 'mole_cricket', 'gypsy_moth']
senticnet['fly_airplane'] = [-0.047, -0.014, 0, -0.062, '#sad', '#disgusting', -0.032, 'take_bus', 'go_drive', 'move_car', 'drive_to_work', 'drive_car']
senticnet['fly_animal'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'fly_insect', 'beautiful_creature', 'insect', 'animal', 'bird']
senticnet['fly_around'] = [-0.094, 0, -0.06, 0, '#sad', '#scared', -0.051, 'shovel_snow', 'smoke_joint', 'blow_away', 'mine_gold', 'sit_floor']
senticnet['fly_away'] = [-0.047, -0.051, 0.114, -0.108, '#angry', '#disgusting', -0.073, 'parasite', 'small_bug', 'annoy_bug', 'nuisance_insect', 'small_insect']
senticnet['fly_balloon'] = [0.088, 0.149, 0, 0.107, '#interesting', '#admirable', 0.115, 'kite', 'childhood', 'play_frisbee', 'fly_kite', 'enjoy_outdoors']
senticnet['fly_fish'] = [-0.048, 0, -0.052, 0, '#sad', '#scared', -0.033, 'coral', 'fish_equipment', 'small_fish', 'aquatic_life', 'sunken_treasure']
senticnet['fly_helicopter'] = [-0.081, 0, 0, -0.065, '#sad', '#disgusting', -0.049, 'journey_far', 'rain_parade', 'land_plane', 'drop_bomb', 'free_bird']
senticnet['fly_high'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'prosper', 'succeed', 'realize', 'enthusiam', 'thrive']
senticnet['fly_insect'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'fly_animal', 'insect', 'mosquito', 'bug', 'bee']
senticnet['fly_kite'] = [0.088, 0.149, 0, 0.107, '#interesting', '#admirable', 0.115, 'kite', 'childhood', 'play_frisbee', 'fly_balloon', 'enjoy_outdoors']
senticnet['fly_plane'] = [-0.072, -0.026, 0, -0.077, '#sad', '#disgusting', -0.041, 'push_limit', 'travel_work', 'rush_work', 'get_stick_traffic', 'plan_day']
senticnet['fly_through_air'] = [0, 0, -0.058, -0.155, '#scared', '#disgusting', -0.071, 'sharpen_knife', 'bird', 'dark_alley', 'leave_table', 'fall_sky']
senticnet['flyblown'] = [-0.85, 0, 0.804, -0.855, '#sad', '#disgusting', -0.836, 'scarred', 'blemished', 'marred', 'acned', 'pimpled']
senticnet['flying_field'] = [-0.975, 0, 0.737, -0.979, '#sad', '#disgusting', -0.897, 'flare_path', 'airfield', 'landing_field', 'airstrip', 'field']
senticnet['foam'] = [0.085, -0.063, 0, 0, '#joyful', '#surprising', 0.049, 'soap', 'drizzle', 'bubbly', 'solid_water', 'ivory']
senticnet['fob'] = [-0.668, 0, 0.789, -0.631, '#sad', '#angry', -0.696, 'humbug', 'play_trick', 'cozen', 'pull_fast_one_on', 'play_trick_on']
senticnet['focal_point'] = [0.53, -0.649, 0, 0.76, '#surprising', '#admirable', 0.646, 'focus', 'get_focused', 'focusing', 'centering', 'particularism']
senticnet['focal_seizure'] = [0.947, -0.562, 0, 0.875, '#joyful', '#admirable', 0.795, 'convulsion', 'raptus', 'ictus', 'absence', 'absence_seizure']
senticnet['focus'] = [0.088, 0.149, 0, 0.107, '#interesting', '#admirable', 0.115, 'analyze', 'concentration', 'concentrate', 'study_hard', 'work_hard']
senticnet['focus_attention'] = [0, 0.835, 0, 0.841, '#interesting', '#admirable', 0.559, 'use_brain', 'think_hard', 'ponder', 'figure_out', 'reach_conclusion']
senticnet['focus_concentration'] = [0, 0.974, 0, 0.756, '#interesting', '#admirable', 0.577, 'remember_fact', 'ask_expert', 'research_topic', 'knowledge_subject', 'absorb_information']
senticnet['focus_light'] = [0.088, 0.149, 0, 0.107, '#interesting', '#admirable', 0.115, 'light', 'study', 'desk', 'drink_cup', 'read_book']
senticnet['focus_time'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'slow', 'long_focus', 'bad_camera', 'long_bad_camera', 'low_quality_photo']
senticnet['focused'] = [-0.762, 0, -0.733, 0, '#sad', '#scared', -0.498, 'concentrate', 'centre', 'focalise', 'sharpen', 'pore']
senticnet['focusing'] = [0.771, -0.621, 0, 0.886, '#joyful', '#admirable', 0.759, 'particularism', 'absorption', 'concentration', 'engrossment', 'immersion']
senticnet['foe'] = [-0.091, 0, -0.054, -0.248, '#sad', '#disgusting', -0.131, 'war', 'enemy', 'arsenal', 'big_fight', 'conflict']
senticnet['foetid'] = [-0.868, 0, 0.644, -0.886, '#sad', '#disgusting', -0.799, 'frowsty', 'fetid', 'malodorous', 'smelly', 'stinking']
senticnet['foetus'] = [0.922, -0.851, 0, 0.962, '#joyful', '#admirable', 0.912, 'teras', 'baby', 'monster', 'abortus', 'vertebrate']
senticnet['fog'] = [-0.091, 0, -0.054, -0.248, '#sad', '#disgusting', -0.131, 'smoke', 'smog', 'haze', 'mist', 'cloudy']
senticnet['foggy'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'hazy', 'blur', 'bleary', 'blurred', 'blurry']
senticnet['foible'] = [0.664, -0.903, 0, 0.788, '#surprising', '#admirable', 0.785, 'individualism', 'individuality', 'individuation', 'idiosyncrasy', 'distinctiveness']
senticnet['foil'] = [0.716, -0.791, 0, 0.543, '#joyful', '#surprising', 0.683, 'chaff', 'wrap', 'aluminium_foil', 'tin_foil', 'gold_foil']
senticnet['foiled'] = [-0.855, 0, 0.922, 0, '#sad', '#angry', -0.592, 'disappointed', 'defeatism', 'thwarted', 'frustrated', 'discomfited']
senticnet['fold'] = [-0.023, 0.095, 0, 0.117, '#interesting', '#admirable', 0.063, 'identification', 'paper_square', 'carry_money', 'money_hold', 'credit']
senticnet['fold_up'] = [0.283, 0.292, -0.109, 0.272, '#joyful', '#interesting', 0.246, 'fill_ink', 'hang_closet', 'make_out_metal', 'hold_garbage', 'display_item']
senticnet['folder'] = [0.038, 0, 0.01, 0.059, '#joyful', '#admirable', 0.029, 'paper_clip', 'eraser_holder', 'pencil_box', 'electric_pencil_sharpener', 'computer_desk']
senticnet['folderol'] = [0.739, -0.899, 0, 0.702, '#joyful', '#surprising', 0.78, 'pap', 'content', 'pablum', 'drivel', 'codswallop']
senticnet['folding'] = [0.592, -0.913, 0, 0.61, '#surprising', '#admirable', 0.705, 'change_of_shape', 'angulation', 'narrowing', 'elongation', 'fold']
senticnet['foliage'] = [0, 0.1, -0.061, 0.126, '#interesting', '#admirable', 0.055, 'plant_big', 'green_leave', 'green_growth', 'large_plant', 'plant_part']
senticnet['folie'] = [-0.525, 0, 0.839, -0.865, '#angry', '#disgusting', -0.743, 'encopresis', 'upset', 'psychosomatic_disorder', 'conversion_disorder', 'conversion_reaction']
senticnet['folie_deux'] = [-0.61, 0, 0.9, -0.563, '#sad', '#angry', -0.691, 'mental_disorder', 'mental_disturbance', 'psychological_disorder', 'folie', 'disturbance']
senticnet['foliolate'] = [-0.508, 0, 0.573, -0.893, '#angry', '#disgusting', -0.658, 'petallike', 'bowery', 'leafy', 'unifoliate', 'bifoliate']
senticnet['folk_dance'] = [-0.744, 0, 0.501, -0.99, '#sad', '#disgusting', -0.745, 'farandole', 'mazurka', 'polka', 'morris_dance', 'morris_dancing']
senticnet['folk_dancing'] = [-0.862, 0, 0.794, -0.865, '#sad', '#disgusting', -0.84, 'farandole', 'mazurka', 'polka', 'morris_dance', 'morris_dancing']
senticnet['folk_music'] = [0.949, 0, 0, 0.712, '#joyful', '#admirable', 0.554, 'play_jazz', 'lovely_music', 'play_in_band', 'produce_musical_sound', 'play_song']
senticnet['folklore'] = [0.95, -0.863, 0, 0.947, '#joyful', '#admirable', 0.92, 'content', 'old_wives_tale', 'lore', 'cognitive_content', 'mental_object']
senticnet['follicle'] = [0, 0, 0.076, -0.03, '#angry', '#disgusting', -0.035, 'cat_hair', 'achene', 'sepal', 'sleep_cat', 'cat']
senticnet['follow'] = [-0.036, 0.168, -0.077, 0.139, '#interesting', '#admirable', 0.065, 'command', 'direct', 'guide', 'take_charge', 'govern']
senticnet['follow_direction'] = [-0.044, -0.025, -0.09, -0.146, '#scared', '#disgusting', -0.085, 'brown_hamburger', 'heat_meal', 'burn_trash', 'heat_up', 'swim_lake']
senticnet['follow_instruction'] = [0.115, -0.039, 0, 0.437, '#joyful', '#admirable', 0.197, 'go_by_book', 'instruction', 'follow_rule', 'know_how', 'read_carefully']
senticnet['follow_mother'] = [0.788, 0.592, -0.207, 0.342, '#joyful', '#interesting', 0.505, 'head_home', 'laugh_clown', 'roll_ball', 'bicycle_school', 'thank_parent']
senticnet['follow_path'] = [-0.083, 0, 0.029, 0, '#sad', '#angry', -0.037, 'find_lake', 'stop_walk', 'put_shoes', 'use_leg', 'go_park']
senticnet['follow_person'] = [-0.111, 0, -0.047, 0, '#sad', '#scared', -0.053, 'cause_accident', 'stay_in_house', 'mark_territory', 'sense_fear', 'guide_blind']
senticnet['follow_recipe'] = [0.754, 0.903, 0, 0, '#joyful', '#interesting', 0.552, 'make_bread', 'cook_dinner', 'cook_meal', 'cook_lunch', 'bake_cake']
senticnet['follow_rule'] = [-0.068, 0, 0.071, -0.087, '#angry', '#disgusting', -0.075, 'strategize', 'win', 'learn_rule', 'act_smart', 'end_game']
senticnet['follow_rule_blindly'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'closed_minded', 'strict', 'inflexible', 'dumb', 'go_by_book']
senticnet['follower'] = [0.065, 0.17, -0.053, 0.143, '#interesting', '#admirable', 0.108, 'supervisor', 'native_american', 'ambassador', 'master', 'general']
senticnet['following'] = [-0.643, 0, 0.684, -0.717, '#angry', '#disgusting', -0.681, 'consecutive', 'postmortem', 'ensuing', 'succeeding', 'undermentioned']
senticnet['folly'] = [-0.144, -0.042, -0.17, -0.039, '#sad', '#scared', -0.104, 'work_together', 'experience_fear', 'stumble', 'cross_country_ski', 'tumble']
senticnet['foment'] = [-0.772, 0, 0.842, 0, '#sad', '#angry', -0.538, 'agitate', 'agitated', 'tumult', 'stir_up', 'earnestness']
senticnet['fond'] = [0.915, 0, 0, 0.772, '#joyful', '#admirable', 0.562, 'lovesome', 'affectionate', 'liking', 'loving', 'caring']
senticnet['fond_memory'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'book_story', 'bed', 'seduce', 'jewish_community', 'suburbs']
senticnet['fond_regard'] = [0.482, 0.676, -0.268, 0.265, '#joyful', '#interesting', 0.385, 'protectively', 'protectiveness', 'soft_spot', 'affectional', 'affectionateness']
senticnet['fondle'] = [0.879, -0.516, 0, 0.569, '#joyful', '#admirable', 0.655, 'pet', 'paw', 'nuzzle', 'pat', 'stroke']
senticnet['fondly'] = [0.494, 0.673, -0.269, 0.25, '#joyful', '#interesting', 0.383, 'adorably', 'loving', 'lovingly', 'endearingly', 'devotedness']
senticnet['fondness'] = [0.743, 0.961, 0, 0.932, '#interesting', '#admirable', 0.879, 'amorous', 'amative', 'amatory', 'amorousness', 'enamoredness']
senticnet['fondue'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'french_toast', 'gnocchi', 'soybean', 'result_cook', 'lasagna']
senticnet['font'] = [0, 0.723, 0, 0.884, '#interesting', '#admirable', 0.536, 'edition', 'headline', 'italic', 'print', 'bold']
senticnet['food'] = [0.04, 0, 0, 0.067, '#joyful', '#admirable', 0.036, 'cook', 'add_flavor', 'taste', 'ingredient', 'tongue']
senticnet['food_and_beverage'] = [0.53, -0.649, 0, 0.76, '#surprising', '#admirable', 0.646, 'drink_coffee', 'beverage', 'coffee_shop', 'kitchen', 'eat_dinner']
senticnet['food_bake'] = [0.067, -0.061, 0, 0.064, '#joyful', '#admirable', 0.064, 'bake_goods', 'pumpkin_pie', 'bakery_item', 'breakfast_food', 'loaf']
senticnet['food_container'] = [0.046, 0, 0.037, 0.085, '#joyful', '#admirable', 0.031, 'metal_container', 'storage_container', 'metal_cylinder', 'common_name', 'tin']
senticnet['food_display'] = [0.53, -0.649, 0, 0.76, '#surprising', '#admirable', 0.646, 'food_fridge', 'deli_case', 'cake', 'cafe', 'desert']
senticnet['food_drink'] = [0.14, -0.133, 0, 0, '#joyful', '#surprising', 0.091, 'junk_food', 'chocolate_pudding', 'pasta', 'liquid_food', 'unhealthy_food']
senticnet['food_flavor'] = [0.028, 0.069, 0, 0.085, '#interesting', '#admirable', 0.061, 'white_grain', 'white_powder', 'granulate', 'flavor', 'granular']
senticnet['food_fridge'] = [0.53, -0.649, 0, 0.76, '#surprising', '#admirable', 0.646, 'deli_case', 'food_display', 'cake', 'cafe', 'desert']
senticnet['food_grain'] = [0.061, 0.093, 0.037, 0.114, '#interesting', '#admirable', 0.077, 'whole_grain', 'food_ingredient', 'staple_food', 'starchy_food', 'cereal_grain']
senticnet['food_group'] = [0.028, 0.071, 0, 0.071, '#interesting', '#admirable', 0.057, 'farm_crop', 'food_type', 'starch', 'cereal_crop', 'staple_food']
senticnet['food_holder'] = [0.17, 0, 0.081, 0.184, '#joyful', '#admirable', 0.091, 'container', 'food_server', 'flat_object', 'food', 'round_flat']
senticnet['food_ingredient'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'starchy_food', 'ingredient', 'food', 'pasta', 'beef']
senticnet['food_item'] = [0.063, 0, 0.042, 0.074, '#joyful', '#admirable', 0.032, 'morning_food', 'type_of_food', 'sweet_treat', 'bake_product', 'dairy_product']
senticnet['food_place'] = [0.055, 0.094, 0.07, 0.162, '#interesting', '#admirable', 0.08, 'flat_object', 'food_server', 'food_holder', 'generic', 'flatter']
senticnet['food_poison'] = [0, 0, -0.889, -0.814, '#scared', '#disgusting', -0.568, 'hunger_go_away', 'no_long_hungry', 'become_little_hungry', 'tooth_hurt', 'get_full']
senticnet['food_poisoning'] = [-0.534, 0, 0.678, -0.73, '#angry', '#disgusting', -0.647, 'malady', 'mushroom_poisoning', 'botulism', 'ptomaine', 'ptomaine_poisoning']
senticnet['food_production'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'food', 'farm', 'milk_product', 'food_ingredient', 'fish_farm']
senticnet['food_scrap'] = [-0.952, 0, 0, -0.73, '#sad', '#disgusting', -0.561, 'waste_food', 'scrap', 'expired_food', 'garbage', 'rubbish']
senticnet['food_server'] = [0.17, 0, 0.081, 0.184, '#joyful', '#admirable', 0.091, 'waiter', 'flatter', 'serve_food', 'food', 'food_holder']
senticnet['food_shop'] = [0.146, 0.114, -0.058, 0.129, '#joyful', '#admirable', 0.11, 'supermarket', 'corner_grocery', 'food_store', 'buy_food', 'market']
senticnet['food_source'] = [0, 0.1, 0.048, 0.092, '#interesting', '#admirable', 0.048, 'edible_plant', 'wheat_rice', 'farm_plant', 'plant_food', 'cereal_crop']
senticnet['food_storage'] = [0.038, 0, 0, 0.089, '#joyful', '#admirable', 0.042, 'kitchen_ware', 'container', 'storage', 'pantry', 'own_kitchen']
senticnet['food_store'] = [0.146, 0.114, -0.058, 0.129, '#joyful', '#admirable', 0.11, 'supermarket', 'corner_grocery', 'food_shop', 'buy_food', 'market']
senticnet['food_type'] = [0, 0.774, 0, 0.812, '#interesting', '#admirable', 0.529, 'staple_food', 'cereal_crop', 'starch', 'granular', 'whole_grain']
senticnet['foodstuff'] = [0.055, 0, 0.028, 0.089, '#joyful', '#admirable', 0.039, 'starchy_food', 'whole_grain', 'staple_food', 'food_ingredient', 'food_item']
senticnet['fool'] = [-0.951, 0, 0, -0.7, '#sad', '#disgusting', -0.55, 'deceive', 'deception', 'trick', 'dare', 'risk']
senticnet['fool_around'] = [-0.952, 0, 0, -0.73, '#sad', '#disgusting', -0.561, 'waste_time', 'polygamy', 'one_night_stand', 'make_fun', 'cheat']
senticnet['fool_person'] = [0, 0, -0.856, -0.765, '#scared', '#disgusting', -0.54, 'fool', 'crazy_person', 'mad', 'foolish', 'stupid']
senticnet['foolery'] = [0.579, -0.582, 0, 0.99, '#surprising', '#admirable', 0.717, 'folly', 'lunacy', 'craziness', 'indulgence', 'mishegaas']
senticnet['foolhardiness'] = [0.828, -0.675, 0, 0.811, '#joyful', '#admirable', 0.771, 'adventurism', 'brashness', 'thoughtlessness', 'desperation', 'unthoughtfulness']
senticnet['foolish'] = [0, 0, 0.764, -0.934, '#angry', '#disgusting', -0.566, 'naughty', 'pollute_air', 'terminal_disease', 'ice_cream_melt', 'bad_luck']
senticnet['foolish_woman'] = [0.689, -0.831, 0, 0.919, '#surprising', '#admirable', 0.813, 'saphead', 'muggins', 'tomfool', 'fool', 'sap']
senticnet['foolishness'] = [0.702, -0.527, 0, 0.981, '#joyful', '#admirable', 0.737, 'injudiciousness', 'asininity', 'silliness', 'fatuity', 'fatuousness']
senticnet['foolproof'] = [0.855, 0, 0, 0.971, '#joyful', '#admirable', 0.609, 'inerrable', 'flawless', 'unfailing', 'reliable', 'sure']
senticnet['foot'] = [0, 0.078, 0.027, 0.196, '#interesting', '#admirable', 0.082, 'heel', 'ankle', 'toe', 'foot_massage', 'nail']
senticnet['foot_action'] = [-0.059, 0.085, 0.02, 0.185, '#interesting', '#admirable', 0.064, 'stride', 'foot_motion', 'foot_movement', 'pace', 'anagram']
senticnet['foot_hurt'] = [-0.701, 0, 0.8, 0, '#sad', '#angry', -0.5, 'leg_tire', 'feel_tired', 'get_tired', 'get_tired_leg', 'sore_leg']
senticnet['foot_massage'] = [0.53, -0.649, 0, 0.76, '#surprising', '#admirable', 0.646, 'heel', 'ankle', 'toe', 'foot', 'nail']
senticnet['foot_motion'] = [0, 0.078, 0.027, 0.196, '#interesting', '#admirable', 0.082, 'foot_movement', 'foot_action', 'pace', 'stride', 'move_foot']
senticnet['foot_movement'] = [0, 0.929, 0, 0.71, '#interesting', '#admirable', 0.546, 'foot_motion', 'move_foot', 'stride', 'foot_action', 'pace']
senticnet['foot_part'] = [0, 0.744, 0, 0.987, '#interesting', '#admirable', 0.577, 'sole', 'type_of_shoes', 'foot', 'twelve_inch', 'heel']
senticnet['foot_tired'] = [-0.096, -0.1, 0.134, -0.229, '#angry', '#disgusting', -0.12, 'get_tired', 'sore_foot', 'become_tired', 'traveling_destination', 'tired_leg']
senticnet['football'] = [0.748, 0.925, 0, 0, '#joyful', '#interesting', 0.558, 'ball', 'bounce', 'ball_bounce', 'soccer', 'play_football']
senticnet['football_coach'] = [-0.032, 0, 0.044, 0, '#sad', '#angry', -0.025, 'child', 'football', 'little_child', 'two_children', 'youth']
senticnet['football_field'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'sport_activity', 'rugby_field', 'field', 'play_football', 'play_sport']
senticnet['football_game'] = [0, 0.978, 0, 0.882, '#interesting', '#admirable', 0.62, 'game', 'beach_house', 'gym_locker', 'football', 'football_stadium']
senticnet['football_highlight'] = [0.53, -0.649, 0, 0.76, '#surprising', '#admirable', 0.646, 'best_moment', 'sport_highlight', 'highlight', 'television_news', 'put_in_evidence']
senticnet['football_play'] = [-0.074, 0.12, -0.068, 0.235, '#interesting', '#admirable', 0.071, 'go_ahead', 'pace', 'foot_action', 'flee', 'stride']
senticnet['football_play_ground'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'stadium', 'sport_event', 'sport_arena', 'play_football', 'football_stadium']
senticnet['football_player'] = [0.053, -0.025, 0, 0, '#joyful', '#surprising', 0.026, 'quarterback', 'manager', 'scrabble', 'card_type', 'contest']
senticnet['football_rule'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'obstruct_justice', 'obstruction', 'block_road', 'hinder', 'interfere']
senticnet['football_stadium'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'stadium', 'sport_event', 'sport_arena', 'play_football', 'football_play_ground']
senticnet['football_team'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'play_football', 'football_stadium', 'football_play_ground', 'football_player', 'football']
senticnet['footprint'] = [0, -0.106, -0.058, 0.076, '#surprising', '#admirable', 0.041, 'mine', 'dirt', 'compost', 'coal_mine', 'soil']
senticnet['footstep'] = [0, 0.757, 0, 0.817, '#interesting', '#admirable', 0.525, 'walker', 'foot', 'wander', 'heel', 'sneaker']
senticnet['footwear'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'clothes', 'high_heel', 'leg_wear', 'shoe', 'shoe_type']
senticnet['for_all'] = [0.138, 0.134, -0.066, 0.151, '#joyful', '#admirable', 0.119, 'sip', 'gulp', 'better_cold', 'potable_liquid', 'liquid_beverage']
senticnet['for_sure'] = [-0.718, 0, 0.785, -0.558, '#sad', '#angry', -0.687, 'unimpeachable', 'acknowledged', 'unquestionable', 'mathematical', 'beyond_doubt']
senticnet['forage'] = [0, 0, -0.903, -0.99, '#scared', '#disgusting', -0.631, 'foraging', 'pasture', 'grass', 'eatage', 'scrounge']
senticnet['foray'] = [0.954, -0.87, 0, 0.583, '#joyful', '#surprising', 0.802, 'penetration', 'air_raid', 'air_attack', 'swoop', 'incursion']
senticnet['foray_into'] = [-0.935, 0, 0.77, -0.666, '#sad', '#angry', -0.79, 'raid', 'come_in', 'encroach_upon', 'enter', 'get_into']
senticnet['forbearance'] = [0.543, -0.678, 0, 0.553, '#surprising', '#admirable', 0.591, 'longanimity', 'patience', 'good_will', 'good_nature', 'grace']
senticnet['forbid'] = [-0.703, 0, 0.791, 0, '#sad', '#angry', -0.498, 'bar', 'debar', 'criminalize', 'outlaw', 'ban']
senticnet['forbidden_fruit'] = [-0.935, 0, 0.77, -0.666, '#sad', '#angry', -0.79, 'enticement', 'allurement', 'hook', 'sweetener', 'influence']
senticnet['force'] = [0, 0, -1, -1, '#scared', '#disgusting', -0.667, 'moon_gravity', 'coercion', 'volt', 'watt', 'power_source']
senticnet['force_enter'] = [-0.931, 0, 0.945, -0.932, '#angry', '#disgusting', -0.936, 'break_into_house', 'break_window_shop', 'accident', 'robbery', 'break_door']
senticnet['force_other_person'] = [-0.101, 0, -0.059, -0.064, '#sad', '#disgusting', -0.075, 'money', 'down_payment', 'take_out_loan', 'find_money', 'find_bug']
senticnet['force_out'] = [-0.83, 0, 0.965, -0.845, '#angry', '#disgusting', -0.88, 'out', 'sacrifice', 'force', 'putout', 'force_play']
senticnet['force_per_unit_area'] = [-0.623, 0, 0.901, -0.715, '#angry', '#disgusting', -0.746, 'pressure', 'hypertonicity', 'hypotonicity', 'pressure_level', 'osmotic_pressure']
senticnet['force_play'] = [-0.83, 0, 0.965, -0.845, '#angry', '#disgusting', -0.88, 'out', 'sacrifice', 'force', 'force_out', 'putout']
senticnet['force_unit'] = [-0.641, 0, 0.678, -0.705, '#angry', '#disgusting', -0.675, 'pound', 'dyne', 'newton', 'sthene', 'poundal']
senticnet['forced'] = [-0.526, 0, 0.857, -0.754, '#angry', '#disgusting', -0.712, 'unwilling', 'unconscious', 'unwilled', 'driven', 'nonvoluntary']
senticnet['forced_removal'] = [0, 0, 0.975, -0.839, '#angry', '#disgusting', -0.605, 'dismissal', 'discharge', 'elimination', 'destitution', 'removal']
senticnet['forceful'] = [0, 0.741, 0, 0.828, '#interesting', '#admirable', 0.523, 'strong', 'powerful', 'energy', 'dynamic', 'vigorous']
senticnet['forcefulness'] = [-0.929, 0, 0.946, -0.567, '#sad', '#angry', -0.814, 'brunt', 'intensiveness', 'impulse', 'vigor', 'energy']
senticnet['forceps'] = [-0.031, 0, -0.217, -0.089, '#scared', '#disgusting', -0.112, 'nurse', 'cure', 'doctor', 'medicine', 'physician']
senticnet['ford'] = [0.049, 0.139, -0.09, 0.123, '#interesting', '#admirable', 0.074, 'guard', 'safety', 'insurance', 'policy', 'protect_home']
senticnet['ford_river'] = [0, 0, 0, 0.099, '#admirable', '#admirable', 0.033, 'waterway', 'water_passage', 'long_road', 'water_flow', 'highway_road']
senticnet['forearm'] = [0.754, 0.903, 0, 0, '#joyful', '#interesting', 0.552, 'hand', 'two_hands', 'five_fingers', 'ten_fingers', 'wrist']
senticnet['foreboding'] = [-0.823, 0, -0.733, 0, '#sad', '#scared', -0.519, 'boding', 'premonition', 'presentiment', 'presage', 'timorous']
senticnet['forecast'] = [0.814, 0.773, 0, 0, '#joyful', '#interesting', 0.529, 'rain_check', 'check_weather', 'weather_control_weather', 'control_weather', 'weather']
senticnet['foreclose'] = [0.704, -0.557, 0, 0.96, '#joyful', '#admirable', 0.74, 'save', 'foil', 'spoil', 'frustrate', 'stymie']
senticnet['foregoing'] = [-0.569, 0, 0.954, -0.804, '#angry', '#disgusting', -0.776, 'previous', 'above', 'old', 'preceding', 'introductory']
senticnet['foregone_conclusion'] = [-0.571, 0, 0.713, -0.649, '#angry', '#disgusting', -0.644, 'sure_thing', 'predictability', 'certainty', 'determinateness', 'definiteness']
senticnet['forehead'] = [0, 0.905, 0, 0.785, '#interesting', '#admirable', 0.563, 'lymph', 'exoskeleton', 'breast_pocket', 'toward', 'squint']
senticnet['foreign'] = [-0.521, 0, 0.783, -0.975, '#angry', '#disgusting', -0.76, 'international', 'abroad', 'overseas', 'external', 'outside']
senticnet['foreign_country'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'holiday', 'new_life', 'new_job', 'discover_world', 'travel']
senticnet['foreigner'] = [-0.575, 0, 0.803, -0.772, '#angry', '#disgusting', -0.717, 'au_pair', 'exile', 'deportee', 'gringo', 'import']
senticnet['foreignness'] = [-0.864, 0, 0.941, -0.622, '#sad', '#angry', -0.809, 'alienage', 'alienism', 'exoticism', 'exoticness', 'exotism']
senticnet['foreknowledge'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'predict_future', 'psychic_phenomenon', 'parapsychology', 'precognition', 'clairvoyance']
senticnet['foreordain'] = [0.716, -0.718, 0, 0.736, '#surprising', '#admirable', 0.723, 'predestinate', 'predetermine', 'predestine', 'influence', 'preordain']
senticnet['foreplay'] = [0.281, 0.169, -0.147, 0.067, '#joyful', '#interesting', 0.123, 'good_feeling', 'arousal', 'new_friendship', 'get_date', 'express_love']
senticnet['foresee'] = [-0.809, 0, 0.945, -0.639, '#sad', '#angry', -0.798, 'fancy', 'conceive_of', 'fantasy', 'daydream', 'woolgather']
senticnet['foreshadowed'] = [0, 0, 0.701, -0.974, '#angry', '#disgusting', -0.558, 'bode', 'prognosticate', 'auspicate', 'portend', 'omen']
senticnet['foreshow'] = [0.527, -0.984, 0, 0.847, '#surprising', '#admirable', 0.786, 'auspicate', 'prefigure', 'bode', 'portend', 'prognosticate']
senticnet['foresighted'] = [0.527, -0.807, 0, 0.705, '#surprising', '#admirable', 0.68, 'careful', 'thrifty', 'farseeing', 'longsighted', 'provident']
senticnet['forest'] = [-0.739, 0, 0.59, -0.893, '#sad', '#disgusting', -0.741, 'desert', 'grassland', 'biome', 'woodland', 'timberland']
senticnet['forest_fire'] = [0, 0, -0.112, -0.124, '#scared', '#disgusting', -0.079, 'scald', 'inferno', 'bright_flash', 'arson', 'fire_product']
senticnet['forestall'] = [0.958, -0.72, 0, 0.737, '#joyful', '#admirable', 0.805, 'save', 'foil', 'spoil', 'frustrate', 'stymie']
senticnet['forested'] = [-0.863, 0, 0.665, -0.616, '#sad', '#angry', -0.715, 'brambly', 'braky', 'rushy', 'scrubby', 'wooded']
senticnet['foretelling'] = [0.993, -0.654, 0, 0.743, '#joyful', '#admirable', 0.797, 'weather_forecast', 'weather_outlook', 'financial_forecast', 'prediction', 'prognosis']
senticnet['forethought'] = [0, 0.378, -0.166, 0.278, '#interesting', '#admirable', 0.163, 'consider', 'plan', 'reason', 'decision', 'idea']
senticnet['forever'] = [0, 0.167, -0.133, 0.244, '#interesting', '#admirable', 0.093, 'everlasting', 'eternal', 'endless', 'never_end', 'infinite']
senticnet['forever_young'] = [0.107, 0.11, -0.084, 0.21, '#interesting', '#admirable', 0.114, 'live_healthy_life', 'live_forever', 'elisir', 'live_long', 'live_good_life']
senticnet['forfeit'] = [0, 0, 0.915, -0.744, '#angry', '#disgusting', -0.553, 'penalty', 'halt', 'pass', 'receive', 'take_turn']
senticnet['forge'] = [0, 0.066, 0, 0.093, '#interesting', '#admirable', 0.053, 'award_winner', 'carve', 'use_tool', 'stir_paint', 'mass_production']
senticnet['forget'] = [-0.808, 0, 0, 0, '#sad', '#sad', -0.269, 'resolve', 'change_attitude', 'make_mistake', 'keep_word', 'blank_stare']
senticnet['forget_else'] = [-0.112, 0.085, 0, -0.096, '#sad', '#disgusting', -0.041, 'solve_mystery', 'think_through', 'gain_insight', 'remember', 'find_answer']
senticnet['forget_everything'] = [-0.724, 0, 0.745, -0.914, '#angry', '#disgusting', -0.794, 'gonorrhea', 'lose_mind', 'bad_feeling', 'schizophrenia', 'disrespect']
senticnet['forget_fact'] = [-0.133, 0, -0.074, -0.037, '#sad', '#scared', -0.081, 'creative_mind', 'question_teacher', 'borrow_book_from_library', 'question_authority', 'succeed_school']
senticnet['forget_name'] = [-0.957, 0, 0.81, -0.7, '#sad', '#angry', -0.822, 'receive_email', 'laugh_oneself', 'reply_question', 'agree_disagree', 'welcome_friend']
senticnet['forget_problem'] = [0.728, 0, 0, 0.998, '#joyful', '#admirable', 0.575, 'forget_trouble', 'get_happy', 'enjoy_person', 'stress_reduction', 'relaxation']
senticnet['forget_trouble'] = [0.889, 0, 0, 0.931, '#joyful', '#admirable', 0.607, 'get_happy', 'forget_problem', 'find_solution', 'pleasure', 'spread_happiness']
senticnet['forgetful'] = [-0.714, 0, 0.906, -0.934, '#angry', '#disgusting', -0.851, 'absent', 'inattentive', 'distracted', 'distrait', 'scatty']
senticnet['forgetfulness'] = [-0.073, -0.071, -0.048, -0.252, '#sad', '#disgusting', -0.101, 'slur_word', 'run_out_booze', 'loss_ofawareness', 'hangover', 'bang_head']
senticnet['forgivable'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'venial', 'excusable', 'mercifully', 'merciful', 'mercifulness']
senticnet['forgive'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'comfort_friend', 'propose_woman', 'thank', 'love_another', 'love_else']
senticnet['forgiven'] = [0.746, 0.97, 0, 0.994, '#interesting', '#admirable', 0.903, 'luck', 'ritual', 'fame', 'prosperity', 'good_luck']
senticnet['forgiveness'] = [0.716, 0, 0, 0, '#joyful', '#joyful', 0.239, 'mercy', 'compassion', 'forgivable', 'excusable', 'venial']
senticnet['forgiver'] = [-0.763, 0, 0.684, -0.868, '#sad', '#disgusting', -0.772, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['forgiving'] = [0.579, -0.541, 0, 0.784, '#joyful', '#admirable', 0.635, 'exculpatory', 'vindicatory', 'absolvitory', 'exonerative', 'extenuating']
senticnet['forgotten'] = [0, 0, 0.935, -0.763, '#angry', '#disgusting', -0.566, 'hear_bad_news', 'death_love', 'disrespect', 'forget_everything', 'toothache']
senticnet['fork'] = [-0.754, 0, 0.886, -0.726, '#sad', '#angry', -0.789, 'harass', 'move', 'check', 'aggress', 'pin']
senticnet['forked'] = [0, 0, -0.889, -0.783, '#scared', '#disgusting', -0.557, 'forficate', 'pronged', 'branched', 'bifurcate', 'biramous']
senticnet['forklift'] = [0.087, -0.041, 0, 0, '#joyful', '#surprising', 0.043, 'hoist', 'control_room', 'utility_case', 'platform_rail', 'torso']
senticnet['forlorn'] = [-0.696, 0.32, -0.389, -0.089, '#sad', '#scared', -0.285, 'forlornly', 'desolation', 'forlornness', 'weepiness', 'tearful']
senticnet['forlorn_hope'] = [-0.83, 0, 0.965, -0.845, '#angry', '#disgusting', -0.88, 'labor', 'racket', 'endeavor', 'fraudulent_scheme', 'business_activity']
senticnet['forlornly'] = [-0.696, 0.32, -0.389, -0.089, '#sad', '#scared', -0.285, 'desolation', 'forlornness', 'forlorn', 'weepiness', 'tearful']
senticnet['forlornness'] = [-0.696, 0.32, -0.389, -0.089, '#sad', '#scared', -0.285, 'forlornly', 'desolation', 'forlorn', 'weepiness', 'tearful']
senticnet['form'] = [0.036, 0.127, 0.019, 0.225, '#interesting', '#admirable', 0.123, 'figure', 'geometric_figure', 'octagon', 'polygon', 'hexagon']
senticnet['form_expression'] = [0.081, 0, 0.051, 0.137, '#joyful', '#admirable', 0.056, 'instrumental', 'universal_language', 'melodic_noise', 'form_of_art', 'rock_music']
senticnet['form_government'] = [0.061, 0.219, -0.069, 0.192, '#interesting', '#admirable', 0.134, 'political_system', 'type_of_government', 'united_country', 'government_person', 'political_entity']
senticnet['form_of_art'] = [0.093, 0, 0.017, 0.183, '#joyful', '#admirable', 0.086, 'art_creation', 'creative_activity', 'form_expression', 'universal_language', 'art_form']
senticnet['form_of_communication'] = [0, 0.912, 0, 0.96, '#interesting', '#admirable', 0.624, 'communication_method', 'information_source', 'comment', 'written_language', 'give_info']
senticnet['form_of_energy'] = [0, 0.852, 0, 0.885, '#interesting', '#admirable', 0.579, 'energy', 'like_electricity', 'power', 'power_source', 'potential']
senticnet['form_of_entertainment'] = [0.101, -0.09, 0.016, 0, '#joyful', '#surprising', 0.058, 'fun_activity', 'form_of_social_interaction', 'stage_production', 'child_game', 'diversion']
senticnet['form_of_exercise'] = [0, 0.769, 0, 0.768, '#interesting', '#admirable', 0.512, 'good_exercise', 'healthy_exercise', 'vigorous_activity', 'great_exercise', 'like_run']
senticnet['form_of_food'] = [0.049, 0, 0.024, 0.056, '#joyful', '#admirable', 0.027, 'form', 'food', 'popular_food', 'raw_fish', 'japanese_food']
senticnet['form_of_gambling'] = [0, 0.988, 0, 0.764, '#interesting', '#admirable', 0.584, 'consider_good_luck', 'game', 'old_game', 'popular_game', 'game_skill']
senticnet['form_of_money'] = [0, 0.096, 0.082, 0.107, '#interesting', '#admirable', 0.04, 'monetary_unit', 'currency_unit', 'money_unit', 'american_coin', 'small_coin']
senticnet['form_of_music'] = [0.136, -0.092, 0.087, -0.033, '#joyful', '#surprising', 0.036, 'style_music', 'pop_music', 'tune', 'rhythm', 'music']
senticnet['form_of_public_transportation'] = [0, -0.019, 0, 0.058, '#surprising', '#admirable', 0.026, 'long_car', 'motor_vehicle', 'large_automobile', 'machine_transportation', 'transportation_vehicle']
senticnet['form_of_punishment'] = [-0.146, -0.042, 0, -0.102, '#sad', '#disgusting', -0.069, 'punish', 'inflict_pain', 'death_penalty', 'kill', 'punishment']
senticnet['form_of_social_interaction'] = [0, 0.941, 0, 0.714, '#interesting', '#admirable', 0.552, 'child_game', 'kid_activity', 'have_fun', 'fun_activity', 'fun_game']
senticnet['form_of_transportation'] = [0, 0.81, 0, 0.979, '#interesting', '#admirable', 0.596, 'mode_transportation', 'machine_transportation', 'long_car', 'car_truck', 'means_of_transportation']
senticnet['form_opinion'] = [-0.146, -0.042, 0, -0.102, '#sad', '#disgusting', -0.069, 'investigate_fact', 'ask_many_questions', 'ask_question', 'epiphany', 'think_logically']
senticnet['form_sentence'] = [-0.112, 0.082, -0.11, -0.05, '#sad', '#scared', -0.063, 'die_only_once', 'hurt_animal', 'eat_animal', 'kill_specific_group', 'wave_flag']
senticnet['form_team'] = [-0.043, -0.041, 0.085, 0, '#sad', '#angry', -0.029, 'gather_team', 'buy_ball', 'suit_up', 'join_team', 'hoop']
senticnet['form_think'] = [0, 0.069, 0, 0.108, '#interesting', '#admirable', 0.059, 'forget_fact', 'vocalization', 'creative_mind', 'human_sound', 'vocal']
senticnet['formal'] = [0.767, 0.995, 0, 0, '#joyful', '#interesting', 0.587, 'head_cover', 'frilly', 'fancy_clothes', 'feminine', 'formal_clothes']
senticnet['formal_cloth'] = [0.53, -0.649, 0, 0.76, '#surprising', '#admirable', 0.646, 'woman_garment', 'woman_cloth', 'woman_suit', 'woman_pant', 'woman_shirt']
senticnet['formal_clothes'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'clothes_style', 'style', 'glamour', 'model', 'fancy_clothes']
senticnet['formal_event'] = [0.076, 0.139, -0.062, 0.173, '#interesting', '#admirable', 0.109, 'lady', 'goddess', 'ceremony', 'priest', 'christian']
senticnet['formal_introduction'] = [0.928, 0.828, 0, 0, '#joyful', '#interesting', 0.585, 'socialize', 'business_card', 'database', 'professional', 'introduce_oneself']
senticnet['formal_logic'] = [0.629, -0.792, 0, 0.758, '#surprising', '#admirable', 0.726, 'system_of_rules', 'symbolic_logic', 'mathematical_logic', 'logical_system', 'system']
senticnet['formality'] = [0.614, -0.953, 0, 0.768, '#surprising', '#admirable', 0.778, 'keeping', 'abidance', 'honoring', 'line', 'observance']
senticnet['formative'] = [0.678, -0.897, 0, 0.804, '#surprising', '#admirable', 0.793, 'reconstructive', 'constructive', 'shaping', 'creative', 'inferential']
senticnet['formidable'] = [0, 0, 0.882, -0.991, '#angry', '#disgusting', -0.624, 'forbidding', 'redoubtable', 'daunting', 'alarming', 'frightening']
senticnet['formless'] = [-0.646, 0, 0.557, -0.739, '#sad', '#disgusting', -0.647, 'unformed', 'amorphous', 'shapeless', 'unshaped', 'unshapen']
senticnet['formula'] = [0.159, -0.005, 0.011, 0.079, '#joyful', '#admirable', 0.077, 'ceiling_fan', 'kitchenette', 'technologic', 'ipod', 'music']
senticnet['formulaic'] = [0.84, -0.646, 0, 0.912, '#joyful', '#admirable', 0.799, 'received', 'customary', 'conventional', 'stuffy', 'stodgy']
senticnet['formulate'] = [-0.957, 0, 0.822, -0.882, '#sad', '#disgusting', -0.887, 'hypothecate', 'speculate', 'conjecture', 'mature', 'suppose']
senticnet['formulation'] = [0.825, -0.916, 0, 0.626, '#joyful', '#surprising', 0.789, 'treacle', 'glop', 'mush', 'slop', 'sentimentalism']
senticnet['fornicate'] = [-0.745, 0, 0.677, -0.77, '#sad', '#disgusting', -0.731, 'whore', 'jazz', 'hump', 'bonk', 'screw']
senticnet['fornication'] = [-0.985, 0, 0.662, -0.738, '#sad', '#disgusting', -0.795, 'extramarital_sex', 'unlawful_carnal_knowledge', 'criminal_congress', 'adultery', 'criminal_conversation']
senticnet['fornicator'] = [-0.684, 0, 0.74, -0.971, '#angry', '#disgusting', -0.798, 'slut', 'trollop', 'libertine', 'adulteress', 'fornicatress']
senticnet['fornicatress'] = [-0.544, 0, 0.691, -0.966, '#angry', '#disgusting', -0.734, 'slut', 'trollop', 'libertine', 'adulteress', 'adulterer']
senticnet['forsake'] = [-0.603, 0, 0.661, -0.872, '#angry', '#disgusting', -0.712, 'maroon', 'strand', 'walk_out', 'expose', 'ditch']
senticnet['forswear'] = [-0.97, 0, 0.616, -0.589, '#sad', '#angry', -0.725, 'abjure', 'recant', 'repudiate', 'deny', 'reject']
senticnet['forswear_oneself'] = [-0.623, 0, 0.901, -0.715, '#angry', '#disgusting', -0.746, 'commit_perjury', 'fabricate', 'prejure_oneself', 'misrepresent', 'prevaricate']
senticnet['fort'] = [0, 0.858, 0, 0.767, '#interesting', '#admirable', 0.542, 'palace', 'fortification', 'defensive', 'medieval', 'mansion']
senticnet['forthright'] = [0, 0.899, 0, 0.779, '#interesting', '#admirable', 0.559, 'free-spoken', 'plainspoken', 'outspoken', 'blunt', 'candid']
senticnet['fortification'] = [0.029, 0.136, 0, 0.087, '#interesting', '#admirable', 0.084, 'defensive', 'palace', 'mansion', 'nice_house', 'domestic_dwell']
senticnet['fortified'] = [-0.898, 0, 0.627, -0.547, '#sad', '#angry', -0.691, 'shielded', 'weatherproof', 'covert', 'stormproof', 'protected']
senticnet['fortnight'] = [0, 0.887, 0, 0.844, '#interesting', '#admirable', 0.577, 'friday', 'monday', 'day_of_week', 'weekend', 'midweek']
senticnet['fortuity'] = [-0.725, 0, 0.552, -0.769, '#sad', '#disgusting', -0.682, 'break', 'good_luck', 'happy_chance', 'hap', 'coincidence']
senticnet['fortunate'] = [0.943, -0.582, 0, 0.694, '#joyful', '#admirable', 0.74, 'better_off', 'happy', 'lucky', 'well', 'felicitous']
senticnet['fortune'] = [0.976, 0.811, 0, 0, '#joyful', '#interesting', 0.596, 'deposit', 'bank_loan', 'wealth', 'finance', 'account']
senticnet['fortune_teller'] = [0.083, 0, 0, 0.075, '#joyful', '#admirable', 0.053, 'carny', 'carnival_ride', 'midway', 'ferris_wheel', 'roller-coaster']
senticnet['forum'] = [0, 0.073, -0.059, 0.067, '#interesting', '#admirable', 0.027, 'blog', 'read_magazine', 'read_news', 'attend_meeting', 'read_book']
senticnet['forward_email'] = [0, 0.711, 0, 0.946, '#interesting', '#admirable', 0.552, 'deal_card_player', 'stand_alone', 'explain_everything', 'bridge_difference', 'position_furniture']
senticnet['forward_motion'] = [0.605, -0.717, 0, 0.937, '#surprising', '#admirable', 0.753, 'plain_sailing', 'clear_sailing', 'easy_going', 'move', 'push']
senticnet['forward_movement'] = [-0.068, 0.233, -0.108, 0.332, '#interesting', '#admirable', 0.13, 'move_ahead', 'go_forward', 'go_ahead', 'move_forward', 'pace']
senticnet['forward_pass'] = [0.53, -0.649, 0, 0.76, '#surprising', '#admirable', 0.646, 'aerial', 'lateral', 'passing', 'lateral_pass', 'spot_pass']
senticnet['fossil'] = [0, 0, 0, 0.882, '#admirable', '#admirable', 0.294, 'bedrock', 'oil', 'dark_liquid', 'smithsonian_institution', 'inert_gas']
senticnet['fossil_fuel'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'fuel', 'car', 'motorbike', 'transport', 'natural_resource']
senticnet['foster_kid'] = [0.911, 0, 0, 0.709, '#joyful', '#admirable', 0.54, 'adopt', 'daughter', 'father_son', 'mom_dad', 'family']
senticnet['fosterage'] = [0.902, -0.5, 0, 0.716, '#joyful', '#admirable', 0.706, 'breeding', 'fostering', 'enculturation', 'cultivation', 'bringing_up']
senticnet['fostering'] = [0.902, -0.5, 0, 0.716, '#joyful', '#admirable', 0.706, 'breeding', 'enculturation', 'fosterage', 'cultivation', 'bringing_up']
senticnet['foul'] = [-0.971, 0, 0.922, -0.533, '#sad', '#angry', -0.809, 'muddy_up', 'muck_up', 'begrime', 'blemish', 'smear']
senticnet['foul_play'] = [-0.522, 0, 0.621, -0.919, '#angry', '#disgusting', -0.687, 'deviltry', 'devilry', 'irreverence', 'iniquity', 'sexual_immorality']
senticnet['foulness'] = [-0.534, 0, 0.733, -0.618, '#angry', '#disgusting', -0.628, 'distressfulness', 'intensiveness', 'intensity', 'severeness', 'seriousness']
senticnet['foundation'] = [0, 0.075, 0, 0.109, '#interesting', '#admirable', 0.061, 'wall', 'horizontal_plane', 'house_front', 'roof', 'home_entrance']
senticnet['founder'] = [-0.778, 0, 0.511, -0.536, '#sad', '#disgusting', -0.608, 'go_under', 'subside', 'fall', 'settle', 'submerge']
senticnet['founding_father'] = [0.812, -0.563, 0, 0.748, '#joyful', '#admirable', 0.708, 'founder', 'beginner', 'mastermind', 'father', 'pioneer']
senticnet['fount'] = [-0.986, 0, 0.969, -0.957, '#sad', '#angry', -0.971, 'face', 'font', 'monospaced_font', 'typeface', 'case']
senticnet['fountain_pen'] = [0.025, 0.176, -0.065, 0.114, '#interesting', '#admirable', 0.083, 'stamp_pad', 'pen', 'mechanical_pencil', 'ballpoint_pen', 'graphite_pencil']
senticnet['four_corners'] = [0, 0.884, 0, 0.708, '#interesting', '#admirable', 0.531, 'rectangular', 'rectangle', 'square', 'four_sides', 'rectangular_shape']
senticnet['four_leaf_clover'] = [0.343, 0.223, -0.168, 0.314, '#joyful', '#admirable', 0.237, 'horseshoe', 'chance', 'sport_person', 'horse_shoes', 'deck_card']
senticnet['four_quarters'] = [0, 0.177, 0.078, 0.12, '#interesting', '#admirable', 0.073, 'monetary_value', 'money_value', 'monetary_amount', 'denomination', 'money_amount']
senticnet['four_seasons'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'weather', 'sunny', 'spring', 'snow', 'climate']
senticnet['four_sides'] = [0, 0.72, 0, 0.773, '#interesting', '#admirable', 0.498, 'six_sides', 'polygon', 'square', 'parallelogram', 'rectangle']
senticnet['four_walls'] = [0, 0, 0, 0.092, '#admirable', '#admirable', 0.031, 'room', 'inside_house', 'house_part', 'square_shape', 'house_area']
senticnet['four_wheels'] = [0, -0.035, 0.013, 0.095, '#surprising', '#admirable', 0.039, 'car', 'internal_combustion_engine', 'lorry', 'automobile', 'bus']
senticnet['fourpenny'] = [0.753, -0.945, 0, 0.965, '#surprising', '#admirable', 0.888, 'threepenny', 'size', 'eightpenny', 'sized', 'ninepenny']
senticnet['fourth'] = [0, 0.149, 0, 0, '#interesting', '#interesting', 0.05, 'home', 'most_homes', 'time_limit', 'monthly', 'modern_home']
senticnet['fox'] = [-0.662, 0, 0.992, -0.726, '#angry', '#disgusting', -0.793, 'vixen', 'red_fox', 'kit_fox', 'prairie_fox', 'white_fox']
senticnet['foxiness'] = [0.784, -0.595, 0, 0.846, '#joyful', '#admirable', 0.742, 'astuteness', 'slyness', 'wiliness', 'craftiness', 'cunning']
senticnet['foxtail'] = [-0.766, 0, 0.513, -0.722, '#sad', '#disgusting', -0.667, 'meadow_grass', 'grass', 'manna_grass', 'sweet_grass', 'wood_meadowgrass']
senticnet['foxtail_grass'] = [-0.766, 0, 0.513, -0.722, '#sad', '#disgusting', -0.667, 'foxtail', 'meadow_grass', 'manna_grass', 'sweet_grass', 'wood_meadowgrass']
senticnet['foyer'] = [0.039, -0.033, 0, 0, '#joyful', '#surprising', 0.024, 'first_floor', 'basement', 'lower_floor', 'hallway', 'lobby']
senticnet['fracas'] = [-0.993, 0, 0.603, -0.827, '#sad', '#disgusting', -0.808, 'batrachomyomachia', 'wrangle', 'dustup', 'quarrel', 'row']
senticnet['fraction'] = [0, 0.119, 0, 0.106, '#interesting', '#admirable', 0.075, 'divide', 'factor', 'subtraction', 'math_action', 'division']
senticnet['fractious'] = [0, 0, -0.849, -0.836, '#scared', '#disgusting', -0.562, 'irritable', 'recalcitrant', 'cranky', 'refractory', 'nettlesome']
senticnet['fractiousness'] = [-0.562, 0, 0.746, -0.627, '#angry', '#disgusting', -0.645, 'contrariness', 'wildness', 'intractability', 'intractableness', 'perversity']
senticnet['fracture'] = [-0.812, 0, 0.745, -0.94, '#sad', '#disgusting', -0.832, 'injury', 'hairline_fracture', 'capillary_fracture', 'incomplete_fracture', 'simple_fracture']
senticnet['fragile'] = [0, 0, 0.771, -0.822, '#angry', '#disgusting', -0.531, 'weak', 'easy_to_break', 'breakable', 'delicate', 'frail']
senticnet['fragment'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'component', 'part_of_whole', 'math_problem', 'segment', 'small_unit']
senticnet['fragmentation'] = [0.774, -0.916, 0, 0.95, '#surprising', '#admirable', 0.88, 'big_bang', 'blowup', 'discharge', 'backfire', 'blast']
senticnet['fragrance'] = [0.718, 0.929, 0, 0, '#joyful', '#interesting', 0.549, 'aroma', 'scent', 'smell', 'odor', 'sniff']
senticnet['fragrancy'] = [0.933, -0.874, 0, 0.766, '#joyful', '#surprising', 0.858, 'scent', 'aroma', 'olfactory_property', 'smell', 'odor']
senticnet['fragrant'] = [0, 0.111, 0, 0.17, '#interesting', '#admirable', 0.094, 'sexual', 'use_decoration', 'garden_plant', 'green', 'colorful']
senticnet['frail'] = [0, 0, 0.771, -0.822, '#angry', '#disgusting', -0.531, 'fragile', 'breakable', 'delicate', 'weak', 'easy_to_break']
senticnet['frailness'] = [0.645, -0.689, 0, 0.625, '#joyful', '#surprising', 0.653, 'cachexia', 'cachexy', 'wasting', 'softness', 'unfitness']
senticnet['frailty'] = [0.591, -0.967, 0, 0.953, '#surprising', '#admirable', 0.837, 'cachexia', 'cachexy', 'wasting', 'softness', 'unfitness']
senticnet['frame'] = [0.033, 0, 0, 0.081, '#joyful', '#admirable', 0.038, 'door', 'door_lock', 'window_door', 'wall', 'doorway']
senticnet['frame_of_mind'] = [0.964, -0.592, 0, 0.982, '#joyful', '#admirable', 0.846, 'case', 'thinking_cap', 'temporary_state', 'psychological_state', 'psychological_condition']
senticnet['frame_picture'] = [0.903, 0.932, 0, 0, '#joyful', '#interesting', 0.612, 'photograph', 'picture', 'painting', 'buy_paint', 'make_paint']
senticnet['framing'] = [0.878, -0.587, 0, 0.624, '#joyful', '#admirable', 0.696, 'conceptualization', 'approach', 'attack', 'plan_of_attack', 'creating_by_mental_acts']
senticnet['franc'] = [0, 0.201, 0.018, 0.077, '#interesting', '#admirable', 0.087, 'cent', 'dollar', 'euro', 'banknote', 'shilling']
senticnet['franchise'] = [0, 0.752, 0, 0.812, '#interesting', '#admirable', 0.521, 'soft_wood', 'wood', 'natural_gas', 'glass', 'fiberglass']
senticnet['frank'] = [0.05, 0.166, -0.071, 0.152, '#interesting', '#admirable', 0.099, 'direct', 'person', 'outspoken', 'direct_person', 'candid']
senticnet['frankness'] = [0.664, -0.941, 0, 0.613, '#joyful', '#surprising', 0.739, 'outspokenness', 'communicativeness', 'garrulity', 'garrulousness', 'loquaciousness']
senticnet['fraternal'] = [0.605, 0.647, -0.266, 0.323, '#joyful', '#interesting', 0.436, 'brother_like', 'brotherly', 'amicableness', 'amicably', 'amicable']
senticnet['fraternity'] = [0.153, 0, 0, 0, '#joyful', '#joyful', 0.051, 'club', 'social_group', 'association', 'member', 'organization']
senticnet['fraud'] = [-0.914, 0, 0.85, -0.766, '#sad', '#angry', -0.843, 'fraud_in_fact', 'positive_fraud', 'mail_fraud', 'swindle', 'rig']
senticnet['fraud_in_fact'] = [-0.914, 0, 0.85, -0.766, '#sad', '#angry', -0.843, 'fraud', 'positive_fraud', 'mail_fraud', 'swindle', 'rig']
senticnet['fraudulence'] = [-0.601, 0, 0.982, -0.562, '#sad', '#angry', -0.715, 'humbug', 'deceit', 'deception', 'chicanery', 'dissembling']
senticnet['fraudulent_intent'] = [-0.106, 0, -0.053, -0.24, '#sad', '#disgusting', -0.133, 'thieving', 'larceny', 'theft', 'thievery', 'stealing']
senticnet['fraudulent_scheme'] = [-0.914, 0, 0.85, -0.766, '#sad', '#angry', -0.843, 'labor', 'racket', 'forlorn_hope', 'endeavor', 'business_activity']
senticnet['frayed'] = [-0.783, 0, -0.837, 0, '#sad', '#scared', -0.54, 'fret', 'rub', 'scratch', 'frazzle', 'chafe']
senticnet['freak'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'weird', 'abnormal', 'monster', 'lunatic', 'odd']
senticnet['freak_out'] = [0, 0, 0.771, -0.822, '#angry', '#disgusting', -0.531, 'amount_nothing', 'act_foolish', 'wet_pant', 'correct_mistake', 'cry_help']
senticnet['freakishness'] = [-0.561, 0, 0.977, -0.869, '#angry', '#disgusting', -0.802, 'strangeness', 'quaintness', 'abnormality', 'queerness', 'crotchet']
senticnet['freckle'] = [-0.721, 0, -0.825, -0.841, '#scared', '#disgusting', -0.796, 'helpless', 'unwanted', 'rabies', 'small_cat', 'big_rat']
senticnet['free'] = [0.734, 0.772, 0, 0.841, '#interesting', '#admirable', 0.782, 'cost_nothing', 'inexpensive', 'good_buy', 'liberate', 'bargain']
senticnet['free_bird'] = [0, 0.708, 0, 0.76, '#interesting', '#admirable', 0.489, 'journey_far', 'near_destination', 'board_boat', 'bug_person', 'travel_by_airplane']
senticnet['free_country'] = [0.904, 0.881, 0, 0.774, '#joyful', '#interesting', 0.853, 'united_country', 'democracy', 'democratic_country', 'unite', 'independent']
senticnet['free_food'] = [0.93, 0.734, 0, 0.958, '#joyful', '#admirable', 0.874, 'art_lover', 'artist', 'oil_paint', 'oil_painting', 'artistic']
senticnet['free_house'] = [-0.769, 0, 0.75, -0.563, '#sad', '#angry', -0.694, 'public_house', 'pub', 'saloon', 'pothouse', 'gin_mill']
senticnet['free_love'] = [-0.792, 0, 0.979, -0.982, '#angry', '#disgusting', -0.918, 'fornication', 'unlawful_carnal_knowledge', 'criminal_congress', 'adultery', 'criminal_conversation']
senticnet['free_mind'] = [0, 0.997, 0, 0.951, '#interesting', '#admirable', 0.649, 'wave_hand', 'trade_stock', 'position_furniture', 'correct_mistake', 'lower_standard']
senticnet['free_night'] = [0.53, -0.649, 0, 0.76, '#surprising', '#admirable', 0.646, 'take_care', 'baby', 'free_time', 'children_in_safe_hands', 'baby_sitter']
senticnet['free_phagocyte'] = [0.702, -0.524, 0, 0.958, '#joyful', '#admirable', 0.728, 'somatic_cell', 'vegetative_cell', 'fixed_phagocyte', 'macrophage', 'phagocyte']
senticnet['free_prisoner'] = [-0.156, 0.081, -0.084, 0, '#sad', '#scared', -0.053, 'turn_key', 'open_lock', 'turn_car_off', 'open_door', 'start_engine']
senticnet['free_seat'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'seat', 'few_people', 'travel_comfortable', 'good_service', 'free']
senticnet['free_sex'] = [0.045, -0.664, 0, 0.363, '#surprising', '#admirable', 0.357, 'enjoy_time_together', 'meet_girl', 'fall_in_love', 'kiss', 'infatuation']
senticnet['free_slave'] = [0, 0.758, 0, 0.935, '#interesting', '#admirable', 0.564, 'helper', 'hire_help', 'laborer', 'occupation', 'career']
senticnet['free_spirit'] = [0.776, -0.575, 0, 0.582, '#joyful', '#admirable', 0.644, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['free_stuff'] = [0.889, 0.762, 0, 0.95, '#joyful', '#admirable', 0.867, 'taken_seriously', 'enough_food', 'simplicity', 'sate', 'complement']
senticnet['free_ticket'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'enjoy_concert', 'enjoy_club', 'ticket', 'free', 'enjoy_football_match']
senticnet['free_time'] = [0.987, 0.882, 0, 0.905, '#joyful', '#admirable', 0.925, 'dress_nicely', 'buy_ticket', 'enjoy', 'plan_time', 'buy_popcorn']
senticnet['free_weight'] = [0.52, -0.972, 0, 0.916, '#surprising', '#admirable', 0.803, 'sporting_goods', 'weight', 'mat', 'sports_equipment', 'exercising_weight']
senticnet['free_will'] = [0, 0.133, 0, 0.206, '#interesting', '#admirable', 0.113, 'scrub', 'cleanse', 'use_soap', 'body_clean', 'clean_laundry']
senticnet['freeboard_deck'] = [0.831, -0.821, 0, 0.826, '#joyful', '#admirable', 0.826, 'deck', 'upper_deck', 'weather_deck', 'shelter_deck', 'boat_deck']
senticnet['freedom'] = [0.965, 0.72, 0, 0.914, '#joyful', '#admirable', 0.866, 'praise', 'equality_everyone', 'honor', 'important', 'glory']
senticnet['freedom_think'] = [0.813, 0.916, 0, 0.841, '#interesting', '#admirable', 0.857, 'text_book', 'wiseman', 'librarian', 'professor', 'teacher']
senticnet['freeload'] = [0.866, -0.917, 0, 0.893, '#surprising', '#admirable', 0.892, 'mooch', 'cadge', 'grub', 'sponge', 'bum']
senticnet['freely_available'] = [0.734, 0, 0, 0.877, '#joyful', '#admirable', 0.537, 'available', 'public', 'population', 'crowd', 'majority']
senticnet['freestyle'] = [-0.03, 0.11, 0, 0.128, '#interesting', '#admirable', 0.069, 'flip', 'take_leak', 'jump_air', 'backstroke', 'go_underwater']
senticnet['freeway'] = [0, 0, 0.013, -0.067, '#angry', '#disgusting', -0.027, 'street', 'wide_street', 'country_road', 'highway', 'road']
senticnet['freewheeler'] = [0.502, -0.829, 0, 0.779, '#surprising', '#admirable', 0.703, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['freewheeling'] = [0.951, -0.895, 0, 0.52, '#joyful', '#surprising', 0.789, 'irresponsible', 'carefree', 'slaphappy', 'unaccountable', 'loose']
senticnet['freeze'] = [-0.641, 0, 0.612, -0.848, '#sad', '#disgusting', -0.7, 'chilling', 'frost', 'lyophilization', 'icing', 'cooling']
senticnet['freeze_cold'] = [-0.984, 0, 0.944, -0.941, '#sad', '#angry', -0.956, 'cold', 'shiver', 'snow', 'cold_winter', 'hypothermia']
senticnet['freeze_off'] = [-0.651, 0, 0.675, -0.963, '#angry', '#disgusting', -0.763, 'snub', 'rebuff', 'repel', 'refuse', 'decline']
senticnet['freezer'] = [0, -0.023, 0, 0.07, '#surprising', '#admirable', 0.031, 'pastry', 'christmas_stock', 'breadbox', 'sundae', 'bakery']
senticnet['french'] = [-0.026, 0, 0, -0.067, '#sad', '#disgusting', -0.031, 'snob', 'snooty', 'full_of_oneself', 'full_of_shit', 'french_person']
senticnet['french_fries'] = [0.838, -0.57, 0, 0.544, '#joyful', '#surprising', 0.651, 'potato', 'white_potato', 'murphy', 'spud', 'tater']
senticnet['french_person'] = [-0.026, 0, 0, -0.067, '#sad', '#disgusting', -0.031, 'snob', 'snooty', 'full_of_oneself', 'full_of_shit', 'french']
senticnet['french_restaurant'] = [0.053, 0.085, 0.019, 0, '#joyful', '#interesting', 0.04, 'mexican_restaurant', 'spanish_restaurant', 'potato', 'pork_butcher', 'toxic_waste']
senticnet['french_revolution'] = [0.52, -0.972, 0, 0.916, '#surprising', '#admirable', 0.803, 'kill', 'behead', 'kill_other_person', 'seek_revenge', 'murder']
senticnet['french_toast'] = [0.053, 0.085, 0.019, 0, '#joyful', '#interesting', 0.04, 'beef', 'pork', 'brisket', 'steak', 'ham']
senticnet['frenzy'] = [-0.682, 0, 0.995, -0.789, '#angry', '#disgusting', -0.822, 'manic_disorder', 'mania', 'nympholepsy', 'mass_hysteria', 'epidemic_hysertia']
senticnet['frequency'] = [0.035, 0.124, 0, 0.23, '#interesting', '#admirable', 0.13, 'hello', 'periodic', 'amplitude', 'vibration', 'redo']
senticnet['frequency_distribution'] = [0.948, -0.992, 0, 0.549, '#joyful', '#surprising', 0.83, 'sampling', 'equidistribution', 'distribution', 'normal_distribution', 'sample_distribution']
senticnet['frequent'] = [0, 0.188, -0.047, 0.191, '#interesting', '#admirable', 0.111, 'usual_ordinary', 'normal', 'typical', 'usual', 'daily_routine']
senticnet['frequently'] = [0.023, 0.082, 0, 0.155, '#interesting', '#admirable', 0.087, 'never_end', 'infinite', 'everlasting', 'unending', 'previous']
senticnet['fresh'] = [0.116, 0.108, -0.091, 0.12, '#joyful', '#admirable', 0.084, 'rinse', 'timely', 'update', 'new', 'feel_refreshed']
senticnet['fresh_air'] = [0.786, 0, 0, 0, '#joyful', '#joyful', 0.262, 'camping', 'outdoor', 'tent', 'bonfire', 'camp_out']
senticnet['fresh_air_exercise'] = [0.921, 0, 0, 0.923, '#joyful', '#admirable', 0.615, 'exercise', 'go_picnic', 'enjoy_competition', 'nice_weather', 'long_happy_life']
senticnet['fresh_breath'] = [0.9, 0.998, 0, 0.82, '#joyful', '#interesting', 0.906, 'good_sense_of_humor', 'simile', 'strong_relationship', 'express_gratitude', 'able_read']
senticnet['fresh_breathe'] = [0.786, 0, 0, 0, '#joyful', '#joyful', 0.262, 'brush_tooth', 'clean_teeth', 'go_bathroom', 'teeth_whitening', 'remove_stain']
senticnet['fresh_food'] = [0.907, 0.794, 0, 0.771, '#joyful', '#interesting', 0.824, 'cookie', 'taste_sugar', 'good_taste_food', 'brownie', 'pie']
senticnet['fresh_fruit'] = [0.973, 0.769, 0, 0.784, '#joyful', '#admirable', 0.842, 'fresh_vegetable', 'fruit', 'frozen_food', 'fruit_vegetable', 'green_bean']
senticnet['fresh_milk'] = [0.053, 0.085, 0.019, 0, '#joyful', '#interesting', 0.04, 'farm', 'countryside', 'farm_animal', 'cow', 'farm_area']
senticnet['fresh_produce'] = [0.957, 0.818, 0, 0.919, '#joyful', '#admirable', 0.898, 'healthy_food', 'groceries', 'chicken_soup', 'delicious_food', 'food']
senticnet['fresh_vegetable'] = [0.065, 0, 0.011, 0.051, '#joyful', '#admirable', 0.035, 'fruit_vegetable', 'fruit', 'fresh_fruit', 'turnip', 'radish']
senticnet['fresh_water'] = [0.057, 0.118, -0.049, 0.151, '#interesting', '#admirable', 0.092, 'small_river', 'panama', 'water_feature', 'water_body', 'large_body']
senticnet['freshen'] = [-0.819, 0, 0.504, -0.966, '#sad', '#disgusting', -0.763, 'regenerate', 'air_out', 'air', 'renew', 'vent']
senticnet['freshen_up'] = [0.857, -0.688, 0, 0.971, '#joyful', '#admirable', 0.839, 'revitalize', 'refurbish', 'reconstruct', 'renovate', 'renew']
senticnet['fresher'] = [0.705, 0, 0, 0.888, '#joyful', '#admirable', 0.531, 'junior', 'undergraduate', 'undergrad', 'freshman', 'original']
senticnet['freshman'] = [0.739, 0.825, 0, 0.782, '#interesting', '#admirable', 0.782, 'school_session', 'academy', 'lesson', 'university', 'undergraduate']
senticnet['freshness'] = [0.102, -0.102, 0.009, -0.121, '#joyful', '#surprising', 0.025, 'weather_report', 'bulletin', 'bird_fly', 'cnn', 'paper_write']
senticnet['fretful'] = [-0.864, 0, -0.85, 0, '#sad', '#scared', -0.571, 'fidgetiness', 'antsy', 'fidgety', 'stewing', 'impatiently']
senticnet['fretfulness'] = [-0.511, 0, 0.584, -0.847, '#angry', '#disgusting', -0.647, 'ill_humor', 'distemper', 'pet', 'testiness', 'touchiness']
senticnet['friar'] = [0.025, 0.253, -0.071, 0.2, '#interesting', '#admirable', 0.136, 'priest', 'church_head', 'preacher', 'pastor', 'bishop']
senticnet['fricative'] = [0.055, -0.054, 0.013, 0, '#joyful', '#surprising', 0.032, 'radio-control_helicopter', 'football', 'spray_paint_grafitti', 'marijuana', 'televise']
senticnet['friction'] = [0, 0, -0.113, 0, '#scared', '#scared', -0.038, 'chemical_reaction', 'set_fire', 'grow_yard', 'heat_light', 'burn_down_house']
senticnet['friday'] = [0.9, 0.773, 0, 0, '#joyful', '#interesting', 0.558, 'day_of_week', 'monday', 'fortnight', 'weekend', 'midweek']
senticnet['fried_fillet'] = [0.027, 0.111, -0.055, 0.167, '#interesting', '#admirable', 0.083, 'price_product', 'food', 'fillet_fish', 'dinner', 'hungry']
senticnet['friend'] = [0.72, 0, 0, 0.879, '#joyful', '#admirable', 0.533, 'friendship', 'adult', 'companion', 'rely_on_other_person', 'have_fun_together']
senticnet['friend_gathering'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'drink', 'party', 'chill_out', 'rest_area', 'relax_time']
senticnet['friend_over'] = [0.719, 0, 0, 0, '#joyful', '#joyful', 0.24, 'go_party', 'enjoy_company_friend', 'celebrate', 'drink_a_lot_of_beer', 'entertain_person']
senticnet['friend_person'] = [0.055, 0.189, -0.097, 0.113, '#interesting', '#admirable', 0.087, 'tame', 'male_and_female', 'sense_fear', 'chap', 'good_manner']
senticnet['friend_wedding'] = [0.027, 0.132, 0, 0.132, '#interesting', '#admirable', 0.097, 'wedding', 'gallery_open', 'synagogue', 'monastery', 'confession']
senticnet['friendliness'] = [0.58, 0.651, -0.264, 0.308, '#joyful', '#interesting', 0.425, 'well-disposed', 'approving', 'approve', 'sanctioned', 'approved']
senticnet['friendly'] = [0.777, 0.972, 0, 0.913, '#interesting', '#admirable', 0.887, 'serene', 'easy', 'adoration', 'togetherness', 'console']
senticnet['friendly_fire'] = [-0.226, -0.062, -0.113, -0.182, '#sad', '#disgusting', -0.153, 'die', 'get_killed', 'beaten', 'lose_war', 'attack_enemy']
senticnet['friendly_person'] = [0.866, 0.965, 0, 0.705, '#joyful', '#interesting', 0.845, 'care_person', 'moderation', 'exercise_much', 'spouse', 'famous_person']
senticnet['friendly_relationship'] = [0.589, -0.608, 0, 0.828, '#surprising', '#admirable', 0.675, 'trust', 'confidence', 'blood_brotherhood', 'company', 'companionship']
senticnet['friendship'] = [0.73, -0.766, 0, 0.817, '#surprising', '#admirable', 0.771, 'trust', 'confidence', 'blood_brotherhood', 'company', 'companionship']
senticnet['fries'] = [0.508, -0.771, 0, 0.622, '#surprising', '#admirable', 0.634, 'potato', 'white_potato', 'murphy', 'spud', 'tater']
senticnet['frieze'] = [0.121, 0, 0, 0.064, '#joyful', '#admirable', 0.062, 'craft', 'art', 'painting', 'portrait', 'design']
senticnet['fright'] = [0, 0, -0.838, -0.75, '#scared', '#disgusting', -0.529, 'dread', 'uneasiness', 'hysteria', 'disquiet', 'anxious']
senticnet['frighten'] = [-0.501, 0.123, -0.306, -0.136, '#sad', '#scared', -0.273, 'scare', 'fright', 'humiliation', 'shame', 'scary']
senticnet['frighten_away'] = [0, 0, -0.973, -0.816, '#scared', '#disgusting', -0.596, 'scarily', 'scared', 'scare_away', 'frighten_off', 'scare_off']
senticnet['frighten_off'] = [0, 0, -0.848, -0.944, '#scared', '#disgusting', -0.597, 'scarily', 'scared', 'frighten_away', 'scare_away', 'scare_off']
senticnet['frighten_person'] = [-0.914, 0, 0.85, -0.766, '#sad', '#angry', -0.843, 'keep_paper_together', 'bind', 'fasten', 'carry_paper', 'beatles_song']
senticnet['frightened'] = [0, 0, -0.953, -0.991, '#scared', '#disgusting', -0.648, 'affright', 'scared', 'daunt', 'scare_off', 'frighten_off']
senticnet['frightening'] = [0, 0, -0.878, -0.799, '#scared', '#disgusting', -0.559, 'dire', 'fearsome', 'dreaded', 'direful', 'horrendous']
senticnet['frighteningly'] = [0, 0, -0.761, -0.806, '#scared', '#disgusting', -0.522, 'scarily', 'scared', 'frighten_away', 'scare_away', 'frighten_off']
senticnet['frightful'] = [0, 0, -0.806, -0.748, '#scared', '#disgusting', -0.518, 'dreaded', 'fearsome', 'frightening', 'horrendous', 'dire']
senticnet['frigid'] = [-0.565, 0, 0.578, -0.744, '#angry', '#disgusting', -0.629, 'cold', 'unloving', 'loveless', 'detached', 'unaffectionate']
senticnet['frigidity'] = [-0.923, 0, 0.972, -0.674, '#sad', '#angry', -0.856, 'cold', 'low_temperature', 'chilliness', 'frigidness', 'coldness']
senticnet['frigidness'] = [-0.923, 0, 0.972, -0.674, '#sad', '#angry', -0.856, 'cold', 'low_temperature', 'frigidity', 'chilliness', 'coldness']
senticnet['frijol'] = [0.861, -0.549, 0, 0.976, '#joyful', '#admirable', 0.795, 'kidney_bean', 'common_bean', 'common_beane', 'green_bean', 'wax_bean']
senticnet['frijole'] = [0.861, -0.549, 0, 0.976, '#joyful', '#admirable', 0.795, 'kidney_bean', 'frijol', 'common_bean', 'green_bean', 'wax_bean']
senticnet['frill'] = [0.1, -0.12, 0.05, -0.032, '#joyful', '#surprising', 0.046, 'fancy_dress', 'blouse', 'fashion', 'dress', 'skirt']
senticnet['frilly'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'formal_clothes', 'woman_clothes', 'girl_clothes', 'woman_garment', 'item_clothes']
senticnet['frilly_design'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'woman_garment', 'skirt', 'female_cloth', 'woman_dress', 'robe']
senticnet['fringe_benefit'] = [0.639, -0.979, 0, 0.648, '#surprising', '#admirable', 0.755, 'benefit', 'appanage', 'provision', 'gratuity', 'tip']
senticnet['fringed'] = [0.613, -0.532, 0, 0.932, '#joyful', '#admirable', 0.692, 'buttony', 'ruffled', 'adorned', 'tessellated', 'mounted']
senticnet['frisbee'] = [0.892, 0.863, 0, 0, '#joyful', '#interesting', 0.585, 'sport_ball', 'sport_equipment', 'toy_ball', 'toy_marble', 'game']
senticnet['frisky'] = [0.582, -0.783, 0, 0.795, '#surprising', '#admirable', 0.72, 'elfish', 'elvish', 'kittenish', 'playful', 'sportive']
senticnet['frisson'] = [0.465, 0.653, -0.258, 0.231, '#joyful', '#interesting', 0.364, 'gratefully', 'appreciatively', 'affectionateness', 'warmness', 'excitement']
senticnet['frivolity'] = [-0.916, 0, 0.808, -0.728, '#sad', '#angry', -0.817, 'levity', 'fun', 'giddiness', 'trait', 'silliness']
senticnet['frivolous'] = [-0.799, 0, 0.904, -0.652, '#sad', '#angry', -0.785, 'dizzy', 'giddy', 'idle', 'airheaded', 'featherbrained']
senticnet['frivolousness'] = [-0.83, 0, 0.905, -0.595, '#sad', '#angry', -0.777, 'levity', 'fun', 'giddiness', 'trait', 'silliness']
senticnet['frock'] = [0.068, 0, 0.014, 0.055, '#joyful', '#admirable', 0.036, 'frill', 'blouse', 'fashion', 'outfit', 'wear']
senticnet['frog'] = [0, 0, 0.073, 0, '#angry', '#angry', -0.024, 'cold-blooded', 'reptile', 'scaly', 'amphibian', 'aquatic']
senticnet['frolic'] = [0.525, -0.857, 0, 0.599, '#surprising', '#admirable', 0.66, 'coquetry', 'gambol', 'romp', 'play', 'caper']
senticnet['from_here'] = [0.102, 0.142, -0.081, 0.224, '#interesting', '#admirable', 0.129, 'origin', 'come_from', 'travel', 'source', 'place_of_origin']
senticnet['from_prison'] = [-0.982, 0, 0.078, -0.919, '#sad', '#disgusting', -0.66, 'escape', 'prisoner', 'killer', 'murderer', 'assassin']
senticnet['front'] = [-0.635, 0, 0.559, -0.828, '#sad', '#disgusting', -0.674, 'take_bull_by_horns', 'breast', 'confront', 'encounter', 'oppose']
senticnet['front_back'] = [0, 0.768, 0, 0.98, '#interesting', '#admirable', 0.583, 'location', 'front_rear', 'part_of_room', 'square', 'front']
senticnet['front_build'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'beach_house', 'television_station', 'football_stadium', 'football_game', 'back_door']
senticnet['front_desk'] = [0.064, 0.07, 0, 0, '#joyful', '#interesting', 0.045, 'top_floor', 'elevator', 'concierge', 'exit', 'ground_floor']
senticnet['front_house'] = [0, 0.782, 0, 0.903, '#interesting', '#admirable', 0.562, 'fancy_house', 'outside_house', 'front', 'front_back', 'house']
senticnet['front_line'] = [-0.766, 0, 0.513, -0.722, '#sad', '#disgusting', -0.667, 'start_over', 'queue', 'find_line', 'take_turn', 'long_line']
senticnet['front_page'] = [0.024, 0.121, -0.077, 0.164, '#interesting', '#admirable', 0.077, 'conceal', 'concealment', 'paper_book', 'vocabulary', 'book_content']
senticnet['front_porch'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'home_depot', 'lumberyard', 'furniture_store', 'carpet_store', 'shoe_shop']
senticnet['front_rear'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'location', 'front_back', 'part_of_room', 'square', 'front']
senticnet['front_yard'] = [0.064, 0.07, 0, 0, '#joyful', '#interesting', 0.045, 'garden_shed', 'fresh_air', 'garden', 'lawn', 'tool_shed']
senticnet['frontal_eminence'] = [0.737, -0.96, 0, 0.552, '#joyful', '#surprising', 0.75, 'prominence', 'hump', 'bump', 'swelling', 'bulge']
senticnet['frontspiece'] = [0.044, 0, 0, 0.206, '#joyful', '#admirable', 0.083, 'begin_end', 'book', 'title_page', 'book_end', 'book_content']
senticnet['frost'] = [0.077, -0.055, 0, 0, '#joyful', '#surprising', 0.044, 'icicle', 'snow_fall', 'winter', 'snow', 'season_year']
senticnet['frostbite'] = [0, 0, -0.842, -0.942, '#scared', '#disgusting', -0.595, 'broken_limb', 'get_cold', 'fall_head', 'bloody_nose', 'break_bone']
senticnet['frostiness'] = [-0.547, 0, 0.823, -0.736, '#angry', '#disgusting', -0.702, 'cold', 'low_temperature', 'frigidity', 'frigidness', 'coldness']
senticnet['frosty'] = [0, 0, -0.986, -0.746, '#scared', '#disgusting', -0.577, 'wintry', 'glacial', 'icy', 'frigid', 'frozen']
senticnet['froth'] = [-0.559, 0, 0.869, -0.838, '#angry', '#disgusting', -0.755, 'air_bubble', 'foam', 'bubble', 'soap_bubble', 'globule']
senticnet['frottage'] = [0.89, -0.646, 0, 0.765, '#joyful', '#admirable', 0.767, 'wank', 'masturbation', 'jacking_off', 'jerking_off', 'hand_job']
senticnet['froward'] = [-0.778, 0, 0.886, -0.584, '#sad', '#angry', -0.749, 'refractory', 'obstinate', 'recalcitrant', 'disobedient', 'headstrong']
senticnet['frown'] = [-0.189, 0, -0.236, 0, '#sad', '#scared', -0.142, 'smile', 'sneer', 'start_laugh', 'go_back_time', 'hear_joke']
senticnet['frowsty'] = [-0.868, 0, 0.644, -0.886, '#sad', '#disgusting', -0.799, 'malodorous', 'fetid', 'foetid', 'smelly', 'stinking']
senticnet['frowzled'] = [-0.852, 0, 0.985, -0.71, '#sad', '#angry', -0.849, 'messy', 'mussy', 'disheveled', 'dirty', 'untidy']
senticnet['frozen'] = [-0.036, 0, 0.014, -0.031, '#sad', '#disgusting', -0.027, 'ice_crystal', 'frozen_water', 'wet_cold', 'coldness', 'wetness']
senticnet['frozen_food'] = [0.064, 0.07, 0, 0, '#joyful', '#interesting', 0.045, 'apple_pie', 'lasagna', 'jelly', 'a_lot_of_food', 'cottage_cheese']
senticnet['frozen_liquid'] = [0.1, 0.076, 0, 0.156, '#joyful', '#admirable', 0.111, 'ice_crystal', 'little_dense_water', 'fragile', 'solid', 'white']
senticnet['frozen_water'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'ice_crystal', 'frozen', 'ice_cube', 'coldness', 'water']
senticnet['fructify'] = [0.969, -0.868, 0, 0.631, '#joyful', '#surprising', 0.823, 'assuage', 'perfect', 'make_look_better', 'relieve', 'sublimate']
senticnet['frugal'] = [0.722, -0.744, 0, 0.554, '#joyful', '#surprising', 0.673, 'saving', 'economical', 'scotch', 'thrifty', 'sparing']
senticnet['frugality'] = [0.533, -0.558, 0, 0.912, '#surprising', '#admirable', 0.668, 'parsimony', 'parsimoniousness', 'thrift', 'economy', 'prudence']
senticnet['frugalness'] = [0.768, -0.844, 0, 0.811, '#surprising', '#admirable', 0.808, 'parsimony', 'parsimoniousness', 'thrift', 'economy', 'prudence']
senticnet['fruit'] = [0, 0.141, 0.01, 0.115, '#interesting', '#admirable', 0.082, 'achene', 'rind', 'funiculus', 'seed', 'pip']
senticnet['fruit_bowl'] = [0.937, 0, 0, 0.828, '#joyful', '#admirable', 0.588, 'bakery', 'produce_section', 'thanksgiving_dinner', 'dinner_meal', 'fast_food']
senticnet['fruit_drink'] = [0.948, 0.992, 0, 0.974, '#interesting', '#admirable', 0.971, 'fermented_beverage', 'yogurt', 'healthy_drink', 'ferment_grape_juice', 'good_taste']
senticnet['fruit_plant'] = [0, -0.012, 0.036, -0.05, '#angry', '#disgusting', -0.025, 'shamrock', 'flower_plant', 'weed', 'green_plant', 'star_anise']
senticnet['fruit_stand'] = [0.064, 0.07, 0, 0, '#joyful', '#interesting', 0.045, 'grocery_cart', 'salad_bar', 'super_market', 'candy_store', 'produce_store']
senticnet['fruit_tree'] = [0.911, 0, 0, 0.738, '#joyful', '#admirable', 0.55, 'fig', 'baby_flower', 'carpel', 'strawberry', 'star_anise']
senticnet['fruit_vegetable'] = [0.102, 0, 0, 0, '#joyful', '#joyful', 0.034, 'fresh_vegetable', 'cabbage', 'cut_flower', 'plant_matter', 'fruit']
senticnet['fruitful'] = [0.851, -0.671, 0, 0.854, '#joyful', '#admirable', 0.792, 'fertile', 'breeding', 'prolific', 'bountiful', 'productive']
senticnet['fruitfulness'] = [0.643, -0.803, 0, 0.681, '#surprising', '#admirable', 0.709, 'quality', 'richness', 'fertility', 'prolificacy', 'productiveness']
senticnet['fruitless'] = [-0.608, 0, 0.761, -0.849, '#angry', '#disgusting', -0.739, 'vain', 'bootless', 'unproductive', 'futile', 'sleeveless']
senticnet['fruits'] = [0.86, 0.788, 0, 0, '#joyful', '#interesting', 0.549, 'citrus_fruit', 'orange_fruit', 'orange_color', 'hair_color', 'citrus']
senticnet['frump'] = [-0.598, 0, 0.573, -0.56, '#sad', '#angry', -0.577, 'termagant', 'old_bag', 'shrew', 'disagreeable_woman', 'hellcat']
senticnet['frustrate'] = [-0.863, 0, 0.863, 0, '#sad', '#angry', -0.575, 'aggravation', 'offend', 'nausea', 'disgust', 'irritate']
senticnet['frustrate_person'] = [-0.985, 0, 0.706, 0, '#sad', '#angry', -0.564, 'round_white', 'baby_chicken', 'oval_shape', 'baby_bird', 'inside_egg']
senticnet['frustrated'] = [-0.978, 0, 0.877, 0, '#sad', '#angry', -0.618, 'disappointed', 'defeatism', 'thwarted', 'foiled', 'discomfited']
senticnet['frustrating'] = [-0.132, 0.071, 0.694, -0.674, '#angry', '#disgusting', -0.476, 'bedevil', 'crucify', 'dun', 'aggravate', 'exasperation']
senticnet['frustration'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'anger', 'frustrate', 'mad', 'angry', 'resentment']
senticnet['fry'] = [-0.83, 0, 0.987, -0.535, '#sad', '#angry', -0.784, 'picaninny', 'kid', 'minor', 'tike', 'small_picaninny']
senticnet['fry_chicken'] = [0.061, 0, 0, 0.078, '#joyful', '#admirable', 0.046, 'fry_fish', 'fry_egg', 'season_meal', 'season_dish', 'make_cake']
senticnet['fry_egg'] = [0.061, 0, 0, 0.078, '#joyful', '#admirable', 0.046, 'fry_fish', 'fry_chicken', 'season_meal', 'season_dish', 'make_cake']
senticnet['fry_fish'] = [-0.057, 0, 0, -0.046, '#sad', '#disgusting', -0.034, 'salt_food', 'brown_hamburger', 'heat_meal', 'fry_chicken', 'bone_chicken']
senticnet['fuck'] = [0, 0, 0.741, -0.8, '#angry', '#disgusting', -0.514, 'sex', 'make_love', 'safe_sex', 'sexual_intercourse', 'become_aroused']
senticnet['fuck_all'] = [-0.671, 0, 0.691, -0.722, '#angry', '#disgusting', -0.695, 'null', 'zero', 'naught', 'zip', 'nothing']
senticnet['fuck_off'] = [-0.922, 0, 0.458, -0.922, '#sad', '#disgusting', -0.767, 'rude_person', 'rude', 'impolite', 'discourteous', 'bad_word']
senticnet['fuckhead'] = [-0.602, 0, 0.908, -0.841, '#angry', '#disgusting', -0.784, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['fuckup'] = [-0.773, 0, 0.503, -0.932, '#sad', '#disgusting', -0.736, 'butcher', 'incompetent', 'slouch', 'bungler', 'blunderer']
senticnet['fucus'] = [-0.896, 0, 0.556, -0.726, '#sad', '#disgusting', -0.726, 'rockweed', 'bladderwrack', 'black_rockweed', 'bladder_rockweed', 'tang']
senticnet['fuddle'] = [-0.855, 0, 0.583, -0.716, '#sad', '#disgusting', -0.718, 'muddle', 'rummage', 'mare_nest', 'welter', 'clutter']
senticnet['fudge'] = [0, 0, 0.77, -0.716, '#angry', '#disgusting', -0.495, 'mousse', 'brownie', 'cake', 'custard', 'cookie']
senticnet['fuel'] = [0, 0, 0, 0.882, '#admirable', '#admirable', 0.294, 'gas', 'inert_gas', 'diesel', 'oil', 'combustible']
senticnet['fuel_source'] = [0.072, 0.065, -0.068, 0.144, '#joyful', '#admirable', 0.071, 'gooey', 'paraffin', 'slick', 'goo', 'bee_product']
senticnet['fuggy'] = [-0.586, 0, 0.593, -0.979, '#angry', '#disgusting', -0.719, 'unvented', 'unventilated', 'unaerated', 'unoxygenated', 'stuffy']
senticnet['fugue'] = [0.514, -0.586, 0, 0.927, '#surprising', '#admirable', 0.676, 'genre', 'serious_music', 'chamber_music', 'opera', 'cantata']
senticnet['fulcrum'] = [0, 0.935, 0, 0.871, '#interesting', '#admirable', 0.602, 'multiple_purposes', 'start_run', 'wrap_around', 'carry_heavy_load', 'rub']
senticnet['fulfill'] = [0.783, 0.595, -0.209, 0.34, '#joyful', '#interesting', 0.503, 'live_up_to', 'fulfillment', 'gloating', 'gloatingly', 'complacency']
senticnet['fulfillment'] = [0.959, 0.821, 0, 0.892, '#joyful', '#admirable', 0.891, 'fulfill', 'glee', 'congratulate', 'live_up_to', 'reach_goal']
senticnet['fulgurant'] = [0, 0.993, 0, 0.937, '#interesting', '#admirable', 0.643, 'surprise', 'eye-popping', 'fulgurous', 'dazzling', 'bedaze']
senticnet['fulgurous'] = [0, 0, -0.752, 0, '#scared', '#scared', -0.251, 'daze', 'fulgurant', 'eye-popping', 'dazzling', 'bedaze']
senticnet['full'] = [0.295, 0.239, 0.049, 0.346, '#joyful', '#admirable', 0.277, 'absolute', 'never_end', 'infinite', 'total', 'unending']
senticnet['full_admiral'] = [0.688, -0.908, 0, 0.877, '#surprising', '#admirable', 0.824, 'fleet_admiral', 'rear_admiral', 'admiral', 'flag_officer', 'vice_admiral']
senticnet['full_air'] = [0, 0.864, 0, 0.909, '#interesting', '#admirable', 0.591, 'popular_unite_state', 'spherical', 'round_orb', 'round', 'seen_night_sky']
senticnet['full_bladder'] = [-0.068, -0.004, -0.085, -0.114, '#scared', '#disgusting', -0.088, 'find_toilet', 'find_restroom', 'drink_lot', 'serve_beer', 'throw_away_trash']
senticnet['full_circle'] = [0.047, 0, 0.009, 0.272, '#joyful', '#admirable', 0.103, 'rotation', 'rotate_movement', 'rotate', 'ninety_degree', 'circular_motion']
senticnet['full_complement'] = [0.814, -0.878, 0, 0.918, '#surprising', '#admirable', 0.87, 'ship_company', 'company', 'work_force', 'workforce', 'manpower']
senticnet['full_moon'] = [0.037, 0.09, 0.049, 0.223, '#interesting', '#admirable', 0.1, 'kick_ass', 'full_moon_party', 'wave_crowd', 'special_day', 'calendar']
senticnet['full_moon_party'] = [0.037, 0.09, 0.049, 0.223, '#interesting', '#admirable', 0.1, 'kick_ass', 'full_moon', 'wave_crowd', 'special_day', 'calendar']
senticnet['full_of_energy'] = [0.884, 0, 0, 0, '#joyful', '#joyful', 0.295, 'feel_good', 'active', 'up_and_coming', 'feel_energetic', 'power']
senticnet['full_of_oneself'] = [-0.766, 0, 0.513, -0.722, '#sad', '#disgusting', -0.667, 'snob', 'snooty', 'french_person', 'full_of_shit', 'french']
senticnet['full_of_shit'] = [-0.252, 0, -0.216, -0.048, '#sad', '#scared', -0.172, 'put_box', 'tell_lie', 'lower_standard', 'say_prayer', 'receive_punishment']
senticnet['full_radiator'] = [0.566, -0.553, 0, 0.776, '#joyful', '#admirable', 0.632, 'whole', 'black_body', 'blackbody', 'natural_object', 'stone']
senticnet['full_stomach'] = [0.047, 0, 0.009, 0.272, '#joyful', '#admirable', 0.103, 'eat', 'full', 'stomach', 'eat_lot', 'eat_food']
senticnet['full_stop'] = [0, 0.824, 0, 0.818, '#interesting', '#admirable', 0.547, 'sentence_end', 'end', 'sequence', 'sport_score', 'dot']
senticnet['full_water'] = [0.037, 0.09, 0.049, 0.223, '#interesting', '#admirable', 0.1, 'depth', 'salty', 'vast', 'oceanside', 'along_beach']
senticnet['fullness'] = [0.726, 0, 0, 0.996, '#joyful', '#admirable', 0.574, 'mood', 'great_relief', 'clean_up_mess', 'good_emotion', 'full']
senticnet['fully_developed'] = [0.72, 0, 0, 0.879, '#joyful', '#admirable', 0.533, 'friendship', 'friend', 'companion', 'rely_on_other_person', 'adult']
senticnet['fulsome'] = [-0.527, 0, 0.651, -0.542, '#angry', '#disgusting', -0.573, 'feigned', 'dissimulative', 'specious', 'hypocritical', 'insincere']
senticnet['fumble'] = [-0.714, 0, 0.924, -0.542, '#sad', '#angry', -0.727, 'flub', 'blunder', 'blooper', 'bungle', 'botch']
senticnet['fumbling'] = [-0.983, 0, 0.505, -0.832, '#sad', '#disgusting', -0.773, 'lowly', 'bungled', 'botched', 'unskilled', 'bungling']
senticnet['fume'] = [0, 0, 0.744, -0.713, '#angry', '#disgusting', -0.486, 'adjust_seat', 'car_wheel', 'fasten_seatbelt', 'road_rage', 'skid_mark']
senticnet['fun'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'entertainment', 'enjoyment', 'pleasure', 'happiness', 'amusement']
senticnet['fun_activity'] = [0.159, -0.064, 0, 0.117, '#joyful', '#admirable', 0.113, 'kid_activity', 'have_fun', 'form_of_social_interaction', 'stage_production', 'fun_time']
senticnet['fun_around'] = [0.144, 0.153, -0.097, 0.17, '#interesting', '#admirable', 0.123, 'max', 'loyal', 'cute', 'hairy', 'play_dead']
senticnet['fun_child'] = [0.144, 0.153, -0.097, 0.17, '#interesting', '#admirable', 0.123, 'fun', 'child_game', 'child', 'child_play', 'happiness']
senticnet['fun_exercise'] = [0.998, 0.702, 0, 0, '#joyful', '#interesting', 0.567, 'athletic', 'keep_fit', 'recreational', 'get_physically_fit', 'fit_person']
senticnet['fun_game'] = [0, -0.089, 0.016, 0.064, '#surprising', '#admirable', 0.046, 'rough_game', 'team_sport', 'rough_sport', 'ball_sport', 'type_of_sport']
senticnet['fun_learn_play'] = [-0.12, 0, 0, -0.063, '#sad', '#disgusting', -0.061, 'painful', 'uncomfortable', 'violent', 'costly', 'expensive']
senticnet['fun_pastime'] = [0.084, -0.087, 0.025, 0, '#joyful', '#surprising', 0.049, 'pastime', 'stage_production', 'have_fun', 'fun_activity', 'diversion']
senticnet['fun_place'] = [0.197, -0.087, 0, -0.045, '#joyful', '#surprising', 0.08, 'have_fun', 'banquet', 'rave', 'orgy', 'disco']
senticnet['fun_play'] = [0.814, 0, 0, 0.856, '#joyful', '#admirable', 0.557, 'radical', 'enjoyable', 'just_fun', 'good_mental_health', 'a_lot_of_fun']
senticnet['fun_read'] = [0.089, -0.017, 0.033, 0.082, '#joyful', '#admirable', 0.052, 'informative', 'epic', 'ephemeral', 'informational', 'ads']
senticnet['fun_ride'] = [0, 0, 0, 0.165, '#admirable', '#admirable', 0.055, 'get_around', 'passenger_car', 'walk_along', 'car_go', 'go_elsewhere']
senticnet['fun_sport'] = [0.034, -0.074, 0.044, 0.079, '#surprising', '#admirable', 0.048, 'pastime', 'sport', 'popular_sport', 'ball_sport', 'outdoor_sport']
senticnet['fun_time'] = [0.143, -0.168, 0, 0, '#joyful', '#surprising', 0.104, 'fun_activity', 'social_gathering', 'diversion', 'nativity', 'have_fun']
senticnet['fun_watch'] = [0.106, -0.079, 0.033, 0, '#joyful', '#surprising', 0.051, 'fun_pastime', 'game_toy', 'stage_production', 'have_fun', 'fun_activity']
senticnet['fun_with_friend'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'competition', 'recreation', 'play_game_together', 'play_friend', 'friend']
senticnet['function'] = [0.075, 0, -0.069, 0.203, '#joyful', '#admirable', 0.07, 'special', 'join_together', 'occurrence', 'gala', 'gathering']
senticnet['functional'] = [0.986, -0.629, 0, 0.807, '#joyful', '#admirable', 0.807, 'operable', 'serviceable', 'user_friendly', 'usable', 'operational']
senticnet['functional_illiterate'] = [-0.901, 0, 0.76, -0.871, '#sad', '#disgusting', -0.844, 'analphabet', 'analphabetic', 'illiterate', 'ignoramus', 'know_nothing']
senticnet['functionality'] = [0.99, -0.88, 0, 0.831, '#joyful', '#surprising', 0.9, 'practicality', 'sensibleness', 'viability', 'usefulness', 'realism']
senticnet['functionary'] = [0, 0.233, -0.079, 0.113, '#interesting', '#admirable', 0.089, 'structure', 'construction_worker', 'peasant', 'builder', 'maker']
senticnet['fund'] = [0, 0.855, 0, 0.798, '#interesting', '#admirable', 0.551, 'business', 'income', 'money_owe', 'revenue', 'extortion']
senticnet['fundamental'] = [0, 0.148, 0, 0.148, '#interesting', '#admirable', 0.099, 'status', 'basic_need', 'mandatory', 'basic', 'classification']
senticnet['fundamentalist'] = [-0.911, 0, 0.794, -0.934, '#sad', '#disgusting', -0.88, 'fanatic', 'extremist', 'obsession', 'stubborn', 'violent']
senticnet['funds'] = [0.534, -0.868, 0, 0.736, '#surprising', '#admirable', 0.713, 'escrow_funds', 'finances', 'monetary_resource', 'cash_in_hand', 'pecuniary_resource']
senticnet['funeral'] = [-0.756, 0, -0.733, 0, '#sad', '#scared', -0.496, 'graveyard', 'tombstone', 'cemetery', 'burial', 'underworld']
senticnet['funeral_celebration'] = [-0.098, 0, -0.11, 0, '#sad', '#scared', -0.069, 'memento', 'memorial', 'funeral', 'funerary', 'cry']
senticnet['funeral_director'] = [-0.911, 0, 0.794, -0.934, '#sad', '#disgusting', -0.88, 'grave', 'dead_person', 'funeral', 'tomb', 'coffin']
senticnet['funeral_home'] = [-0.707, 0, 0, 0, '#sad', '#sad', -0.236, 'death_row', 'another_planet', 'loose_end', 'car_race', 'mortuary']
senticnet['funeral_pyre'] = [-0.77, 0, 0.588, -0.801, '#sad', '#disgusting', -0.72, 'heap', 'agglomerate', 'piles', 'mound', 'cumulation']
senticnet['funerary'] = [-0.098, 0, -0.11, 0, '#sad', '#scared', -0.069, 'funeral_celebration', 'memorial', 'funeral', 'memento', 'cry']
senticnet['funfair'] = [-0.726, 0, 0.978, -0.861, '#angry', '#disgusting', -0.855, 'amusement_park', 'commons', 'pleasure_ground', 'village_green', 'tract']
senticnet['fungal_infection'] = [-0.964, 0, 0.694, -0.623, '#sad', '#angry', -0.76, 'ringworm', 'mycosis', 'kerion', 'tinea_pedis', 'athlete_foot']
senticnet['fungibility'] = [0.928, -0.651, 0, 0.856, '#joyful', '#admirable', 0.812, 'transferability', 'convertibility', 'changeableness', 'changeability', 'permutability']
senticnet['fungible'] = [0.552, -0.585, 0, 0.762, '#surprising', '#admirable', 0.633, 'transposable', 'permutable', 'exchangeable', 'commutable', 'substitutable']
senticnet['fungicide'] = [0.932, -0.56, 0, 0.617, '#joyful', '#admirable', 0.703, 'antifungal', 'antifungal_agent', 'lamisil', 'antimycotic', 'antimycotic_agent']
senticnet['fungus'] = [-0.872, 0, 0.723, -0.946, '#sad', '#disgusting', -0.847, 'potato_wart_fungus', 'bottom_rot_fungus', 'potato_fungus', 'black_root_rot_fungus', 'sclerotinia']
senticnet['funiculus'] = [0, 0.141, 0.01, 0.115, '#interesting', '#admirable', 0.082, 'fruit', 'rind', 'achene', 'seed', 'pip']
senticnet['funny'] = [0.881, 0, 0, 0.976, '#joyful', '#admirable', 0.619, 'fun', 'guffaw', 'make_laugh', 'amuse', 'droll']
senticnet['funny_farm'] = [-0.807, 0, 0.798, -0.968, '#sad', '#disgusting', -0.858, 'asylum', 'mental_hospital', 'psychiatric_hospital', 'mental_institution', 'mental_home']
senticnet['funny_friend'] = [0.056, 0.157, 0, 0.154, '#interesting', '#admirable', 0.122, 'enjoy_outdoors', 'competition', 'learn_teamwork', 'exercise_entertainment', 'entertainment']
senticnet['funny_house'] = [-0.861, 0, 0.822, -0.617, '#sad', '#angry', -0.767, 'asylum', 'mental_hospital', 'psychiatric_hospital', 'mental_institution', 'mental_home']
senticnet['funny_joke'] = [0.225, -0.049, 0, 0.07, '#joyful', '#admirable', 0.115, 'funny', 'social_event', 'amuse', 'amusement', 'make_laugh']
senticnet['funny_look'] = [0, 0, 0.988, -0.803, '#angry', '#disgusting', -0.597, 'fight_against', 'uprise', 'rival', 'disagreement', 'anti']
senticnet['funny_man'] = [0.793, -0.829, 0, 0, '#joyful', '#surprising', 0.541, 'heroism', 'perpetrator', 'role_play', 'role', 'act']
senticnet['funny_moment'] = [0.928, 0.778, 0, 0, '#joyful', '#interesting', 0.569, 'child_book', 'disney_cartoon', 'children_story', 'child_movie', 'childhood']
senticnet['fur'] = [-0.835, 0, 0, -0.708, '#sad', '#disgusting', -0.514, 'animal_hair', 'animal_fur', 'pelt', 'strand', 'make_wool']
senticnet['fur_keep_warm'] = [-0.762, 0, 0, -0.738, '#sad', '#disgusting', -0.5, 'worm_intestine', 'bad_breath', 'bald', 'tic', 'claw']
senticnet['furbish_up'] = [-0.564, 0, 0.917, -0.889, '#angry', '#disgusting', -0.79, 'troubleshoot', 'fiddle', 'fill', 'darn', 'sole']
senticnet['furious'] = [-0.137, 0.145, 0.624, -0.638, '#angry', '#disgusting', -0.418, 'enraged', 'infuriated', 'maddened', 'angered', 'indignantly']
senticnet['furiously'] = [-0.127, 0.13, 0.647, -0.648, '#angry', '#disgusting', -0.431, 'infuriate', 'exasperating', 'infuriating', 'maddening', 'dudgeon']
senticnet['furiousness'] = [-0.63, 0, 0.921, -0.621, '#sad', '#angry', -0.724, 'fury', 'wildness', 'ferocity', 'fierceness', 'savagery']
senticnet['furlike'] = [-0.754, 0, 0.734, -0.825, '#sad', '#disgusting', -0.771, 'puberulent', 'sericeous', 'haired', 'pappose', 'pilous']
senticnet['furnace'] = [0.091, 0, 0.034, 0.049, '#joyful', '#admirable', 0.035, 'fireplace', 'flame', 'huge_fire', 'fire', 'heater']
senticnet['furnish'] = [0, 0.128, -0.122, 0.183, '#interesting', '#admirable', 0.063, 'support_roof', 'interior', 'ceiling', 'window_door', 'frame']
senticnet['furnishing'] = [-0.741, 0, 0.722, -0.562, '#sad', '#angry', -0.675, 'trapping', 'accouterment', 'wear', 'wearable', 'belt']
senticnet['furniture'] = [0.514, -0.979, 0, 0.899, '#surprising', '#admirable', 0.797, 'board', 'beaver_board', 'fiberboard', 'dry_wall', 'particle_board']
senticnet['furniture_shop'] = [0.056, 0.157, 0, 0.154, '#interesting', '#admirable', 0.122, 'hat_shop', 'chest', 'nervous_system', 'crotch', 'skeleton']
senticnet['furniture_store'] = [0.056, 0.157, 0, 0.154, '#interesting', '#admirable', 0.122, 'home_depot', 'lumberyard', 'carpet_store', 'front_porch', 'shoe_shop']
senticnet['furnitures'] = [0, -0.069, 0, 0, '#surprising', '#surprising', 0.023, 'rooms', 'home', 'apartment', 'kitchen', 'flats']
senticnet['furrow'] = [0.689, -0.565, 0, 0.74, '#joyful', '#admirable', 0.665, 'crease', 'crinkle', 'wrinkle', 'heart_line', 'seam']
senticnet['furry'] = [0, 0, 0.07, 0, '#angry', '#angry', -0.023, 'animal_hair', 'animal_skin', 'dog_fur', 'fluffy_animal', 'animal_fur']
senticnet['furry_creature'] = [0.03, 0.068, -0.044, 0.093, '#interesting', '#admirable', 0.049, 'critter', 'equine', 'live_creature', 'beast', 'domesticate_animal']
senticnet['further'] = [0.846, -0.765, 0, 0.688, '#joyful', '#surprising', 0.766, 'add_on', 'promote', 'encourage', 'boost', 'advance']
senticnet['further_career'] = [0.847, 0.643, 0, 0.973, '#joyful', '#admirable', 0.821, 'get_high_education', 'prepare_exam', 'demonstrate_knowledge', 'earn_money', 'get_better_job']
senticnet['further_education'] = [0.847, 0.643, 0, 0.973, '#joyful', '#admirable', 0.821, 'further_knowledge', 'further_career', 'further', 'school_student', 'education']
senticnet['further_goal'] = [0.918, 0.476, -0.197, 0.417, '#joyful', '#interesting', 0.538, 'fail', 'flunk', 'try_again', 'cheat', 'wrong_answer']
senticnet['further_knowledge'] = [0.918, 0.476, -0.197, 0.417, '#joyful', '#interesting', 0.538, 'explain_problem', 'thrown_out', 'make_cry', 'page_through_book', 'sell_book']
senticnet['furtive'] = [0, 0, -0.77, -0.712, '#scared', '#disgusting', -0.494, 'backstair', 'surreptitious', 'sneak', 'sneaky', 'stealthy']
senticnet['furtiveness'] = [0.742, -0.839, 0, 0.889, '#surprising', '#admirable', 0.823, 'secretiveness', 'sneakiness', 'stealthiness', 'unsociability', 'unsociableness']
senticnet['fury'] = [0, 0, 0.786, -0.965, '#angry', '#disgusting', -0.584, 'madness', 'rage', 'temper', 'irritate', 'animosity']
senticnet['fuse'] = [0.13, 0.097, -0.077, 0.198, '#joyful', '#admirable', 0.116, 'jiggle', 'back_forth', 'vibrate', 'blend', 'mixture']
senticnet['fuse_together'] = [0.065, 0.209, -0.119, 0.297, '#interesting', '#admirable', 0.151, 'come_together', 'put_together', 'gather', 'bring_together', 'inclusion']
senticnet['fuss'] = [-0.748, 0, 0.982, -0.506, '#sad', '#angry', -0.745, 'bother', 'trouble', 'disturbance', 'hassle', 'activity']
senticnet['fuss_about'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'agitation', 'up_roar', 'commotion', 'disturbance', 'upset']
senticnet['fussiness'] = [-0.54, 0, 0.601, -0.69, '#angry', '#disgusting', -0.61, 'ill_humor', 'distemper', 'pet', 'testiness', 'touchiness']
senticnet['fusspot'] = [-0.827, 0, 0.556, -0.867, '#sad', '#disgusting', -0.75, 'worrier', 'killjoy', 'worrywart', 'unwelcome_person', 'party_pooper']
senticnet['fussy'] = [-0.73, 0.288, -0.367, -0.108, '#sad', '#scared', -0.306, 'fastidious', 'hard_to_please', 'anxiety', 'concerned', 'pester']
senticnet['fustian'] = [-0.544, 0, 0.7, -0.64, '#angry', '#disgusting', -0.628, 'flourish', 'rant', 'bombast', 'ornateness', 'claptrap']
senticnet['futile'] = [0, -0.869, 0.992, -0.92, '#angry', '#disgusting', -0.348, 'pointless', 'useless', 'small', 'embarrassment', 'insignificant']
senticnet['futility'] = [-0.704, 0, 0, -0.841, '#sad', '#disgusting', -0.515, 'inutility', 'impracticality', 'worthlessness', 'impracticability', 'failure']
senticnet['future_robot'] = [0.065, 0.209, -0.119, 0.297, '#interesting', '#admirable', 0.151, 'drive_recklessly', 'type_of_dog', 'dog', 'dangerous', 'drive']
senticnet['futures_contract'] = [0.868, -0.847, 0, 0.673, '#joyful', '#surprising', 0.796, 'instrument', 'option', 'derivative_instrument', 'legal_document', 'legal_instrument']
senticnet['futurism'] = [0, 0, 0, -0.122, '#disgusting', '#disgusting', -0.041, 'native_person', 'revolutionary', 'republic', 'revolution', 'look_ahead']
senticnet['fuzz'] = [0, 0, 0.064, -0.04, '#angry', '#disgusting', -0.035, 'calyx', 'funiculus', 'plant_product', 'bird_food', 'agricultural_product']
senticnet['fuzziness'] = [0.973, -0.777, 0, 0.983, '#joyful', '#admirable', 0.911, 'opaqueness', 'faintness', 'dimness', 'opacity', 'vagueness']
senticnet['fuzzy'] = [0.03, 0.069, 0, 0.168, '#interesting', '#admirable', 0.089, 'softness', 'soft_cloth', 'texture', 'soft_fabric', 'curly']
senticnet['fuzzy_animal'] = [0.065, 0.209, -0.119, 0.297, '#interesting', '#admirable', 0.151, 'domestic_pet', 'cute', 'woolly_animal', 'hairy', 'animal_furry']
senticnet['gab'] = [-0.515, 0, 0.545, -0.911, '#angry', '#disgusting', -0.657, 'gossip', 'chitchat', 'chit_chat', 'chat', 'small_talk']
senticnet['gabble'] = [-0.875, 0, 0.838, -0.695, '#sad', '#angry', -0.803, 'prate', 'prattle', 'gibber', 'blabber', 'blither']
senticnet['gabby'] = [0.949, -0.694, 0, 0.992, '#joyful', '#admirable', 0.878, 'chatty', 'voluble', 'garrulous', 'loquacious', 'talky']
senticnet['gable'] = [0.083, -0.036, 0, 0, '#joyful', '#surprising', 0.04, 'good_view', 'bird_droppings', 'slate', 'nature', 'homeowner']
senticnet['gaboon_viper'] = [-0.96, 0, 0.865, -0.753, '#sad', '#angry', -0.859, 'viper', 'ophidian', 'serpent', 'snake', 'adder']
senticnet['gad'] = [-0.665, 0, 0.949, -0.754, '#angry', '#disgusting', -0.789, 'roam', 'move', 'gallivant', 'jazz_around', 'travel']
senticnet['gadgetry'] = [0.843, -0.998, 0, 0.706, '#joyful', '#surprising', 0.849, 'contrivance', 'gimbal', 'injector', 'mod_con', 'device']
senticnet['gag'] = [0.632, -0.861, 0, 0.703, '#surprising', '#admirable', 0.732, 'humor', 'wow', 'funny', 'dirty_joke', 'dirty_story']
senticnet['gaiety'] = [0.918, 0.476, -0.197, 0.417, '#joyful', '#interesting', 0.538, 'merriment', 'cheery', 'festal', 'playfulness', 'pridefulness']
senticnet['gain'] = [0.733, 0.991, 0, 0.843, '#interesting', '#admirable', 0.856, 'improvement', 'advantage', 'return', 'receive', 'contribution']
senticnet['gain_energy'] = [0.042, -0.043, -0.053, -0.144, '#scared', '#disgusting', -0.037, 'slow_heart_beat', 'feel_refreshed', 'late_work', 'tired', 'take_breath']
senticnet['gain_experience'] = [0.918, 0.476, -0.197, 0.417, '#joyful', '#interesting', 0.538, 'new_experience', 'experience', 'study', 'listen', 'gain']
senticnet['gain_ground'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'climb_hill', 'reach_top', 'win_battle', 'score_goal', 'accomplish_mission']
senticnet['gain_information'] = [0.941, 0.748, 0, 0.56, '#joyful', '#interesting', 0.75, 'keep_up_current_event', 'gain_knowledge', 'expand_mind', 'pass_knowledge', 'get_information']
senticnet['gain_insight'] = [0.892, 0.897, 0, 0.86, '#joyful', '#interesting', 0.883, 'understand', 'trivia', 'great_understand', 'knowledge', 'know_fact']
senticnet['gain_interest'] = [0.896, 0, 0, 0, '#joyful', '#joyful', 0.299, 'walk_exercise', 'pay_dinner', 'subscribe_magazine', 'buy_candy', 'buy_soda']
senticnet['gain_knowledge'] = [0.932, 0.919, 0, 0.996, '#joyful', '#admirable', 0.949, 'increase_knowledge', 'become_smart', 'learn', 'become_intelligent', 'learn_information']
senticnet['gain_land'] = [0.065, 0.209, -0.119, 0.297, '#interesting', '#admirable', 0.151, 'buy_present_for_others', 'fight_inflation', 'buy_love', 'buy_present', 'buy_christmas_present']
senticnet['gain_money'] = [0.779, 0.978, 0, 0.975, '#interesting', '#admirable', 0.911, 'investment_return', 'monetary_gain', 'financial_gain', 'money_earn', 'extra_money']
senticnet['gain_new_knowledge'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'accumulate_knowledge', 'know', 'read_out_loud', 'gather_information', 'learn_history']
senticnet['gain_power'] = [0.852, 0, 0, 0, '#joyful', '#joyful', 0.284, 'transmit_disease', 'sometimes_bad', 'end_war', 'protect_family', 'rape']
senticnet['gain_qualification'] = [-0.146, -0.055, 0, -0.113, '#sad', '#disgusting', -0.068, 'finish_college', 'learn_evolution', 'complete_course', 'get_high_education', 'obtain_degree']
senticnet['gain_respect'] = [0.914, 0.836, 0, 0.799, '#joyful', '#interesting', 0.85, 'experience_life', 'happiness', 'good_feeling', 'appreciate', 'say_love']
senticnet['gain_skill'] = [0.716, 0.845, 0, 0.814, '#interesting', '#admirable', 0.792, 'entertain_others', 'develop_skill', 'learn_play', 'lovely_music', 'appreciate_music']
senticnet['gain_speed'] = [-0.061, 0.149, -0.116, 0.223, '#interesting', '#admirable', 0.065, 'pull_car', 'corner_well', 'appear_suddenly', 'action', 'movement']
senticnet['gain_territory'] = [0, 0, -0.117, -0.17, '#scared', '#disgusting', -0.096, 'conquer_enemy', 'keep_peace', 'make_war', 'defeat_enemy', 'kill_soldier']
senticnet['gain_understand'] = [0.802, 0.795, 0, 0.839, '#joyful', '#admirable', 0.812, 'learn_much', 'read_out_loud', 'discover_new', 'know_new', 'know_world']
senticnet['gain_wealth'] = [0.839, 0.861, 0, 0.738, '#joyful', '#interesting', 0.813, 'become_rich', 'increase_wealth', 'save_money', 'become_wealthy', 'find_money']
senticnet['gain_weight'] = [-0.889, 0, 0, 0, '#sad', '#sad', -0.296, 'get_laugh', 'tooth_hurt', 'choke_death', 'sore_throat', 'feel_satisfied']
senticnet['gainer'] = [0.868, -0.89, 0, 0.803, '#joyful', '#surprising', 0.854, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['gainful'] = [0.998, -0.54, 0, 0.856, '#joyful', '#admirable', 0.798, 'lucrative', 'moneymaking', 'profitable', 'paying', 'paid']
senticnet['gainly'] = [0.734, -0.531, 0, 0.914, '#joyful', '#admirable', 0.726, 'graceful', 'gracile', 'willowy', 'elegant', 'smooth']
senticnet['gait'] = [-0.155, 0, 0.028, 0, '#sad', '#angry', -0.061, 'use_leg', 'walk_quickly', 'casual', 'take_step', 'strut']
senticnet['gala'] = [0.138, -0.113, -0.066, 0.068, '#joyful', '#surprising', 0.084, 'reunion', 'special_moment', 'festivity', 'special_happen', 'celebration']
senticnet['galaxy'] = [0, 0.945, 0, 0.794, '#interesting', '#admirable', 0.58, 'dwarf_planet', 'universe', 'planetary', 'sun', 'moon']
senticnet['gale'] = [-0.984, 0, 0.96, -0.923, '#sad', '#angry', -0.956, 'thunderstorm', 'storm', 'bad_weather', 'heavy_rain', 'hurricane']
senticnet['galere'] = [-0.692, 0, 0.829, -0.695, '#angry', '#disgusting', -0.739, 'camp', 'pack', 'clique', 'coterie', 'ingroup']
senticnet['gall'] = [0.034, 0.126, 0.758, -0.673, '#angry', '#disgusting', -0.424, 'resentfully', 'rancor', 'seek_revenge', 'resentful', 'warpath']
senticnet['gallantry'] = [0.603, -0.987, 0, 0.648, '#surprising', '#admirable', 0.746, 'urbanity', 'niceness', 'politeness', 'good_manners', 'politesse']
senticnet['gallery'] = [0.07, 0, 0, 0, '#joyful', '#joyful', 0.023, 'artist', 'artwork', 'sculpture', 'tapestry', 'drawing']
senticnet['gallery_open'] = [0, 0.074, 0, 0.055, '#interesting', '#admirable', 0.043, 'art_show', 'museum', 'antique_store', 'laundromat', 'friend_wedding']
senticnet['galling'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'annoying', 'vexatious', 'teasing']
senticnet['gallivant'] = [0.779, -0.55, 0, 0.678, '#joyful', '#admirable', 0.669, 'range', 'ramble', 'vagabond', 'tramp', 'roam']
senticnet['gallon'] = [0.092, 0.07, 0.036, 0.068, '#joyful', '#interesting', 0.065, 'pint', 'quart', 'lite', 'ounce', 'liquid_measurement']
senticnet['galosh'] = [-0.881, 0, 0.75, -0.855, '#sad', '#disgusting', -0.829, 'rubber', 'overshoe', 'golosh', 'arctic', 'gumshoe']
senticnet['galvanize'] = [-0.569, 0, 0.897, -0.651, '#angry', '#disgusting', -0.706, 'shock', 'floor', 'ball_over', 'blow_out_of_water', 'take_aback']
senticnet['gamble'] = [0, 0, 0.957, -0.725, '#angry', '#disgusting', -0.561, 'pass_card', 'card_game', 'go_casino', 'desire_win', 'magic_trick']
senticnet['gamble_game'] = [0.869, 0.728, 0, 0, '#joyful', '#interesting', 0.532, 'game_piece', 'greeting', 'form_of_gambling', 'kid_game', 'game']
senticnet['gamble_money'] = [0, 0, 0.725, -0.812, '#angry', '#disgusting', -0.512, 'win_money', 'funny_friend', 'play_friend', 'waste_money', 'loser']
senticnet['gambler'] = [-0.786, 0, 0.944, -0.511, '#sad', '#angry', -0.747, 'loser', 'speculator', 'mortal', 'better', 'bettor']
senticnet['gamblin'] = [-0.039, -0.003, 0, -0.05, '#sad', '#disgusting', -0.029, 'salt_food', 'bone_chicken', 'brown_hamburger', 'heat_meal', 'play_jack']
senticnet['gambling'] = [-0.887, 0, 0, -0.902, '#sad', '#disgusting', -0.596, 'bad_habit', 'smoke_cigarette', 'drink_alcohol', 'vice_addiction', 'vice']
senticnet['gambling_addiction'] = [-0.889, 0, 0, 0, '#sad', '#sad', -0.296, 'bad_habit', 'smoke_cigarette', 'drink_alcohol', 'vice', 'gambling']
senticnet['gambol'] = [0.525, -0.857, 0, 0.599, '#surprising', '#admirable', 0.66, 'frolic', 'coquetry', 'romp', 'play', 'caper']
senticnet['game'] = [-0.975, 0, 0.677, -0.955, '#sad', '#disgusting', -0.869, 'stunt', 'animate_being', 'mutant', 'invertebrate', 'varmint']
senticnet['game_action'] = [0.056, 0, 0, 0.145, '#joyful', '#admirable', 0.067, 'kid_activity', 'form_of_social_interaction', 'fun_activity', 'activity', 'outdoor_activity']
senticnet['game_card'] = [0.028, -0.006, 0, 0.096, '#joyful', '#admirable', 0.043, 'action_figure', 'toy_car', 'racquet', 'toy_marble', 'yo-yo']
senticnet['game_chance'] = [0.035, -0.054, 0, 0.101, '#surprising', '#admirable', 0.063, 'form_of_gambling', 'game', 'consider_good_luck', 'game_skill', 'popular_game']
senticnet['game_chess'] = [0.048, 0, 0, 0.092, '#joyful', '#admirable', 0.047, 'find_other_player', 'know_how_play_baseball', 'step_up_plate', 'contest', 'babe_ruth']
senticnet['game_part'] = [0, 0.894, 0, 0.954, '#interesting', '#admirable', 0.616, 'build_block', 'hard_paper', 'sound_like', 'kid_game', 'with_person']
senticnet['game_piece'] = [0, -0.057, 0.013, 0.127, '#surprising', '#admirable', 0.057, 'gamble_game', 'play_device', 'play_object', 'plaything', 'child_toy']
senticnet['game_room'] = [0.048, 0, 0, 0.092, '#joyful', '#admirable', 0.047, 'grandma_house', 'chess_tournament', 'old_folk_home', 'computer_lab', 'mortuary']
senticnet['game_show'] = [-0.051, 0.29, -0.115, 0.264, '#interesting', '#admirable', 0.129, 'good_buy', 'good_price', 'bargain', 'business_deal', 'cheap_price']
senticnet['game_skill'] = [0, -0.077, 0, 0.073, '#surprising', '#admirable', 0.05, 'popular_game', 'violent_sport', 'rough_sport', 'type_of_sport', 'team_sport']
senticnet['game_toy'] = [0.071, -0.096, 0.056, 0, '#joyful', '#surprising', 0.037, 'fun_watch', 'stage_production', 'child_game', 'kid_activity', 'fun_activity']
senticnet['gamelan'] = [-0.507, 0, 0.902, -0.548, '#angry', '#disgusting', -0.652, 'ensemble', 'jug_band', 'pop_group', 'mariachi', 'skiffle_group']
senticnet['games'] = [0.738, 0.961, 0, 0, '#joyful', '#interesting', 0.566, 'amusement', 'entertainment', 'fun', 'play', 'alleviate_boredom']
senticnet['gaminess'] = [-0.698, 0, 0.597, -0.569, '#sad', '#angry', -0.621, 'improperness', 'impropriety', 'raciness', 'spiciness', 'indelicacy']
senticnet['gamma_ray'] = [0.048, 0, 0, 0.092, '#joyful', '#admirable', 0.047, 'radio_wave', 'sun', 'solar_cell', 'x-ray', 'cosmic_ray']
senticnet['gammon'] = [0.648, -0.539, 0, 0.94, '#joyful', '#admirable', 0.709, 'bacon_strip', 'flitch', 'side_of_bacon', 'bacon', 'cut_of_pork']
senticnet['gamut'] = [0.624, -0.654, 0, 0.939, '#surprising', '#admirable', 0.739, 'reach', 'range', 'compass', 'scope', 'orbit']
senticnet['gang'] = [0.867, -0.846, 0, 0.876, '#joyful', '#admirable', 0.863, 'meet', 'team', 'team_up', 'embed', 'aggroup']
senticnet['gangster_moll'] = [0.794, -0.508, 0, 0.531, '#joyful', '#admirable', 0.611, 'felon', 'crook', 'malefactor', 'outlaw', 'criminal']
senticnet['gaol'] = [0.977, -0.556, 0, 0.679, '#joyful', '#admirable', 0.737, 'lockup', 'holding_cell', 'workhouse', 'bastille', 'hoosegow']
senticnet['gap'] = [-0.229, 0, -0.095, -0.165, '#sad', '#disgusting', -0.163, 'inequality', 'reject', 'discard', 'divergency', 'difference']
senticnet['gape'] = [-0.129, -0.015, -0.098, -0.111, '#sad', '#disgusting', -0.108, 'gloat', 'blown', 'gash', 'mistake', 'ouch']
senticnet['garage'] = [0, -0.075, 0, 0, '#surprising', '#surprising', 0.025, 'bicycle_storage_area', 'storeroom', 'trunks', 'motor_oil', 'bicycle']
senticnet['garage_sale'] = [0.048, 0, 0, 0.092, '#joyful', '#admirable', 0.047, 'gym_locker', 'observatory', 'prison_cell', 'luggage_store', 'luggage_compartment']
senticnet['garb'] = [-0.578, 0, 0.734, -0.74, '#angry', '#disgusting', -0.684, 'finery', 'sportswear', 'athletic_wear', 'activewear', 'costume']
senticnet['garbage'] = [-0.982, 0, 0, -0.994, '#sad', '#disgusting', -0.659, 'store_trash', 'trash', 'hold_trash', 'rubbish', 'put_trash']
senticnet['garbage_bag'] = [0, 0, 0, -0.758, '#disgusting', '#disgusting', -0.253, 'carry_document', 'lock_box', 'legal_document', 'carry_paper', 'store_document']
senticnet['garbage_can'] = [-0.992, 0, 0, -0.906, '#sad', '#disgusting', -0.633, 'trash', 'garbage', 'store_trash', 'wastebasket', 'rubbish']
senticnet['garbage_carter'] = [-0.533, 0, 0.954, -0.541, '#angry', '#disgusting', -0.676, 'garbage_man', 'garbageman', 'garbage_collector', 'hauler', 'garbage_hauler']
senticnet['garbage_collector'] = [-0.533, 0, 0.954, -0.541, '#angry', '#disgusting', -0.676, 'garbage_man', 'garbageman', 'hauler', 'garbage_carter', 'garbage_hauler']
senticnet['garbage_dump'] = [-0.72, 0, 0, -0.873, '#sad', '#disgusting', -0.531, 'trash_bin', 'garage', 'repair_shop', 'tool', 'dumpster']
senticnet['garbage_hauler'] = [-0.533, 0, 0.954, -0.541, '#angry', '#disgusting', -0.676, 'garbage_man', 'garbageman', 'garbage_collector', 'garbage_carter', 'hauler']
senticnet['garbage_heap'] = [-0.707, 0, 0.611, -0.695, '#sad', '#disgusting', -0.671, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'wasteyard']
senticnet['garbage_man'] = [-0.533, 0, 0.954, -0.541, '#angry', '#disgusting', -0.676, 'hauler', 'garbageman', 'garbage_collector', 'garbage_carter', 'garbage_hauler']
senticnet['garbage_waste'] = [-0.931, 0, 0, -0.754, '#sad', '#disgusting', -0.562, 'garbage', 'rubbish', 'refuse', 'store_trash', 'waste']
senticnet['garbageman'] = [0.665, -0.649, 0, 0.871, '#joyful', '#admirable', 0.728, 'garbage_man', 'hauler', 'garbage_collector', 'garbage_carter', 'garbage_hauler']
senticnet['garbled'] = [-0.84, 0, 0.522, -0.989, '#sad', '#disgusting', -0.784, 'unconnected', 'confused', 'scattered', 'disordered', 'incoherent']
senticnet['garboil'] = [-0.524, 0, 0.677, -0.874, '#angry', '#disgusting', -0.692, 'hurly_burly', 'kerfuffle', 'commotion', 'disruption', 'disturbance']
senticnet['garden'] = [0, 0.085, 0, 0.146, '#interesting', '#admirable', 0.077, 'adam_and_eve', 'apple', 'fruit', 'tree', 'outdoor']
senticnet['garden_implement'] = [0.048, 0, 0, 0.092, '#joyful', '#admirable', 0.047, 'use_screwdriver', 'tool', 'study_physic', 'take_pulse', 'medical_equipment']
senticnet['garden_plant'] = [-0.037, 0.097, -0.046, 0.091, '#interesting', '#admirable', 0.035, 'fragrant', 'sexual', 'small_flower', 'use_decoration', 'usual_green']
senticnet['garden_salad'] = [0.041, -0.045, 0, 0, '#joyful', '#surprising', 0.029, 'meatloaf', 'salad', 'delicious_meal', 'casserole', 'apple_pie']
senticnet['garden_shed'] = [-0.037, 0, 0, -0.032, '#sad', '#disgusting', -0.023, 'front_yard', 'fresh_air', 'garden', 'lawn', 'tool_shed']
senticnet['garden_tool'] = [-0.035, 0, 0.085, 0, '#sad', '#angry', -0.04, 'tool', 'woodworking_tool', 'geometrical_figure', 'pointy', 'device']
senticnet['garden_yard'] = [-0.123, 0.066, -0.086, -0.069, '#sad', '#scared', -0.071, 'greenhouse', 'see_sky', 'plant_tree', 'hair', 'seed_lawn']
senticnet['gardener'] = [0, 0.076, 0, 0, '#interesting', '#interesting', 0.025, 'person', 'alive', 'investor', 'young_man', 'human_being']
senticnet['garish'] = [0, -0.71, 0, 0.975, '#surprising', '#admirable', 0.562, 'brassy', 'flashy', 'gaudy', 'cheap', 'flash']
senticnet['garishness'] = [-0.874, 0, 0.584, -0.711, '#sad', '#disgusting', -0.723, 'unsightliness', 'eyesore', 'hideousness', 'unattractiveness', 'ugliness']
senticnet['garlic'] = [0.077, 0, 0, 0, '#joyful', '#joyful', 0.026, 'ginger', 'dip', 'oat', 'savory', 'rye']
senticnet['garment'] = [0, -0.056, 0.092, -0.059, '#angry', '#disgusting', -0.032, 'piece_of_clothing', 'clothes', 'robe', 'slack', 'shirt']
senticnet['garment_bag'] = [0.041, -0.045, 0, 0, '#joyful', '#surprising', 0.029, 'fit_room', 'clothes_store_change_room', 'dress_room', 'clothes_shelf', 'changing_room']
senticnet['garner'] = [0, 0, -0.7, -0.912, '#scared', '#disgusting', -0.537, 'earn', 'pull_together', 'gather', 'collect', 'granary']
senticnet['garrulity'] = [0.664, -0.941, 0, 0.613, '#joyful', '#surprising', 0.739, 'outspokenness', 'frankness', 'communicativeness', 'garrulousness', 'loquaciousness']
senticnet['garrulous'] = [0.949, -0.694, 0, 0.992, '#joyful', '#admirable', 0.878, 'chatty', 'gabby', 'voluble', 'loquacious', 'talky']
senticnet['garrulousness'] = [0.664, -0.941, 0, 0.613, '#joyful', '#surprising', 0.739, 'outspokenness', 'frankness', 'garrulity', 'communicativeness', 'loquaciousness']
senticnet['gas'] = [0, 0.76, 0, 0.817, '#interesting', '#admirable', 0.526, 'diesel', 'fuel', 'kerosene', 'coal', 'inert_coal']
senticnet['gas_electric'] = [0, 0.082, -0.077, 0.151, '#interesting', '#admirable', 0.052, 'electric_car', 'car_engine', 'work_well', 'car_power', 'machine_transportation']
senticnet['gas_guzzler'] = [-0.512, 0, 0.552, -0.659, '#angry', '#disgusting', -0.574, 'car', 'auto', 'automobile', 'machine', 'motorcar']
senticnet['gas_oil'] = [0, 0.765, 0, 0.775, '#interesting', '#admirable', 0.513, 'fossil_fuel', 'state_matter', 'petroleum', 'car_gas', 'combustible']
senticnet['gas_station'] = [0.065, -0.021, 0.009, 0, '#joyful', '#surprising', 0.026, 'rest_area', 'motel_room', 'service_station', 'buy_snack', 'go_toilet']
senticnet['gas_stove'] = [0.088, 0.076, 0.016, 0.094, '#joyful', '#admirable', 0.081, 'copper_wire', 'stove', 'several_types', 'place_somewhere', 'suspect']
senticnet['gas_turbine'] = [0.065, -0.021, 0.009, 0, '#joyful', '#surprising', 0.026, 'turbine', 'hydroelectric_turbine', 'impulse_turbine', 'reaction_turbine', 'steam_turbine']
senticnet['gaseous'] = [0, 0.073, -0.052, 0.093, '#interesting', '#admirable', 0.038, 'vapor', 'water_vapor', 'evaporate', 'condense_water', 'bubble']
senticnet['gash'] = [-0.126, -0.022, 0, -0.15, '#sad', '#disgusting', -0.085, 'incision', 'laceration', 'abrasion', 'cut_skin', 'painful_injury']
senticnet['gasoline'] = [0.043, 0.112, 0, 0, '#joyful', '#interesting', 0.052, 'petrol', 'diesel', 'kerosene', 'fuel', 'butane']
senticnet['gasp'] = [0.877, 0, 0, 0.931, '#joyful', '#admirable', 0.603, 'breath', 'wind', 'respite', 'blow', 'whiff']
senticnet['gastric_antacid'] = [-0.533, 0, 0.954, -0.541, '#angry', '#disgusting', -0.676, 'antacid', 'histamine_blocker', 'ranitidine', 'alkalizer', 'antiacid']
senticnet['gastrin'] = [0.685, -0.898, 0, 0.765, '#surprising', '#admirable', 0.783, 'motilin', 'gastrointestinal_hormone', 'cholecystokinin', 'secretin', 'ghrelin']
senticnet['gastritis'] = [-0.959, 0, 0.729, -0.989, '#sad', '#disgusting', -0.892, 'chronic_gastritis', 'rubor', 'redness', 'acute_gastritis', 'inflammation']
senticnet['gastroenteritis'] = [-0.756, 0, 0.84, -0.633, '#sad', '#angry', -0.743, 'angina', 'inflammatory_disease', 'stomach_flu', 'intestinal_flu', 'pelvic_inflammatory_disease']
senticnet['gastrointestinal_hormone'] = [0.685, -0.898, 0, 0.765, '#surprising', '#admirable', 0.783, 'motilin', 'gastrin', 'cholecystokinin', 'secretin', 'ghrelin']
senticnet['gastrointestinal_tract'] = [-0.823, 0, 0.67, -0.848, '#sad', '#disgusting', -0.78, 'alimentary_canal', 'alimentary_tract', 'digestive_tube', 'digestive_tract', 'enteron']
senticnet['gastronome'] = [0.897, -0.961, 0, 0.785, '#joyful', '#surprising', 0.881, 'erotic', 'voluptuary', 'epicure', 'gourmet', 'sensualist']
senticnet['gastronomy'] = [0.528, -0.606, 0, 0.724, '#surprising', '#admirable', 0.619, 'artistic_creation', 'arts_and_crafts', 'carving', 'decoupage', 'ceramics']
senticnet['gastroscope'] = [0.255, 0.182, -0.06, 0.314, '#joyful', '#admirable', 0.23, 'doctor_office', 'urethroscope', 'sigmoidoscope', 'hospital', 'check_health']
senticnet['gate'] = [0, 0, 0, 0.076, '#admirable', '#admirable', 0.025, 'door', 'glass_front', 'use_farm', 'doorway', 'entranceway']
senticnet['gate_leg_table'] = [0.054, -0.077, 0.025, 0, '#joyful', '#surprising', 0.035, 'table', 'glass_front_cupboard', 'dine_table', 'sideboard', 'dine_room_table']
senticnet['gather'] = [0.042, 0.114, -0.11, 0.163, '#interesting', '#admirable', 0.07, 'assemble', 'bring_together', 'organize_group', 'join', 'come_together']
senticnet['gather_berry'] = [-0.092, 0.072, -0.088, 0, '#sad', '#scared', -0.036, 'hang_picture_on_wall', 'see_star_night', 'wave_flag', 'drink_espresso', 'deal_card_player']
senticnet['gather_crop'] = [0, 0.097, 0, 0.095, '#interesting', '#admirable', 0.064, 'harvest', 'water_crop', 'farm_land', 'farm_vegetable', 'farm_food']
senticnet['gather_data'] = [0, 0.764, 0, 0, '#interesting', '#interesting', 0.255, 'start_computer', 'make_error', 'type_of_keyboard', 'train_open_mind', 'blow_up_balloon']
senticnet['gather_energy_tomorrow'] = [0.852, 0, 0, 0, '#joyful', '#joyful', 0.284, 'wake_up_morning', 'up_early', 'get_up_early', 'awake', 'sit_chair']
senticnet['gather_evidence'] = [-0.069, 0, 0, 0, '#sad', '#sad', -0.023, 'contact_police', 'make_up_mind', 'give_verdict', 'bang_gavel', 'environmentalist']
senticnet['gather_fact'] = [0.215, 0.194, -0.204, 0.279, '#joyful', '#admirable', 0.161, 'figure_out', 'become_aware', 'cognition', 'arrive_conclusion', 'revelation']
senticnet['gather_flower'] = [-0.114, 0, 0, -0.093, '#sad', '#disgusting', -0.069, 'dress_doll', 'battle_illness', 'sun_oneself', 'spring_action', 'visit_grandmother']
senticnet['gather_friend'] = [0.171, -0.118, 0.018, -0.113, '#joyful', '#surprising', 0.053, 'celebrate_wedding', 'celebrate_special_occasion', 'eat_drink', 'get_wasted', 'meet_other_person']
senticnet['gather_information'] = [0.83, 0.907, 0, 0.559, '#joyful', '#interesting', 0.765, 'educate_oneself', 'gain_knowledge', 'read_out_loud', 'increase_knowledge', 'gain_information']
senticnet['gather_intelligence'] = [0.487, 0.675, -0.267, 0.266, '#joyful', '#interesting', 0.387, 'find_subway_stop', 'collective_intelligence', 'intelligent', 'become_smart', 'clever']
senticnet['gather_kindle'] = [0.215, 0.194, -0.204, 0.279, '#joyful', '#admirable', 0.161, 'use_match', 'diligence', 'combustible_material', 'rub_two_stick_together', 'lighter']
senticnet['gather_person'] = [0.097, -0.004, 0.022, 0.071, '#joyful', '#admirable', 0.05, 'group_gathering', 'gathering', 'public_gathering', 'large_number', 'big_group']
senticnet['gather_place'] = [0.025, 0.145, 0.023, 0.151, '#interesting', '#admirable', 0.099, 'tower', 'entrance_room', 'religious_place', 'edifice', 'inside_build']
senticnet['gather_team'] = [0.873, 0.825, 0, 0, '#joyful', '#interesting', 0.566, 'form_team', 'buy_ball', 'suit_up', 'join_team', 'ball_player']
senticnet['gather_together'] = [0.72, 0, 0, 0.982, '#joyful', '#admirable', 0.567, 'teamwork', 'team_play', 'play_together', 'play', 'coperation']
senticnet['gather_wood'] = [0.025, 0, -0.054, -0.056, '#scared', '#disgusting', -0.028, 'create_flame', 'create_fire', 'make_fire', 'burn_finger', 'light_cigarette']
senticnet['gathering'] = [0.161, -0.057, 0, 0.064, '#joyful', '#admirable', 0.094, 'group_gathering', 'public_gathering', 'social_drink', 'meet_up', 'social_gathering']
senticnet['gator'] = [-0.853, 0, 0.685, -0.838, '#sad', '#disgusting', -0.792, 'allicrocodilian', 'crocodile', 'false_gavial', 'crocodilian', 'caiman']
senticnet['gaucheness'] = [0.606, -0.978, 0, 0.742, '#surprising', '#admirable', 0.775, 'bad_manners', 'rudeness', 'impoliteness', 'crudeness', 'crudity']
senticnet['gaucherie'] = [0, 0, 0.844, -0.94, '#angry', '#disgusting', -0.595, 'rusticity', 'slip', 'solecism', 'gaffe', 'faux_pas']
senticnet['gauffer'] = [0.522, -0.824, 0, 0.568, '#surprising', '#admirable', 0.638, 'adornment', 'goffer', 'ruffle', 'jabot', 'peplum']
senticnet['gauge'] = [0, 0.872, 0, 0.78, '#interesting', '#admirable', 0.551, 'dimension', 'measure', 'count_item', 'length', 'measurement']
senticnet['gaunt'] = [0, 0, -0.809, -0.934, '#scared', '#disgusting', -0.581, 'bony', 'cadaverous', 'emaciated', 'pinched', 'haggard']
senticnet['gauntlet'] = [0, -0.967, 0, 0.938, '#surprising', '#admirable', 0.635, 'tack', 'foot_part', 'casual_shoes', 'spike', 'pin']
senticnet['gauze'] = [0, 0, 0, -0.17, '#disgusting', '#disgusting', -0.057, 'medicine', 'aspirin', 'blank_check', 'painkiller', 'video_tape']
senticnet['gavel'] = [0, 0.096, 0, 0.064, '#interesting', '#admirable', 0.053, 'judge_jury', 'arbiter', 'juror', 'jury', 'negotiator']
senticnet['gawker'] = [0.713, -0.848, 0, 0.694, '#joyful', '#surprising', 0.752, 'looker', 'spectator', 'viewer', 'watcher', 'witness']
senticnet['gay'] = [0.735, 0.597, -0.243, 0.356, '#joyful', '#interesting', 0.482, 'fulfill', 'gratify', 'gloat', 'rejoice', 'glee']
senticnet['gay_person'] = [0.754, 0, 0, 0.717, '#joyful', '#admirable', 0.49, 'homosexual', 'same_sex_attraction', 'gay', 'unconventional', 'open_minded']
senticnet['gayly'] = [0.653, 0.635, -0.244, 0.294, '#joyful', '#interesting', 0.446, 'merrily', 'jubilantly', 'happily', 'mirthfully', 'blithely']
senticnet['gayness'] = [0.807, -0.88, 0, 0.718, '#joyful', '#surprising', 0.802, 'sex', 'inversion', 'sexual_inversion', 'lesbianism', 'sapphism']
senticnet['gear'] = [-0.034, -0.068, 0.052, 0.087, '#surprising', '#admirable', 0.023, 'wheel', 'two_wheels', 'spoke', 'bumper', 'steer_wheel']
senticnet['gear_shift'] = [0.025, 0, -0.054, -0.056, '#scared', '#disgusting', -0.028, 'steer_wheel', 'suspension', 'chassis', 'brake_pedal', 'air_vent']
senticnet['gee'] = [-0.786, 0, 0.701, -0.782, '#sad', '#disgusting', -0.756, 'express', 'utter', 'cry_out', 'ooh', 'aah']
senticnet['geek'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'book_worm', 'nerd', 'loser', 'underdog', 'computer_lover']
senticnet['geezerhood'] = [-0.796, 0, 0.802, -0.549, '#sad', '#angry', -0.716, 'age', 'old_age', 'years', 'eld', 'dotage']
senticnet['gel'] = [-0.04, 0.069, 0, 0.075, '#interesting', '#admirable', 0.035, 'sculpt_gel', 'hairstyle', 'hairdresser', 'cosmetic', 'hair_sculpt_gel']
senticnet['gel_toothpaste'] = [0, 0.934, 0, 0.795, '#interesting', '#admirable', 0.576, 'tartar_control_toothpaste', 'toothpaste', 'wax_dental_floss', 'dental_floss', 'double_edge_razor']
senticnet['gelatin_dessert'] = [0.708, -0.934, 0, 0.764, '#surprising', '#admirable', 0.802, 'dainty', 'delicacy', 'treat', 'jelly', 'aspic']
senticnet['gelded'] = [0.945, -0.861, 0, 0.802, '#joyful', '#surprising', 0.869, 'cut', 'altered', 'neutered', 'emasculated', 'castrated']
senticnet['gelidity'] = [-0.846, 0, 0.655, -0.806, '#sad', '#disgusting', -0.769, 'cold', 'low_temperature', 'frigidity', 'frigidness', 'coldness']
senticnet['gem'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'art', 'art_piece', 'museum', 'artist', 'jewel']
senticnet['gem_stone'] = [0.708, -0.934, 0, 0.764, '#surprising', '#admirable', 0.802, 'precious_gem', 'expensive_stone', 'precious_stone', 'jewel', 'gem']
senticnet['gemstone'] = [0.037, 0.073, 0.027, 0.072, '#interesting', '#admirable', 0.052, 'sapphire', 'birth_stone', 'turquoise', 'amethyst', 'precious_stone']
senticnet['gender'] = [0, 0.761, 0, 0.882, '#interesting', '#admirable', 0.548, 'masculine', 'small_man', 'hold_child', 'female_person', 'male_person']
senticnet['general'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'army_boss', 'sergeant', 'military_rank', 'lieutenant', 'high_rank']
senticnet['general_anesthesia'] = [-0.651, 0, 0.824, -0.869, '#angry', '#disgusting', -0.781, 'put_to_sleep', 'operation', 'anesthesia', 'surgery', 'local_anesthesia']
senticnet['general_knowledge'] = [0.745, -0.771, 0, 0.655, '#joyful', '#surprising', 0.724, 'light', 'open', 'common_knowledge', 'surface', 'cognition']
senticnet['general_ledger'] = [0, 0.119, 0, 0, '#interesting', '#interesting', 0.04, 'ledger', 'computer_disk', 'memo_pad', 'intern', 'graphite_pencil']
senticnet['general_name'] = [0.052, 0.129, 0, 0.16, '#interesting', '#admirable', 0.114, 'general_term', 'generic', 'generic_term', 'thing', 'name']
senticnet['general_practitioner'] = [0.738, -0.537, 0, 0.856, '#joyful', '#admirable', 0.71, 'doctor', 'country_doctor', 'family_doctor', 'doctor_office', 'physician']
senticnet['general_relativity'] = [0.708, -0.934, 0, 0.764, '#surprising', '#admirable', 0.802, 'relativity', 'general_theory_of_relativity', 'relativity_theory', 'special_relativity', 'special_theory_of_relativity']
senticnet['general_relativity_theory'] = [0.708, -0.934, 0, 0.764, '#surprising', '#admirable', 0.802, 'general_relativity', 'general_theory_of_relativity', 'relativity', 'special_relativity', 'special_theory_of_relativity']
senticnet['general_store'] = [0.027, 0.083, 0.019, 0, '#joyful', '#interesting', 0.03, 'large_supermarket', 'corner_shop', 'large_food_store', 'bazaar', 'dime_store']
senticnet['general_term'] = [0.052, 0.129, 0, 0.16, '#interesting', '#admirable', 0.114, 'general_name', 'generic', 'generic_term', 'thing', 'name']
senticnet['general_theory_of_relativity'] = [-0.69, 0, 0.83, -0.997, '#angry', '#disgusting', -0.839, 'general_relativity', 'relativity', 'general_relativity_theory', 'special_relativity', 'special_theory_of_relativity']
senticnet['general_time'] = [0.705, -0.606, 0, 0.913, '#joyful', '#admirable', 0.741, 'eternal', 'no_end', 'hot_weather', 'ell', 'common_practice']
senticnet['generate_energy'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'potential', 'power_source', 'electrical', 'power', 'potential_energy']
senticnet['generate_heat'] = [-0.066, 0, -0.113, 0, '#sad', '#scared', -0.06, 'turn_key', 'danger', 'open_car_door', 'shine_car', 'corrode']
senticnet['generate_sound'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'sand_paper', 'measure_angle', 'music_sheet', 'read_music', 'low_note']
senticnet['generic'] = [0.044, 0.115, 0.023, 0.138, '#interesting', '#admirable', 0.091, 'general_term', 'generic_term', 'opaque', 'thing', 'delicate']
senticnet['generic_name'] = [0.05, 0, 0, 0.115, '#joyful', '#admirable', 0.055, 'poisonous_human', 'poisonous', 'fauna', 'rare', 'hard_material']
senticnet['generic_term'] = [0.052, 0.129, 0, 0.16, '#interesting', '#admirable', 0.114, 'general_term', 'generic', 'general_name', 'thing', 'name']
senticnet['generosity'] = [0.976, 0, 0, 0.741, '#joyful', '#admirable', 0.572, 'get_something_from_person', 'generous', 'alms', 'better_life', 'love_parent']
senticnet['generous'] = [0.92, 0, 0, 0.752, '#joyful', '#admirable', 0.557, 'really_want', 'help_out', 'benevolent', 'need', 'generosity']
senticnet['genesis'] = [0, 0.106, -0.052, 0.163, '#interesting', '#admirable', 0.072, 'band', 'kit', 'oblivion', 'rock_band', 'high_school_band']
senticnet['genetic_abnormality'] = [-0.871, 0, 0.873, -0.621, '#sad', '#angry', -0.788, 'pycnodysostosis', 'genetic_disease', 'genetic_disorder', 'dwarfism', 'genetic_defect']
senticnet['genetic_code'] = [0.888, -0.815, 0, 0.617, '#joyful', '#surprising', 0.773, 'bacteria_order', 'word_order', 'ordering', 'genome', 'series']
senticnet['genetic_defect'] = [-0.871, 0, 0.873, -0.621, '#sad', '#angry', -0.788, 'pycnodysostosis', 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'dwarfism']
senticnet['genetic_disease'] = [-0.871, 0, 0.873, -0.621, '#sad', '#angry', -0.788, 'pycnodysostosis', 'dwarfism', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect']
senticnet['genetic_disorder'] = [-0.988, 0, 0.182, -0.917, '#sad', '#disgusting', -0.696, 'need_cure', 'ill', 'sickness', 'sick', 'disorder']
senticnet['geniality'] = [0.913, -0.753, 0, 0.699, '#joyful', '#surprising', 0.788, 'sweetness_and_light', 'condescension', 'condescendingness', 'mellowness', 'friendliness']
senticnet['genitive'] = [-0.827, 0, 0.81, -0.617, '#sad', '#angry', -0.751, 'accusative', 'oblique', 'oblique_case', 'possessive', 'possessive_case']
senticnet['genitive_case'] = [-0.827, 0, 0.81, -0.617, '#sad', '#angry', -0.751, 'accusative', 'genitive', 'oblique', 'possessive', 'possessive_case']
senticnet['genius'] = [0.703, -0.593, 0, 0.739, '#joyful', '#admirable', 0.678, 'fruitfulness', 'creative_thinking', 'fecundity', 'ability', 'wizardry']
senticnet['genius_loci'] = [0.673, -0.64, 0, 0.669, '#joyful', '#admirable', 0.661, 'eudemon', 'white_angel', 'good_spirit', 'guardian_angel', 'angel']
senticnet['genocide'] = [0, 0, 0.92, -0.797, '#angry', '#disgusting', -0.572, 'kill_another_person', 'violent_person', 'death_destruction', 'murder', 'death_penalty']
senticnet['genome'] = [0.888, -0.815, 0, 0.617, '#joyful', '#surprising', 0.773, 'bacteria_order', 'word_order', 'genetic_code', 'ordering', 'series']
senticnet['genotype'] = [-0.96, 0, 0.556, -0.872, '#sad', '#disgusting', -0.796, 'animal_group', 'group', 'biological_group', 'clade', 'taxonomic_group']
senticnet['genre'] = [0, 0.951, 0, 0, '#interesting', '#interesting', 0.317, 'part_of_history', 'movie_action_movie', 'action_movie', 'fictional', 'horror_movie']
senticnet['genre_music'] = [0.946, 0.816, 0, 0.984, '#joyful', '#admirable', 0.915, 'music', 'good_music', 'hear_music', 'beautiful_music', 'enjoy_music']
senticnet['genteelness'] = [0.639, -0.701, 0, 0.507, '#joyful', '#surprising', 0.616, 'tastefulness', 'daintiness', 'eclat', 'breeding', 'elegance']
senticnet['gentile'] = [-0.888, 0, 0.929, -0.843, '#sad', '#angry', -0.887, 'paynim', 'nonreligious_person', 'idolizer', 'idolater', 'idol_worshiper']
senticnet['gentle'] = [0, 0, 0, 0.961, '#admirable', '#admirable', 0.32, 'kind', 'nice', 'precaution', 'proper', 'softly']
senticnet['gentleman'] = [0.093, 0.106, -0.091, 0, '#joyful', '#interesting', 0.036, 'educated', 'generous', 'princess', 'queen', 'president_united_states']
senticnet['gentlemanlike'] = [0.614, -0.959, 0, 0.537, '#joyful', '#surprising', 0.703, 'mincing', 'twee', 'refined', 'gentlemanly', 'ladylike']
senticnet['gentlemanly'] = [0.614, -0.959, 0, 0.537, '#joyful', '#surprising', 0.703, 'mincing', 'twee', 'gentlemanlike', 'refined', 'ladylike']
senticnet['gentleness'] = [0, 0, 0, 0.98, '#admirable', '#admirable', 0.327, 'kindness', 'demand', 'sympathy', 'type_of_bear', 'express_gratitude']
senticnet['gentlewoman'] = [0.964, -0.811, 0, 0.926, '#joyful', '#admirable', 0.9, 'girl', 'grande_dame', 'madam', 'dame', 'lady']
senticnet['genuflection'] = [-0.705, 0, 0.925, 0, '#sad', '#angry', -0.543, 'reverence', 'obeisance', 'genuflexion', 'kowtow', 'mafia']
senticnet['genuflexion'] = [-0.705, 0, 0.925, 0, '#sad', '#angry', -0.543, 'reverence', 'genuflection', 'obeisance', 'kowtow', 'mafia']
senticnet['genuine'] = [0.729, 0.872, 0, 0.877, '#interesting', '#admirable', 0.826, 'good_quality', 'all_of_it', 'good_character', 'mass_measure', 'description']
senticnet['genus'] = [0.868, 0.992, 0, 0, '#joyful', '#interesting', 0.62, 'centerfold', 'fairy', 'honey_bee', 'infant', 'dove']
senticnet['geographic'] = [0, 0.08, 0.032, 0.096, '#interesting', '#admirable', 0.048, 'school_subject', 'chemistry', 'geometric', 'physic', 'geology']
senticnet['geographic_feature'] = [0, 0.146, 0.02, 0.091, '#interesting', '#admirable', 0.072, 'landscape_feature', 'land_formation', 'land_feature', 'land_form', 'geographical_feature']
senticnet['geographical_feature'] = [0, 0.08, 0.032, 0.096, '#interesting', '#admirable', 0.048, 'land_form', 'land_formation', 'land_feature', 'geographic_feature', 'landscape_feature']
senticnet['geology'] = [0, 0.08, 0.032, 0.096, '#interesting', '#admirable', 0.048, 'school_subject', 'chemistry', 'geometric', 'physic', 'geographic']
senticnet['geomancer'] = [0.703, -0.612, 0, 0.637, '#joyful', '#admirable', 0.651, 'oracle', 'necromancer', 'illusionist', 'visionary', 'diviner']
senticnet['geometric'] = [0, 0.894, 0, 0.769, '#interesting', '#admirable', 0.554, 'geometric_figure', 'geometric_shape', 'geometry_shape', 'geometrical_shape', 'no_corner']
senticnet['geometric_figure'] = [0, 0.795, 0, 0.756, '#interesting', '#admirable', 0.517, 'polygon', 'parallelogram', 'geometric_shape', 'geometry_shape', 'geometrical_shape']
senticnet['geometric_object'] = [0, 0.729, 0, 0.753, '#interesting', '#admirable', 0.494, 'sharp_end', 'indicate', 'sharp_corner', 'sharpness', 'sport_score']
senticnet['geometric_shape'] = [0, 0.805, 0, 0.868, '#interesting', '#admirable', 0.558, 'geometry_shape', 'geometrical_shape', 'geometric_figure', 'no_edge', 'no_corner']
senticnet['geometrical'] = [0, 0.911, 0, 0.993, '#interesting', '#admirable', 0.635, 'geometric_object', 'geometric_figure', 'geometric_shape', 'geometric', 'geometry_shape']
senticnet['geometrical_figure'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'tool', 'woodworking_tool', 'garden_tool', 'pointy', 'device']
senticnet['geometrical_irregularity'] = [-0.596, 0, 0.672, -0.831, '#angry', '#disgusting', -0.7, 'asymmetry', 'radial_asymmetry', 'lopsidedness', 'skewness', 'irregularity']
senticnet['geometrical_shape'] = [0, 0.703, 0, 0.96, '#interesting', '#admirable', 0.554, 'geometry_shape', 'geometric_shape', 'polygon', 'no_edge', 'geometric_figure']
senticnet['geometry'] = [-0.04, 0.138, -0.085, 0.111, '#interesting', '#admirable', 0.041, 'blade_geometry', 'craft', 'katana', 'blade', 'collect_item']
senticnet['geometry_shape'] = [0, 0.98, 0, 0.752, '#interesting', '#admirable', 0.577, 'geometric_shape', 'geometrical_shape', 'no_edge', 'no_corner', 'geometric_figure']
senticnet['germ'] = [-0.112, 0, -0.126, -0.152, '#scared', '#disgusting', -0.13, 'infectious_disease', 'bacterium', 'polio', 'disease', 'malady']
senticnet['german_car'] = [0, 0.751, 0, 0, '#interesting', '#interesting', 0.25, 'top_dog', 'give_order', 'status_symbol', 'plumber', 'army_officer']
senticnet['germander'] = [-0.565, 0, 0.91, -0.809, '#angry', '#disgusting', -0.761, 'subshrub', 'suffrutex', 'wood_sage', 'wall_germander', 'cat_thyme']
senticnet['germplasm'] = [0, 0.095, 0.016, 0.106, '#interesting', '#admirable', 0.062, 'blood_plasma', 'cytoplasm', 'plasma', 'nucleoplasm', 'protoplasm']
senticnet['gerrymander'] = [0.842, -0.986, 0, 0.756, '#joyful', '#surprising', 0.861, 'cheating', 'dissimulation', 'dissembling', 'deception', 'deceit']
senticnet['gestate'] = [0.513, -0.768, 0, 0.668, '#surprising', '#admirable', 0.65, 'find', 'design', 'preconceive', 'discover', 'create_by_mental_act']
senticnet['gestation'] = [-0.752, 0, 0.715, -0.725, '#sad', '#disgusting', -0.731, 'abdominal_pregnancy', 'ovarian_pregnancy', 'tubal_pregnancy', 'pregnancy', 'ectopic_gestation']
senticnet['gesture'] = [0.026, 0.14, -0.136, 0.31, '#interesting', '#admirable', 0.113, 'touch', 'hand_gesture', 'hand_movement', 'earth_movement', 'hand_action']
senticnet['get'] = [0.92, -0.883, 0, 0.695, '#joyful', '#surprising', 0.833, 'attract', 'catch', 'arrest', 'tug', 'retract']
senticnet['get_accident'] = [-0.133, -0.032, -0.058, -0.085, '#sad', '#disgusting', -0.081, 'accident', 'stop_red_light', 'crash', 'shift_gear', 'crash_tree']
senticnet['get_across'] = [0.743, -0.517, 0, 0.551, '#joyful', '#admirable', 0.604, 'communicate', 'pass_on', 'pass', 'pass_along', 'put_across']
senticnet['get_ahead'] = [0.572, -0.603, 0, 0.892, '#surprising', '#admirable', 0.689, 'tally', 'steal', 'score', 'hit', 'rack_up']
senticnet['get_along'] = [0.186, 0.139, -0.095, 0.167, '#joyful', '#admirable', 0.132, 'cease_fire', 'refresh', 'extreme_elation', 'exhilarate', 'set_example']
senticnet['get_angry'] = [-0.969, 0, 0.525, -0.959, '#sad', '#disgusting', -0.818, 'angry', 'become_rude', 'rude', 'shout', 'anger']
senticnet['get_answer'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'add_two_numbers_together', 'learn_add', 'get_total', 'add_number_together', 'sharpen_pencil']
senticnet['get_around'] = [0.99, 0, 0, 0.87, '#joyful', '#admirable', 0.62, 'get_place', 'transportation', 'locomotion', 'personal_transport', 'go_elsewhere']
senticnet['get_around_town'] = [0.895, 0.982, 0, 0, '#joyful', '#interesting', 0.626, 'commute_work', 'get_place', 'sightsee', 'get_school', 'roam_around']
senticnet['get_arrested'] = [-0.929, 0, -0.827, -0.73, '#sad', '#scared', -0.829, 'arrest_police', 'feel_anger', 'end_life', 'call_help', 'feel_bad']
senticnet['get_at'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['get_attention'] = [0.12, -0.157, 0.032, 0.075, '#joyful', '#surprising', 0.107, 'bludgeon', 'bart', 'knock', 'hook_up', 'waltz']
senticnet['get_away'] = [0.901, 0, 0, 0.916, '#joyful', '#admirable', 0.606, 'absolution', 'bread', 'glory', 'counsel', 'vow']
senticnet['get_away_crime'] = [-0.596, 0, 0.672, -0.831, '#angry', '#disgusting', -0.7, 'attempt_bribe', 'commit_murder', 'steal', 'commit_perjury', 'hurt_else']
senticnet['get_back'] = [-0.596, 0, 0.672, -0.831, '#angry', '#disgusting', -0.7, 'concede', 'give_up', 'try_hard', 'locate', 'military_action']
senticnet['get_beaten'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'fight', 'violence', 'anger', 'punch', 'assault']
senticnet['get_best'] = [-0.627, 0, 0.962, -0.535, '#sad', '#angry', -0.708, 'crush', 'trounce', 'beat', 'beat_out', 'vanquish']
senticnet['get_better'] = [0.803, 0.821, 0, 0.723, '#joyful', '#interesting', 0.782, 'improve', 'quit_work', 'effort', 'dress_success', 'help_person']
senticnet['get_better_job'] = [0.856, 0, 0, 0.963, '#joyful', '#admirable', 0.606, 'progress', 'advancement', 'further_career', 'graduate_school', 'get_diploma']
senticnet['get_better_of'] = [0.639, 0.547, 0, 0.692, '#joyful', '#admirable', 0.626, 'disappointed', 'defeatism', 'thwarted', 'frustrated', 'foiled']
senticnet['get_big'] = [0, 0.153, -0.074, 0.203, '#interesting', '#admirable', 0.094, 'flourish', 'get_large', 'increase_size', 'plant_big', 'enlarge']
senticnet['get_bigger'] = [0.777, -0.895, 0, 0.508, '#joyful', '#surprising', 0.727, 'stretching', 'enlarge', 'dilatation', 'enlargement', 'distension']
senticnet['get_boat'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'go_dive', 'take_cruise', 'go_sea', 'take_leak', 'hold_fish']
senticnet['get_bomb'] = [-0.968, 0, 0.394, -0.908, '#sad', '#disgusting', -0.757, 'explosion', 'get_hurt', 'blow_up', 'detonate', 'squib_bomb']
senticnet['get_bored'] = [0, 0, 0, -0.718, '#disgusting', '#disgusting', -0.239, 'become_bored', 'drink_soda', 'boredom', 'extreme_boredom', 'masturbate']
senticnet['get_burnt'] = [0, 0, -0.075, -0.076, '#scared', '#disgusting', -0.05, 'create_smoke', 'burn_oneself', 'burn_finger', 'create_flame', 'make_fire']
senticnet['get_bus'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'travel', 'get_plane', 'come_back_home', 'go_new_place', 'reach_destination']
senticnet['get_by'] = [-0.795, 0, 0.974, -0.839, '#angry', '#disgusting', -0.869, 'manage', 'make_out', 'cope', 'fend', 'make_do']
senticnet['get_changed'] = [-0.074, -0.024, 0.082, -0.048, '#sad', '#angry', -0.06, 'join_team', 'form_team', 'turn_off_computer', 'go_park', 'tie_shoes']
senticnet['get_clean'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'clean_clothes', 'become_clean', 'take_shower', 'clean_body', 'wash_clothes']
senticnet['get_close'] = [0.908, 0.743, 0, 0, '#joyful', '#interesting', 0.55, 'express_appreciation', 'get_know_better', 'comedian', 'spread_happiness', 'make_laugh']
senticnet['get_coffee'] = [0.974, 0.789, 0, 0.828, '#joyful', '#admirable', 0.864, 'get_out_of_bed', 'start_new_day', 'buy_sandwich', 'eat_breakfast', 'wait_table']
senticnet['get_cold'] = [0, 0, 0, -0.755, '#disgusting', '#disgusting', -0.252, 'go_downhill', 'see_dog', 'break_bone', 'loss_ofbreath', 'hit_tree']
senticnet['get_contract'] = [0.878, 0.777, 0, 0.85, '#joyful', '#admirable', 0.835, 'create_help_other_person', 'please_parent', 'give_assistance', 'make_better_world', 'see_idea_become_reality']
senticnet['get_cured'] = [0.878, 0.777, 0, 0.85, '#joyful', '#admirable', 0.835, 'medicine', 'avoid_pain', 'kill_specific_group', 'live_apartment', 'wave_flag']
senticnet['get_dark'] = [-0.083, 0, -0.045, 0, '#sad', '#scared', -0.043, 'dark_outside', 'night_time', 'day_end', 'sundown', 'dusk']
senticnet['get_date'] = [0.739, 0.926, 0, 0, '#joyful', '#interesting', 0.555, 'new_friendship', 'find_mate', 'dating', 'romance', 'fall_in_love']
senticnet['get_degree'] = [0.974, 0.789, 0, 0.828, '#joyful', '#admirable', 0.864, 'learn_knowledge', 'become_educated', 'pass_exam', 'degree', 'get_education']
senticnet['get_diploma'] = [0.856, 0, 0, 0.963, '#joyful', '#admirable', 0.606, 'progress', 'get_better_job', 'further_career', 'graduate_school', 'advancement']
senticnet['get_dirty'] = [-0.795, 0, 0.974, -0.839, '#angry', '#disgusting', -0.869, 'fight_fire', 'fall_mud', 'become_dirty', 'feel_dirty', 'dirty']
senticnet['get_divorce'] = [-0.814, -0.742, 0.946, -0.807, '#sad', '#angry', -0.608, 'stop_marry', 'take_oath', 'divorce', 'institute_civil_action', 'change_society']
senticnet['get_dizzy'] = [-0.963, 0, 0, -0.977, '#sad', '#disgusting', -0.647, 'tire', 'enjoy_fresh_air', 'see_neighbor', 'heart_rate_increase', 'bump_head']
senticnet['get_done'] = [0.974, 0.789, 0, 0.828, '#joyful', '#admirable', 0.864, 'earn_paycheck', 'finish_task', 'get_work_done', 'get_to_work_on_time', 'work_hard']
senticnet['get_down'] = [-0.81, 0.239, -0.443, -0.064, '#sad', '#scared', -0.359, 'feel_down', 'deject', 'cast_down', 'dispirit', 'demoralize']
senticnet['get_drink'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'boring', 'dumb', 'dull', 'get_bored', 'loser']
senticnet['get_drunk'] = [-0.795, 0, 0.974, -0.839, '#angry', '#disgusting', -0.869, 'alcoholic_drink', 'alcoholic_beverage', 'ferment_beverage', 'adult_drink', 'booze']
senticnet['get_education'] = [0.987, 0.882, 0, 0.905, '#joyful', '#admirable', 0.925, 'get_knowledge', 'become_smart', 'gain_knowledge', 'become_intelligent', 'learn_information']
senticnet['get_energy'] = [0.842, 0.913, 0, 0, '#joyful', '#interesting', 0.585, 'replenish_energy', 'satisfy_sweet_tooth', 'entertain_friend', 'sociable', 'feel_content']
senticnet['get_entertain'] = [0.84, 0.803, 0, 0.81, '#joyful', '#admirable', 0.818, 'cultural_experience', 'entertain_oneself', 'entertainment', 'pastime', 'clear_mind_bad_thought']
senticnet['get_erection'] = [0.702, 0.965, 0, 0, '#joyful', '#interesting', 0.556, 'mass_hysteria', 'wet_clothes', 'pain_suffer', 'obsessive_compulsive_disorder', 'catch_cold']
senticnet['get_excited'] = [0.997, 0.929, 0, 0.941, '#joyful', '#admirable', 0.956, 'lose_track_time', 'tell_friend', 'boredom', 'bored', 'kill_brain_cell']
senticnet['get_exercise'] = [0.909, 0, 0, 0.87, '#joyful', '#admirable', 0.593, 'high_blood_pressure', 'train_marathon', 'run_marathon', 'run_long_distance', 'go_gym']
senticnet['get_exhausted'] = [-0.71, 0, 0, -0.98, '#sad', '#disgusting', -0.563, 'breaheavily', 'run_out_breath', 'heavy_breathe', 'become_wind', 'get_out_breath']
senticnet['get_famous'] = [0.766, 0, 0, 0.839, '#joyful', '#admirable', 0.535, 'like_challenge', 'win_money', 'fun', 'profitable', 'keep_busy']
senticnet['get_fast'] = [0, -0.004, 0, 0.073, '#surprising', '#admirable', 0.026, 'pay_toll', 'drive_upon', 'travel_car', 'fast_travel', 'access']
senticnet['get_fat'] = [-0.596, 0, 0.672, -0.831, '#angry', '#disgusting', -0.7, 'make_little_hungry', 'stomach_ache', 'become_fat', 'feel_rejuvenated', 'feel_full']
senticnet['get_fight'] = [0, 0, 0.986, -0.789, '#angry', '#disgusting', -0.592, 'lose_sleep', 'lose_temper', 'tension', 'make_error', 'call_name']
senticnet['get_fired'] = [-0.464, 0, -0.327, -0.17, '#sad', '#scared', -0.32, 'anguish', 'feel_bad', 'death_love', 'feeling_guilt', 'hurt_feeling']
senticnet['get_fit'] = [0.673, -0.64, 0, 0.669, '#joyful', '#admirable', 0.661, 'get_shape', 'stay_fit', 'lose_weight', 'maintain_muscle_strength', 'eat_healthily']
senticnet['get_floor_another'] = [0.812, 0, 0, 0.812, '#joyful', '#admirable', 0.541, 'walk_up', 'climb_up', 'go_upstairs', 'go_up_down', 'move_between_floor_building']
senticnet['get_focused'] = [0.946, -0.628, 0, 0.846, '#joyful', '#admirable', 0.807, 'particularism', 'absorption', 'concentration', 'engrossment', 'immersion']
senticnet['get_food'] = [0.797, 0, 0, 0.786, '#joyful', '#admirable', 0.528, 'food', 'buy_food', 'prepare_food', 'eat_lunch', 'sate_hunger']
senticnet['get_fresh_air'] = [0.953, 0.989, 0, 0.955, '#interesting', '#admirable', 0.966, 'exercise', 'enjoy_outdoors', 'relieve_stress', 'keep_shape', 'fun']
senticnet['get_front'] = [-0.118, -0.07, 0.1, -0.277, '#sad', '#disgusting', -0.142, 'learn_patience', 'get_sore_foot', 'become_impatient', 'get_ticket', 'take_turn']
senticnet['get_front_line'] = [0, 0.937, 0, 0.803, '#interesting', '#admirable', 0.58, 'get_front', 'learn_patience', 'patience', 'wait_patiently', 'conformist_attitude']
senticnet['get_full'] = [-0.908, 0, 0, -0.926, '#sad', '#disgusting', -0.611, 'satiate', 'become_full', 'acid_indigestion', 'burp', 'a_little_hungry']
senticnet['get_gift'] = [0.829, 0, 0, 0.788, '#joyful', '#admirable', 0.539, 'obtain', 'acquire', 'wrap_gift', 'gift_wrap', 'comparison_shop']
senticnet['get_good_job'] = [0.972, 0, 0, 0.766, '#joyful', '#admirable', 0.579, 'get_diploma', 'get_degree', 'obtain_degree', 'learn_knowledge', 'pass_exam']
senticnet['get_goods'] = [0.673, -0.64, 0, 0.669, '#joyful', '#admirable', 0.661, 'purchase_item', 'buy_item', 'buy_stuff', 'buy_cheap_item', 'buy_goods']
senticnet['get_grade'] = [0.913, 0, 0, 0.866, '#joyful', '#admirable', 0.593, 'complete_course', 'grade', 'test_knowledge', 'receive_grade', 'get_qualification']
senticnet['get_grocery'] = [0, 0.728, 0, 0.721, '#interesting', '#admirable', 0.483, 'buy_milk', 'buy_food', 'buy_goods', 'buy_bread', 'buy_stuff']
senticnet['get_hair_colored'] = [0.742, 0, 0, 0.935, '#joyful', '#admirable', 0.559, 'get_manicure', 'get_haircut', 'get_hair_style', 'stylish', 'go_get_haircut']
senticnet['get_hair_style'] = [0.844, 0, 0, 0.866, '#joyful', '#admirable', 0.57, 'get_manicure', 'get_hair_colored', 'get_haircut', 'stylish', 'go_get_haircut']
senticnet['get_haircut'] = [0.799, 0, 0, 0.729, '#joyful', '#admirable', 0.509, 'get_manicure', 'get_hair_colored', 'get_hair_style', 'stylish', 'go_get_haircut']
senticnet['get_hammered'] = [-0.734, 0, 0, -0.749, '#sad', '#disgusting', -0.494, 'social_interaction', 'get_drunk', 'meet_member_opposite_sex', 'good_time', 'get_to_know_person']
senticnet['get_happy'] = [0.208, -0.167, 0.026, -0.137, '#joyful', '#surprising', 0.071, 'spread_happiness', 'forget_trouble', 'enjoy_person', 'pleasure', 'give_pleasure']
senticnet['get_healthy'] = [0.673, -0.64, 0, 0.669, '#joyful', '#admirable', 0.661, 'healthy_live', 'build_muscle', 'improve_self-image', 'increase_muscle_mass', 'stay_physically_fit']
senticnet['get_heard'] = [0.383, 0.246, -0.108, 0.256, '#joyful', '#admirable', 0.259, 'hear_opinion', 'ignore_distraction', 'stare', 'acquire_information', 'audience']
senticnet['get_help'] = [0.912, 0, 0, 0.966, '#joyful', '#admirable', 0.626, 'pray', 'kiss', 'faith_god', 'pray_god', 'propose_woman']
senticnet['get_high_education'] = [0.383, 0.246, -0.108, 0.256, '#joyful', '#admirable', 0.259, 'finish_school', 'finish_college', 'high_education', 'obtain_degree', 'prepare_exam']
senticnet['get_hired'] = [0.982, 0.831, 0, 0.837, '#joyful', '#admirable', 0.883, 'find_job', 'get_job', 'eat_fruit', 'calm_mind', 'inflation']
senticnet['get_hit'] = [-0.596, 0, 0.672, -0.831, '#angry', '#disgusting', -0.7, 'die', 'lose_blood', 'lose_war', 'die_in_war', 'kamikaze']
senticnet['get_hit_by_car'] = [-0.177, -0.017, -0.077, -0.046, '#sad', '#scared', -0.094, 'trip_fall_down', 'step_dog_poop', 'move_leg', 'hurt_toe', 'bump_head']
senticnet['get_hot'] = [-0.596, 0, 0.672, -0.831, '#angry', '#disgusting', -0.7, 'tier', 'make_toast', 'house_smell_good', 'spoilage', 'bread_crumb']
senticnet['get_hurt'] = [-0.79, 0, 0, 0, '#sad', '#sad', -0.263, 'serious_injury', 'arrest_police', 'hurt_oneself', 'bloody_nose', 'die_painfully']
senticnet['get_hurt_badly'] = [0, 0, 0.869, -0.755, '#angry', '#disgusting', -0.541, 'skin_irritation', 'get_hurt', 'ouch', 'bleed', 'cut_skin']
senticnet['get_in'] = [0, 0.944, 0, 0.92, '#interesting', '#admirable', 0.621, 'enter_area', 'result_injury', 'computer_key', 'drag', 'move_object']
senticnet['get_information'] = [0.558, 0.68, 0, 0.53, '#joyful', '#interesting', 0.589, 'find_out_information', 'gain_information', 'keep_up_current_event', 'learn_entertainment', 'understand_current_event']
senticnet['get_informed'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'get_news', 'appreciate_art', 'view_art', 'stimulate_mind', 'expand_horizon']
senticnet['get_injured'] = [-0.791, 0, -0.806, 0.718, '#sad', '#scared', -0.293, 'sprain_ankle', 'knee_injury', 'become_exhausted', 'minor_injury', 'twist_ankle']
senticnet['get_into'] = [-0.935, 0, 0.77, -0.666, '#sad', '#angry', -0.79, 'raid', 'come_in', 'foray_into', 'enter', 'encroach_upon']
senticnet['get_into_place'] = [0.097, -0.097, 0.1, -0.162, '#angry', '#disgusting', -0.023, 'go_some_place', 'get_to_destination', 'use_gas', 'get_somewhere', 'need_go_somewhere']
senticnet['get_involved_in_accident'] = [0, -0.004, -0.081, -0.085, '#scared', '#disgusting', -0.054, 'lose_consciousness', 'bungee_jump_high_bridge', 'go_coma', 'jump_out_of_window', 'drug_addiction']
senticnet['get_it_on'] = [0.518, -0.924, 0, 0.788, '#surprising', '#admirable', 0.743, 'have', 'pair', 'take', 'couple', 'fornicate']
senticnet['get_job'] = [0.982, 0.831, 0, 0.837, '#joyful', '#admirable', 0.883, 'find_job', 'get_hired', 'eat_fruit', 'calm_mind', 'inflation']
senticnet['get_job_done'] = [0, 0.861, 0, 0.818, '#interesting', '#admirable', 0.56, 'earn_paycheck', 'support_family', 'make_live', 'make_money', 'accomplish']
senticnet['get_killed'] = [-0.184, -0.043, -0.191, -0.226, '#scared', '#disgusting', -0.186, 'die', 'lose_war', 'cause_death', 'death', 'attack_enemy']
senticnet['get_know'] = [0.759, 0, 0, 0.932, '#joyful', '#admirable', 0.564, 'socialize', 'find_new_friend', 'look_sexy', 'impress_person', 'visit_friend']
senticnet['get_know_better'] = [0.947, 0, 0, 0.834, '#joyful', '#admirable', 0.594, 'new_information', 'misunderstanding', 'exchange_idea', 'find_solution', 'change_attitude']
senticnet['get_knowledge'] = [0.715, 0.717, 0, 0.813, '#interesting', '#admirable', 0.748, 'gain_knowledge', 'expand_knowledge', 'become_intelligent', 'become_smart', 'increase_knowledge']
senticnet['get_laid'] = [0.733, 0.994, 0, 0, '#joyful', '#interesting', 0.576, 'make_new_friend', 'get_date', 'get_happy', 'become_happy', 'joke_around']
senticnet['get_large'] = [0, 0.148, -0.115, 0.296, '#interesting', '#admirable', 0.11, 'get_big', 'enlarge', 'flourish', 'make_big', 'growth']
senticnet['get_latest_hairstyle'] = [0.765, 0, 0, 0.892, '#joyful', '#admirable', 0.552, 'improve_image', 'look_better', 'dress_nice', 'change_appearance', 'groom']
senticnet['get_laugh'] = [-0.167, -0.129, -0.069, -0.313, '#sad', '#disgusting', -0.14, 'clown', 'embarrassment', 'disappoint', 'feel_sad', 'sad']
senticnet['get_line'] = [0, 0, 0, -0.1, '#disgusting', '#disgusting', -0.033, 'stand_queue', 'wait_line', 'wait_turn', 'stand_in_line', 'carve_niche']
senticnet['get_lose'] = [-0.95, 0, 0, -0.748, '#sad', '#disgusting', -0.566, 'traffic_accident', 'meet_old_friend', 'arrive_late', 'stop_traffic_light', 'press_accelerator']
senticnet['get_lost'] = [-0.027, 0.13, -0.057, 0.134, '#interesting', '#admirable', 0.06, 'flee', 'move_ahead', 'go_fast', 'move_forward', 'run_slowly']
senticnet['get_lung_cancer'] = [-0.118, -0.033, -0.156, -0.231, '#scared', '#disgusting', -0.157, 'die', 'old_age', 'disease', 'capital_punishment', 'suicide']
senticnet['get_manicure'] = [0, 0.849, 0, 0.93, '#interesting', '#admirable', 0.593, 'dye_hair', 'case_house', 'change_hairstyle', 'cut_hair', 'consult_expert']
senticnet['get_married'] = [0.997, 0.838, 0, 0.911, '#joyful', '#admirable', 0.915, 'love_back', 'love_oneself', 'love_another_person', 'show_empathy', 'warm_fuzzy_feeling']
senticnet['get_meal'] = [0.196, 0.077, 0, 0.064, '#joyful', '#interesting', 0.112, 'lower_temperature', 'reduce_temperature', 'temporary_shelter', 'entertain_company', 'remove_heat']
senticnet['get_money'] = [0, 0.117, -0.048, 0.089, '#interesting', '#admirable', 0.053, 'collect_debt', 'get_paid', 'receive_money', 'support_family', 'buy_gas']
senticnet['get_mug'] = [-0.96, 0, 0.995, 0, '#sad', '#angry', -0.652, 'sweaty', 'heart_rate_increase', 'stiffness', 'increase_metabolism', 'lack_energy']
senticnet['get_naked'] = [-0.158, 0.074, -0.176, -0.104, '#sad', '#scared', -0.121, 'call_doctor', 'doctor_appointment', 'wear_clean_underwear', 'go_doctor', 'take_shirt_off']
senticnet['get_need'] = [-0.03, -0.046, 0.07, -0.115, '#angry', '#disgusting', -0.056, 'buy', 'check_price', 'acquire_goods', 'make_purchase', 'look_buy']
senticnet['get_nervous'] = [0, 0, 0.95, 0, '#angry', '#angry', -0.317, 'chew_pencil', 'write_essay', 'scratch_head', 'look_clock', 'write_down']
senticnet['get_new_hairstyle'] = [0.196, 0.077, 0, 0.064, '#joyful', '#interesting', 0.112, 'look_smart', 'improve_appearance', 'short_hair', 'look_neat', 'change_hair_style']
senticnet['get_news'] = [0, 0.956, 0, 0, '#interesting', '#interesting', 0.319, 'learn_news', 'get_informed', 'view_art', 'appreciate_art', 'learn_entertainment']
senticnet['get_off'] = [0.861, -0.529, 0, 0.598, '#joyful', '#admirable', 0.663, 'exit', 'detrain', 'deplane', 'go_out', 'get_out']
senticnet['get_old'] = [-0.784, 0, 0, -0.935, '#sad', '#disgusting', -0.573, 'old', 'teen', 'elderly', 'years', 'annual_celebration']
senticnet['get_on'] = [0.686, -0.776, 0, 0.797, '#surprising', '#admirable', 0.753, 'come_in', 'board', 'intrude', 'irrupt', 'invade']
senticnet['get_out'] = [-0.904, 0, 0.943, -0.985, '#angry', '#disgusting', -0.944, 'kick_out', 'push_out', 'keep_distant', 'bouncer', 'push']
senticnet['get_out_breath'] = [-0.937, 0, 0, -0.834, '#sad', '#disgusting', -0.59, 'become_wind', 'breathlessness', 'run_out_breath', 'shin_splint', 'heavy_breathe']
senticnet['get_out_of_bed'] = [-0.137, -0.007, 0, -0.09, '#sad', '#disgusting', -0.073, 'start_new_day', 'hard_work', 'find_job', 'dig_ground', 'work_hard']
senticnet['get_out_of_house'] = [0.097, -0.097, 0.1, -0.162, '#angry', '#disgusting', -0.023, 'fun', 'lift_car', 'exercise_entertainment', 'health_benefit', 'get_fresh_air']
senticnet['get_over_illness'] = [0.849, 0, 0, 0, '#joyful', '#joyful', 0.283, 'get_rest', 'feel_little_tired', 'sleep_well', 'get_sleep', 'lie_back']
senticnet['get_oxygen'] = [0.827, 0, 0, 0.835, '#joyful', '#admirable', 0.554, 'survive', 'stay_alive', 'live', 'like_taste', 'sustain_life']
senticnet['get_paid'] = [0.849, 0, 0, 0, '#joyful', '#joyful', 0.283, 'get_money', 'collect_debt', 'receive_money', 'collect_money', 'pay_service']
senticnet['get_paycheck'] = [0.918, 0, 0, 0.996, '#joyful', '#admirable', 0.638, 'earn_money', 'support_family', 'responsible', 'money', 'paycheck']
senticnet['get_perm'] = [0, -0.035, 0.059, -0.066, '#angry', '#disgusting', -0.03, 'shape_hair', 'change_hairstyle', 'get_hair_colored', 'get_manicure', 'get_hair_style']
senticnet['get_physical_activity'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'physical_activity', 'maintain_muscle_strength', 'get_fit', 'release_energy', 'prove_physical_endurance']
senticnet['get_physically_fit'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'fun_exercise', 'keep_fit', 'recreational', 'athletic', 'fit_person']
senticnet['get_picture'] = [0.901, -0.53, 0, 0.732, '#joyful', '#admirable', 0.721, 'understand', 'twig', 'digest', 'tumble', 'intuit']
senticnet['get_place'] = [0.047, -0.012, 0.033, 0.071, '#joyful', '#admirable', 0.032, 'wander_around', 'get_somewhere', 'get_around_town', 'go_to_place', 'go_some_place']
senticnet['get_plane'] = [0.097, -0.097, 0.1, -0.162, '#angry', '#disgusting', -0.023, 'travel_quickly', 'press_accelerator', 'traffic_accident', 'get_lose', 'arrive_late']
senticnet['get_present'] = [0.727, 0.797, 0, 0.869, '#interesting', '#admirable', 0.798, 'show_care', 'make_happy', 'feel_obligated', 'say_thank_you', 'celebrate_anniversary']
senticnet['get_published'] = [0.504, -0.826, 0, 0.503, '#joyful', '#surprising', 0.611, 'learn_new_word', 'fantasize', 'spread_idea', 'self_expression', 'writer_cramp']
senticnet['get_qualification'] = [-0.071, -0.012, 0, -0.035, '#sad', '#disgusting', -0.031, 'prove_learn', 'prove_knowledge', 'want_pass_class', 'get_grade', 'complete_course']
senticnet['get_reaction'] = [0, 0, 0.828, 0, '#angry', '#angry', -0.276, 'amuse_oneself', 'pleasure', 'feel_different', 'give_pleasure', 'make_someone_happy']
senticnet['get_ready'] = [-0.031, 0.079, 0, 0.207, '#interesting', '#admirable', 0.085, 'make_food', 'make_tea', 'fry_chicken', 'season_meal', 'fry_egg']
senticnet['get_ready_to_fight'] = [-0.071, 0, -0.051, -0.176, '#sad', '#disgusting', -0.099, 'arm_oneself', 'declare_war', 'fight_man', 'armory', 'battle']
senticnet['get_reply'] = [-0.293, 0, -0.229, 0.108, '#sad', '#scared', -0.138, 'response', 'get_response', 'write_back', 'answer_back', 'interrogation']
senticnet['get_response'] = [0.097, -0.097, 0.1, -0.162, '#angry', '#disgusting', -0.023, 'response', 'get_reply', 'write_back', 'answer_back', 'interrogation']
senticnet['get_rest'] = [0.847, 0.871, 0, 0.903, '#interesting', '#admirable', 0.874, 'rejuvenation', 'recuperate', 'rest_dream', 'feel_refreshed', 'feel_little_tired']
senticnet['get_result'] = [0.847, 0.871, 0, 0.903, '#interesting', '#admirable', 0.874, 'result', 'study', 'get_degree', 'pass_exam', 'finish_college']
senticnet['get_revenge'] = [0, 0, 0.825, -0.853, '#angry', '#disgusting', -0.559, 'revenge', 'arrest', 'murderer', 'harden_criminal', 'weigh_consequence']
senticnet['get_rich'] = [0.848, 0.998, 0, 0, '#joyful', '#interesting', 0.615, 'gain_wealth', 'become_rich', 'increase_wealth', 'work_done', 'receive_money']
senticnet['get_rid'] = [-0.81, 0, 0, -0.914, '#sad', '#disgusting', -0.575, 'dispose', 'ditch', 'exchange_goods', 'discard', 'delete']
senticnet['get_rid_of_dirt'] = [0.036, 0, 0, 0.119, '#joyful', '#admirable', 0.052, 'disinfect', 'cleanliness', 'keep_clean', 'wash_away_dirt', 'hygiene']
senticnet['get_rid_of_enemy'] = [0.835, 0, 0, 0, '#joyful', '#joyful', 0.278, 'murder', 'death_destruction', 'kill_another_person', 'hurt_others', 'defend_oneself']
senticnet['get_salary'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'bill', 'file_bill', 'credit_check', 'get_paid', 'bank']
senticnet['get_school'] = [0.92, 0.734, 0, 0, '#joyful', '#interesting', 0.551, 'get_around_town', 'get_place', 'sightsee', 'commute_work', 'place_of_work']
senticnet['get_sex'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'become_popular', 'good_time', 'give_pleasure', 'get_to_know_person', 'social_interaction']
senticnet['get_shape'] = [0.02, -0.003, 0, 0.057, '#joyful', '#admirable', 0.027, 'get_fit', 'stay_fit', 'lose_weight', 'maintain_muscle_strength', 'eat_healthily']
senticnet['get_sick'] = [-0.108, 0, -0.097, -0.17, '#sad', '#disgusting', -0.125, 'choke_death', 'lower_standard', 'battle_cancer', 'vomit', 'cry_help']
senticnet['get_skin_cancer'] = [0, 0, -0.084, -0.12, '#scared', '#disgusting', -0.068, 'burn_skin', 'much_sun', 'ultraviolet', 'expose_skin_sun', 'get_burnt']
senticnet['get_sleep'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'feel_little_tired', 'take_nap', 'sleepy', 'asleep', 'lie_back']
senticnet['get_sleepy'] = [-0.893, 0, 0, -0.721, '#sad', '#disgusting', -0.538, 'boring', 'increase_knowledge', 'change_opinion', 'learn', 'become_smart']
senticnet['get_small'] = [-0.056, 0.277, -0.063, 0.239, '#interesting', '#admirable', 0.132, 'good_value', 'price_item', 'good_price', 'good_deal', 'tag']
senticnet['get_smart'] = [0.985, 0, 0, 0.931, '#joyful', '#admirable', 0.639, 'increase_knowledge', 'gain_knowledge', 'become_smart', 'learn', 'learn_information']
senticnet['get_smash'] = [-0.996, 0, 0.428, -0.955, '#sad', '#disgusting', -0.793, 'smash', 'crash', 'get_drunk', 'alcohol', 'accident']
senticnet['get_social_contact'] = [0.985, 0, 0, 0.931, '#joyful', '#admirable', 0.639, 'meet_people', 'go_party', 'go_out', 'expand_horizon', 'cultural_experience']
senticnet['get_something'] = [0.899, -0.753, 0, 0, '#joyful', '#surprising', 0.551, 'buy_love', 'buy_present_for_others', 'fight_inflation', 'give_gift', 'open_gift']
senticnet['get_something_from_person'] = [0.253, 0.332, -0.297, 0.3, '#interesting', '#admirable', 0.196, 'warm_feeling', 'desire', 'lust', 'better_person', 'demand']
senticnet['get_somewhere'] = [0.047, -0.012, 0.033, 0.071, '#joyful', '#admirable', 0.032, 'wander_around', 'get_place', 'get_around_town', 'go_to_place', 'go_some_place']
senticnet['get_somewhere_fast'] = [0, 0.961, 0, 0.87, '#interesting', '#admirable', 0.61, 'personal_transport', 'like_run', 'locomotion', 'go_fast', 'human_motion']
senticnet['get_sore_foot'] = [-0.921, 0, 0, -0.965, '#sad', '#disgusting', -0.629, 'get_front', 'learn_patience', 'become_impatient', 'get_ticket', 'take_turn']
senticnet['get_stick_traffic'] = [-0.923, 0, 0.767, -0.962, '#sad', '#disgusting', -0.884, 'plan_day', 'fly_plane', 'get_lose', 'meet_old_friend', 'rush_work']
senticnet['get_stolen'] = [-0.912, 0, 0.618, -0.932, '#sad', '#disgusting', -0.821, 'give_away', 'second_hand', 'old_stuff', 'lose_wallet', 'away']
senticnet['get_strong'] = [0.825, 0, 0, 0.722, '#joyful', '#admirable', 0.516, 'increase_stamina', 'sweat_lot', 'become_physically_fit', 'wear_out_shoes', 'exercise_dog']
senticnet['get_stuff'] = [0.762, 0, 0, 0.807, '#joyful', '#admirable', 0.523, 'obtain', 'satisfy_need', 'business_transaction', 'acquire', 'return_goods']
senticnet['get_sum'] = [0.829, 0, 0, 0.805, '#joyful', '#admirable', 0.545, 'add_two_numbers_together', 'get_total', 'find_total', 'add_number_together', 'find_number']
senticnet['get_sweaty'] = [-0.043, -0.038, 0.049, -0.076, '#angry', '#disgusting', -0.043, 'tired_leg', 'strain_muscle', 'increased_heart_rate', 'sweat', 'sweat_lot']
senticnet['get_table'] = [0.859, -0.81, 0, 0.615, '#joyful', '#surprising', 0.761, 'accessible', 'approachable', 'reachable', 'handy', 'ready_to_hand']
senticnet['get_tanned'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'make_beautiful', 'express_individuality', 'good_mental_health', 'personal_fulfillment', 'express_opinion']
senticnet['get_ticket'] = [0.776, 0.93, 0, 0, '#joyful', '#interesting', 0.569, 'get_front', 'take_turn', 'learn_patience', 'conformist_attitude', 'get_sore_foot']
senticnet['get_tired'] = [-0.951, 0, 0, -0.852, '#sad', '#disgusting', -0.601, 'tired_leg', 'pull_muscle', 'sweat', 'increased_heart_rate', 'sore_muscle']
senticnet['get_tired_leg'] = [-0.99, 0, 0, -0.945, '#sad', '#disgusting', -0.645, 'become_tired', 'fatigue', 'sore_leg', 'heavy_breathe', 'tiredness']
senticnet['get_to'] = [0.094, -0.036, 0.028, 0, '#joyful', '#surprising', 0.034, 'reach', 'achieve', 'attain', 'get', 'catch_up']
senticnet['get_to_another_place'] = [0.094, -0.036, 0.028, 0, '#joyful', '#surprising', 0.034, 'crash_tree', 'press_accelerator', 'stop_traffic_light', 'enjoy_view', 'flat_tire']
senticnet['get_to_destination'] = [0.1, -0.039, 0.034, 0.055, '#joyful', '#admirable', 0.053, 'get_place', 'travel', 'go_some_place', 'go_to_place', 'get_to_another_place']
senticnet['get_to_know_person'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'become_popular', 'get_sex', 'make_laugh', 'social_bond', 'give_pleasure']
senticnet['get_to_work_on_time'] = [-0.103, -0.072, 0.04, -0.118, '#sad', '#disgusting', -0.063, 'muscle_ache', 'work_day', 'tiredness', 'lack_energy', 'fatigue']
senticnet['get_together'] = [0.772, 0.868, 0, 0.895, '#interesting', '#admirable', 0.845, 'social_event', 'radical', 'enjoyable', 'become_popular', 'comedian']
senticnet['get_together_friend'] = [0.754, -0.838, 0, 0.608, '#joyful', '#surprising', 0.733, 'find_friend', 'socialization', 'relay_information', 'find_out_information', 'nothing_better']
senticnet['get_total'] = [0.094, -0.036, 0.028, 0, '#joyful', '#surprising', 0.034, 'add_two_numbers_together', 'learn_add', 'add_number_together', 'get_answer', 'sharpen_pencil']
senticnet['get_train'] = [-0.922, 0, 0, -0.97, '#sad', '#disgusting', -0.631, 'run_out_gas', 'stop_red_light', 'shift_gear', 'traveling_destination', 'automobile_accident']
senticnet['get_trouble'] = [-0.067, 0, -0.151, -0.159, '#scared', '#disgusting', -0.126, 'sexual_excitement', 'arousal', 'new_friendship', 'wet_lip', 'become_aroused']
senticnet['get_turn'] = [-0.079, 0, 0, -0.136, '#sad', '#disgusting', -0.072, 'pay_grocery', 'take_number', 'wait_service', 'take_turn', 'wait_until_turn']
senticnet['get_up'] = [0, 0.148, -0.071, 0.136, '#interesting', '#admirable', 0.071, 'move_upward', 'ascend', 'come_up', 'sun_up', 'go_up']
senticnet['get_up_early'] = [0.094, -0.036, 0.028, 0, '#joyful', '#surprising', 0.034, 'wake_up_morning', 'up_early', 'awake', 'gather_energy_tomorrow', 'sit_chair']
senticnet['get_up_morning'] = [0.258, 0, 0, 0, '#joyful', '#joyful', 0.086, 'out_bed', 'enough_sleep', 'read_good_book', 'good_day', 'good_night_sleep']
senticnet['get_vitamin'] = [0.81, 0, 0, 0.943, '#joyful', '#admirable', 0.584, 'stay_alive', 'healthy', 'get_oxygen', 'sustain_life', 'healthy_lifestyle']
senticnet['get_wasted'] = [-0.823, 0, 0, -0.866, '#sad', '#disgusting', -0.563, 'become_drunk', 'meet_new_person', 'act_stupid', 'pick_up_woman', 'drunkenness']
senticnet['get_water'] = [0.094, -0.036, 0.028, 0, '#joyful', '#surprising', 0.034, 'rinse', 'catch_trout', 'bathe', 'bath', 'take_shower']
senticnet['get_well'] = [0, 0, -0.091, -0.067, '#scared', '#disgusting', -0.053, 'cure_disease', 'treat_illness', 'unconscious', 'unwell', 'get_oxygen']
senticnet['get_wet'] = [-0.73, 0, 0, -0.928, '#sad', '#disgusting', -0.553, 'water_ear', 'wet_hair', 'get_killed', 'drown', 'slip_fall']
senticnet['get_wind'] = [-0.611, 0, 0.949, -0.598, '#sad', '#angry', -0.719, 'learn', 'hear', 'get_word', 'get_goods', 'pick_up']
senticnet['get_word'] = [0.094, -0.036, 0.028, 0, '#joyful', '#surprising', 0.034, 'learn', 'hear', 'get_goods', 'get_wind', 'pick_up']
senticnet['get_word_out'] = [0.047, 0, 0.018, 0.068, '#joyful', '#admirable', 0.032, 'talk_person', 'remember_name', 'communicate_person', 'find_person', 'send_information']
senticnet['get_work'] = [0.95, 0.953, 0, 0, '#joyful', '#interesting', 0.634, 'go_holiday', 'take_vacation', 'see_new_place', 'take_time_off_work', 'sightsee']
senticnet['get_work_done'] = [0.974, 0.788, 0, 0.964, '#joyful', '#admirable', 0.909, 'finish_task', 'accomplish_mission', 'earn_paycheck', 'good_job', 'get_done']
senticnet['get_worse'] = [-0.975, 0, 0.936, -0.986, '#sad', '#disgusting', -0.966, 'worse', 'minus_sign', 'negative', 'worse_health_condition', 'worse_economic_condition']
senticnet['getaway'] = [0.024, 0.152, -0.065, 0.236, '#interesting', '#admirable', 0.116, 'vacation', 'exit', 'stance', 'take_break', 'holiday']
senticnet['getting_strong'] = [0.709, 0.977, 0, 0.795, '#interesting', '#admirable', 0.827, 'increased_heart_rate', 'go_jogging_everyday', 'live_long', 'feel_strong', 'stay_fit']
senticnet['gherkin'] = [-0.818, 0, 0.543, -0.63, '#sad', '#disgusting', -0.664, 'caper', 'pickle', 'relish', 'dill_pickle', 'sweet_pickle']
senticnet['ghetto'] = [-0.024, -0.005, -0.049, 0, '#sad', '#scared', -0.023, 'medikit', 'manchester', 'medical_build', 'metropolitan_city', 'new_york_city']
senticnet['ghost'] = [0, 0, -0.722, -0.906, '#scared', '#disgusting', -0.543, 'spirit', 'soul', 'mind_control', 'angel', 'god']
senticnet['ghrelin'] = [0.685, -0.898, 0, 0.765, '#surprising', '#admirable', 0.783, 'motilin', 'gastrin', 'cholecystokinin', 'secretin', 'gastrointestinal_hormone']
senticnet['gi_hormones'] = [0.536, -0.693, 0, 0.643, '#surprising', '#admirable', 0.624, 'motilin', 'gastrin', 'cholecystokinin', 'secretin', 'ghrelin']
senticnet['giant'] = [-0.79, 0, 0.7, -0.517, '#sad', '#angry', -0.669, 'animal', 'animate_being', 'beast', 'creature', 'brute']
senticnet['giant_hives'] = [-0.998, 0, 0.605, -0.764, '#sad', '#disgusting', -0.789, 'angioedema', 'atrophedema', 'dropsy', 'periodic_edema', 'lymphedema']
senticnet['giant_hornet'] = [-0.663, 0, 0.946, -0.554, '#sad', '#angry', -0.721, 'yellow_hornet', 'yellow_jacket', 'hornet', 'vespid', 'vespid_wasp']
senticnet['giant_moa'] = [-0.681, 0, 0.956, -0.909, '#angry', '#disgusting', -0.849, 'moa', 'anomalopteryx', 'ratite', 'ratite_bird', 'flightless_bird']
senticnet['giantism'] = [-0.762, 0, 0.571, -0.847, '#sad', '#disgusting', -0.727, 'bigger_than_usual', 'hypertrophy', 'disease', 'overgrowth', 'feel_pain']
senticnet['gibber'] = [-0.614, 0, 0.738, -0.803, '#angry', '#disgusting', -0.718, 'babbling', 'double_talk', 'mumbo_jumbo', 'babble', 'lallation']
senticnet['gibbering'] = [0, 0, -0.869, -0.97, '#scared', '#disgusting', -0.613, 'prate', 'tittle-tattle', 'palaver', 'piffle', 'chatter']
senticnet['gibberish'] = [-0.826, 0, 0.921, -0.982, '#angry', '#disgusting', -0.91, 'babbling', 'double_talk', 'mumbo_jumbo', 'babble', 'lallation']
senticnet['gibe'] = [0.695, -0.525, 0, 0.957, '#joyful', '#admirable', 0.726, 'jibe', 'slam', 'cheap_shot', 'shot', 'shaft']
senticnet['giddiness'] = [-0.916, 0, 0.808, -0.728, '#sad', '#angry', -0.817, 'levity', 'fun', 'frivolity', 'trait', 'silliness']
senticnet['giddy'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'unwell', 'sick', 'nausea', 'pregnant', 'low_blood_pressure']
senticnet['gift'] = [0.974, 0.788, 0, 0.964, '#joyful', '#admirable', 0.909, 'present', 'birthday_gift', 'win_lottery', 'holiday', 'birthday']
senticnet['gift_adult'] = [-0.061, 0, -0.096, -0.104, '#scared', '#disgusting', -0.087, 'human_truthful', 'nurse', 'doctor', 'elderly_person', 'doctor_surgery']
senticnet['gift_box'] = [0.827, -0.935, 0, 0.759, '#joyful', '#surprising', 0.84, 'party', 'use_party', 'birthday_party', 'gift_shop', 'talk_show']
senticnet['gift_shop'] = [0.742, -0.767, 0, 0, '#joyful', '#surprising', 0.503, 'convention', 'prisoner_war_camp', 'rave', 'box_ring', 'dark_alley']
senticnet['gift_wrap'] = [0.991, 0, 0, 0.859, '#joyful', '#admirable', 0.617, 'generosity', 'oral_sex', 'win_lottery', 'consumerism', 'give_away']
senticnet['gifted'] = [0.777, 0.948, 0, 0, '#joyful', '#interesting', 0.575, 'empower', 'present', 'give', 'invest', 'talented']
senticnet['gig'] = [0.107, -0.046, 0, 0, '#joyful', '#surprising', 0.051, 'eclectic', 'rocker', 'jazz', 'rock_group', 'folk_music']
senticnet['giggle'] = [0.814, 0.705, 0, 0, '#joyful', '#interesting', 0.506, 'make_fun', 'hear_joke', 'make_others_laugh', 'laugh', 'clown']
senticnet['gigot'] = [0.783, -0.635, 0, 0.829, '#joyful', '#admirable', 0.749, 'leg_of_lamb', 'lamb_roast', 'joint', 'roast', 'rack_of_lamb']
senticnet['gild'] = [0.967, -0.982, 0, 0.64, '#joyful', '#surprising', 0.863, 'club', 'social_club', 'society', 'guild', 'jockey_club']
senticnet['gild_lily'] = [0.564, -0.731, 0, 0.58, '#surprising', '#admirable', 0.625, 'beautify', 'embellish', 'decorate', 'adorn', 'grace']
senticnet['gill'] = [-0.202, -0.108, 0.07, -0.245, '#sad', '#disgusting', -0.136, 'flipper', 'sea_life', 'seafood', 'swim_animal', 'fillet']
senticnet['gimbal'] = [0.843, -0.998, 0, 0.706, '#joyful', '#surprising', 0.849, 'gadgetry', 'contrivance', 'injector', 'mod_con', 'device']
senticnet['gin'] = [0.903, 0, 0, 0.704, '#joyful', '#admirable', 0.536, 'bourbon', 'vodka', 'scotch', 'brandy', 'wine']
senticnet['gin_mill'] = [-0.769, 0, 0.75, -0.563, '#sad', '#angry', -0.694, 'public_house', 'pub', 'saloon', 'pothouse', 'free_house']
senticnet['ginger'] = [0.077, 0, 0, 0, '#joyful', '#joyful', 0.026, 'dip', 'garlic', 'oat', 'savory', 'rye']
senticnet['ginger_up'] = [0.863, -0.665, 0, 0.646, '#joyful', '#surprising', 0.725, 'enliven', 'liven', 'liven_up', 'invigorate', 'animate']
senticnet['gingerol'] = [-0.829, 0, 0.642, -0.72, '#sad', '#disgusting', -0.73, 'substance', 'capsaicin', 'chemical_irritant', 'piperine', 'pepper_spray']
senticnet['ginmill'] = [-0.814, 0, 0.553, -0.928, '#sad', '#disgusting', -0.765, 'bar', 'barroom', 'saloon', 'sawdust_saloon', 'taproom']
senticnet['giraffe'] = [0, 0.161, -0.089, 0.09, '#interesting', '#admirable', 0.054, 'cheetah', 'kangaroo', 'caribou', 'mule', 'horse']
senticnet['girdle'] = [0.033, -0.073, 0, 0, '#joyful', '#surprising', 0.035, 'stuff_pillow', 'write_suicide_note', 'write', 'witting', 'become_dull']
senticnet['girl'] = [0.033, -0.073, 0, 0, '#joyful', '#surprising', 0.035, 'female', 'house_wife', 'mother', 'woman', 'girlfriend']
senticnet['girl_clothes'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'formal_clothes', 'woman_clothes', 'frilly', 'woman_garment', 'item_clothes']
senticnet['girl_name'] = [0, 0.19, -0.066, 0.093, '#interesting', '#admirable', 0.072, 'shine', 'alias', 'shiny', 'earl', 'patina']
senticnet['girl_room'] = [0, 0.921, 0, 0.701, '#interesting', '#admirable', 0.541, 'fancy_dress', 'shoe_shop', 'kid_room', 'furniture_store', 'toy_box']
senticnet['girlfriend'] = [0.033, -0.073, 0, 0, '#joyful', '#surprising', 0.035, 'female', 'house_wife', 'mother', 'woman', 'girl']
senticnet['girly'] = [0.027, -0.059, 0, 0.051, '#surprising', '#admirable', 0.046, 'frill', 'fashion', 'puppet', 'glamour', 'fad']
senticnet['gist'] = [0, 0.087, 0.038, 0.106, '#interesting', '#admirable', 0.052, 'control_access', 'gate', 'door', 'use_farm', 'juice']
senticnet['give'] = [0.722, 0, 0, 0.827, '#joyful', '#admirable', 0.516, 'receive', 'limit_time', 'offer', 'return', 'bid']
senticnet['give_answer'] = [-0.081, 0.109, -0.077, 0.184, '#interesting', '#admirable', 0.045, 'write_back', 'elaborate', 'response', 'tell', 'explain_detail']
senticnet['give_assistance'] = [0.643, 0.69, 0, 0.874, '#interesting', '#admirable', 0.736, 'comfort_friend', 'create_help_other_person', 'forgive', 'please_parent', 'make_better_world']
senticnet['give_attention'] = [0.147, 0.167, -0.123, 0.183, '#interesting', '#admirable', 0.125, 'give_food', 'feed', 'animal', 'domesticate_animal', 'feed_animal']
senticnet['give_away'] = [-0.912, 0, 0.618, -0.932, '#sad', '#disgusting', -0.821, 'get_stolen', 'second_hand', 'old_stuff', 'lose_wallet', 'away']
senticnet['give_back'] = [0, 0.983, 0, 0, '#interesting', '#interesting', 0.328, 'increase_money', 'money_transfer', 'give_take', 'transaction', 'financial_transaction']
senticnet['give_birth'] = [0.807, 0, 0, 0.829, '#joyful', '#admirable', 0.545, 'father_child', 'mother_child', 'pregnancy', 'love_another_person', 'relationship']
senticnet['give_birth_child'] = [0.069, 0.153, -0.111, 0.112, '#interesting', '#admirable', 0.074, 'procreate', 'reproduce', 'copulate', 'make_love', 'sexual_intercourse']
senticnet['give_blood'] = [0, 0, 0, 0.762, '#admirable', '#admirable', 0.254, 'kill_oneself', 'raise_flag', 'battle_cancer', 'box_ear', 'lower_standard']
senticnet['give_cash'] = [-0.084, 0.295, -0.12, 0.189, '#interesting', '#admirable', 0.093, 'money', 'send_money', 'currency_exchange', 'money_exchange', 'bill_pay']
senticnet['give_change'] = [0, 0.765, 0, 0.888, '#interesting', '#admirable', 0.551, 'carry_home', 'pay_money', 'settle_bill', 'make_change', 'count_change']
senticnet['give_comfort'] = [0.072, -0.02, 0, 0, '#joyful', '#surprising', 0.031, 'stay_touch', 'communicate_friend', 'send_information', 'spread_meme', 'communicate_thought']
senticnet['give_direction'] = [-0.045, 0.076, 0.033, 0.094, '#interesting', '#admirable', 0.031, 'elaborate', 'response', 'respond', 'explain', 'inquire']
senticnet['give_dog_exercise'] = [0.114, -0.111, 0.078, 0, '#joyful', '#surprising', 0.049, 'get_fresh_air', 'enjoy_outdoors', 'fun_exercise', 'get_physically_fit', 'learn_teamwork']
senticnet['give_flower'] = [0.906, 0.992, 0, 0.947, '#interesting', '#admirable', 0.948, 'give_gift', 'buy_love', 'buy_present_for_others', 'propose_woman', 'kiss']
senticnet['give_food'] = [0.076, 0.133, 0, 0.17, '#interesting', '#admirable', 0.126, 'sip', 'gulp', 'better_cold', 'potable_liquid', 'fluid']
senticnet['give_gift'] = [0.874, 0, 0, 0.704, '#joyful', '#admirable', 0.526, 'give_flower', 'buy_love', 'buy_present_for_others', 'give_assistance', 'thank']
senticnet['give_help'] = [0.944, 0, 0, 0.778, '#joyful', '#admirable', 0.574, 'demand', 'help_out', 'generous', 'wish', 'end_argument']
senticnet['give_hint'] = [0.894, 0, 0, 0.765, '#joyful', '#admirable', 0.553, 'give_answer', 'response', 'respond', 'yes_no', 'know_talk']
senticnet['give_hug'] = [0.956, 0, 0, 0.759, '#joyful', '#admirable', 0.572, 'know_other', 'become_aroused', 'say_welcome', 'hug', 'sexual_attraction']
senticnet['give_in'] = [-0.813, 0, 0.839, 0, '#sad', '#angry', -0.551, 'knuckle_under', 'buckle_under', 'succumb', 'give_up', 'yield']
senticnet['give_info'] = [0, 0.753, 0, 0.774, '#interesting', '#admirable', 0.509, 'communication_method', 'information_source', 'comment', 'written_language', 'form_of_communication']
senticnet['give_information'] = [0.956, 0, 0, 0.759, '#joyful', '#admirable', 0.572, 'exchange_information', 'express_opinion', 'communicate_idea', 'exchange_idea', 'social_life']
senticnet['give_lecture'] = [0.122, 0.066, 0, 0, '#joyful', '#interesting', 0.063, 'teach_student', 'teach_person', 'hear_speech', 'teach', 'time_test']
senticnet['give_lift'] = [0.794, -0.664, 0, 0.699, '#joyful', '#admirable', 0.719, 'take_kindly_to', 'tend', 'incline', 'lean', 'run']
senticnet['give_light'] = [-0.119, 0, -0.089, 0, '#sad', '#scared', -0.069, 'black_liquid', 'greasy', 'energy_source', 'dark_liquid', 'black_water']
senticnet['give_money'] = [0.792, 0, 0, 0.87, '#joyful', '#admirable', 0.554, 'compensation', 'earn_income', 'work_for_money', 'money', 'send_money']
senticnet['give_notice'] = [0.661, -0.821, 0, 0.952, '#surprising', '#admirable', 0.811, 'displace', 'fire', 'pension_off', 'can', 'dismiss']
senticnet['give_order'] = [0.102, 0.23, -0.058, 0.205, '#interesting', '#admirable', 0.16, 'command', 'leadership', 'army_officer', 'military_order', 'army_position']
senticnet['give_out'] = [0, 0.219, -0.174, 0.348, '#interesting', '#admirable', 0.131, 'hand_out', 'cope', 'hand_over', 'send', 'distribute']
senticnet['give_party'] = [-0.047, 0, 0, -0.102, '#sad', '#disgusting', -0.05, 'eat_potato_chip', 'stuff_face', 'enjoy_food', 'eat_out', 'able_eat']
senticnet['give_performance'] = [0, -0.016, 0.038, -0.079, '#angry', '#disgusting', -0.034, 'computer_software', 'play_instrument', 'annoy_person', 'like_music', 'play_musical_instrument']
senticnet['give_pleasure'] = [0.246, -0.145, 0.051, -0.1, '#joyful', '#surprising', 0.08, 'amuse', 'spread_happiness', 'good_time', 'make_laugh', 'comedian']
senticnet['give_plug'] = [0, -0.115, 0.024, 0.052, '#surprising', '#admirable', 0.048, 'know_how_stock_market_perform', 'go_public', 'give_assistance', 'sex_same_gender', 'create_help_other_person']
senticnet['give_present'] = [0.915, 0, 0.724, 0.952, '#joyful', '#admirable', 0.381, 'walk_exercise', 'wrap_gift', 'comparison_shop', 'spend_a_lot_of_money', 'buy_gift']
senticnet['give_sentence'] = [-0.912, 0, 0.618, -0.932, '#sad', '#disgusting', -0.821, 'judge', 'court', 'jury', 'death_sentence', 'trial']
senticnet['give_signal'] = [0, 0.837, 0, 0.756, '#interesting', '#admirable', 0.531, 'look_clue', 'remember_event', 'think_past', 'think_creatively', 'face_music']
senticnet['give_speech'] = [0.963, 0, 0, 0.929, '#joyful', '#admirable', 0.631, 'become_artist', 'speak_clearly', 'show_how', 'recite_poem', 'put_costume']
senticnet['give_take'] = [0, 0.297, -0.089, 0.365, '#interesting', '#admirable', 0.191, 'swap', 'barter', 'exchange_goods', 'transaction', 'give_back']
senticnet['give_testimony'] = [0.214, 0.258, -0.09, 0.2, '#joyful', '#interesting', 0.194, 'gather_evidence', 'testify', 'crime_scene', 'contact_police', 'receive_help']
senticnet['give_thank'] = [0.894, 0, 0, 0.932, '#joyful', '#admirable', 0.609, 'sigh_relief', 'company_come', 'little_hunger', 'say_goodbye', 'pet_cat']
senticnet['give_up'] = [-0.892, 0, 0, -0.968, '#sad', '#disgusting', -0.62, 'military_action', 'cancel', 'get_back', 'concede', 'beaten']
senticnet['give_up_struggle'] = [-0.918, 0, 0.871, -0.934, '#sad', '#disgusting', -0.908, 'death', 'die', 'kill', 'dead', 'murder']
senticnet['give_verdict'] = [0, 0.927, 0, 0.791, '#interesting', '#admirable', 0.573, 'close_case', 'bang_gavel', 'verdict', 'make_judgment', 'jugde']
senticnet['give_water'] = [0, 0.089, 0, 0.085, '#interesting', '#admirable', 0.058, 'water_spill', 'water', 'obtain_water', 'cool_water', 'atmosphere']
senticnet['give_word'] = [0, 0.94, 0, 0.907, '#interesting', '#admirable', 0.616, 'make_promise', 'testify', 'tell_truth', 'give_testimony', 'promise']
senticnet['given'] = [0, 0.367, -0.274, 0.436, '#interesting', '#admirable', 0.176, 'give', 'limit_time', 'donate', 'acceptance', 'donation']
senticnet['giver'] = [0.97, 0, 0, 0.751, '#joyful', '#admirable', 0.574, 'tribute', 'tradition', 'accomplice', 'good_intention', 'emancipation']
senticnet['giving'] = [0, -0.772, 0, 0.795, '#surprising', '#admirable', 0.522, 'return', 'dedicate', 'yield', 'liberal', 'sacrifice']
senticnet['glabrescent'] = [-0.587, 0, 0.66, -0.8, '#angry', '#disgusting', -0.682, 'bald', 'depilous', 'hairless', 'glabrous', 'balding']
senticnet['glabrous'] = [-0.587, 0, 0.66, -0.8, '#angry', '#disgusting', -0.682, 'bald', 'depilous', 'glabrescent', 'hairless', 'balding']
senticnet['glacial'] = [0, 0, -0.915, -0.913, '#scared', '#disgusting', -0.609, 'frozen', 'frosty', 'wintry', 'frigid', 'icy']
senticnet['glacier'] = [0.032, -0.039, 0, 0, '#joyful', '#surprising', 0.024, 'frozen_water', 'slush', 'come_down', 'water_fall', 'water_drop']
senticnet['glad'] = [0.726, 0.497, -0.309, 0.325, '#joyful', '#interesting', 0.413, 'merry', 'elation', 'contentment', 'joy', 'euphoria']
senticnet['gladden'] = [0.622, 0.641, -0.241, 0.285, '#joyful', '#interesting', 0.436, 'gleeful', 'gladsome', 'happiness', 'gladness', 'gladfulness']
senticnet['gladdened'] = [0.645, 0.637, -0.239, 0.299, '#joyful', '#interesting', 0.447, 'stimulating', 'tickle_pink', 'inebriate', 'exalt', 'beatify']
senticnet['glade'] = [-0.611, 0, 0.966, -0.729, '#angry', '#disgusting', -0.769, 'tract', 'piece_of_land', 'piece_of_ground', 'parcel_of_land', 'parcel']
senticnet['gladfulness'] = [0.635, 0.639, -0.243, 0.291, '#joyful', '#interesting', 0.441, 'gladsomeness', 'gladness', 'gladsome', 'beaming', 'gladden']
senticnet['gladiator'] = [-0.038, 0.092, 0.07, 0.1, '#interesting', '#admirable', 0.028, 'ancient_rome', 'civilization', 'church_build', 'coliseum', 'every_town']
senticnet['gladness'] = [0.635, 0.639, -0.243, 0.291, '#joyful', '#interesting', 0.441, 'gladsomeness', 'gladfulness', 'gladsome', 'beaming', 'gladden']
senticnet['gladsome'] = [0.635, 0.639, -0.243, 0.291, '#joyful', '#interesting', 0.441, 'gladsomeness', 'gladfulness', 'gladness', 'beaming', 'gladden']
senticnet['gladsomeness'] = [0.635, 0.639, -0.243, 0.291, '#joyful', '#interesting', 0.441, 'gladfulness', 'gladness', 'gladsome', 'beaming', 'gladden']
senticnet['glamour'] = [0.058, 0, 0, 0.073, '#joyful', '#admirable', 0.044, 'frilly', 'fancy_clothes', 'formal_clothes', 'woman_clothes', 'make_fashion_statement']
senticnet['glance'] = [0, 0.811, 0, 0, '#interesting', '#interesting', 0.27, 'observe', 'glimpse', 'look', 'stare', 'observation']
senticnet['gland'] = [-0.076, 0, -0.099, -0.167, '#scared', '#disgusting', -0.114, 'birth_control', 'infect', 'cure_illness', 'sickness', 'sexuality']
senticnet['gland_disease'] = [-0.533, 0, 0.667, -0.556, '#angry', '#disgusting', -0.585, 'exophthalmic_goiter', 'glandular_disease', 'thyrotoxicosis', 'glandular_disorder', 'adenosis']
senticnet['glandular_disease'] = [-0.533, 0, 0.667, -0.556, '#angry', '#disgusting', -0.585, 'exophthalmic_goiter', 'thyrotoxicosis', 'gland_disease', 'glandular_disorder', 'adenosis']
senticnet['glandular_disorder'] = [-0.533, 0, 0.667, -0.556, '#angry', '#disgusting', -0.585, 'exophthalmic_goiter', 'glandular_disease', 'gland_disease', 'thyrotoxicosis', 'adenosis']
senticnet['glandular_plague'] = [-0.949, 0, 0.905, -0.98, '#sad', '#disgusting', -0.945, 'pestis', 'plague', 'pestilence', 'pest', 'ambulant_plague']
senticnet['glare'] = [0.799, 0, 0, 0.897, '#joyful', '#admirable', 0.565, 'brightness', 'blaze', 'brilliance', 'glitter', 'glister']
senticnet['glaring'] = [0, 0, 0.709, -0.957, '#angry', '#disgusting', -0.555, 'fulgent', 'dazzling', 'egregious', 'blinding', 'glower']
senticnet['glass'] = [0, 0.069, 0.025, 0.074, '#interesting', '#admirable', 0.039, 'pane', 'look_glass', 'glass_of_water', 'see_thru', 'clear']
senticnet['glass_break'] = [-0.046, -0.049, 0.052, -0.116, '#angry', '#disgusting', -0.055, 'break_glass', 'shatter', 'hit_car', 'use_brake', 'see_dog']
senticnet['glass_case'] = [0, 0.069, 0.025, 0.074, '#interesting', '#admirable', 0.039, 'checkbook_holder', 'key_chain', 'precious', 'eyeglass_case', 'checkbook_cover']
senticnet['glass_container'] = [0, 0.98, 0, 0.947, '#interesting', '#admirable', 0.642, 'drink_container', 'liquid_container', 'drink_cup', 'drink_holder', 'type_of_container']
senticnet['glass_front'] = [0, 0, 0, 0.077, '#admirable', '#admirable', 0.026, 'door', 'gate', 'doorway', 'use_farm', 'entranceway']
senticnet['glass_front_cupboard'] = [0.054, -0.077, 0.025, 0, '#joyful', '#surprising', 0.035, 'table', 'dine_table', 'gate_leg_table', 'sideboard', 'dine_room_table']
senticnet['glass_front_display_cabinet'] = [0.066, 0.071, 0, 0, '#joyful', '#interesting', 0.046, 'old_photograph', 'picture_of_family', 'photo_album', 'family_picture', 'video_tape']
senticnet['glass_of_milk'] = [0.026, 0.08, 0.043, 0.064, '#interesting', '#admirable', 0.042, 'gunk', 'rotten_food', 'sour_cream', 'acid', 'lemon_juice']
senticnet['glass_of_water'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'water', 'tap', 'rattle', 'run_water', 'vibration']
senticnet['glass_water'] = [0.078, 0, 0, 0, '#joyful', '#joyful', 0.026, 'cold_water', 'refreshed', 'smoothie', 'lemonade', 'coke']
senticnet['glasses'] = [0.214, 0.258, -0.09, 0.2, '#joyful', '#interesting', 0.194, 'cup', 'carafe', 'pitcher', 'mug', 'container_cup']
senticnet['glassware'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'carafe', 'pitcher', 'container_cup', 'mug', 'glasses']
senticnet['glaucous_gull'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'white_bird', 'dove', 'egret', 'white_swan', 'eismowe']
senticnet['glaze'] = [-0.063, 0, 0.028, 0, '#sad', '#angry', -0.03, 'polish', 'magnify', 'see_out', 'sill', 'pane']
senticnet['gleam'] = [-0.663, 0, 0.616, -0.708, '#sad', '#disgusting', -0.662, 'flicker', 'coruscation', 'streak', 'glint', 'flash']
senticnet['gleaming'] = [0.65, -0.618, 0, 0.703, '#joyful', '#admirable', 0.657, 'effulgence', 'luster', 'polish', 'glow', 'burnish']
senticnet['glee'] = [0.761, 0.566, -0.212, 0.293, '#joyful', '#interesting', 0.469, 'gratify', 'jubilation', 'gloat', 'gloating', 'gloatingly']
senticnet['gleeful'] = [0.62, 0.643, -0.239, 0.287, '#joyful', '#interesting', 0.437, 'elated', 'bonheur', 'gladden', 'gladfulness', 'gladsome']
senticnet['gleefully'] = [0.593, 0.647, -0.238, 0.272, '#joyful', '#interesting', 0.425, 'joyfully', 'joyously', 'joyousness', 'joyfulness', 'bonheur']
senticnet['gleefulness'] = [0.695, 0.623, -0.231, 0.319, '#joyful', '#interesting', 0.469, 'uproarious', 'hilariously', 'hilarious', 'screaming', 'uproariously']
senticnet['gleet'] = [-0.525, 0, 0.538, -0.959, '#angry', '#disgusting', -0.674, 'sanies', 'pus', 'purulence', 'suppuration', 'ichor']
senticnet['glide'] = [-0.037, -0.02, 0.059, -0.057, '#angry', '#disgusting', -0.044, 'bus_person', 'fly_high', 'go_down', 'buzz', 'drop_bomb']
senticnet['glimpse'] = [0, 0.095, 0, 0.112, '#interesting', '#admirable', 0.069, 'stare', 'look', 'observation', 'ship_part', 'see']
senticnet['glint'] = [-0.663, 0, 0.616, -0.708, '#sad', '#disgusting', -0.662, 'flicker', 'coruscation', 'streak', 'flash', 'gleam']
senticnet['glistening'] = [0, 0, 0.963, -0.871, '#angry', '#disgusting', -0.611, 'shining', 'sheeny', 'gleam', 'glossy', 'lustrous']
senticnet['glittering'] = [0, 0, 0.762, -0.835, '#angry', '#disgusting', -0.532, 'glisten', 'scintillating', 'fulgid', 'coruscant', 'sparkly']
senticnet['gloat'] = [0, 0, 0.945, -0.857, '#angry', '#disgusting', -0.601, 'gloating', 'gloatingly', 'proudly', 'fulfillment', 'live_up_to']
senticnet['gloating'] = [0.779, 0.595, -0.21, 0.338, '#joyful', '#interesting', 0.501, 'gloatingly', 'fulfillment', 'live_up_to', 'fulfill', 'self-satisfaction']
senticnet['gloatingly'] = [-0.938, 0, 0, -0.842, '#sad', '#disgusting', -0.593, 'gloat', 'gloating', 'cheer', 'dwell', 'schadenfreude']
senticnet['global_thermonuclear_war'] = [-0.712, 0, -0.811, -0.974, '#scared', '#disgusting', -0.832, 'war', 'death', 'thermonuclear_war', 'bomb', 'get_killed']
senticnet['global_warming'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'panda', 'hunting', 'air_pollution', 'endangered_species', 'sea_pollution']
senticnet['globe_trotter'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'wanderlust', 'travel', 'visit_new_place', 'explore', 'discover']
senticnet['globule'] = [-0.559, 0, 0.869, -0.838, '#angry', '#disgusting', -0.755, 'air_bubble', 'foam', 'froth', 'soap_bubble', 'bubble']
senticnet['glochid'] = [-0.849, 0, 0.987, -0.777, '#sad', '#angry', -0.871, 'thorn', 'sticker', 'pricker', 'prickle', 'spikelet']
senticnet['glochidium'] = [-0.879, 0, 0.983, -0.918, '#angry', '#disgusting', -0.927, 'thorn', 'sticker', 'pricker', 'prickle', 'spikelet']
senticnet['glomerulonephritis'] = [-0.848, 0, 0.608, -0.523, '#sad', '#angry', -0.66, 'nephritis', 'nephrosis', 'kidney_disease', 'renal_disorder', 'nephropathy']
senticnet['gloom'] = [-0.934, 0, 0, -0.955, '#sad', '#disgusting', -0.63, 'dreary', 'melancholy', 'grim', 'drab', 'sorry']
senticnet['gloomful'] = [-0.798, 0.257, -0.471, -0.036, '#sad', '#scared', -0.349, 'glooming', 'darkness', 'somberness', 'gloominess', 'gloomily']
senticnet['gloomily'] = [-0.798, 0.257, -0.471, -0.036, '#sad', '#scared', -0.349, 'gloomful', 'glooming', 'darkness', 'somberness', 'gloominess']
senticnet['gloominess'] = [-0.798, 0.257, -0.471, -0.036, '#sad', '#scared', -0.349, 'gloomful', 'glooming', 'darkness', 'somberness', 'gloomily']
senticnet['glooming'] = [-0.798, 0.257, -0.471, -0.036, '#sad', '#scared', -0.349, 'gloomful', 'darkness', 'somberness', 'gloominess', 'gloomily']
senticnet['gloomy'] = [-0.79, 0.262, -0.459, -0.045, '#sad', '#scared', -0.344, 'downhearted', 'down_in_mouth', 'depressed', 'downcast', 'low-spirited']
senticnet['glop'] = [0.825, -0.916, 0, 0.626, '#joyful', '#surprising', 0.789, 'treacle', 'sentimentalism', 'mush', 'slop', 'formulation']
senticnet['glorify'] = [0.54, -0.976, 0, 0.569, '#surprising', '#admirable', 0.695, 'overstate', 'hyperbolize', 'aggrandize', 'exaggerate', 'overdraw']
senticnet['glorious'] = [0.936, 0, 0, 0.741, '#joyful', '#admirable', 0.559, 'storied', 'historied', 'divine', 'empyreal', 'glory']
senticnet['glory'] = [0.802, 0.798, 0, 0.773, '#joyful', '#interesting', 0.791, 'honor', 'valor', 'mission_accomplished', 'respect', 'praise']
senticnet['glossitis'] = [-0.638, 0, 0.961, -0.705, '#angry', '#disgusting', -0.768, 'acute_glossitis', 'glossodynia_exfoliativa', 'rubor', 'redness', 'inflammation']
senticnet['glossodynia_exfoliativa'] = [-0.638, 0, 0.961, -0.705, '#angry', '#disgusting', -0.768, 'acute_glossitis', 'glossitis', 'rubor', 'redness', 'inflammation']
senticnet['glossy'] = [0.042, 0, 0.012, 0.103, '#joyful', '#admirable', 0.044, 'book_write', 'media', 'written', 'readable', 'book_content']
senticnet['glove'] = [0.57, -0.566, 0, 0.888, '#joyful', '#admirable', 0.675, 'wearable', 'wear', 'muff', 'hand_wear', 'clothing']
senticnet['glove_leather'] = [0.087, -0.037, 0, 0.063, '#joyful', '#admirable', 0.062, 'puppet', 'bouncy', 'curly', 'throw_object', 'testicle']
senticnet['glow'] = [0.637, -0.713, 0, 0.932, '#surprising', '#admirable', 0.761, 'brightness_level', 'illumination', 'incandescence', 'luminescence', 'illuminance']
senticnet['glucosamine'] = [0.677, -0.545, 0, 0.587, '#joyful', '#admirable', 0.603, 'glucose', 'corn_sugar', 'dextrose', 'dextroglucose', 'grape_sugar']
senticnet['glucose'] = [0.677, -0.545, 0, 0.587, '#joyful', '#admirable', 0.603, 'glucosamine', 'corn_sugar', 'dextrose', 'dextroglucose', 'grape_sugar']
senticnet['glue'] = [0.105, -0.178, 0.057, 0.079, '#joyful', '#surprising', 0.102, 'stick', 'adhesive', 'follow', 'believe_in', 'adhere']
senticnet['glue_stick'] = [0.038, 0, 0, 0.097, '#joyful', '#admirable', 0.045, 'blank_check', 'address_book', 'post-it_note', 'ball_point_pen', 'paper_clip']
senticnet['glued'] = [0.993, -0.893, 0, 0.891, '#joyful', '#surprising', 0.926, 'mounted', 'appendant', 'basifixed', 'affixed', 'pasted']
senticnet['gluey'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'wet', 'sticky', 'tacky', 'viscous', 'gooey']
senticnet['glum'] = [-0.557, 0, 0.557, -0.703, '#sad', '#angry', -0.606, 'downhearted', 'down_in_mouth', 'dispirited', 'grim', 'dejected']
senticnet['glumness'] = [-0.934, 0, 0.508, -0.848, '#sad', '#disgusting', -0.763, 'nakedness', 'cloud', 'bleakness', 'desolation', 'bareness']
senticnet['glut'] = [0, 0.285, -0.075, 0.163, '#interesting', '#admirable', 0.124, 'plus', 'importance', 'a_lot', 'bonus', 'extra']
senticnet['glutton'] = [0.066, 0.157, 0.045, -0.028, '#joyful', '#interesting', 0.05, 'eat_food', 'cheap_food', 'pork', 'meal', 'cut_meat']
senticnet['gluttony'] = [0.768, -0.723, 0, 0.838, '#joyful', '#admirable', 0.776, 'edacity', 'esurience', 'voracity', 'voraciousness', 'rapaciousness']
senticnet['glyptic_art'] = [0.969, -0.686, 0, 0.756, '#joyful', '#admirable', 0.804, 'vermiculation', 'cinquefoil', 'carving', 'glyptography', 'scrimshaw']
senticnet['glyptography'] = [0.969, -0.686, 0, 0.756, '#joyful', '#admirable', 0.804, 'vermiculation', 'cinquefoil', 'glyptic_art', 'carving', 'scrimshaw']
senticnet['gnarl'] = [0.697, -0.507, 0, 0.792, '#joyful', '#admirable', 0.665, 'tortuousness', 'distorted_shape', 'warp', 'tortuosity', 'torsion']
senticnet['gnat'] = [-0.024, -0.096, 0.133, -0.142, '#angry', '#disgusting', -0.068, 'mosquito', 'flea', 'gypsy_moth', 'mole_cricket', 'cucumber_beetle']
senticnet['gnaw'] = [-0.221, -0.077, -0.144, 0.08, '#sad', '#scared', -0.069, 'stagger', 'hunt_human', 'monitor_heart_rate', 'prevent_conception', 'choke']
senticnet['gnocchi'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'french_toast', 'fondue', 'soybean', 'result_cook', 'lasagna']
senticnet['gnome'] = [0.809, -0.695, 0, 0.95, '#joyful', '#admirable', 0.818, 'faery', 'faerie', 'fairy', 'fay', 'sprite']
senticnet['go_abroad'] = [0, 0.067, 0, 0.062, '#interesting', '#admirable', 0.043, 'social_skill', 'show_up', 'take_place', 'go_new_place', 'visit']
senticnet['go_after'] = [-0.963, 0, 0.968, 0, '#sad', '#angry', -0.644, 'vicious', 'violent', 'overpower', 'raid', 'arm_man']
senticnet['go_against'] = [-0.126, 0.115, -0.064, -0.119, '#sad', '#disgusting', -0.065, 'opposition', 'fight_against', 'rival', 'uprise', 'anti']
senticnet['go_ahead'] = [-0.078, 0.271, -0.145, 0.343, '#interesting', '#admirable', 0.13, 'forward_movement', 'go_forward', 'move_ahead', 'movement', 'flee']
senticnet['go_airport'] = [-0.041, 0, 0.035, -0.115, '#sad', '#disgusting', -0.064, 'decide_to_go', 'buy_plane_ticket', 'buy_airplane_ticket', 'read_map', 'know_go']
senticnet['go_amusement_park'] = [0.741, 0.762, 0, 0.893, '#interesting', '#admirable', 0.799, 'play_on_grass', 'drive_crazy', 'become_adult', 'head_home', 'ring_doorbell']
senticnet['go_around'] = [0, 0.156, -0.057, 0.265, '#interesting', '#admirable', 0.121, 'rotate', 'rotate_movement', 'change_direction', 'manoeuvre', 'eight_sides']
senticnet['go_art_gallery'] = [0.039, 0.09, 0, 0.091, '#interesting', '#admirable', 0.073, 'like_art', 'go_museum', 'go_art_museum', 'use_eye', 'open_eye']
senticnet['go_art_museum'] = [0.039, 0.09, 0, 0.091, '#interesting', '#admirable', 0.073, 'like_art', 'go_museum', 'go_art_gallery', 'use_eye', 'open_eye']
senticnet['go_away'] = [-0.037, 0.095, -0.061, 0.174, '#interesting', '#admirable', 0.057, 'get_lost', 'drag', 'departure', 'movement', 'bring_together']
senticnet['go_back'] = [-0.05, 0.182, -0.083, 0.185, '#interesting', '#admirable', 0.078, 'reject', 'no_stop', 'come', 'commence', 'move_ahead']
senticnet['go_back_home'] = [0.738, 0, 0, 0, '#joyful', '#joyful', 0.246, 'hang_up_towel', 'become_aroused', 'contraception', 'safe_sex', 'sex']
senticnet['go_back_on'] = [0.985, -0.761, 0, 0.96, '#joyful', '#admirable', 0.902, 'reverse', 'lift', 'overturn', 'vacate', 'annul']
senticnet['go_back_time'] = [-0.091, 0.078, -0.112, -0.093, '#scared', '#disgusting', -0.073, 'start_laugh', 'sneer', 'frown', 'hear_joke', 'hallucination']
senticnet['go_backwards'] = [-0.112, 0.184, -0.131, 0.157, '#interesting', '#admirable', 0.033, 'rear', 'backside', 'rear_end', 'flipside', 'exception']
senticnet['go_bad'] = [-0.806, 0, 0.899, -0.834, '#angry', '#disgusting', -0.846, 'blow', 'change', 'crash', 'go_down', 'blow_out']
senticnet['go_ball'] = [0.055, -0.055, 0.064, -0.129, '#angry', '#disgusting', -0.028, 'hear_sing', 'hear_music', 'go_concert', 'listen_music', 'see_band']
senticnet['go_bank'] = [0, 0.729, 0, 0.816, '#interesting', '#admirable', 0.515, 'open_wallet', 'take_out_wallet', 'write_check', 'save_money', 'money_bank']
senticnet['go_bankrupt'] = [-0.819, -0.715, 0.843, -0.726, '#sad', '#angry', -0.558, 'go_broke', 'bankruptcy', 'lose_money', 'become_poor', 'owe_money']
senticnet['go_bar'] = [0, 0.081, 0, 0.071, '#interesting', '#admirable', 0.051, 'designate_driver', 'valet', 'drink_a_lot_of_beer', 'go_party', 'drink_alcohol']
senticnet['go_barber'] = [0.738, 0, 0, 0, '#joyful', '#joyful', 0.246, 'visit_barber', 'go_hair_salon', 'haircut', 'go_barbershop', 'get_hair_colored']
senticnet['go_barber_shop'] = [0, 0.886, 0, 0, '#interesting', '#interesting', 0.295, 'go_barber', 'visit_barber', 'go_hair_salon', 'beard_cut', 'haircut']
senticnet['go_barbershop'] = [-0.024, 0.122, 0, 0.137, '#interesting', '#admirable', 0.078, 'get_line', 'wait_turn', 'wait_line', 'stand_in_line', 'get_haircut']
senticnet['go_baseball_game'] = [0, 0.071, 0, 0, '#interesting', '#interesting', 0.024, 'go_sport_event', 'go_performance', 'go_play', 'go_movie', 'go_opus']
senticnet['go_bathroom'] = [-0.068, 0, -0.051, -0.071, '#sad', '#disgusting', -0.063, 'go_toilet', 'take_off_shoes', 'defecate', 'remove_clothes', 'go_pee']
senticnet['go_bathroom_first'] = [-0.095, 0, 0.014, 0, '#sad', '#angry', -0.036, 'go_park', 'wear_running_shoes', 'act_quickly', 'put_running_shoes', 'wear_good_shoes']
senticnet['go_bed'] = [0.054, -0.04, 0, 0, '#joyful', '#surprising', 0.031, 'go_sleep', 'sleep_night', 'want_sleep', 'sleep', 'sleep_sometimes']
senticnet['go_bed_early'] = [0, 0.851, 0, 0.817, '#interesting', '#admirable', 0.556, 'set_alarm', 'rest_up', 'sleep_early', 'need_to_rest', 'catch_breath']
senticnet['go_bookshop'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'open_book', 'buy_book', 'visit_library', 'book', 'read_book']
senticnet['go_broke'] = [-0.873, -0.794, 0.729, -0.976, '#sad', '#disgusting', -0.595, 'bankruptcy', 'go_bankrupt', 'empty_pocket', 'hobo', 'go_debt']
senticnet['go_build'] = [-0.053, 0.158, -0.068, 0.275, '#interesting', '#admirable', 0.104, 'go_through', 'hang_door', 'enter_area', 'enter', 'enter_room']
senticnet['go_burger_king'] = [0.061, -0.049, 0, 0, '#joyful', '#surprising', 0.037, 'go_supermarket', 'find_shop', 'find_store', 'go_grocery_store', 'drive_to_store']
senticnet['go_by_book'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'follow_rule_blindly', 'strict', 'inflexible', 'dumb', 'closed_minded']
senticnet['go_cafe'] = [0.832, 0.861, 0, 0.848, '#interesting', '#admirable', 0.847, 'drink_espresso', 'espresso', 'drink_coffee', 'eat_dinner', 'coffee']
senticnet['go_cashless'] = [0, 0.76, 0, 0.864, '#interesting', '#admirable', 0.541, 'buy_goods_service', 'pay_goods', 'incur_debt', 'postpone_payment', 'buy_item']
senticnet['go_casino'] = [0, -0.038, 0, 0.075, '#surprising', '#admirable', 0.038, 'poker_chip', 'deck_card', 'toy_car', 'yo-yo', 'poker']
senticnet['go_church'] = [0.88, 0.856, 0, 0.947, '#joyful', '#admirable', 0.894, 'belief_god', 'listen_sermon', 'religious_purpose', 'faith', 'religious']
senticnet['go_cinema'] = [0.804, 0.979, 0, 0, '#joyful', '#interesting', 0.594, 'check_listing', 'buy_popcorn', 'buy_movie_ticket', 'go_movie_theater', 'pay_ticket']
senticnet['go_class'] = [-0.074, 0, 0.024, -0.112, '#sad', '#disgusting', -0.07, 'a_lot_of_study', 'study_lot', 'study_hard', 'enroll_school', 'show_up_time']
senticnet['go_club'] = [0.777, 0.738, 0, 0, '#joyful', '#interesting', 0.505, 'dance', 'hook_up', 'socialize', 'go_party', 'social_skill']
senticnet['go_clubbing'] = [0.966, 0.921, 0, 0.892, '#joyful', '#interesting', 0.926, 'disco', 'nightclub', 'shop_complex', 'discotheque', 'dance_club']
senticnet['go_college'] = [-0.054, 0, 0.035, -0.129, '#sad', '#disgusting', -0.073, 'enroll_school', 'a_lot_of_study', 'study_material', 'study_lot', 'earn_degree']
senticnet['go_colorado'] = [-0.09, 0.067, -0.089, -0.047, '#sad', '#scared', -0.053, 'falling_water', 'put_bath_suit', 'water_fall', 'take_off_clothes', 'remove_clothes']
senticnet['go_coma'] = [0, -0.004, -0.081, -0.085, '#scared', '#disgusting', -0.054, 'lose_consciousness', 'epileptic_fit', 'get_involved_in_accident', 'jump_out_of_window', 'drug_addiction']
senticnet['go_concert'] = [0, 0, 0, -0.072, '#disgusting', '#disgusting', -0.024, 'go_movie', 'watch_musician_perform', 'attend_opus', 'go_opus', 'turn_stereo']
senticnet['go_court'] = [-0.906, 0, -0.953, 0, '#sad', '#scared', -0.62, 'make_judgment', 'question_witness', 'verdict', 'go_courtroom', 'call_lawyer']
senticnet['go_courtroom'] = [-0.068, 0, -0.099, -0.188, '#scared', '#disgusting', -0.118, 'examine_evidence', 'accuse', 'listen_witness', 'call_witness', 'sit_jury']
senticnet['go_crazy'] = [-0.292, -0.025, -0.097, -0.133, '#sad', '#disgusting', -0.166, 'speeding_ticket', 'feel_ashamed', 'feel_stupid', 'go_insane', 'punch_face']
senticnet['go_date'] = [0.817, 0.78, 0, 0.971, '#joyful', '#admirable', 0.856, 'enjoy_performance', 'laugh_lot', 'make_out_date', 'feel_happy', 'see_show']
senticnet['go_debt'] = [-0.729, 0, -0.945, -0.809, '#scared', '#disgusting', -0.828, 'lose_wallet', 'carry_home', 'run_out_money', 'bankruptcy', 'receive_change']
senticnet['go_deep'] = [0.524, -0.759, 0, 0.828, '#surprising', '#admirable', 0.704, 'go_onwards', 'lead', 'run', 'pass', 'extend']
senticnet['go_dentist'] = [-0.159, -0.06, 0, -0.081, '#sad', '#disgusting', -0.06, 'prevent_cavity', 'miss_appointment', 'snore', 'jump_off_bridge', 'unplug']
senticnet['go_department_store'] = [-0.032, 0, 0.041, 0, '#sad', '#angry', -0.024, 'go_to_shopping_mall', 'moolah', 'drive_to_store', 'bring_a_lot_of_money', 'find_merchant']
senticnet['go_diet'] = [-0.058, 0, 0.018, 0, '#sad', '#angry', -0.025, 'exercise', 'go_gym', 'eat_right', 'work_out', 'eat_little']
senticnet['go_dive'] = [0, -0.029, 0.06, -0.042, '#angry', '#disgusting', -0.024, 'get_boat', 'take_cruise', 'go_sea', 'take_leak', 'hold_fish']
senticnet['go_doctor'] = [-0.916, 0, -0.83, 0, '#sad', '#scared', -0.582, 'visit_doctor', 'go_see_doctor', 'see_doctor', 'blood_test', 'call_doctor']
senticnet['go_doctor_office'] = [-0.785, 0, -0.945, 0, '#sad', '#scared', -0.577, 'wear_clean_underwear', 'schedule_appointment_doctor', 'make_doctor_appointment', 'make_appointment_with_doctor', 'go_see_doctor']
senticnet['go_down'] = [-0.176, -0.159, -0.082, -0.207, '#sad', '#disgusting', -0.102, 'stumble', 'fall', 'before_fall', 'drop_down', 'almost_fall']
senticnet['go_downhill'] = [0.993, 0, 0, 0.873, '#joyful', '#admirable', 0.622, 'easy', 'nice', 'relax', 'little_effort', 'take_break']
senticnet['go_drive'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'out_car', 'avoid_fall', 'move_car', 'take_car_drive', 'drive_car']
senticnet['go_elsewhere'] = [0.827, 0, 0, 0.891, '#joyful', '#admirable', 0.573, 'trucking', 'mobility', 'transport_person', 'car_travel', 'transportation']
senticnet['go_end'] = [0.731, 0.729, 0, 0.866, '#joyful', '#admirable', 0.775, 'stand_behind', 'start_move', 'conform', 'stand', 'able_run']
senticnet['go_far'] = [-0.063, 0.124, -0.045, 0.125, '#interesting', '#admirable', 0.047, 'proximity', 'long_distance', 'afar', 'give_up', 'distant']
senticnet['go_fast'] = [0, 0, 0, 0.12, '#admirable', '#admirable', 0.04, 'move_fast', 'get_somewhere_fast', 'personal_transport', 'locomotion', 'change_location']
senticnet['go_fast_walk'] = [0.812, 0.982, 0, 0, '#joyful', '#interesting', 0.598, 'movement_place_another', 'enjoy_scenery', 'enjoy_nature', 'move_fast', 'enjoy_outdoors']
senticnet['go_fishing'] = [-0.861, 0, 0.941, -0.713, '#sad', '#angry', -0.838, 'salmon', 'trout', 'salmonid', 'fish', 'catch_fish']
senticnet['go_for'] = [0.694, -0.567, 0, 0.888, '#joyful', '#admirable', 0.716, 'bear_on', 'touch', 'concern', 'come_to', 'refer']
senticnet['go_for_broke'] = [-0.566, 0, 0.863, -0.537, '#sad', '#angry', -0.655, 'hazard', 'risk', 'chance', 'adventure', 'gamble']
senticnet['go_for_stroll'] = [-0.137, 0, -0.051, 0, '#sad', '#scared', -0.063, 'walk', 'find_garden', 'walk_down', 'walk_style', 'enter_place']
senticnet['go_forth'] = [-0.072, 0.227, -0.131, 0.203, '#interesting', '#admirable', 0.076, 'progress', 'lunge', 'advance', 'meander', 'go_ahead']
senticnet['go_forward'] = [-0.049, 0.189, -0.09, 0.3, '#interesting', '#admirable', 0.117, 'move_ahead', 'forward_movement', 'go_ahead', 'movement', 'relocation']
senticnet['go_friend'] = [0.203, 0.111, 0, 0.089, '#joyful', '#interesting', 0.134, 'ticket_taker', 'ticket_turnstile', 'other_person', 'movie_star', 'opus_ticket']
senticnet['go_from_place_to_place'] = [0.063, -0.032, 0.022, 0.077, '#joyful', '#admirable', 0.05, 'travel_long_distance', 'transport_person', 'travel_to_another_place', 'wander_around', 'get_to_another_place']
senticnet['go_game'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'delight_audience', 'amuse_child', 'bounce_up_down', 'add_two_numbers', 'play_on_grass']
senticnet['go_get'] = [0.054, 0.237, -0.152, 0.33, '#interesting', '#admirable', 0.156, 'retrieve', 'bring', 'tote', 'take', 'fetch']
senticnet['go_get_haircut'] = [0.816, 0.977, 0, 0, '#joyful', '#interesting', 0.598, 'get_manicure', 'get_hair_colored', 'get_hair_style', 'stylish', 'get_haircut']
senticnet['go_green'] = [0.561, 0.575, 0, 0.763, '#interesting', '#admirable', 0.633, 'better_world', 'nice_environment', 'live', 'religious_experience', 'good_health']
senticnet['go_grocery_shop'] = [0, 0.886, 0, 0, '#interesting', '#interesting', 0.295, 'buy_food', 'grocery_shop', 'christmas_shop', 'buy_fresh_fruit_vegetable', 'buy_bread']
senticnet['go_grocery_store'] = [-0.043, -0.004, 0.058, 0, '#sad', '#angry', -0.032, 'go_supermarket', 'find_shop', 'go_burger_king', 'find_store', 'drive_to_store']
senticnet['go_gym'] = [-0.062, 0, -0.059, 0, '#sad', '#scared', -0.04, 'check_doctor', 'join_gym', 'workout', 'lift_weight', 'eat_balance_diet']
senticnet['go_hair_salon'] = [0, 0.886, 0, 0, '#interesting', '#interesting', 0.295, 'go_barber', 'visit_barber', 'go_barber_shop', 'beard_cut', 'haircut']
senticnet['go_high'] = [0.048, 0.146, 0, 0.137, '#interesting', '#admirable', 0.11, 'move_upwards', 'ascend', 'move_up', 'move_upward', 'go_up']
senticnet['go_hike'] = [0.777, 0.797, 0, 0, '#joyful', '#interesting', 0.525, 'sail_around_world', 'wind_watch', 'think_issue', 'chair_committee', 'see_star_night']
senticnet['go_holiday'] = [0.95, 0.953, 0, 0, '#joyful', '#interesting', 0.634, 'get_work', 'take_vacation', 'see_new_place', 'take_time_off_work', 'sightsee']
senticnet['go_home'] = [0.041, 0.074, 0, 0, '#joyful', '#interesting', 0.038, 'stretch_out', 'home_sweet_home', 'return_home', 'sit_back_relax', 'take_afternoon_nap']
senticnet['go_home_early'] = [-0.065, 0.068, -0.123, -0.163, '#scared', '#disgusting', -0.094, 'curfew', 'rule', 'restriction', 'cinderella', 'limitation']
senticnet['go_hospital'] = [-0.73, 0, -0.942, -0.818, '#scared', '#disgusting', -0.83, 'chest_pain', 'kill_oneself', 'take_aspirin', 'die', 'trouble_breathe']
senticnet['go_insane'] = [0, 0, 0.797, -0.789, '#angry', '#disgusting', -0.529, 'punch_face', 'feel_stupid', 'fall_down_flight_stair', 'lose_mind', 'feel_ashamed']
senticnet['go_inside'] = [0, 0.149, -0.076, 0.261, '#interesting', '#admirable', 0.111, 'hang_door', 'enter_area', 'go_build', 'enter', 'go_through']
senticnet['go_interview'] = [0.928, 0.778, 0, 0, '#joyful', '#interesting', 0.569, 'look_for_job', 'change_job', 'change_life', 'change_work', 'new_job']
senticnet['go_jail'] = [-0.42, 0, -0.344, -0.141, '#sad', '#scared', -0.302, 'go_to_prison', 'send_to_jail', 'injustice', 'arrest', 'incarceration']
senticnet['go_job'] = [0, 0.076, 0, 0, '#interesting', '#interesting', 0.025, 'earn_paycheck', 'get_job_done', 'write_resume', 'turn_off_alarm', 'get_paycheck']
senticnet['go_jogging'] = [-0.046, 0.091, 0, 0.185, '#interesting', '#admirable', 0.077, 'human_movement', 'fast_walk', 'get_somewhere_fast', 'vigorous_activity', 'human_motion']
senticnet['go_jogging_everyday'] = [0.709, 0.977, 0, 0.795, '#interesting', '#admirable', 0.827, 'increased_heart_rate', 'getting_strong', 'live_long', 'feel_strong', 'stay_fit']
senticnet['go_kiss'] = [0.854, 0.975, 0, 0.926, '#interesting', '#admirable', 0.918, 'look_through_binoculars', 'kiss', 'valentine_day', 'find_love', 'procreate']
senticnet['go_kitchen'] = [-0.038, 0.182, -0.05, 0.096, '#interesting', '#admirable', 0.063, 'choose_eat', 'find_restaurant', 'order_lunch', 'decide_want_eat', 'decide_eat']
senticnet['go_lake'] = [-0.053, 0, 0.035, 0, '#sad', '#angry', -0.029, 'catch_fish', 'put_swimsuit', 'go_pool', 'put_bath_suit', 'cool_water']
senticnet['go_long_way'] = [0.277, 0.161, 0, 0.337, '#joyful', '#admirable', 0.258, 'go_around', 'fulfill', 'conform', 'suffice', 'satisfy']
senticnet['go_mall'] = [0, -0.041, 0.063, -0.058, '#angry', '#disgusting', -0.027, 'go_store', 'go_market', 'grocery_shop', 'carry_wallet', 'pay_credit_card']
senticnet['go_market'] = [0.059, 0.212, 0, 0.143, '#interesting', '#admirable', 0.138, 'go_mall', 'go_store', 'grocery_shop', 'pay_credit_card', 'pay_cash']
senticnet['go_meet'] = [0, 0.808, 0, 0.925, '#interesting', '#admirable', 0.578, 'enroll_class', 'enroll', 'matriculate', 'plan_time', 'bring_book']
senticnet['go_moon'] = [0.054, 0.129, -0.053, 0.104, '#interesting', '#admirable', 0.078, 'avoid_pain', 'talk_oneself', 'sleep_late', 'age_gracefully', 'eat_potato']
senticnet['go_mountain'] = [0.054, 0.129, -0.053, 0.104, '#interesting', '#admirable', 0.078, 'find_mountain', 'enjoy_view', 'enjoy_nature', 'go_outside', 'beautiful_view']
senticnet['go_movie'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'watch_movie', 'go_performance', 'go_play', 'go_baseball_game', 'go_sport_event']
senticnet['go_movie_theater'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'watch_movie', 'go_to_theater', 'go_watch', 'find_out_play', 'go_cinema']
senticnet['go_museum'] = [0.039, 0.09, 0, 0.091, '#interesting', '#admirable', 0.073, 'like_art', 'go_art_museum', 'go_art_gallery', 'use_eye', 'open_eye']
senticnet['go_new_place'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'travel', 'get_plane', 'get_bus', 'come_back_home', 'reach_destination']
senticnet['go_nowhere'] = [0, 0, -0.784, -0.746, '#scared', '#disgusting', -0.51, 'waste_time', 'lost', 'scared', 'run_errand', 'anxious']
senticnet['go_off_strike'] = [0, 0, 0.937, -0.879, '#angry', '#disgusting', -0.605, 'make_porn', 'sell_new_book', 'deal_drug', 'go_public', 'open_business']
senticnet['go_office'] = [-0.05, 0, 0.014, -0.039, '#sad', '#disgusting', -0.034, 'take_dump', 'plan_time', 'little_effort', 'put_nice_clothes', 'out_bed']
senticnet['go_on'] = [0, 0.29, -0.149, 0.418, '#interesting', '#admirable', 0.186, 'proceed', 'take', 'bring_up', 'proceedwards', 'permission']
senticnet['go_on-line'] = [-0.098, 0, 0.03, -0.04, '#sad', '#disgusting', -0.056, 'efficient', 'browser', 'find_computer', 'detour', 'internet_connection']
senticnet['go_on_foot'] = [0.107, 0.098, 0, 0.135, '#joyful', '#admirable', 0.113, 'go_green', 'respect_nature', 'save_water', 'reduce_pollution', 'spread_seed']
senticnet['go_on_holiday'] = [-0.055, 0.077, 0, 0.058, '#interesting', '#admirable', 0.027, 'travel', 'buy_plane_ticket', 'book_ticket', 'look_map', 'buy_airplane_ticket']
senticnet['go_on_trip'] = [0, 0.14, 0, 0.172, '#interesting', '#admirable', 0.104, 'last', 'destination', 'go_abroad', 'result_injury', 'elsewhere']
senticnet['go_online'] = [0, 0.201, 0.018, 0.077, '#interesting', '#admirable', 0.087, 'type_url', 'boot_up_computer', 'connect_internet', 'buy_computer', 'find_address']
senticnet['go_onwards'] = [0.524, -0.759, 0, 0.828, '#surprising', '#admirable', 0.704, 'go_deep', 'lead', 'run', 'pass', 'extend']
senticnet['go_opus'] = [0, 0, 0, -0.072, '#disgusting', '#disgusting', -0.024, 'go_movie', 'watch_musician_perform', 'go_concert', 'attend_opus', 'turn_stereo']
senticnet['go_out'] = [0.861, -0.529, 0, 0.598, '#joyful', '#admirable', 0.663, 'exit', 'detrain', 'deplane', 'get_off', 'get_out']
senticnet['go_out_party'] = [0.699, 0.62, -0.23, 0.323, '#joyful', '#interesting', 0.471, 'jolliness', 'joviality', 'jolity', 'josh', 'chaff']
senticnet['go_out_public'] = [0.06, 0.076, 0, 0.071, '#interesting', '#admirable', 0.069, 'take_shower', 'take_shower_bath', 'take_bath', 'bath', 'wash_up']
senticnet['go_out_with_dad'] = [0.967, 0.861, 0, 0, '#joyful', '#interesting', 0.609, 'woman_child', 'relative', 'kin', 'family_relation', 'family_member']
senticnet['go_outdoors'] = [0.879, 0.83, 0, 0, '#joyful', '#interesting', 0.57, 'dress_appropriately', 'put_shoes', 'put_walking_shoes', 'dress_occasion', 'leave_house']
senticnet['go_outside'] = [0.879, 0.83, 0, 0, '#joyful', '#interesting', 0.57, 'go_park', 'put_shoes', 'wear_dress', 'wear_running_shoes', 'enjoy_nature']
senticnet['go_outside_even'] = [0.92, 0.976, 0, 0.722, '#joyful', '#interesting', 0.873, 'plan_vacation', 'leave_country', 'go_somewhere', 'go_vacation', 'go_pub']
senticnet['go_over'] = [0, 0.765, 0, 0.844, '#interesting', '#admirable', 0.536, 'acknowledge', 'organize_data', 'recognize_pattern', 'deduce', 'figure_out']
senticnet['go_park'] = [-0.092, 0, 0.051, 0, '#sad', '#angry', -0.048, 'go_outside', 'wear_good_shoes', 'put_running_shoes', 'put_shoes', 'wear_running_shoes']
senticnet['go_party'] = [0.719, 0, 0, 0, '#joyful', '#joyful', 0.24, 'celebrate', 'enjoy_company_friend', 'friend_over', 'drink_a_lot_of_beer', 'entertain_person']
senticnet['go_pee'] = [-0.054, 0, 0, -0.092, '#sad', '#disgusting', -0.049, 'take_off_shoes', 'go_toilet', 'brush_tooth', 'go_potty', 'use_toilet']
senticnet['go_performance'] = [0, 0.071, 0, 0, '#interesting', '#interesting', 0.024, 'go_sport_event', 'go_baseball_game', 'go_play', 'go_movie', 'go_opus']
senticnet['go_picnic'] = [0.879, 0.83, 0, 0, '#joyful', '#interesting', 0.57, 'fresh_air_exercise', 'enjoy_competition', 'exercise', 'challenge_oneself', 'relieve_stress']
senticnet['go_play'] = [0, 0.071, 0, 0, '#interesting', '#interesting', 0.024, 'go_sport_event', 'go_performance', 'go_baseball_game', 'go_movie', 'go_opus']
senticnet['go_pool'] = [-0.053, 0, 0.035, 0, '#sad', '#angry', -0.029, 'catch_fish', 'put_swimsuit', 'go_lake', 'put_bath_suit', 'cool_water']
senticnet['go_post_office'] = [-0.054, 0, 0, -0.092, '#sad', '#disgusting', -0.049, 'long_queue', 'waiting_time', 'queue', 'waste_time', 'stress']
senticnet['go_potty'] = [-0.044, 0, 0, -0.099, '#sad', '#disgusting', -0.048, 'urinate', 'go_toilet', 'bladder_full', 'go_pee', 'pee']
senticnet['go_pub'] = [0.92, 0.976, 0, 0.722, '#joyful', '#interesting', 0.873, 'plan_vacation', 'leave_country', 'go_somewhere', 'go_outside_even', 'go_vacation']
senticnet['go_public'] = [-0.032, -0.049, 0, 0.06, '#surprising', '#admirable', 0.026, 'make_better_world', 'change_society', 'take_oath', 'sex_same_gender', 'marry']
senticnet['go_read_book'] = [0.028, -0.015, 0, 0.087, '#joyful', '#admirable', 0.043, 'find_book', 'use_book', 'open_book', 'research', 'store_knowledge']
senticnet['go_restroom'] = [-0.063, 0, 0, -0.091, '#sad', '#disgusting', -0.051, 'drink_much_beer', 'use_fork', 'burp', 'acid_indigestion', 'eat_salad']
senticnet['go_rock_concert'] = [0.839, 0.821, 0, 0, '#joyful', '#interesting', 0.553, 'able_hear', 'attend_concert', 'sensibility', 'buy_concert_ticket', 'turn_radio']
senticnet['go_room'] = [-0.983, 0, 0, 0, '#sad', '#sad', -0.328, 'put_pyjamas', 'count_sheep', 'call_sick', 'sleepwalk', 'turn_out_light']
senticnet['go_scuba_dive'] = [0.771, 0, 0, 0, '#joyful', '#joyful', 0.257, 'die_young', 'cry_help', 'end_life', 'feel_stupid', 'feel_ashamed']
senticnet['go_sea'] = [0, -0.029, 0.06, -0.042, '#angry', '#disgusting', -0.024, 'get_boat', 'take_cruise', 'go_dive', 'take_leak', 'hold_fish']
senticnet['go_see_doctor'] = [-0.976, 0, -0.934, 0, '#sad', '#scared', -0.637, 'blood_test', 'see_doctor', 'visit_doctor', 'go_doctor', 'find_doctor']
senticnet['go_see_shrink'] = [-0.094, 0, 0.012, -0.056, '#sad', '#disgusting', -0.054, 'buy_diamond_ring', 'find_out_want', 'go_shopping', 'go_department_store', 'drive_to_store']
senticnet['go_shopping'] = [0.771, 0, 0, 0, '#joyful', '#joyful', 0.257, 'shop', 'store', 'shop_mall', 'shopping_center', 'buy_stuff']
senticnet['go_sleep'] = [0.054, -0.04, 0, 0, '#joyful', '#surprising', 0.031, 'go_bed', 'sleep_night', 'want_sleep', 'sleep', 'sleep_sometimes']
senticnet['go_slow'] = [0.822, 0.86, 0, 0.751, '#joyful', '#interesting', 0.811, 'drive_safe', 'take_nap', 'prevent_accident', 'feel_little_tired', 'rest_dream']
senticnet['go_some_place'] = [0.047, -0.012, 0.033, 0.071, '#joyful', '#admirable', 0.032, 'wander_around', 'get_somewhere', 'get_around_town', 'go_to_place', 'get_place']
senticnet['go_some_place_quiet'] = [-0.048, 0.104, 0, 0.064, '#interesting', '#admirable', 0.04, 'intelligence', 'read_much', 'book_subject', 'study', 'focus_concentration']
senticnet['go_somewhere'] = [0.92, 0.976, 0, 0.722, '#joyful', '#interesting', 0.873, 'plan_vacation', 'leave_country', 'go_vacation', 'go_outside_even', 'go_pub']
senticnet['go_somewhere_else'] = [-0.038, 0, 0.077, 0, '#sad', '#angry', -0.038, 'traveling_destination', 'change_location', 'little_pollution', 'expend_energy', 'win_race']
senticnet['go_sport_event'] = [0, 0.071, 0, 0, '#interesting', '#interesting', 0.024, 'go_baseball_game', 'go_performance', 'go_play', 'go_movie', 'go_opus']
senticnet['go_stadium'] = [-0.053, -0.022, 0.045, 0, '#sad', '#angry', -0.025, 'find_out_play', 'drive_theater', 'turn_on_tv', 'near_tv', 'open_eye']
senticnet['go_stage'] = [0.861, 0.928, 0, 0, '#joyful', '#interesting', 0.596, 'perform', 'act_play', 'pretend', 'play_violin', 'play_guitar']
senticnet['go_stall'] = [-0.058, -0.019, 0.036, -0.061, '#sad', '#disgusting', -0.045, 'bus_person', 'buzz', 'jump', 'glide', 'jump_high']
senticnet['go_store'] = [0.771, 0, 0, 0, '#joyful', '#joyful', 0.257, 'shop', 'store', 'shop_mall', 'shopping_center', 'buy_stuff']
senticnet['go_straight'] = [0, 0.175, 0, 0.231, '#interesting', '#admirable', 0.135, 'compass_direction', 'direction', 'end_point', 'eight_sides', 'red_light']
senticnet['go_supermarket'] = [-0.034, -0.008, 0.058, 0, '#sad', '#angry', -0.028, 'find_merchant', 'go_department_store', 'moolah', 'drive_to_store', 'go_to_shopping_mall']
senticnet['go_swim_pool'] = [-0.032, 0, 0.044, 0, '#sad', '#angry', -0.025, 'put_bath_suit', 'go_water', 'go_pool', 'jump_in_water', 'know_how_swim']
senticnet['go_symphony'] = [0, 0.746, 0, 0.911, '#interesting', '#admirable', 0.552, 'enjoy_art', 'bring_friend', 'classical_music', 'understand_plot', 'insert_dvd_in_player']
senticnet['go_through'] = [-0.029, 0.141, -0.064, 0.285, '#interesting', '#admirable', 0.111, 'enter_area', 'go_build', 'hang_door', 'enter_room', 'separate_room']
senticnet['go_to_another_place'] = [0.884, 0, 0, 0.898, '#joyful', '#admirable', 0.594, 'hitchhike', 'take_walk', 'take_bus', 'ask_for_lift', 'take_metro']
senticnet['go_to_beach'] = [0.896, 0.857, 0, 0, '#joyful', '#interesting', 0.584, 'sunscreen', 'wear_sunscreen', 'sunblock', 'sunny_day', 'summertime']
senticnet['go_to_bed'] = [0.85, -0.891, 0, 0, '#joyful', '#surprising', 0.58, 'fall_asleep', 'doze_off', 'turn_off_television', 'bed_time', 'drowsiness']
senticnet['go_to_cinema'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'theater_ticket', 'movie_ticket', 'watch_movie', 'enjoy_movie', 'have_fun']
senticnet['go_to_class'] = [0.737, 0, 0, 0.94, '#joyful', '#admirable', 0.559, 'teach_lesson', 'professor', 'school_student', 'teacher', 'teach_class']
senticnet['go_to_court'] = [-0.922, 0, 0.85, 0, '#sad', '#angry', -0.591, 'lawyer', 'take_court', 'call_lawyer', 'determine_guilt', 'lawsuit']
senticnet['go_to_dogs'] = [-0.519, 0, 0.965, -0.953, '#angry', '#disgusting', -0.812, 'go_to_pot', 'deteriorate', 'dilapidate', 'decay', 'wear']
senticnet['go_to_gym'] = [0.981, 0.955, 0, 0.709, '#joyful', '#interesting', 0.882, 'shape_up', 'fit', 'healthy', 'keep_fit', 'better_shape']
senticnet['go_to_hairdresser'] = [0, -0.097, 0.035, 0.1, '#surprising', '#admirable', 0.054, 'cut_hair', 'go_get_haircut', 'haircut', 'hairdressing_salon', 'hairdresser_chair']
senticnet['go_to_heaven'] = [0.88, 0.909, 0, 0.855, '#joyful', '#interesting', 0.881, 'human_emotion', 'emotion', 'donate', 'need_help', 'demand']
senticnet['go_to_hell'] = [-0.795, 0, -0.941, -0.849, '#scared', '#disgusting', -0.862, 'go_scuba_dive', 'cry_help', 'experience_pain', 'end_life', 'feel_stupid']
senticnet['go_to_jail'] = [0, 0, 0, -0.759, '#disgusting', '#disgusting', -0.253, 'put_in_jail', 'arrest', 'find_guilty', 'verdict', 'injustice']
senticnet['go_to_library'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'open_book', 'read_book', 'quiet_place', 'visit_library', 'buy_textbook']
senticnet['go_to_museum'] = [0.114, 0.071, -0.059, 0.074, '#joyful', '#admirable', 0.067, 'picture', 'look_art', 'look_picture', 'take_picture', 'see_picture']
senticnet['go_to_pieces'] = [0.957, -0.926, 0, 0.577, '#joyful', '#surprising', 0.82, 'behave', 'dissolve', 'die', 'fall_apart', 'lose_it']
senticnet['go_to_place'] = [0.1, -0.039, 0.034, 0.055, '#joyful', '#admirable', 0.053, 'get_place', 'travel', 'go_some_place', 'get_to_destination', 'get_to_another_place']
senticnet['go_to_pot'] = [-0.519, 0, 0.965, -0.953, '#angry', '#disgusting', -0.812, 'deteriorate', 'go_to_dogs', 'dilapidate', 'decay', 'wear']
senticnet['go_to_prison'] = [-0.837, 0, -0.882, -0.785, '#sad', '#scared', -0.835, 'go_jail', 'jail_time', 'send_to_jail', 'injustice', 'feel_guilt']
senticnet['go_to_school'] = [0.034, 0.252, -0.137, 0.277, '#interesting', '#admirable', 0.142, 'book', 'read_book', 'hold_book', 'go_to_library', 'choose_book']
senticnet['go_to_shopping_mall'] = [-0.027, 0, 0.042, 0, '#sad', '#angry', -0.023, 'go_department_store', 'moolah', 'find_market', 'find_merchant', 'drive_to_store']
senticnet['go_to_sleep'] = [0.101, -0.237, 0.031, 0.105, '#surprising', '#admirable', 0.137, 'finish_work', 'go_home', 'relax_time', 'end_day', 'meet_family']
senticnet['go_to_supermarket'] = [0, -0.031, 0.066, -0.044, '#angry', '#disgusting', -0.026, 'get_grocery', 'buy_goods', 'buy_bread', 'buy_gum', 'buy_milk']
senticnet['go_to_swimming_pool'] = [-0.04, 0.069, 0, 0.075, '#interesting', '#admirable', 0.035, 'scuba_gear', 'scuba', 'learn_swimming', 'jump_into_water', 'enjoy_nature']
senticnet['go_to_theater'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'go_movie_theater', 'go_cinema', 'drive_theater', 'pay_ticket', 'watch_movie']
senticnet['go_to_university'] = [0.061, 0.179, 0, 0.177, '#interesting', '#admirable', 0.139, 'study_lot', 'go_to_school', 'pass_exam', 'prepare_exam', 'study']
senticnet['go_to_work'] = [-0.047, -0.014, 0, -0.062, '#sad', '#disgusting', -0.032, 'commute', 'transportation', 'drive_to_work', 'drive', 'drive_car']
senticnet['go_toilet'] = [-0.711, 0, 0, -0.811, '#sad', '#disgusting', -0.507, 'go_pee', 'defecate', 'go_bathroom', 'brush_tooth', 'turn_heat']
senticnet['go_toward'] = [0, 0.21, -0.113, 0.345, '#interesting', '#admirable', 0.147, 'direction', 'unto', 'forehead', 'upon', 'toward']
senticnet['go_town'] = [0, 0.185, -0.064, 0.222, '#interesting', '#admirable', 0.114, 'book_flight', 'drive_car', 'visit_new_place', 'travel', 'explore']
senticnet['go_trial'] = [-0.245, 0, -0.198, -0.052, '#sad', '#scared', -0.165, 'send_to_prison', 'send_to_jail', 'arrest', 'find_guilty', 'commit_crime']
senticnet['go_trip'] = [0, 0.185, -0.064, 0.222, '#interesting', '#admirable', 0.114, 'book_flight', 'visit_new_place', 'trip', 'drive_car', 'travel']
senticnet['go_under'] = [-0.778, 0, 0.511, -0.536, '#sad', '#disgusting', -0.608, 'founder', 'subside', 'fall', 'settle', 'submerge']
senticnet['go_underwater'] = [0, 0.754, 0, 0.806, '#interesting', '#admirable', 0.52, 'fall_overboard', 'swim', 'scuba_dive', 'dive', 'pool_party']
senticnet['go_university'] = [-0.033, -0.027, 0.029, -0.058, '#sad', '#disgusting', -0.031, 'study', 'go_class', 'enroll_school', 'study_lot', 'a_lot_of_study']
senticnet['go_up'] = [0, 0.185, -0.064, 0.222, '#interesting', '#admirable', 0.114, 'ascend', 'move_upward', 'raise_up', 'upward_movement', 'move_up']
senticnet['go_up_down'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'walk_up', 'get_floor_another', 'go_upstairs', 'climb_up', 'move_between_floor_building']
senticnet['go_uphill'] = [0, 0.089, 0, 0.154, '#interesting', '#admirable', 0.081, 'move_upward', 'mountaineer', 'ascend', 'move_up', 'up_mountain']
senticnet['go_upstairs'] = [0, 0.135, -0.087, 0.123, '#interesting', '#admirable', 0.057, 'rise', 'lift', 'store_garage', 'arise', 'reflect_water']
senticnet['go_vacation'] = [0.92, 0.976, 0, 0.722, '#joyful', '#interesting', 0.873, 'plan_vacation', 'leave_country', 'go_somewhere', 'go_outside_even', 'go_pub']
senticnet['go_war'] = [-0.732, 0, -0.915, -0.903, '#scared', '#disgusting', -0.85, 'make_war', 'conquer_enemy', 'gain_territory', 'lose_war', 'ready_troop']
senticnet['go_watch'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'watch_movie', 'go_to_theater', 'go_movie_theater', 'find_out_play', 'go_cinema']
senticnet['go_water'] = [-0.032, 0, 0.044, 0, '#sad', '#angry', -0.025, 'put_bath_suit', 'go_swim_pool', 'go_pool', 'jump_in_water', 'know_how_swim']
senticnet['go_work'] = [0.229, 0.127, 0, 0, '#joyful', '#interesting', 0.119, 'return_work', 'start_project', 'work_box_office', 'write_program', 'begin_work']
senticnet['go_work_to_earn_money'] = [0.05, -0.029, 0, 0.111, '#joyful', '#admirable', 0.063, 'earn_live', 'get_paycheck', 'responsible', 'earn_money', 'earn_paycheck']
senticnet['go_wrong'] = [-0.786, 0, 0.915, -0.99, '#angry', '#disgusting', -0.897, 'bodge', 'botch_up', 'flub', 'ball_up', 'bollix']
senticnet['goa_bean'] = [-0.705, 0, 0.606, -0.723, '#sad', '#disgusting', -0.678, 'common_bean', 'soya', 'bean', 'mung_bean', 'mung']
senticnet['goad'] = [0, 0, 0.722, -0.768, '#angry', '#disgusting', -0.497, 'prod', 'spur', 'needle', 'urging', 'prick']
senticnet['goal'] = [0.05, 0.223, -0.049, 0.303, '#interesting', '#admirable', 0.176, 'option', 'conclusion', 'end_point', 'intend', 'conclude']
senticnet['goal_driven'] = [0, 0.717, 0, 0.765, '#interesting', '#admirable', 0.494, 'intelligent_agent', 'artificial_intelligence', 'goal_driven_active_entity', 'proactive', 'intelligent']
senticnet['goal_driven_active_entity'] = [0, 0.717, 0, 0.765, '#interesting', '#admirable', 0.494, 'intelligent_agent', 'artificial_intelligence', 'goal_driven', 'proactive', 'intelligent']
senticnet['goalie'] = [0.915, -0.91, 0, 0, '#joyful', '#surprising', 0.608, 'bleacher', 'hockey_fan', 'competitor', 'spectator', 'hockey_stick']
senticnet['goat'] = [0, 0.819, 0, 0.88, '#interesting', '#admirable', 0.566, 'servant', 'hog', 'lamb', 'peasant', 'shepherd']
senticnet['gob'] = [-0.926, 0, 0.783, -0.511, '#sad', '#angry', -0.74, 'clot', 'coagulum', 'lump', 'clew', 'agglomeration']
senticnet['goblin'] = [0, -0.032, -0.057, -0.121, '#scared', '#disgusting', -0.049, 'gnome', 'elf', 'dwarf', 'undersized', 'small_person']
senticnet['god'] = [0.878, 0, 0, 0.85, '#joyful', '#admirable', 0.576, 'dogma', 'goddess', 'saint', 'holy_man', 'minister']
senticnet['god_creation'] = [0.052, 0, 0, 0.094, '#joyful', '#admirable', 0.049, 'orbit_around_sun', 'enormous', 'milky', 'milky_galaxy', 'nasa']
senticnet['goddess'] = [0.958, 0, 0, 0.887, '#joyful', '#admirable', 0.615, 'god', 'priest', 'church_head', 'monk', 'pastor']
senticnet['godlessness'] = [0.905, -0.802, 0, 0.583, '#joyful', '#surprising', 0.763, 'unrighteousness', 'undutifulness', 'impiety', 'ungodliness', 'irreligiousness']
senticnet['godliness'] = [0.082, 0.17, -0.075, 0.291, '#interesting', '#admirable', 0.156, 'sanitary', 'sterile', 'pure', 'use_clean', 'free_will']
senticnet['goffer'] = [0.991, -0.733, 0, 0.668, '#joyful', '#surprising', 0.797, 'busy_bee', 'gopher', 'actor', 'doer', 'worker']
senticnet['gog'] = [0.065, 0.215, 0.011, 0.199, '#interesting', '#admirable', 0.156, 'domesticate_dog', 'domesticate_animal', 'pet_dog', 'cat', 'pet']
senticnet['going'] = [-0.666, 0, 0.585, -0.917, '#sad', '#disgusting', -0.723, 'withdrawal', 'exit', 'dispatch', 'breaking_away', 'farewell']
senticnet['gold'] = [0.04, 0, 0.017, 0.056, '#joyful', '#admirable', 0.026, 'platinum', 'silver', 'iron_ore', 'alloy', 'heavy_element']
senticnet['gold_dust'] = [-0.624, 0, 0.504, -0.798, '#sad', '#disgusting', -0.642, 'green_gold', 'pure_gold', 'atomic_number_79', 'guinea_gold', 'noble_metal']
senticnet['gold_fish'] = [0, 0.07, 0, 0, '#interesting', '#interesting', 0.023, 'sunken_treasure', 'scuba_diver', 'urchin', 'mussel', 'real_duck']
senticnet['gold_foil'] = [0.716, -0.791, 0, 0.543, '#joyful', '#surprising', 0.683, 'chaff', 'wrap', 'aluminium_foil', 'tin_foil', 'foil']
senticnet['goldbrick'] = [-0.86, 0, 0.675, -0.841, '#sad', '#disgusting', -0.792, 'shenanigan', 'chicanery', 'wile', 'dupery', 'trickery']
senticnet['goldcup'] = [-0.512, 0, 0.773, -0.802, '#angry', '#disgusting', -0.696, 'herb', 'meadow_buttercup', 'tall_buttercup', 'tall_crowfoot', 'tall_field_buttercup']
senticnet['golden'] = [0.049, 0.145, 0, 0.171, '#interesting', '#admirable', 0.122, 'kingly', 'govern', 'head_wear', 'chivalry', 'blue_blood']
senticnet['golden_age'] = [-0.963, 0, 0.615, -0.734, '#sad', '#disgusting', -0.771, 'flush', 'blossom', 'prime', 'peak', 'efflorescence']
senticnet['golden_ager'] = [0.556, -0.641, 0, 0.64, '#surprising', '#admirable', 0.612, 'centenarian', 'nonagenarian', 'octogenarian', 'septuagenarian', 'sexagenarian']
senticnet['golden_algae'] = [-0.659, 0, 0.523, -0.739, '#sad', '#disgusting', -0.64, 'confervoid_algae', 'seaweed', 'alga', 'diatom', 'brown_algae']
senticnet['golden_gate_bridge'] = [0.734, 0.852, 0, 0, '#joyful', '#interesting', 0.529, 'bridge', 'under_bridge', 'suspension_bridge', 'side_road', 'roadside']
senticnet['golden_saxifrage'] = [-0.839, 0, 0.768, -0.697, '#sad', '#angry', -0.768, 'water_carpet', 'water_mat', 'aquatic_plant', 'water_plant', 'hydrophyte']
senticnet['golden_spleen'] = [-0.592, 0, 0.78, -0.667, '#angry', '#disgusting', -0.68, 'water_carpet', 'water_mat', 'aquatic_plant', 'water_plant', 'hydrophyte']
senticnet['goldfish_bowl'] = [-0.519, 0, 0.562, -0.699, '#angry', '#disgusting', -0.593, 'fishbowl', 'fish_bowl', 'bowl', 'jorum', 'mazer']
senticnet['golf'] = [0.059, -0.049, 0.014, 0, '#joyful', '#surprising', 0.031, 'table_tennis', 'rugby', 'soccer', 'football', 'play_golf']
senticnet['golf_bag'] = [0.059, -0.049, 0.014, 0, '#joyful', '#surprising', 0.031, 'sports_equipment', 'sport_stuff', 'golf', 'sport_store', 'bag']
senticnet['golf_club'] = [0.137, -0.11, 0.036, -0.032, '#joyful', '#surprising', 0.06, 'wrench', 'metal_rod', 'nut_bolt', 'vise', 'spanner']
senticnet['golf_course'] = [0.049, 0.145, 0, 0.171, '#interesting', '#admirable', 0.122, 'golf_playground', 'yard', 'golf', 'play_golf', 'play_game']
senticnet['golf_place'] = [0, -0.013, 0.027, -0.1, '#angry', '#disgusting', -0.038, 'sand_paper', 'obstacle', 'chalk_board', 'paper', 'school_class']
senticnet['golf_playground'] = [0.049, 0.145, 0, 0.171, '#interesting', '#admirable', 0.122, 'golf_course', 'yard', 'golf', 'play_golf', 'play_game']
senticnet['golfer'] = [0, 0.78, 0, 0.959, '#interesting', '#admirable', 0.58, 'cultural_experience', 'entertain_oneself', 'film_critic', 'pastime', 'get_entertain']
senticnet['golosh'] = [-0.881, 0, 0.75, -0.855, '#sad', '#disgusting', -0.829, 'rubber', 'galosh', 'overshoe', 'arctic', 'gumshoe']
senticnet['gondola'] = [0.215, 0.194, -0.204, 0.279, '#joyful', '#admirable', 0.161, 'launch', 'mast', 'platform', 'launch_platform', 'ocean']
senticnet['gone'] = [-0.727, 0, 0, -0.771, '#sad', '#disgusting', -0.499, 'absent', 'give_up', 'dead', 'elsewhere', 'around_corner']
senticnet['gone_moon'] = [0, 0, -0.135, 0, '#scared', '#scared', -0.045, 'womb', 'anus', 'sister_house', 'asshole', 'land_moon']
senticnet['gonococcus'] = [0.905, -0.659, 0, 0.851, '#joyful', '#admirable', 0.805, 'bacteria', 'acidophil', 'acidophile', 'probiotic', 'probiotic_bacterium']
senticnet['gonorrhea'] = [-0.895, 0, -0.728, -0.743, '#sad', '#disgusting', -0.789, 'psychoneurosis', 'schizophrenia', 'toothache', 'feel_pain', 'feel_bad']
senticnet['gonorrhoea'] = [-0.611, 0, 0.899, -0.622, '#angry', '#disgusting', -0.711, 'venereal_disease', 'venereal_infection', 'social_disease', 'sexually_transmitted_disease', 'dose']
senticnet['goo'] = [0, 0, -0.712, -0.968, '#scared', '#disgusting', -0.56, 'sticky_substance', 'flour_water', 'insert', 'adhesive', 'sticky']
senticnet['good'] = [0.92, 0.98, 0, 0.75, '#joyful', '#interesting', 0.883, 'uncommon', 'niceness', 'like_candy', 'hard_find', 'pleasant']
senticnet['good-hearted'] = [0.552, 0.681, -0.294, 0.297, '#joyful', '#interesting', 0.412, 'charitable', 'large-hearted', 'openhearted', 'benevolent', 'kindly']
senticnet['good_acoustic'] = [-0.027, -0.057, 0.078, -0.122, '#angry', '#disgusting', -0.057, 'play_in_band', 'annoy_mom', 'play_orchestra', 'blow_note', 'play_music']
senticnet['good_actor'] = [0.47, 0.419, -0.318, 0.367, '#joyful', '#interesting', 0.313, 'wish_entertain', 'entertain_oneself', 'see_actor', 'enjoyment', 'entertainment']
senticnet['good_appearance'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'hot_girl', 'good_looking', 'appear_beautiful', 'beauty', 'enjoy_view']
senticnet['good_attitude'] = [0.281, 0.276, -0.274, 0.315, '#joyful', '#admirable', 0.199, 'better_person', 'demand', 'attitude', 'please', 'courtesy']
senticnet['good_balance'] = [0, 0.98, 0, 0.958, '#interesting', '#admirable', 0.646, 'put_helmet', 'buy_shoes', 'put_protective_gear', 'use_leg', 'slow']
senticnet['good_band'] = [0.74, 0.981, 0, 0.73, '#joyful', '#interesting', 0.817, 'good_music', 'string_quartet', 'music_shop', 'high_school_band', 'musical_instrument_store']
senticnet['good_behavior'] = [0.926, 0.744, 0, 0.914, '#joyful', '#admirable', 0.861, 'politeness', 'courtesy', 'good_etiquette', 'courteous', 'obey']
senticnet['good_bet'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'make_comparison', 'put_bid', 'ask_question', 'share_opinion', 'spread_out']
senticnet['good_body'] = [0.837, 0.818, 0, 0.874, '#joyful', '#admirable', 0.843, 'healthy_activity', 'good_human', 'fitness', 'push_up', 'athletic_activity']
senticnet['good_book'] = [0.044, 0, 0, 0.206, '#joyful', '#admirable', 0.083, 'cookbook', 'begin_end', 'book_end', 'novel', 'book']
senticnet['good_boy'] = [0.877, -0.922, 0, 0.795, '#joyful', '#surprising', 0.865, 'study_material', 'study_lot', 'study_language', 'go_class', 'diligent']
senticnet['good_break'] = [0.039, 0.152, 0, 0.157, '#interesting', '#admirable', 0.116, 'keep_safe', 'drive_safely', 'avoid_problem', 'just_in_time', 'avoid_accident']
senticnet['good_buy'] = [-0.026, 0.292, -0.077, 0.296, '#interesting', '#admirable', 0.162, 'good_price', 'bargain', 'cheap_price', 'sale', 'good_deal']
senticnet['good_catholic'] = [0.021, 0.199, 0.035, 0.171, '#interesting', '#admirable', 0.119, 'church', 'confession', 'catholic_church', 'spirituality', 'christianity']
senticnet['good_character'] = [0.093, 0.244, -0.174, 0.333, '#interesting', '#admirable', 0.165, 'honest', 'character_trait', 'trait', 'good_quality', 'characteristic']
senticnet['good_child'] = [0.935, 0, 0, 0.715, '#joyful', '#admirable', 0.55, 'feel_obligated', 'show_affection', 'express_love', 'show_love', 'pleasant_emotion']
senticnet['good_citizen'] = [0.889, 0.98, 0, 0.982, '#interesting', '#admirable', 0.95, 'pay_off_debt', 'positive_reinforcement', 'good_value', 'good_deal', 'discount']
senticnet['good_condition'] = [0.029, 0.21, -0.086, 0.298, '#interesting', '#admirable', 0.15, 'characteristic', 'character_trait', 'healthy', 'forward_movement', 'result_injury']
senticnet['good_conversation'] = [0.963, 0.974, 0, 0.721, '#joyful', '#interesting', 0.886, 'good_listener', 'human_contact', 'friendship', 'prepare_snack', 'talk_much']
senticnet['good_credit'] = [0.728, 0.922, 0, 0.996, '#interesting', '#admirable', 0.882, 'use_money', 'enough_money', 'money_credit', 'out_wallet', 'moolah']
senticnet['good_customer'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'save_money', 'buy_cheaper', 'better_price', 'sales', 'on_sale']
senticnet['good_day'] = [0.799, 0.753, 0, 0.946, '#joyful', '#admirable', 0.833, 'remission', 'strong_relationship', 'sexual_pleasure', 'self_respect', 'happiness']
senticnet['good_deal'] = [0.74, 0.777, 0, 0.706, '#joyful', '#interesting', 0.741, 'cheap_price', 'tag', 'good_value', 'good_price', 'good_buy']
senticnet['good_deed'] = [0.71, 0.882, 0, 0.9, '#interesting', '#admirable', 0.831, 'positive_reinforcement', 'brownie_point', 'benefit', 'given', 'gratification']
senticnet['good_dog'] = [0, 0.078, 0, 0.069, '#interesting', '#admirable', 0.049, 'get_perm', 'dog_treat', 'in_person', 'inside_body', 'below_neck']
senticnet['good_drink'] = [0.948, 0.992, 0, 0.974, '#interesting', '#admirable', 0.971, 'liquid_drink', 'hold_soda', 'popular_soda', 'healthy_drink', 'ferment_beverage']
senticnet['good_eat'] = [0.061, 0, 0.039, 0.097, '#joyful', '#admirable', 0.04, 'edible', 'delicious', 'yummy', 'tasty', 'part_of_meal']
senticnet['good_education'] = [0.188, 0.085, 0.035, 0.111, '#joyful', '#admirable', 0.116, 'financial_security', 'plenty_sleep', 'interest_job', 'good_job', 'keep_job']
senticnet['good_emotion'] = [0.605, 0.329, -0.275, 0.337, '#joyful', '#admirable', 0.332, 'wonderful_feeling', 'happy_emotion', 'ecstatic', 'happy_feeling', 'pleasant_emotion']
senticnet['good_environment'] = [0.967, 0.982, 0, 0.777, '#joyful', '#interesting', 0.909, 'other_side', 'make_strong', 'green', 'cultivate', 'usual_green']
senticnet['good_etiquette'] = [0.105, 0.284, -0.182, 0.418, '#interesting', '#admirable', 0.208, 'politeness', 'niceness', 'good_behavior', 'courtesy', 'reliable']
senticnet['good_everyone'] = [0.799, 0.81, 0, 0.91, '#interesting', '#admirable', 0.84, 'learn_sport', 'acquire_knowledge', 'information_gathering', 'resolve_dispute', 'get_knowledge']
senticnet['good_example'] = [0.84, -0.86, 0, 0.525, '#joyful', '#surprising', 0.742, 'beaut', 'ideal', 'beauty', 'pattern', 'pacesetter']
senticnet['good_exercise'] = [0.881, 0, 0, 0.9, '#joyful', '#admirable', 0.594, 'form_of_exercise', 'healthy_exercise', 'vigorous_activity', 'great_exercise', 'like_run']
senticnet['good_eyesight'] = [0.925, 0.962, 0, 0.848, '#joyful', '#interesting', 0.912, 'able_read', 'good_sense_of_humor', 'taken_seriously', 'much_need', 'complement']
senticnet['good_feeling'] = [0.878, 0.861, 0, 0.908, '#joyful', '#admirable', 0.882, 'happiness', 'self_satisfaction', 'happy', 'feel_good', 'pleasant_emotion']
senticnet['good_food'] = [0.076, 0, 0.045, 0.07, '#joyful', '#admirable', 0.034, 'good_meal', 'food_item', 'dairy_product', 'morning_food', 'flavor_food']
senticnet['good_for_you'] = [0.656, -0.731, 0, 0.736, '#surprising', '#admirable', 0.708, 'wholesome', 'salubrious', 'healthy', 'solid', 'alimentary']
senticnet['good_form_exercise'] = [0, 0, 0, 0.108, '#admirable', '#admirable', 0.036, 'fast', 'flee', 'sprint', 'race', 'marathon']
senticnet['good_fortune'] = [0.862, 0.762, 0, 0.917, '#joyful', '#admirable', 0.847, 'complement', 'world_peace', 'taken_seriously', 'spice_life', 'live_well']
senticnet['good_friend'] = [0.932, 0.931, 0, 0.78, '#joyful', '#interesting', 0.881, 'social_animal', 'feel_comfort', 'fun_around', 'good_pet', 'social_creature']
senticnet['good_fun'] = [0.868, 0.99, 0, 0, '#joyful', '#interesting', 0.619, 'acculturation', 'stimulate_mind', 'kill_time', 'pastime', 'enjoy_story']
senticnet['good_grade'] = [0.108, 0, 0, 0.056, '#joyful', '#admirable', 0.055, 'graduate_school', 'make_parent_happy', 'show_know', 'pass_grade', 'knowledge_power']
senticnet['good_habit'] = [0.827, 0.913, 0, 0.867, '#interesting', '#admirable', 0.869, 'competitive_nature', 'healthy_environment', 'good_nutrition', 'healthy_lifestyle', 'common_sense']
senticnet['good_health'] = [0.071, 0, 0, 0, '#joyful', '#joyful', 0.024, 'build_muscle', 'improve_health', 'stay_shape', 'healthy', 'become_fit']
senticnet['good_heart'] = [0.862, 0.744, 0, 0.851, '#joyful', '#admirable', 0.819, 'important_good_health', 'get_something_from_person', 'survive', 'good', 'healthy']
senticnet['good_human'] = [0.727, 0, 0, 0.886, '#joyful', '#admirable', 0.538, 'important_good_health', 'good_body', 'push_up', 'good_health', 'healthy']
senticnet['good_humor'] = [0.634, -0.518, 0, 0.785, '#joyful', '#admirable', 0.646, 'jolity', 'jolliness', 'joviality', 'humor', 'temper']
senticnet['good_hygiene'] = [0.101, 0, 0, 0.063, '#joyful', '#admirable', 0.055, 'smell_good', 'ensure_proper_hygiene', 'smell_better', 'impress_other_person', 'hygiene']
senticnet['good_idea'] = [0.041, 0, 0, 0.109, '#joyful', '#admirable', 0.05, 'understand_world', 'party', 'use_party', 'hold_beer', 'relax_friend']
senticnet['good_imagination'] = [0.934, 0.751, 0, 0, '#joyful', '#interesting', 0.562, 'become_actor', 'play_role', 'role_play', 'fool_person', 'part_of_play']
senticnet['good_intention'] = [0.882, 0, 0, 0.984, '#joyful', '#admirable', 0.622, 'kindness', 'need_help', 'altruistic', 'need', 'honor']
senticnet['good_investment'] = [0, 0.166, -0.087, 0.152, '#interesting', '#admirable', 0.077, 'build_home', 'place_where_people_live', 'small_building', 'habitation', 'own_land']
senticnet['good_job'] = [0.787, 0.857, 0, 0.766, '#joyful', '#interesting', 0.803, 'better_job', 'job', 'succeed', 'good_education', 'get_better_job']
senticnet['good_joke'] = [0.786, 0.744, 0, 0.813, '#joyful', '#admirable', 0.781, 'sense_of_humor', 'make_joke', 'hear_joke', 'tell_joke', 'tell_funny_joke']
senticnet['good_karma'] = [0.825, 0, 0, 0.865, '#joyful', '#admirable', 0.563, 'help', 'receive_thank', 'assistance', 'kindness', 'good_person']
senticnet['good_life'] = [0.853, 0.936, 0, 0.949, '#interesting', '#admirable', 0.913, 'improve_life', 'make_life_better', 'finish_college', 'serenity', 'make_life_easy']
senticnet['good_listener'] = [0.845, 0.99, 0, 0.862, '#interesting', '#admirable', 0.899, 'others_understand', 'good_sense_of_humor', 'strong_relationship', 'develop_talent', 'save_environment']
senticnet['good_look'] = [0.896, 0.887, 0, 0.719, '#joyful', '#interesting', 0.834, 'nice_look', 'gorgeous', 'lovely', 'attractive', 'compliment']
senticnet['good_looking'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'hot_girl', 'appear_beautiful', 'good_appearance', 'beauty', 'enjoy_view']
senticnet['good_lover'] = [0.914, 0, 0, 0.725, '#joyful', '#admirable', 0.546, 'look_night_sky', 'sanity', 'good_mental_health', 'stimulation', 'time_relax']
senticnet['good_luck'] = [0.746, 0.97, 0, 0.994, '#interesting', '#admirable', 0.903, 'luck', 'ritual', 'fame', 'prosperity', 'forgiven']
senticnet['good_luck_charm'] = [0.667, -0.869, 0, 0.884, '#surprising', '#admirable', 0.807, 'fetish', 'juju', 'object', 'voodoo', 'fetich']
senticnet['good_man'] = [-0.041, 0.077, -0.081, -0.082, '#scared', '#disgusting', -0.042, 'medic', 'sad_person', 'declare_war', 'arm_oneself', 'soldier']
senticnet['good_manner'] = [0.879, 0.97, 0, 0.921, '#interesting', '#admirable', 0.923, 'courteous', 'aide', 'compliment', 'politeness', 'handle_carefully']
senticnet['good_manners'] = [0.603, -0.987, 0, 0.648, '#surprising', '#admirable', 0.746, 'urbanity', 'niceness', 'politeness', 'gallantry', 'politesse']
senticnet['good_match'] = [0.587, 0.698, -0.53, 0.52, '#joyful', '#interesting', 0.425, 'compatibility', 'compatible', 'kind', 'kindhearted', 'kindheartedness']
senticnet['good_meal'] = [0.966, 0, 0, 0.951, '#joyful', '#admirable', 0.639, 'chef_special', 'hot_table', 'good_food', 'plate_silverware', 'chopstick']
senticnet['good_memory'] = [0.982, 0.978, 0, 0.803, '#joyful', '#interesting', 0.921, 'feel_smart', 'make_good_decision', 'much_need', 'others_understand', 'knowledgeable']
senticnet['good_mental_health'] = [0.845, 0.932, 0, 0.86, '#interesting', '#admirable', 0.879, 'good_lover', 'sit_sun', 'give_pleasure', 'get_sex', 'social_interaction']
senticnet['good_mood'] = [0.755, 0.928, 0, 0.991, '#interesting', '#admirable', 0.891, 'outgo_personality', 'picture_taken', 'make_smile', 'sense_joy', 'plan_party']
senticnet['good_morning'] = [0.279, 0.113, -0.115, 0.209, '#joyful', '#admirable', 0.162, 'cherish', 'eat_together', 'a_lot_of_sex', 'feel_pleasure', 'breakfast_bed']
senticnet['good_movie'] = [0.965, 0.949, 0, 0.82, '#joyful', '#interesting', 0.911, 'go_art_museum', 'pretty_woman', 'kind_gesture', 'humor', 'simile']
senticnet['good_music'] = [0.946, 0.816, 0, 0.984, '#joyful', '#admirable', 0.915, 'music', 'genre_music', 'hear_music', 'beautiful_music', 'enjoy_music']
senticnet['good_nature'] = [0.543, -0.678, 0, 0.553, '#surprising', '#admirable', 0.591, 'longanimity', 'patience', 'good_will', 'forbearance', 'grace']
senticnet['good_news'] = [0.946, 0.816, 0, 0.984, '#joyful', '#admirable', 0.915, 'good', 'bring_happiness', 'win_lottery', 'find_job', 'make_happy']
senticnet['good_night'] = [0.169, 0.113, -0.047, 0.127, '#joyful', '#admirable', 0.121, 'inactivity', 'rest_night', 'shut_eye', 'sleep_well', 'count_sheep']
senticnet['good_night_sleep'] = [0.258, 0, 0, 0, '#joyful', '#joyful', 0.086, 'out_bed', 'enough_sleep', 'read_good_book', 'good_day', 'get_up_morning']
senticnet['good_nutrition'] = [0.058, 0.109, -0.108, 0.14, '#interesting', '#admirable', 0.066, 'live_healthy_lifestyle', 'eat_healthy_food', 'live_long', 'eat_healthy', 'live_long_life']
senticnet['good_parent'] = [0.821, 0.855, 0, 0.962, '#interesting', '#admirable', 0.879, 'medical_care', 'smooth_skin', 'spice_life', 'complement', 'much_need']
senticnet['good_person'] = [0.738, 0.804, 0, 0.842, '#interesting', '#admirable', 0.795, 'good_karma', 'kindness', 'receive_thank', 'feel_happy', 'lust']
senticnet['good_pet'] = [0.711, 0.792, 0, 0.93, '#interesting', '#admirable', 0.811, 'carnivore', 'house_animal', 'household_animal', 'large_cat', 'small_elephant']
senticnet['good_physical_condition'] = [0, -0.063, 0.113, -0.107, '#angry', '#disgusting', -0.052, 'run_fast', 'put_sneaker', 'bring_dog', 'wear_boot', 'expend_energy']
senticnet['good_place'] = [0.067, 0.206, -0.098, 0.267, '#interesting', '#admirable', 0.147, 'encompass', 'from_here', 'family_live', 'line_place', 'live_life']
senticnet['good_place_eat'] = [0.094, 0.084, 0.024, 0.062, '#joyful', '#interesting', 0.072, 'good_reastaurant', 'cafe', 'place_eat', 'eatery', 'pub']
senticnet['good_plan'] = [0, 0.783, 0, 0.822, '#interesting', '#admirable', 0.535, 'weigh_consequence', 'make_plan', 'right_wrong', 'vengeance', 'plan_carefully']
senticnet['good_poem'] = [0.738, 0.723, 0, 0, '#joyful', '#interesting', 0.487, 'write_book', 'write_story', 'poet', 'write_poem', 'witting']
senticnet['good_price'] = [0.762, 0.745, 0, 0.751, '#joyful', '#admirable', 0.753, 'good_buy', 'cheap_price', 'bargain', 'discount', 'good_deal']
senticnet['good_quality'] = [0.169, 0.23, -0.196, 0.431, '#interesting', '#admirable', 0.211, 'well_done', 'character_trait', 'best', 'goodness', 'good_etiquette']
senticnet['good_reason'] = [0, 0.878, 0, 0.809, '#interesting', '#admirable', 0.562, 'motivate', 'use_hand', 'make_contact', 'donate', 'strike_against']
senticnet['good_reastaurant'] = [0.094, 0.084, 0.024, 0.062, '#joyful', '#interesting', 0.072, 'good_place_eat', 'cafe', 'place_eat', 'eatery', 'pub']
senticnet['good_reputation'] = [0.154, 0.142, -0.048, 0.09, '#joyful', '#interesting', 0.113, 'desire_money', 'keep_job', 'accomplish', 'support_family', 'tip_waiter']
senticnet['good_review'] = [0.801, 0, 0, 0.941, '#joyful', '#admirable', 0.581, 'enlightenment', 'know_happen', 'see_advertisement', 'desire_entertainment', 'expand_mind']
senticnet['good_sense'] = [0.678, -0.523, 0, 0.718, '#joyful', '#admirable', 0.64, 'road_sense', 'sagacity', 'sagaciousness', 'logic', 'nous']
senticnet['good_sense_of_humor'] = [0.845, 0.811, 0, 0.96, '#joyful', '#admirable', 0.872, 'complement', 'knowledgeable', 'taken_seriously', 'much_need', 'strong_relationship']
senticnet['good_service'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'seat', 'few_people', 'travel_comfortable', 'free_seat', 'free']
senticnet['good_shape'] = [0.125, 0.097, 0, 0.152, '#joyful', '#admirable', 0.125, 'after_exercise', 'rest_tire', 'elongate', 'plenty_rest', 'physical_condition']
senticnet['good_shoes'] = [0, 0.899, 0, 0.862, '#interesting', '#admirable', 0.587, 'put_shoes', 'choose_destination', 'put_running_shoes', 'wear_good_shoes', 'put_jogging_shoes']
senticnet['good_sleep'] = [0.961, 0, 0, 0.997, '#joyful', '#admirable', 0.653, 'comfortable_place_sleep', 'place_sleep', 'shut_eye', 'laze', 'sleep_upon']
senticnet['good_smell'] = [0.032, 0.072, 0, 0.08, '#interesting', '#admirable', 0.061, 'red_fruit', 'delicious_fruit', 'yellow_fruit', 'green_fruit', 'small_fruit']
senticnet['good_soul'] = [0.125, -0.01, 0, 0.173, '#joyful', '#admirable', 0.103, 'good_human', 'important_good_health', 'please_person', 'rhythmic', 'groove']
senticnet['good_spirit'] = [0.673, -0.64, 0, 0.669, '#joyful', '#admirable', 0.661, 'eudemon', 'white_angel', 'guardian_angel', 'genius_loci', 'angel']
senticnet['good_sport'] = [0.07, 0, 0, 0.086, '#joyful', '#admirable', 0.052, 'ephemeral', 'enjoyable_activity', 'card_type', 'competitive', 'medical_test']
senticnet['good_story'] = [0.801, 0.779, 0, 0, '#joyful', '#interesting', 0.527, 'child_book', 'interesting_story', 'something_to_tell', 'scholar', 'nice_ending']
senticnet['good_strategy'] = [0, 0.764, 0, 0, '#interesting', '#interesting', 0.255, 'gain_ground', 'conquer', 'win_battle', 'kill_enemy', 'win_war']
senticnet['good_student'] = [0.72, 0, 0, 0.982, '#joyful', '#admirable', 0.567, 'school_division', 'pupil', 'learning_place', 'college_course', 'group_student']
senticnet['good_taste'] = [0.706, 0.877, 0, 0.773, '#interesting', '#admirable', 0.785, 'wear_clean_clothes', 'personal_hygiene', 'put_clean_clothes', 'go_out_public', 'nice_clothes']
senticnet['good_taste_food'] = [0.984, 0.96, 0, 0.711, '#joyful', '#interesting', 0.885, 'fresh_fruit', 'apple_pie', 'steak', 'result_cook', 'ice_cream']
senticnet['good_teacher'] = [0.904, 0.932, 0, 0.976, '#interesting', '#admirable', 0.937, 'reliability', 'husband_wife', 'voyeur', 'smart_man', 'college_professor']
senticnet['good_temper'] = [0.825, -0.604, 0, 0.697, '#joyful', '#admirable', 0.709, 'jolity', 'jolliness', 'joviality', 'humor', 'temper']
senticnet['good_time'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'social_interaction', 'spend_time_with_friend', 'have_fun', 'pleasure', 'enjoy_oneself']
senticnet['good_tooth'] = [0.718, 0.849, 0, 0.704, '#joyful', '#interesting', 0.757, 'insulin', 'self_confidence', 'big_paycheck', 'good_credit', 'look_beautiful']
senticnet['good_trait'] = [0, 0.104, 0, 0.124, '#interesting', '#admirable', 0.076, 'era', 'constant', 'time_increment', 'time_designation', 'time_length']
senticnet['good_transportation'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'traffic_rule', 'new_buildings', 'bicycle_area', 'develop_city', 'control_road']
senticnet['good_value'] = [0.73, 0.814, 0, 0.912, '#interesting', '#admirable', 0.819, 'good_deal', 'tag', 'sales', 'sale_price', 'value']
senticnet['good_view'] = [0.16, 0.067, 0, 0.083, '#joyful', '#admirable', 0.103, 'great_view', 'summit', 'gable', 'snowflake', 'antenna']
senticnet['good_vision'] = [0.099, 0, 0, 0.168, '#joyful', '#admirable', 0.089, 'find_car_key', 'start_car_engine', 'know_how_drive', 'drive_license', 'license']
senticnet['good_weather'] = [0.956, 0.963, 0, 0.764, '#joyful', '#interesting', 0.894, 'large_dog', 'dog_like', 'type_of_dog', 'future_robot', 'sunny_day']
senticnet['good_wife'] = [0.051, 0.112, 0, 0, '#joyful', '#interesting', 0.054, 'wife', 'woman', 'mother', 'family', 'housewife']
senticnet['good_will'] = [0.601, 0.648, -0.265, 0.321, '#joyful', '#interesting', 0.435, 'brother', 'fraternal', 'brotherly', 'brother_like', 'amicability']
senticnet['good_wine'] = [0.82, 0, 0, 0.872, '#joyful', '#admirable', 0.564, 'drink_wine', 'wine_opener', 'wine_glass', 'made_of_glass', 'wine_bottle']
senticnet['good_word'] = [0.746, -0.648, 0, 0.898, '#joyful', '#admirable', 0.764, 'congratulations', 'kudos', 'extolment', 'character', 'puff']
senticnet['good_work'] = [0.785, 0.76, 0, 0.979, '#joyful', '#admirable', 0.841, 'achievement', 'positive_reinforcement', 'set_goal', 'good_job', 'good_deed']
senticnet['goodbye'] = [0, 0.145, 0, 0.2, '#interesting', '#admirable', 0.115, 'hand_gesture', 'arm_movement', 'water_splash', 'hand_motion', 'water_form']
senticnet['goodness'] = [0.129, 0.169, -0.139, 0.444, '#interesting', '#admirable', 0.201, 'excellent', 'well_done', 'best', 'excellence', 'greatness']
senticnet['goods'] = [0.028, 0.119, 0.018, 0.085, '#interesting', '#admirable', 0.071, 'grocery', 'merchandise', 'vendor', 'shopper', 'groceries']
senticnet['gooey'] = [0, 0, -0.723, -0.761, '#scared', '#disgusting', -0.495, 'bee_product', 'flammable', 'remove_hair', 'slick', 'really_hot']
senticnet['goof'] = [-0.816, 0, -0.924, 0, '#sad', '#scared', -0.58, 'pup', 'magical', 'bloodhound', 'chance', 'karma']
senticnet['goof_off'] = [0, 0, 0.748, -0.819, '#angry', '#disgusting', -0.522, 'search_information', 'look_for_information', 'check_email', 'phone_line_busy', 'distract']
senticnet['goofball'] = [0.821, -0.994, 0, 0.572, '#joyful', '#surprising', 0.796, 'clown', 'buffoon', 'goof', 'zany', 'merry_andrew']
senticnet['goofy'] = [0, 0.119, -0.071, 0.189, '#interesting', '#admirable', 0.079, 'play_dead', 'pull_cart', 'woolly_animal', 'action', 'beatles_song']
senticnet['goon'] = [-0.713, 0, 0.845, -0.691, '#sad', '#angry', -0.75, 'lump', 'clumsy_person', 'mortal', 'duffer', 'butterfingers']
senticnet['goose_bump'] = [0, 0.119, -0.071, 0.189, '#interesting', '#admirable', 0.079, 'enjoy', 'good_feeling', 'excitement', 'emotion', 'good_emotion']
senticnet['goose_down'] = [0.814, -0.539, 0, 0.624, '#joyful', '#admirable', 0.659, 'feather', 'plume', 'duck_down', 'down_feather', 'swan_down']
senticnet['goose_pimple'] = [-0.562, 0, 0.646, -0.506, '#sad', '#angry', -0.571, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['goose_skin'] = [-0.929, 0, 0.66, -0.639, '#sad', '#angry', -0.743, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['goosebump'] = [-0.893, 0, 0.722, -0.94, '#sad', '#disgusting', -0.852, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['gooseflesh'] = [-0.697, 0, 0.725, -0.92, '#angry', '#disgusting', -0.781, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['gopher'] = [0.991, -0.733, 0, 0.668, '#joyful', '#surprising', 0.797, 'goffer', 'busy_bee', 'actor', 'doer', 'worker']
senticnet['gore'] = [-0.71, 0, -0.965, -0.712, '#scared', '#disgusting', -0.796, 'wind', 'heal_wind', 'welt', 'ache', 'cut']
senticnet['gorgeous'] = [0.749, 0.788, 0, 0.967, '#interesting', '#admirable', 0.835, 'nice_look', 'good_look', 'lovely', 'appearance', 'pretty']
senticnet['gospel'] = [0.028, 0.273, 0, 0.26, '#interesting', '#admirable', 0.187, 'religion', 'prayer', 'world_religion', 'philosophy', 'pastor']
senticnet['gossamer'] = [0, 0, -0.771, -0.721, '#scared', '#disgusting', -0.497, 'gauzy', 'diaphanous', 'filmy', 'cobweb', 'ethereal']
senticnet['gossip'] = [0, 0, 0.833, -0.841, '#angry', '#disgusting', -0.558, 'exchange_idea', 'exchange_information', 'share_information', 'give_information', 'express_opinion']
senticnet['gossip_girl'] = [-0.682, 0, 0.726, -0.741, '#angry', '#disgusting', -0.716, 'gossip', 'gossiper', 'gossipmonger', 'talebearer', 'rumormonger']
senticnet['gossiper'] = [-0.804, 0, 0.56, -0.608, '#sad', '#disgusting', -0.657, 'gossip', 'blabbermouth', 'gossipmonger', 'talk_too_much', 'rumormonger']
senticnet['gossipmonger'] = [-0.804, 0, 0.56, -0.608, '#sad', '#disgusting', -0.657, 'gossip', 'gossiper', 'blabbermouth', 'talk_too_much', 'rumormonger']
senticnet['gothic_architecture'] = [0.578, -0.957, 0, 0.979, '#surprising', '#admirable', 0.838, 'perpendicular', 'perpendicular_style', 'architectural_style', 'style_of_architecture', 'type_of_architecture']
senticnet['gouge'] = [0, 0, -0.842, -0.864, '#scared', '#disgusting', -0.569, 'ding', 'force_out', 'extort', 'nick', 'dent']
senticnet['gouger'] = [0.599, -0.933, 0, 0.583, '#joyful', '#surprising', 0.705, 'combatant', 'battler', 'belligerent', 'fighter', 'scrapper']
senticnet['goulash'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'main_course', 'cream_soup', 'soup', 'ragout', 'stew']
senticnet['gourmet'] = [0.897, -0.961, 0, 0.785, '#joyful', '#surprising', 0.881, 'erotic', 'voluptuary', 'epicure', 'sensualist', 'gastronome']
senticnet['govern'] = [0, 0.235, -0.078, 0.241, '#interesting', '#admirable', 0.133, 'axiom', 'command', 'confirmation', 'tenet', 'government_person']
senticnet['govern_city'] = [0, 0, 0, 0.104, '#admirable', '#admirable', 0.035, 'downtown', 'city', 'large_town', 'govern', 'small_city']
senticnet['govern_country'] = [-0.06, 0.205, -0.107, 0.144, '#interesting', '#admirable', 0.061, 'govern_peasant', 'govern_city', 'govern_nation', 'lose_election', 'gain_money']
senticnet['govern_nation'] = [0, 0.726, 0, 0.872, '#interesting', '#admirable', 0.533, 'date_man', 'date_woman', 'voice_concern', 'carry_briefcase', 'captain_ship']
senticnet['govern_peasant'] = [-0.031, 0.248, -0.055, 0.167, '#interesting', '#admirable', 0.11, 'govern_country', 'govern_person', 'peasant', 'preist', 'loathing']
senticnet['govern_person'] = [-0.051, 0.078, 0, 0.067, '#interesting', '#admirable', 0.031, 'learn_love_another', 'arm_oneself', 'large_state', 'group_object', 'large_area']
senticnet['governable'] = [0.5, -0.9, 0, 0.525, '#surprising', '#admirable', 0.642, 'administrable', 'controllable', 'manageable', 'steerable', 'dirigible']
senticnet['governance'] = [0.952, -0.844, 0, 0.875, '#joyful', '#admirable', 0.89, 'administration', 'judiciary', 'governing_body', 'establishment', 'brass']
senticnet['governing'] = [-0.825, 0, 0.575, -0.923, '#sad', '#disgusting', -0.774, 'misgovernment', 'administration', 'government', 'governance', 'government_activity']
senticnet['governing_body'] = [0.952, -0.844, 0, 0.875, '#joyful', '#admirable', 0.89, 'administration', 'governance', 'judiciary', 'establishment', 'brass']
senticnet['government'] = [0.032, 0.245, -0.057, 0.154, '#interesting', '#admirable', 0.125, 'legislature', 'president', 'government_person', 'representative', 'form_government']
senticnet['government_activity'] = [-0.825, 0, 0.575, -0.923, '#sad', '#disgusting', -0.774, 'governing', 'administration', 'government', 'governance', 'misgovernment']
senticnet['government_agency'] = [0.685, -0.849, 0, 0.903, '#surprising', '#admirable', 0.812, 'agency', 'federal_agency', 'bureau_of_diplomatic_security', 'bureau', 'office']
senticnet['government_agreement'] = [0.04, 0.202, 0, 0.051, '#interesting', '#admirable', 0.098, 'bank', 'safe', 'bank_vault', 'wallet', 'treasurer']
senticnet['government_branch'] = [-0.046, 0.145, -0.079, 0.088, '#interesting', '#admirable', 0.036, 'atmosphere', 'water', 'cool_water', 'obtain_water', 'government']
senticnet['government_building'] = [0, 0.119, 0, 0.095, '#interesting', '#admirable', 0.071, 'building', 'government', 'govern_city', 'accommodation', 'large_building']
senticnet['government_job'] = [0.032, 0.126, 0, 0.133, '#interesting', '#admirable', 0.097, 'congress', 'government', 'nominate', 'contact_police', 'legislature']
senticnet['government_office'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'train_station', 'baggage_compartment', 'cable_car', 'sport_stadium', 'terminal']
senticnet['government_official'] = [0.037, 0.221, 0, 0.198, '#interesting', '#admirable', 0.152, 'political_figure', 'religious_official', 'religious_leader', 'church_head', 'protestant']
senticnet['government_person'] = [0, 0.299, -0.115, 0.278, '#interesting', '#admirable', 0.154, 'form_government', 'nominate', 'presidential', 'government', 'tenet']
senticnet['government_system'] = [0.031, 0.106, -0.055, 0.089, '#interesting', '#admirable', 0.057, 'political_system', 'free_country', 'political_party', 'political_entity', 'united_country']
senticnet['governor'] = [0.034, 0.156, -0.059, 0.099, '#interesting', '#admirable', 0.077, 'state_head', 'politician', 'legislature', 'political_leader', 'country_leader']
senticnet['gown'] = [-0.531, 0, 0.569, -0.776, '#angry', '#disgusting', -0.625, 'pinafore', 'pinny', 'dirndl', 'dress', 'muumuu']
senticnet['gowned'] = [-0.533, 0, 0.937, -0.802, '#angry', '#disgusting', -0.757, 'clad', 'petticoated', 'surpliced', 'arrayed', 'caparisoned']
senticnet['gps'] = [0, 0.071, 0, 0.143, '#interesting', '#admirable', 0.071, 'post_notice', 'indicator', 'way', 'one_way', 'arrow']
senticnet['grab'] = [0, 0.115, -0.112, 0.215, '#interesting', '#admirable', 0.073, 'grasp', 'extend_arm', 'hold', 'reach_out', 'reach']
senticnet['grab_ball'] = [-0.041, 0, 0.015, -0.045, '#sad', '#disgusting', -0.034, 'run_fast', 'chase_ball', 'throw_ball', 'run_quickly', 'put_tennis_shoes']
senticnet['grabby'] = [0.098, 0.084, 0.819, -0.682, '#angry', '#disgusting', -0.44, 'grasp', 'covet', 'covetousness', 'avaricious', 'prehensile']
senticnet['grace'] = [0.865, 0.748, 0, 0.795, '#joyful', '#admirable', 0.803, 'dancer', 'old_dance', 'dance', 'enter_contest', 'believe']
senticnet['graceful'] = [0.734, -0.531, 0, 0.914, '#joyful', '#admirable', 0.726, 'gainly', 'gracile', 'willowy', 'elegant', 'smooth']
senticnet['gracefulness'] = [0.992, -0.826, 0, 0.901, '#joyful', '#admirable', 0.906, 'gracility', 'grace', 'lissomeness', 'litheness', 'suppleness']
senticnet['gracile'] = [0.734, -0.531, 0, 0.914, '#joyful', '#admirable', 0.726, 'gainly', 'graceful', 'willowy', 'elegant', 'smooth']
senticnet['gracility'] = [0.992, -0.826, 0, 0.901, '#joyful', '#admirable', 0.906, 'gracefulness', 'grace', 'lissomeness', 'litheness', 'suppleness']
senticnet['gracious'] = [0.736, -0.663, 0, 0.777, '#joyful', '#admirable', 0.725, 'lucky', 'propitious', 'prosperous', 'favorable', 'favourable']
senticnet['graciousness'] = [0.753, -0.898, 0, 0.652, '#joyful', '#surprising', 0.768, 'good_manners', 'suavity', 'suaveness', 'courtesy', 'smoothness']
senticnet['grade'] = [0.887, -0.95, 0, 0.913, '#surprising', '#admirable', 0.917, 'high_quality', 'superiority', 'level', 'caliber', 'degree']
senticnet['grade_paper'] = [-0.095, 0, -0.094, 0, '#sad', '#scared', -0.063, 'type_of_paper', 'receive_mail', 'breaking_news', 'crossword', 'make_card']
senticnet['graduate'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'become_doctor', 'doctor', 'important_person', 'become_judge', 'study']
senticnet['graduate_college'] = [-0.062, -0.017, 0.016, -0.058, '#sad', '#disgusting', -0.04, 'read_lot', 'study_hard', 'study_course_material', 'stay_school', 'bribe_teacher']
senticnet['graduate_school'] = [0, 0.963, 0, 0.953, '#interesting', '#admirable', 0.639, 'pass_grade', 'pass_test', 'knowledge_power', 'get_diploma', 'pass_exam']
senticnet['graduate_student'] = [0, 0.963, 0, 0.953, '#interesting', '#admirable', 0.639, 'student', 'serious_student', 'college_student', 'get_degree', 'finish_college']
senticnet['graduated_table'] = [-0.662, 0, 0.918, -0.96, '#angry', '#disgusting', -0.847, 'measure', 'standard', 'wage_scale', 'wage_schedule', 'wind_scale']
senticnet['graduation'] = [0, 0.984, 0, 0.997, '#interesting', '#admirable', 0.66, 'graduate', 'get_diploma', 'earn_degree', 'receive_grade', 'diploma']
senticnet['graduation_ceremony'] = [0, 0.802, 0, 0.942, '#interesting', '#admirable', 0.581, 'ceremony', 'graduation', 'math_camp', 'open_gift', 'football_game']
senticnet['graffiti'] = [-0.127, 0, -0.063, -0.046, '#sad', '#scared', -0.079, 'bum', 'homeless_people', 'homeless_person', 'panhandler', 'homeless']
senticnet['graft'] = [0, 0, -0.745, -0.957, '#scared', '#disgusting', -0.567, 'abduction', 'punishment', 'emergency', 'illiteracy', 'heal']
senticnet['graham_cracker'] = [-0.955, 0, 0.762, -0.648, '#sad', '#angry', -0.788, 'saltine', 'soda_cracker', 'oyster_cracker', 'water_biscuit', 'cracker']
senticnet['grain'] = [0, 0.065, 0.031, 0.052, '#interesting', '#admirable', 0.029, 'wheat', 'white_rice', 'rye', 'corn', 'oat']
senticnet['grain_alcohol'] = [-0.538, 0, 0.598, -0.734, '#angry', '#disgusting', -0.623, 'absolute_alcohol', 'spirits_of_wine', 'denatured_alcohol', 'alcohol', 'plant_product']
senticnet['grain_sand'] = [-0.027, -0.003, 0.045, -0.034, '#angry', '#disgusting', -0.034, 'sand', 'salt', 'quartz', 'sandy', 'silica']
senticnet['graininess'] = [-0.9, 0, 0.841, -0.731, '#sad', '#angry', -0.824, 'nubbiness', 'tweediness', 'harshness', 'raggedness', 'granularity']
senticnet['grainy'] = [-0.051, 0.07, 0, 0.062, '#interesting', '#admirable', 0.027, 'salty', 'fine_grain', 'powder', 'granulate', 'food_flavor']
senticnet['grammar'] = [0, 0.118, -0.089, 0.146, '#interesting', '#admirable', 0.058, 'typeface', 'jot', 'dissertation', 'unit_language', 'grammatical_term']
senticnet['grammar_mistake'] = [-0.728, 0, 0, -0.819, '#sad', '#disgusting', -0.516, 'mistake', 'error', 'misspell', 'poor_english', 'bad_writing']
senticnet['grammar_part'] = [0, 0.078, -0.048, 0.205, '#interesting', '#admirable', 0.078, 'part_of_speech', 'speech_part', 'written_language', 'information_source', 'grammatical_term']
senticnet['grammatical_case'] = [0.843, -0.602, 0, 0.97, '#joyful', '#admirable', 0.805, 'oblique', 'oblique_case', 'nominative', 'nominative_case', 'subject_case']
senticnet['grammatical_term'] = [0, 0, -0.074, 0, '#scared', '#scared', -0.025, 'typeface', 'print_word', 'dissertation', 'hold_information', 'continue_story']
senticnet['grand'] = [0, 0.899, 0, 0.846, '#interesting', '#admirable', 0.582, 'fantastic', 'amaze', 'pose', 'wondrous', 'wonderfully']
senticnet['grand_canyon'] = [0.106, -0.018, 0, 0, '#joyful', '#surprising', 0.041, 'western', 'sumo', 'rodeo', 'circus_act', 'have_fun']
senticnet['grand_piano'] = [-0.988, 0, 0.614, -0.905, '#sad', '#disgusting', -0.836, 'grand', 'upright', 'piano', 'mechanical_piano', 'player_piano']
senticnet['grandchild'] = [0, 0.208, -0.142, 0.162, '#interesting', '#admirable', 0.076, 'much_child', 'nowhere_live', 'offspring', 'descendant', 'human_offspring']
senticnet['granddaughter'] = [0.938, 0.813, 0, 0, '#joyful', '#interesting', 0.584, 'relation', 'mom', 'kin', 'cousin', 'grandson']
senticnet['grande_dame'] = [0.964, -0.811, 0, 0.926, '#joyful', '#admirable', 0.9, 'girl', 'gentlewoman', 'madam', 'dame', 'lady']
senticnet['grandfather'] = [0, 0.08, 0.016, 0.103, '#interesting', '#admirable', 0.056, 'father', 'mother', 'daughter', 'son', 'part_of_family']
senticnet['grandiose'] = [0, 0, -0.89, -0.833, '#scared', '#disgusting', -0.574, 'hifalutin', 'la-di-da', 'highfaluting', 'highfalutin', 'hoity-toity']
senticnet['grandma_house'] = [0, 0, -0.05, -0.034, '#scared', '#disgusting', -0.028, 'chess_tournament', 'game_room', 'old_folk_home', 'computer_lab', 'mortuary']
senticnet['grandmother'] = [0.955, 0.971, 0, 0, '#joyful', '#interesting', 0.642, 'aunt_uncle', 'picture_of_family', 'aunt', 'family_photo', 'relative']
senticnet['grandparent'] = [0, 0.899, 0, 0.846, '#interesting', '#admirable', 0.582, 'family', 'cousin', 'father', 'sister', 'parent']
senticnet['grandson'] = [0.762, 0.953, 0, 0, '#joyful', '#interesting', 0.572, 'relation', 'mom', 'kin', 'cousin', 'granddaughter']
senticnet['granola'] = [-0.923, 0, 0.609, -0.745, '#sad', '#disgusting', -0.759, 'puffed_rice', 'cold_cereal', 'raisin_bran', 'corn_flake', 'bran_flake']
senticnet['grant'] = [0.865, -0.844, 0, 0.915, '#joyful', '#admirable', 0.875, 'contract', 'sale_in_gross', 'contract_of_hazard', 'adhesion_contract', 'contract_of_adhesion']
senticnet['granular'] = [0, 0.065, 0.064, 0.079, '#interesting', '#admirable', 0.027, 'small_grain', 'white_grain', 'granule', 'food_type', 'staple_food']
senticnet['granularity'] = [-0.9, 0, 0.841, -0.731, '#sad', '#angry', -0.824, 'nubbiness', 'tweediness', 'harshness', 'graininess', 'raggedness']
senticnet['granulate'] = [-0.051, 0.07, 0, 0.062, '#interesting', '#admirable', 0.027, 'salty', 'grainy', 'powder', 'fine_grain', 'food_flavor']
senticnet['granule'] = [0, 0.065, 0.064, 0.079, '#interesting', '#admirable', 0.027, 'small_grain', 'white_grain', 'granular', 'food_type', 'staple_food']
senticnet['granulocyte'] = [-0.553, 0, 0.922, -0.887, '#angry', '#disgusting', -0.787, 'leukocyte', 'leucocyte', 'white_blood_cell', 'white_cell', 'white_blood_corpuscle']
senticnet['granuloma_inguinale'] = [-0.517, 0, 0.561, -0.976, '#angry', '#disgusting', -0.685, 'venereal_disease', 'venereal_infection', 'social_disease', 'sexually_transmitted_disease', 'dose']
senticnet['granuloma_venereum'] = [-0.744, 0, 0.86, -0.644, '#sad', '#angry', -0.749, 'venereal_disease', 'venereal_infection', 'social_disease', 'sexually_transmitted_disease', 'dose']
senticnet['grape_juice'] = [0.068, 0, 0, 0, '#joyful', '#joyful', 0.023, 'soft_drink', 'apple_juice', 'cola', 'juice', 'ice_tea']
senticnet['grape_sugar'] = [0.677, -0.545, 0, 0.587, '#joyful', '#admirable', 0.603, 'glucosamine', 'corn_sugar', 'dextrose', 'dextroglucose', 'glucose']
senticnet['grapefruit'] = [0, -0.045, 0.098, -0.113, '#angry', '#disgusting', -0.055, 'oriental_medicine', 'plum', 'lemon_juice', 'green_apple', 'apricot']
senticnet['grapefruit_peel'] = [-0.952, 0, 0.845, -0.679, '#sad', '#angry', -0.825, 'candied_citrus_peel', 'lemon_peel', 'orange_peel', 'candied_fruit', 'succade']
senticnet['graph'] = [0.027, 0.093, 0.025, 0.071, '#interesting', '#admirable', 0.055, 'octagon', 'angle', 'indication', 'geometry', 'facet']
senticnet['grapheme'] = [-0.61, 0, 0.721, -0.683, '#angry', '#disgusting', -0.671, 'character', 'logogram', 'logograph', 'graph', 'ideogram']
senticnet['graphic'] = [0.501, -0.996, 0, 0.68, '#surprising', '#admirable', 0.726, 'stated', 'hardcore', 'declared', 'definitive', 'explicit']
senticnet['graphical_representation'] = [0.031, 0.08, 0.023, 0.069, '#interesting', '#admirable', 0.052, 'pencil', 'marker', 'photo', 'icon', 'quill_brush']
senticnet['graphite_pencil'] = [0.022, -0.065, 0.072, -0.083, '#angry', '#disgusting', -0.023, 'marker', 'pencil', 'pen', 'mechanical_pencil', 'stamp_pad']
senticnet['graphology'] = [-0.846, 0, 0.585, -0.852, '#sad', '#disgusting', -0.761, 'subject', 'discipline', 'study', 'subject_area', 'subject_field']
senticnet['grasp'] = [0, 0.137, -0.099, 0.226, '#interesting', '#admirable', 0.088, 'grab', 'hold', 'grip', 'extend_arm', 'reach']
senticnet['grasp_hand'] = [0, 0.126, 0, 0.062, '#interesting', '#admirable', 0.063, 'distribute', 'grab', 'walk_away', 'hand_over', 'extend_arm']
senticnet['grasper'] = [0, 0.088, -0.082, 0.153, '#interesting', '#admirable', 0.053, 'grasp', 'hold', 'grab', 'reach', 'grip']
senticnet['grass'] = [0.034, 0.111, -0.094, 0.148, '#interesting', '#admirable', 0.066, 'up_mountain', 'hike_trail', 'tress', 'fallen_leaf', 'ant_hill']
senticnet['grass_area'] = [0, 0.081, 0.03, 0.071, '#interesting', '#admirable', 0.041, 'grow_place', 'vegetable_grow', 'plant_place', 'grassy_area', 'outside_area']
senticnet['grass_clipping'] = [-0.752, 0, 0, -0.85, '#sad', '#disgusting', -0.534, 'grass_area', 'homeless_people', 'litter', 'streetlight', 'traffic_light']
senticnet['grass_snake'] = [-0.514, 0, 0.625, -0.984, '#angry', '#disgusting', -0.708, 'common_water_snake', 'banded_water_snake', 'water_moccasin', 'water_snake', 'ring_snake']
senticnet['grass_tree'] = [0.098, 0, 0, 0.055, '#joyful', '#admirable', 0.051, 'green', 'grass', 'vegetation', 'green_yard', 'green_grass']
senticnet['grasshopper'] = [0, 0.82, 0, 0.861, '#interesting', '#admirable', 0.56, 'many_insects', 'cutworm', 'beetle', 'gypsy_moth', 'mole_cricket']
senticnet['grassland'] = [-0.739, 0, 0.59, -0.893, '#sad', '#disgusting', -0.741, 'desert', 'biome', 'forest', 'woodland', 'timberland']
senticnet['grassy'] = [0, 0.073, 0.051, 0.116, '#interesting', '#admirable', 0.046, 'open_land', 'grassy_area', 'acreage', 'terrain', 'sometimes_green']
senticnet['grassy_area'] = [0, 0.102, 0.031, 0.1, '#interesting', '#admirable', 0.057, 'grass_area', 'crop_place', 'grow_place', 'vegetable_grow', 'outside_area']
senticnet['grassy_field'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'windsor', 'lair', 'habitat', 'bee_hive', 'pet_store']
senticnet['grate'] = [0, 0, 0.986, -0.926, '#angry', '#disgusting', -0.637, 'grating', 'fret', 'rankle', 'eat_into', 'grind']
senticnet['grateful'] = [0.89, 0.975, 0, 0.905, '#interesting', '#admirable', 0.923, 'enthusiasm', 'thankful', 'worshipful', 'adoring', 'fondness']
senticnet['gratefully'] = [0.468, 0.661, -0.252, 0.231, '#joyful', '#interesting', 0.369, 'appreciatively', 'gratefulness', 'appreciativeness', 'thankfulness', 'unfearing']
senticnet['gratefulness'] = [0.488, 0.661, -0.256, 0.244, '#joyful', '#interesting', 0.379, 'appreciativeness', 'thankfulness', 'unafraid', 'intrepidly', 'audacious']
senticnet['gratification'] = [0.978, 0.81, 0, 0.848, '#joyful', '#admirable', 0.879, 'brownie_point', 'feel_proud', 'receive_thank', 'appreciate', 'positive_reinforcement']
senticnet['gratify'] = [0.779, 0.924, 0, 0.848, '#interesting', '#admirable', 0.85, 'joy', 'glee', 'fulfill', 'live_up_to', 'fulfillment']
senticnet['gratifyingly'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'satiable', 'satisfactorily', 'comforting', 'satisfyingly', 'cheering']
senticnet['grating'] = [-0.937, 0, 0.576, -0.545, '#sad', '#angry', -0.686, 'cacophonic', 'rasping', 'raspy', 'jarring', 'gruff']
senticnet['gratis'] = [0, -0.854, 0, 0.991, '#surprising', '#admirable', 0.615, 'free', 'costless', 'gratuitous', 'for_free', 'complimentary']
senticnet['gratitude'] = [0.798, 0.754, 0, 0.779, '#joyful', '#admirable', 0.777, 'affection', 'joy', 'glad', 'admire', 'sympathetic']
senticnet['gratuitous'] = [0, 0, 0.791, -0.755, '#angry', '#disgusting', -0.515, 'costless', 'complimentary', 'needless', 'gratis', 'free']
senticnet['gratuity'] = [0, 0.193, -0.092, 0.181, '#interesting', '#admirable', 0.094, 'dollar', 'cash_bill', 'franc', 'money_earn', 'money_involve']
senticnet['grave'] = [-0.736, 0, -0.8, 0, '#sad', '#scared', -0.512, 'coffin', 'casket', 'morgue', 'headstone', 'burial']
senticnet['gravel'] = [-0.726, 0, 0.899, 0, '#sad', '#angry', -0.542, 'vex', 'stun', 'dazed', 'stunned', 'stupefied']
senticnet['graveness'] = [0.912, -0.646, 0, 0.889, '#joyful', '#admirable', 0.816, 'earnestness', 'sincerity', 'seriousness', 'stuffiness', 'stodginess']
senticnet['graveyard'] = [-0.84, 0, -0.899, 0, '#sad', '#scared', -0.58, 'cemetery', 'funeral', 'funeral_home', 'tombstone', 'die']
senticnet['gravid'] = [0.159, 0.068, -0.079, 0.118, '#joyful', '#admirable', 0.089, 'stomach', 'uterus', 'pregnant', 'lap', 'womb']
senticnet['gravitas'] = [0.841, -0.568, 0, 0.654, '#joyful', '#admirable', 0.688, 'dignity', 'comportment', 'lordliness', 'personal_manner', 'manner']
senticnet['gravitate'] = [0.708, -0.807, 0, 0.747, '#surprising', '#admirable', 0.754, 'move_around', 'tend', 'incline', 'lean', 'run']
senticnet['gravity'] = [0, 0.915, 0, 0.737, '#interesting', '#admirable', 0.551, 'wake', 'go_high', 'downward', 'elevation', 'physic_term']
senticnet['gray'] = [-0.513, 0, 0.651, -0.612, '#angry', '#disgusting', -0.592, 'silver_gray', 'gray_hair', 'old', 'tattletale_gray', 'achromatic_color']
senticnet['gray_hair'] = [0, 0, 0.841, -0.704, '#angry', '#disgusting', -0.515, 'ancient', 'many_years', 'years', 'old', 'teen']
senticnet['grayness'] = [-0.974, 0, 0.932, -0.78, '#sad', '#angry', -0.895, 'gray', 'silver_gray', 'old', 'tattletale_gray', 'achromatic_color']
senticnet['graze'] = [0.032, 0.075, 0, 0, '#joyful', '#interesting', 0.036, 'aperitif', 'fondue', 'crop', 'maple', 'kernel']
senticnet['graze_cattle'] = [0, 0.903, 0, 0.701, '#interesting', '#admirable', 0.535, 'harvest', 'crop', 'grow_crop', 'plant_crop', 'reap']
senticnet['graze_field'] = [0.034, 0, 0, 0.064, '#joyful', '#admirable', 0.033, 'barn', 'barn_field', 'field', 'stable', 'farmyard']
senticnet['grazing_land'] = [-0.907, 0, 0.765, -0.98, '#sad', '#disgusting', -0.884, 'pastureland', 'common_land', 'ley', 'pasture', 'lea']
senticnet['grease_trap'] = [0, 0, 0.066, -0.077, '#angry', '#disgusting', -0.048, 'container_cup', 'cup', 'open_container', 'dish', 'salad_bowl']
senticnet['greaseproof'] = [-0.9, 0, 0.657, -0.644, '#sad', '#angry', -0.734, 'soundproof', 'mothproof', 'resistant', 'proof', 'imperviable']
senticnet['greasy'] = [0, 0, -0.072, 0, '#scared', '#scared', -0.024, 'crude', 'liquid_fuel', 'natural_resource', 'dark_liquid', 'fossil_fuel']
senticnet['greasy_food'] = [-0.925, 0, 0.254, -0.961, '#sad', '#disgusting', -0.713, 'fat', 'become_fat', 'fat_person', 'unhealthy_food', 'greasy']
senticnet['great'] = [0.905, 0.773, 0, 0.892, '#joyful', '#admirable', 0.857, 'best', 'excellent', 'well_done', 'goodness', 'good_quality']
senticnet['great_anger'] = [0, 0, 0.766, 0, '#angry', '#angry', -0.255, 'choose_victim', 'target_practice', 'shoot_target', 'alibi', 'self_defense']
senticnet['great_burdock'] = [0.683, -0.547, 0, 0.568, '#joyful', '#admirable', 0.599, 'subshrub', 'suffrutex', 'common_burdock', 'lesser_burdock', 'burdock']
senticnet['great_carrier'] = [0.97, 0.729, 0, 0.946, '#joyful', '#admirable', 0.882, 'become_famous', 'become_rich', 'money', 'good_job', 'make_a_lot_of_money']
senticnet['great_dane'] = [0, 0, 0.737, -0.864, '#angry', '#disgusting', -0.534, 'annoy', 'skin_rash', 'bother', 'irritation', 'nag']
senticnet['great_exercise'] = [0.905, 0.773, 0, 0.892, '#joyful', '#admirable', 0.857, 'good_exercise', 'great', 'exercise', 'healthy_lifestyle', 'physical_exercise']
senticnet['great_invention'] = [-0.043, 0.077, 0.073, 0.118, '#interesting', '#admirable', 0.026, 'round_figure', 'orb', 'torus', 'circle_shape', 'ball_shape']
senticnet['great_joy'] = [0.326, 0.149, -0.078, 0, '#joyful', '#interesting', 0.132, 'sense_pride', 'happiness', 'delight_sense', 'have_fun', 'feel_pleasure']
senticnet['great_love'] = [0, 0.962, 0, 0.822, '#interesting', '#admirable', 0.595, 'passion', 'lust', 'love', 'love_god', 'beloved']
senticnet['great_performance'] = [0.715, 0.717, 0, 0.813, '#interesting', '#admirable', 0.748, 'performance', 'show', 'skilled', 'play', 'interesting_show']
senticnet['great_relief'] = [-0.226, 0, -0.187, -0.095, '#sad', '#scared', -0.169, 'feel_depressed', 'clean_up_mess', 'sadness', 'rainy_day', 'erection']
senticnet['great_time'] = [0.758, 0.719, 0, 0.778, '#joyful', '#admirable', 0.752, 'set_mood', 'good_time', 'deafness', 'like', 'enjoy_music']
senticnet['great_understand'] = [0.757, 0, 0, 0, '#joyful', '#joyful', 0.252, 'add_knowledge', 'learn_much', 'learn', 'know_fact', 'understand']
senticnet['great_view'] = [0.16, 0.067, 0, 0.083, '#joyful', '#admirable', 0.103, 'good_view', 'summit', 'gable', 'snowflake', 'antenna']
senticnet['great_yellowcress'] = [0.758, -0.975, 0, 0.851, '#surprising', '#admirable', 0.861, 'marsh_cress', 'yellow_watercress', 'mountain_watercress', 'common_watercress', 'watercress']
senticnet['greater_stitchwort'] = [-0.642, 0, 0.555, -0.627, '#sad', '#disgusting', -0.608, 'herb', 'common_chickweed', 'stitchwort', 'chickweed', 'starwort']
senticnet['greatness'] = [0.131, 0.074, 0, 0.373, '#joyful', '#admirable', 0.193, 'superlative', 'excellence', 'ultimate', 'great', 'well_done']
senticnet['greed'] = [-0.5, 0, 0.939, -0.835, '#angry', '#disgusting', -0.758, 'avarice', 'covetousness', 'possessiveness', 'desire', 'acquisitiveness']
senticnet['greediness'] = [-0.813, 0, 0.886, -0.656, '#sad', '#angry', -0.785, 'opportunism', 'selfishness', 'rapaciousness', 'voraciousness', 'expedience']
senticnet['greedy'] = [0, 0, 0.857, -0.885, '#angry', '#disgusting', -0.581, 'jealous', 'avaricious', 'prehensile', 'covetousness', 'grasp']
senticnet['greedy_person'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'blind_person', 'rubber_duck', 'kink', 'vegetarian', 'foreigner']
senticnet['greek'] = [0.043, 0, 0, 0.094, '#joyful', '#admirable', 0.046, 'proton_neutron', 'proton', 'atom', 'basic_unit', 'neutron']
senticnet['greek_god'] = [0, 0, 0, 0.122, '#admirable', '#admirable', 0.041, 'animal_sound', 'sound', 'loudness', 'audio', 'ear_activity']
senticnet['green'] = [-0.024, 0.078, 0.042, 0.066, '#interesting', '#admirable', 0.026, 'sexual', 'purple_color', 'fragrant', 'colorful', 'purple']
senticnet['green-eyed'] = [0.093, 0.086, 0.814, -0.682, '#angry', '#disgusting', -0.439, 'green-eyed_monster', 'overjealous', 'covetous', 'grasp', 'covet']
senticnet['green-eyed_monster'] = [0.093, 0.086, 0.814, -0.682, '#angry', '#disgusting', -0.439, 'green-eyed', 'overjealous', 'covetous', 'grasp', 'covet']
senticnet['green_apple'] = [0, -0.015, 0.037, -0.046, '#angry', '#disgusting', -0.023, 'pear', 'lime', 'apricot', 'cherry', 'pumpkin']
senticnet['green_bean'] = [0.861, -0.549, 0, 0.976, '#joyful', '#admirable', 0.795, 'kidney_bean', 'frijol', 'frijole', 'common_bean', 'wax_bean']
senticnet['green_black'] = [0, 0.855, 0, 0.854, '#interesting', '#admirable', 0.57, 'purple', 'red', 'bright_red', 'red_green', 'peelable']
senticnet['green_bread'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'mouldy_bread', 'rotten', 'disgusting', 'taste_awful', 'mouldy']
senticnet['green_color'] = [0.034, 0.065, 0, 0.07, '#interesting', '#admirable', 0.056, 'leafy', 'renewable_resource', 'part_of_plant', 'leafy_green', 'root']
senticnet['green_fruit'] = [0.053, 0.071, 0.058, 0.102, '#interesting', '#admirable', 0.056, 'round_fruit', 'red_fruit', 'small_fruit', 'crunchy', 'delicious_fruit']
senticnet['green_garden'] = [0, 0.071, 0.017, 0.084, '#interesting', '#admirable', 0.046, 'usual_green', 'vegetation', 'green', 'green_growth', 'plant_big']
senticnet['green_gold'] = [-0.624, 0, 0.504, -0.798, '#sad', '#disgusting', -0.642, 'atomic_number_79', 'pure_gold', 'gold_dust', 'guinea_gold', 'noble_metal']
senticnet['green_grass'] = [0.098, 0, 0, 0.055, '#joyful', '#admirable', 0.051, 'green', 'grass', 'vegetation', 'green_yard', 'grass_tree']
senticnet['green_growth'] = [0, 0.071, 0.017, 0.084, '#interesting', '#admirable', 0.046, 'usual_green', 'vegetation', 'green', 'green_garden', 'plant_big']
senticnet['green_leave'] = [-0.055, 0, 0, -0.071, '#sad', '#disgusting', -0.042, 'vine', 'green_color', 'ivy', 'evergreen_tree', 'large_plant']
senticnet['green_orange'] = [-0.06, 0.089, 0, 0.088, '#interesting', '#admirable', 0.039, 'yellow_green', 'red_orange', 'spectrum', 'red_green', 'black_green']
senticnet['green_plant'] = [0.427, 0.227, 0, 0.37, '#joyful', '#admirable', 0.341, 'forest', 'plant', 'jungle', 'grass', 'tree']
senticnet['green_red'] = [0, 0.108, 0, 0.113, '#interesting', '#admirable', 0.074, 'taken', 'visual', 'category', 'yellow_green', 'green_orange']
senticnet['green_stuff'] = [0, 0.828, 0, 0.726, '#interesting', '#admirable', 0.518, 'mow', 'grass', 'greenery', 'tree_flower', 'many_plants']
senticnet['green_tea'] = [0.092, 0, 0, 0, '#joyful', '#joyful', 0.031, 'coffee', 'tea', 'ice_tea', 'juice', 'part_of_dinner']
senticnet['green_thumb'] = [0.427, 0.227, 0, 0.37, '#joyful', '#admirable', 0.341, 'taken_seriously', 'complement', 'much_need', 'remission', 'knowledgeable']
senticnet['green_vegetable'] = [0.175, 0.101, 0.035, 0.195, '#joyful', '#admirable', 0.145, 'leafy_green', 'rabbit_food', 'fruit_plant', 'vegetarian_food', 'lawn_green']
senticnet['green_yard'] = [0.098, 0, 0, 0.055, '#joyful', '#admirable', 0.051, 'green', 'grass', 'vegetation', 'green_grass', 'grass_tree']
senticnet['green_yellow'] = [-0.062, 0.081, 0, 0.082, '#interesting', '#admirable', 0.034, 'yellow_green', 'red_orange', 'red_green', 'green_orange', 'red_blue']
senticnet['greenery'] = [0, 0.07, 0, 0.071, '#interesting', '#admirable', 0.047, 'tree_flower', 'bloom', 'perennial', 'poppy', 'blossom']
senticnet['greenhorn'] = [-0.642, 0, 0.667, -0.821, '#angry', '#disgusting', -0.71, 'novice', 'beginner', 'tyro', 'tiro', 'initiate']
senticnet['greenhouse'] = [-0.123, 0.066, -0.086, -0.069, '#sad', '#scared', -0.071, 'garden_yard', 'see_sky', 'plant_tree', 'hair', 'seed_lawn']
senticnet['greenhouse_gas'] = [-0.799, 0, 0, -0.7, '#sad', '#disgusting', -0.5, 'pollution', 'smog', 'unhealthy', 'bad_habit', 'lung_cancer']
senticnet['greenness'] = [-0.938, 0, 0.906, -0.539, '#sad', '#angry', -0.794, 'juvenility', 'state', 'immatureness', 'callowness', 'jejuneness']
senticnet['greet'] = [0.896, 0, 0, 0.755, '#joyful', '#admirable', 0.55, 'mutual_understand', 'greetings', 'tell_name', 'hello', 'suggest']
senticnet['greet_card'] = [0.93, 0, 0, 0, '#joyful', '#joyful', 0.31, 'like_poetry', 'rhyme', 'song_lyric', 'refrain', 'musical_notation']
senticnet['greet_each_other'] = [0.974, 0, 0, 0.932, '#joyful', '#admirable', 0.635, 'greet', 'salute', 'wave_arm', 'say_goodbye_to', 'attract_attention']
senticnet['greet_guest'] = [-0.95, 0, -0.736, -0.736, '#sad', '#scared', -0.807, 'alcoholism', 'hold_beer', 'become_intoxicated', 'intoxication', 'social_occasion']
senticnet['greet_person'] = [-0.026, 0.093, 0.01, 0.084, '#interesting', '#admirable', 0.047, 'get_word_out', 'diplomacy', 'remember_name', 'talk_another_person', 'find_another_person']
senticnet['greeting'] = [0.898, -0.708, 0, 0.712, '#joyful', '#admirable', 0.773, 'wish', 'reception', 'welcome', 'hail', 'regard']
senticnet['greetings'] = [0.896, 0, 0, 0.755, '#joyful', '#admirable', 0.55, 'mutual_understand', 'greet', 'tell_name', 'hello', 'suggest']
senticnet['gregariousness'] = [-0.648, 0, 0.574, -0.89, '#sad', '#disgusting', -0.704, 'sociability', 'ambiversion', 'openness', 'nakedness', 'extraversion']
senticnet['gremlin'] = [-0.73, 0, 0.72, -0.936, '#sad', '#disgusting', -0.795, 'imp', 'elf', 'hob', 'leprechaun', 'pixie']
senticnet['grenade'] = [0, 0, 0.796, -0.99, '#angry', '#disgusting', -0.595, 'weapon', 'aerial_bomb', 'machine_gun', 'cannon', 'handgun']
senticnet['grid'] = [0, 0.72, 0, 0.915, '#interesting', '#admirable', 0.545, 'calculator', 'efficient', 'computer_internet_connection', 'internet_connection', 'boot_up_computer']
senticnet['grid_object'] = [0, 0.757, 0, 0.96, '#interesting', '#admirable', 0.572, 'hang_up', 'think', 'cogitate', 'brainstorm', 'make_right_decision']
senticnet['grief'] = [-1, 0, 0, 0, '#sad', '#sad', -0.333, 'sorrow', 'remorse', 'guilt', 'heartache', 'regret']
senticnet['grief-stricken'] = [-0.884, 0.175, -0.599, 0, '#sad', '#scared', -0.436, 'bereaved', 'sorrowing', 'bereft', 'grieving', 'mourning']
senticnet['grievance'] = [0.046, 0.118, 0.77, -0.676, '#angry', '#disgusting', -0.427, 'heartburning', 'sulkiness', 'bulk_large', 'loom', 'huffishness']
senticnet['grieve'] = [-0.757, 0, 0, 0, '#sad', '#sad', -0.252, 'guilt_feeling', 'guilt_trip', 'self-reproach', 'compunction', 'heartbreaking']
senticnet['griever'] = [-0.989, 0, 0.664, -0.524, '#sad', '#angry', -0.726, 'unfortunate', 'unfortunate_person', 'weeper', 'pallbearer', 'bearer']
senticnet['grieving'] = [-0.884, 0.175, -0.599, 0, '#sad', '#scared', -0.436, 'bereaved', 'grief-stricken', 'sorrowing', 'bereft', 'mourning']
senticnet['grievous'] = [-0.894, 0.161, -0.613, 0.053, '#sad', '#scared', -0.431, 'heartrending', 'heartbreaking', 'grievously', 'aggrieve', 'brokenheartedness']
senticnet['grievously'] = [-0.894, 0.161, -0.613, 0.053, '#sad', '#scared', -0.431, 'heartrending', 'heartbreaking', 'grievous', 'aggrieve', 'brokenheartedness']
senticnet['grill'] = [0.061, -0.049, 0, 0, '#joyful', '#surprising', 0.037, 'heat_element', 'stick_butter', 'find_recipe', 'bake_oven', 'food_bake']
senticnet['grill_food'] = [0.032, -0.068, 0, 0, '#joyful', '#surprising', 0.033, 'bake_bread', 'bake_cookie', 'roast', 'bake', 'roasted_chicken']
senticnet['grilled_vegetables'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'grill', 'red_meat', 'barbecue', 'cook', 'cook_grill']
senticnet['grillwork'] = [0.5, -0.762, 0, 0.814, '#surprising', '#admirable', 0.692, 'net', 'network', 'mesh', 'meshing', 'meshwork']
senticnet['grim'] = [-0.906, 0, 0.761, -0.726, '#sad', '#angry', -0.798, 'gloominess', 'somberness', 'gloomful', 'darkness', 'gloomily']
senticnet['grimace'] = [-0.059, -0.033, -0.164, -0.149, '#scared', '#disgusting', -0.113, 'feel_anger', 'feel_hurt', 'scare_dog', 'scream', 'embarrassment']
senticnet['grime'] = [-0.93, 0, 0.897, -0.923, '#sad', '#disgusting', -0.917, 'dirty', 'soil', 'bemuddy', 'muddy', 'colly']
senticnet['grimness'] = [0.529, -0.755, 0, 0.578, '#surprising', '#admirable', 0.621, 'asperity', 'sternness', 'rigor', 'hardship', 'rigorousness']
senticnet['grin'] = [0.715, 0, 0, 0.77, '#joyful', '#admirable', 0.495, 'smile', 'hear_joke', 'happy_emotion', 'tell_funny_joke', 'sneer']
senticnet['grind'] = [-0.055, 0, 0, -0.075, '#sad', '#disgusting', -0.043, 'favorite', 'mill', 'crowd', 'several_people', 'considerable']
senticnet['grind_grain'] = [-0.067, 0, 0.023, 0, '#sad', '#angry', -0.03, 'circulate_blood', 'dispense', 'fail_work', 'cremate', 'dry_wet_hair']
senticnet['grinding'] = [-0.85, 0, 0.743, -0.839, '#sad', '#disgusting', -0.811, 'atom', 'molecule', 'particle', 'corpuscle', 'mote']
senticnet['gringo'] = [-0.575, 0, 0.803, -0.772, '#angry', '#disgusting', -0.717, 'au_pair', 'exile', 'deportee', 'foreigner', 'import']
senticnet['grip'] = [0, 0.088, -0.082, 0.153, '#interesting', '#admirable', 0.053, 'grasp', 'hold', 'grab', 'reach', 'grasper']
senticnet['grip_tool'] = [0, 0.103, 0, 0.111, '#interesting', '#admirable', 0.071, 'body_extremity', 'arm_part', 'extremity', 'human_appendage', 'appendage']
senticnet['gripe'] = [-0.524, 0, 0.607, -0.549, '#angry', '#disgusting', -0.56, 'bewail', 'bemoan', 'mutter', 'scold', 'quetch']
senticnet['grippe'] = [0.998, -0.546, 0, 0.957, '#joyful', '#admirable', 0.834, 'contagious_disease', 'contagion', 'swine_influenza', 'swine_flu', 'respiratory_disease']
senticnet['gripping'] = [0.566, -0.912, 0, 0.599, '#surprising', '#admirable', 0.692, 'intriguing', 'absorbing', 'engrossing', 'fascinating', 'interesting']
senticnet['gristle'] = [-0.536, 0, 0.982, -0.671, '#angry', '#disgusting', -0.73, 'meniscus', 'semilunar_cartilage', 'fibrocartilage', 'hyaline_cartilage', 'arytenoid']
senticnet['grit'] = [0.973, 0.74, 0, 0, '#joyful', '#interesting', 0.571, 'courage', 'hardiness', 'resolve', 'determination', 'resolution']
senticnet['gritty'] = [0, -0.899, 0, 0.932, '#surprising', '#admirable', 0.61, 'granular', 'gamy', 'spirited', 'farinaceous', 'coarse-grained']
senticnet['grizzle'] = [-0.848, 0, 0.633, -0.539, '#sad', '#angry', -0.673, 'wig', 'postiche', 'horsehair_wig', 'periwig', 'peruke']
senticnet['grizzled'] = [0, 0, -0.918, -0.726, '#scared', '#disgusting', -0.548, 'brood', 'stew', 'whine', 'yammer', 'yawp']
senticnet['grizzly'] = [0.026, 0.082, -0.047, 0.068, '#interesting', '#admirable', 0.043, 'hare', 'bear', 'big_rat', 'omnivore', 'chipmunk']
senticnet['grizzly_bear'] = [0, 0, -0.71, -0.873, '#scared', '#disgusting', -0.528, 'animal', 'brown_bear', 'forest', 'creatures', 'polar_bear']
senticnet['groan'] = [0, 0, -0.825, -0.883, '#scared', '#disgusting', -0.569, 'freak_out', 'loud_cry', 'loud_shout', 'squeak', 'clamor']
senticnet['groaner'] = [-0.878, 0, 0.746, -0.631, '#sad', '#angry', -0.752, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['groceries'] = [0.03, 0.073, 0.027, 0.084, '#interesting', '#admirable', 0.053, 'grocery', 'store_vegetable', 'fresh_vegetable', 'vendor', 'fruit_vegetable']
senticnet['grocery'] = [0.025, -0.062, 0, 0.135, '#surprising', '#admirable', 0.074, 'cold_drink', 'groceries', 'fresh_vegetable', 'vendor', 'goods']
senticnet['grocery_cart'] = [0, 0.074, 0, 0.071, '#interesting', '#admirable', 0.048, 'super_market', 'salad_bar', 'fruit_stand', 'candy_store', 'produce_store']
senticnet['grocery_shop'] = [0.059, 0.212, 0, 0.143, '#interesting', '#admirable', 0.138, 'christmas_shop', 'go_grocery_shop', 'pay_credit_card', 'pay_cash', 'holiday_shop']
senticnet['grocery_store'] = [0.02, 0, 0, 0.081, '#joyful', '#admirable', 0.034, 'city_country', 'supermarket', 'fast_food', 'restaurant', 'retail_store']
senticnet['groggy'] = [-0.567, 0, 0.577, -0.619, '#angry', '#disgusting', -0.588, 'foggy', 'lethargic', 'logy', 'stuporous', 'dazed']
senticnet['groin'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'skeletal_system', 'artery', 'scrotum', 'main_artery', 'diaphragm']
senticnet['grok'] = [0.789, -0.948, 0, 0.824, '#surprising', '#admirable', 0.854, 'understand', 'twig', 'digest', 'tumble', 'intuit']
senticnet['groom'] = [0.028, -0.015, 0, 0.087, '#joyful', '#admirable', 0.043, 'improve_image', 'look_better', 'get_latest_hairstyle', 'change_appearance', 'dress_nice']
senticnet['groom_hair'] = [-0.025, 0, 0.068, 0, '#sad', '#angry', -0.031, 'make_hair_look_nice', 'comb_hair', 'fix_hair', 'arrange_hair', 'style_hair']
senticnet['groomed'] = [0.888, -0.683, 0, 0.914, '#joyful', '#admirable', 0.828, 'tidy', 'kempt', 'sleek', 'pomaded', 'brushed']
senticnet['grooming'] = [0.767, -0.81, 0, 0.714, '#joyful', '#surprising', 0.764, 'practice', 'activity', 'discipline', 'athletic_training', 'drill']
senticnet['groove'] = [0.082, 0, 0.073, 0.168, '#joyful', '#admirable', 0.059, 'instrumental', 'melodic_noise', 'piece_of_music', 'lyric', 'music_storage']
senticnet['gross'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'dirty', 'filthy', 'unclean', 'dingy', 'soiled']
senticnet['gross_out'] = [-0.074, 0.139, 0.688, -0.669, '#angry', '#disgusting', -0.431, 'loathsome', 'churn_up', 'nauseate', 'sicken', 'repel']
senticnet['grouch'] = [-0.936, 0, 0.77, -0.649, '#sad', '#angry', -0.785, 'hothead', 'unpleasant_person', 'disagreeable_person', 'crabby_person', 'crab']
senticnet['grouchy'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'discontent', 'malcontent', 'dissatisfied', 'displeased', 'disgruntled']
senticnet['ground'] = [0.082, 0, 0.073, 0.168, '#joyful', '#admirable', 0.059, 'floor', 'soil', 'underground', 'surface_earth', 'ground_level']
senticnet['ground_cover'] = [0.082, 0, 0.073, 0.168, '#joyful', '#admirable', 0.059, 'soil', 'ground', 'vegetation', 'underground', 'ground_level']
senticnet['ground_floor'] = [0.064, 0.07, 0, 0, '#joyful', '#interesting', 0.045, 'top_floor', 'front_desk', 'concierge', 'exit', 'elevator']
senticnet['ground_level'] = [0.082, 0, 0.073, 0.168, '#joyful', '#admirable', 0.059, 'soil', 'ground', 'underground', 'floor', 'ground_cover']
senticnet['ground_material'] = [-0.028, -0.01, 0.071, 0, '#sad', '#angry', -0.03, 'small_stone', 'small_rock', 'small_pebble', 'dirt', 'abrasive']
senticnet['ground_ocean'] = [-0.024, -0.015, 0.03, -0.049, '#angry', '#disgusting', -0.029, 'ocean_beach', 'beach', 'water_sea', 'shore', 'ocean_floor']
senticnet['groundcover'] = [-0.725, 0, 0.64, -0.585, '#sad', '#angry', -0.65, 'pearlwort', 'pearlweed', 'flora', 'rupturewort', 'whitlowwort']
senticnet['grounded'] = [0, 0, -0.907, -0.969, '#scared', '#disgusting', -0.625, 'anchor', 'base', 'establish', 'strand', 'undercoat']
senticnet['groundless'] = [-0.974, 0, 0.59, -0.93, '#sad', '#disgusting', -0.831, 'idle', 'baseless', 'unsupported', 'unfounded', 'unwarranted']
senticnet['group'] = [0.065, 0.113, 0, 0.1, '#interesting', '#admirable', 0.093, 'big_group', 'clique', 'group_of_people', 'multitude', 'large_group']
senticnet['group_animal'] = [-0.038, 0.082, 0, 0.062, '#interesting', '#admirable', 0.035, 'pull_cart', 'play_dead', 'fun_around', 'jump_over_fence', 'max']
senticnet['group_company'] = [0.049, 0.11, 0.04, 0.146, '#interesting', '#admirable', 0.088, 'business_group', 'large_company', 'neat_tidy', 'business_firm', 'large_business']
senticnet['group_gathering'] = [0, 0.811, 0, 0, '#interesting', '#interesting', 0.27, 'meet_up', 'gather_person', 'public_gathering', 'group_of_people', 'gathering']
senticnet['group_meet'] = [0.045, 0.092, -0.073, 0.14, '#interesting', '#admirable', 0.068, 'business_group', 'organization', 'organize_group', 'assembly', 'business_firm']
senticnet['group_object'] = [-0.09, 0.136, -0.064, 0.121, '#interesting', '#admirable', 0.034, 'climb_to_top', 'meet_greet', 'hot_summer', 'price_goods', 'appear_beautiful']
senticnet['group_of_people'] = [0.124, 0, 0, 0.098, '#joyful', '#admirable', 0.074, 'team_up', 'group', 'social_group', 'mass_person', 'large_group']
senticnet['group_star'] = [0.031, 0.146, -0.141, 0.191, '#interesting', '#admirable', 0.076, 'let_someone_do', 'leave_alone', 'tolerant', 'orbit', 'outer_space']
senticnet['group_student'] = [0, 0.98, 0, 0, '#interesting', '#interesting', 0.327, 'team_work', 'student', 'college_course', 'university', 'class_lesson']
senticnet['group_together'] = [-0.098, 0, 0, 0, '#sad', '#sad', -0.033, 'needy', 'come_house', 'laugh_oneself', 'bridge_gap', 'journey_far']
senticnet['grouse'] = [0.567, -0.935, 0, 0.659, '#surprising', '#admirable', 0.72, 'bird', 'wildfowl', 'quail', 'partridge', 'pheasant']
senticnet['grovel'] = [-0.761, 0, 0, -0.998, '#sad', '#disgusting', -0.586, 'creeps', 'cringe', 'creep', 'cower', 'hysterically']
senticnet['groveler'] = [-0.558, 0, 0.588, -0.65, '#angry', '#disgusting', -0.599, 'apple_polisher', 'bootlicker', 'fawner', 'web', 'crawler']
senticnet['groveling'] = [0.679, -0.947, 0, 0.661, '#joyful', '#surprising', 0.762, 'bowing', 'cringing', 'submissive', 'sub', 'wormlike']
senticnet['grow'] = [0, 0.229, -0.099, 0.187, '#interesting', '#admirable', 0.106, 'increase', 'make_big', 'get_large', 'expansion', 'expand']
senticnet['grow_beard'] = [0.05, -0.029, 0, 0.111, '#joyful', '#admirable', 0.063, 'change_hair', 'makeover', 'case_house', 'dye_hair', 'get_haircut']
senticnet['grow_corn'] = [-0.087, -0.034, 0.048, -0.029, '#sad', '#angry', -0.043, 'flat_land', 'bumpy', 'farm_crop', 'stalk', 'cold_night']
senticnet['grow_crop'] = [0, 0.066, 0.017, 0.057, '#interesting', '#admirable', 0.035, 'plant_crop', 'raise_animal', 'agriculture', 'grow_stuff', 'grow_food']
senticnet['grow_flower'] = [0, -0.097, 0.035, 0.1, '#surprising', '#admirable', 0.054, 'dig_dirt', 'plant_flower', 'decorate_yard', 'plant_garden', 'cut_grass']
senticnet['grow_food'] = [0, 0.078, 0, 0.069, '#interesting', '#admirable', 0.049, 'cultivation', 'grow_stuff', 'grow_crop', 'harvest_food', 'raise_crop']
senticnet['grow_garden'] = [0, 0.078, 0, 0.069, '#interesting', '#admirable', 0.049, 'plant_tree', 'cut_grass', 'plant_flower', 'garden', 'flower']
senticnet['grow_healthy'] = [0.755, -0.713, 0, 0.972, '#joyful', '#admirable', 0.813, 'digest', 'digestion', 'grow_up', 'metabolism', 'healthy_lifestyle']
senticnet['grow_impatient'] = [-0.129, -0.088, 0.051, -0.173, '#sad', '#disgusting', -0.088, 'talk_neighbor', 'think_dog', 'boredom', 'act_bored', 'stop_bleed']
senticnet['grow_large'] = [0, 0.102, -0.058, 0.374, '#interesting', '#admirable', 0.139, 'inclusion', 'widen', 'augment', 'expand', 'grow_long']
senticnet['grow_long'] = [-0.044, 0.179, -0.059, 0.287, '#interesting', '#admirable', 0.121, 'elasticity', 'elongate', 'widen', 'reach_out', 'extend']
senticnet['grow_old'] = [0, 0.98, 0, 0, '#interesting', '#interesting', 0.327, 'get_old', 'sometimes_bad', 'man_spacecraft', 'blow_out_candle', 'grow_up']
senticnet['grow_older'] = [0, 0, 0, -0.847, '#disgusting', '#disgusting', -0.282, 'get_old', 'become_old', 'old', 'lose_energy', 'lose_health']
senticnet['grow_organic_garden'] = [0, -0.017, 0.065, -0.05, '#angry', '#disgusting', -0.033, 'decide_want_eat', 'find_restaurant', 'bite_food', 'make_sandwich', 'obtain_food']
senticnet['grow_place'] = [0, 0.089, 0.014, 0.086, '#interesting', '#admirable', 0.054, 'vegetable_grow', 'plant_ground', 'grass_area', 'crop_place', 'grow_stuff']
senticnet['grow_plant'] = [0, 0, 0, 0.074, '#admirable', '#admirable', 0.025, 'grow_pot', 'grown_soil', 'use_decoration', 'pot', 'make_tea']
senticnet['grow_pot'] = [0, 0, 0, 0.074, '#admirable', '#admirable', 0.025, 'grow_plant', 'grown_soil', 'use_decoration', 'pot', 'make_tea']
senticnet['grow_stuff'] = [0, 0.086, 0.025, 0.078, '#interesting', '#admirable', 0.046, 'harvest_food', 'cultivation', 'grow_food', 'grow_crop', 'agricultural']
senticnet['grow_tree'] = [0.021, 0, 0, 0.081, '#joyful', '#admirable', 0.034, 'many_plants', 'tree_flower', 'greenery', 'flower_plant', 'vegetation']
senticnet['grow_up'] = [0, 0.87, 0, 0, '#interesting', '#interesting', 0.29, 'smartness', 'grow_old', 'good_news', 'learn_quickly', 'endless']
senticnet['grow_vegetable'] = [-0.026, 0.073, 0.025, 0.054, '#interesting', '#admirable', 0.025, 'make_food', 'make_bread', 'follow_recipe', 'cook_curry', 'cook_meal']
senticnet['grow_yard'] = [-0.025, -0.012, -0.078, -0.124, '#scared', '#disgusting', -0.072, 'burn', 'stain_clothes', 'big_fire', 'set_on_fire', 'chemical_process']
senticnet['growing'] = [-0.595, 0, 0.983, -0.675, '#angry', '#disgusting', -0.751, 'growth', 'caenogenesis', 'maturation', 'development', 'ontogeny']
senticnet['growl'] = [-0.084, 0, -0.055, -0.095, '#sad', '#disgusting', -0.078, 'hunt_game', 'cause_illness', 'crazy', 'even_odds', 'hunt_animal']
senticnet['grown'] = [0, 0.903, 0, 0.809, '#interesting', '#admirable', 0.571, 'agricultural_product', 'grown_field', 'organic', 'nutritious', 'cultivate_yard']
senticnet['grown_field'] = [0, 0.08, 0.049, 0.092, '#interesting', '#admirable', 0.041, 'agricultural_product', 'farm_plant', 'farm_food', 'grown_food', 'plant_food']
senticnet['grown_food'] = [0, 0.077, 0.036, 0.071, '#interesting', '#admirable', 0.037, 'farm_food', 'plant_food', 'farm_plant', 'farm_vegetable', 'farm_crop']
senticnet['grown_soil'] = [0, 0.978, 0, 0.782, '#interesting', '#admirable', 0.587, 'harvest_fall', 'mall', 'require_good_health', 'eaten', 'find_mall']
senticnet['grown_up'] = [0.086, 0.095, -0.065, 0.066, '#joyful', '#interesting', 0.061, 'married_couple', 'presidential_election', 'intelligent_person', 'use_binoculars', 'torpedo']
senticnet['growth'] = [0.02, 0.192, -0.14, 0.198, '#interesting', '#admirable', 0.09, 'get_big', 'get_large', 'grow', 'increase_size', 'flourish']
senticnet['grub'] = [0.866, -0.917, 0, 0.893, '#surprising', '#admirable', 0.892, 'mooch', 'cadge', 'freeload', 'sponge', 'bum']
senticnet['grubby'] = [0, 0, -0.925, -0.825, '#scared', '#disgusting', -0.583, 'raunchy', 'begrimed', 'dingy', 'grimy', 'dirty']
senticnet['grudge'] = [0, 0, 0.901, -0.928, '#angry', '#disgusting', -0.61, 'animosity', 'jealous', 'bitterness', 'grudging', 'enviousness']
senticnet['grudging'] = [0.067, 0.104, 0.791, -0.679, '#angry', '#disgusting', -0.433, 'enviousness', 'enviably', 'enviable', 'begrudge', 'sulkiness']
senticnet['gruesome'] = [0, 0, 0.808, -0.91, '#angry', '#disgusting', -0.573, 'grim', 'ghastly', 'macabre', 'sick', 'grisly']
senticnet['gruff'] = [-0.937, 0, 0.576, -0.545, '#sad', '#angry', -0.686, 'grating', 'rasping', 'raspy', 'jarring', 'cacophonic']
senticnet['grump'] = [-0.738, 0, 0.568, -0.766, '#sad', '#disgusting', -0.691, 'hothead', 'unpleasant_person', 'disagreeable_person', 'crabby_person', 'crab']
senticnet['grumpy'] = [-0.892, 0, 0.887, 0, '#sad', '#angry', -0.593, 'elderly', 'old', 'age', 'ancient', 'get_old']
senticnet['grunt'] = [-0.085, 0, -0.054, 0, '#sad', '#scared', -0.046, 'bicycle_store', 'enter_door', 'cost_a_lot_of_money', 'open', 'hang_door']
senticnet['gruntle'] = [0.984, -0.891, 0, 0.881, '#joyful', '#surprising', 0.919, 'tranquilize', 'tranquillize', 'calm_down', 'quieten', 'calm']
senticnet['guanaco'] = [-0.535, 0, 0.751, -0.971, '#angry', '#disgusting', -0.752, 'llama', 'domestic_llama', 'alpaca', 'artiodactyl', 'artiodactyl_mammal']
senticnet['guarantee'] = [0, 0.841, 0, 0, '#interesting', '#interesting', 0.28, 'stuff', 'put_paper', 'blank_check', 'brief', 'supply']
senticnet['guard'] = [0.049, 0.139, -0.09, 0.123, '#interesting', '#admirable', 0.074, 'insurance', 'safety', 'ford', 'policy', 'protect_home']
senticnet['guard_bank'] = [-0.103, 0, -0.05, -0.12, '#sad', '#disgusting', -0.091, 'storm_fortress', 'fight_battle', 'commit_genocide', 'storm_castle', 'keep_peace']
senticnet['guard_prisoner'] = [0.981, 0.791, 0, 0, '#joyful', '#interesting', 0.591, 'delight_audience', 'even_score', 'add_two_numbers', 'play', 'collect']
senticnet['guarded'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'safety', 'absence_of_risk', 'absence_of_danger', 'secure', 'defended']
senticnet['guardian'] = [0, 0.942, 0, 0, '#interesting', '#interesting', 0.314, 'guy', 'special_person', 'pedophile', 'boys', 'male']
senticnet['guardian_angel'] = [0.673, -0.64, 0, 0.669, '#joyful', '#admirable', 0.661, 'eudemon', 'white_angel', 'good_spirit', 'genius_loci', 'angel']
senticnet['guardian_spirit'] = [0.612, -0.653, 0, 0.941, '#surprising', '#admirable', 0.735, 'eudemon', 'eudaemon', 'good_spirit', 'genius_loci', 'angel']
senticnet['guess'] = [0, -0.727, 0, 0.962, '#surprising', '#admirable', 0.563, 'question_start', 'inquiry', 'solution', 'ask', 'question']
senticnet['guess_answer'] = [-0.14, 0, 0, -0.038, '#sad', '#disgusting', -0.059, 'question_teacher', 'study_biology', 'school_student', 'enter_classroom', 'study_library']
senticnet['guest'] = [0, 0.75, 0, 0.781, '#interesting', '#admirable', 0.51, 'privacy', 'red_light_district', 'friend', 'overnight_guest', 'protection_element']
senticnet['guest_service'] = [0, 0.707, 0, 0.861, '#interesting', '#admirable', 0.523, 'come_warranty', 'make_comparison', 'customer_service', 'put_pocket', 'see_action']
senticnet['guff'] = [-0.894, 0, 0.739, -0.972, '#sad', '#disgusting', -0.868, 'rot', 'bunk', 'bunkum', 'buncombe', 'dogshit']
senticnet['guffaw'] = [0.748, 0, 0, 0, '#joyful', '#joyful', 0.249, 'lol', 'giggle', 'funny', 'express_feeling', 'emotional_response']
senticnet['guidance'] = [0.743, -0.863, 0, 0.859, '#surprising', '#admirable', 0.822, 'hint', 'content', 'cynosure', 'confidential_information', 'lead']
senticnet['guide'] = [-0.036, 0.168, -0.077, 0.139, '#interesting', '#admirable', 0.065, 'command', 'direct', 'follow', 'take_charge', 'govern']
senticnet['guide_blind'] = [-0.079, 0, 0, 0, '#sad', '#sad', -0.026, 'cause_accident', 'follow_person', 'stay_in_house', 'mark_territory', 'sense_fear']
senticnet['guide_blind_person'] = [-0.037, 0, -0.05, 0, '#sad', '#scared', -0.029, 'think_food', 'sense_fear', 'trust_friend', 'play_outside', 'cause_accident']
senticnet['guild'] = [0.967, -0.982, 0, 0.64, '#joyful', '#surprising', 0.863, 'club', 'social_club', 'society', 'jockey_club', 'gild']
senticnet['guile'] = [-0.837, 0, 0.802, -0.521, '#sad', '#angry', -0.72, 'dishonesty', 'deceitfulness', 'craftiness', 'disingenuousness', 'artfulness']
senticnet['guileless'] = [0, 0, 0.957, -0.857, '#angry', '#disgusting', -0.605, 'ingenuous', 'gullible', 'artless', 'childlike', 'naive']
senticnet['guilt'] = [-0.897, 0, 0, -0.798, '#sad', '#disgusting', -0.565, 'remorse', 'grief', 'regret', 'sorrow', 'heartache']
senticnet['guilt_feeling'] = [-0.904, 0.152, -0.629, 0.061, '#sad', '#scared', -0.44, 'guilt_trip', 'guilty', 'dolor', 'grieve', 'penitentially']
senticnet['guilt_trip'] = [-0.904, 0.152, -0.629, 0.061, '#sad', '#scared', -0.44, 'guilt_feeling', 'guilty', 'dolor', 'grieve', 'penitentially']
senticnet['guiltiness'] = [-0.985, 0, 0.657, -0.959, '#sad', '#disgusting', -0.867, 'impeachability', 'indictability', 'blameworthiness', 'culpability', 'culpableness']
senticnet['guiltless'] = [0.913, -0.745, 0, 0.703, '#joyful', '#surprising', 0.787, 'absolved', 'exculpated', 'exonerated', 'vindicated', 'clear']
senticnet['guilty'] = [-0.919, 0, 0, -0.929, '#sad', '#disgusting', -0.616, 'wretched', 'dolefully', 'disconsolateness', 'despondence', 'despondency']
senticnet['guilty_conscience'] = [-0.772, 0, 0, -0.89, '#sad', '#disgusting', -0.554, 'heartbreak', 'repent', 'repentance', 'guilt_feeling', 'guilt_trip']
senticnet['guilty_crime'] = [0, 0, 0, -0.995, '#disgusting', '#disgusting', -0.332, 'uneducated', 'homophobic', 'precise', 'strange', 'ignorant']
senticnet['guilty_person'] = [-0.873, 0, 0, -0.898, '#sad', '#disgusting', -0.59, 'person', 'stockholder', 'commit_crime', 'nacho', 'criminal']
senticnet['guinea_gold'] = [-0.624, 0, 0.504, -0.798, '#sad', '#disgusting', -0.642, 'green_gold', 'pure_gold', 'gold_dust', 'atomic_number_79', 'noble_metal']
senticnet['guinness'] = [0.918, 0.763, 0, 0, '#joyful', '#interesting', 0.56, 'drunkard', 'alcoholic_beverage', 'drunk_person', 'booze', 'alcoholic_drink']
senticnet['guitar_player'] = [0.032, 0.092, 0, 0.075, '#interesting', '#admirable', 0.066, 'rock_group', 'music_player', 'make_musicr', 'musical_group', 'eclectic']
senticnet['guitar_string'] = [0, 0.855, 0, 0.983, '#interesting', '#admirable', 0.613, 'music_sound', 'musical_sound', 'piece_of_music', 'musical_term', 'music_note']
senticnet['gulf'] = [0, 0.976, 0, 0.928, '#interesting', '#admirable', 0.635, 'harpoon', 'armory', 'lake', 'river', 'bay']
senticnet['gullible'] = [0, 0, 0.957, -0.857, '#angry', '#disgusting', -0.605, 'ingenuous', 'naive', 'artless', 'childlike', 'guileless']
senticnet['gulp'] = [0.102, 0.084, 0, 0.076, '#joyful', '#interesting', 0.087, 'better_cold', 'sip', 'potable_liquid', 'ingest', 'liquid_beverage']
senticnet['gulping'] = [-0.723, 0, 0.561, -0.68, '#sad', '#disgusting', -0.655, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['gum'] = [0.965, 0.775, 0, 0.968, '#joyful', '#admirable', 0.903, 'snot', 'bad_taste', 'mouth_part', '32_teeth', 'near_mouth']
senticnet['gummosis'] = [-0.833, 0, 0.754, -0.979, '#sad', '#disgusting', -0.855, 'brown_rot_brown_rot', 'ring_rot', 'ring_disease', 'tobacco_wilt', 'brown_rot']
senticnet['gummy'] = [0, 0, -0.841, -0.83, '#scared', '#disgusting', -0.557, 'gluey', 'pasty', 'sticky', 'mucilaginous', 'glutinous']
senticnet['gumption'] = [0.605, -0.936, 0, 0.742, '#surprising', '#admirable', 0.761, 'road_sense', 'sagacity', 'sagaciousness', 'logic', 'nous']
senticnet['gumshoe'] = [-0.881, 0, 0.75, -0.855, '#sad', '#disgusting', -0.829, 'rubber', 'galosh', 'golosh', 'arctic', 'overshoe']
senticnet['gun'] = [0, 0, 0.952, -0.883, '#angry', '#disgusting', -0.612, 'rifle', 'pistol', 'revolver', 'hydrogen_bomb', 'firearm']
senticnet['gun_barrel'] = [-0.912, 0, 0.585, -0.933, '#sad', '#disgusting', -0.81, 'bullet', 'gun', 'rifle', 'shoot', 'pistol']
senticnet['gun_knife'] = [0, 0, 0.984, -0.97, '#angry', '#disgusting', -0.651, 'weapon', 'atomic_bomb', 'hydrogen_bomb', 'shotgun', 'dangerous_weapon']
senticnet['gun_moll'] = [0.909, -0.944, 0, 0.992, '#surprising', '#admirable', 0.948, 'felon', 'crook', 'malefactor', 'outlaw', 'criminal']
senticnet['gun_shop'] = [-0.041, -0.005, -0.065, -0.213, '#scared', '#disgusting', -0.105, 'holster', 'armory', 'gun_store', 'arsenal', 'war_zone']
senticnet['gun_store'] = [-0.044, 0, -0.094, -0.204, '#scared', '#disgusting', -0.114, 'holster', 'arsenal', 'gun_shop', 'war', 'war_zone']
senticnet['guncotton'] = [-0.888, 0, 0.643, -0.611, '#sad', '#angry', -0.714, 'cellulose_ester', 'pyroxylin', 'pyroxyline', 'pyrocellulose', 'nitrate']
senticnet['gunfire'] = [0, 0, 0.791, -0.817, '#angry', '#disgusting', -0.536, 'automatic', 'atomic_bomb', 'hydrogen_bomb', 'shotgun', 'nuclear_weapon']
senticnet['gunk'] = [0.071, 0, -0.085, -0.09, '#scared', '#disgusting', -0.035, 'acid', 'rotten_food', 'sour_cream', 'glass_of_milk', 'lemon_juice']
senticnet['gunny'] = [0.572, -0.716, 0, 0.895, '#surprising', '#admirable', 0.728, 'material', 'burlap', 'sacking', 'fabric', 'cloth']
senticnet['gunpowder'] = [0, 0, 0, -0.101, '#disgusting', '#disgusting', -0.034, 'piece_of_metal', 'ammunition', 'badge', 'bullet', 'projectile']
senticnet['gunshot'] = [-0.087, -0.021, 0, -0.193, '#sad', '#disgusting', -0.086, 'wound', 'lethal', 'vaccination', 'destruction', 'fire_bullet']
senticnet['gunwale'] = [0, 0.855, 0, 0.737, '#interesting', '#admirable', 0.531, 'propeller', 'hull', 'cleat', 'boat_part', 'stern']
senticnet['guru'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'good_view', 'summit', 'great_view', 'mountain_climber', 'powerful_man']
senticnet['gush'] = [0, -0.801, 0, 0.746, '#surprising', '#admirable', 0.516, 'doughnut', 'mousse', 'biscuit', 'custard', 'cookie']
senticnet['gust'] = [0.957, -0.576, 0, 0.857, '#joyful', '#admirable', 0.797, 'bluster', 'puff', 'sandblast', 'puff_of_air', 'whiff']
senticnet['gustatory_perception'] = [-0.93, 0, 0.537, -0.572, '#sad', '#disgusting', -0.68, 'taste', 'taste_sensation', 'gustatory_sensation', 'taste_perception', 'astringence']
senticnet['gustatory_sensation'] = [-0.93, 0, 0.537, -0.572, '#sad', '#disgusting', -0.68, 'taste', 'taste_sensation', 'astringence', 'taste_perception', 'gustatory_perception']
senticnet['gusto'] = [0.508, 0.659, -0.254, 0.253, '#joyful', '#interesting', 0.389, 'zestfulness', 'exuberantly', 'riotously', 'expansively', 'ebulliently']
senticnet['gut_issue'] = [0.648, -0.873, 0, 0.597, '#joyful', '#surprising', 0.706, 'issue', 'content', 'paramount_issue', 'pocketbook_issue', 'quodlibet']
senticnet['gutter'] = [-0.9, 0, 0.749, -0.719, '#sad', '#angry', -0.789, 'chute', 'slide', 'slideway', 'sloping_trough', 'cullis']
senticnet['guy'] = [0, 0.807, 0, 0.943, '#interesting', '#admirable', 0.583, 'male', 'bloke', 'boys', 'man_child', 'man']
senticnet['gym'] = [0.035, -0.015, 0.009, 0.063, '#joyful', '#admirable', 0.035, 'go_to_gym', 'sport', 'sporty', 'sport_store', 'fit']
senticnet['gym_equipment'] = [0, 0.142, 0, 0.125, '#interesting', '#admirable', 0.089, 'exercise_equipment', 'plumber', 'weight_machine', 'old_book', 'pulley']
senticnet['gym_locker'] = [0, 0.912, 0, 0.911, '#interesting', '#admirable', 0.608, 'game', 'beach_house', 'football_game', 'football', 'football_stadium']
senticnet['gym_suit'] = [-0.76, 0, 0.58, -0.507, '#sad', '#angry', -0.616, 'attire', 'garb', 'dress', 'activewear', 'running_suit']
senticnet['gymnasium'] = [0.024, 0.152, -0.065, 0.236, '#interesting', '#admirable', 0.116, 'basketball_court', 'play_sport', 'tennis_game', 'squash_court', 'playground_equipment']
senticnet['gymnast'] = [0, 0.833, 0, 0.895, '#interesting', '#admirable', 0.576, 'distinctive_smell', 'bikini', 'underwear', 'basketball_hoop', 'dirty_sock']
senticnet['gymnastics'] = [0.816, 0.723, 0, 0, '#joyful', '#interesting', 0.513, 'martial_art', 'judo', 'jump_around', 'go_underwater', 'athletics']
senticnet['gymnosperm'] = [-0.772, 0, 0.585, -0.835, '#sad', '#disgusting', -0.731, 'progymnosperm', 'welwitschia', 'cycad', 'seed_fern', 'pteridosperm']
senticnet['gypsy_moth'] = [0, -0.095, 0.123, -0.119, '#angry', '#disgusting', -0.049, 'mole_cricket', 'japanese_beetle', 'cucumber_beetle', 'mosquito', 'earwig']
senticnet['gyroscope'] = [0, 0.142, 0, 0.125, '#interesting', '#admirable', 0.089, 'orientation', 'instrument', 'find_way', 'compass', 'use_compass']
senticnet['habit'] = [-0.994, 0, 0.827, -0.636, '#sad', '#angry', -0.819, 'substance_abuse', 'drug_abuse', 'misuse', 'usage', 'use']
senticnet['habit_form'] = [0, -0.877, 0, 0.8, '#surprising', '#admirable', 0.559, 'card', 'chance', 'bet', 'poker_chip', 'deck_card']
senticnet['habitability'] = [0.603, -0.778, 0, 0.641, '#surprising', '#admirable', 0.674, 'suitability', 'suitableness', 'fitness', 'habitableness', 'qualification']
senticnet['habitableness'] = [0.603, -0.778, 0, 0.641, '#surprising', '#admirable', 0.674, 'suitability', 'suitableness', 'habitability', 'fitness', 'qualification']
senticnet['habitant'] = [0.9, -0.513, 0, 0.836, '#joyful', '#admirable', 0.75, 'indweller', 'invillager', 'villager', 'dweller', 'denizen']
senticnet['habitat'] = [0, 0.076, 0.024, 0.137, '#interesting', '#admirable', 0.063, 'kennel', 'hive', 'lair', 'animal_home', 'beehive']
senticnet['habitation'] = [0, 0.765, 0, 0.772, '#interesting', '#admirable', 0.512, 'domicile', 'dwell_place', 'domestic_dwell', 'live_place', 'residence']
senticnet['habitual_criminal'] = [0.559, -0.675, 0, 0.651, '#surprising', '#admirable', 0.628, 'felon', 'crook', 'malefactor', 'outlaw', 'criminal']
senticnet['habituation'] = [0.637, -0.674, 0, 0.942, '#surprising', '#admirable', 0.751, 'drug_addiction', 'white_plague', 'physical_condition', 'physiological_state', 'physiological_condition']
senticnet['habitus'] = [0.98, -0.614, 0, 0.598, '#joyful', '#surprising', 0.731, 'diathesis', 'hypersensitivity', 'susceptibility', 'susceptibleness', 'predisposition']
senticnet['hachure'] = [-0.912, 0, 0.796, -0.872, '#sad', '#disgusting', -0.86, 'hatch', 'hatching', 'crosshatch', 'shading', 'marking']
senticnet['hack'] = [0, -0.712, 0, 0.705, '#surprising', '#admirable', 0.472, 'use_internet', 'surf_web', 'read_magazine', 'surf_net', 'read_letter']
senticnet['hacker'] = [-0.381, 0.108, -0.389, 0.072, '#sad', '#scared', -0.197, 'undercover', 'hide', 'fake', 'hide_identity', 'internet']
senticnet['hackles'] = [-0.15, 0.162, 0.596, -0.625, '#angry', '#disgusting', -0.403, 'dander', 'umbrage', 'offense', 'ire', 'see_red']
senticnet['hackneyed'] = [0, 0, -0.924, -0.94, '#scared', '#disgusting', -0.621, 'shopworn', 'banal', 'stock', 'old-hat', 'commonplace']
senticnet['haddock'] = [0, -0.023, 0.026, -0.085, '#angry', '#disgusting', -0.029, 'dryad', 'pier', 'canoe', 'shallow', 'find_sea']
senticnet['haematoma'] = [-0.697, 0, 0.517, -0.619, '#sad', '#disgusting', -0.611, 'hematoma', 'intumescence', 'puffiness', 'swelling', 'lump']
senticnet['hag'] = [-0.542, 0, 0.992, -0.872, '#angry', '#disgusting', -0.802, 'jawless_fish', 'osteostracan', 'cephalaspid', 'ostracoderm', 'heterostracan']
senticnet['haiku'] = [0.051, 0, 0.015, 0.078, '#joyful', '#admirable', 0.038, 'verse', 'like_poetry', 'rhyme', 'song_lyric', 'lyrics']
senticnet['hail'] = [0.898, -0.708, 0, 0.712, '#joyful', '#admirable', 0.773, 'wish', 'reception', 'welcome', 'greeting', 'regard']
senticnet['hailstone'] = [-0.195, -0.105, 0.041, -0.233, '#sad', '#disgusting', -0.121, 'dandruff', 'cold_hot', 'snow', 'monsoon', 'rain']
senticnet['hailstorm'] = [-0.782, 0, 0.906, -0.545, '#sad', '#angry', -0.744, 'rainstorm', 'atmospheric_phenomenon', 'northeaster', 'noreaster', 'storm']
senticnet['hair'] = [0, -0.011, 0.044, -0.069, '#angry', '#disgusting', -0.034, 'no_hair', 'two_eyes', 'fur_keep_warm', 'hold_hair', 'facial_hair']
senticnet['hair_accessory'] = [0.789, 0.757, 0, 0, '#joyful', '#interesting', 0.515, 'cosmetic', 'hair_roller', 'hairdresser_chair', 'straighten_hair', 'sculpt_gel']
senticnet['hair_become_short'] = [-0.055, 0, -0.077, -0.043, '#sad', '#scared', -0.058, 'keep_hair_short', 'cold_head', 'short_hair', 'little_hair', 'hair_get_short']
senticnet['hair_brush'] = [0.022, -0.015, 0.062, -0.099, '#angry', '#disgusting', -0.041, 'electric_toothbrush', 'moistener', 'hairbrush', 'shampoo_conditioner', 'shave_kit']
senticnet['hair_care_article'] = [-0.724, 0, 0, -0.846, '#sad', '#disgusting', -0.523, 'sculpt_gel', 'barrette', 'dandruff_shampoo', 'get_clean', 'mouthwash']
senticnet['hair_clip'] = [0.881, 0.817, 0, 0, '#joyful', '#interesting', 0.566, 'barrette', 'hairpin', 'hair_dryer', 'bobby_pin', 'curl_iron']
senticnet['hair_color'] = [0, 0.073, -0.059, 0.067, '#interesting', '#admirable', 0.027, 'blonde', 'purple', 'violet', 'dark_light', 'hue']
senticnet['hair_colored'] = [0.035, 0, 0, 0.116, '#joyful', '#admirable', 0.05, 'maroon', 'color', 'bright_color', 'scarlet', 'cool_color']
senticnet['hair_conditioner'] = [0.843, 0.955, 0, 0, '#joyful', '#interesting', 0.599, 'dandruff_shampoo', 'hair_shape_gel', 'wax_dental_floss', 'fluoride_toothpaste', 'tartar_control_toothpaste']
senticnet['hair_dryer'] = [0, 0.792, 0, 0.794, '#interesting', '#admirable', 0.529, 'barrette', 'hair_gel', 'blow_dryer', 'dry_hair', 'wet_hair']
senticnet['hair_gel'] = [0, 0.896, 0, 0.756, '#interesting', '#admirable', 0.551, 'hair_dryer', 'barrette', 'hair_shape_gel', 'sculpt_gel', 'haircut_scissor']
senticnet['hair_get_short'] = [-0.065, 0, 0, -0.044, '#sad', '#disgusting', -0.036, 'talk_hairdresser', 'bad_haircut', 'hair_become_short', 'keep_hair_short', 'change_style']
senticnet['hair_long'] = [0, 0, 0, 0.07, '#admirable', '#admirable', 0.023, 'get_new_hairstyle', 'new_hair_style', 'change_hair_style', 'get_haircut', 'look_smart']
senticnet['hair_lotion'] = [0, 0.086, -0.069, 0.12, '#interesting', '#admirable', 0.046, 'gel_toothpaste', 'tartar_control_toothpaste', 'fluoride_mouthwash', 'toothpaste', 'lotion']
senticnet['hair_roller'] = [0, 0.852, 0, 0.809, '#interesting', '#admirable', 0.554, 'barber_comb', 'hairdresser_chair', 'hair_accessory', 'sculpt_gel', 'barrette']
senticnet['hair_salon'] = [-0.024, 0.122, 0, 0.137, '#interesting', '#admirable', 0.078, 'barber_shop', 'barbershop', 'hairdressing_salon', 'beauty_salon', 'salon']
senticnet['hair_shape_gel'] = [0, 0.907, 0, 0.98, '#interesting', '#admirable', 0.629, 'dandruff_shampoo', 'barrette', 'sculpt_gel', 'hair_gel', 'wax_dental_floss']
senticnet['hair_style'] = [0, 0.097, 0, 0.146, '#interesting', '#admirable', 0.081, 'hairstyle', 'hair', 'case_house', 'hold', 'case_joint']
senticnet['hair_wash'] = [-0.103, 0, 0, -0.062, '#sad', '#disgusting', -0.055, 'short_hair', 'talk_hairdresser', 'hair_become_short', 'pay_barber', 'keep_hair_short']
senticnet['hairball'] = [0, -0.016, 0.067, -0.031, '#angry', '#disgusting', -0.027, 'waste_water', 'clog', 'false_tooth', 'stench', 'still_water']
senticnet['hairbrush'] = [0.022, -0.015, 0.062, -0.099, '#angry', '#disgusting', -0.041, 'electric_toothbrush', 'moistener', 'hair_brush', 'shampoo_conditioner', 'shave_kit']
senticnet['haircloth'] = [0, 0.824, 0, 0.726, '#interesting', '#admirable', 0.517, 'needle', 'sew_needle', 'sew_machine', 'needle_thread', 'oilcloth']
senticnet['haircut'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'visit_barber', 'new_hair_style', 'makeover', 'get_hair_colored', 'go_barber']
senticnet['haircut_scissor'] = [0, 0.786, 0, 0.806, '#interesting', '#admirable', 0.531, 'barrette', 'sculpt_gel', 'barber_comb', 'hair_gel', 'hair_accessory']
senticnet['hairdo'] = [-0.974, 0, 0.567, -0.598, '#sad', '#disgusting', -0.713, 'coif', 'coiffure', 'marcel', 'hairstyle', 'hair_style']
senticnet['hairdresser'] = [0.723, 0, 0, 0.795, '#joyful', '#admirable', 0.506, 'hair', 'haircut', 'hairdresser_chair', 'scissor', 'hairstyle']
senticnet['hairdresser_chair'] = [0, -0.058, 0.061, -0.104, '#angry', '#disgusting', -0.036, 'hair_accessory', 'barber_comb', 'hair_roller', 'hairdressing_salon', 'sculpt_gel']
senticnet['hairdressing_salon'] = [0.829, 0, 0, 0.725, '#joyful', '#admirable', 0.518, 'hairdresser', 'haircut', 'hairdresser_chair', 'cut_hair', 'hairstyle']
senticnet['haired'] = [-0.754, 0, 0.734, -0.825, '#sad', '#disgusting', -0.771, 'puberulent', 'sericeous', 'furlike', 'pappose', 'pilous']
senticnet['hairless'] = [-0.587, 0, 0.66, -0.8, '#angry', '#disgusting', -0.682, 'bald', 'depilous', 'glabrescent', 'glabrous', 'balding']
senticnet['hairline_fracture'] = [-0.812, 0, 0.745, -0.94, '#sad', '#disgusting', -0.832, 'injury', 'fracture', 'capillary_fracture', 'incomplete_fracture', 'simple_fracture']
senticnet['hairpin'] = [0, 0.822, 0, 0.701, '#interesting', '#admirable', 0.508, 'bobby_pin', 'barrette', 'haircut_scissor', 'hair_gel', 'double_edge_razor']
senticnet['hairsplitter'] = [-0.856, 0, 0.749, -0.998, '#sad', '#disgusting', -0.868, 'controversialist', 'fight', 'quarrel', 'obstructor', 'obstructer']
senticnet['hairstyle'] = [0, 0.097, 0, 0.146, '#interesting', '#admirable', 0.081, 'hair_style', 'hair', 'case_house', 'hold', 'case_joint']
senticnet['hairy'] = [-0.598, 0, 0.637, -0.923, '#angry', '#disgusting', -0.719, 'puberulent', 'sericeous', 'furlike', 'pappose', 'pilous']
senticnet['hairy_animal'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'brown_bear', 'woodland_creature', 'brown_fur', 'huge_animal', 'brown_hair']
senticnet['hairy_leg'] = [0, 0, 0, -0.847, '#disgusting', '#disgusting', -0.282, 'look_alike', 'low_self-esteem', 'damage_car', 'broken_car', 'remove_hair']
senticnet['halcyon'] = [0, 0.96, 0, 0.823, '#interesting', '#admirable', 0.594, 'mythical_creature', 'hero', 'mythical_being', 'calm', 'pleseant']
senticnet['hale'] = [0.816, 0.76, 0, 0.956, '#joyful', '#admirable', 0.844, 'cold_air', 'tumble', 'frost', 'ice_cube', 'drop']
senticnet['haleness'] = [0.939, -0.745, 0, 0.57, '#joyful', '#surprising', 0.751, 'healthiness', 'wholeness', 'rosiness', 'health', 'vitality']
senticnet['half'] = [-0.022, 0, 0.061, 0, '#sad', '#angry', -0.028, 'cut_up', 'cut', 'cut_half', 'separate', 'bake_cookie']
senticnet['halloween'] = [0.754, 0, 0, 0.861, '#joyful', '#admirable', 0.538, 'clown', 'juggler', 'swing', 'acrobat', 'dare']
senticnet['hallucinate'] = [-0.78, 0, -0.889, 0, '#sad', '#scared', -0.556, 'change_mind', 'think_sex', 'invigorate', 'alter_state_consciousness', 'loss_of_consciousness']
senticnet['hallucination'] = [0, 0, -0.84, 0, '#scared', '#scared', -0.28, 'blank_stare', 'unsettle', 'reflect', 'delusion', 'think_past']
senticnet['hallucinatory'] = [-0.677, 0, 0.716, -0.897, '#angry', '#disgusting', -0.763, 'imaginary', 'notional', 'fabled', 'unreal', 'illusional']
senticnet['hallucinogen'] = [-0.646, 0, 0.911, -0.709, '#angry', '#disgusting', -0.755, 'headache', 'see_dragon', 'illusion', 'distorted_vision', 'distorted_perception']
senticnet['hallucinogenic_drug'] = [-0.693, 0, 0.991, -0.509, '#sad', '#angry', -0.731, 'headache', 'see_dragon', 'illusion', 'distorted_vision', 'distorted_perception']
senticnet['hallway'] = [0.039, -0.033, 0, 0, '#joyful', '#surprising', 0.024, 'lower_floor', 'floor', 'ground_floor', 'first_floor', 'level_one']
senticnet['halt'] = [-0.998, 0, 0.893, -0.703, '#sad', '#angry', -0.865, 'stop', 'red_light', 'eight_sides', 'come', 'pause']
senticnet['halve'] = [-0.065, 0, 0.058, 0, '#sad', '#angry', -0.041, 'divide', 'math_action', 'mathematical_operation', 'division', 'separate']
senticnet['ham'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'beef', 'pork', 'french_toast', 'steak', 'brisket']
senticnet['ham_actor'] = [-0.714, 0, 0.794, -0.899, '#angry', '#disgusting', -0.802, 'role_player', 'thespian', 'actor', 'histrion', 'player']
senticnet['hamburger'] = [0.062, 0, 0.027, 0.055, '#joyful', '#admirable', 0.03, 'porridge', 'meal', 'broth', 'appetizer', 'hearty']
senticnet['hamelia'] = [0.938, -0.773, 0, 0.944, '#joyful', '#admirable', 0.885, 'bush', 'scarlet_bush', 'scarlet_hamelia', 'coloradillo', 'shrub']
senticnet['hamlet'] = [-0.97, 0, -0.854, 0, '#sad', '#scared', -0.608, 'play', 'perpetrator', 'role_play', 'act_part', 'terrible_event']
senticnet['hammer_nail'] = [-0.077, 0, 0, 0, '#sad', '#sad', -0.026, 'market', 'refrigerate', 'buy_market', 'put_napkin_lap', 'defrost']
senticnet['hammerhead'] = [-0.986, 0, 0.714, -0.903, '#sad', '#disgusting', -0.868, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['hamper'] = [-0.056, -0.047, 0.017, -0.056, '#sad', '#disgusting', -0.027, 'shoe_shop', 'shoe_store', 'attic', 'obstruct', 'closet']
senticnet['hand'] = [0.883, -0.593, 0, 0.533, '#joyful', '#surprising', 0.67, 'hooks', 'meat_hooks', 'maulers', 'right', 'left']
senticnet['hand_action'] = [0.021, 0.146, -0.128, 0.258, '#interesting', '#admirable', 0.099, 'hand_movement', 'hand_motion', 'feel_action', 'hand_gesture', 'back_forth']
senticnet['hand_clapping'] = [0.502, -0.845, 0, 0.769, '#surprising', '#admirable', 0.705, 'hand', 'round', 'approval', 'commendation', 'handclap']
senticnet['hand_cramp'] = [0, -0.755, 0, 0, '#surprising', '#surprising', 0.252, 'writer_cramp', 'scratch_head', 'think_past', 'think_story', 'stare_off_space']
senticnet['hand_foot'] = [0, 0.072, 0, 0.064, '#interesting', '#admirable', 0.045, 'physique', 'leg_arm', 'anatomy', 'human_part', 'below_neck']
senticnet['hand_gesture'] = [0.034, 0.13, -0.083, 0.258, '#interesting', '#admirable', 0.113, 'hand_motion', 'hand_movement', 'arm_movement', 'hand_action', 'goodbye']
senticnet['hand_glass'] = [0.584, -0.627, 0, 0.815, '#surprising', '#admirable', 0.675, 'cheval_glass', 'car_mirror', 'mirror', 'hand_mirror', 'looking_glass']
senticnet['hand_hold'] = [0, 0.767, 0, 0.749, '#interesting', '#admirable', 0.505, 'move_liquid', 'pour_liquid', 'fill_in_glass', 'pour', 'push']
senticnet['hand_in_hand'] = [-0.046, 0.194, -0.106, 0.124, '#interesting', '#admirable', 0.055, 'together', 'musical_note', 'music_note', 'just_in_time', 'same_time']
senticnet['hand_job'] = [0.89, -0.646, 0, 0.765, '#joyful', '#admirable', 0.767, 'wank', 'frottage', 'jacking_off', 'jerking_off', 'masturbation']
senticnet['hand_luggage'] = [0, 0.809, 0, 0.795, '#interesting', '#admirable', 0.535, 'baggage', 'passenger_ticket', 'air_ticket', 'move_sidewalk', 'aircraft_roadway']
senticnet['hand_made'] = [0, 0.794, 0, 0.848, '#interesting', '#admirable', 0.547, 'dead', 'hard', 'power_electricity', 'man-made', 'little_dense_water']
senticnet['hand_mirror'] = [0.584, -0.627, 0, 0.815, '#surprising', '#admirable', 0.675, 'cheval_glass', 'car_mirror', 'hand_glass', 'mirror', 'looking_glass']
senticnet['hand_motion'] = [0.034, 0.103, -0.086, 0.239, '#interesting', '#admirable', 0.097, 'hand_gesture', 'hand_movement', 'hand_action', 'arm_movement', 'hand_signal']
senticnet['hand_movement'] = [0, 0.766, 0, 0.918, '#interesting', '#admirable', 0.561, 'hand_action', 'hand_motion', 'hand_gesture', 'back_forth', 'feel_action']
senticnet['hand_out'] = [-0.03, 0.275, -0.178, 0.398, '#interesting', '#admirable', 0.155, 'donate', 'give_out', 'give', 'hand_over', 'receive']
senticnet['hand_over'] = [0, 0.79, 0, 0.88, '#interesting', '#admirable', 0.557, 'donate', 'distribute', 'wedding_vow', 'hand_out', 'give']
senticnet['hand_print'] = [0.026, 0, 0, 0.073, '#joyful', '#admirable', 0.033, 'coupon', 'bottle_water', 'plastic_container', 'carton_milk', 'loaf_bread']
senticnet['hand_signal'] = [0, 0.105, -0.068, 0.208, '#interesting', '#admirable', 0.082, 'hand_motion', 'hand_gesture', 'hand_movement', 'hand_action', 'arm_movement']
senticnet['hand_tool'] = [0, 0.74, 0, 0.931, '#interesting', '#admirable', 0.557, 'make_outline', 'press_button', 'put_bag', 'add_two_numbers_together', 'short_version']
senticnet['hand_towel'] = [0.024, 0.157, 0.018, 0.145, '#interesting', '#admirable', 0.103, 'toilet_paper', 'beach_towel', 'face_towel', 'towel', 'tissue']
senticnet['hand_wash'] = [0, 0.844, 0, 0.701, '#interesting', '#admirable', 0.515, 'clean_agent', 'tv_drama', 'cleanser', 'lather', 'free_will']
senticnet['hand_wear'] = [0.57, -0.566, 0, 0.888, '#joyful', '#admirable', 0.675, 'wearable', 'wear', 'muff', 'glove', 'clothing']
senticnet['handbag'] = [0, -0.009, 0.045, -0.081, '#angry', '#disgusting', -0.039, 'shoulder_bag', 'pantyhose', 'holdall', 'vanity_case', 'tote_bag']
senticnet['handclap'] = [0.857, -0.773, 0, 0.878, '#joyful', '#admirable', 0.836, 'hand', 'round', 'approval', 'commendation', 'clapping']
senticnet['handcuff'] = [-0.136, 0.113, -0.162, 0, '#sad', '#scared', -0.062, 'question_witness', 'legal_process', 'find_guilty', 'convict_criminal', 'close_case']
senticnet['handgrip'] = [-0.816, 0, 0.844, -0.766, '#sad', '#angry', -0.809, 'hold', 'grip', 'basket_hilt', 'handle', 'hilt']
senticnet['handgun'] = [0, 0, 0.829, -0.9, '#angry', '#disgusting', -0.576, 'firearm', 'rifle', 'machine_gun', 'gun', 'pistol']
senticnet['handicap'] = [-0.768, 0, -0.797, 0, '#sad', '#scared', -0.522, 'strangle', 'bloodshed', 'cripple', 'hear_bad_news', 'sexually_transmit_disease']
senticnet['handkerchief'] = [0.028, 0.066, 0, 0, '#joyful', '#interesting', 0.031, 'cowhide', 'kerchief', 'hanky', 'facial_tissue', 'zipper']
senticnet['handle'] = [0, 0.072, 0, 0.117, '#interesting', '#admirable', 0.063, 'knob', 'door_knob', 'restrict_access', 'lock', 'latch']
senticnet['handle_carefully'] = [0, 0.712, 0, 0.829, '#interesting', '#admirable', 0.514, 'upgrade', 'deflate', 'appraise', 'read_cover', 'look_behind']
senticnet['handless'] = [-0.61, 0, 0.533, -0.971, '#sad', '#disgusting', -0.705, 'bungling', 'bumbling', 'butterfingered', 'inept', 'maladroit']
senticnet['handmade'] = [0, 0, 0, 0.122, '#admirable', '#admirable', 0.041, 'pencil_mark', 'make_book', 'make_newspaper', 'script', 'written_text']
senticnet['handmaid'] = [0, 0.902, 0, 0.792, '#interesting', '#admirable', 0.565, 'touch', 'thumb', 'rub', 'knuckle', 'grasp']
senticnet['handmaiden'] = [-0.626, 0, 0.649, -0.673, '#angry', '#disgusting', -0.649, 'handmaid', 'maid', 'chambermaid', 'lady_maid', 'parlormaid']
senticnet['handout'] = [0, 0.748, 0, 0.914, '#interesting', '#admirable', 0.554, 'scotch_tape', 'fountain_pen', 'pen', 'stamp_pad', 'scrap_paper']
senticnet['handset'] = [0.04, -0.045, 0.024, 0.094, '#surprising', '#admirable', 0.052, 'receiver', 'speaker', 'phone', 'utterance', 'channel_selector']
senticnet['handshake'] = [0.083, 0.129, -0.097, 0.155, '#interesting', '#admirable', 0.09, 'shake_hand', 'say_hello', 'introduce_oneself', 'breath_sigh_relief', 'hump_leg']
senticnet['handsome'] = [0.757, 0.837, 0, 0, '#joyful', '#interesting', 0.531, 'big', 'well-favored', 'good-looking', 'better-looking', 'bighearted']
senticnet['handwear'] = [0.891, -0.59, 0, 0.502, '#joyful', '#surprising', 0.661, 'wearable', 'wear', 'muff', 'glove', 'clothing']
senticnet['handwriting'] = [-0.842, 0, 0.579, -0.747, '#sad', '#disgusting', -0.723, 'squiggle', 'hand', 'chicken_scratch', 'cacography', 'script']
senticnet['handwritten'] = [0, 0.995, 0, 0.958, '#interesting', '#admirable', 0.651, 'jot', 'note_down', 'written_message', 'correspondence', 'written_communication']
senticnet['handy'] = [0, 0.778, 0, 0.982, '#interesting', '#admirable', 0.587, 'feel_action', 'sensual', 'hand_action', 'engage', 'hand_movement']
senticnet['hang'] = [0, 0.073, 0, 0.079, '#interesting', '#admirable', 0.051, 'shutter', 'window', 'window_cover', 'drape', 'drop']
senticnet['hang_ceiling'] = [0, 0.136, -0.071, 0.107, '#interesting', '#admirable', 0.057, 'plant_yard', 'like_flower', 'small_flower', 'cut_grass', 'garden_plant']
senticnet['hang_closet'] = [0.283, 0.292, -0.109, 0.272, '#joyful', '#interesting', 0.246, 'fill_ink', 'fold_up', 'make_out_metal', 'hold_garbage', 'display_item']
senticnet['hang_clothes'] = [0, 0.833, 0, 0.71, '#interesting', '#admirable', 0.514, 'hanger', 'hang_up_clothes', 'clothes_hanger', 'storage_space', 'find_kitchen']
senticnet['hang_door'] = [-0.072, 0.143, -0.059, 0.215, '#interesting', '#admirable', 0.076, 'go_build', 'enter_room', 'go_through', 'enter', 'separate_room']
senticnet['hang_flower'] = [0, 0.075, 0.028, 0.173, '#interesting', '#admirable', 0.073, 'hang_picture', 'hang_paint', 'hang_frame', 'hang_picture_to_wall', 'hang_up']
senticnet['hang_frame'] = [0, 0.075, 0.028, 0.173, '#interesting', '#admirable', 0.073, 'hang_picture', 'hang_paint', 'hang_picture_to_wall', 'hang_flower', 'hang_up']
senticnet['hang_hanger'] = [0, 0.075, 0.028, 0.173, '#interesting', '#admirable', 0.073, 'store_dress', 'adornment', 'organize_clothes', 'accessory', 'wear_clothes']
senticnet['hang_in'] = [-0.605, 0, 0.648, -0.663, '#angry', '#disgusting', -0.639, 'obstinate', 'ask_for_it', 'ask_for_trouble', 'preserve', 'plug']
senticnet['hang_on'] = [-0.979, 0, 0.988, -0.504, '#sad', '#angry', -0.824, 'persevere', 'hang_in', 'persist', 'ask_for_it', 'hold_on']
senticnet['hang_onto'] = [0, 0.065, 0, 0.115, '#interesting', '#admirable', 0.06, 'beep', 'pluck_string', 'strum', 'sound_loud', 'compose_music']
senticnet['hang_out'] = [0, 0.075, 0.028, 0.173, '#interesting', '#admirable', 0.073, 'friend', 'spend_time_with_friend', 'party', 'fun', 'hang_out_with_friend']
senticnet['hang_out_with_friend'] = [0, 0.075, 0.028, 0.173, '#interesting', '#admirable', 0.073, 'friend', 'spend_time_with_friend', 'party', 'fun', 'hang_out']
senticnet['hang_paint'] = [0, 0.075, 0.028, 0.173, '#interesting', '#admirable', 0.073, 'hang_picture', 'hang_picture_to_wall', 'hang_frame', 'hang_flower', 'hang_up']
senticnet['hang_picture'] = [-0.117, 0, 0, 0, '#sad', '#sad', -0.039, 'enter_door', 'divide_country', 'turn_knob', 'shut_door', 'bicycle_store']
senticnet['hang_picture_on_wall'] = [0.925, 0.858, 0, 0, '#joyful', '#interesting', 0.594, 'welcome_friend', 'captain_boat', 'gather_berry', 'agree_disagree', 'laugh_oneself']
senticnet['hang_picture_to_wall'] = [0, 0.075, 0.028, 0.173, '#interesting', '#admirable', 0.073, 'hang_picture', 'hang_paint', 'hang_frame', 'hang_flower', 'hang_up']
senticnet['hang_up'] = [-0.964, 0, -0.771, 0, '#sad', '#scared', -0.578, 'end_conversation', 'sad', 'uncomfortable', 'stressed', 'commit_suicide']
senticnet['hang_up_clothes'] = [-0.045, -0.007, 0.031, -0.032, '#sad', '#disgusting', -0.034, 'organize_clothes', 'store_dress', 'keep_clothes', 'protective_cover', 'clothes']
senticnet['hang_up_towel'] = [0.035, 0.081, 0, 0, '#joyful', '#interesting', 0.039, 'become_aroused', 'contraception', 'safe_sex', 'sex', 'fuck']
senticnet['hang_wall'] = [0.071, 0.127, 0, 0.197, '#interesting', '#admirable', 0.132, 'place_work', 'workplace', 'office', 'work', 'beside']
senticnet['hangar'] = [-0.045, 0.092, 0, 0.062, '#interesting', '#admirable', 0.036, 'hanger', 'atmosphere', 'air', 'aircraft_carrier', 'umbrella']
senticnet['hangdog'] = [-0.733, 0.301, -0.439, -0.061, '#sad', '#scared', -0.311, 'shamed', 'miserably', 'suffering', 'misfortunate', 'pitiful']
senticnet['hanger'] = [0, 0.778, 0, 0.788, '#interesting', '#admirable', 0.522, 'clothes_hanger', 'hang_up_clothes', 'hang_clothes', 'storage_space', 'laundry']
senticnet['hangers'] = [0.069, 0.112, 0, 0.167, '#interesting', '#admirable', 0.116, 'cupboard', 'clothes_shelf', 'compartment', 'jeans', 'drawers']
senticnet['hangout'] = [0.165, -0.071, 0.033, 0, '#joyful', '#surprising', 0.068, 'metal_stick', 'drinking_place', 'bart', 'meet_place', 'water_hole']
senticnet['hangover'] = [0, -0.044, -0.081, -0.272, '#scared', '#disgusting', -0.103, 'forgetfulness', 'slur_word', 'throw_up', 'blackout', 'drunkenness']
senticnet['hangry'] = [0, 0, 0.883, -0.767, '#angry', '#disgusting', -0.55, 'become_hungry', 'a_little_hungry', 'become_little_hungry', 'angry', 'need_food']
senticnet['hank'] = [0, -0.029, 0.062, -0.107, '#angry', '#disgusting', -0.047, 'louse', 'muzzle', 'flea', 'nip', 'mosquito']
senticnet['hank_panky'] = [0.947, -0.811, 0, 0.656, '#joyful', '#surprising', 0.805, 'sexual_intercourse', 'intercourse', 'sex_act', 'copulation', 'coitus']
senticnet['hankie'] = [0.057, 0.111, 0, 0.143, '#interesting', '#admirable', 0.104, 'facial_tissue', 'kleenex', 'hanky', 'handkerchief', 'tissue']
senticnet['hanky'] = [0.057, 0.111, 0, 0.143, '#interesting', '#admirable', 0.104, 'hankie', 'kleenex', 'facial_tissue', 'handkerchief', 'tissue']
senticnet['hap'] = [-0.912, 0, 0.769, -0.841, '#sad', '#disgusting', -0.841, 'break', 'good_luck', 'chance_eventpy_chance', 'chance_event', 'coincidence']
senticnet['haphazardness'] = [-0.897, 0, 0.972, -0.502, '#sad', '#angry', -0.79, 'unsteadiness', 'unregularity', 'stochasticity', 'variability', 'fitfulness']
senticnet['hapless'] = [-0.727, 0.304, -0.418, -0.073, '#sad', '#scared', -0.305, 'suffering', 'miserably', 'pitiable', 'piteous', 'pitiful']
senticnet['happen'] = [0.774, 0, 0, 0.873, '#joyful', '#admirable', 0.549, 'special_time', 'occasion', 'event', 'incident', 'occurrence']
senticnet['happen_anyone'] = [-0.758, 0, -0.783, 0, '#sad', '#scared', -0.514, 'cause_injury', 'stab', 'hurt_person', 'happen_quickly', 'destroy']
senticnet['happen_now'] = [-0.825, 0, -0.831, 0, '#sad', '#scared', -0.552, 'relevant', 'up_date', 'latest', 'sea_movement', 'contemporary']
senticnet['happen_quickly'] = [-0.771, 0, -0.965, 0, '#sad', '#scared', -0.579, 'stab', 'cause_injury', 'parry', 'kill_life', 'elephant_sit_chest']
senticnet['happening'] = [-0.737, 0, 0.591, -0.681, '#sad', '#disgusting', -0.67, 'whammy', 'setback', 'occurrence', 'occurrent', 'natural_event']
senticnet['happily'] = [0.653, 0.635, -0.244, 0.294, '#joyful', '#interesting', 0.446, 'merrily', 'jubilantly', 'mirthfully', 'gayly', 'blithely']
senticnet['happiness'] = [0.868, 0, 0, 0, '#joyful', '#joyful', 0.289, 'good_feeling', 'gain_respect', 'appreciate', 'foreplay', 'feel_good']
senticnet['happy'] = [0.894, 0, 0, 0, '#joyful', '#joyful', 0.298, 'happiness', 'good_feeling', 'happy_feeling', 'joy', 'good_emotion']
senticnet['happy-go-lucky'] = [0, 0, -0.938, -0.932, '#scared', '#disgusting', -0.623, 'carefree', 'freewheeling', 'slaphappy', 'harum-scarum', 'devil-may-care']
senticnet['happy_chance'] = [-0.912, 0, 0.769, -0.841, '#sad', '#disgusting', -0.841, 'break', 'good_luck', 'chance_event', 'hap', 'coincidence']
senticnet['happy_child'] = [0.839, 0, 0, 0, '#joyful', '#joyful', 0.28, 'a_lot_of_fun', 'fun_play', 'enjoyable_activity', 'enjoyable', 'sanity']
senticnet['happy_emotion'] = [0.77, 0.838, 0, 0.714, '#joyful', '#interesting', 0.774, 'pleasant_emotion', 'happy_feeling', 'good_emotion', 'good_feeling', 'ecstatic']
senticnet['happy_event'] = [0.13, 0, 0.023, 0.118, '#joyful', '#admirable', 0.075, 'happy_occasion', 'sunday', 'religious_event', 'ceremony', 'celebration']
senticnet['happy_family'] = [0.937, 0.878, 0, 0.738, '#joyful', '#interesting', 0.851, 'strong_relationship', 'good_fortune', 'love_parent', 'spice_life', 'world_peace']
senticnet['happy_feeling'] = [0.712, 0.97, 0, 0.778, '#interesting', '#admirable', 0.82, 'happy_emotion', 'pleasant_emotion', 'happiness', 'happy', 'good_emotion']
senticnet['happy_life'] = [0, 0.718, 0, 0.871, '#interesting', '#admirable', 0.53, 'retirement', 'plan', 'plan_retirement', 'free_time', 'hobby']
senticnet['happy_moment'] = [0.161, 0.155, -0.081, 0.223, '#joyful', '#admirable', 0.153, 'family', 'family_reunion', 'aunt_uncle', 'brother_sister', 'relation']
senticnet['happy_occasion'] = [0.706, 0.825, 0, 0.847, '#interesting', '#admirable', 0.793, 'happy_event', 'gala', 'christmas_time', 'special_moment', 'social_occasion']
senticnet['happy_person'] = [0.739, 0.967, 0, 0.95, '#interesting', '#admirable', 0.885, 'make_someone_happy', 'comedian', 'make_oneself_feel_better', 'spread_happiness', 'release_tension']
senticnet['happy_time'] = [0.722, 0.902, 0, 0.759, '#interesting', '#admirable', 0.794, 'happiness', 'special_occasion', 'annual_celebration', 'new_relationship', 'party_time']
senticnet['happy_together'] = [0.044, 0.142, -0.079, 0.084, '#interesting', '#admirable', 0.064, 'many_people', 'relate_person', 'human_group', 'double_happiness', 'parent_child']
senticnet['haptic'] = [0.026, 0.14, -0.136, 0.31, '#interesting', '#admirable', 0.113, 'teach_new', 'share_idea', 'gesture', 'start_talk', 'exchange_idea']
senticnet['haptic_sensation'] = [-0.692, 0, 0.516, -0.961, '#sad', '#disgusting', -0.723, 'itch', 'urtication', 'itchiness', 'itching', 'tickle']
senticnet['harangue'] = [-0.912, 0, 0.704, -0.702, '#sad', '#angry', -0.773, 'rant', 'raving', 'declamation', 'ranting', 'tirade']
senticnet['harass'] = [-0.593, 0.162, 0.221, -0.503, '#sad', '#disgusting', -0.385, 'annoy', 'provoke', 'beset', 'molest', 'chivvy']
senticnet['harassed'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['harassment'] = [-0.211, 0.069, 0.654, -0.671, '#angry', '#disgusting', -0.489, 'torment', 'plaguy', 'pissed', 'irritated', 'miffed']
senticnet['harbingers'] = [0, 0, -0.773, -0.981, '#scared', '#disgusting', -0.585, 'forerunner', 'announce', 'precursor', 'predecessor', 'herald']
senticnet['harbor'] = [0, 0, 0.027, -0.047, '#angry', '#disgusting', -0.025, 'port', 'sea', 'boat', 'ocean', 'ship']
senticnet['hard'] = [-0.818, 0, 0, 0, '#sad', '#sad', -0.273, 'difficult', 'tough', 'arduous', 'hard_work', 'hard_day_at_work']
senticnet['hard_cheese'] = [-0.693, 0, 0.957, -0.865, '#angry', '#disgusting', -0.838, 'ill_luck', 'weakness', 'gutter', 'adversity', 'hardship']
senticnet['hard_day_at_work'] = [-0.818, 0, 0, 0, '#sad', '#sad', -0.273, 'get_tired', 'sore_knee', 'sleep_pill', 'tired', 'tiredness']
senticnet['hard_drink'] = [0.679, -0.512, 0, 0.502, '#joyful', '#surprising', 0.564, 'liquor', 'spirits', 'booze', 'firewater', 'hard_liquor']
senticnet['hard_drive'] = [0, 0.084, 0.027, 0.095, '#interesting', '#admirable', 0.051, 'efficient', 'computer_program', 'browser', 'telephone_computer', 'internet_connection']
senticnet['hard_find'] = [0.172, 0.236, -0.135, 0.287, '#interesting', '#admirable', 0.187, 'good', 'niceness', 'similar', 'worse', 'nice']
senticnet['hard_hit'] = [-0.025, -0.042, 0.045, -0.071, '#angry', '#disgusting', -0.033, 'hit', 'push_wind', 'stab', 'cool_air', 'exhalation']
senticnet['hard_knocks'] = [-0.962, 0, 0.768, -0.524, '#sad', '#angry', -0.751, 'distress', 'affliction', 'catastrophe', 'misfortune', 'bad_luck']
senticnet['hard_life'] = [-0.069, 0, 0, 0, '#sad', '#sad', -0.023, 'dig_ground', 'hard_work', 'work_hard', 'find_job', 'job']
senticnet['hard_liquor'] = [0.679, -0.512, 0, 0.502, '#joyful', '#surprising', 0.564, 'liquor', 'spirits', 'booze', 'hard_drink', 'firewater']
senticnet['hard_material'] = [0, 0.769, 0, 0.767, '#interesting', '#admirable', 0.512, 'hard_rock', 'hard_mineral', 'hard_plastic', 'solid_room_temperature', 'hard']
senticnet['hard_mineral'] = [0, 0.92, 0, 0.711, '#interesting', '#admirable', 0.544, 'hard_rock', 'hard_material', 'hard_plastic', 'solid_room_temperature', 'magnetic']
senticnet['hard_paper'] = [0, 0, 0, 0.16, '#admirable', '#admirable', 0.053, 'use_school', 'game_piece', 'flat_thin', 'game_part', 'porous']
senticnet['hard_plastic'] = [0.781, 0, 0, 0.949, '#joyful', '#admirable', 0.577, 'use_jewelry', 'tin', 'magnetic', 'solid_room_temperature', 'strong_material']
senticnet['hard_rock'] = [0, 0, 0.03, -0.128, '#angry', '#disgusting', -0.053, 'hard_material', 'hard_mineral', 'hard', 'construction_vehicle', 'sturdy']
senticnet['hard_roe'] = [-0.527, 0, 0.748, -0.926, '#angry', '#disgusting', -0.734, 'coral', 'caviar', 'caviare', 'shad_roe', 'seafood']
senticnet['hard_see'] = [0, 0, -0.739, -0.792, '#scared', '#disgusting', -0.51, 'dizzy', 'rain_fall', 'dew', 'rain', 'mist']
senticnet['hard_substance'] = [0.046, 0, 0.04, 0.109, '#joyful', '#admirable', 0.038, 'magnetic', 'heavy', 'dense', 'hard_mineral', 'hard_rock']
senticnet['hard_surface'] = [0, 0, 0.095, 0, '#angry', '#angry', -0.032, 'build_part', 'flat', 'stair', 'large_rock', 'inanimate_object']
senticnet['hard_to_define'] = [-0.607, 0.202, -0.576, 0.268, '#sad', '#scared', -0.238, 'inherit', 'harmful_human', 'bad', 'difficult', 'bad_choice']
senticnet['hard_to_please'] = [-0.73, 0.288, -0.367, -0.108, '#sad', '#scared', -0.306, 'fastidious', 'fussy', 'anxiety', 'concerned', 'pester']
senticnet['hard_to_understand'] = [0, 0, 0.837, -0.87, '#angry', '#disgusting', -0.569, 'difficult', 'problematic', 'difficult_concept', 'tough', 'hard']
senticnet['hard_use'] = [0.094, -0.042, 0.031, 0.149, '#joyful', '#admirable', 0.085, 'easy_use', 'power_electricity', 'just_fun', 'dangerous_drive', 'fun_play']
senticnet['hard_work'] = [-0.069, 0, 0, 0, '#sad', '#sad', -0.023, 'dig_ground', 'hard_life', 'work_hard', 'find_job', 'job']
senticnet['hard_worker'] = [0.134, 0.1, -0.112, 0.246, '#joyful', '#admirable', 0.123, 'apprentice', 'pupil', 'student', 'serious_student', 'much_information']
senticnet['hardcore'] = [0.501, -0.996, 0, 0.68, '#surprising', '#admirable', 0.726, 'stated', 'explicit', 'declared', 'definitive', 'graphic']
senticnet['harden_criminal'] = [-0.094, 0, -0.183, -0.106, '#scared', '#disgusting', -0.128, 'revenge', 'death_sentence', 'murderer', 'get_revenge', 'criminal']
senticnet['hardening'] = [-0.643, 0, 0.938, -0.521, '#sad', '#angry', -0.701, 'extinction', 'adiabatic_process', 'natural_action', 'decay', 'absorption']
senticnet['hardhat'] = [0, 0, -0.891, -0.749, '#scared', '#disgusting', -0.547, 'tangerine', 'fire_engine', 'cranberry', 'apple', 'plum']
senticnet['hardheaded'] = [-0.505, 0, 0.625, -0.84, '#angry', '#disgusting', -0.657, 'earthy', 'realistic', 'real', 'practical', 'graphic']
senticnet['hardhearted'] = [-0.701, 0, 0, -0.764, '#sad', '#disgusting', -0.488, 'hardheartedness', 'coldheartedness', 'heartlessly', 'heartlessness', 'heartless']
senticnet['hardheartedness'] = [-0.817, 0, 0, -0.888, '#sad', '#disgusting', -0.568, 'coldheartedness', 'heartlessly', 'heartlessness', 'heartless', 'hardhearted']
senticnet['hardihood'] = [0.904, -0.745, 0, 0.605, '#joyful', '#surprising', 0.751, 'daredevilry', 'daredeviltry', 'temerity', 'audacity', 'audaciousness']
senticnet['hardness'] = [-0.676, 0, 0.863, -0.862, '#angry', '#disgusting', -0.8, 'incompressibility', 'substance', 'firmness', 'consistency', 'consistence']
senticnet['hardscrabble'] = [-0.551, 0, 0.912, -0.654, '#angry', '#disgusting', -0.706, 'meager', 'meagre', 'meagerly', 'scrimpy', 'stingy']
senticnet['hardship'] = [-0.952, 0, 0, 0, '#sad', '#sad', -0.317, 'obligation', 'cause_problem', 'toil', 'responsibility', 'stress']
senticnet['hardware'] = [0.024, 0.108, 0, 0.144, '#interesting', '#admirable', 0.092, 'make_out_metal', 'door_opener', 'both_functional_decorative', 'mix_metal', 'ore']
senticnet['hardware_shop'] = [0.048, 0.19, -0.061, 0.077, '#interesting', '#admirable', 0.085, 'circular_route', 'city_hall', 'walking_stick', 'other_half_marriage', 'crutch']
senticnet['hardware_store'] = [0.831, 0.793, 0, 0, '#joyful', '#interesting', 0.541, 'tool_shed', 'tool', 'garage', 'tool_belt', 'toolbox']
senticnet['hardwood'] = [-0.066, -0.035, 0.046, 0, '#sad', '#angry', -0.026, 'wood_board', 'plank', 'build_ground', 'wooden_board', 'cover_ground']
senticnet['hardwood_floor'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'floor', 'wood', 'hardwood', 'precious_floor', 'fancy_house']
senticnet['hardy'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'intrepidly', 'fearlessness', 'fearlessly', 'unafraid', 'unfearing']
senticnet['hare'] = [0, 0.099, -0.052, 0.113, '#interesting', '#admirable', 0.053, 'make_throw_up', 'blind', 'big_rat', 'grizzly', 'cause_headache']
senticnet['harlequinade'] = [0.628, -0.94, 0, 0.731, '#surprising', '#admirable', 0.766, 'folly', 'lunacy', 'craziness', 'indulgence', 'shtik']
senticnet['harlot'] = [-0.648, 0, 0.665, -0.784, '#angry', '#disgusting', -0.699, 'slattern', 'camp_follower', 'call_girl', 'comfort_woman', 'ianfu']
senticnet['harm'] = [0, 0, 0.937, -0.761, '#angry', '#disgusting', -0.566, 'damage', 'hurt', 'cut_skin', 'ouch', 'ache']
senticnet['harmful'] = [-0.104, 0, -0.169, -0.092, '#sad', '#scared', -0.122, 'hazardous', 'deadly', 'toxic', 'bad_health', 'threat']
senticnet['harmful_human'] = [-0.619, 0.113, -0.573, 0.162, '#sad', '#scared', -0.306, 'bad', 'inherit', 'hard_to_define', 'bad_health', 'treatable']
senticnet['harmfulness'] = [-0.721, 0, 0.71, -0.9, '#sad', '#disgusting', -0.777, 'perniciousness', 'unwholesomeness', 'toxicity', 'noisomeness', 'noxiousness']
senticnet['harmonical'] = [0.826, -0.719, 0, 0.913, '#joyful', '#admirable', 0.819, 'true', 'pure', 'symphonious', 'harmonious', 'harmonized']
senticnet['harmonious'] = [0.826, -0.719, 0, 0.913, '#joyful', '#admirable', 0.819, 'true', 'pure', 'symphonious', 'harmonical', 'harmonized']
senticnet['harmonize'] = [0.711, -0.925, 0, 0.951, '#surprising', '#admirable', 0.862, 'check', 'music', 'match', 'correspond', 'jibe']
senticnet['harmonized'] = [0.826, -0.719, 0, 0.913, '#joyful', '#admirable', 0.819, 'true', 'pure', 'symphonious', 'harmonical', 'harmonious']
senticnet['harmony'] = [0.852, 0.907, 0, 0.805, '#joyful', '#interesting', 0.855, 'tune', 'melody', 'lyric', 'written_music', 'music']
senticnet['harpoon'] = [0, 0, -0.984, -0.784, '#scared', '#disgusting', -0.589, 'armory', 'tank', 'hydrogen_bomb', 'rifle', 'use_hunt']
senticnet['harridan'] = [-0.718, 0, 0.972, -0.625, '#sad', '#angry', -0.772, 'scold', 'nag', 'scolder', 'nagger', 'common_scold']
senticnet['harried'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['harry'] = [-0.615, 0, 0.518, -0.934, '#sad', '#disgusting', -0.689, 'torment', 'nettle', 'bedevil', 'bother', 'devil']
senticnet['harsh'] = [0.858, -0.817, 0, 0, '#joyful', '#surprising', 0.558, 'granulate', 'grainy', 'fine_grain', 'food_flavor', 'white_grain']
senticnet['harshness'] = [-0.9, 0, 0.841, -0.731, '#sad', '#angry', -0.824, 'nubbiness', 'tweediness', 'raggedness', 'graininess', 'granularity']
senticnet['harvest'] = [0, 0.072, 0, 0.074, '#interesting', '#admirable', 0.049, 'food_production', 'grow_food', 'grow_crop', 'grow_stuff', 'cultivation']
senticnet['harvest_fall'] = [0.884, 0, 0, 0.914, '#joyful', '#admirable', 0.599, 'find_mall', 'fall', 'require_good_health', 'eaten', 'grown_soil']
senticnet['harvest_food'] = [0, 0.105, 0, 0.1, '#interesting', '#admirable', 0.068, 'agricultural', 'grow_food', 'cultivation', 'grow_stuff', 'grow_crop']
senticnet['harvest_mouse'] = [-0.55, 0, 0.955, -0.96, '#angry', '#disgusting', -0.822, 'house_mouse', 'mouse', 'field_mouse', 'fieldmouse', 'nude_mouse']
senticnet['hash'] = [0.022, -0.134, 0.153, -0.314, '#angry', '#disgusting', -0.104, 'codeine', 'morphine', 'infection', 'cocaine', 'nuclear_war']
senticnet['hassle'] = [-0.593, 0.162, 0.221, -0.503, '#sad', '#disgusting', -0.385, 'annoy', 'harass', 'provoke', 'beset', 'chivvy']
senticnet['hastate_leaf'] = [-0.666, 0, 0.971, -0.753, '#angry', '#disgusting', -0.797, 'lyrate_leaf', 'needle', 'elliptic_leaf', 'simple_leaf', 'obovate_leaf']
senticnet['haste'] = [0.03, 0.104, 0, 0.149, '#interesting', '#admirable', 0.094, 'swift', 'quick', 'rapid', 'fast', 'quickness']
senticnet['hasten'] = [-0.978, 0, 0.504, -0.52, '#sad', '#disgusting', -0.667, 'rush', 'race', 'hotfoot', 'push_forward', 'hie']
senticnet['hastiness'] = [-0.566, 0, 0.828, -0.689, '#angry', '#disgusting', -0.694, 'abruptness', 'precipitateness', 'precipitousness', 'precipitance', 'precipitancy']
senticnet['hat'] = [0.08, 0.106, -0.048, 0.112, '#interesting', '#admirable', 0.083, 'helmet', 'head_gear', 'worn_head', 'head_wear', 'head_protection']
senticnet['hat_shop'] = [0, 0, 0.821, -0.717, '#angry', '#disgusting', -0.513, 'furniture_shop', 'chest', 'nervous_system', 'crotch', 'skeleton']
senticnet['hatband'] = [0.942, -0.61, 0, 0.908, '#joyful', '#admirable', 0.82, 'adornment', 'cigar_band', 'stripe', 'neckband', 'pinstripe']
senticnet['hatch'] = [0, -0.06, 0.022, 0.054, '#surprising', '#admirable', 0.031, 'chick', 'wild_bird', 'baby_bird', 'lay_egg', 'bird_home']
senticnet['hatchet'] = [0, 0, -0.819, -0.749, '#scared', '#disgusting', -0.523, 'knife', 'sword', 'sharp_weapon', 'angle_grinder', 'bayonet']
senticnet['hatchet_job'] = [-0.622, 0, 0.698, -0.814, '#angry', '#disgusting', -0.711, 'malignment', 'vilification', 'smear', 'character_assassination', 'libel']
senticnet['hatching'] = [-0.912, 0, 0.796, -0.872, '#sad', '#disgusting', -0.86, 'hatch', 'shading', 'crosshatch', 'hachure', 'marking']
senticnet['hate'] = [-0.714, 0, 0.83, -0.962, '#angry', '#disgusting', -0.835, 'angry', 'mad', 'hatred', 'anger', 'resentment']
senticnet['hate_boss'] = [-0.103, -0.013, 0, -0.177, '#sad', '#disgusting', -0.089, 'stress', 'quit_job', 'much_work', 'hate_colleague', 'need_holiday']
senticnet['hate_colleague'] = [-0.103, -0.013, 0, -0.177, '#sad', '#disgusting', -0.089, 'stress', 'quit_job', 'hate_boss', 'much_work', 'need_holiday']
senticnet['hate_somebody'] = [-0.943, 0, 0.866, -0.929, '#sad', '#disgusting', -0.913, 'think_too_much', 'anxiety', 'mull_over', 'bad_feeling', 'bad_memory']
senticnet['hateful'] = [-0.092, 0.213, 0.596, -0.619, '#angry', '#disgusting', -0.365, 'hatefully', 'detest', 'misanthropy', 'misopedia', 'misology']
senticnet['hatefully'] = [-0.092, 0.213, 0.596, -0.619, '#angry', '#disgusting', -0.365, 'hateful', 'detest', 'misanthropy', 'misopedia', 'misology']
senticnet['hater'] = [-0.559, 0, 0.689, -0.806, '#angry', '#disgusting', -0.685, 'abominator', 'loather', 'mortal', 'anglophobe', 'person']
senticnet['hatred'] = [-0.125, 0.121, 0.446, -0.652, '#angry', '#disgusting', -0.367, 'hate', 'rage', 'aggression', 'evil', 'mad']
senticnet['haughtiness'] = [0.968, -0.88, 0, 0.831, '#joyful', '#surprising', 0.893, 'superiority', 'pride', 'superbia', 'imperiousness', 'domineeringness']
senticnet['haul'] = [0, 0.175, -0.11, 0.281, '#interesting', '#admirable', 0.115, 'move', 'carry', 'spring_leak', 'carry_belongings', 'move_object']
senticnet['hauler'] = [0.665, -0.649, 0, 0.871, '#joyful', '#admirable', 0.728, 'garbage_man', 'garbageman', 'garbage_collector', 'garbage_carter', 'garbage_hauler']
senticnet['haulier'] = [0.865, -0.805, 0, 0.871, '#joyful', '#admirable', 0.847, 'garbage_man', 'garbageman', 'garbage_collector', 'garbage_carter', 'garbage_hauler']
senticnet['haunch'] = [0.023, 0.085, -0.045, 0.088, '#interesting', '#admirable', 0.05, 'thigh', 'hip', 'joint', 'above_leg', 'knee']
senticnet['haunt_house'] = [0.105, 0.073, 0, 0, '#joyful', '#interesting', 0.059, 'tavern', 'nightclub', 'rum', 'brandy', 'scotch']
senticnet['haunting'] = [0, -0.862, 0, 0.987, '#surprising', '#admirable', 0.616, 'ghost', 'stalk', 'obsess', 'frequent', 'persistent']
senticnet['hauteur'] = [0.828, -0.887, 0, 0.551, '#joyful', '#surprising', 0.755, 'superiority', 'pride', 'superbia', 'imperiousness', 'domineeringness']
senticnet['have'] = [0.702, -0.65, 0, 0.788, '#joyful', '#admirable', 0.713, 'bonk', 'pair', 'take', 'couple', 'fornicate']
senticnet['have_accident'] = [-0.952, 0, 0.046, -0.978, '#sad', '#disgusting', -0.659, 'fall_down', 'lose_consciousness', 'car_accident', 'motorbike_accident', 'accident']
senticnet['have_baby'] = [0.1, 0.216, -0.185, 0.22, '#interesting', '#admirable', 0.117, 'maternity', 'birth', 'become_mom', 'hospital', 'maternity_ward']
senticnet['have_best'] = [-0.671, 0, 0.879, -0.519, '#sad', '#angry', -0.69, 'crush', 'trounce', 'beat', 'beat_out', 'vanquish']
senticnet['have_breakfast'] = [0.96, 0.79, 0, 0, '#joyful', '#interesting', 0.583, 'awake', 'get_up_early', 'drink_coffee', 'drink_milk', 'wake_up']
senticnet['have_epilepsy'] = [-0.97, 0, 0.332, -0.999, '#sad', '#disgusting', -0.767, 'epilepsy_attack', 'crowd', 'humanity', 'epilepsy', 'sickness']
senticnet['have_fun'] = [0.056, -0.019, 0.036, 0.073, '#joyful', '#admirable', 0.037, 'thrill_ride', 'amusement_park', 'drag_race', 'enjoyment', 'roller_coaster']
senticnet['have_fun_together'] = [0.755, 0.702, 0, 0, '#joyful', '#interesting', 0.486, 'explore_underwater', 'pool_party', 'pool', 'swim', 'go_underwater']
senticnet['have_go_at_it'] = [0.905, -0.65, 0, 0.899, '#joyful', '#admirable', 0.818, 'have', 'pair', 'take', 'couple', 'fornicate']
senticnet['have_good_carrier'] = [0.936, 0.749, 0, 0.871, '#joyful', '#admirable', 0.852, 'get_married', 'finish_college', 'have_good_job', 'make_parent_happy', 'support_family']
senticnet['have_good_job'] = [0.936, 0.749, 0, 0.871, '#joyful', '#admirable', 0.852, 'get_married', 'finish_college', 'make_parent_happy', 'have_good_carrier', 'support_family']
senticnet['have_got'] = [0.853, -0.504, 0, 0.708, '#joyful', '#admirable', 0.688, 'hold', 'stockpile', 'hold_on', 'stock', 'bear']
senticnet['have_intercourse'] = [0.563, -0.974, 0, 0.607, '#surprising', '#admirable', 0.715, 'have', 'pair', 'take', 'couple', 'fornicate']
senticnet['have_it_away'] = [0.696, -0.645, 0, 0.582, '#joyful', '#surprising', 0.641, 'have', 'pair', 'take', 'couple', 'fornicate']
senticnet['have_it_off'] = [0.709, -0.572, 0, 0.532, '#joyful', '#surprising', 0.604, 'have', 'pair', 'take', 'couple', 'fornicate']
senticnet['have_much'] = [-0.054, 0.102, 0, 0.167, '#interesting', '#admirable', 0.072, 'orphan', 'take_child', 'youth', 'become_parent', 'progeny']
senticnet['have_problem'] = [-0.96, 0, 0.88, -0.949, '#sad', '#disgusting', -0.93, 'problem', 'trouble', 'unwanted_outcome', 'exam_failed', 'job_interview_failed']
senticnet['have_sex'] = [0.892, -0.856, 0, 0.575, '#joyful', '#surprising', 0.774, 'have', 'pair', 'take', 'couple', 'fornicate']
senticnet['have_some'] = [-0.069, -0.009, 0.049, 0, '#sad', '#angry', -0.036, 'buy_shirt', 'pay_cash', 'buy_product', 'purchase_gift', 'buy_clothes']
senticnet['have_something'] = [0.062, 0.229, -0.066, 0.26, '#interesting', '#admirable', 0.162, 'own', 'ownership', 'possess', 'possession', 'goods']
senticnet['have_something_to_do'] = [0, -0.045, 0.053, -0.086, '#angry', '#disgusting', -0.031, 'keep_job', 'make_connection', 'career_advancement', 'make_money', 'responsible']
senticnet['have_weapon'] = [-0.922, 0, 0.162, -0.933, '#sad', '#disgusting', -0.672, 'kill', 'kill_person', 'fight_war', 'war', 'weapon']
senticnet['have_words'] = [-0.996, 0, 0.658, -0.889, '#sad', '#disgusting', -0.848, 'castigate', 'tell_off', 'brush_down', 'chasten', 'objurgate']
senticnet['hawk'] = [-0.81, 0, 0.913, -0.858, '#angry', '#disgusting', -0.86, 'bird', 'bird_of_prey', 'eagle', 'vulture', 'secretary_bird']
senticnet['hawker'] = [-0.774, 0, 0.874, -0.803, '#angry', '#disgusting', -0.817, 'peddler', 'pedlar', 'packman', 'cheapjack', 'pitchman']
senticnet['hawkishness'] = [0.729, -0.561, 0, 0.785, '#joyful', '#admirable', 0.692, 'ideology', 'militarism', 'warmongering', 'war_advocacy', 'political_orientation']
senticnet['hay_fever'] = [-0.606, 0, 0.931, -0.922, '#angry', '#disgusting', -0.82, 'rhinitis', 'coryza', 'allergic_rhinitis', 'pollinosis', 'hypersensitivity_reaction']
senticnet['hayseed'] = [-0.967, 0, 0.924, -0.865, '#sad', '#angry', -0.919, 'redneck', 'yokel', 'rube', 'hick', 'rustic']
senticnet['haywire'] = [-0.732, 0, 0.787, -0.662, '#sad', '#angry', -0.727, 'wrong', 'malfunctioning', 'bad', 'out_of_whack', 'amiss']
senticnet['hazard'] = [-0.219, 0, -0.268, -0.028, '#sad', '#scared', -0.172, 'unsafe', 'danger', 'big_monster', 'caution', 'menace']
senticnet['hazardous'] = [0, 0, -0.84, -0.878, '#scared', '#disgusting', -0.573, 'deadly', 'threat', 'bad_health', 'unsafe', 'violent']
senticnet['hazardous_health'] = [-0.325, 0.158, -0.365, 0.189, '#sad', '#scared', -0.114, 'dangerous_health', 'bad_health', 'uncontrollable', 'harmful_human', 'unhealthy']
senticnet['haze'] = [0, 0, -0.073, 0, '#scared', '#scared', -0.024, 'vapor', 'gaseous', 'bad_habit', 'smoke', 'smog']
senticnet['hazy'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'blurry', 'blur', 'bleary', 'blurred', 'foggy']
senticnet['head'] = [-0.801, 0, 0.522, -0.83, '#sad', '#disgusting', -0.718, 'administrator', 'executive', 'executive_director', 'chief', 'academic_administrator']
senticnet['head_ball'] = [-0.075, 0, 0.07, 0, '#sad', '#angry', -0.048, 'no_sight', 'part_of_face', 'face_feature', 'ball', 'facial_organ']
senticnet['head_class'] = [-0.123, 0, -0.052, -0.127, '#sad', '#disgusting', -0.101, 'detention', 'conduct_experiment', 'crowd_room', 'seat_chair', 'ledge']
senticnet['head_committee'] = [-0.735, 0, 0, -0.823, '#sad', '#disgusting', -0.519, 'state_fact', 'lower_expectation', 'file_complaint', 'reply_question', 'oversee']
senticnet['head_corporation'] = [0, 0.906, 0, 0.864, '#interesting', '#admirable', 0.59, 'govern_nation', 'date_man', 'chair_meet', 'captain_ship', 'voice_concern']
senticnet['head_cover'] = [0.152, 0, 0.046, 0.128, '#joyful', '#admirable', 0.078, 'head_wear', 'head_gear', 'headdress', 'formal', 'cap']
senticnet['head_gear'] = [0.119, 0.082, 0, 0.141, '#joyful', '#admirable', 0.114, 'head_wear', 'headdress', 'head_cover', 'top_head', 'cap']
senticnet['head_guy'] = [0.041, 0.095, 0, 0, '#joyful', '#interesting', 0.045, 'leadership_position', 'navy_officer', 'head_person', 'police_rank', 'navy_leader']
senticnet['head_home'] = [0.788, 0.592, -0.207, 0.342, '#joyful', '#interesting', 0.505, 'follow_mother', 'home_sweet_home', 'go_back_home', 'home', 'family']
senticnet['head_honcho'] = [0.534, -0.692, 0, 0.724, '#surprising', '#admirable', 0.65, 'knocker', 'supremo', 'important_person', 'influential_person', 'personage']
senticnet['head_hurt'] = [-0.165, 0, 0, -0.236, '#sad', '#disgusting', -0.134, 'lifestyle_change', 'headache', 'mind_boggle', 'relieve_pain', 'tired_eye']
senticnet['head_injury'] = [-0.039, -0.008, -0.072, -0.18, '#scared', '#disgusting', -0.094, 'injury', 'get_hurt', 'bruise', 'lose_game', 'get_injured']
senticnet['head_lice'] = [-0.841, 0, 0.767, -0.996, '#sad', '#disgusting', -0.868, 'pediculosis_capitis', 'lousiness', 'pediculosis_corporis', 'pediculosis_pubis', 'crabs']
senticnet['head_organ'] = [0, 0.071, 0.014, 0.085, '#interesting', '#admirable', 0.047, 'head_person', 'part_of_face', 'facial_part', 'facial_organ', 'face_feature']
senticnet['head_person'] = [0.037, 0.097, 0, 0, '#joyful', '#interesting', 0.045, 'head_guy', 'navy_officer', 'navy_leader', 'police_rank', 'commander']
senticnet['head_protection'] = [0.08, 0.106, -0.048, 0.112, '#interesting', '#admirable', 0.083, 'helmet', 'head_gear', 'worn_head', 'head_wear', 'hat']
senticnet['head_shoulder'] = [0, 0, 0, -0.068, '#disgusting', '#disgusting', -0.023, 'body', 'nervous_system', 'normal_human_body', 'human_body', 'crotch']
senticnet['head_smut'] = [-0.935, 0, 0.699, -0.91, '#sad', '#disgusting', -0.848, 'onion_smut', 'smut_fungus', 'stinking_smut', 'flag_smut_fungus', 'covered_smut']
senticnet['head_start'] = [0.065, 0.073, 0, 0, '#joyful', '#interesting', 0.046, 'look_catalog', 'make_selection', 'good_credit', 'find_out_want', 'save_money']
senticnet['head_tail'] = [0, 0.172, 0.034, 0.151, '#interesting', '#admirable', 0.096, 'dense_water', 'smooth_surface', 'nickel', 'round_metal', 'shinny']
senticnet['head_wear'] = [0.123, 0.07, 0.015, 0.147, '#joyful', '#admirable', 0.108, 'head_gear', 'headdress', 'head_cover', 'top_head', 'blue_blood']
senticnet['headache'] = [-0.06, -0.034, 0.017, -0.259, '#sad', '#disgusting', -0.101, 'relieve_pain', 'lifestyle_change', 'eye_strain', 'move_eye', 'new_perspective']
senticnet['headdress'] = [0.084, 0.065, 0, 0.112, '#joyful', '#admirable', 0.087, 'head_gear', 'head_wear', 'kingly', 'head_cover', 'blue_blood']
senticnet['headgear'] = [-0.626, 0, 0.961, -0.544, '#sad', '#angry', -0.71, 'crown', 'diadem', 'tiara', 'headdress', 'jeweled_headdress']
senticnet['headhunter'] = [-0.73, 0, 0.734, -0.786, '#angry', '#disgusting', -0.75, 'primitive', 'barbarian', 'cannibal', 'anthropophagus', 'anthropophagite']
senticnet['headlight'] = [0, 0.81, 0, 0.92, '#interesting', '#admirable', 0.577, 'brake_pedal', 'fan_belt', 'emergency_brake', 'dynamo', 'air_vent']
senticnet['headline'] = [0, 0.835, 0, 0.931, '#interesting', '#admirable', 0.589, 'current_event', 'bulletin', 'paper_write', 'paper_page', 'many_pages']
senticnet['headlines'] = [0.088, -0.003, 0, 0, '#joyful', '#surprising', 0.03, 'look_up_information', 'news', 'find_newspaper', 'enter_contest', 'latest_news']
senticnet['headquarters'] = [0, 0.089, 0, 0, '#interesting', '#interesting', 0.03, 'legislature', 'state_head', 'own_flag', 'reign', 'department_head']
senticnet['headstone'] = [-0.904, 0, -0.909, 0, '#sad', '#scared', -0.604, 'burial_place', 'death_place', 'bury_dead', 'burial', 'coffin']
senticnet['headstrong'] = [-0.778, 0, 0.886, -0.584, '#sad', '#angry', -0.749, 'refractory', 'obstinate', 'recalcitrant', 'froward', 'disobedient']
senticnet['heady'] = [0.625, -0.88, 0, 0.782, '#surprising', '#admirable', 0.762, 'judicious', 'discreet', 'prudential', 'prudent', 'circumspect']
senticnet['heal'] = [0, 0.763, 0, 0.932, '#interesting', '#admirable', 0.565, 'alleviate', 'cure_illness', 'recovery', 'regenarate', 'cure']
senticnet['heal_disease'] = [0.911, 0, 0, 0, '#joyful', '#joyful', 0.304, 'treat_illness', 'heal', 'cure_illness', 'get_well', 'cure_disease']
senticnet['heal_injury'] = [0.296, 0.278, -0.145, 0.128, '#joyful', '#interesting', 0.186, 'rejuvenation', 'heal', 'regain_energy', 'feel_good', 'recuperate']
senticnet['heal_wind'] = [-0.067, 0, 0, -0.111, '#sad', '#disgusting', -0.059, 'wind', 'welt', 'cover_wind', 'gore', 'cover_wound']
senticnet['health'] = [0.953, 0.983, 0, 0, '#joyful', '#interesting', 0.645, 'long_life', 'keep_healthy', 'good_nutrition', 'healthy_live', 'maintain_health']
senticnet['health_benefit'] = [0.097, -0.097, 0.1, -0.162, '#angry', '#disgusting', -0.023, 'fun', 'lift_car', 'exercise_entertainment', 'get_out_of_house', 'get_fresh_air']
senticnet['health_care_provider'] = [0.654, -0.579, 0, 0.685, '#joyful', '#admirable', 0.639, 'pharmacologist', 'pharmaceutical_chemist', 'health_professional', 'primary_care_provider', 'druggist']
senticnet['health_food_store'] = [0, 0, 0.012, -0.063, '#angry', '#disgusting', -0.025, 'shop_arcade', 'large_supermarket', 'large_food_store', 'dime_store', 'vend_stand']
senticnet['health_hazard'] = [0.565, -0.766, 0, 0.982, '#surprising', '#admirable', 0.771, 'risk', 'hazard', 'jeopardy', 'endangerment', 'peril']
senticnet['health_improve'] = [0.783, -0.877, 0, 0, '#joyful', '#surprising', 0.553, 'extreme_elation', 'stare', 'heart_beat_fast', 'win_game', 'minor_injury']
senticnet['health_issue'] = [0, 0, -0.98, -0.978, '#scared', '#disgusting', -0.653, 'disease', 'heart_attack', 'worse', 'clinical_problem', 'obese']
senticnet['health_problem'] = [-0.775, 0, -0.786, -0.85, '#scared', '#disgusting', -0.804, 'feel_sick', 'ill_health', 'poor_health', 'feel_pain', 'addict']
senticnet['health_professional'] = [0.654, -0.579, 0, 0.685, '#joyful', '#admirable', 0.639, 'pharmacologist', 'pharmaceutical_chemist', 'druggist', 'primary_care_provider', 'health_care_provider']
senticnet['healthcare'] = [-0.128, 0, -0.126, -0.086, '#sad', '#scared', -0.113, 'hospital', 'check_up', 'check_doctor', 'check_pulse', 'check_blood_pressure']
senticnet['healthful'] = [0.854, 0, 0, 0.963, '#joyful', '#admirable', 0.606, 'healthy', 'make_healthy', 'feel_energized', 'social_activity', 'keep_body_healthy']
senticnet['healthiness'] = [0.939, -0.745, 0, 0.57, '#joyful', '#surprising', 0.751, 'haleness', 'wholeness', 'rosiness', 'health', 'vitality']
senticnet['healthy'] = [0.736, 0, 0, 0.802, '#joyful', '#admirable', 0.513, 'good_health', 'keep_body_healthy', 'long_life', 'keep_healthy', 'prolong_life']
senticnet['healthy_activity'] = [0, 0.079, 0, 0.21, '#interesting', '#admirable', 0.096, 'good_body', 'athletic_activity', 'push_up', 'go_jogging', 'vigorous_activity']
senticnet['healthy_drink'] = [0.045, 0, -0.052, -0.08, '#scared', '#disgusting', -0.029, 'diuretic', 'cola', 'popular_soda', 'beverage', 'soft_drink']
senticnet['healthy_eat'] = [0.07, 0.073, 0, 0.141, '#interesting', '#admirable', 0.095, 'eaten_raw', 'good_eat', 'delicious', 'tasty_good', 'tasty']
senticnet['healthy_environment'] = [0.928, 0, 0, 0.774, '#joyful', '#admirable', 0.567, 'long_happy_life', 'exercise_often', 'healthy_lifestyle', 'take_vitamin', 'eat_healthy']
senticnet['healthy_exercise'] = [0, 0.08, 0, 0.117, '#interesting', '#admirable', 0.066, 'exercise', 'aerobic_exercise', 'good_environment', 'make_strong', 'want_exercise']
senticnet['healthy_food'] = [0.716, 0.937, 0, 0, '#joyful', '#interesting', 0.551, 'plan', 'eat_potato_chip', 'intelligent', 'careful_plan', 'stuff_face']
senticnet['healthy_life'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'exercise', 'keep_fit', 'bicycle_riding', 'sport', 'bicycle']
senticnet['healthy_lifestyle'] = [0.97, 0, 0, 0.894, '#joyful', '#admirable', 0.621, 'stay_alive', 'healthy', 'get_oxygen', 'sustain_life', 'get_vitamin']
senticnet['healthy_live'] = [0.865, 0, 0, 0.74, '#joyful', '#admirable', 0.535, 'get_healthy', 'build_muscle', 'improve_self-image', 'increase_muscle_mass', 'stay_physically_fit']
senticnet['healthy_person'] = [0.052, 0, 0, 0.069, '#joyful', '#admirable', 0.04, 'philanthropist', 'nazi', 'man', 'pervert', 'compatriot']
senticnet['healthy_snack'] = [0.952, 0.89, 0, 0, '#joyful', '#interesting', 0.614, 'eat_apple', 'healthy_food', 'quick_snack', 'sate_hunger', 'eat_quickly']
senticnet['healty'] = [0.135, 0.065, 0, 0.082, '#joyful', '#admirable', 0.094, 'lose_weight', 'healthy_life', 'stay_fit', 'burn_calorie', 'go_to_gym']
senticnet['heap'] = [-0.441, -0.138, -0.08, -0.407, '#sad', '#disgusting', -0.263, 'disorder', 'untidy', 'mess', 'jumble', 'chaos']
senticnet['hear'] = [0, 0, 0, 0.097, '#admirable', '#admirable', 0.032, 'use_ear', 'audible', 'audio', 'ear_activity', 'ear_work']
senticnet['hear_bad_news'] = [-0.441, -0.138, -0.08, -0.407, '#sad', '#disgusting', -0.263, 'disrespect', 'lose_team', 'cause_suffer', 'suffer_fool', 'disability']
senticnet['hear_beautiful_music'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'like_music', 'classical_music', 'sound_beautiful', 'love_music', 'part_of_band']
senticnet['hear_crowd_go_mad'] = [0.026, -0.047, 0, 0, '#joyful', '#surprising', 0.024, 'hear_sing', 'see_band', 'see_beautiful_girl', 'attend_rock_concert', 'go_stage']
senticnet['hear_funny'] = [0, 0, -0.045, -0.095, '#scared', '#disgusting', -0.047, 'jitters', 'listen_joke', 'view_film', 'rewind', 'use_remote_control']
senticnet['hear_funny_joke'] = [0.832, 0.843, 0, 0, '#joyful', '#interesting', 0.558, 'tickle', 'express_how_funny', 'see_favorite_show', 'enjoy_film', 'see_beautiful_girl']
senticnet['hear_joke'] = [0.759, 0, 0, 0, '#joyful', '#joyful', 0.253, 'start_laugh', 'sense_of_humor', 'giggle', 'smile', 'smile_laugh']
senticnet['hear_live_music'] = [0.931, 0, 0, 0, '#joyful', '#joyful', 0.31, 'watch_parade', 'hear_music', 'earring', 'listen_music', 'enjoy_music']
senticnet['hear_loss'] = [-0.924, 0, 0, -0.767, '#sad', '#disgusting', -0.564, 'earring', 'enjoy_music', 'deafness', 'damage_ear', 'like']
senticnet['hear_loud_sound'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'deafening', 'roaring', 'ear_splitting', 'rowdy', 'noisy']
senticnet['hear_music'] = [0, 0.716, 0, 0.741, '#interesting', '#admirable', 0.486, 'make_music', 'compose_music', 'artist', 'make_drawing', 'art']
senticnet['hear_news'] = [0, -0.121, 0, 0, '#surprising', '#surprising', 0.04, 'read_news', 'read_letter', 'see_exhibit', 'see_artifact', 'see_art']
senticnet['hear_noise'] = [-0.041, 0.078, 0, 0.094, '#interesting', '#admirable', 0.044, 'hear_voice', 'detect', 'ear_activity', 'use_ear', 'vibration']
senticnet['hear_opinion'] = [0.383, 0.246, -0.108, 0.256, '#joyful', '#admirable', 0.259, 'acquire_information', 'information', 'stare', 'obtain', 'acquire']
senticnet['hear_sing'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'attend_rock_concert', 'see_band', 'see_beautiful_girl', 'hear_crowd_go_mad', 'go_stage']
senticnet['hear_song'] = [0.959, 0, 0, 0, '#joyful', '#joyful', 0.32, 'earring', 'tap_foot', 'sing_along', 'tap_toe', 'like']
senticnet['hear_sound'] = [0.708, 0, 0, 0, '#joyful', '#joyful', 0.236, 'shut_up', 'hear_voice', 'listen_news', 'stop_talk', 'ability_hear']
senticnet['hear_speech'] = [0.708, 0, 0, 0, '#joyful', '#joyful', 0.236, 'learn_new_information', 'prepare_exam', 'gain_information', 'inform', 'offer_opinion']
senticnet['hear_story'] = [0.948, 0.884, 0, 0, '#joyful', '#interesting', 0.611, 'find_fact', 'judge_person', 'play_on_grass', 'wit', 'help_find']
senticnet['hear_voice'] = [0, 0.069, 0, 0.104, '#interesting', '#admirable', 0.058, 'hear_noise', 'clear_throat', 'detect', 'audible', 'hear_sound']
senticnet['hear_well'] = [0.216, -0.122, 0.085, -0.115, '#joyful', '#surprising', 0.046, 'hear_song', 'sing_along', 'earring', 'listen_well', 'tap_foot']
senticnet['hearing_disorder'] = [-0.523, 0, 0.832, -0.58, '#angry', '#disgusting', -0.645, 'disability', 'disablement', 'handicap', 'impairment', 'sensorineural_hearing_loss']
senticnet['hearing_impairment'] = [-0.962, 0, 0.522, -0.667, '#sad', '#disgusting', -0.717, 'disability', 'disablement', 'handicap', 'impairment', 'sensorineural_hearing_loss']
senticnet['heart'] = [0.249, 0.33, -0.198, 0.143, '#joyful', '#interesting', 0.175, 'two_arms', 'nerve', 'liver', 'tummy', 'two_ears']
senticnet['heart_and_soul'] = [0.957, -0.633, 0, 0.888, '#joyful', '#admirable', 0.826, 'content', 'quintessence', 'stuff', 'bare_bones', 'hypostasis']
senticnet['heart_attack'] = [-0.823, 0, -0.859, -0.759, '#sad', '#scared', -0.814, 'drug_addiction', 'die', 'old_age', 'apnea', 'call_help']
senticnet['heart_beat_fast'] = [0.99, 0.832, 0, 0, '#joyful', '#interesting', 0.607, 'health_improve', 'stare', 'extreme_elation', 'win_game', 'minor_injury']
senticnet['heart_block'] = [-0.83, 0, 0.987, -0.504, '#sad', '#angry', -0.774, 'arrhythmia', 'atrioventricular_block', 'bradycardia', 'ventricular_fibrillation', 'tachycardia']
senticnet['heart_broken'] = [-0.975, 0, 0.893, -0.993, '#sad', '#disgusting', -0.954, 'bad_couple', 'wrong_person', 'fake_love', 'bad_person', 'bad_marriage']
senticnet['heart_disease'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'heart_problem', 'ill', 'illness', 'myocardiopathy', 'rheumatic_heart_disease']
senticnet['heart_failure'] = [-0.982, 0, 0.827, -0.943, '#sad', '#disgusting', -0.917, 'congestive_heart_failure', 'heart_attack', 'failure', 'heart_disease', 'cardiopathy']
senticnet['heart_line'] = [0.689, -0.565, 0, 0.74, '#joyful', '#admirable', 0.665, 'crease', 'crinkle', 'wrinkle', 'furrow', 'seam']
senticnet['heart_problem'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'heart_disease', 'ill', 'illness', 'myocardiopathy', 'rheumatic_heart_disease']
senticnet['heart_rate_increase'] = [0, 0, -0.708, -0.842, '#scared', '#disgusting', -0.517, 'breathlessness', 'breaheavily', 'get_exhausted', 'get_out_breath', 'heavy_breathe']
senticnet['heartache'] = [-0.888, 0.142, -0.645, 0, '#sad', '#scared', -0.464, 'heartbreak', 'sorrow', 'guilty_conscience', 'woe', 'repent']
senticnet['heartbeat'] = [0.802, 0.975, 0, 0, '#joyful', '#interesting', 0.592, 'form_of_music', 'popular_music', 'style_music', 'hear_well', 'dancer']
senticnet['heartbreak'] = [-0.856, 0, -0.727, -0.865, '#sad', '#disgusting', -0.816, 'repent', 'grieve', 'guilt_trip', 'guilt_feeling', 'repentant']
senticnet['heartbreaking'] = [-0.894, 0.161, -0.613, 0.053, '#sad', '#scared', -0.431, 'heartrending', 'grievous', 'grievously', 'aggrieve', 'brokenheartedness']
senticnet['heartburn'] = [-0.91, 0, 0, -0.917, '#sad', '#disgusting', -0.609, 'become_full', 'indigestion', 'stomach_ache', 'get_full', 'a_little_hungry']
senticnet['heartburning'] = [0.046, 0.117, 0.772, -0.676, '#angry', '#disgusting', -0.428, 'grievance', 'resentfully', 'gall', 'rancor', 'resentful']
senticnet['hearten'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerfully', 'cheerful', 'jolly_up', 'chirk_up', 'embolden']
senticnet['heartfelt'] = [0, 0.84, 0, 0.78, '#interesting', '#admirable', 0.54, 'seriously', 'devout', 'earnestness', 'earnestly', 'seriousness']
senticnet['hearth'] = [-0.791, 0, -0.738, 0, '#sad', '#scared', -0.51, 'residence', 'no_place', 'domicile', 'live_area', 'dwell_place']
senticnet['heartleaf'] = [-0.524, 0, 0.527, -0.782, '#angry', '#disgusting', -0.611, 'herb', 'black_snakeroot', 'wild_ginger', 'asarabacca', 'herbaceous_plant']
senticnet['heartless'] = [-0.711, 0, -0.978, 0, '#sad', '#scared', -0.563, 'hardheartedness', 'coldheartedness', 'heartlessly', 'heartlessness', 'hardhearted']
senticnet['heartlessly'] = [-0.764, 0, -0.745, 0, '#sad', '#scared', -0.503, 'hardheartedness', 'coldheartedness', 'heartlessness', 'heartless', 'hardhearted']
senticnet['heartlessness'] = [-0.743, 0, -0.873, 0, '#sad', '#scared', -0.539, 'hardheartedness', 'coldheartedness', 'heartlessly', 'heartless', 'hardhearted']
senticnet['heartrending'] = [-0.894, 0.161, -0.613, 0.053, '#sad', '#scared', -0.431, 'heartbreaking', 'grievous', 'grievously', 'aggrieve', 'brokenheartedness']
senticnet['heartsease'] = [0.621, 0.648, -0.252, 0.296, '#joyful', '#interesting', 0.438, 'pacifically', 'repose', 'peace-loving', 'peaceably', 'peaceable']
senticnet['heartsick'] = [-0.826, 0.226, -0.461, -0.051, '#sad', '#scared', -0.371, 'despondence', 'heartsickness', 'disconsolateness', 'despondent', 'despondency']
senticnet['heartsickness'] = [-0.826, 0.226, -0.461, -0.051, '#sad', '#scared', -0.371, 'despondence', 'disconsolateness', 'heartsick', 'despondent', 'despondency']
senticnet['hearty'] = [0.062, 0, 0.027, 0.055, '#joyful', '#admirable', 0.03, 'porridge', 'meal', 'broth', 'hamburger', 'appetizer']
senticnet['heat'] = [-0.903, 0, 0.251, -0.962, '#sad', '#disgusting', -0.705, 'burn_inside', 'hot', 'fire', 'warmth', 'burn']
senticnet['heat_element'] = [0.061, -0.049, 0, 0, '#joyful', '#surprising', 0.037, 'bake_oven', 'stick_butter', 'find_recipe', 'grill', 'food_bake']
senticnet['heat_exhaustion'] = [-0.721, 0, 0.762, -0.795, '#angry', '#disgusting', -0.759, 'heat_hyperpyrexia', 'heat_prostration', 'prostration', 'sunstroke', 'thermic_fever']
senticnet['heat_food'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'cook_rice', 'roast_meat', 'cook_food', 'make_food_taste_better', 'cook_hamburger']
senticnet['heat_home'] = [0.608, 0.647, -0.266, 0.325, '#joyful', '#interesting', 0.438, 'warm_house', 'produce_heat', 'heat_house', 'warm_room', 'warm_place']
senticnet['heat_house'] = [-0.915, 0, 0.871, -0.995, '#sad', '#disgusting', -0.927, 'fire', 'heat', 'burn', 'flame', 'hot']
senticnet['heat_hyperpyrexia'] = [-0.721, 0, 0.762, -0.795, '#angry', '#disgusting', -0.759, 'heat_exhaustion', 'heat_prostration', 'prostration', 'sunstroke', 'thermic_fever']
senticnet['heat_light'] = [-0.141, 0, -0.214, -0.078, '#sad', '#scared', -0.144, 'arson', 'burn_down_house', 'set_on_fire', 'rapid_oxidation', 'flame']
senticnet['heat_meal'] = [0.792, 0.973, 0, 0, '#joyful', '#interesting', 0.588, 'scrumble_egg', 'beat_egg', 'pan', 'breakfast', 'food']
senticnet['heat_measure'] = [0.034, 0.096, 0.061, 0.067, '#interesting', '#admirable', 0.045, 'temperature_measure', 'celsius', 'measure_heat', 'circle_part', 'temperature_measurement']
senticnet['heat_pot_water'] = [-0.042, -0.021, 0, -0.105, '#sad', '#disgusting', -0.042, 'stir_pot', 'chop_vegetable', 'open_package', 'cut_food', 'cut_vegetable']
senticnet['heat_prostration'] = [-0.721, 0, 0.762, -0.795, '#angry', '#disgusting', -0.759, 'heat_exhaustion', 'heat_hyperpyrexia', 'prostration', 'sunstroke', 'thermic_fever']
senticnet['heat_source'] = [0.091, 0, 0.034, 0.049, '#joyful', '#admirable', 0.035, 'lantern', 'candle', 'heater', 'illuminate_room', 'furnace']
senticnet['heat_towel_rack'] = [0.722, 0.981, 0, 0, '#joyful', '#interesting', 0.568, 'electric_toothbrush', 'towel', 't_shirt', 'toilet_seat', 'hair_brush']
senticnet['heat_up'] = [0, 0, -0.827, -0.85, '#scared', '#disgusting', -0.559, 'corrode', 'light_up', 'burn_heat', 'dig_up', 'burn_up']
senticnet['heater'] = [-0.091, 0, 0, 0, '#sad', '#sad', -0.03, 'water_garden', 'water_lawn', 'adjust_water_temperature', 'shower', 'cook']
senticnet['heathen'] = [-0.643, 0, 0.834, -0.643, '#sad', '#angry', -0.707, 'paynim', 'nonreligious_person', 'idolizer', 'idolater', 'idol_worshiper']
senticnet['heathenish'] = [-0.932, 0, 0.75, -0.645, '#sad', '#angry', -0.776, 'heathen', 'irreligious', 'pagan', 'lapsed', 'nonchurchgoing']
senticnet['heatiness'] = [-0.964, 0, 0, -0.715, '#sad', '#disgusting', -0.56, 'fever', 'sickness', 'sweat', 'body_heat', 'high_fever']
senticnet['heatstroke'] = [-0.569, 0, 0.958, -0.533, '#sad', '#angry', -0.687, 'heat_exhaustion', 'heat_prostration', 'prostration', 'sunstroke', 'thermic_fever']
senticnet['heaume'] = [-0.595, 0, 0.887, -0.715, '#angry', '#disgusting', -0.732, 'armet', 'basinet', 'casque', 'helmet', 'morion']
senticnet['heave'] = [-0.027, -0.05, 0.092, -0.065, '#angry', '#disgusting', -0.045, 'gasp', 'puff', 'wheeze', 'blow', 'pant']
senticnet['heaven'] = [0.028, 0.176, 0, 0.134, '#interesting', '#admirable', 0.113, 'paradise', 'sky', 'thunder_storm', 'angel', 'spiritual']
senticnet['heavenly'] = [0.902, 0.954, 0, 0.968, '#interesting', '#admirable', 0.941, 'idol', 'eden', 'religious_belief', 'deity', 'assumption']
senticnet['heavenly_body'] = [0.761, 0, 0, 0.974, '#joyful', '#admirable', 0.578, 'celestial_body', 'around_earth', 'celestial_object', 'small_earth', 'crescent']
senticnet['heaviness'] = [-0.826, 0.226, -0.461, -0.051, '#sad', '#scared', -0.371, 'heavy_weight', 'heavy', 'heavy_person', 'heavy_breathe', 'heavy_air']
senticnet['heavy'] = [-0.826, 0.226, -0.461, -0.051, '#sad', '#scared', -0.371, 'heaviness', 'heavy_weight', 'heavy_person', 'heavy_breathe', 'heavy_air']
senticnet['heavy_air'] = [0.058, 0, 0.023, 0.058, '#joyful', '#admirable', 0.031, 'fluid', 'white_water', 'liquid', 'wet_air', 'potable_liquid']
senticnet['heavy_breathe'] = [0, 0, -0.938, -0.896, '#scared', '#disgusting', -0.611, 'shin_splint', 'run_out_breath', 'breaheavily', 'get_out_breath', 'get_exhausted']
senticnet['heavy_breathing'] = [0, -0.052, 0.027, 0.05, '#surprising', '#admirable', 0.025, 'exercise', 'catch_breath', 'need_break', 'rest_up', 'regain_energy']
senticnet['heavy_dinner'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'fat', 'bloated', 'enlarged', 'expanded', 'bulging']
senticnet['heavy_element'] = [0.04, 0, 0.017, 0.056, '#joyful', '#admirable', 0.026, 'platinum', 'silver', 'mixed_metal', 'titanium', 'alloy']
senticnet['heavy_metal'] = [0.046, -0.15, 0.016, 0.167, '#surprising', '#admirable', 0.116, 'dense_air', 'toxic_metal', 'north_south', 'heavy_element', 'tin_foil']
senticnet['heavy_object'] = [-0.023, 0.083, 0.041, 0.184, '#interesting', '#admirable', 0.068, 'keep_out', 'metal_bar', 'control_access', 'door_handle', 'use_farm']
senticnet['heavy_paper'] = [0.02, -0.009, 0, 0.109, '#joyful', '#admirable', 0.046, 'heavy_element', 'strong_material', 'magnetic', 'tin', 'tin_aluminium']
senticnet['heavy_person'] = [0, 0, 0.071, 0, '#angry', '#angry', -0.024, 'fat', 'heavy_weight', 'eat_too_much', 'heavy', 'fast_food']
senticnet['heavy_rain'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'storm', 'bad_climate', 'rain', 'snow', 'become_sick']
senticnet['heavy_weight'] = [-0.137, 0.145, 0.624, -0.638, '#angry', '#disgusting', -0.418, 'heavy', 'heaviness', 'fat', 'obese', 'burden']
senticnet['heavyhearted'] = [-0.77, 0.277, -0.449, -0.051, '#sad', '#scared', -0.331, 'heavyheartedness', 'bored', 'world-weariness', 'weltschmerz', 'world-weary']
senticnet['heavyheartedness'] = [-0.77, 0.277, -0.449, -0.051, '#sad', '#scared', -0.331, 'heavyhearted', 'bored', 'world-weariness', 'weltschmerz', 'world-weary']
senticnet['heck'] = [-0.248, -0.105, -0.118, -0.372, '#sad', '#disgusting', -0.211, 'conflict', 'bloodshed', 'siege', 'fight', 'war']
senticnet['hectic'] = [0, 0, 0, -0.761, '#disgusting', '#disgusting', -0.254, 'fevered', 'feverish', 'feverishly', 'buck_fever', 'expectantly']
senticnet['hedge'] = [-0.949, 0, 0.736, 0, '#sad', '#angry', -0.562, 'hem_in', 'surround', 'environ', 'ring', 'skirt']
senticnet['hedonism'] = [0.601, -0.846, 0, 0.872, '#surprising', '#admirable', 0.773, 'bioethics', 'moral_philosophy', 'philosophy', 'casuistry', 'eudemonism']
senticnet['heed'] = [0, 0, -0.984, -0.838, '#scared', '#disgusting', -0.607, 'attentiveness', 'listen', 'mind', 'paying_attention', 'regard']
senticnet['heedful'] = [0.709, -0.613, 0, 0.762, '#joyful', '#admirable', 0.695, 'careful', 'mindful', 'resonant', 'evocative', 'redolent']
senticnet['heedlessness'] = [0.991, -0.75, 0, 0.815, '#joyful', '#admirable', 0.852, 'incaution', 'incautiousness', 'mindlessness', 'rashness', 'imprudence']
senticnet['heel'] = [-0.037, -0.027, 0.065, -0.029, '#sad', '#angry', -0.035, 'leg', 'toe', 'hold_canvas', 'foot', 'ankle']
senticnet['hefty'] = [0.737, 0, 0, 0.957, '#joyful', '#admirable', 0.565, 'muscular', 'goodly', 'sinewy', 'powerful', 'brawny']
senticnet['hegira'] = [-0.691, 0, 0.998, -0.84, '#angry', '#disgusting', -0.843, 'evasion', 'lam', 'break', 'skedaddle', 'escape']
senticnet['height'] = [0.028, 0.123, 0.071, 0.162, '#interesting', '#admirable', 0.081, 'angle', 'math_term', 'pinnacle', 'downward', 'tall']
senticnet['heighten'] = [0.737, -0.808, 0, 0.611, '#joyful', '#surprising', 0.719, 'compound', 'intensify', 'deepen', 'potentiate', 'enhance']
senticnet['heightening'] = [0.652, -0.649, 0, 0.953, '#joyful', '#admirable', 0.751, 'intensifying', 'thickening', 'aggravating', 'exacerbating', 'deepening']
senticnet['heinousness'] = [-0.99, 0, 0.947, -0.883, '#sad', '#angry', -0.94, 'atrociousness', 'barbarousness', 'inhumanity', 'atrocity', 'barbarity']
senticnet['helicopter'] = [0.627, 0.61, -0.24, 0.234, '#joyful', '#interesting', 0.41, 'aircraft', 'plane', 'airplane', 'aeroplane', 'airliner']
senticnet['heliothis_moth'] = [-0.534, 0, 0.8, -0.619, '#angry', '#disgusting', -0.651, 'armyworm', 'underwing', 'antler_moth', 'noctuid', 'moth']
senticnet['helium_balloon'] = [0.064, -0.228, 0, -0.041, '#joyful', '#surprising', 0.084, 'toy_balloon', 'balloon', 'dart_board', 'kite', 'confetti']
senticnet['hell'] = [-0.084, 0.068, -0.134, -0.118, '#scared', '#disgusting', -0.089, 'box_match', 'battlefield', 'funeral', 'shoot_range', 'underworld']
senticnet['hell_dust'] = [-0.7, 0, 0.698, -0.578, '#sad', '#angry', -0.659, 'smack', 'diacetylmorphine', 'nose_drops', 'thunder', 'skag']
senticnet['hellcat'] = [-0.598, 0, 0.573, -0.56, '#sad', '#angry', -0.577, 'termagant', 'old_bag', 'shrew', 'frump', 'disagreeable_woman']
senticnet['hellfire'] = [-0.924, 0, 0.687, -0.75, '#sad', '#disgusting', -0.787, 'infernal_region', 'red_region', 'imaginary_place', 'mythical_place', 'fictitious_place']
senticnet['hellhound'] = [-0.651, 0, 0.716, -0.942, '#angry', '#disgusting', -0.77, 'disturber', 'provoker', 'inciter', 'instigant', 'bad_hat']
senticnet['hello'] = [0.944, 0, 0, 0.799, '#joyful', '#admirable', 0.581, 'goodbye', 'friend', 'greetings', 'frequency', 'greet']
senticnet['helmet'] = [-0.595, 0, 0.887, -0.715, '#angry', '#disgusting', -0.732, 'armet', 'basinet', 'casque', 'heaume', 'morion']
senticnet['helmeted'] = [0.84, -0.973, 0, 0.517, '#joyful', '#surprising', 0.777, 'prepared', 'visored', 'armored', 'outfitted', 'equipped']
senticnet['helminthic'] = [0.621, -0.767, 0, 0.947, '#surprising', '#admirable', 0.778, 'thiabendazole', 'medicament', 'medicinal_drug', 'medication', 'medicine']
senticnet['help'] = [0.967, 0.795, 0, 0.706, '#joyful', '#interesting', 0.823, 'give_assistance', 'thank', 'good_karma', 'please_parent', 'forgive']
senticnet['help_another'] = [0.794, 0.769, 0, 0.866, '#joyful', '#admirable', 0.81, 'hunt_duck', 'shake_hand', 'talk_other_person', 'call_mom', 'say_hello']
senticnet['help_another_person'] = [0.823, 0.891, 0, 0.759, '#joyful', '#interesting', 0.824, 'point_out', 'complete_sentence', 'state_fact', 'lower_expectation', 'find_book_library']
senticnet['help_each_other'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'cooperate', 'interact', 'connect', 'face_to_face', 'interaction']
senticnet['help_find'] = [0.8, 0.817, 0, 0.895, '#interesting', '#admirable', 0.837, 'orientation', 'help_understand', 'involve', 'investigation', 'deduce']
senticnet['help_learn'] = [0.8, 0.817, 0, 0.895, '#interesting', '#admirable', 0.837, 'help', 'get_social_contact', 'educate', 'learn_skill', 'learn']
senticnet['help_less_fortunate'] = [0, 0.106, -0.086, 0.115, '#interesting', '#admirable', 0.045, 'donate', 'give', 'donate_charity', 'purchase_food', 'help']
senticnet['help_neighbor'] = [0, 0.097, 0, 0.059, '#interesting', '#admirable', 0.052, 'say_hi', 'neighbor', 'talk_neighbor', 'meet_neighbor', 'see_neighbor']
senticnet['help_others'] = [0.741, 0.749, 0, 0.915, '#interesting', '#admirable', 0.802, 'make_world_better_place', 'improve_world', 'help_person', 'personal_improvement', 'become_better_person']
senticnet['help_out'] = [0.912, 0, 0, 0.872, '#joyful', '#admirable', 0.595, 'need', 'help_person', 'demand', 'want_badly', 'give_help']
senticnet['help_people'] = [0, 0.991, 0, 0.804, '#interesting', '#admirable', 0.598, 'pillar', 'sustain', 'solid_basis', 'structure', 'back_bone']
senticnet['help_person'] = [0.829, 0.713, 0, 0.856, '#joyful', '#admirable', 0.799, 'help_others', 'meet_need', 'animal_person', 'make_world_better_place', 'feel_happy']
senticnet['help_relax'] = [0.068, 0, 0, 0, '#joyful', '#joyful', 0.023, 'smell_nice', 'feel_clean', 'remove_stain', 'smell_good', 'smell_better']
senticnet['help_remember'] = [-0.059, 0, 0.079, -0.081, '#angry', '#disgusting', -0.073, 'press_key', 'loose_track_time', 'move_finger', 'tune_instrument', 'listen']
senticnet['help_sleep'] = [0.903, -0.704, 0, 0, '#joyful', '#surprising', 0.536, 'lower_stress', 'use_energy', 'good_fun', 'sleeping_pill', 'stay_physically_fit']
senticnet['help_solve_problem'] = [0.702, 0.903, 0, 0.751, '#interesting', '#admirable', 0.785, 'process_data', 'process_information', 'consider_option', 'surf_internet', 'word_process']
senticnet['help_someone_live_long'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'good_shape', 'fitness', 'much_exercise', 'feel_great', 'cause_dehydration']
senticnet['help_team'] = [0.902, 0.864, 0, 0, '#joyful', '#interesting', 0.589, 'fun', 'difficult_play', 'enjoy_sport', 'like_sport', 'competitive']
senticnet['help_travelling'] = [0.74, 0.776, 0, 0, '#joyful', '#interesting', 0.505, 'travel', 'find_way', 'compass', 'compass_direction', 'use_compass']
senticnet['help_understand'] = [0, 0, 0, 0.075, '#admirable', '#admirable', 0.025, 'job_application', 'resume', 'respond', 'questionnaire', 'application']
senticnet['helper'] = [0, 0.158, -0.125, 0.138, '#interesting', '#admirable', 0.057, 'free_slave', 'occupation', 'laborer', 'hire_help', 'career']
senticnet['helpful'] = [0.098, 0.249, -0.169, 0.233, '#interesting', '#admirable', 0.137, 'meet_need', 'kindness', 'help_person', 'courtesy', 'helpful_tool']
senticnet['helpful_tool'] = [0.928, 0, 0, 0.788, '#joyful', '#admirable', 0.572, 'cobol', 'woodworking_tool', 'helpful', 'type_of_fruit', 'hand_tool']
senticnet['helpfulness'] = [0.951, -0.96, 0, 0.707, '#joyful', '#surprising', 0.873, 'avail', 'help', 'usefulness', 'utility', 'service']
senticnet['helpless'] = [-0.988, 0, -0.875, 0, '#sad', '#scared', -0.621, 'small_boy', 'young_kid', 'little_person', 'small_adult', 'small_kid']
senticnet['helplessness'] = [-0.796, 0.251, -0.432, -0.07, '#sad', '#scared', -0.349, 'dysphoria', 'cast_down', 'deject', 'get_down', 'dispirit']
senticnet['helpmate'] = [0.905, -0.515, 0, 0.913, '#joyful', '#admirable', 0.778, 'spouse', 'partner', 'married_person', 'mate', 'better_half']
senticnet['helpmeet'] = [0.539, -0.968, 0, 0.745, '#surprising', '#admirable', 0.751, 'spouse', 'partner', 'married_person', 'mate', 'better_half']
senticnet['hem_in'] = [0.826, -0.607, 0, 0.598, '#joyful', '#surprising', 0.677, 'hedge', 'surround', 'environ', 'ring', 'skirt']
senticnet['hematoma'] = [-0.697, 0, 0.517, -0.619, '#sad', '#disgusting', -0.611, 'intumescence', 'haematoma', 'puffiness', 'swelling', 'lump']
senticnet['hemisphere'] = [0, 0, 0, 0.119, '#admirable', '#admirable', 0.04, 'planet', 'earth', 'spherical', 'planet_solar_system', 'terrain']
senticnet['hemlock_water_dropwort'] = [-0.799, 0, 0.906, -0.671, '#sad', '#angry', -0.792, 'water_dropwort', 'poisonous_plant', 'water_hemlock', 'plant_life', 'poison_sumac']
senticnet['hen'] = [0.039, 0.089, -0.081, 0.143, '#interesting', '#admirable', 0.063, 'jay', 'nightingale', 'stork', 'bird', 'rooster']
senticnet['hen_baby'] = [0.053, 0.091, 0, 0.152, '#interesting', '#admirable', 0.099, 'inside_egg', 'baby_chicken', 'oval_shape', 'lay_egg', 'hatch']
senticnet['hen_child'] = [0.902, 0.995, 0, 0, '#joyful', '#interesting', 0.632, 'hot_babe', 'hen_baby', 'slang_woman', 'beautiful_girl', 'bird']
senticnet['henchman'] = [0, 0, -0.06, -0.063, '#scared', '#disgusting', -0.041, 'neck', 'adam_apple', 'nape', 'shoulder', 'head']
senticnet['hep'] = [0.61, -0.983, 0, 0.795, '#surprising', '#admirable', 0.796, 'enlightened', 'conversant', 'informed', 'hip', 'hip_to']
senticnet['hepatitis'] = [-0.881, 0, 0.864, -0.795, '#sad', '#angry', -0.847, 'viral_hepatitis', 'disease', 'feel_sick', 'liver_disease', 'infectious_disease']
senticnet['heraldic'] = [-0.607, 0, 0.523, -0.959, '#sad', '#disgusting', -0.696, 'blabbermouthed', 'expansive', 'communicatory', 'talkative', 'leaky']
senticnet['herb'] = [0.062, 0.115, 0, 0, '#joyful', '#interesting', 0.059, 'lettuce', 'spinach', 'mint', 'baby_flower', 'cabbage']
senticnet['herbaceous_plant'] = [-0.81, 0, 0.699, -0.526, '#sad', '#angry', -0.678, 'herb', 'spider_flower', 'spider_plant', 'stinking_clover', 'cleome']
senticnet['herd_sheep'] = [0.109, 0.066, 0, 0, '#joyful', '#interesting', 0.058, 'social_animal', 'home_animal', 'household_animal', 'household_pet', 'domestic_animal']
senticnet['heritage'] = [0.679, -0.757, 0, 0.658, '#joyful', '#surprising', 0.698, 'moneymaking', 'acquisition', 'purchase', 'assumption', 'restitution']
senticnet['hermaphroditism'] = [0.984, -0.517, 0, 0.501, '#joyful', '#surprising', 0.667, 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder', 'congenital_abnormality']
senticnet['hermit'] = [0, 0, -0.102, 0, '#scared', '#scared', -0.034, 'lonely_person', 'vegetarian', 'raccoon', 'lab_rat', 'user']
senticnet['hermitic'] = [-0.948, 0, 0.779, -0.858, '#sad', '#disgusting', -0.862, 'eremitic', 'eremitical', 'cloistered', 'anchoritic', 'unworldly']
senticnet['hero'] = [0, 0.991, 0, 0.804, '#interesting', '#admirable', 0.598, 'senator', 'save_life', 'egalitarian', 'pioneer', 'help_people']
senticnet['hero-worship'] = [0, 0.788, 0, 0.844, '#interesting', '#admirable', 0.544, 'reverently', 'idolize', 'venerate', 'worship', 'veneration']
senticnet['hero_worship'] = [0.591, 0.634, -0.269, 0.328, '#joyful', '#interesting', 0.428, 'laudably', 'praiseworthily', 'admirably', 'look_up_to', 'commendable']
senticnet['heroin'] = [-0.635, 0, 0.819, -0.547, '#sad', '#angry', -0.667, 'smack', 'hell_dust', 'nose_drops', 'thunder', 'skag']
senticnet['heroine'] = [0.806, -0.579, 0, 0.744, '#joyful', '#admirable', 0.71, 'character', 'role', 'theatrical_role', 'part', 'persona']
senticnet['heroism'] = [0, 0, 0.764, -0.777, '#angry', '#disgusting', -0.514, 'restriction', 'tragedy', 'perpetrator', 'dominate', 'control']
senticnet['heron'] = [0, 0.065, 0.021, 0.052, '#interesting', '#admirable', 0.032, 'microscopic', 'tiny_organism', 'microbe', 'amoeba', 'single_celled']
senticnet['herpes'] = [-0.739, -0.728, -0.861, -0.793, '#scared', '#disgusting', -0.555, 'venereal_disease', 'overpopulation', 'std', 'loss_offreedom', 'lower_standard_live']
senticnet['herpes_genitalis'] = [-0.981, 0, 0.703, -0.847, '#sad', '#disgusting', -0.844, 'venereal_disease', 'venereal_infection', 'social_disease', 'sexually_transmitted_disease', 'herpes_simplex']
senticnet['herpes_simplex'] = [-0.981, 0, 0.703, -0.847, '#sad', '#disgusting', -0.844, 'venereal_disease', 'venereal_infection', 'social_disease', 'sexually_transmitted_disease', 'herpes_genitalis']
senticnet['herpes_simplex_virus'] = [-0.964, 0, 0.726, -0.848, '#sad', '#disgusting', -0.846, 'herpes', 'labial_herpes', 'herpes_simplex', 'herpes_virus', 'virus']
senticnet['herpes_virus'] = [-0.964, 0, 0.726, -0.848, '#sad', '#disgusting', -0.846, 'herpes', 'labial_herpes', 'herpes_simplex', 'herpes_simplex_virus', 'virus']
senticnet['herringbone'] = [0, 0.068, -0.065, 0.081, '#interesting', '#admirable', 0.028, 'pyramid', 'buckle', 'mexican_restaurant', 'anemone', 'japanese_person']
senticnet['hesitance'] = [-0.755, 0, -0.796, 0, '#sad', '#scared', -0.517, 'hesitantly', 'hesitancy', 'hesitatingly', 'unassertive', 'unassertively']
senticnet['hesitancy'] = [-0.97, 0, -0.879, 0, '#sad', '#scared', -0.616, 'hesitantly', 'hesitance', 'hesitatingly', 'unassertive', 'unassertively']
senticnet['hesitant'] = [0.778, -0.502, 0, 0.517, '#joyful', '#admirable', 0.599, 'on_fence', 'suspensive', 'undecided', 'indecisive', 'hesitating']
senticnet['hesitantly'] = [-0.782, 0, -0.823, 0, '#sad', '#scared', -0.535, 'hesitance', 'hesitancy', 'hesitatingly', 'unassertive', 'unassertively']
senticnet['hesitate'] = [-0.885, 0, 0.925, -0.556, '#sad', '#angry', -0.789, 'falter', 'waver', 'linger', 'boggle', 'dwell_on']
senticnet['hesitating'] = [0.778, -0.502, 0, 0.517, '#joyful', '#admirable', 0.599, 'on_fence', 'suspensive', 'undecided', 'hesitant', 'indecisive']
senticnet['hesitatingly'] = [-0.994, 0, -0.818, 0, '#sad', '#scared', -0.604, 'hesitantly', 'hesitance', 'hesitancy', 'unassertive', 'unassertively']
senticnet['hesitation'] = [-0.893, 0, 0.565, -0.76, '#sad', '#disgusting', -0.739, 'irresolution', 'uncertainty', 'doubt', 'incertitude', 'dubiety']
senticnet['heterodoxy'] = [0.526, -0.633, 0, 0.59, '#surprising', '#admirable', 0.583, 'nonconformity', 'iconoclasm', 'nonconformism', 'nonconformance', 'orientation']
senticnet['heterogeneity'] = [-0.646, 0, 0.773, -0.686, '#angry', '#disgusting', -0.702, 'diverseness', 'multifariousness', 'diversity', 'variety', 'nonuniformity']
senticnet['heterogeneous'] = [-0.826, 0, 0.756, -0.516, '#sad', '#angry', -0.699, 'inhomogeneous', 'nonuniform', 'assorted', 'sundry', 'mixed']
senticnet['heterogeneousness'] = [-0.919, 0, 0.905, -0.926, '#sad', '#disgusting', -0.917, 'diverseness', 'multifariousness', 'diversity', 'variety', 'nonuniformity']
senticnet['heterogenous'] = [-0.545, 0, 0.737, -0.615, '#angry', '#disgusting', -0.632, 'inhomogeneous', 'nonuniform', 'assorted', 'sundry', 'mixed']
senticnet['heterology'] = [-0.545, 0, 0.979, -0.858, '#angry', '#disgusting', -0.794, 'unlikeness', 'dissimilitude', 'difference', 'dissimilarity', 'disparateness']
senticnet['heteropterous_insect'] = [-0.773, 0, 0.576, -0.922, '#sad', '#disgusting', -0.757, 'insect', 'firebug', 'water_bug', 'assassin_bug', 'reduviid']
senticnet['heterostracan'] = [-0.542, 0, 0.992, -0.872, '#angry', '#disgusting', -0.802, 'hag', 'osteostracan', 'cephalaspid', 'ostracoderm', 'jawless_fish']
senticnet['hex'] = [0.521, -0.552, 0, 0.657, '#surprising', '#admirable', 0.577, 'bewitch', 'enchant', 'jinx', 'becharm', 'witch']
senticnet['hexagon'] = [0, 0.093, 0, 0.205, '#interesting', '#admirable', 0.099, 'form', 'body_type', 'figure', 'entity', 'shape']
senticnet['hexanedioic_acid'] = [-0.652, 0, 0.935, -0.968, '#angry', '#disgusting', -0.852, 'acid', 'carboxylic_acid', 'adipic_acid', 'succinic_acid', 'valeric_acid']
senticnet['hexose'] = [-0.528, 0, 0.681, -0.768, '#angry', '#disgusting', -0.659, 'triose', 'tetrose', 'pentose', 'simple_sugar', 'aldose']
senticnet['heyday'] = [0.906, -0.627, 0, 0.941, '#joyful', '#admirable', 0.825, 'honeymoon', 'period', 'time', 'efflorescence', 'millennium']
senticnet['hiatus'] = [-0.779, 0, 0.905, -0.825, '#angry', '#disgusting', -0.836, 'defervescence', 'subsidence', 'break', 'remission', 'remittal']
senticnet['hibernation'] = [-0.758, 0, 0.512, -0.758, '#sad', '#disgusting', -0.676, 'inactivity', 'inactiveness', 'slumber', 'inaction', 'dormancy']
senticnet['hiccup'] = [-0.234, -0.133, 0.055, -0.294, '#sad', '#disgusting', -0.15, 'back_pain', 'a_lot_of_noise', 'step_dog_shit', 'dog_bark', 'backache']
senticnet['hick'] = [-0.967, 0, 0.924, -0.865, '#sad', '#angry', -0.919, 'redneck', 'yokel', 'rube', 'rustic', 'hayseed']
senticnet['hickey'] = [-0.859, 0, 0.676, -0.827, '#sad', '#disgusting', -0.787, 'erythroderma', 'erythema_nodosum', 'erythema_multiforme', 'windburn', 'erythema']
senticnet['hidden'] = [-0.139, 0.07, -0.105, 0.104, '#sad', '#scared', -0.023, 'unseen', 'hide', 'conceal', 'hide_evidence', 'out_of_sight']
senticnet['hiddenness'] = [0.779, -0.756, 0, 0.526, '#joyful', '#surprising', 0.687, 'privateness', 'covertness', 'bosom', 'isolation', 'confidentiality']
senticnet['hide'] = [-0.139, 0.07, -0.105, 0.104, '#sad', '#scared', -0.023, 'conceal', 'trick', 'concealment', 'hide_body', 'hide_truth']
senticnet['hide-a-bed'] = [0, 0, -0.064, -0.116, '#scared', '#disgusting', -0.06, 'elderly_person', 'old_lady', 'homosexual', 'linen_chest', 'dust_mite']
senticnet['hide-a-bed_sofa'] = [0.978, -0.751, 0, 0, '#joyful', '#surprising', 0.576, 'sofa_bed', 'small_seat', 'beanbag_chair', 'airline_seat', 'chair']
senticnet['hide_body'] = [0, 0, 0.738, -0.91, '#angry', '#disgusting', -0.549, 'run_away', 'jump_over', 'murder', 'wilt', 'run_president']
senticnet['hide_evidence'] = [0, 0, 0.877, -0.972, '#angry', '#disgusting', -0.616, 'choose_victim', 'stab_knife', 'take_life', 'use_weapon', 'homicide']
senticnet['hide_face'] = [-0.911, 0, 0.429, -0.96, '#sad', '#disgusting', -0.767, 'hide_identity', 'wear_mask', 'bad_person', 'thief', 'robbery']
senticnet['hide_from_view'] = [-0.951, 0, 0.08, -0.988, '#sad', '#disgusting', -0.673, 'lie', 'hide', 'fraud', 'trick_someone', 'dishonesty']
senticnet['hide_identity'] = [-0.381, 0.108, -0.389, 0.072, '#sad', '#scared', -0.197, 'undercover', 'hide', 'fake', 'hacker', 'internet']
senticnet['hide_mistake'] = [-0.767, 0, 0, 0, '#sad', '#sad', -0.256, 'dissimulation', 'cover_up', 'camouflage', 'deception', 'error']
senticnet['hide_shell'] = [0, 0.073, 0, 0.069, '#interesting', '#admirable', 0.047, 'race_hare', 'live_old', 'swim', 'save_someone_from_drowning', 'hold_fish']
senticnet['hide_truth'] = [-0.16, 0.117, -0.221, 0.075, '#sad', '#scared', -0.063, 'liar', 'no_choice', 'deceive', 'phony', 'stay_out_jail']
senticnet['hide_your_identity'] = [-0.906, 0, 0.529, -0.993, '#sad', '#disgusting', -0.809, 'run_away', 'cover_up', 'criminal', 'escape', 'conceal']
senticnet['hideaway'] = [0.803, -0.893, 0, 0.94, '#surprising', '#admirable', 0.879, 'lurking_place', 'spot', 'drop', 'hiding_place', 'den']
senticnet['hideous'] = [-0.161, 0.19, 0.572, -0.625, '#angry', '#disgusting', -0.389, 'dislikeable', 'antipathy', 'distaste', 'aversion', 'disapproval']
senticnet['hideously'] = [-0.843, 0, -0.923, 0, '#sad', '#scared', -0.589, 'horrifying', 'atrocious', 'dreadfully', 'horrifyingly', 'horrified']
senticnet['hideousness'] = [-0.874, 0, 0.584, -0.711, '#sad', '#disgusting', -0.723, 'unsightliness', 'eyesore', 'ugliness', 'unattractiveness', 'garishness']
senticnet['hideout'] = [0, 0.912, 0, 0.945, '#interesting', '#admirable', 0.619, 'home_plate', 'mew', 'animal_dwell', 'live_place', 'bee_home']
senticnet['hiding_place'] = [0.803, -0.893, 0, 0.94, '#surprising', '#admirable', 0.879, 'lurking_place', 'spot', 'drop', 'hideaway', 'den']
senticnet['hidrosis'] = [-0.584, 0, 0.773, -0.797, '#angry', '#disgusting', -0.718, 'perspiration', 'sweating', 'diaphoresis', 'sudation', 'polyhidrosis']
senticnet['hie'] = [-0.978, 0, 0.504, -0.52, '#sad', '#disgusting', -0.667, 'rush', 'race', 'hotfoot', 'hasten', 'push_forward']
senticnet['hierarchy'] = [0.037, 0.143, 0, 0.09, '#interesting', '#admirable', 0.09, 'rank', 'military_order', 'supervisor', 'army_position', 'leader']
senticnet['hifalutin'] = [0.596, -0.815, 0, 0.767, '#surprising', '#admirable', 0.726, 'inflated', 'pretentious', 'snooty', 'highfalutin', 'portentous']
senticnet['high'] = [0, 0.14, -0.049, 0.165, '#interesting', '#admirable', 0.085, 'upwards', 'high_land', 'altitude', 'top', 'upward']
senticnet['high-strung'] = [-0.954, 0, -0.901, 0, '#sad', '#scared', -0.618, 'uptight', 'restive', 'overstrung', 'nervy', 'jumpy']
senticnet['high_animal'] = [0, 0.072, 0, 0.09, '#interesting', '#admirable', 0.054, 'equine', 'wild_animal', 'rodent', 'primate', 'mustang']
senticnet['high_blood_pressure'] = [-0.857, 0, -0.719, -0.865, '#sad', '#disgusting', -0.814, 'get_exercise', 'train_marathon', 'run_marathon', 'run_long_distance', 'go_gym']
senticnet['high_calorie'] = [0.105, 0.095, 0, 0.169, '#joyful', '#admirable', 0.123, 'delicious', 'yummy', 'sweet', 'creamy', 'tasty']
senticnet['high_chair'] = [0.702, 0.703, 0, 0, '#joyful', '#interesting', 0.468, 'alcohol', 'bar', 'bar_stool', 'beer_mug', 'minibar']
senticnet['high_cholesterol'] = [-0.954, 0, -0.945, -0.765, '#sad', '#scared', -0.888, 'smoke_cigarette', 'cholesterol', 'get_lung_cancer', 'unhealthy', 'die']
senticnet['high_class'] = [0, 0, 0, 0.96, '#admirable', '#admirable', 0.32, 'status', 'social_class', 'best', 'chivalry', 'kingly']
senticnet['high_cost'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'costly', 'high_price', 'debit', 'expense', 'expensive']
senticnet['high_dudgeon'] = [-0.127, 0.13, 0.647, -0.647, '#angry', '#disgusting', -0.43, 'dudgeon', 'infuriating', 'exasperating', 'maddening', 'infuriate']
senticnet['high_education'] = [0.383, 0.246, -0.108, 0.256, '#joyful', '#admirable', 0.259, 'finish_school', 'finish_college', 'get_high_education', 'obtain_degree', 'prepare_exam']
senticnet['high_esteem'] = [0, 0, 0, 0.716, '#admirable', '#admirable', 0.239, 'certainty', 'dignity', 'attitude', 'strong_feeling', 'prefer']
senticnet['high_fever'] = [-0.933, 0, 0.52, -0.99, '#sad', '#disgusting', -0.814, 'disease', 'illness', 'sickness', 'sick', 'sick_person']
senticnet['high_heel'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'footwear', 'foot', 'leg_wear', 'shoe', 'shoe_type']
senticnet['high_iq'] = [0, 0.954, 0, 0.837, '#interesting', '#admirable', 0.597, 'energy', 'genius', 'energy_use', 'gas_oil', 'invent']
senticnet['high_jinks'] = [-0.85, 0, 0.691, -0.821, '#sad', '#disgusting', -0.787, 'jinks', 'jollification', 'hijinks', 'high_jinx', 'revel']
senticnet['high_jinx'] = [-0.85, 0, 0.691, -0.821, '#sad', '#disgusting', -0.787, 'jinks', 'high_jinks', 'hijinks', 'jollification', 'revel']
senticnet['high_land'] = [0, 0.093, 0.025, 0.122, '#interesting', '#admirable', 0.063, 'cover_snow', 'landscape_feature', 'beautiful_look', 'upwards', 'steep']
senticnet['high_level'] = [0.051, 0.214, 0, 0.142, '#interesting', '#admirable', 0.136, 'tennis_match', 'middle_road', 'stick_wall', 'odd', 'auction']
senticnet['high_mountain'] = [0, 0.069, 0, 0.065, '#interesting', '#admirable', 0.045, 'canyon', 'alp', 'rocky_area', 'ski_resort', 'high_place']
senticnet['high_music'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'hear_loss', 'damaged_eardrums', 'deaf', 'loud_music', 'damage_ear']
senticnet['high_music_note'] = [-0.177, -0.049, 0.035, -0.081, '#sad', '#disgusting', -0.081, 'bad_music', 'squeak', 'annoy_sound', 'bang', 'loud']
senticnet['high_octane'] = [-0.035, 0.09, -0.062, 0.093, '#interesting', '#admirable', 0.029, 'bright_color', 'primary_color', 'color', 'color_rainbow', 'light_red']
senticnet['high_pay_job'] = [0.109, 0.104, 0, 0, '#joyful', '#interesting', 0.071, 'go_job', 'find_woman', 'get_hired', 'happiness', 'say_welcome']
senticnet['high_phone_bill'] = [-0.254, -0.159, 0.059, -0.361, '#sad', '#disgusting', -0.172, 'large_phone_bill', 'interrupt', 'boredom', 'phone_line_busy', 'lose_track_time']
senticnet['high_pitch'] = [0, -0.033, 0, 0.054, '#surprising', '#admirable', 0.029, 'mouth_sound', 'animal_sound', 'sound', 'noise', 'loud_shout']
senticnet['high_place'] = [0, 0.069, 0, 0.065, '#interesting', '#admirable', 0.045, 'alp', 'high_mountain', 'rocky_area', 'ski_resort', 'canyon']
senticnet['high_point'] = [0.052, 0.09, 0.056, 0.124, '#interesting', '#admirable', 0.07, 'top', 'pinnacle', 'peak', 'high_land', 'landscape_feature']
senticnet['high_price'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'expensive', 'spend_lot', 'unaffordable', 'overprice', 'immoderate']
senticnet['high_protein'] = [0.05, 0, 0.049, 0.071, '#joyful', '#admirable', 0.024, 'dairy_product', 'commonly', 'type_of_food', 'food_item', 'tree_fruit']
senticnet['high_quality'] = [0.131, -0.108, -0.051, 0.469, '#joyful', '#admirable', 0.219, 'really_good', 'well_done', 'most_good', 'better_good', 'high_standard']
senticnet['high_rank'] = [0.023, 0.079, 0, 0, '#joyful', '#interesting', 0.034, 'military_rank', 'army_rank', 'army_leader', 'military_position', 'army_boss']
senticnet['high_rise'] = [0.046, 0.111, 0, 0, '#joyful', '#interesting', 0.052, 'duplex', 'rent_apartment', 'brownstone', 'condominium', 'skyscraper']
senticnet['high_rise_building'] = [0, 0.105, 0, 0.076, '#interesting', '#admirable', 0.06, 'house', 'mansion', 'block_flat', 'home', 'modern_home']
senticnet['high_salary'] = [0, 0.133, -0.098, 0.211, '#interesting', '#admirable', 0.082, 'much_money', 'extra_money', 'need_money', 'earn_wage', 'money_earn']
senticnet['high_school'] = [0.065, -0.021, 0.009, 0, '#joyful', '#surprising', 0.026, 'college_class', 'school_level', 'class', 'session', 'lecture']
senticnet['high_school_band'] = [0, 0.994, 0, 0.916, '#interesting', '#admirable', 0.637, 'string_quartet', 'music_store', 'musical_instrument_store', 'music_shop', 'band_room']
senticnet['high_school_student'] = [0, 0.133, -0.098, 0.211, '#interesting', '#admirable', 0.082, 'student', 'serious_student', 'college_student', 'graduate_student', 'get_high_education']
senticnet['high_skill'] = [0.887, 0.877, 0, 0, '#joyful', '#interesting', 0.588, 'win', 'win_battle', 'ready_troop', 'win_war', 'gain_territory']
senticnet['high_spirits'] = [0.643, 0.64, -0.24, 0.3, '#joyful', '#interesting', 0.448, 'elate', 'elating', 'exhilarating', 'elated', 'cheerful']
senticnet['high_standard'] = [0.115, -0.039, 0, 0.437, '#joyful', '#admirable', 0.197, 'excellence', 'really_good', 'high_quality', 'well_done', 'superlative']
senticnet['high_status'] = [0.594, -0.688, 0, 0.957, '#surprising', '#admirable', 0.746, 'preeminence', 'eminence', 'senior_status', 'higher_status', 'higher_rank']
senticnet['high_tax'] = [-0.835, 0, 0.953, -0.822, '#sad', '#angry', -0.87, 'blame', 'injustice', 'complication', 'sleepless_night', 'black_eye']
senticnet['high_temperature'] = [-0.835, 0, 0.953, -0.822, '#sad', '#angry', -0.87, 'danger', 'hot_temperature', 'hot', 'dangerous', 'heat']
senticnet['high_tide'] = [0.632, -0.613, 0, 0.525, '#joyful', '#surprising', 0.59, 'neap_tide', 'neap', 'springtide', 'direct_tide', 'tide']
senticnet['high_up'] = [-0.046, 0.078, 0, 0.174, '#interesting', '#admirable', 0.069, 'up_high', 'block_sun', 'crystal_clear', 'sun_cover', 'water_particle']
senticnet['high_value'] = [0.026, 0.227, 0, 0.233, '#interesting', '#admirable', 0.162, 'quality', 'amount', 'assurance', 'importance', 'merit']
senticnet['high_volume'] = [-0.95, 0, -0.736, -0.736, '#sad', '#scared', -0.807, 'make_noise', 'loud_music', 'loudly', 'noise', 'loud']
senticnet['high_water'] = [0.501, -0.744, 0, 0.973, '#surprising', '#admirable', 0.739, 'neap_tide', 'neap', 'springtide', 'direct_tide', 'tide']
senticnet['highbinder'] = [-0.782, 0, 0.671, -0.989, '#sad', '#disgusting', -0.814, 'criminal', 'outlaw', 'malefactor', 'felon', 'crook']
senticnet['higher_law'] = [0.841, -0.657, 0, 0.645, '#joyful', '#surprising', 0.714, 'moral_principle', 'rule', 'caveat_emptor', 'precept', 'hypothetical_imperative']
senticnet['higher_rank'] = [0.594, -0.688, 0, 0.957, '#surprising', '#admirable', 0.746, 'preeminence', 'eminence', 'senior_status', 'higher_status', 'high_status']
senticnet['higher_status'] = [0.594, -0.688, 0, 0.957, '#surprising', '#admirable', 0.746, 'preeminence', 'eminence', 'senior_status', 'high_status', 'higher_rank']
senticnet['highest'] = [0, 0.075, 0, 0.159, '#interesting', '#admirable', 0.078, 'maximum', 'max', 'utmost', 'top', 'most']
senticnet['highest_pitch'] = [0.034, 0, 0.01, 0.087, '#joyful', '#admirable', 0.037, 'music', 'voice', 'bell', 'singing', 'alto']
senticnet['highfalutin'] = [0.596, -0.815, 0, 0.767, '#surprising', '#admirable', 0.726, 'inflated', 'hifalutin', 'snooty', 'pretentious', 'portentous']
senticnet['highflier'] = [0.701, -0.596, 0, 0.908, '#joyful', '#admirable', 0.735, 'great', 'achiever', 'highflyer', 'natural', 'mortal']
senticnet['highflyer'] = [0.701, -0.596, 0, 0.908, '#joyful', '#admirable', 0.735, 'great', 'highflier', 'achiever', 'natural', 'mortal']
senticnet['highlight'] = [0.026, 0.227, 0, 0.233, '#interesting', '#admirable', 0.162, 'best_moment', 'sport_highlight', 'football_highlight', 'television_news', 'put_in_evidence']
senticnet['highlighter'] = [0, -0.892, 0, 0.793, '#surprising', '#admirable', 0.562, 'paper_clip', 'paper_punch', 'ring_binder', 'office', 'pencil_sharpener']
senticnet['highlighter_pen'] = [0.02, -0.037, 0.059, -0.105, '#angry', '#disgusting', -0.036, 'memo_pad', 'notepad', 'intern', 'stamp_pad', 'paper_punch']
senticnet['highly_skilled'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'coordination', 'coordinated', 'find_ball', 'cooperation', 'teamwork']
senticnet['highly_strung'] = [-0.866, 0, -0.919, 0, '#sad', '#scared', -0.595, 'high-strung', 'uptight', 'restive', 'overstrung', 'nervy']
senticnet['highwater'] = [0.738, -0.712, 0, 0.854, '#joyful', '#admirable', 0.768, 'neap_tide', 'neap', 'springtide', 'direct_tide', 'tide']
senticnet['highway'] = [0, 0.072, 0, 0.092, '#interesting', '#admirable', 0.055, 'street', 'wide_street', 'freeway', 'country_road', 'road']
senticnet['highway_road'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'highway', 'road', 'long_road', 'asphalt', 'avenue']
senticnet['hijinks'] = [-0.85, 0, 0.691, -0.821, '#sad', '#disgusting', -0.787, 'jinks', 'high_jinks', 'jollification', 'high_jinx', 'revel']
senticnet['hike'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'hike_trail', 'trail', 'picnic', 'enjoy_nature', 'nice_walk']
senticnet['hike_trail'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'hike', 'trail', 'picnic', 'enjoy_nature', 'nice_walk']
senticnet['hilarious'] = [0.695, 0.623, -0.231, 0.319, '#joyful', '#interesting', 0.469, 'uproarious', 'screaming', 'hilariously', 'uproariously', 'hilarity']
senticnet['hilariously'] = [0.695, 0.623, -0.231, 0.319, '#joyful', '#interesting', 0.469, 'uproarious', 'screaming', 'uproariously', 'hilarious', 'hilarity']
senticnet['hilarity'] = [0.695, 0.623, -0.231, 0.319, '#joyful', '#interesting', 0.469, 'uproarious', 'hilariously', 'hilarious', 'screaming', 'uproariously']
senticnet['hill'] = [0, 0.093, 0, 0.078, '#interesting', '#admirable', 0.057, 'steep', 'landscape_feature', 'knoll', 'hill_mountain', 'incline']
senticnet['hill_mountain'] = [0, 0.093, 0, 0.078, '#interesting', '#admirable', 0.057, 'steep', 'landscape_feature', 'knoll', 'hill', 'incline']
senticnet['hilt'] = [-0.816, 0, 0.844, -0.766, '#sad', '#angry', -0.809, 'hold', 'grip', 'basket_hilt', 'handle', 'handgrip']
senticnet['hind'] = [-0.045, 0.226, -0.208, 0.209, '#interesting', '#admirable', 0.061, 'rear', 'elongation', 'go_backwards', 'rear_end', 'buttocks']
senticnet['hinder'] = [-0.99, 0, 0.581, -0.97, '#sad', '#disgusting', -0.847, 'obstruct_justice', 'football_rule', 'block_road', 'obstruction', 'interfere']
senticnet['hindrance'] = [0, 0, 0, -0.729, '#disgusting', '#disgusting', -0.243, 'impediment', 'obstacle', 'obstruction', 'drag', 'annoyance']
senticnet['hindu'] = [0, 0.196, 0, 0.19, '#interesting', '#admirable', 0.129, 'sanctuary', 'bible', 'philosophy', 'capital_build', 'monastery']
senticnet['hinge'] = [0, 0, 0, 0.112, '#admirable', '#admirable', 0.037, 'build_open', 'home_entrance', 'door_knob', 'knob', 'entry']
senticnet['hint'] = [-0.039, 0.245, -0.183, 0.232, '#interesting', '#admirable', 0.085, 'dare', 'jeopardy', 'suggestion', 'resolution', 'etiquette']
senticnet['hip'] = [0.023, 0.085, -0.045, 0.088, '#interesting', '#admirable', 0.05, 'thigh', 'haunch', 'joint', 'above_leg', 'knee']
senticnet['hip_hop'] = [0.081, -0.054, 0.052, 0.072, '#joyful', '#admirable', 0.052, 'rhythm', 'type_of_music', 'instrumental', 'lyric', 'melody']
senticnet['hip_socket'] = [0.681, -0.632, 0, 0.647, '#joyful', '#admirable', 0.653, 'socket', 'tooth_socket', 'alveolus', 'acetabulum', 'cotyloid_cavity']
senticnet['hip_to'] = [0.61, -0.983, 0, 0.795, '#surprising', '#admirable', 0.796, 'enlightened', 'conversant', 'hep', 'hip', 'informed']
senticnet['hipflask'] = [0.619, -0.834, 0, 0.912, '#surprising', '#admirable', 0.788, 'flask', 'pocket_flask', 'ampulla', 'canteen', 'vacuum_flask']
senticnet['hippie'] = [-0.861, 0, -0.922, 0, '#sad', '#scared', -0.594, 'no_war', 'army_man', 'opposition', 'army_person', 'warrior']
senticnet['hippies'] = [0.52, -0.911, 0, 0.65, '#surprising', '#admirable', 0.694, 'flower_people', 'youth_subculture', 'hipsters', 'beat_generation', 'beats']
senticnet['hippy'] = [0.979, 0.982, 0, 0.752, '#joyful', '#interesting', 0.904, 'rock_star', 'philanthropist', 'male_human', 'singer', 'nazi']
senticnet['hipsters'] = [0.52, -0.911, 0, 0.65, '#surprising', '#admirable', 0.694, 'flower_people', 'hippies', 'youth_subculture', 'beat_generation', 'beats']
senticnet['hire'] = [-0.033, 0.098, 0, 0.086, '#interesting', '#admirable', 0.05, 'overprice', 'job', 'ask_person', 'find_job', 'work_oneself']
senticnet['hire_attorney'] = [-0.255, 0.068, -0.152, -0.059, '#sad', '#scared', -0.133, 'hire_lawyer', 'see_lawyer', 'win_case', 'contact_lawyer', 'call_lawyer']
senticnet['hire_help'] = [-0.03, 0.106, -0.056, 0.08, '#interesting', '#admirable', 0.033, 'job', 'task', 'ask_person', 'career', 'chore']
senticnet['hire_lawyer'] = [-0.188, 0.112, -0.134, 0, '#sad', '#scared', -0.07, 'hire_attorney', 'see_lawyer', 'contact_lawyer', 'call_lawyer', 'go_court']
senticnet['hirschsprung_disease'] = [-0.503, 0, 0.542, -0.511, '#angry', '#disgusting', -0.519, 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect', 'congenital_disease']
senticnet['hirsute'] = [-0.646, 0, 0.647, -0.554, '#sad', '#angry', -0.616, 'puberulent', 'sericeous', 'furlike', 'pappose', 'pilous']
senticnet['histamine_blocker'] = [-0.533, 0, 0.954, -0.541, '#angry', '#disgusting', -0.676, 'antacid', 'ranitidine', 'gastric_antacid', 'alkalizer', 'antiacid']
senticnet['historied'] = [-0.838, 0, 0.896, -0.959, '#angry', '#disgusting', -0.898, 'storied', 'incandescent', 'glorious', 'divine', 'empyreal']
senticnet['history'] = [-0.03, 0.106, -0.056, 0.08, '#interesting', '#admirable', 0.033, 'long_ago', 'past_event', 'school_topic', 'school_subject', 'subject']
senticnet['history_book'] = [0.046, 0, 0, 0.085, '#joyful', '#admirable', 0.044, 'action_movie', 'history', 'medieval_time', 'human_history', 'part_of_history']
senticnet['histrion'] = [-0.714, 0, 0.794, -0.899, '#angry', '#disgusting', -0.802, 'role_player', 'thespian', 'actor', 'ham_actor', 'player']
senticnet['histrionics'] = [0.558, -0.602, 0, 0.779, '#surprising', '#admirable', 0.646, 'benefit', 'pianism', 'song_and_dance', 'routine', 'performance']
senticnet['hit'] = [-0.998, 0, 0.722, 0, '#sad', '#angry', -0.573, 'dribble', 'break_window', 'best_opponent', 'hit_hard', 'skip']
senticnet['hit_ball'] = [0.932, 0.931, 0, 0.78, '#joyful', '#interesting', 0.881, 'strike_out', 'throw_ball', 'catch_baseball', 'play_football', 'run_first_base']
senticnet['hit_ball_hard'] = [0, -0.758, 0, 0.766, '#surprising', '#admirable', 0.508, 'play_rugby', 'break_record', 'play_volleyball', 'run_basis', 'play_basketball']
senticnet['hit_ball_with_bat'] = [0, -0.05, 0.066, -0.134, '#angry', '#disgusting', -0.05, 'strike_out', 'throw_ball', 'hit_ball', 'catch_baseball', 'run_first_base']
senticnet['hit_baseball_bat'] = [-0.317, -0.079, 0.014, -0.236, '#sad', '#disgusting', -0.163, 'hit_face', 'bloody_nose', 'lose_a_lot_of_money', 'car_wreck', 'go_insane']
senticnet['hit_bottle'] = [0.081, -0.058, 0, -0.032, '#joyful', '#surprising', 0.036, 'drink_alcohol', 'consume_alcoholic_beverage', 'drink_much', 'drink_liquor', 'meet_woman']
senticnet['hit_brother'] = [-0.063, 0, 0.077, -0.105, '#angry', '#disgusting', -0.082, 'backup', 'make_easy', 'compose_music', 'make_drawing', 'use_musical_instrument']
senticnet['hit_car'] = [-0.199, -0.054, 0, -0.202, '#sad', '#disgusting', -0.116, 'automobile_accident', 'accident', 'use_brake', 'stagger', 'hurt_back']
senticnet['hit_corner'] = [-0.173, -0.016, 0, -0.188, '#sad', '#disgusting', -0.115, 'pass_out', 'bump_head', 'loss_ofawareness', 'bang_head', 'serious_accident']
senticnet['hit_face'] = [-0.936, 0, 0.847, -1.0, '#sad', '#disgusting', -0.928, 'fight', 'punch', 'beat', 'physical_pain', 'hit']
senticnet['hit_fist'] = [-0.193, -0.003, -0.095, -0.082, '#sad', '#scared', -0.122, 'hit_hard', 'violent_action', 'demolish', 'mock', 'terminate']
senticnet['hit_golf_ball'] = [0.121, -0.193, 0, 0, '#joyful', '#surprising', 0.105, 'dance_well', 'enter_contest', 'hook_up', 'old_dance', 'dance']
senticnet['hit_ground'] = [-0.099, 0, -0.088, -0.085, '#sad', '#scared', -0.091, 'fall_ground', 'loss_ofbreath', 'loss_ofawareness', 'broken_limb', 'hope_win']
senticnet['hit_hard'] = [0, 0, 0.821, -0.937, '#angry', '#disgusting', -0.586, 'violent_action', 'break_apart', 'demolish', 'break_glass', 'pulverize']
senticnet['hit_hard_wall'] = [0.849, -0.862, 0, 0, '#joyful', '#surprising', 0.57, 'bounce_up_down', 'hit', 'ball_game', 'hit_hard', 'play_catch']
senticnet['hit_head'] = [-0.973, 0, 0.532, -0.985, '#sad', '#disgusting', -0.83, 'head', 'jump_out_of_window', 'fall_down', 'injury', 'physical_pain']
senticnet['hit_headlines'] = [-0.083, 0, -0.111, 0, '#sad', '#scared', -0.065, 'crossword', 'grade_paper', 'type_of_paper', 'breaking_news', 'narrative']
senticnet['hit_home_run'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'score_point', 'run_first_base', 'win_game', 'score_goal', 'strike_out']
senticnet['hit_jackpot'] = [0.528, -0.844, 0, 0.65, '#surprising', '#admirable', 0.674, 'deliver_goods', 'succeed', 'win', 'bring_home_bacon', 'come_through']
senticnet['hit_oneself_head'] = [-0.094, -0.042, -0.064, -0.186, '#sad', '#disgusting', -0.101, 'become_unconscious', 'stop_move', 'unconsciousness', 'unplug', 'lose_consciousness']
senticnet['hit_somebody'] = [-0.905, 0, 0.592, -0.91, '#sad', '#disgusting', -0.802, 'hit', 'beat', 'punch', 'damage_body', 'painful']
senticnet['hit_target'] = [0, 0, -0.715, -0.954, '#scared', '#disgusting', -0.556, 'shoot_cannon', 'shoot', 'shoot_person', 'weapon_war', 'ammunition']
senticnet['hit_tree'] = [0, 0, -0.903, -0.708, '#scared', '#disgusting', -0.537, 'see_dog', 'go_downhill', 'fall_butt', 'break_bone', 'crash_tree']
senticnet['hit_wall'] = [-0.817, 0, 0, -0.909, '#sad', '#disgusting', -0.575, 'little_pollution', 'physical_exertion', 'dehydration', 'sweat_lot', 'strain_muscle']
senticnet['hit_with_baton'] = [-0.914, 0, 0.931, -0.724, '#sad', '#angry', -0.856, 'baton', 'get_hurt', 'whip', 'arrow', 'hurt']
senticnet['hitch'] = [-0.948, 0, 0.704, 0, '#sad', '#angry', -0.551, 'block', 'obstacle', 'nodus', 'impediment', 'obstruction']
senticnet['hitchhike'] = [0, 0.779, 0, 0.899, '#interesting', '#admirable', 0.559, 'ask_for_lift', 'take_walk', 'take_bus', 'go_to_another_place', 'take_metro']
senticnet['hitler'] = [-0.111, 0, 0.033, -0.324, '#sad', '#disgusting', -0.156, 'conquer_enemy', 'lose_war', 'lose_territory', 'go_war', 'enslave_person']
senticnet['hiv'] = [-0.989, 0, 0.942, -0.9, '#sad', '#angry', -0.944, 'disease', 'aids', 'immunological_disorder', 'die', 'immunodeficiency']
senticnet['hive'] = [-0.069, -0.013, -0.048, 0, '#sad', '#scared', -0.035, 'hut', 'animal_home', 'lair', 'habitat', 'beehive']
senticnet['hives'] = [-0.951, 0, 0.783, -0.689, '#sad', '#angry', -0.808, 'hypersensitivity_reaction', 'rash', 'efflorescence', 'roseola', 'skin_rash']
senticnet['hoard'] = [0.041, 0.127, -0.054, 0.134, '#interesting', '#admirable', 0.083, 'acquire', 'buy_sell', 'treasure', 'return_goods', 'get_goods']
senticnet['hoarding'] = [0.952, -0.527, 0, 0.835, '#joyful', '#admirable', 0.771, 'billboard', 'signboard', 'sandwich_board', 'scoreboard', 'shingle']
senticnet['hoary'] = [0, 0, -0.86, -0.799, '#scared', '#disgusting', -0.553, 'gray-haired', 'gray', 'rusty', 'canescent', 'grizzly']
senticnet['hoax'] = [-0.847, 0, 0.968, -0.769, '#sad', '#angry', -0.861, 'shenanigan', 'chicanery', 'wile', 'goldbrick', 'trickery']
senticnet['hob'] = [0.865, -0.757, 0, 0.717, '#joyful', '#surprising', 0.78, 'fairy_godmother', 'imp', 'gnome', 'elf', 'faerie']
senticnet['hobby'] = [0.729, 0.717, 0, 0, '#joyful', '#interesting', 0.482, 'pastime', 'leisure', 'leisure_activity', 'leisure_time', 'diversion']
senticnet['hobo'] = [-0.817, 0, 0.747, -0.886, '#sad', '#disgusting', -0.817, 'vagrant', 'drifter', 'floater', 'vagabond', 'dosser']
senticnet['hockey'] = [0.7, -0.798, 0, 0.873, '#surprising', '#admirable', 0.79, 'sport', 'game', 'ice_athletic_game', 'athletic_game', 'winter_sport']
senticnet['hockey_equipment'] = [0.841, -0.82, 0, 0, '#joyful', '#surprising', 0.554, 'adhere', 'wooden_rod', 'cue', 'glue', 'brick']
senticnet['hockey_fan'] = [0.902, -0.841, 0, 0, '#joyful', '#surprising', 0.581, 'bleacher', 'goalie', 'competitor', 'spectator', 'hockey_stick']
senticnet['hockey_game'] = [0, 0, -0.09, -0.085, '#scared', '#disgusting', -0.058, 'drive-in_movie', 'game', 'sport_event', 'movie_theater', 'theater']
senticnet['hockey_player'] = [0, -0.053, 0.016, 0.053, '#surprising', '#admirable', 0.03, 'player', 'football_player', 'game', 'play_game', 'sport']
senticnet['hockey_puck'] = [0.722, -0.747, 0, 0, '#joyful', '#surprising', 0.49, 'baseball_bat', 'water_gun', 'goalie', 'hockey_stick', 'bullseye']
senticnet['hockey_rink'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'wrong_place', 'mortuary', 'hockey', 'another_planet', 'death_row']
senticnet['hockey_stick'] = [0.945, -0.792, 0, 0, '#joyful', '#surprising', 0.579, 'baseball_bat', 'water_gun', 'goalie', 'hockey_puck', 'bullseye']
senticnet['hodgepodge'] = [0.901, -0.745, 0, 0.765, '#joyful', '#admirable', 0.804, 'mixture', 'variety', 'motley', 'assortment', 'mixed_bag']
senticnet['hoe'] = [-0.088, 0, 0, 0, '#sad', '#sad', -0.029, 'needlework', 'sow', 'cultivate', 'pip', 'vegetable_field']
senticnet['hog'] = [0, 0, -0.989, -0.759, '#scared', '#disgusting', -0.583, 'servant', 'goat', 'lamb', 'peasant', 'shepherd']
senticnet['hognosed_skunk'] = [-0.547, 0, 0.768, -0.503, '#sad', '#angry', -0.606, 'striped_skunk', 'hooded_skunk', 'polecat', 'badger_skunk', 'rooter_skunk']
senticnet['hoisin_sauce'] = [-0.756, 0, 0.593, -0.591, '#sad', '#angry', -0.647, 'taco_sauce', 'chili_sauce', 'steak_sauce', 'duck_sauce', 'condiment']
senticnet['hoist'] = [0.087, -0.041, 0, 0, '#joyful', '#surprising', 0.043, 'forklift', 'control_room', 'utility_case', 'platform_rail', 'torso']
senticnet['hokum'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'nonsense', 'meaninglessness', 'bunk', 'nonsensicality', 'absurdity']
senticnet['hold'] = [0.704, 0.834, 0, 0, '#joyful', '#interesting', 0.513, 'grasp', 'hold_object', 'retain', 'grab', 'hold_onto']
senticnet['hold_baby'] = [0.926, 0, 0, 0.901, '#joyful', '#admirable', 0.609, 'female_relative', 'woman_child', 'parent', 'mother', 'family_member']
senticnet['hold_back'] = [0.034, 0.252, -0.137, 0.277, '#interesting', '#admirable', 0.142, 'retain', 'carry_laundry', 'hold_stuff', 'back_off', 'hold_onto']
senticnet['hold_beer'] = [-0.95, 0, -0.736, -0.736, '#sad', '#scared', -0.807, 'alcoholism', 'become_intoxicated', 'greet_guest', 'intoxication', 'social_occasion']
senticnet['hold_beverage'] = [0, -0.008, 0.03, -0.049, '#angry', '#disgusting', -0.024, 'full_bladder', 'throw_away_trash', 'hold_liquid', 'drink', 'land_ground']
senticnet['hold_book'] = [0.034, 0.252, -0.137, 0.277, '#interesting', '#admirable', 0.142, 'book', 'read_book', 'go_to_school', 'go_to_library', 'choose_book']
senticnet['hold_brain'] = [0, 0.076, 0, 0.052, '#interesting', '#admirable', 0.043, 'eye_nose', 'face', 'skull', 'top_face', 'nose_mouth']
senticnet['hold_breath'] = [-0.035, -0.007, 0, -0.094, '#sad', '#disgusting', -0.041, 'wear_suit', 'underwater', 'turn_aircon_on', 'sit_in_shade', 'think_food']
senticnet['hold_canvas'] = [0, 0.967, 0, 0.771, '#interesting', '#admirable', 0.579, 'canvas', 'painting', 'paint', 'color', 'oil_painting']
senticnet['hold_card'] = [-0.086, 0.118, 0.017, 0.105, '#interesting', '#admirable', 0.04, 'spend_little_money', 'pay_off', 'dumpster_dive', 'barter', 'make_offer']
senticnet['hold_cereal'] = [0.059, 0, 0.01, 0.061, '#joyful', '#admirable', 0.037, 'hold_soup', 'hold_salad', 'eat_cereal', 'drink_soup', 'chicken_soup']
senticnet['hold_change'] = [0, 0.173, 0, 0.067, '#interesting', '#admirable', 0.08, 'bank_account', 'bank_vault', 'wallet', 'safe', 'government_agreement']
senticnet['hold_child'] = [0.734, 0.831, 0, 0, '#joyful', '#interesting', 0.522, 'woman_child', 'female_relative', 'female_parent', 'family_relation', 'kin']
senticnet['hold_clothes'] = [0.055, 0, 0.397, -0.235, '#angry', '#disgusting', -0.192, 'privacy', 'modesty', 'cover_window', 'worn_improve_vision', 'keep_bathroom_dry']
senticnet['hold_coffee'] = [0, 0.091, -0.06, 0.114, '#interesting', '#admirable', 0.048, 'put_liquid', 'drink_liquid', 'chill_drink', 'serve_beer', 'store_liquid']
senticnet['hold_coin'] = [0.02, 0.231, 0, 0.132, '#interesting', '#admirable', 0.128, 'money_collector', 'money_keeper', 'money_hold', 'money_place', 'money_holder']
senticnet['hold_cupcake'] = [0, 0.911, 0, 0.865, '#interesting', '#admirable', 0.592, 'store_dish', 'store_stuff', 'storage', 'store_item', 'carton']
senticnet['hold_document'] = [-0.842, 0, -0.793, 0, '#sad', '#scared', -0.545, 'bereavement', 'write_note', 'continue_story', 'make_paper_airplane', 'write']
senticnet['hold_dog'] = [0, 0.881, 0, 0.928, '#interesting', '#admirable', 0.603, 'hold_puppy', 'dog', 'domesticate_dog', 'nice_dog', 'domesticate_animal']
senticnet['hold_drink'] = [0.03, 0, 0.022, 0.062, '#joyful', '#admirable', 0.023, 'large_cup', 'beer_container', 'cool_drink', 'store_ice_cream', 'drink_holder']
senticnet['hold_egg'] = [0, -0.06, 0.022, 0.054, '#surprising', '#admirable', 0.031, 'bird_home', 'baby_bird', 'hatch', 'lay_egg', 'wild_bird']
senticnet['hold_every_four_years'] = [0, 0.069, 0, 0.111, '#interesting', '#admirable', 0.06, 'olympiads', 'event', 'important_event', 'important_game', 'important_occasion']
senticnet['hold_firm'] = [-0.733, 0, 0.835, -0.576, '#sad', '#angry', -0.715, 'stand_pat', 'insist', 'stand_fast', 'maintain', 'stand_firm']
senticnet['hold_fish'] = [0, -0.029, 0.06, -0.042, '#angry', '#disgusting', -0.024, 'get_boat', 'take_cruise', 'go_sea', 'take_leak', 'go_dive']
senticnet['hold_flower'] = [-0.029, 0.153, -0.057, 0.223, '#interesting', '#admirable', 0.097, 'hold_small_item', 'carry_item', 'carry_stuff', 'hold_stuff', 'put_stuff']
senticnet['hold_food'] = [-0.029, 0.153, -0.057, 0.223, '#interesting', '#admirable', 0.097, 'put_food', 'food', 'eat_food', 'serve_food', 'eat_meal']
senticnet['hold_garbage'] = [0.283, 0.292, -0.109, 0.272, '#joyful', '#interesting', 0.246, 'fill_ink', 'hang_closet', 'make_out_metal', 'fold_up', 'display_item']
senticnet['hold_glass'] = [0, 0.08, 0.016, 0.098, '#interesting', '#admirable', 0.054, 'organ_body', 'sensory_organ', 'side_face', 'sense_organ', 'listen_device']
senticnet['hold_grocery'] = [0, 0.723, 0, 0.788, '#interesting', '#admirable', 0.504, 'hold_small_item', 'carry_goods', 'hold_flower', 'hold_item', 'small_shop']
senticnet['hold_hair'] = [0, -0.011, 0.044, -0.069, '#angry', '#disgusting', -0.034, 'no_hair', 'two_eyes', 'fur_keep_warm', 'hair', 'facial_hair']
senticnet['hold_hand'] = [0.072, 0, 0, 0, '#joyful', '#joyful', 0.024, 'move_place_another', 'raise_arm', 'raise_money', 'try_forget', 'pull_out']
senticnet['hold_in'] = [0.713, -0.828, 0, 0.981, '#surprising', '#admirable', 0.841, 'hold', 'bear', 'rail', 'bound', 'border']
senticnet['hold_information'] = [0, 0, -0.074, 0, '#scared', '#scared', -0.025, 'typeface', 'print_word', 'grammatical_term', 'dissertation', 'continue_story']
senticnet['hold_inside'] = [0.062, 0.161, -0.076, 0.216, '#interesting', '#admirable', 0.121, 'dampness', 'wooden_spoon', 'smoothie', 'like_food', 'obey_traffic_law']
senticnet['hold_item'] = [-0.063, 0.105, -0.05, 0.158, '#interesting', '#admirable', 0.05, 'store_dry_goods', 'hold_grocery', 'hold_small_item', 'hold_garbage', 'store_stuff']
senticnet['hold_liquid'] = [0, -0.008, 0.03, -0.049, '#angry', '#disgusting', -0.024, 'full_bladder', 'throw_away_trash', 'land_ground', 'drink', 'hold_beverage']
senticnet['hold_liquor'] = [0, 0, 0.949, -0.72, '#angry', '#disgusting', -0.556, 'like_beer', 'travel_fast_light', 'live_ocean', 'drink_alcohol', 'drink_sea_water']
senticnet['hold_makeup'] = [-0.029, 0.139, 0.029, 0.227, '#interesting', '#admirable', 0.103, 'safekeep', 'carry_stuff', 'put_stuff', 'hold_stuff', 'store_dry_goods']
senticnet['hold_many'] = [-0.054, 0.08, -0.054, 0.158, '#interesting', '#admirable', 0.043, 'store_dry_goods', 'hold', 'hold_object', 'many_different', 'cup_breast']
senticnet['hold_match'] = [-0.054, 0.08, -0.054, 0.158, '#interesting', '#admirable', 0.043, 'hold_out', 'resist', 'strike_against', 'put_effort', 'change_plan']
senticnet['hold_meet'] = [0.063, 0, 0, 0.063, '#joyful', '#admirable', 0.042, 'stay_overnight', 'sleep_sometimes', 'sleep', 'place_sleep', 'sleep_upon']
senticnet['hold_milk'] = [0, 0.716, 0, 0.741, '#interesting', '#admirable', 0.486, 'backup', 'make_noise', 'keep_beat', 'play_orchestra', 'beep']
senticnet['hold_money'] = [0, 0.165, 0, 0.09, '#interesting', '#admirable', 0.085, 'money_holder', 'keep_money', 'money_storage', 'store_money', 'put_money']
senticnet['hold_object'] = [0.036, 0.191, -0.129, 0.297, '#interesting', '#admirable', 0.132, 'hold', 'many_different', 'hold_stuff', 'multiple_purposes', 'grab']
senticnet['hold_off'] = [-0.571, 0, 0.612, -0.97, '#angry', '#disgusting', -0.718, 'stand_firm', 'defy', 'withstand', 'hold_up', 'fight']
senticnet['hold_on'] = [0.51, -0.562, 0, 0.768, '#surprising', '#admirable', 0.613, 'hold', 'clasp', 'cling', 'latch_on', 'hang']
senticnet['hold_onto'] = [0, 0.263, -0.142, 0.295, '#interesting', '#admirable', 0.139, 'keep', 'hold', 'retain', 'hold_stuff', 'upkeep']
senticnet['hold_out'] = [-0.054, 0.08, -0.054, 0.158, '#interesting', '#admirable', 0.043, 'hold_match', 'resist', 'strike_against', 'put_effort', 'change_plan']
senticnet['hold_paper'] = [0, 0.091, 0, 0.079, '#interesting', '#admirable', 0.057, 'hold_document', 'store_pen', 'organize_paper', 'write_paper', 'keep_paper']
senticnet['hold_pencil'] = [0, 0.099, 0, 0, '#interesting', '#interesting', 0.033, 'think_need', 'store_checkbook', 'paper_plane', 'waste_paper', 'pen_and_paper']
senticnet['hold_place'] = [0, 0.123, 0.024, 0.135, '#interesting', '#admirable', 0.078, 'small_room', 'microscopic', 'carry_around', 'tiny_organism', 'structural_support']
senticnet['hold_point'] = [-0.077, -0.013, -0.066, -0.228, '#sad', '#disgusting', -0.119, 'armory', 'grenade', 'aerial_bomb', 'bomb', 'arm_oneself']
senticnet['hold_puppy'] = [0.809, 0.96, 0, 0, '#joyful', '#interesting', 0.59, 'female_child', 'young_lady', 'hold_dog', 'young_woman', 'human_offspring']
senticnet['hold_salad'] = [0.059, 0, 0.01, 0.061, '#joyful', '#admirable', 0.037, 'hold_cereal', 'hold_soup', 'eat_cereal', 'drink_soup', 'chicken_soup']
senticnet['hold_sign'] = [0, 0, 0.95, -0.822, '#angry', '#disgusting', -0.591, 'political_statement', 'go_against', 'picket', 'anti', 'petition']
senticnet['hold_small_item'] = [-0.023, 0.169, -0.059, 0.249, '#interesting', '#admirable', 0.112, 'hold_flower', 'put_stuff', 'carry_item', 'hold_stuff', 'carry_stuff']
senticnet['hold_soda'] = [0.948, 0.992, 0, 0.974, '#interesting', '#admirable', 0.971, 'liquid_drink', 'good_drink', 'popular_soda', 'healthy_drink', 'ferment_beverage']
senticnet['hold_soup'] = [0.059, 0, 0.01, 0.061, '#joyful', '#admirable', 0.037, 'hold_cereal', 'hold_salad', 'eat_cereal', 'drink_soup', 'chicken_soup']
senticnet['hold_steady'] = [0.304, 0.339, -0.197, 0.333, '#interesting', '#admirable', 0.26, 'careful', 'reinforce', 'load_bear', 'go_outdoors', 'allowance']
senticnet['hold_strong'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'tighten', 'squeeze', 'keep', 'hold', 'clasp']
senticnet['hold_stuff'] = [0, 0.188, -0.076, 0.285, '#interesting', '#admirable', 0.132, 'carry_item', 'tote', 'carry_book', 'carry_stuff', 'hold_object']
senticnet['hold_together'] = [0.066, -0.14, 0.026, 0.211, '#surprising', '#admirable', 0.13, 'bind_together', 'fasten_two_objects_together', 'sharp_nail', 'tie_together', 'put']
senticnet['hold_trash'] = [-0.047, -0.019, 0, -0.124, '#sad', '#disgusting', -0.051, 'put_garbage', 'store_trash', 'put_trash', 'rubbish', 'garbage']
senticnet['hold_trial'] = [0, 0.086, 0, 0, '#interesting', '#interesting', 0.029, 'call_witness', 'become_judge', 'see_justice_done', 'determine_guilt_innocence', 'become_lawyer']
senticnet['hold_two_together'] = [-0.129, 0, -0.092, -0.042, '#sad', '#scared', -0.088, 'collide', 'install_window', 'float_through_air', 'spring_up', 'collision']
senticnet['hold_up'] = [0.055, 0.353, -0.191, 0.338, '#interesting', '#admirable', 0.185, 'tote', 'take', 'hold_stuff', 'bring', 'carry']
senticnet['hold_up_office'] = [0.049, 0.078, 0, 0.051, '#interesting', '#admirable', 0.059, 'work_in_garden', 'sweatshop', 'workplace', 'courier', 'rendezvous']
senticnet['hold_water'] = [0, 0.184, -0.051, 0.179, '#interesting', '#admirable', 0.104, 'hygroscope', 'absorb_water', 'antiquate', 'molecule', 'tangent']
senticnet['holdall'] = [0, -0.009, 0.045, -0.081, '#angry', '#disgusting', -0.039, 'shoulder_bag', 'pantyhose', 'handbag', 'vanity_case', 'tote_bag']
senticnet['holder'] = [0.04, 0.096, 0.039, 0.134, '#interesting', '#admirable', 0.077, 'hold', 'store_stuff', 'four_sides', 'storage_container', 'storage']
senticnet['holding_cell'] = [-0.606, 0, 0.866, -0.613, '#angry', '#disgusting', -0.695, 'pokey', 'clink', 'slammer', 'jail', 'jailhouse']
senticnet['hole'] = [0.788, -0.605, 0, 0.884, '#joyful', '#admirable', 0.759, 'gap', 'rathole', 'aperture', 'bullet_hole', 'cranny']
senticnet['hole_card'] = [0.522, -0.88, 0, 0.965, '#surprising', '#admirable', 0.789, 'overage', 'crown_jewel', 'security', 'capital', 'assets']
senticnet['hole_center'] = [-0.998, 0, 0.971, 0, '#sad', '#angry', -0.656, 'wedding_band', 'piece_of_jewelry', 'bell_sound', 'hole', 'jewelry']
senticnet['hole_ground'] = [-0.055, -0.009, 0.086, -0.184, '#angry', '#disgusting', -0.105, 'playful_mood', 'rain_forest', 'sadness', 'bad_mood', 'feel_down']
senticnet['hole_slot'] = [0, 0, 0.042, -0.047, '#angry', '#disgusting', -0.03, 'baby', 'small_child', 'lower_standard_live', 'large_family', 'youth']
senticnet['holiday'] = [0.952, 0.772, 0, 0, '#joyful', '#interesting', 0.575, 'party_time', 'new_baby', 'special_day', 'birthday', 'annual_celebration']
senticnet['holiday_shop'] = [0.742, -0.985, 0, 0, '#joyful', '#surprising', 0.576, 'buy_present', 'christmas_shop', 'buy_christmas_present', 'store', 'buy_product']
senticnet['holidaymaker'] = [-0.653, 0, 0.943, -0.756, '#angry', '#disgusting', -0.784, 'rubberneck', 'sightseer', 'excursionist', 'tripper', 'traveler']
senticnet['hollo'] = [0.975, -0.661, 0, 0.813, '#joyful', '#admirable', 0.816, 'cry', 'yell', 'scream', 'shrill', 'call']
senticnet['hollow'] = [0, 0, 0.042, -0.047, '#angry', '#disgusting', -0.03, 'dig', 'excavate', 'cavity', 'hollow_out', 'hole']
senticnet['hollow_out'] = [0, 0, 0.042, -0.047, '#angry', '#disgusting', -0.03, 'dig', 'excavate', 'cavity', 'hollow', 'hole']
senticnet['holocaust'] = [-0.99, 0, 0.518, -0.994, '#sad', '#disgusting', -0.834, 'noxious_gas', 'kill_person', 'gas', 'poison_gas', 'noxious']
senticnet['holster'] = [-0.041, 0, -0.085, -0.208, '#scared', '#disgusting', -0.111, 'gun_store', 'gun_shop', 'arsenal', 'war', 'war_zone']
senticnet['holy'] = [0.754, 0.981, 0, 0.966, '#interesting', '#admirable', 0.9, 'bible', 'prayer', 'philosophy', 'religious', 'spiritual']
senticnet['holy_man'] = [0.803, 0, 0, 0.734, '#joyful', '#admirable', 0.512, 'church_head', 'protestant', 'christian', 'religious_official', 'goddess']
senticnet['holy_matrimony'] = [0.219, 0.233, -0.224, 0.328, '#interesting', '#admirable', 0.185, 'niceness', 'similarity', 'behavior', 'matrimony', 'double_happiness']
senticnet['holy_order'] = [0.546, -0.768, 0, 0.74, '#surprising', '#admirable', 0.685, 'exorcist', 'deacon', 'acolyte', 'anagnost', 'doorkeeper']
senticnet['holy_place'] = [0.872, 0.756, 0, 0.715, '#joyful', '#interesting', 0.781, 'religious_build', 'worship_house', 'worship_place', 'place_of_worship', 'religious_place']
senticnet['holy_terror'] = [-0.625, 0, 0.768, -0.588, '#sad', '#angry', -0.66, 'rascal', 'rapscallion', 'scalawag', 'scallywag', 'monkey']
senticnet['homage'] = [0.781, -0.732, 0, 0.786, '#joyful', '#admirable', 0.766, 'props', 'politeness', 'deference', 'civility', 'court']
senticnet['home'] = [0, -0.069, 0, 0, '#surprising', '#surprising', 0.023, 'rooms', 'apartment', 'furnitures', 'kitchen', 'flats']
senticnet['home_animal'] = [0.727, 0, 0, 0.705, '#joyful', '#admirable', 0.477, 'loyal', 'household_animal', 'house_pet', 'good_pet', 'best_friend']
senticnet['home_build'] = [0, 0.07, 0, 0.125, '#interesting', '#admirable', 0.065, 'live_quarter', 'live_area', 'make_building', 'domestic_dwell', 'small_building']
senticnet['home_decoration'] = [-0.023, 0.087, 0, 0.112, '#interesting', '#admirable', 0.059, 'social_convention', 'cover_floor', 'decoration', 'floor_cover', 'cover_wall']
senticnet['home_depot'] = [0.929, -0.856, 0, 0, '#joyful', '#surprising', 0.595, 'carpet_store', 'lumberyard', 'furniture_store', 'front_porch', 'shoe_shop']
senticnet['home_entrance'] = [0.825, 0, 0, 0.825, '#joyful', '#admirable', 0.55, 'entry', 'build_open', 'house_front', 'hinge', 'entrance_room']
senticnet['home_ground'] = [0.092, -0.091, 0, 0, '#joyful', '#surprising', 0.061, 'sport', 'pitch', 'baseball_bat', 'match', 'collectible']
senticnet['home_improvement'] = [0.116, 0, -0.049, 0.091, '#joyful', '#admirable', 0.053, 'cover_wall', 'wall_cover', 'latex', 'please_eye', 'create_image']
senticnet['home_improvement_store'] = [0.893, -0.759, 0, 0, '#joyful', '#surprising', 0.551, 'under_carpet', 'shoe_shop', 'carpet_store', 'attic', 'closet']
senticnet['home_plate'] = [0, 0.175, -0.063, 0.064, '#interesting', '#admirable', 0.059, 'hideout', 'stronghold', 'safe_place', 'base', 'fort']
senticnet['home_renovation'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'buy_bedroom', 'buy_pillow', 'buy_home_appliance', 'buy_bed_sheet', 'buy_bed']
senticnet['home_run'] = [0.742, 0.995, 0, 0.747, '#interesting', '#admirable', 0.828, 'score_home_run', 'win_game', 'reach_advantage', 'jump_chance', 'compete_against']
senticnet['home_sweet_home'] = [-0.104, 0.235, -0.127, 0.246, '#interesting', '#admirable', 0.083, 'love', 'settle_down', 'family_nest', 'family', 'happy_family']
senticnet['homeland'] = [0, 0.19, -0.066, 0.093, '#interesting', '#admirable', 0.072, 'pride', 'revolution', 'patriot', 'motherland', 'patriotism']
senticnet['homeless'] = [-0.887, 0, 0, -0.737, '#sad', '#disgusting', -0.541, 'bum', 'red_light', 'petition', 'take', 'violent_action']
senticnet['homeless_people'] = [-0.127, 0, -0.063, -0.046, '#sad', '#scared', -0.079, 'graffiti', 'bum', 'homeless_person', 'panhandler', 'homeless']
senticnet['homeless_person'] = [-0.887, 0, 0, -0.737, '#sad', '#disgusting', -0.541, 'homeless_people', 'homeless', 'need_money', 'need_food', 'poor_person']
senticnet['homeless_shelter'] = [-0.767, 0, 0, 0, '#sad', '#sad', -0.256, 'bowl_alley', 'gutter', 'crack_house', 'junction', 'tavern']
senticnet['homeotherm'] = [-0.989, 0, 0.705, -0.93, '#sad', '#disgusting', -0.875, 'animal', 'animate_being', 'beast', 'creature', 'brute']
senticnet['homeowner'] = [0.066, -0.014, 0, 0, '#joyful', '#surprising', 0.027, 'workman', 'man', 'stalactite', 'pauper', 'nazi']
senticnet['homestead'] = [0, 0.113, 0, 0.111, '#interesting', '#admirable', 0.075, 'animal_house', 'cow_home', 'animal_place', 'crop_place', 'acreage']
senticnet['homework'] = [-0.122, 0, 0, -0.155, '#sad', '#disgusting', -0.092, 'go_college', 'study_test', 'sharpen_pencil', 'revise', 'take_test']
senticnet['homicide'] = [0, 0, -0.956, -0.858, '#scared', '#disgusting', -0.605, 'choose_victim', 'murder_weapon', 'hide_evidence', 'murder', 'shoot_gun']
senticnet['homiletics'] = [0.607, -0.997, 0, 0.847, '#surprising', '#admirable', 0.817, 'eristic', 'puppetry', 'artistry', 'aviation', 'airmanship']
senticnet['hominid'] = [0.914, -0.572, 0, 0.908, '#joyful', '#admirable', 0.798, 'primate', 'homo', 'man', 'human_being', 'human']
senticnet['homo'] = [0.537, -0.514, 0, 0.807, '#joyful', '#admirable', 0.619, 'lesbian', 'fairy', 'fagot', 'faggot', 'fag']
senticnet['homoeroticism'] = [0.886, -0.79, 0, 0.584, '#joyful', '#surprising', 0.753, 'sex', 'inversion', 'sexual_inversion', 'lesbianism', 'sapphism']
senticnet['homogeneity'] = [-0.638, 0, 0.822, -0.953, '#angry', '#disgusting', -0.804, 'uniformness', 'homogeneousness', 'consistency', 'consistence', 'similarity']
senticnet['homogeneousness'] = [-0.638, 0, 0.822, -0.953, '#angry', '#disgusting', -0.804, 'homogeneity', 'uniformness', 'consistency', 'consistence', 'similarity']
senticnet['homogenization'] = [-0.773, 0, 0.914, -0.501, '#sad', '#angry', -0.729, 'confluence', 'conflux', 'merging', 'blending', 'combination']
senticnet['homoiotherm'] = [-0.91, 0, 0.958, -0.5, '#sad', '#angry', -0.789, 'animal', 'animate_being', 'beast', 'creature', 'brute']
senticnet['homophile'] = [0.662, -0.746, 0, 0.836, '#surprising', '#admirable', 0.748, 'lesbian', 'fairy', 'fagot', 'faggot', 'fag']
senticnet['homophobia'] = [0, 0.264, 0, 0.246, '#interesting', '#admirable', 0.17, 'christianity', 'judaism', 'religion', 'world_religion', 'catholic_church']
senticnet['homophobic'] = [0, 0, 0, -0.995, '#disgusting', '#disgusting', -0.332, 'uneducated', 'guilty_crime', 'precise', 'strange', 'ignorant']
senticnet['homophony'] = [0.524, -0.751, 0, 0.932, '#surprising', '#admirable', 0.736, 'accent', 'assibilation', 'sibilation', 'mispronunciation', 'pronunciation']
senticnet['homosexual'] = [0.547, -0.858, 0, 0.924, '#surprising', '#admirable', 0.776, 'lesbian', 'fairy', 'fagot', 'faggot', 'fag']
senticnet['homosexualism'] = [0.778, -0.73, 0, 0.559, '#joyful', '#surprising', 0.689, 'sex', 'inversion', 'sexual_inversion', 'lesbianism', 'sapphism']
senticnet['homosexuality'] = [0.591, -0.963, 0, 0.861, '#surprising', '#admirable', 0.805, 'sex', 'inversion', 'sexual_inversion', 'lesbianism', 'sapphism']
senticnet['homotherm'] = [-0.596, 0, 0.79, -0.631, '#angry', '#disgusting', -0.672, 'animal', 'animate_being', 'beast', 'creature', 'brute']
senticnet['honest'] = [0.773, 0.708, 0, 0.961, '#joyful', '#admirable', 0.814, 'good_character', 'virtue', 'truthful', 'good_quality', 'goodness']
senticnet['honestness'] = [0.741, -0.849, 0, 0.543, '#joyful', '#surprising', 0.711, 'integrity', 'righteousness', 'scrupulousness', 'incorruptness', 'incorruption']
senticnet['honesty'] = [0.867, 0, 0, 0.852, '#joyful', '#admirable', 0.573, 'truthful', 'honest', 'integrity', 'goodness', 'virtue']
senticnet['honey'] = [0.744, -0.77, 0, 0.661, '#joyful', '#surprising', 0.725, 'sugarcoat', 'dulcify', 'glaze', 'change_taste', 'sugar']
senticnet['honey_bee'] = [0.815, -0.94, 0, 0, '#joyful', '#surprising', 0.585, 'centerfold', 'genus', 'fairy', 'infant', 'dove']
senticnet['honey_insect'] = [0.03, 0.078, 0, 0.101, '#interesting', '#admirable', 0.07, 'flora', 'live_object', 'species', 'fauna', 'live_organism']
senticnet['honey_locust'] = [-0.856, 0, 0.5, -0.709, '#sad', '#disgusting', -0.688, 'courbaril', 'water_locust', 'swamp_locust', 'locust_tree', 'black_locust']
senticnet['honeycomb'] = [0.039, 0, 0, 0.075, '#joyful', '#admirable', 0.038, 'hive', 'ration', 'nutrient', 'result_cook', 'noodle']
senticnet['honeyed'] = [0.704, -0.502, 0, 0.923, '#joyful', '#admirable', 0.71, 'mellifluous', 'mellisonant', 'dulcet', 'lyrical', 'melodic']
senticnet['honeymoon'] = [0.878, 0.84, 0, 0.91, '#joyful', '#admirable', 0.876, 'stumble', 'slip', 'fall', 'trip', 'tumble']
senticnet['honeymooner'] = [0.869, -0.535, 0, 0.772, '#joyful', '#admirable', 0.725, 'bride', 'groom', 'bridegroom', 'spouse', 'partner']
senticnet['honk'] = [0.691, -0.973, 0, 0.771, '#surprising', '#admirable', 0.812, 'squeal', 'blate', 'churr', 'let_loose', 'sibilate']
senticnet['honk_horn'] = [-0.085, -0.07, 0.045, -0.122, '#sad', '#disgusting', -0.061, 'shift_gear', 'turn_steer_wheel', 'stop_stop_sign', 'stop_red_light', 'discover_new_place']
senticnet['honkey'] = [-0.934, 0, 0.77, -0.792, '#sad', '#disgusting', -0.832, 'whitey', 'honky', 'caucasian', 'honkie', 'mortal']
senticnet['honkie'] = [-0.934, 0, 0.77, -0.792, '#sad', '#disgusting', -0.832, 'whitey', 'honky', 'honkey', 'caucasian', 'mortal']
senticnet['honky'] = [-0.934, 0, 0.77, -0.792, '#sad', '#disgusting', -0.832, 'whitey', 'caucasian', 'honkey', 'honkie', 'mortal']
senticnet['honkytonk'] = [-0.803, 0, 0.508, -0.805, '#sad', '#disgusting', -0.705, 'cabaret', 'nightclub', 'night_club', 'club', 'nightspot']
senticnet['honor'] = [0.857, 0.824, 0, 0.708, '#joyful', '#interesting', 0.796, 'mandatory', 'gentleman', 'obey', 'virtue', 'dignity']
senticnet['honor_parent'] = [-0.13, 0, -0.066, -0.028, '#sad', '#scared', -0.075, 'throw_fit', 'watch_d', 'sun_oneself', 'battle_illness', 'laugh_clown']
senticnet['honor_person'] = [0, 0.715, 0, 0.941, '#interesting', '#admirable', 0.552, 'remember', 'contemplation', 'remember_past', 'use_memory', 'commemorate_event']
senticnet['honorable'] = [0.739, 0.995, 0, 0, '#joyful', '#interesting', 0.578, 'ethical', 'honest', 'good', 'estimable', 'fair']
senticnet['honorable_mention'] = [0.682, -0.705, 0, 0.98, '#surprising', '#admirable', 0.789, 'prize', 'seal_of_approval', 'laurels', 'aliyah', 'cachet']
senticnet['honorableness'] = [0.66, -0.842, 0, 0.712, '#surprising', '#admirable', 0.738, 'respectability', 'reputability', 'venerability', 'venerableness', 'righteousness']
senticnet['honored'] = [0.991, -0.989, 0, 0.588, '#joyful', '#surprising', 0.856, 'estimable', 'respected', 'esteemed', 'reputable', 'prestigious']
senticnet['honoring'] = [0.559, -0.839, 0, 0.593, '#surprising', '#admirable', 0.664, 'abidance', 'compliance', 'punctilio', 'conformity', 'conformation']
senticnet['honourableness'] = [0.909, -0.854, 0, 0.846, '#joyful', '#surprising', 0.87, 'respectability', 'reputability', 'venerability', 'venerableness', 'righteousness']
senticnet['hooch'] = [0.765, 0.919, 0, 0.778, '#interesting', '#admirable', 0.821, 'get_hired', 'win_hand', 'alcohol', 'booze', 'dance']
senticnet['hood'] = [-0.95, 0, 0.699, -0.725, '#sad', '#disgusting', -0.791, 'criminal', 'bully', 'outlaw', 'malefactor', 'felon']
senticnet['hooded_skunk'] = [-0.547, 0, 0.768, -0.503, '#sad', '#angry', -0.606, 'striped_skunk', 'polecat', 'hognosed_skunk', 'badger_skunk', 'rooter_skunk']
senticnet['hoodlum'] = [-0.933, 0, 0.576, -0.589, '#sad', '#disgusting', -0.699, 'criminal', 'bully', 'outlaw', 'malefactor', 'felon']
senticnet['hooey'] = [-0.636, 0, 0.796, -0.788, '#angry', '#disgusting', -0.74, 'meaninglessness', 'nonsense', 'bunk', 'nonsensicality', 'hokum']
senticnet['hoof_animal'] = [0, -0.021, 0, 0.06, '#surprising', '#admirable', 0.027, 'male_cow', 'donkey', 'little_horse', 'baby_cow', 'animal']
senticnet['hoof_mammal'] = [0.029, 0, 0.018, 0.059, '#joyful', '#admirable', 0.023, 'domestic_animal', 'wild_animal', 'big_animal', 'large_mammal', 'animal']
senticnet['hoofing'] = [0.764, -0.526, 0, 0.866, '#joyful', '#admirable', 0.719, 'tap_dancing', 'tap_dance', 'bachata', 'dance', 'salsa']
senticnet['hook'] = [0.854, -0.955, 0, 0.554, '#joyful', '#surprising', 0.788, 'forbidden_fruit', 'allurement', 'enticement', 'sweetener', 'influence']
senticnet['hook_up'] = [0.192, -0.161, 0.055, -0.032, '#joyful', '#surprising', 0.089, 'serve_drink', 'go_club', 'drink_beer', 'get_wasted', 'socialize']
senticnet['hook_up_with'] = [-0.838, 0, 0.64, -0.536, '#sad', '#angry', -0.671, 'marry', 'get_married', 'wed', 'conjoin', 'mismarry']
senticnet['hooker'] = [0.094, 0, 0, 0, '#joyful', '#joyful', 0.031, 'exit', 'registry_office', 'restaurant_entrance', 'elevator', 'treadmill']
senticnet['hooks'] = [0.883, -0.593, 0, 0.533, '#joyful', '#surprising', 0.67, 'hand', 'meat_hand', 'maulers', 'right', 'left']
senticnet['hooky_player'] = [-0.514, 0, 0.63, -0.842, '#angry', '#disgusting', -0.662, 'absentee', 'truant', 'defaulter', 'exile', 'expatriate']
senticnet['hooligan'] = [-0.896, 0, 0.933, -0.932, '#angry', '#disgusting', -0.92, 'bullyboy', 'muscleman', 'muscle', 'skinhead', 'skin']
senticnet['hooliganism'] = [-0.595, 0, 0.567, -0.959, '#sad', '#disgusting', -0.707, 'devilment', 'roguery', 'mischief', 'shenanigan', 'deviltry']
senticnet['hoop'] = [-0.029, 0.075, 0, 0.059, '#interesting', '#admirable', 0.035, 'gather_team', 'form_team', 'buy_ball', 'suit_up', 'basketball_hoop']
senticnet['hoosegow'] = [0.977, -0.556, 0, 0.679, '#joyful', '#admirable', 0.737, 'lockup', 'holding_cell', 'workhouse', 'bastille', 'gaol']
senticnet['hoot'] = [-0.744, 0, 0.585, -0.599, '#sad', '#disgusting', -0.643, 'outcry', 'call', 'cry', 'yell', 'shout']
senticnet['hootch'] = [-0.831, 0, 0.647, -0.946, '#sad', '#disgusting', -0.808, 'intoxicant', 'pruno', 'alcohol', 'alcoholic_drink', 'alcoholic_beverage']
senticnet['hop'] = [0.023, 0, 0, 0.102, '#joyful', '#admirable', 0.042, 'jump', 'move_slowly', 'leap', 'revolve', 'sway']
senticnet['hope'] = [0, 0.892, 0, 0, '#interesting', '#interesting', 0.297, 'worship', 'trust', 'optimism', 'devotion', 'believe']
senticnet['hope_peace'] = [0.701, 0.764, 0, 0.828, '#interesting', '#admirable', 0.764, 'gather_berry', 'hang_picture_on_wall', 'see_star_night', 'need_go_bathroom', 'wave_flag']
senticnet['hope_win'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'expectation', 'optimism', 'win_game', 'dream_victory', 'wish_success']
senticnet['hopeful'] = [0.315, 0.687, -0.297, 0.224, '#joyful', '#interesting', 0.31, 'hopefully', 'anticipate', 'affectionate', 'fond', 'lovesome']
senticnet['hopefully'] = [0.37, 0.686, -0.286, 0.233, '#joyful', '#interesting', 0.334, 'hopeful', 'anticipate', 'hopefulness', 'affectionateness', 'affectional']
senticnet['hopefulness'] = [0.475, 0.684, -0.271, 0.263, '#joyful', '#interesting', 0.384, 'optimistically', 'optimistic', 'encouragingly', 'encouraging', 'bucked_up']
senticnet['hopeless'] = [-0.875, 0, 0.943, -0.862, '#sad', '#angry', -0.893, 'fearful', 'dreadful', 'humiliate', 'hysteria', 'dumb']
senticnet['hopelessly'] = [-0.848, 0, -0.75, 0, '#sad', '#scared', -0.533, 'dispiritedly', 'hopelessness', 'despairing', 'pessimistically', 'pessimistic']
senticnet['hopelessness'] = [-0.935, 0, -0.843, 0, '#sad', '#scared', -0.593, 'dispiritedly', 'hopelessly', 'despairing', 'pessimistically', 'pessimistic']
senticnet['hoper'] = [0.694, -0.745, 0, 0.83, '#surprising', '#admirable', 0.756, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['horizon'] = [0, -0.987, 0, 0.859, '#surprising', '#admirable', 0.615, 'porpoise', 'many_fishes', 'seahorse', 'sea_wee', 'mermaid']
senticnet['horizontal_plane'] = [-0.097, 0, 0.033, 0, '#sad', '#angry', -0.043, 'cover_ground', 'build_ground', 'underfoot', 'wood_board', 'basis']
senticnet['horizontal_surface'] = [0.058, 0, 0.045, 0.078, '#joyful', '#admirable', 0.03, 'sleep_area', 'sleep_place', 'comfy', 'rest_place', 'occur']
senticnet['hormone'] = [0.78, 0.959, 0, 0, '#joyful', '#interesting', 0.58, 'feeling', '32_teeth', 'gone_moon', 'competitive_nature', 'two_ears']
senticnet['horn'] = [0.063, 0.089, 0.036, 0.146, '#interesting', '#admirable', 0.087, 'antler', 'jew_harp', 'brass_instrument', 'trumpet', 'crash_cymbal']
senticnet['hornet'] = [-0.663, 0, 0.946, -0.554, '#sad', '#angry', -0.721, 'yellow_hornet', 'yellow_jacket', 'giant_hornet', 'vespid', 'vespid_wasp']
senticnet['horny'] = [0.132, 0.115, -0.063, 0.121, '#joyful', '#admirable', 0.102, 'make_person', 'survival_species', 'make_baby', 'lover', 'man_wife']
senticnet['horrendous'] = [-0.785, 0, -0.985, 0, '#sad', '#scared', -0.59, 'dire', 'fearsome', 'dreaded', 'direful', 'frightening']
senticnet['horrible'] = [-0.939, 0, -0.935, -0.942, '#sad', '#disgusting', -0.939, 'dread', 'distressed', 'terrible', 'dismay', 'uneasiness']
senticnet['horribly'] = [-0.99, 0, -0.902, 0, '#sad', '#scared', -0.631, 'horrifying', 'atrocious', 'dreadfully', 'horrifyingly', 'horrified']
senticnet['horrid'] = [-0.231, 0.235, 0.456, -0.571, '#angry', '#disgusting', -0.341, 'outrageous', 'queasy', 'misanthropical', 'misanthropic', 'sulky']
senticnet['horridly'] = [-0.856, 0, -0.762, 0, '#sad', '#scared', -0.539, 'horrifying', 'atrocious', 'dreadfully', 'horrifyingly', 'horrified']
senticnet['horrific'] = [-0.341, 0.317, 0.205, -0.431, '#sad', '#disgusting', -0.22, 'discouraging', 'misanthropic', 'misanthropical', 'discouraged', 'outrageous']
senticnet['horrified'] = [-0.972, 0, -0.971, 0, '#sad', '#scared', -0.648, 'horrifying', 'atrocious', 'dreadfully', 'horrifyingly', 'horribly']
senticnet['horrify'] = [-0.761, 0, -0.829, 0, '#sad', '#scared', -0.53, 'appall', 'horror', 'horrifying', 'atrocious', 'horrifyingly']
senticnet['horrifying'] = [-0.791, 0, -0.867, 0, '#sad', '#scared', -0.553, 'atrocious', 'dreadfully', 'horrifyingly', 'horrified', 'horribly']
senticnet['horrifyingly'] = [-0.981, 0, -0.723, 0, '#sad', '#scared', -0.568, 'horrifying', 'atrocious', 'dreadfully', 'horrified', 'horribly']
senticnet['horripilation'] = [-0.689, 0, 0.601, -0.806, '#sad', '#disgusting', -0.699, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['horror'] = [-0.977, 0, -0.819, -0.953, '#sad', '#disgusting', -0.916, 'dislike', 'loathe', 'queasy', 'horrid', 'outrageous']
senticnet['horror-stricken'] = [-0.94, 0, -0.811, 0, '#sad', '#scared', -0.584, 'horrifying', 'atrocious', 'dreadfully', 'horrifyingly', 'horrified']
senticnet['horror-struck'] = [-0.929, 0, -0.846, 0, '#sad', '#scared', -0.592, 'horrifying', 'atrocious', 'dreadfully', 'horrifyingly', 'horrified']
senticnet['horror_movie'] = [-0.087, -0.012, -0.163, -0.13, '#scared', '#disgusting', -0.123, 'hockey_game', 'movie', 'scary_movie', 'cinema', 'cctv']
senticnet['horse'] = [0, 0, 0, 0.071, '#admirable', '#admirable', 0.024, 'two_barbs', 'barb', 'mule', 'buddhist', 'ride_barb']
senticnet['horse_chestnut'] = [-0.579, 0, 0.582, -0.65, '#angry', '#disgusting', -0.604, 'sweet_buckeye', 'dwarf_buckeye', 'bottlebrush_buckeye', 'red_buckeye', 'particolored_buckeye']
senticnet['horse_fancier'] = [-0.615, 0, 0.606, -0.539, '#sad', '#angry', -0.587, 'enthusiast', 'cat_fancier', 'horseman', 'animal_fancier', 'fancier']
senticnet['horse_farm'] = [0.046, -0.025, 0, 0, '#joyful', '#surprising', 0.024, 'dairy', 'milk_product', 'salad_dress', 'food_production', 'farm']
senticnet['horse_movie'] = [0.845, -0.896, 0, 0, '#joyful', '#surprising', 0.58, 'saloon', 'metal_detector', 'box_ring', 'minibar', 'war_zone']
senticnet['horse_sense'] = [0.525, -0.704, 0, 0.848, '#surprising', '#admirable', 0.692, 'road_sense', 'sagacity', 'sagaciousness', 'logic', 'nous']
senticnet['horse_shoes'] = [0.037, 0.148, 0, 0.212, '#interesting', '#admirable', 0.132, 'horseshoe', 'four_leaf_clover', 'rotary_phone', 'ping_pong', 'billiards']
senticnet['horseback'] = [0.064, 0, 0, 0.123, '#joyful', '#admirable', 0.062, 'horse', 'passenger_car', 'car_action', 'conveyance', 'car_travel']
senticnet['horseback_ride'] = [0.046, -0.035, 0, 0, '#joyful', '#surprising', 0.027, 'anarchy', 'play_marble', 'dinner_party', 'spray_paint_grafitti', 'family_activity']
senticnet['horseback_rider'] = [0, 0.803, 0, 0.77, '#interesting', '#admirable', 0.524, 'business_man', 'artwork', 'peace_sign', 'logo', 'captive']
senticnet['horsehair_wig'] = [-0.848, 0, 0.633, -0.539, '#sad', '#angry', -0.673, 'grizzle', 'postiche', 'wig', 'periwig', 'peruke']
senticnet['horseleech'] = [-0.716, 0, 0.605, -0.623, '#sad', '#disgusting', -0.648, 'medicinal_leech', 'leech', 'annelid', 'annelid_worm', 'segmented_worm']
senticnet['horseman'] = [-0.615, 0, 0.606, -0.539, '#sad', '#angry', -0.587, 'enthusiast', 'cat_fancier', 'animal_fancier', 'horse_fancier', 'fancier']
senticnet['horsemanship'] = [0.798, -0.542, 0, 0.552, '#joyful', '#admirable', 0.631, 'acquirement', 'skill', 'accomplishment', 'acquisition', 'attainment']
senticnet['horseradish'] = [-0.086, -0.075, 0.029, -0.178, '#sad', '#disgusting', -0.073, 'sour_milk', 'moldy_food', 'mayonnaise', 'box_cereal', 'bottle_water']
senticnet['horseshit'] = [-0.709, 0, 0.668, -0.6, '#sad', '#angry', -0.659, 'rot', 'bunk', 'bunkum', 'buncombe', 'guff']
senticnet['horseshoe'] = [0.035, -0.108, 0.026, 0, '#joyful', '#surprising', 0.039, 'helium_balloon', 'most_balls', 'ball', 'roller_coaster', 'dart_board']
senticnet['horseshoer'] = [0, 0.115, 0, 0.105, '#interesting', '#admirable', 0.073, 'farrier', 'miner', 'blacksmith', 'locksmith', 'smith']
senticnet['hosanna'] = [0.6, -0.928, 0, 0.601, '#surprising', '#admirable', 0.71, 'cry', 'yell', 'call', 'outcry', 'shout']
senticnet['hospice'] = [-0.628, 0, 0.987, -0.742, '#angry', '#disgusting', -0.786, 'disinfection', 'treatment', 'medical_aid', 'digitalization', 'bloodletting']
senticnet['hospitable'] = [0.957, 0.907, 0, 0.844, '#joyful', '#interesting', 0.903, 'celebrate_special_occasion', 'express_appreciation', 'celebrate_holiday', 'make_smile', 'celebrate_birthday']
senticnet['hospital'] = [-0.026, 0, -0.158, -0.146, '#scared', '#disgusting', -0.11, 'doctor_office', 'clinic', 'medical_office', 'emergency_room', 'doctor']
senticnet['hospital_room'] = [0.839, -0.89, 0, 0.687, '#joyful', '#surprising', 0.805, 'emergency_room', 'room', 'operating_room', 'operating_theater', 'surgery']
senticnet['hospitalize'] = [-0.87, 0, -0.757, 0, '#sad', '#scared', -0.542, 'influenza', 'cripple', 'overpay', 'ill_health', 'diabetes']
senticnet['host'] = [0, 0.084, 0, 0.083, '#interesting', '#admirable', 0.056, 'home_sweet_home', 'guest', 'take_care', 'offer_accommodation', 'show_around']
senticnet['host_party'] = [0.922, 0.765, 0, 0, '#joyful', '#interesting', 0.562, 'make_friend', 'relax_friend', 'skilled', 'social_event', 'breed']
senticnet['hostage'] = [-0.95, 0, -0.896, 0, '#sad', '#scared', -0.615, 'specialist', 'prisoner', 'connoisseur', 'accomplice', 'egalitarian']
senticnet['hostel'] = [0.931, -0.745, 0, 0.729, '#joyful', '#surprising', 0.802, 'caravansary', 'caravanserai', 'khan', 'caravan_inn', 'imaret']
senticnet['hostess'] = [0, -0.013, 0.025, -0.06, '#angry', '#disgusting', -0.024, 'chef_special', 'bottle_soda', 'dispense', 'bottle_wine', 'waiter']
senticnet['hostile'] = [0, 0.161, 0.7, -0.657, '#angry', '#disgusting', -0.399, 'ill_will', 'enmity', 'vindictive', 'despiteful', 'vindictively']
senticnet['hostilely'] = [0, 0.149, 0.719, -0.664, '#angry', '#disgusting', -0.411, 'belligerently', 'antagonism', 'class_feeling', 'aggressiveness', 'animus']
senticnet['hostility'] = [0, 0, -0.859, -0.936, '#scared', '#disgusting', -0.598, 'aggression', 'animosity', 'aggressive', 'malice', 'grudge']
senticnet['hot'] = [0, 0, -0.858, -0.992, '#scared', '#disgusting', -0.617, 'heat', 'hot_weather', 'hotness', 'hot_temperature', 'high_temperature']
senticnet['hot-air_balloon'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'balloon', 'float_through_air', 'air', 'float', 'luna_park']
senticnet['hot_air'] = [-0.959, 0, 0.218, -0.938, '#sad', '#disgusting', -0.705, 'steam', 'hot', 'fire', 'heat', 'sweat']
senticnet['hot_air_balloon'] = [-0.045, 0.092, 0, 0.062, '#interesting', '#admirable', 0.036, 'hangar', 'blimp', 'aircraft_carrier', 'war_museum', 'spaceship']
senticnet['hot_babe'] = [0.902, 0.995, 0, 0, '#joyful', '#interesting', 0.632, 'beautiful_girl', 'hen_baby', 'slang_woman', 'hen_child', 'bird']
senticnet['hot_chick'] = [0, -0.009, -0.093, -0.069, '#scared', '#disgusting', -0.051, 'jew', 'atheist', 'computer_user', 'fastener_binder', 'monitor']
senticnet['hot_chocolate'] = [0, -0.069, 0, 0, '#surprising', '#surprising', 0.023, 'coffee', 'table', 'coffee_shop', 'coffee_house', 'coffee_table']
senticnet['hot_cross_bun'] = [-0.843, 0, 0.713, -0.636, '#sad', '#angry', -0.731, 'cross_bun', 'coffee_roll', 'bear_paw', 'bear_claw', 'bun']
senticnet['hot_day'] = [0.085, 0.107, -0.081, 0, '#joyful', '#interesting', 0.037, 'hot_sun', 'hot_weather', 'hot', 'bright_light', 'light']
senticnet['hot_dog'] = [0.028, -0.073, 0, 0, '#joyful', '#surprising', 0.034, 'casserole', 'meatloaf', 'delicious_meal_bun', 'hamburger', 'delicious_meal']
senticnet['hot_dog_bun'] = [0, -0.068, 0, 0, '#surprising', '#surprising', 0.023, 'meatloaf', 'hot_dog', 'delicious_meal', 'eat_hamburger', 'old_lady_house']
senticnet['hot_faucet'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'faucet_overflow', 'dirty_dish', 'hot_tap', 'faucet', 'washcloth']
senticnet['hot_girl'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'appear_beautiful', 'good_looking', 'good_appearance', 'beauty', 'enjoy_view']
senticnet['hot_liquid'] = [0.079, 0.071, 0, 0, '#joyful', '#interesting', 0.05, 'broth', 'hearty', 'serve_hot', 'liquid_food', 'porridge']
senticnet['hot_meal'] = [0.206, 0.093, 0.049, 0.143, '#joyful', '#admirable', 0.131, 'good_meal', 'delicious_food', 'broth', 'meal', 'liquid_food']
senticnet['hot_summer'] = [0, 0, -0.916, -0.901, '#scared', '#disgusting', -0.606, 'appear_beautiful', 'stand_alone', 'rush_job', 'forward_email', 'deal_card_player']
senticnet['hot_sun'] = [0, 0, -0.714, -0.754, '#scared', '#disgusting', -0.489, 'illumination', 'hot_day', 'hot', 'yellow_orange', 'hot_weather']
senticnet['hot_table'] = [0.92, 0.985, 0, 0, '#joyful', '#interesting', 0.635, 'good_meal', 'chef_special', 'special', 'plate_silverware', 'chopstick']
senticnet['hot_tap'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'faucet_overflow', 'hot_faucet', 'dirty_dish', 'faucet', 'washcloth']
senticnet['hot_temperature'] = [-0.849, 0, -0.729, -0.883, '#sad', '#disgusting', -0.82, 'high_temperature', 'heat', 'feel_sick', 'fever', 'char']
senticnet['hot_water'] = [-0.873, 0, 0.673, -0.553, '#sad', '#angry', -0.7, 'plight', 'difficulty', 'care', 'corner', 'box']
senticnet['hot_water_heater'] = [0.02, 0.076, 0, 0, '#joyful', '#interesting', 0.032, 'land_earth', 'tidal_wave', 'puddle', 'brine', 'spurt']
senticnet['hot_weather'] = [0, 0, -0.741, -0.986, '#scared', '#disgusting', -0.576, 'hot', 'hotness', 'high_temperature', 'heat', 'hot_temperature']
senticnet['hot_woman'] = [0.053, 0.091, 0, 0.152, '#interesting', '#admirable', 0.099, 'slang_woman', 'hen_baby', 'baby_chicken', 'hot_babe', 'cute']
senticnet['hotdog'] = [0.662, -0.636, 0, 0.628, '#joyful', '#surprising', 0.642, 'knackwurst', 'knockwurst', 'salami', 'frank', 'sausage']
senticnet['hotel'] = [-0.075, 0, 0.009, -0.125, '#sad', '#disgusting', -0.07, 'check_out', 'travel', 'holiday', 'go_home', 'staycation']
senticnet['hotel_bathroom'] = [0, -0.106, 0, 0, '#surprising', '#surprising', 0.035, 'washroom', 'bath_robe', 'toilet', 'bathroom', 'bathroom_drawer']
senticnet['hotel_receptionist'] = [0.141, -0.125, -0.063, -0.06, '#joyful', '#surprising', 0.048, 'emergency_ward', 'dentist', 'receptionist', 'reception', 'receptionist_call']
senticnet['hotel_room'] = [-0.067, 0, -0.07, -0.036, '#sad', '#scared', -0.058, 'live_room', 'living_room', 'seat_many_person', 'furniture_store', 'loft']
senticnet['hotfoot'] = [-0.978, 0, 0.504, -0.52, '#sad', '#disgusting', -0.667, 'rush', 'race', 'push_forward', 'hasten', 'hie']
senticnet['hothead'] = [-0.579, 0, 0.711, -0.995, '#angry', '#disgusting', -0.762, 'grouch', 'grump', 'crosspatch', 'churl', 'crank']
senticnet['hotheaded'] = [0, 0, 0.825, -0.703, '#angry', '#disgusting', -0.509, 'impulsive', 'tearaway', 'incautious', 'madcap', 'impetuous']
senticnet['hotness'] = [0.1, 0.085, 0, 0.093, '#joyful', '#admirable', 0.093, 'high_temperature', 'hot', 'hot_weather', 'fire_product', 'heat']
senticnet['hotspot'] = [-0.998, 0, 0.714, 0, '#sad', '#angry', -0.571, 'slow_speed', 'wifi', 'computer_internet_connection', 'internet_connection', 'boot_up_computer']
senticnet['hound'] = [0, 0, 0.022, -0.08, '#angry', '#disgusting', -0.034, 'kind_animal', 'wild_animal', 'predator', 'feline', 'fang']
senticnet['hour'] = [0.1, 0.085, 0, 0.093, '#joyful', '#admirable', 0.093, 'watch', 'clock', 'hourglass', 'minute', 'stopwatch']
senticnet['hourglass'] = [0.1, 0.085, 0, 0.093, '#joyful', '#admirable', 0.093, 'watch', 'clock', 'hour', 'minute', 'stopwatch']
senticnet['houri'] = [-0.805, 0, 0.747, -0.748, '#sad', '#disgusting', -0.767, 'mythical_monster', 'mythical_creature', 'hero', 'mythical_being', 'halcyon']
senticnet['hours'] = [0.769, -0.614, 0, 0.746, '#joyful', '#admirable', 0.71, 'day', 'period', 'work_time', 'face_time', 'workweek']
senticnet['house'] = [0.82, 0.976, 0, 0, '#joyful', '#interesting', 0.599, 'capitol', 'government_building', 'apartment_house', 'white_apartment_house', 'government']
senticnet['house_animal'] = [0.711, 0.792, 0, 0.93, '#interesting', '#admirable', 0.811, 'carnivore', 'good_pet', 'household_animal', 'large_cat', 'small_elephant']
senticnet['house_area'] = [0, 0, 0, 0.092, '#admirable', '#admirable', 0.031, 'room', 'inside_house', 'house_part', 'square_shape', 'four_walls']
senticnet['house_car'] = [0.036, 0.155, -0.048, 0.166, '#interesting', '#admirable', 0.103, 'house_land', 'personal_belong', 'decorate', 'real_estate', 'have_something']
senticnet['house_fire'] = [-0.773, 0, -0.733, 0, '#sad', '#scared', -0.502, 'terminal_illness', 'suffer_fool', 'ill_health', 'lyme_disease', 'censorship']
senticnet['house_front'] = [0.71, 0, 0, 0.711, '#joyful', '#admirable', 0.474, 'home_entrance', 'entry', 'build_open', 'house_open', 'house_part']
senticnet['house_land'] = [0, 0.173, -0.045, 0.185, '#interesting', '#admirable', 0.104, 'estate', 'house_place', 'real_estate', 'house_location', 'area_land']
senticnet['house_location'] = [0.021, 0.106, 0.014, 0.172, '#interesting', '#admirable', 0.095, 'house_place', 'house', 'live_area', 'live_quarter', 'part_of_building']
senticnet['house_look_better'] = [0.73, 0, 0, 0, '#joyful', '#joyful', 0.243, 'kill_spider', 'tidiness', 'remove_spot', 'house', 'free_sex']
senticnet['house_mouse'] = [-0.55, 0, 0.955, -0.96, '#angry', '#disgusting', -0.822, 'mouse', 'harvest_mouse', 'field_mouse', 'fieldmouse', 'nude_mouse']
senticnet['house_of_cards'] = [0.681, -0.851, 0, 0.605, '#joyful', '#surprising', 0.712, 'contrivance', 'bubble', 'strategy', 'stratagem', 'waiting_game']
senticnet['house_of_prostitution'] = [0.754, -0.823, 0, 0.947, '#surprising', '#admirable', 0.841, 'whorehouse', 'brothel', 'bordello', 'bagnio', 'massage_parlor']
senticnet['house_open'] = [0, 0.074, 0.018, 0.13, '#interesting', '#admirable', 0.062, 'build_open', 'open_close', 'house_front', 'aperture', 'portal']
senticnet['house_part'] = [0, 0.928, 0, 0.889, '#interesting', '#admirable', 0.606, 'part_of_house', 'house_front', 'house_open', 'house_area', 'inside_house']
senticnet['house_person'] = [0.054, 0.124, -0.106, 0.158, '#interesting', '#admirable', 0.077, 'live_life', 'no_place', 'family_live', 'raise_family', 'residence']
senticnet['house_pet'] = [0.727, 0, 0, 0.705, '#joyful', '#admirable', 0.477, 'loyal', 'household_animal', 'best_friend', 'good_pet', 'home_animal']
senticnet['house_place'] = [0.031, 0.117, 0, 0.184, '#interesting', '#admirable', 0.111, 'house_location', 'house', 'part_of_building', 'live_area', 'live_quarter']
senticnet['house_roof'] = [0.037, 0.096, 0, 0.063, '#interesting', '#admirable', 0.065, 'slope', 'incline', 'slant', 'ramp', 'mountain_side']
senticnet['house_smell_good'] = [-0.088, -0.046, 0.023, -0.076, '#sad', '#disgusting', -0.047, 'tier', 'make_toast', 'spoilage', 'get_hot', 'bread_crumb']
senticnet['house_wife'] = [0.033, -0.073, 0, 0, '#joyful', '#surprising', 0.035, 'female', 'girl', 'mother', 'woman', 'girlfriend']
senticnet['house_yard'] = [0.062, 0.135, 0, 0.161, '#interesting', '#admirable', 0.119, 'live_environment', 'house_land', 'residence', 'house_location', 'estate']
senticnet['housebreaker'] = [-0.846, 0, 0.96, -0.91, '#angry', '#disgusting', -0.905, 'housewrecker', 'wrecker', 'knacker', 'laborer', 'manual_laborer']
senticnet['houseclean'] = [0.971, -0.535, 0, 0.665, '#joyful', '#admirable', 0.724, 'tidy', 'tidy_up', 'clean_up', 'neaten', 'straighten']
senticnet['housecraft'] = [0.921, -0.615, 0, 0.91, '#joyful', '#admirable', 0.815, 'craftsmanship', 'tradecraft', 'watercraft', 'acquirement', 'skill']
senticnet['household'] = [0.051, 0.112, 0, 0, '#joyful', '#interesting', 0.054, 'neighbor', 'family_reunion', 'clan', 'desire', 'little_specific']
senticnet['household_animal'] = [0.727, 0, 0, 0.705, '#joyful', '#admirable', 0.477, 'loyal', 'best_friend', 'house_pet', 'good_pet', 'home_animal']
senticnet['household_pet'] = [-0.025, 0, 0.044, 0, '#sad', '#angry', -0.023, 'large_cat', 'carnivore', 'fast_person', 'big_cat', 'good_pet']
senticnet['housekeeper'] = [0, 0, 0, 0.075, '#admirable', '#admirable', 0.025, 'healthy_person', 'philanthropist', 'nazi', 'pervert', 'programmer']
senticnet['housewife'] = [0.051, 0.112, 0, 0, '#joyful', '#interesting', 0.054, 'wife', 'woman', 'mother', 'family', 'good_wife']
senticnet['housewrecker'] = [-0.846, 0, 0.96, -0.91, '#angry', '#disgusting', -0.905, 'wrecker', 'housebreaker', 'knacker', 'laborer', 'manual_laborer']
senticnet['hovel'] = [0.846, -0.665, 0, 0.941, '#joyful', '#admirable', 0.817, 'hut', 'mudhif', 'hutch', 'shack', 'shanty']
senticnet['hover'] = [0.056, 0.105, 0.786, -0.681, '#angry', '#disgusting', -0.435, 'huffishness', 'sulkiness', 'sulk', 'loom', 'bulk_large']
senticnet['how_far'] = [0.045, 0.092, 0.06, 0.22, '#interesting', '#admirable', 0.099, 'distance_measure', 'distance', 'space_between', 'length_measurement', 'measurement_unit']
senticnet['howl'] = [-0.502, 0, 0.611, -0.752, '#angry', '#disgusting', -0.622, 'waul', 'wail', 'ululate', 'roar', 'yawl']
senticnet['howl_laughter'] = [0.778, -1.0, 0, 0, '#joyful', '#surprising', 0.593, 'make_someone_laugh', 'break_silence', 'laugh_joke', 'laugh', 'thank']
senticnet['howler'] = [-0.713, 0, 0.83, -0.683, '#sad', '#angry', -0.742, 'gag', 'jest', 'jape', 'joke', 'laugh']
senticnet['howling'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'terrific', 'wondrously', 'tremendous', 'marvelous', 'wondrous']
senticnet['hoyden'] = [0.7, -0.959, 0, 0.531, '#joyful', '#surprising', 0.73, 'girl', 'miss', 'missy', 'young_lady', 'young_woman']
senticnet['hubbard_squash'] = [-0.562, 0, 0.696, -0.964, '#angry', '#disgusting', -0.741, 'squash', 'acorn_squash', 'winter_squash', 'turban_squash', 'butternut_squash']
senticnet['huckster'] = [-0.516, 0, 0.664, -0.532, '#angry', '#disgusting', -0.571, 'seller', 'marketer', 'vender', 'vendor', 'trafficker']
senticnet['hue'] = [0, 0.073, -0.059, 0.067, '#interesting', '#admirable', 0.027, 'hair_color', 'purple', 'violet', 'dark_light', 'blonde']
senticnet['hue_tint'] = [0.735, 0.714, 0, 0, '#joyful', '#interesting', 0.483, 'tint', 'red_blue', 'green_yellow', 'spectrum', 'red_orange']
senticnet['hueless'] = [-0.7, 0, 0.617, -0.523, '#sad', '#angry', -0.613, 'silvery', 'blackish', 'bluish_black', 'achromatic', 'pitchy']
senticnet['huffily'] = [-0.147, 0.152, 0.613, -0.64, '#angry', '#disgusting', -0.416, 'huffy', 'huffiness', 'offense', 'umbrage', 'umbrageous']
senticnet['huffiness'] = [-0.147, 0.152, 0.613, -0.64, '#angry', '#disgusting', -0.416, 'huffy', 'huffily', 'offense', 'umbrage', 'umbrageous']
senticnet['huffish'] = [-0.023, 0.125, 0.728, -0.673, '#angry', '#disgusting', -0.433, 'antagonism', 'class_feeling', 'belligerently', 'hostilely', 'bad_blood']
senticnet['huffishness'] = [0.056, 0.105, 0.786, -0.681, '#angry', '#disgusting', -0.435, 'sulkiness', 'sulk', 'hover', 'loom', 'bulk_large']
senticnet['huffy'] = [-0.147, 0.152, 0.613, -0.64, '#angry', '#disgusting', -0.416, 'huffiness', 'huffily', 'offense', 'umbrage', 'umbrageous']
senticnet['hug'] = [0.929, 0, 0, 0.775, '#joyful', '#admirable', 0.568, 'give_hug', 'show_empathy', 'kiss_other', 'love_oneself', 'fall_love']
senticnet['huge'] = [0, -0.915, 0, 0.788, '#surprising', '#admirable', 0.568, 'big', 'large', 'really_big', 'wide', 'tall']
senticnet['huge_animal'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'brown_bear', 'woodland_creature', 'hairy_animal', 'brown_fur', 'brown_hair']
senticnet['huge_fire'] = [0.038, 0, -0.083, -0.05, '#scared', '#disgusting', -0.032, 'rapid_oxidation', 'fire', 'flame', 'heat_light', 'cinder']
senticnet['huh'] = [-0.2, 0.071, -0.191, 0, '#sad', '#scared', -0.107, 'lethal', 'piece_of_metal', 'gunpowder', 'victim', 'prepare_go_jail']
senticnet['hull'] = [0.042, 0, 0.033, 0.068, '#joyful', '#admirable', 0.026, 'stalin', 'sail_sea', 'yacht', 'seagoing_vessel', 'water_vehicle']
senticnet['hum'] = [0.949, -0.851, 0, 0, '#joyful', '#surprising', 0.6, 'sing_song', 'receive_applause', 'perform_on_stage', 'use_microphone', 'exaggerate']
senticnet['human'] = [0, 0.102, 0, 0, '#interesting', '#interesting', 0.034, 'two_arms', 'belly_button', 'two_ears', 'five_fingers_hand', 'adam_apple']
senticnet['human_action'] = [0.022, 0, 0, 0.186, '#joyful', '#admirable', 0.069, 'vigorous_activity', 'human_movement', 'body_movement', 'fast_movement', 'like_run']
senticnet['human_activity'] = [0.84, 0, 0, 0.726, '#joyful', '#admirable', 0.522, 'fast_movement', 'foot_movement', 'vigorous_activity', 'body_movement', 'move_foot']
senticnet['human_appendage'] = [0, 0.98, 0, 0.751, '#interesting', '#admirable', 0.577, 'body_limb', 'body_member', 'body_appendage', 'extremity', 'body_extremity']
senticnet['human_being'] = [0, 0.076, 0, 0, '#interesting', '#interesting', 0.025, 'person', 'alive', 'investor', 'young_man', 'gardener']
senticnet['human_body'] = [0.026, 0.069, 0, 0, '#joyful', '#interesting', 0.032, 'atom', 'fuse', 'nucleus', 'cell', 'rash']
senticnet['human_cell'] = [0.999, 0.724, 0, 0, '#joyful', '#interesting', 0.574, 'mother_father', 'brother_sister', 'aunt_uncle', 'mom_dad', 'family']
senticnet['human_chest'] = [0, 0, 0, -0.084, '#disgusting', '#disgusting', -0.028, 'human_body', 'body', 'nervous_system', 'normal_human_body', 'crotch']
senticnet['human_child'] = [0.026, 0.203, -0.073, 0.109, '#interesting', '#admirable', 0.088, 'true_believer', 'cleric', 'religious_figure', 'believer', 'gentleman']
senticnet['human_communication'] = [0, 0, 0, 0.164, '#admirable', '#admirable', 0.055, 'verbal_communication', 'orate', 'mouth_move', 'spoken', 'speech']
senticnet['human_condition'] = [-0.217, 0.128, -0.341, 0, '#sad', '#scared', -0.143, 'medical_problem', 'medical_condition', 'ailment', 'caution', 'diagnose']
senticnet['human_contact'] = [0.276, 0.103, 0, 0.255, '#joyful', '#admirable', 0.211, 'mental_health', 'look_sexy', 'a_lot', 'others_understand', 'spread_word']
senticnet['human_death'] = [-0.812, 0, 0.62, -0.565, '#sad', '#angry', -0.666, 'casualty', 'fatal_accident', 'killing', 'violent_death', 'death']
senticnet['human_ear'] = [0.038, -0.174, 0.024, 0.141, '#surprising', '#admirable', 0.11, 'old_technology', 'phone_call', 'baby_born', 'dust_particle', 'computer_chip']
senticnet['human_emotion'] = [0.982, 0.851, 0, 0.902, '#joyful', '#admirable', 0.912, 'passion', 'beloved', 'amour', 'wonderful_feeling', 'pleasant_emotion']
senticnet['human_experience'] = [0, 0.75, 0, 0.888, '#interesting', '#admirable', 0.546, 'life', 'human_life', 'experience', 'sometimes_bad', 'patriot']
senticnet['human_flourishing'] = [0.971, -0.717, 0, 0.656, '#joyful', '#surprising', 0.781, 'wellbeing', 'successfulness', 'eudaimonia', 'upbeat', 'strength']
senticnet['human_fuel'] = [0.043, 0.13, -0.08, 0.105, '#interesting', '#admirable', 0.066, 'necessary_live', 'make_hot', 'flatulence', 'often_red', 'plasma']
senticnet['human_group'] = [0.084, 0.129, -0.048, 0.105, '#interesting', '#admirable', 0.09, 'many_people', 'happy_together', 'group_of_people', 'team_up', 'meet_up']
senticnet['human_hair'] = [0.05, 0.081, 0.012, -0.04, '#joyful', '#interesting', 0.026, 'semi-truck', 'fire_hydrant', 'row_house', 'flight_terminal', 'taxi']
senticnet['human_hand'] = [0.064, 0, 0, 0.057, '#joyful', '#admirable', 0.04, 'keep_hand_warm', 'hand', 'tong', 'finger', 'grasper']
senticnet['human_history'] = [0.046, 0, 0, 0.085, '#joyful', '#admirable', 0.044, 'action_movie', 'history', 'medieval_time', 'part_of_history', 'history_book']
senticnet['human_intelligence'] = [0.081, 0, 0, 0, '#joyful', '#joyful', 0.027, 'bottle_wine', 'table_chair', 'coconut', 'chef_special', 'oatmeal']
senticnet['human_invention'] = [0.028, 0, 0, 0.131, '#joyful', '#admirable', 0.053, 'mechanical_device', 'mechanism', 'complex_machine', 'move_part', 'device']
senticnet['human_language'] = [0, 0, 0, 0.113, '#admirable', '#admirable', 0.038, 'language', 'speech', 'oration', 'phone_conversation', 'say']
senticnet['human_life'] = [0.933, 0.776, 0, 0, '#joyful', '#interesting', 0.57, 'human_experience', 'smart_man', 'human', 'delusional', 'use_illegal_drug']
senticnet['human_limb'] = [-0.04, 0, 0.059, 0, '#sad', '#angry', -0.033, 'lower_body', 'two_feet', 'thigh', 'ten_toes', 'body_limb']
senticnet['human_mass'] = [0.033, 0.143, 0.046, 0.178, '#interesting', '#admirable', 0.103, 'large_amount', 'large_mass', 'small_group', 'many_people', 'body_type']
senticnet['human_memory'] = [-0.029, 0.075, 0, 0.059, '#interesting', '#admirable', 0.035, 'courthouse_look_public_record', 'transportation_device', 'new_caledonia', 'minor_planet', 'poo']
senticnet['human_mind'] = [-0.05, 0.076, -0.055, 0.244, '#interesting', '#admirable', 0.072, 'church_part', 'synagogue', 'steeple', 'chapel', 'cathedral']
senticnet['human_motion'] = [0, 0.069, 0.019, 0.193, '#interesting', '#admirable', 0.081, 'human_movement', 'like_run', 'vigorous_activity', 'get_somewhere_fast', 'fast_movement']
senticnet['human_movement'] = [-0.026, 0.078, 0, 0.204, '#interesting', '#admirable', 0.085, 'human_motion', 'vigorous_activity', 'like_run', 'fast_movement', 'human_action']
senticnet['human_noise'] = [0.078, 0, 0, 0.176, '#joyful', '#admirable', 0.085, 'vocalization', 'mouth_noise', 'human_sound', 'audible', 'vocal_sound']
senticnet['human_offspring'] = [0, 0.09, -0.06, 0.065, '#interesting', '#admirable', 0.032, 'descendant', 'female_child', 'small_adult', 'young', 'young_people']
senticnet['human_organ'] = [0, 0.078, 0, 0.096, '#interesting', '#admirable', 0.058, 'human_part', 'part_of_body', 'body_organ', 'human', 'anatomy']
senticnet['human_part'] = [0, 0.076, 0, 0.086, '#interesting', '#admirable', 0.054, 'part_of_body', 'body_organ', 'human', 'human_organ', 'anatomy']
senticnet['human_race_survive'] = [0.224, 0.155, -0.057, 0.217, '#joyful', '#admirable', 0.18, 'financial_security', 'take_vacation', 'acquire_wealth', 'accomplish', 'prepare_event']
senticnet['human_relationship'] = [0.988, -0.609, 0, 0.7, '#joyful', '#admirable', 0.766, 'indebtedness', 'bonding', 'obligation', 'relationship', 'personal_relation']
senticnet['human_sense'] = [0.027, 0.144, -0.078, 0.265, '#interesting', '#admirable', 0.119, 'five_senses', 'sensory_input', 'sense', 'ear_activity', 'human']
senticnet['human_shape'] = [0, 0, 0, 0.072, '#admirable', '#admirable', 0.024, 'dog_treat', 'structural_support', 'human_part', 'dog_toy', 'inside_body']
senticnet['human_sound'] = [0.089, 0, 0, 0.13, '#joyful', '#admirable', 0.073, 'vocalization', 'loud_soft', 'vocal_cord', 'audible', 'mouth_noise']
senticnet['human_trait'] = [0.155, 0.381, -0.24, 0.308, '#interesting', '#admirable', 0.201, 'charge', 'physical_quantity', 'human', 'excise', 'prize']
senticnet['human_truthful'] = [-0.841, 0, -0.949, 0, '#sad', '#scared', -0.597, 'doctor', 'nurse', 'medical_person', 'surgeon', 'doctor_surgery']
senticnet['humanity'] = [0.028, 0.139, -0.075, 0.222, '#interesting', '#admirable', 0.105, 'human_sense', 'sense', 'five_senses', 'bad_odor', 'sensory_input']
senticnet['humankind'] = [0, 0.903, 0, 0.84, '#interesting', '#admirable', 0.581, 'gender', 'mankind', 'person', 'pedophile', 'guardian']
senticnet['humate'] = [0.599, -0.879, 0, 0.673, '#surprising', '#admirable', 0.717, 'humic_shale', 'material', 'stuff', 'peat', 'lignite']
senticnet['humble'] = [0.958, 0, 0, 0.968, '#joyful', '#admirable', 0.642, 'kind', 'nice', 'respectful', 'at_your_service', 'red_carpet']
senticnet['humbleness'] = [0.884, 0, 0, 0.914, '#joyful', '#admirable', 0.599, 'humbling', 'demeaning', 'niceness', 'demeaningly', 'kindness']
senticnet['humbling'] = [0.861, 0, 0, 0.976, '#joyful', '#admirable', 0.612, 'kind', 'humbleness', 'nice', 'at_your_service', 'kindness']
senticnet['humbug'] = [-0.601, 0, 0.982, -0.562, '#sad', '#angry', -0.715, 'chicanery', 'deceit', 'deception', 'fraudulence', 'dissembling']
senticnet['humdinger'] = [0.581, -0.598, 0, 0.906, '#surprising', '#admirable', 0.695, 'nonesuch', 'nonsuch', 'ideal', 'nonpareil', 'apotheosis']
senticnet['humic_shale'] = [0.599, -0.879, 0, 0.673, '#surprising', '#admirable', 0.717, 'humate', 'material', 'stuff', 'peat', 'lignite']
senticnet['humid'] = [0, -0.037, 0.05, -0.142, '#angry', '#disgusting', -0.052, 'moistureity', 'wetness', 'damp', 'moisture', 'dank']
senticnet['humidity'] = [0, -0.037, 0.05, -0.142, '#angry', '#disgusting', -0.052, 'moisture', 'wetness', 'damp', 'humid', 'dank']
senticnet['humiliate'] = [-0.756, 0, 0.962, -0.929, '#angry', '#disgusting', -0.882, 'hopeless', 'fearful', 'scary', 'dreadful', 'intimidated']
senticnet['humiliated'] = [-0.892, 0, 0, -0.894, '#sad', '#disgusting', -0.595, 'mortifying', 'mortified', 'self-hatred', 'self-disgust', 'shameful']
senticnet['humiliating'] = [-0.766, 0, 0.759, -0.846, '#sad', '#disgusting', -0.79, 'humbling', 'demeaning', 'humbleness', 'demeaningly', 'humiliatingly']
senticnet['humiliatingly'] = [-0.858, 0, 0, -0.863, '#sad', '#disgusting', -0.574, 'humbling', 'demeaning', 'humbleness', 'humiliating', 'demeaningly']
senticnet['humiliation'] = [-0.581, 0.282, -0.414, -0.16, '#sad', '#scared', -0.291, 'shame', 'upset', 'despair', 'fright', 'unhappiness']
senticnet['humility'] = [0, 0, 0, 0.99, '#admirable', '#admirable', 0.33, 'concerned', 'anxious', 'consternation', 'hysteria', 'fidgetiness']
senticnet['hummingbird'] = [0.992, 0.915, 0, 0, '#joyful', '#interesting', 0.636, 'bird', 'colorful', 'pup', 'seagull', 'minnow']
senticnet['humor'] = [0.706, 0, 0, 0.792, '#joyful', '#admirable', 0.499, 'entertain_others', 'express_emotion', 'sing_song', 'listen', 'sound_good']
senticnet['hump'] = [-0.745, 0, 0.677, -0.77, '#sad', '#disgusting', -0.731, 'whore', 'jazz', 'fornicate', 'bonk', 'screw']
senticnet['hump_leg'] = [0.032, 0, 0, 0.057, '#joyful', '#admirable', 0.03, 'introduce_oneself', 'chat', 'talk_person', 'start_conversation', 'busy_signal']
senticnet['humpback'] = [-0.942, 0, 0.87, -0.902, '#sad', '#disgusting', -0.905, 'lordosis', 'kyphosis', 'spinal_curvature', 'hunchback', 'abnormality']
senticnet['hunchback'] = [-0.942, 0, 0.87, -0.902, '#sad', '#disgusting', -0.905, 'lordosis', 'kyphosis', 'humpback', 'spinal_curvature', 'abnormality']
senticnet['hundred_year'] = [0, -0.003, 0.063, -0.037, '#angry', '#disgusting', -0.032, 'thirty', 'dozen', 'twelve', 'day_month', 'time_measurement']
senticnet['hunger'] = [-0.867, 0, -0.743, 0, '#sad', '#scared', -0.537, 'hungry', 'crave', 'need_food', 'smell_food', 'need_grocery']
senticnet['hunger_go_away'] = [0.81, -0.895, 0, 0, '#joyful', '#surprising', 0.568, 'get_full', 'a_little_hungry', 'become_little_hungry', 'feel_little_hungry', 'no_long_hungry']
senticnet['hungry'] = [-0.713, 0, 0.692, -0.818, '#sad', '#disgusting', -0.741, 'famished', 'starved', 'ravenous', 'esurient', 'peckish']
senticnet['hunt'] = [-0.026, 0, 0, -0.129, '#sad', '#disgusting', -0.052, 'shoot', 'archery', 'fire_gun', 'shoot_cannon', 'shoot_person']
senticnet['hunt_animal'] = [-0.084, 0, -0.055, -0.095, '#sad', '#disgusting', -0.078, 'hunt_game', 'cause_illness', 'crazy', 'even_odds', 'growl']
senticnet['hunt_duck'] = [0.941, -0.746, 0, 0, '#joyful', '#surprising', 0.562, 'call_mom', 'answer_telephone', 'talk_telephone', 'receive_letter', 'learn_listen']
senticnet['hunt_fish'] = [0, 0.072, 0, 0, '#interesting', '#interesting', 0.024, 'counselor', 'rest_place', 'temporary_house', 'summer_vacation', 'military_installation']
senticnet['hunt_food'] = [-0.049, 0, -0.062, 0, '#sad', '#scared', -0.037, 'corner_prey', 'cut_knife', 'circle_prey', 'even_odds', 'hunt_game']
senticnet['hunt_fox'] = [-0.898, 0, -0.953, 0, '#sad', '#scared', -0.617, 'cause_accident', 'mark_territory', 'sense_fear', 'bladder_full', 'crap']
senticnet['hunt_game'] = [-0.114, -0.031, -0.061, -0.128, '#sad', '#disgusting', -0.091, 'corner_prey', 'even_odds', 'kill_other_person', 'arm_bomb', 'commit_genocide']
senticnet['hunt_human'] = [-0.221, -0.077, -0.144, 0.08, '#sad', '#scared', -0.069, 'stagger', 'gnaw', 'monitor_heart_rate', 'prevent_conception', 'choke']
senticnet['hunter'] = [0, 0, -0.113, -0.123, '#scared', '#disgusting', -0.079, 'hunting_season', 'hound', 'cougar', 'outlaw', 'dragon']
senticnet['hunting'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'panda', 'endangered_species', 'air_pollution', 'global_warming', 'sea_pollution']
senticnet['hunting_problem'] = [-0.961, 0, 0.704, -0.97, '#sad', '#disgusting', -0.878, 'break', 'crash', 'smash', 'damage', 'break_arrow']
senticnet['hunting_season'] = [0, 0, -0.113, -0.123, '#scared', '#disgusting', -0.079, 'hunter', 'hound', 'cougar', 'outlaw', 'dragon']
senticnet['hurler'] = [-0.922, 0, 0.767, -0.85, '#sad', '#disgusting', -0.846, 'closer', 'finisher', 'pitcher', 'relief_pitcher', 'twirler']
senticnet['hurly_burly'] = [-0.65, 0, 0.858, -0.831, '#angry', '#disgusting', -0.78, 'turmoil', 'convulsion', 'tempest', 'disorder', 'earthquake']
senticnet['hurricane'] = [-0.028, 0, 0, -0.081, '#sad', '#disgusting', -0.036, 'atmospheric_phenomenon', 'natural_disaster', 'flood', 'weather_element', 'tropical_storm']
senticnet['hurriedness'] = [-0.873, 0, 0.837, -0.891, '#sad', '#disgusting', -0.867, 'abruptness', 'precipitateness', 'precipitousness', 'precipitance', 'precipitancy']
senticnet['hurry_along'] = [-0.081, 0.124, -0.094, 0.176, '#interesting', '#admirable', 0.042, 'jump_over', 'jump_up', 'mark_territory', 'jump', 'hurry_up']
senticnet['hurry_up'] = [-0.081, 0.124, -0.094, 0.176, '#interesting', '#admirable', 0.042, 'jump_over', 'hurry_along', 'mark_territory', 'jump', 'jump_up']
senticnet['hurry_work'] = [-0.95, 0, 0, -0.753, '#sad', '#disgusting', -0.568, 'carry_briefcase', 'mine_diamond', 'bicycle_across_town', 'sail_around_world', 'voice_concern']
senticnet['hurt'] = [-0.726, 0, -0.891, 0, '#sad', '#scared', -0.539, 'harm', 'ouch', 'pain', 'damage', 'ache']
senticnet['hurt_animal'] = [-0.101, 0, -0.078, 0, '#sad', '#scared', -0.06, 'kill_specific_group', 'mine_diamond', 'bicycle_across_town', 'dig_grave', 'wave_flag']
senticnet['hurt_back'] = [-0.992, 0, 0, -0.731, '#sad', '#disgusting', -0.574, 'break_leg', 'loss_ofbreath', 'hit_car', 'get_injured', 'sprain_ankle']
senticnet['hurt_ear'] = [0.727, -0.81, 0, 0, '#joyful', '#surprising', 0.512, 'like', 'hear_song', 'tap_foot', 'earring', 'change_mood']
senticnet['hurt_else'] = [-0.728, 0, 0, -0.768, '#sad', '#disgusting', -0.499, 'obstruct_justice', 'get_away_crime', 'punish', 'commit_perjury', 'commit_murder']
senticnet['hurt_feeling'] = [-0.993, 0, 0, -0.766, '#sad', '#disgusting', -0.586, 'feel_hurt', 'dislike', 'feel_bad', 'become_angry', 'get_fired']
senticnet['hurt_foot'] = [-0.993, 0, 0.521, -0.928, '#sad', '#disgusting', -0.814, 'pain', 'hurt', 'injury', 'painful', 'knee_injury']
senticnet['hurt_oneself'] = [-0.788, -0.77, 0, -0.779, '#sad', '#disgusting', -0.266, 'get_hurt', 'get_injured', 'hurt_back', 'bump_head', 'hit_car']
senticnet['hurt_other_person'] = [-0.734, 0, 0, -0.866, '#sad', '#disgusting', -0.533, 'censorship', 'bigot', 'broken_finger', 'skin_knee', 'schizophrenia']
senticnet['hurt_others'] = [-0.76, 0, 0, -0.983, '#sad', '#disgusting', -0.581, 'get_rid_of_enemy', 'destroy_live', 'terrorize', 'death_destruction', 'murder']
senticnet['hurt_person'] = [-0.7, 0, 0, -0.794, '#sad', '#disgusting', -0.498, 'stab', 'cause_injury', 'destroy', 'maim', 'die_painfully']
senticnet['hurt_skin'] = [-0.907, 0, 0.209, -0.927, '#sad', '#disgusting', -0.681, 'sun_burn', 'erythema', 'fire', 'lighting', 'burn_skin']
senticnet['hurt_them'] = [-0.998, 0, 0.894, -0.9, '#sad', '#disgusting', -0.931, 'kill_person', 'beat', 'torture', 'shoot', 'kick']
senticnet['hurt_toe'] = [-0.121, -0.023, 0.028, 0, '#sad', '#angry', -0.042, 'move_leg', 'trip_fall_down', 'swing_arm', 'tie_shoes', 'take_photo']
senticnet['hurt_wrongly'] = [-0.998, 0, 0.434, -0.904, '#sad', '#disgusting', -0.779, 'friendly_fire', 'fight_war', 'battle', 'attack', 'kill_friend']
senticnet['hurt_yourself'] = [-0.937, 0, 0.643, -0.951, '#sad', '#disgusting', -0.844, 'fall_down', 'car_accident', 'stumble', 'accident', 'sport_accident']
senticnet['hurtful'] = [-0.185, 0, -0.119, -0.114, '#sad', '#scared', -0.139, 'destructive', 'bloody', 'severe', 'gash', 'ouch']
senticnet['hurting'] = [-0.735, 0, 0.555, -0.908, '#sad', '#disgusting', -0.733, 'aching', 'dysmenorrhea', 'labor_pain', 'neuralgia', 'neuralgy']
senticnet['husband'] = [0.894, 0.717, 0, 0, '#joyful', '#interesting', 0.537, 'wife', 'boys', 'mum', 'male_parent', 'male_relative']
senticnet['husband_wife'] = [0.701, 0, 0, 0.759, '#joyful', '#admirable', 0.487, 'holy_matrimony', 'good_teacher', 'female_person', 'existence', 'marriage']
senticnet['hush'] = [0.206, 0.329, -0.071, 0.22, '#interesting', '#admirable', 0.228, 'listen_sermon', 'religious_purpose', 'belief', 'spirituality', 'faith']
senticnet['hush_up'] = [-0.691, 0, 0.89, -0.707, '#angry', '#disgusting', -0.763, 'still', 'burke', 'moderate', 'suppress', 'quell']
senticnet['husky'] = [-0.532, 0, 0.798, -0.73, '#angry', '#disgusting', -0.687, 'robust', 'hardy', 'sturdy', 'chesty', 'stalwart']
senticnet['hustle'] = [-0.947, 0, 0.492, -0.921, '#sad', '#disgusting', -0.787, 'make_noise', 'disturb', 'confusion', 'hustle_and_bustle', 'bustle']
senticnet['hustle_and_bustle'] = [-0.947, 0, 0.492, -0.921, '#sad', '#disgusting', -0.787, 'make_noise', 'disturb', 'confusion', 'hustle', 'bustle']
senticnet['hut'] = [-0.069, -0.013, -0.048, 0, '#sad', '#scared', -0.035, 'hive', 'animal_home', 'lair', 'habitat', 'beehive']
senticnet['hutch'] = [0.846, -0.665, 0, 0.941, '#joyful', '#admirable', 0.817, 'hut', 'hovel', 'mudhif', 'shack', 'shanty']
senticnet['hutzpah'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'rudeness', 'discourtesy', 'insolence', 'ccheekiness', 'cheekiness']
senticnet['hyaline_cartilage'] = [-0.536, 0, 0.982, -0.671, '#angry', '#disgusting', -0.73, 'meniscus', 'semilunar_cartilage', 'fibrocartilage', 'gristle', 'arytenoid']
senticnet['hybrid'] = [0.042, -0.036, 0, 0.112, '#joyful', '#admirable', 0.063, 'double_nature', 'clean', 'highway_road', 'go_green', 'car_drive']
senticnet['hydroelectric_turbine'] = [-0.976, 0, 0.658, -0.606, '#sad', '#angry', -0.747, 'gas_turbine', 'turbine', 'impulse_turbine', 'reaction_turbine', 'steam_turbine']
senticnet['hydrogen'] = [0.909, 0.983, 0, 0, '#joyful', '#interesting', 0.631, 'oxygen', 'breathable', 'atmosphere', 'air', 'inhale_air']
senticnet['hydrogen_bomb'] = [0, 0, -0.868, -0.792, '#scared', '#disgusting', -0.553, 'revolver', 'shotgun', 'pistol', 'rifle', 'gun']
senticnet['hydromorphone'] = [-0.985, 0, 0.601, -0.695, '#sad', '#disgusting', -0.76, 'pain_pill_hydrochloride', 'pain_pill', 'acetaminophen', 'codeine', 'medicine']
senticnet['hydromorphone_hydrochloride'] = [-0.985, 0, 0.601, -0.695, '#sad', '#disgusting', -0.76, 'pain_pill', 'hydromorphone', 'acetaminophen', 'codeine', 'medicine']
senticnet['hydrophyte'] = [-0.839, 0, 0.768, -0.697, '#sad', '#angry', -0.768, 'water_carpet', 'water_mat', 'aquatic_plant', 'water_plant', 'golden_saxifrage']
senticnet['hydrops'] = [-0.639, 0, 0.982, -0.649, '#angry', '#disgusting', -0.757, 'angioedema', 'atrophedema', 'giant_hives', 'periodic_edema', 'lymphedema']
senticnet['hygiene'] = [0.909, 0.704, 0, 0, '#joyful', '#interesting', 0.538, 'hand_wash', 'body_care', 'godliness', 'clean_agent', 'tv_drama']
senticnet['hygroscope'] = [0, 0.184, -0.051, 0.179, '#interesting', '#admirable', 0.104, 'absorb_water', 'hold_water', 'antiquate', 'molecule', 'tangent']
senticnet['hymn'] = [0.073, 0.109, 0.031, 0.165, '#interesting', '#admirable', 0.105, 'song', 'song_lyric', 'lyrics', 'melody', 'lyric']
senticnet['hype_up'] = [-0.902, 0, 0.851, -0.92, '#sad', '#disgusting', -0.891, 'charge_up', 'commove', 'agitate', 'excite', 'charge']
senticnet['hyper'] = [0.234, 0.214, -0.203, 0.266, '#joyful', '#admirable', 0.17, 'create_destroy', 'power_source', 'potential', 'like_electricity', 'form_of_energy']
senticnet['hyperbolize'] = [0.617, -0.839, 0, 0.828, '#surprising', '#admirable', 0.761, 'brag', 'embellish', 'overemphasize', 'overstress', 'vaunt']
senticnet['hypericism'] = [-0.726, 0, 0.778, -0.98, '#angry', '#disgusting', -0.828, 'actinic_dermatitis', 'dermatitis', 'diaper_rash', 'diaper_dermatitis', 'seborrheic_dermatitis']
senticnet['hypermastigote'] = [0.807, -0.868, 0, 0.611, '#joyful', '#surprising', 0.762, 'costia', 'zoomastigote', 'zooflagellate', 'dinoflagellate', 'flagellate']
senticnet['hypermetropia'] = [0.7, -0.628, 0, 0.58, '#joyful', '#surprising', 0.636, 'see_far', 'hyperopia', 'farsightedness', 'hypermetropy', 'longsightedness']
senticnet['hypermetropic'] = [0.545, -0.599, 0, 0.865, '#surprising', '#admirable', 0.67, 'farseeing', 'longsighted', 'telescopic', 'hyperopic', 'farsighted']
senticnet['hypermetropy'] = [0.7, -0.628, 0, 0.58, '#joyful', '#surprising', 0.636, 'see_far', 'hyperopia', 'hypermetropia', 'farsightedness', 'longsightedness']
senticnet['hyperope'] = [-0.638, 0, 0.625, -0.989, '#sad', '#disgusting', -0.751, 'aphakic', 'blind_person', 'myope', 'mortal', 'visually_impaired_person']
senticnet['hyperopia'] = [0.7, -0.628, 0, 0.58, '#joyful', '#surprising', 0.636, 'see_far', 'farsightedness', 'hypermetropia', 'hypermetropy', 'longsightedness']
senticnet['hyperopic'] = [0.545, -0.599, 0, 0.865, '#surprising', '#admirable', 0.67, 'farseeing', 'longsighted', 'telescopic', 'farsighted', 'hypermetropic']
senticnet['hyperpigmentation'] = [-0.969, 0, 0.636, -0.646, '#sad', '#disgusting', -0.75, 'burn', 'tan', 'suntan', 'sunburn', 'physical_condition']
senticnet['hypersensitivity'] = [-0.587, 0, 0.577, -0.64, '#sad', '#disgusting', -0.601, 'cryesthesia', 'cryaesthesia', 'hypersensitivity_reaction', 'sensitivity', 'predisposition']
senticnet['hypersensitivity_reaction'] = [-0.939, 0, 0.877, -0.726, '#sad', '#angry', -0.847, 'urtication', 'urticaria', 'hives', 'nettle_rash', 'allergy']
senticnet['hypertension'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'illness', 'ill', 'tension', 'bad_health', 'malignant_hypertension']
senticnet['hypertonicity'] = [-0.623, 0, 0.901, -0.715, '#angry', '#disgusting', -0.746, 'pressure', 'osmotic_pressure', 'hypotonicity', 'pressure_level', 'force_per_unit_area']
senticnet['hypertrophy'] = [-0.762, 0, 0.571, -0.847, '#sad', '#disgusting', -0.727, 'bigger_than_usual', 'giantism', 'disease', 'overgrowth', 'feel_pain']
senticnet['hyperventilate'] = [0.822, -0.88, 0, 0.591, '#joyful', '#surprising', 0.764, 'expire', 'inspire', 'respire', 'yawn', 'breathe']
senticnet['hypnotic'] = [0, 0.855, 0, 0.84, '#interesting', '#admirable', 0.565, 'like_electricity', 'take_over', 'essential', 'high_class', 'movie_picture']
senticnet['hypnotic_effect'] = [0.354, -0.231, -0.051, 0, '#joyful', '#surprising', 0.178, 'happiness', 'enjoy_show', 'deafness', 'listen_classical_music', 'applaud']
senticnet['hypnotized'] = [0.998, -0.75, 0, 0.695, '#joyful', '#surprising', 0.814, 'bewitched', 'ensorcelled', 'fascinated', 'enchanted', 'mesmerized']
senticnet['hypocrisy'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'pretense', 'feigning', 'dissembling', 'pretence', 'crocodile_tears']
senticnet['hypocrite'] = [-0.734, 0, 0, -0.961, '#sad', '#disgusting', -0.565, 'plaster_saint', 'humbug', 'pretender', 'phoney', 'imposter']
senticnet['hypocritical'] = [-0.527, 0, 0.651, -0.542, '#angry', '#disgusting', -0.573, 'feigned', 'dissimulative', 'specious', 'insincere', 'fulsome']
senticnet['hypodermic_needle'] = [0, -0.018, -0.073, -0.185, '#scared', '#disgusting', -0.08, 'syringe', 'latex_glove', 'medical_record', 'x-ray_machine', 'doctor_examination_room']
senticnet['hypophosphoric_acid'] = [-0.814, 0, 0.774, -0.776, '#sad', '#disgusting', -0.788, 'acid', 'oxyacid', 'periodic_acid', 'hypophosphorous_acid', 'phosphorous_acid']
senticnet['hypophosphorous_acid'] = [-0.814, 0, 0.774, -0.776, '#sad', '#disgusting', -0.788, 'acid', 'hypophosphoric_acid', 'periodic_acid', 'oxyacid', 'phosphorous_acid']
senticnet['hypopigmentation'] = [-0.917, 0, 0.961, -0.556, '#sad', '#angry', -0.811, 'albinism', 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder']
senticnet['hypostasis'] = [0.645, -0.766, 0, 0.961, '#surprising', '#admirable', 0.791, 'content', 'quintessence', 'stuff', 'bare_bones', 'essence']
senticnet['hypothecate'] = [-0.957, 0, 0.822, -0.882, '#sad', '#disgusting', -0.887, 'formulate', 'speculate', 'conjecture', 'mature', 'suppose']
senticnet['hypothermia'] = [-0.969, 0, 0.172, -0.997, '#sad', '#disgusting', -0.713, 'severe_cold', 'cold', 'cold_winter', 'possibility_to_die', 'freeze']
senticnet['hypothesis'] = [-0.042, 0.127, -0.062, 0.137, '#interesting', '#admirable', 0.053, 'experiment', 'theory', 'supposition', 'prove_theory', 'test_hypothesis']
senticnet['hypothesize'] = [0.615, -0.899, 0, 0.714, '#surprising', '#admirable', 0.743, 'reconstruct', 'retrace', 'explicate', 'expect', 'formulate']
senticnet['hypothetical'] = [-0.062, 0.247, -0.115, 0.217, '#interesting', '#admirable', 0.096, 'theory', 'supposition', 'hypothesis', 'scientific_statement', 'conjecture']
senticnet['hypothetical_creature'] = [-0.654, 0, 0.859, -0.639, '#sad', '#angry', -0.717, 'alien', 'extraterrestrial_being', 'extraterrestrial', 'imaginary_being', 'imaginary_creature']
senticnet['hypothetical_imperative'] = [0.841, -0.657, 0, 0.645, '#joyful', '#surprising', 0.714, 'moral_principle', 'rule', 'caveat_emptor', 'higher_law', 'precept']
senticnet['hypotonicity'] = [-0.623, 0, 0.901, -0.715, '#angry', '#disgusting', -0.746, 'pressure', 'hypertonicity', 'osmotic_pressure', 'pressure_level', 'force_per_unit_area']
senticnet['hypovitaminosis'] = [-0.712, 0, 0.74, -0.506, '#sad', '#angry', -0.653, 'kwashiorkor', 'marasmus', 'avitaminosis', 'malnutrition', 'deficiency_disease']
senticnet['hysteria'] = [-0.897, 0, -0.904, 0, '#sad', '#scared', -0.6, 'anxious', 'fearful', 'panicked', 'panic-stricken', 'panic-struck']
senticnet['hysteric'] = [-0.707, 0, 0.624, -0.653, '#sad', '#disgusting', -0.661, 'sick_person', 'diseased_person', 'sufferer', 'claustrophobe', 'mental_case']
senticnet['hysterical'] = [-0.769, 0, -0.751, 0, '#sad', '#scared', -0.507, 'hysterically', 'dire', 'direful', 'dreaded', 'fearsome']
senticnet['hysterical_neurosis'] = [-0.552, 0, 0.736, -0.714, '#angry', '#disgusting', -0.667, 'neurosis', 'neuroticism', 'psychoneurosis', 'hysterocatalepsy', 'anxiety_hysteria']
senticnet['hysterically'] = [-0.97, 0, -0.814, 0, '#sad', '#scared', -0.595, 'hysterical', 'dire', 'direful', 'dreaded', 'fearsome']
senticnet['hysterocatalepsy'] = [-0.552, 0, 0.736, -0.714, '#angry', '#disgusting', -0.667, 'neurosis', 'neuroticism', 'psychoneurosis', 'hysterical_neurosis', 'anxiety_hysteria']
senticnet['hysteron_proteron'] = [0.623, -0.532, 0, 0.873, '#joyful', '#admirable', 0.676, 'petitio_principii', 'petitio', 'logical_fallacy', 'fallacy', 'false_belief']
senticnet['i-beam'] = [0.87, 0, 0, 0.753, '#joyful', '#admirable', 0.541, 'cork', 'rod', 'nest_table', 'wand', 'beam']
senticnet['ianfu'] = [-0.917, 0, 0.974, -0.612, '#sad', '#angry', -0.834, 'slattern', 'camp_follower', 'call_girl', 'comfort_woman', 'bawd']
senticnet['ibex'] = [-0.51, 0, 0.845, -0.993, '#angry', '#disgusting', -0.783, 'bezoar_goat', 'pasang', 'markhor', 'goat', 'wild_goat']
senticnet['ibis'] = [0.797, -0.719, 0, 0.736, '#joyful', '#admirable', 0.751, 'wood_ibis', 'wood_stork', 'sacred_ibis', 'wading_bird', 'wader']
senticnet['ibuprofen'] = [-0.046, -0.013, -0.098, -0.206, '#scared', '#disgusting', -0.112, 'analgesic', 'palliative', 'sleep_drug', 'phenobarbital', 'medicine']
senticnet['ice'] = [-0.838, 0, 0, -0.704, '#sad', '#disgusting', -0.514, 'cold_weather', 'snow', 'arctic', 'cold', 'without_human_habitation']
senticnet['ice_cream'] = [0.088, -0.062, 0, 0, '#joyful', '#surprising', 0.05, 'candy', 'pumpkin_pie', 'chocolate', 'apple_pie', 'chocolate_dessert']
senticnet['ice_cream_melt'] = [0, 0, 0, -0.848, '#disgusting', '#disgusting', -0.283, 'bad_hair_day', 'toothache', 'brain_tumor', 'lyme_disease', 'suffer_fool']
senticnet['ice_crystal'] = [0.084, 0, 0.054, 0.067, '#joyful', '#admirable', 0.032, 'ice_rain', 'coldness', 'icy', 'cold', 'frozen']
senticnet['ice_cube'] = [0.816, 0.76, 0, 0.956, '#joyful', '#admirable', 0.844, 'cold_air', 'tumble', 'frost', 'hale', 'drop']
senticnet['ice_hockey'] = [0.7, -0.798, 0, 0.873, '#surprising', '#admirable', 0.79, 'sport', 'game', 'athletic_game', 'hockey', 'hockey_game']
senticnet['ice_rain'] = [0.093, 0.204, -0.088, 0.254, '#interesting', '#admirable', 0.154, 'change_shape', 'blend', 'circumstance', 'ice_crystal', 'become_liquid']
senticnet['ice_rink'] = [0, 0, 0, -0.1, '#disgusting', '#disgusting', -0.033, 'skate_rink', 'skate', 'room_temperature', 'loose_end', 'another_planet']
senticnet['ice_skate'] = [0.128, 0.103, 0, 0.208, '#joyful', '#admirable', 0.146, 'hockey_stick', 'basketball_hoop', 'snorkel', 'rope', 'have_fun']
senticnet['ice_skater'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'video_recorder', 'terrier', 'vertebrate', 'elf', 'live_human']
senticnet['ice_sport'] = [0.051, -0.068, 0.028, 0.069, '#surprising', '#admirable', 0.053, 'fun_sport', 'sport_play', 'rough_game', 'ball_sport', 'dangerous_sport']
senticnet['ice_tea'] = [0.076, -0.013, 0, 0, '#joyful', '#surprising', 0.03, 'juice', 'tea', 'soft_drink', 'apple_juice', 'drink']
senticnet['icebox'] = [0.045, -0.053, 0, -0.029, '#joyful', '#surprising', 0.023, 'refrigerator', 'store_refrigerator', 'cold_storage', 'restaurant_storage_area', 'plastic_bag']
senticnet['ichor'] = [-0.525, 0, 0.538, -0.959, '#angry', '#disgusting', -0.674, 'sanies', 'pus', 'purulence', 'suppuration', 'gleet']
senticnet['icicle'] = [0.077, -0.055, 0, 0, '#joyful', '#surprising', 0.044, 'frost', 'snow_fall', 'winter', 'snow', 'season_year']
senticnet['iciness'] = [-0.657, 0, 0.814, -0.793, '#angry', '#disgusting', -0.755, 'cold', 'low_temperature', 'frigidity', 'frigidness', 'coldness']
senticnet['icing'] = [-0.641, 0, 0.612, -0.848, '#sad', '#disgusting', -0.7, 'chilling', 'frost', 'lyophilization', 'freeze', 'cooling']
senticnet['icky'] = [0, 0, -0.877, -0.998, '#scared', '#disgusting', -0.625, 'crappy', 'rotten', 'lousy', 'stinking', 'shitty']
senticnet['icon'] = [0.055, 0.117, 0, 0.133, '#interesting', '#admirable', 0.102, 'graphical_representation', 'pencil_pen', 'note_pad', 'marker', 'stationery']
senticnet['iconic_place'] = [0, 0.111, 0, 0.07, '#interesting', '#admirable', 0.06, 'beautiful_view', 'tourist_attraction', 'eiffel_tower', 'piece_of_story', 'monument']
senticnet['iconoclasm'] = [0.526, -0.633, 0, 0.59, '#surprising', '#admirable', 0.583, 'nonconformity', 'heterodoxy', 'nonconformism', 'nonconformance', 'orientation']
senticnet['icterus'] = [-0.647, 0, 0.903, -0.634, '#sad', '#angry', -0.728, 'jaundice_of_newborn', 'disease', 'icterus_neonatorum', 'kernicterus', 'symptom']
senticnet['icterus_neonatorum'] = [-0.647, 0, 0.903, -0.634, '#sad', '#angry', -0.728, 'jaundice_of_newborn', 'disease', 'icterus', 'kernicterus', 'symptom']
senticnet['ictus'] = [0.947, -0.562, 0, 0.875, '#joyful', '#admirable', 0.795, 'convulsion', 'raptus', 'focal_seizure', 'absence', 'absence_seizure']
senticnet['icy'] = [0.097, 0, 0, 0.067, '#joyful', '#admirable', 0.055, 'cold_outside', 'coldness', 'cold', 'cold_weather', 'ice_crystal']
senticnet['id_card'] = [0, 0.707, 0, 0.846, '#interesting', '#admirable', 0.518, 'receipt', 'bet', 'electric_bill', 'letter_slot', 'deal']
senticnet['idea'] = [-0.059, 0.277, -0.08, 0.111, '#interesting', '#admirable', 0.083, 'new_think', 'brain_activity', 'memory', 'brain_function', 'make_right_decision']
senticnet['ideal'] = [0.069, 0.21, -0.067, 0.285, '#interesting', '#admirable', 0.166, 'record', 'protect_house', 'strive', 'store_record', 'perfect']
senticnet['ideal_solid'] = [0.641, -0.6, 0, 0.957, '#joyful', '#admirable', 0.733, 'regular_tetrahedron', 'cube', 'regular_hexahedron', 'regular_dodecahedron', 'regular_octahedron']
senticnet['idealist'] = [0.915, 0, 0, 0.75, '#joyful', '#admirable', 0.555, 'dreamer', 'visionary', 'person', 'individual', 'romantic']
senticnet['ideate'] = [-0.656, 0, 0.792, -0.617, '#sad', '#angry', -0.688, 'fancy', 'foresee', 'fantasy', 'daydream', 'woolgather']
senticnet['identical'] = [0.056, 0.184, 0, 0.243, '#interesting', '#admirable', 0.161, 'duplicate', 'alike', 'similar', 'same', 'twice']
senticnet['identifiable'] = [0.935, -0.958, 0, 0.949, '#surprising', '#admirable', 0.947, 'acknowledgeable', 'specifiable', 'recognizable', 'diagnosable', 'classifiable']
senticnet['identification'] = [0.034, 0.244, -0.142, 0.199, '#interesting', '#admirable', 0.112, 'credit', 'fold', 'probability', 'record_keep', 'greeting']
senticnet['identification_picture'] = [0.082, 0.184, -0.075, 0.208, '#interesting', '#admirable', 0.133, 'identify_person', 'profile_picture', 'capitalize', 'personal_identification', 'passport']
senticnet['identify'] = [0.057, 0.383, -0.277, 0.325, '#interesting', '#admirable', 0.163, 'tell_everyone', 'newscaster', 'again_and_again', 'make_right', 'band_together']
senticnet['identify_oneself'] = [0, 0.121, 0, 0.164, '#interesting', '#admirable', 0.095, 'stretch_out', 'recognize', 'no_stop', 'grow_long', 'pull_out']
senticnet['identify_person'] = [0.042, 0.227, -0.122, 0.298, '#interesting', '#admirable', 0.148, 'proclamation', 'request', 'personal_identification', 'identify', 'proverb']
senticnet['identity'] = [0.122, 0.159, -0.054, 0.217, '#interesting', '#admirable', 0.148, 'profile_picture', 'unity', 'country_person', 'unite', 'name_state']
senticnet['ideogram'] = [-0.61, 0, 0.721, -0.683, '#angry', '#disgusting', -0.671, 'character', 'logogram', 'logograph', 'graph', 'grapheme']
senticnet['ideograph'] = [-0.866, 0, 0.619, -0.806, '#sad', '#disgusting', -0.764, 'character', 'logogram', 'logograph', 'graph', 'grapheme']
senticnet['ideological_barrier'] = [-0.765, 0, 0.692, -0.845, '#sad', '#disgusting', -0.767, 'iron_curtain', 'bamboo_curtain', 'color_bar', 'color_line', 'barrier']
senticnet['ideology'] = [0, 0, 0, 0.986, '#admirable', '#admirable', 0.329, 'idea', 'decision', 'consider', 'polarize', 'make_right_decision']
senticnet['idiocy'] = [-0.847, 0, 0.702, -0.614, '#sad', '#angry', -0.721, 'slowness', 'mental_retardation', 'backwardness', 'subnormality', 'retardation']
senticnet['idiom'] = [0, 0.724, 0, 0.828, '#interesting', '#admirable', 0.517, 'utterance', 'enunciation', 'say', 'speech', 'language']
senticnet['idiomatic_expression'] = [0.563, -0.728, 0, 0.644, '#surprising', '#admirable', 0.645, 'idiom', 'ruralism', 'phrasal_idiom', 'set_phrase', 'phrase']
senticnet['idiosyncrasy'] = [0.664, -0.903, 0, 0.788, '#surprising', '#admirable', 0.785, 'individualism', 'individuality', 'individuation', 'distinctiveness', 'foible']
senticnet['idiot'] = [0, 0, 0.934, -0.806, '#angry', '#disgusting', -0.58, 'idiotic', 'stupid', 'dumb', 'brainless', 'dummy']
senticnet['idiotic'] = [0, 0, 0.781, -0.891, '#angry', '#disgusting', -0.557, 'stupid', 'idiot', 'dummy', 'newbie', 'dumb']
senticnet['idle'] = [0, 0, 0.808, -0.973, '#angry', '#disgusting', -0.594, 'inaction', 'lazy', 'stay', 'inactive', 'recline']
senticnet['idleness'] = [-0.664, 0, 0.749, -0.549, '#sad', '#angry', -0.654, 'inertia', 'inactiveness', 'inactivity', 'faineance', 'indolence']
senticnet['idol'] = [0, 0, 0, 0.961, '#admirable', '#admirable', 0.32, 'heavenly', 'assumption', 'deity', 'maker', 'almighty']
senticnet['idol_worshiper'] = [-0.888, 0, 0.929, -0.843, '#sad', '#angry', -0.887, 'paynim', 'nonreligious_person', 'idolizer', 'idolater', 'gentile']
senticnet['idolater'] = [-0.888, 0, 0.929, -0.843, '#sad', '#angry', -0.887, 'paynim', 'nonreligious_person', 'idolizer', 'gentile', 'idol_worshiper']
senticnet['idolize'] = [0, 0.712, 0, 0.959, '#interesting', '#admirable', 0.557, 'reverently', 'hero-worship', 'venerate', 'worship', 'veneration']
senticnet['idolize_actor'] = [0.539, 0.983, 0, 0.694, '#interesting', '#admirable', 0.739, 'want_entertain', 'see_actor', 'get_entertain', 'interest_art', 'experience_different_culture']
senticnet['idolizer'] = [-0.888, 0, 0.929, -0.843, '#sad', '#angry', -0.887, 'paynim', 'nonreligious_person', 'gentile', 'idolater', 'idol_worshiper']
senticnet['igloo'] = [0.021, 0, -0.044, -0.06, '#scared', '#disgusting', -0.028, 'log_cabin', 'chess_tournament', 'another_planet', 'death_row', 'loose_end']
senticnet['ignite'] = [0, 0, 0.752, -0.732, '#angry', '#disgusting', -0.495, 'arouse', 'kindle', 'trigger', 'spark', 'instigate']
senticnet['ignition'] = [-0.831, 0, 0.711, -0.639, '#sad', '#angry', -0.727, 'inflammation', 'lighting', 'arson', 'incendiarism', 'burning']
senticnet['ignition_key'] = [0.943, -0.787, 0, 0.571, '#joyful', '#surprising', 0.767, 'master', 'key', 'latchkey', 'passkey', 'master_key']
senticnet['ignobility'] = [-0.774, 0, 0.748, -0.606, '#sad', '#angry', -0.709, 'ignobleness', 'dishonorableness', 'sleaziness', 'unrespectability', 'disreputability']
senticnet['ignobleness'] = [-0.774, 0, 0.748, -0.606, '#sad', '#angry', -0.709, 'dishonorableness', 'ignobility', 'sleaziness', 'unrespectability', 'disreputability']
senticnet['ignominious'] = [-0.745, 0, 0, -0.82, '#sad', '#disgusting', -0.522, 'disgraceful', 'shameful', 'dishonorably', 'inglorious', 'dishonored']
senticnet['ignominiously'] = [-0.933, 0, 0, -0.922, '#sad', '#disgusting', -0.618, 'disgraceful', 'shameful', 'dishonorably', 'inglorious', 'dishonored']
senticnet['ignominy'] = [-0.5, 0, 0.921, -0.878, '#angry', '#disgusting', -0.766, 'reproach', 'obloquy', 'odium', 'dishonor', 'humiliation']
senticnet['ignoramus'] = [-0.901, 0, 0.76, -0.871, '#sad', '#disgusting', -0.844, 'analphabet', 'analphabetic', 'functional_illiterate', 'illiterate', 'know_nothing']
senticnet['ignorance'] = [-0.061, 0, -0.132, 0.061, '#sad', '#scared', -0.044, 'curiosity', 'ignorant', 'uncertainty', 'feel_hurt', 'loneliness']
senticnet['ignorant'] = [0, 0, 0.943, -0.795, '#angry', '#disgusting', -0.579, 'vulnerable', 'selfish', 'uneducated', 'guilty_crime', 'homophobic']
senticnet['ignore'] = [-0.297, 0, -0.163, -0.208, '#sad', '#disgusting', -0.223, 'feel_pain', 'cause_someone_to_die', 'feel_bad', 'anguish', 'feel_hurt']
senticnet['ignore_distraction'] = [-0.739, 0, 0, -0.804, '#sad', '#disgusting', -0.514, 'get_heard', 'motion_sickness', 'get_fight', 'loss_ofmemory', 'break_leg']
senticnet['ignored'] = [-0.603, 0, 0.564, -0.85, '#sad', '#disgusting', -0.672, 'unmarked', 'unnoticed', 'unheeded', 'overlooked', 'unnoted']
senticnet['ill'] = [-0.891, 0, -0.994, -0.752, '#sad', '#scared', -0.879, 'sickness', 'polio', 'malady', 'illness', 'ailment']
senticnet['ill_health'] = [-0.858, 0, -0.824, -0.867, '#sad', '#disgusting', -0.85, 'terminal_illness', 'physical_pain', 'schizophrenia', 'influenza', 'poor_health']
senticnet['ill_humor'] = [-0.589, 0, 0.944, -0.585, '#sad', '#angry', -0.706, 'crossness', 'fretfulness', 'peevishness', 'petulance', 'moodiness']
senticnet['ill_luck'] = [-0.693, 0, 0.957, -0.865, '#angry', '#disgusting', -0.838, 'hard_cheese', 'weakness', 'gutter', 'adversity', 'hardship']
senticnet['ill_nature'] = [-0.959, 0, 0.694, -0.949, '#sad', '#disgusting', -0.867, 'sullenness', 'moroseness', 'crabbiness', 'crabbedness', 'crankiness']
senticnet['ill_person'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'ill', 'avoid_food', 'sickness', 'sick', 'fast_day']
senticnet['ill_temper'] = [-0.139, 0.151, 0.613, -0.627, '#angry', '#disgusting', -0.409, 'bad_temper', 'umbrage', 'offense', 'outraged', 'indignant']
senticnet['ill_will'] = [0, 0.161, 0.7, -0.657, '#angry', '#disgusting', -0.399, 'enmity', 'hostile', 'vindictive', 'despiteful', 'vindictively']
senticnet['illegal'] = [-0.196, 0.14, -0.283, 0.141, '#sad', '#scared', -0.066, 'violent', 'inherit', 'dangerous', 'bad_health', 'tricky']
senticnet['illegal_activity'] = [0, 0, 0.968, -0.73, '#angry', '#disgusting', -0.566, 'blackmail', 'sell_out', 'go_bankrupt', 'deserve', 'penalty']
senticnet['illegal_drug'] = [0, -0.009, -0.087, -0.107, '#scared', '#disgusting', -0.062, 'drug', 'medication', 'narcotic', 'illegal', 'cook_grill']
senticnet['illegality'] = [-0.722, 0, 0.742, -0.802, '#angry', '#disgusting', -0.755, 'illicitness', 'unlawfulness', 'illegitimacy', 'shadiness', 'quality']
senticnet['illegitimacy'] = [-0.722, 0, 0.742, -0.802, '#angry', '#disgusting', -0.755, 'illicitness', 'illegality', 'unlawfulness', 'shadiness', 'quality']
senticnet['illicitness'] = [-0.722, 0, 0.742, -0.802, '#angry', '#disgusting', -0.755, 'unlawfulness', 'illegality', 'illegitimacy', 'shadiness', 'quality']
senticnet['illimitable'] = [-0.808, 0, 0.761, -0.705, '#sad', '#angry', -0.758, 'immeasurable', 'limitless', 'measureless', 'unmeasured', 'abysmal']
senticnet['illiteracy'] = [-0.896, 0, -0.822, -0.732, '#sad', '#scared', -0.817, 'bad_karma', 'bad_food', 'abduction', 'ignorance', 'loathing']
senticnet['illiterate'] = [-0.901, 0, 0.76, -0.871, '#sad', '#disgusting', -0.844, 'analphabet', 'analphabetic', 'functional_illiterate', 'ignoramus', 'know_nothing']
senticnet['illiterate_person'] = [-0.562, 0, 0.969, -0.657, '#angry', '#disgusting', -0.729, 'analphabet', 'analphabetic', 'functional_illiterate', 'ignoramus', 'know_nothing']
senticnet['illness'] = [-0.092, 0, -0.166, -0.216, '#scared', '#disgusting', -0.158, 'sickness', 'malady', 'polio', 'disease', 'ailment']
senticnet['illogic'] = [-0.551, 0, 0.741, -0.768, '#angry', '#disgusting', -0.687, 'invalidityality', 'invalidityalness', 'invalidity', 'inconsequence', 'fallaciousness']
senticnet['illogical'] = [-0.91, 0, 0, -0.844, '#sad', '#disgusting', -0.585, 'absurd', 'inconsequential', 'visceral', 'nonrational', 'groundless']
senticnet['illogicality'] = [-0.551, 0, 0.741, -0.768, '#angry', '#disgusting', -0.687, 'invalidity', 'illogicalness', 'illogic', 'inconsequence', 'fallaciousness']
senticnet['illogicalness'] = [-0.551, 0, 0.741, -0.768, '#angry', '#disgusting', -0.687, 'illogicality', 'invalidity', 'illogic', 'inconsequence', 'fallaciousness']
senticnet['illuminance'] = [0.637, -0.713, 0, 0.932, '#surprising', '#admirable', 0.761, 'glow', 'illumination', 'incandescence', 'luminescence', 'brightness_level']
senticnet['illuminate'] = [0, 0.889, 0, 0.754, '#interesting', '#admirable', 0.548, 'sort_out', 'shed_light_on', 'light_up', 'elucidate', 'clear']
senticnet['illuminate_area'] = [-0.034, -0.012, -0.08, 0, '#sad', '#scared', -0.034, 'find_hotel', 'find_library', 'read_human', 'read', 'explain_problem']
senticnet['illuminate_room'] = [0, 0, -0.116, 0, '#scared', '#scared', -0.039, 'light', 'illumination', 'hot_sun', 'ultraviolet', 'provide_light']
senticnet['illumination'] = [0, 0, -0.116, 0, '#scared', '#scared', -0.039, 'light', 'illuminate_room', 'hot_sun', 'ultraviolet', 'provide_light']
senticnet['illusion'] = [-0.888, 0, 0.589, -0.856, '#sad', '#disgusting', -0.778, 'phantom', 'shadow', 'disbelief', 'dark_magic', 'fool']
senticnet['illusional'] = [-0.677, 0, 0.716, -0.897, '#angry', '#disgusting', -0.763, 'imaginary', 'notional', 'fabled', 'hallucinatory', 'unreal']
senticnet['illusionist'] = [-0.985, 0, 0.599, -0.932, '#sad', '#disgusting', -0.839, 'diviner', 'intellect', 'anticipant', 'intellectual', 'anticipator']
senticnet['illustrate'] = [0.777, -0.663, 0, 0.839, '#joyful', '#admirable', 0.76, 'elaborate', 'lucubrate', 'expatiate', 'exposit', 'enlarge']
senticnet['illustrate_point'] = [0, -0.944, 0, 0.763, '#surprising', '#admirable', 0.569, 'tell_story', 'tell_many_person', 'reach_tentative_agreement', 'express_information', 'express_oneself']
senticnet['illustration'] = [-0.026, 0.11, 0, 0.131, '#interesting', '#admirable', 0.072, 'wall_decoration', 'image', 'representation', 'artwork', 'wall_hang']
senticnet['illustrious'] = [0.971, 0.764, 0, 0, '#joyful', '#interesting', 0.578, 'notable', 'far-famed', 'famous', 'famed', 'celebrated']
senticnet['image'] = [0, 0.119, -0.054, 0.151, '#interesting', '#admirable', 0.072, 'wall_decoration', 'illustration', 'wall_hang', 'artwork', 'representation']
senticnet['imaginary'] = [0.075, 0.207, -0.061, 0.12, '#interesting', '#admirable', 0.114, 'false', 'unreal', 'non_existent', 'fictional', 'fictitious']
senticnet['imaginary_being'] = [-0.654, 0, 0.859, -0.639, '#sad', '#angry', -0.717, 'alien', 'extraterrestrial_being', 'extraterrestrial', 'hypothetical_creature', 'imaginary_creature']
senticnet['imaginary_creature'] = [-0.654, 0, 0.859, -0.639, '#sad', '#angry', -0.717, 'alien', 'extraterrestrial_being', 'extraterrestrial', 'imaginary_being', 'hypothetical_creature']
senticnet['imaginary_place'] = [-0.924, 0, 0.687, -0.75, '#sad', '#disgusting', -0.787, 'hellfire', 'red_region', 'infernal_region', 'mythical_place', 'fictitious_place']
senticnet['imagination'] = [0, 0.264, -0.09, 0.135, '#interesting', '#admirable', 0.103, 'imaginative', 'idea', 'mental_activity', 'new_think', 'honor_person']
senticnet['imaginative'] = [0, 0.287, -0.101, 0.171, '#interesting', '#admirable', 0.119, 'mental_activity', 'brain_function', 'polarize', 'new_think', 'idea']
senticnet['imaginativeness'] = [-0.956, 0, 0.872, -0.654, '#sad', '#angry', -0.827, 'fancy', 'fantasy', 'dream', 'creativity', 'creativeness']
senticnet['imagine'] = [-0.818, 0, 0.568, -0.837, '#sad', '#disgusting', -0.741, 'fancy', 'foresee', 'fantasy', 'daydream', 'woolgather']
senticnet['imaret'] = [0.931, -0.745, 0, 0.729, '#joyful', '#surprising', 0.802, 'caravansary', 'caravanserai', 'khan', 'caravan_inn', 'hostel']
senticnet['imbalance'] = [-0.596, 0, 0.6, -0.519, '#sad', '#angry', -0.572, 'asymmetry', 'dissymmetry', 'radial_asymmetry', 'directivity', 'directionality']
senticnet['imbecile'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'simple', 'stupid', 'idiotic', 'moron', 'daft']
senticnet['imbecility'] = [-0.907, 0, 0.596, -0.959, '#sad', '#disgusting', -0.821, 'slowness', 'mental_retardation', 'backwardness', 'subnormality', 'retardation']
senticnet['imbibe'] = [0.869, -0.598, 0, 0.66, '#joyful', '#admirable', 0.709, 'assimilate', 'take_up', 'reabsorb', 'resorb', 'absorb']
senticnet['imbroglio'] = [-0.872, 0, 0.762, -0.921, '#sad', '#disgusting', -0.852, 'misreading', 'misconstrual', 'misconstruction', 'misinterpretation', 'interpretation']
senticnet['imitate'] = [-0.046, 0.127, -0.121, 0.223, '#interesting', '#admirable', 0.061, 'act', 'emote', 'portray', 'shorten', 'bold']
senticnet['imitation'] = [0.099, 0.242, -0.157, 0.291, '#interesting', '#admirable', 0.158, 'replicate', 'similarity', 'make_copy', 'make_right', 'band_together']
senticnet['imitative'] = [-0.5, 0, 0.97, -0.521, '#angry', '#disgusting', -0.664, 'simulated', 'apish', 'parrotlike', 'apelike', 'mimic']
senticnet['imitator'] = [-0.969, 0, 0.81, -0.986, '#sad', '#disgusting', -0.922, 'mimic', 'beguiler', 'slicker', 'mimicker', 'deceiver']
senticnet['immaterial'] = [-0.868, 0, 0.894, -0.72, '#sad', '#angry', -0.827, 'inapplicable', 'unsuitable', 'irrelevant', 'extraneous', 'orthogonal']
senticnet['immature'] = [-0.827, 0, 0.87, 0, '#sad', '#angry', -0.566, 'small_boy', 'young_kid', 'fussy', 'helpless', 'little_person']
senticnet['immatureness'] = [-0.938, 0, 0.906, -0.539, '#sad', '#angry', -0.794, 'juvenility', 'state', 'greenness', 'callowness', 'jejuneness']
senticnet['immaturity'] = [-0.72, 0, 0.713, -0.944, '#sad', '#disgusting', -0.792, 'juvenility', 'state', 'greenness', 'callowness', 'jejuneness']
senticnet['immeasurable'] = [-0.808, 0, 0.761, -0.705, '#sad', '#angry', -0.758, 'illimitable', 'limitless', 'measureless', 'unmeasured', 'abysmal']
senticnet['immediacy'] = [0.772, -0.953, 0, 0.89, '#surprising', '#admirable', 0.872, 'downrightness', 'straightforwardness', 'characteristic', 'directness', 'immediateness']
senticnet['immediate'] = [0, 0, 0, -0.783, '#disgusting', '#disgusting', -0.261, 'suddenly', 'precipitous', 'sudden', 'unexpected', 'sudden_asthma_attack']
senticnet['immediately'] = [0.746, 0, 0, 0.824, '#joyful', '#admirable', 0.523, 'now_time', 'right_now', 'contemporary', 'timely', 'time']
senticnet['immediateness'] = [0.772, -0.953, 0, 0.89, '#surprising', '#admirable', 0.872, 'downrightness', 'straightforwardness', 'characteristic', 'immediacy', 'directness']
senticnet['immensurable'] = [-0.628, 0, 0.865, -0.657, '#angry', '#disgusting', -0.717, 'illimitable', 'limitless', 'measureless', 'unmeasured', 'abysmal']
senticnet['immersion'] = [0.633, -0.968, 0, 0.612, '#joyful', '#surprising', 0.738, 'particularism', 'absorption', 'concentration', 'engrossment', 'centering']
senticnet['immersion_foot'] = [-0.503, 0, 0.737, -0.741, '#angry', '#disgusting', -0.66, 'injury', 'harm', 'hurt', 'trench_foot', 'cryopathy']
senticnet['immigrant'] = [0, 0, 0, -0.959, '#disgusting', '#disgusting', -0.32, 'far_from_home', 'expat', 'live_abroad', 'connoisseur', 'work_abroad']
senticnet['immobile'] = [-0.576, 0, 0.97, -0.761, '#angry', '#disgusting', -0.769, 'immovable', 'immoveable', 'unmovable', 'nonmotile', 'immotile']
senticnet['immobilization'] = [-0.973, 0, 0.885, -0.976, '#sad', '#disgusting', -0.945, 'protection', 'conservation', 'environmentalism', 'reservation', 'preservation']
senticnet['immobilize'] = [0.63, -0.696, 0, 0.865, '#surprising', '#admirable', 0.73, 'curtail', 'limit', 'abridge', 'ration', 'restrict']
senticnet['immoderate'] = [-0.891, 0, 0.6, -0.925, '#sad', '#disgusting', -0.805, 'outrageous', 'exorbitant', 'extortionate', 'usurious', 'abnormal']
senticnet['immoderateness'] = [-0.501, 0, 0.89, -0.786, '#angry', '#disgusting', -0.726, 'excess', 'degree', 'grade', 'level', 'excessiveness']
senticnet['immoderation'] = [-0.76, 0, 0.79, -0.981, '#angry', '#disgusting', -0.844, 'excess', 'degree', 'grade', 'level', 'excessiveness']
senticnet['immodesty'] = [-0.526, 0, 0.648, -0.967, '#angry', '#disgusting', -0.714, 'improperness', 'outrageousness', 'impropriety', 'indecency', 'obscenity']
senticnet['immoral'] = [0, 0, 0, -0.959, '#disgusting', '#disgusting', -0.32, 'unethical', 'bad', 'obscene', 'indecent', 'shameless']
senticnet['immorality'] = [-0.693, 0, 0.89, -0.988, '#angry', '#disgusting', -0.857, 'evil', 'wrongness', 'putrefaction', 'wantonness', 'corruptibility']
senticnet['immortal'] = [0, 0, 0, 0.816, '#admirable', '#admirable', 0.272, 'immortality', 'live_forever', 'never_die', 'eternal_life', 'everlasting_life']
senticnet['immortality'] = [0, 0, 0, 0.825, '#admirable', '#admirable', 0.275, 'live_forever', 'immortal', 'eternal_life', 'everlasting_life', 'never_die']
senticnet['immotile'] = [-0.576, 0, 0.97, -0.761, '#angry', '#disgusting', -0.769, 'immovable', 'immoveable', 'unmovable', 'nonmotile', 'immobile']
senticnet['immovability'] = [-0.708, 0, 0.947, -0.957, '#angry', '#disgusting', -0.871, 'tautness', 'fixity', 'secureness', 'steadiness', 'firmness']
senticnet['immovable'] = [0.975, -0.993, 0, 0.644, '#joyful', '#surprising', 0.871, 'entail', 'barony', 'seigneury', 'seigniory', 'demesne']
senticnet['immovableness'] = [-0.806, 0, 0.675, -0.645, '#sad', '#angry', -0.709, 'tautness', 'fixity', 'secureness', 'steadiness', 'firmness']
senticnet['immovale'] = [0, 0, -0.818, -0.716, '#scared', '#disgusting', -0.511, 'breathless', 'tight', 'narrow', 'without_space', 'small']
senticnet['immoveable'] = [-0.576, 0, 0.97, -0.761, '#angry', '#disgusting', -0.769, 'immovable', 'immobile', 'unmovable', 'nonmotile', 'immotile']
senticnet['immune'] = [-0.921, 0, 0.731, -0.852, '#sad', '#disgusting', -0.835, 'unimpressed', 'untouched', 'uninfluenced', 'unswayed', 'unaffected']
senticnet['immunity'] = [0, 0, 0, 0.816, '#admirable', '#admirable', 0.272, 'resitence', 'protection', 'untouchable', 'invunerable', 'sacrosanct']
senticnet['immunodeficiency'] = [-0.989, 0, 0.942, -0.9, '#sad', '#angry', -0.944, 'disease', 'aids', 'immunological_disorder', 'die', 'hiv']
senticnet['immunological_disorder'] = [-0.65, 0, 0.744, -0.802, '#angry', '#disgusting', -0.732, 'upset', 'disorder', 'immunodeficiency', 'anergy', 'immunosuppression']
senticnet['immunologist'] = [0.904, -0.93, 0, 0.639, '#joyful', '#surprising', 0.824, 'toxicologist', 'epidemiologist', 'medical_scientist', 'serologist', 'scientist']
senticnet['immunosuppression'] = [-0.65, 0, 0.744, -0.802, '#angry', '#disgusting', -0.732, 'upset', 'disorder', 'immunodeficiency', 'anergy', 'immunological_disorder']
senticnet['immutability'] = [-0.834, 0, 0.696, -0.989, '#sad', '#disgusting', -0.84, 'unalterability', 'agelessness', 'changelessness', 'unchangeability', 'unchangeableness']
senticnet['immutableness'] = [-0.727, 0, 0.81, -0.78, '#angry', '#disgusting', -0.772, 'unalterability', 'agelessness', 'changelessness', 'unchangeability', 'unchangeableness']
senticnet['imp'] = [0.526, -0.997, 0, 0.673, '#surprising', '#admirable', 0.732, 'faery', 'faerie', 'fairy', 'leprechaun', 'sandman']
senticnet['impact'] = [-0.084, 0.23, -0.186, 0.196, '#interesting', '#admirable', 0.052, 'tell_why', 'inquire', 'explanation', 'question_start', 'request']
senticnet['impair'] = [-0.624, 0, 0.756, -0.626, '#angry', '#disgusting', -0.669, 'vitiate', 'mar', 'maul', 'mangle', 'deface']
senticnet['impaired'] = [-0.968, 0, 0.624, -0.99, '#sad', '#disgusting', -0.861, 'vitiated', 'dicky', 'dickey', 'lessened', 'diminished']
senticnet['impairment'] = [-0.641, 0, 0.731, -0.524, '#sad', '#angry', -0.632, 'hurt', 'detriment', 'deformation', 'distortion', 'modification']
senticnet['impairment_person'] = [0, 0, -0.073, 0, '#scared', '#scared', -0.024, 'nymph', 'mole', 'nightly_ritual', 'rabbit', 'squirrel']
senticnet['impalement'] = [-0.875, 0, 0.932, -0.6, '#sad', '#angry', -0.802, 'atrocity', 'maltreatment', 'abuse', 'inhumanity', 'inhuman_treatment']
senticnet['impart'] = [0.99, -0.769, 0, 0.571, '#joyful', '#surprising', 0.777, 'add', 'contribute', 'lend', 'breathe', 'instill']
senticnet['impartial'] = [0.837, -0.996, 0, 0.559, '#joyful', '#surprising', 0.797, 'disinterested', 'dispassionate', 'indifferent', 'unbiased', 'fair']
senticnet['impassioned'] = [0, 0, -0.72, -0.762, '#scared', '#disgusting', -0.494, 'fervent', 'fervid', 'fiery', 'perfervid', 'ardent']
senticnet['impassive'] = [-0.947, 0, 0.636, -0.745, '#sad', '#disgusting', -0.776, 'incommunicado', 'unpronounceable', 'incommunicative', 'inexpressive', 'silent']
senticnet['impassiveness'] = [0, 0, -0.72, -0.992, '#scared', '#disgusting', -0.571, 'apathetically', 'impassivity', 'emotionlessness', 'unemotionality', 'stolidity']
senticnet['impassivity'] = [0, 0, -0.97, -0.912, '#scared', '#disgusting', -0.627, 'impassiveness', 'apathetically', 'emotionlessness', 'unemotionality', 'stolidity']
senticnet['impatience'] = [0, 0, 0, -0.971, '#disgusting', '#disgusting', -0.324, 'fidget', 'impatient', 'nervous', 'restlessness', 'nervousness']
senticnet['impatient'] = [-0.719, 0, 0, -0.97, '#sad', '#disgusting', -0.563, 'fidget', 'impatience', 'restlessness', 'impatiently', 'raring']
senticnet['impatiently'] = [-0.786, 0, 0, -0.724, '#sad', '#disgusting', -0.503, 'raring', 'fretful', 'fidgetiness', 'antsy', 'fidgety']
senticnet['impeachability'] = [-0.985, 0, 0.657, -0.959, '#sad', '#disgusting', -0.867, 'guiltiness', 'indictability', 'blameworthiness', 'culpability', 'culpableness']
senticnet['impecunious'] = [0, 0, -0.736, -0.741, '#scared', '#disgusting', -0.492, 'pinched', 'in_straitened_circumstances', 'hard_up', 'penniless', 'penurious']
senticnet['impede'] = [-0.393, 0.149, -0.166, 0.062, '#sad', '#scared', -0.116, 'block', 'confuse', 'confound', 'frustrate', 'baffle']
senticnet['impediment'] = [-0.885, 0, 0.944, -0.918, '#angry', '#disgusting', -0.916, 'difficulty', 'straitjacket', 'millstone', 'drag', 'obstruction']
senticnet['impedimenta'] = [-0.842, 0, 0.553, -0.897, '#sad', '#disgusting', -0.764, 'encumbrance', 'incumbrance', 'block', 'bar', 'blockade']
senticnet['impeding'] = [-0.904, 0, 0.922, 0, '#sad', '#angry', -0.609, 'obturate', 'occlude', 'hinder', 'impede', 'obstruct']
senticnet['impend_danger'] = [-0.272, 0.17, -0.302, 0, '#sad', '#scared', -0.135, 'caution', 'retribution', 'wrong', 'kidnap', 'mental_disorder']
senticnet['impenetrable'] = [-0.991, 0, 0.797, -0.569, '#sad', '#angry', -0.786, 'dark', 'uncomprehensible', 'lost', 'missed', 'unfathomable']
senticnet['impenitence'] = [-0.633, 0, 0.942, -0.528, '#sad', '#angry', -0.701, 'stubbornness', 'obstinacy', 'obstinance', 'bullheadedness', 'pigheadedness']
senticnet['impenitency'] = [-0.799, 0, 0.607, -0.923, '#sad', '#disgusting', -0.776, 'stubbornness', 'obstinacy', 'obstinance', 'bullheadedness', 'pigheadedness']
senticnet['impenitent'] = [-0.677, 0, 0.715, -0.89, '#angry', '#disgusting', -0.761, 'obstinate', 'unrepentant', 'unregenerated', 'unconverted', 'unpersuaded']
senticnet['imperative'] = [0, 0.314, -0.201, 0.404, '#interesting', '#admirable', 0.172, 'compel', 'permission', 'take', 'take_over', 'computer_key']
senticnet['imperceptible'] = [-0.781, 0, 0.792, -0.616, '#sad', '#angry', -0.73, 'incognizable', 'incognoscible', 'insensible', 'unobservable', 'indiscernible']
senticnet['imperfectibility'] = [0.946, -0.641, 0, 0.602, '#joyful', '#surprising', 0.73, 'grasp', 'perfectibility', 'capableness', 'reach', 'aptitude']
senticnet['imperfection'] = [-0.848, 0, 0.613, -0.605, '#sad', '#angry', -0.689, 'weakness', 'fault', 'flaw', 'defect', 'wart']
senticnet['imperfectness'] = [-0.974, 0, 0.781, -0.913, '#sad', '#disgusting', -0.889, 'weakness', 'fault', 'flaw', 'defect', 'wart']
senticnet['imperial'] = [0.039, 0, 0.038, 0.099, '#joyful', '#admirable', 0.033, 'ruler', 'kingly', 'nobleman', 'blue_blood', 'nobility']
senticnet['imperial_measurement'] = [0, 0.082, 0.076, 0.111, '#interesting', '#admirable', 0.039, 'measurement_unit', 'measure', 'centimetre', 'length', 'measurement']
senticnet['imperiousness'] = [0.968, -0.88, 0, 0.831, '#joyful', '#surprising', 0.893, 'superiority', 'pride', 'superbia', 'haughtiness', 'domineeringness']
senticnet['imperishable'] = [-0.957, 0, 0.799, -0.673, '#sad', '#angry', -0.81, 'imputrescible', 'undestroyable', 'indestructible', 'durable', 'perdurable']
senticnet['imperium'] = [0.742, -0.927, 0, 0.564, '#joyful', '#surprising', 0.744, 'potency', 'lordship', 'power_of_appointment', 'carte_blanche', 'command']
senticnet['impermanence'] = [-0.877, 0, 0.744, -0.54, '#sad', '#angry', -0.72, 'temporariness', 'transience', 'transiency', 'transitoriness', 'mortality']
senticnet['impermanency'] = [-0.859, 0, 0.968, -0.758, '#sad', '#angry', -0.862, 'temporariness', 'transience', 'transiency', 'transitoriness', 'mortality']
senticnet['impermanent'] = [0.053, 0.264, -0.119, 0.23, '#interesting', '#admirable', 0.143, 'totality', 'temporary', 'character_trait', 'all_of_it', 'end_soon']
senticnet['impermeability'] = [-0.522, 0, 0.596, -0.76, '#angry', '#disgusting', -0.626, 'retention', 'retentiveness', 'retentivity', 'solidness', 'nonabsorbency']
senticnet['impermeableness'] = [-0.649, 0, 0.868, -0.955, '#angry', '#disgusting', -0.824, 'retention', 'retentiveness', 'retentivity', 'solidness', 'nonabsorbency']
senticnet['impermissible'] = [-0.75, 0, 0.614, -0.743, '#sad', '#disgusting', -0.702, 'out', 'unmentionable', 'untouchable', 'taboo', 'tabu']
senticnet['impersonator'] = [-0.589, 0, 0.768, -0.895, '#angry', '#disgusting', -0.751, 'mimic', 'beguiler', 'slicker', 'mimicker', 'deceiver']
senticnet['imperturbability'] = [0.527, 0.659, -0.249, 0.258, '#joyful', '#interesting', 0.398, 'imperturbableness', 'tranquil', 'unagitated', 'placidly', 'placidity']
senticnet['imperturbableness'] = [0.527, 0.659, -0.249, 0.258, '#joyful', '#interesting', 0.398, 'imperturbability', 'tranquil', 'unagitated', 'placidly', 'placidity']
senticnet['imperviable'] = [-0.9, 0, 0.657, -0.644, '#sad', '#angry', -0.734, 'soundproof', 'mothproof', 'resistant', 'proof', 'greaseproof']
senticnet['impervious'] = [0, 0.925, 0, 0.897, '#interesting', '#admirable', 0.607, 'soundproof', 'mothproof', 'resistant', 'proof', 'greaseproof']
senticnet['impetuous'] = [0, 0, 0.782, -0.803, '#angry', '#disgusting', -0.528, 'impulsive', 'tearaway', 'hotheaded', 'madcap', 'incautious']
senticnet['impiety'] = [-0.919, 0, 0, -0.75, '#sad', '#disgusting', -0.556, 'irreverence', 'disrespect', 'apostasy', 'atheism', 'sacrilege']
senticnet['impinge_on'] = [-0.536, 0, 0.57, -0.732, '#angry', '#disgusting', -0.613, 'run_into', 'strike', 'hit', 'bump_into', 'collide_with']
senticnet['impiousness'] = [0.619, -0.975, 0, 0.728, '#surprising', '#admirable', 0.774, 'unrighteousness', 'undutifulness', 'godlessness', 'ungodliness', 'irreligiousness']
senticnet['impish'] = [0, 0, -0.732, -0.857, '#scared', '#disgusting', -0.53, 'mischievous', 'prankish', 'implike', 'arch', 'pixilated']
senticnet['implacable'] = [-0.969, 0, 0.836, 0, '#sad', '#angry', -0.602, 'stern', 'relentless', 'unrelenting', 'grim', 'merciless']
senticnet['implausible'] = [0, 0, -0.767, -0.745, '#scared', '#disgusting', -0.504, 'farfetched', 'unbelievable', 'cockamamie', 'cockamamy', 'unlikely']
senticnet['implement'] = [0, 0, 0, 0.14, '#admirable', '#admirable', 0.047, 'type_of_game', 'monopoly', 'game_part', 'expensive_hobby', 'kid_game']
senticnet['implicative'] = [0.734, -0.56, 0, 0.64, '#joyful', '#admirable', 0.645, 'inferential', 'suggestive', 'connotative', 'connotational', 'connotative_of']
senticnet['implicit'] = [0.531, -0.769, 0, 0.603, '#surprising', '#admirable', 0.634, 'tacit', 'understood', 'unvoiced', 'silent', 'unspoken']
senticnet['implore'] = [-0.855, 0, 0.518, -0.572, '#sad', '#disgusting', -0.648, 'conjure', 'appeal', 'beg', 'plead', 'pray']
senticnet['implosion_therapy'] = [0.542, -0.63, 0, 0.912, '#surprising', '#admirable', 0.695, 'behavior_modification', 'flooding', 'reciprocal_inhibition', 'aversion_therapy', 'desensitization_technique']
senticnet['imply'] = [0.832, 0.87, 0, 0, '#joyful', '#interesting', 0.567, 'show', 'justify', 'smack', 'incriminate', 'inculpate']
senticnet['impolite'] = [0.584, -0.592, 0, 0.753, '#surprising', '#admirable', 0.643, 'ungracious', 'discourteous', 'bratty', 'brattish', 'unparliamentary']
senticnet['impoliteness'] = [0.606, -0.978, 0, 0.742, '#surprising', '#admirable', 0.775, 'bad_manners', 'rudeness', 'gaucheness', 'crudeness', 'crudity']
senticnet['import'] = [-0.031, 0.223, -0.155, 0.35, '#interesting', '#admirable', 0.129, 'return', 'gain', 'cheap_buy', 'receive', 'bequest']
senticnet['importance'] = [0, 0.737, 0, 0.914, '#interesting', '#admirable', 0.55, 'assurance', 'quality', 'total', 'important_thing', 'amount']
senticnet['important'] = [0, 0.712, 0, 0.929, '#interesting', '#admirable', 0.547, 'capitalize', 'good_quality', 'niceness', 'good', 'hard_find']
senticnet['important_event'] = [0.044, 0, -0.135, -0.068, '#scared', '#disgusting', -0.053, 'good_news', 'history', 'past_time', 'past_event', 'long_ago']
senticnet['important_game'] = [0, 0.069, 0, 0.111, '#interesting', '#admirable', 0.06, 'olympiads', 'event', 'important_event', 'hold_every_four_years', 'important_occasion']
senticnet['important_good_health'] = [0.044, 0.092, -0.052, 0.165, '#interesting', '#admirable', 0.083, 'good_human', 'good_body', 'healthy', 'push_up', 'good_health']
senticnet['important_human'] = [0, 0.924, 0, 0.885, '#interesting', '#admirable', 0.603, 'priceless', 'universal', 'visual_representation', 'bourgeois', 'artistic_expression']
senticnet['important_job'] = [0, 0.112, -0.049, 0.099, '#interesting', '#admirable', 0.054, 'profession', 'career', 'vocation', 'occupation', 'laborer']
senticnet['important_man'] = [0.186, -0.024, 0, 0.166, '#joyful', '#admirable', 0.125, 'please_person', 'beautiful', 'divine', 'sung', 'universal']
senticnet['important_message'] = [0, 0.913, 0, 0, '#interesting', '#interesting', 0.304, 'loud_shout', 'loud_cry', 'loud_yell', 'freak_out', 'human_noise']
senticnet['important_occasion'] = [0, 0.069, 0, 0.111, '#interesting', '#admirable', 0.06, 'olympiads', 'event', 'important_event', 'important_game', 'hold_every_four_years']
senticnet['important_person'] = [0, 0.755, 0, 0.951, '#interesting', '#admirable', 0.569, 'priceless', 'universal', 'good', 'subjective', 'easy_use']
senticnet['important_stay_healthy'] = [0.778, 0, 0, 0.787, '#joyful', '#admirable', 0.522, 'godliness', 'remove_stain', 'physical_reaction', 'neurotic', 'shrinkage']
senticnet['important_thing'] = [-0.048, 0.198, -0.133, 0.185, '#interesting', '#admirable', 0.067, 'do_something', 'big_deal', 'factory_output', 'creation', 'make_happen']
senticnet['impose'] = [-0.171, 0.149, -0.222, 0, '#sad', '#scared', -0.081, 'raid', 'defence', 'fight_against', 'get_revenge', 'uprise']
senticnet['imposing'] = [0, 0, 0.714, -0.804, '#angry', '#disgusting', -0.506, 'stately', 'dignified', 'courtly', 'distinguished', 'grand']
senticnet['imposition'] = [-0.706, 0, 0.552, -0.681, '#sad', '#disgusting', -0.646, 'protection', 'regimentation', 'taxation', 'trade_protection', 'reimposition']
senticnet['impossibility'] = [-0.661, 0, 0.984, -0.554, '#sad', '#angry', -0.733, 'inconceivability', 'inconceivableness', 'nonexistence', 'nonentity', 'unattainableness']
senticnet['impossible'] = [-0.808, 0, -0.803, -0.961, '#sad', '#disgusting', -0.857, 'unable', 'absurd', 'difficult', 'impratical', 'unimaginable']
senticnet['impossibleness'] = [-0.516, 0, 0.789, -0.6, '#angry', '#disgusting', -0.635, 'inconceivability', 'inconceivableness', 'nonexistence', 'nonentity', 'unattainableness']
senticnet['imposter'] = [-0.744, 0, 0.93, -0.589, '#sad', '#angry', -0.754, 'beguiler', 'slicker', 'name_dropper', 'ringer', 'deceiver']
senticnet['impostor'] = [-0.754, 0, 0.519, -0.648, '#sad', '#disgusting', -0.64, 'beguiler', 'slicker', 'name_dropper', 'ringer', 'deceiver']
senticnet['impotence'] = [-0.962, 0, 0.531, -0.518, '#sad', '#angry', -0.67, 'impuissance', 'weakness', 'unpersuasiveness', 'uninterestingness', 'helplessness']
senticnet['impotency'] = [-0.797, 0, 0.792, -0.863, '#sad', '#disgusting', -0.817, 'impuissance', 'weakness', 'unpersuasiveness', 'uninterestingness', 'helplessness']
senticnet['impotent'] = [-0.941, 0, 0.987, -0.643, '#sad', '#angry', -0.857, 'unable', 'ineffectual', 'ineffective', 'impuissant', 'effete']
senticnet['impoverish'] = [-0.892, 0, 0, -0.736, '#sad', '#disgusting', -0.543, 'leave_out', 'lose_team', 'cause_suffer', 'disrespect', 'loathing']
senticnet['impoverished'] = [-0.622, 0, 0.863, -0.991, '#angry', '#disgusting', -0.825, 'spoilt', 'wrecked', 'destroyed', 'blighted', 'extinguished']
senticnet['impoverishment'] = [-0.617, 0, 0.712, -0.861, '#angry', '#disgusting', -0.73, 'destitution', 'deprivation', 'indigence', 'penury', 'pauperism']
senticnet['impracticability'] = [-0.978, 0, 0.675, -0.937, '#sad', '#disgusting', -0.863, 'infeasibility', 'unfeasibility', 'inutility', 'uselessness', 'unusefulness']
senticnet['impracticableness'] = [-0.612, 0, 0.985, -0.667, '#angry', '#disgusting', -0.755, 'infeasibility', 'unfeasibility', 'inutility', 'uselessness', 'unusefulness']
senticnet['impractical'] = [-0.755, 0, 0.832, -0.695, '#sad', '#angry', -0.761, 'unfunctional', 'useless', 'stupid', 'difficult', 'hard']
senticnet['impracticality'] = [0.909, -0.731, 0, 0.635, '#joyful', '#surprising', 0.758, 'quality', 'futility', 'inutility', 'worthlessness', 'impracticability']
senticnet['impratical'] = [-0.808, 0, -0.803, -0.961, '#sad', '#disgusting', -0.857, 'unable', 'absurd', 'difficult', 'impossible', 'unimaginable']
senticnet['imprecate'] = [-0.995, 0, 0.993, -0.905, '#sad', '#angry', -0.964, 'call_down', 'stir', 'call_forth', 'conjure', 'bring_up']
senticnet['imprecation'] = [-0.708, 0, 0.874, -0.75, '#angry', '#disgusting', -0.777, 'blame', 'incrimination', 'inculpation', 'complaint', 'accusation']
senticnet['impregnable'] = [0.702, -0.95, 0, 0.997, '#surprising', '#admirable', 0.883, 'fertilizable', 'fecund', 'conceptive', 'fertile', 'rank']
senticnet['impregnate_female'] = [0.081, 0.134, -0.077, 0, '#joyful', '#interesting', 0.046, 'sexual_intercourse', 'find_mate', 'fuck', 'make_love', 'pregnant']
senticnet['impregnation'] = [0.789, -0.925, 0, 0.964, '#surprising', '#admirable', 0.893, 'ammonification', 'carbonation', 'permeation', 'saturation', 'diffusion']
senticnet['impress'] = [0.463, 0.561, -0.294, 0.281, '#joyful', '#interesting', 0.337, 'self-esteem', 'grateful', 'encouragement', 'positive', 'adoration']
senticnet['impress_boss'] = [0.748, 0.844, 0, 0.51, '#joyful', '#interesting', 0.701, 'share_knowledge', 'find_solution', 'share_information', 'tell_information', 'learn_oneself']
senticnet['impress_date'] = [0.463, 0.561, -0.294, 0.281, '#joyful', '#interesting', 0.337, 'write_date', 'digitate_date', 'use_computer', 'use_pen', 'date']
senticnet['impress_girl'] = [0.936, 0, 0, 0.974, '#joyful', '#admirable', 0.637, 'charm', 'like_compete', 'funny_friend', 'learn_teamwork', 'fun_exercise']
senticnet['impress_girlfriend'] = [0.964, 0, 0, 0, '#joyful', '#joyful', 0.321, 'weight_gain', 'become_little_hungry', 'eat_pizza', 'eat', 'satisfy_crave']
senticnet['impress_other_person'] = [0, 0.793, 0, 0.91, '#interesting', '#admirable', 0.568, 'make_good_impression', 'hygiene', 'smell_good', 'social_acceptance', 'smell_better']
senticnet['impress_others'] = [0, 0.718, 0, 0.814, '#interesting', '#admirable', 0.511, 'impress_other_person', 'feel_good_oneself', 'set_example', 'feel_better_oneself', 'look_good']
senticnet['impress_person'] = [0, 0.827, 0, 0.84, '#interesting', '#admirable', 0.556, 'tell_day', 'get_know', 'look_sexy', 'find_new_friend', 'visit_friend']
senticnet['impressed'] = [0.854, -0.845, 0, 0.679, '#joyful', '#surprising', 0.793, 'taken', 'subject', 'stricken', 'struck', 'affected']
senticnet['impressible'] = [0.808, -0.699, 0, 0.938, '#joyful', '#admirable', 0.815, 'spinnable', 'susceptible', 'easy', 'pliant', 'plastic']
senticnet['impression'] = [0, 0.809, 0, 0.991, '#interesting', '#admirable', 0.6, 'presentation', 'bold', 'movie_star', 'emote', 'tv_show']
senticnet['impressionable'] = [0.724, -0.703, 0, 0.571, '#joyful', '#surprising', 0.666, 'spinnable', 'susceptible', 'easy', 'pliant', 'plastic']
senticnet['impressive'] = [0.562, -0.698, 0, 0.883, '#surprising', '#admirable', 0.714, 'majestic', 'formidable', 'awesome', 'awing', 'brilliant']
senticnet['impressiveness'] = [0, 0.967, 0, 0.824, '#interesting', '#admirable', 0.597, 'stateliness', 'excellence', 'grandness', 'richness', 'expansivity']
senticnet['imprimatur'] = [0.751, -0.986, 0, 0.989, '#surprising', '#admirable', 0.909, 'okay', 'approval', 'commendation', 'okey', 'okeh']
senticnet['imprison'] = [-0.868, 0, -0.993, -0.935, '#scared', '#disgusting', -0.932, 'feel_guilt', 'die', 'send_to_prison', 'feel_remorse', 'go_to_prison']
senticnet['imprisoned'] = [0, 0, -0.992, -0.913, '#scared', '#disgusting', -0.635, 'jailbird', 'prisoner', 'captive', 'convict', 'inmate']
senticnet['imprisonment'] = [-0.808, 0, -0.803, -0.961, '#sad', '#disgusting', -0.857, 'stab_knife', 'die', 'feel_guilt', 'seek_revenge', 'feel_remorse']
senticnet['improbability'] = [0.602, -0.728, 0, 0.892, '#surprising', '#admirable', 0.741, 'unlikelihood', 'unlikeliness', 'uncertainty', 'precariousness', 'uncertainness']
senticnet['improbable'] = [-0.542, 0, 0.646, -0.62, '#angry', '#disgusting', -0.603, 'unbelievable', 'undreamed', 'undreamed_of', 'undreamt', 'undreamt_of']
senticnet['improbableness'] = [0.76, -0.864, 0, 0.819, '#surprising', '#admirable', 0.814, 'unlikelihood', 'unlikeliness', 'uncertainty', 'precariousness', 'uncertainness']
senticnet['impromptu'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'play_by_ear', 'improvise', 'natural', 'easy_going', 'spontaneous']
senticnet['improper'] = [-0.648, 0, 0.52, -0.532, '#sad', '#disgusting', -0.567, 'wrong', 'incorrect', 'unbecoming', 'uncomely', 'unseemly']
senticnet['improperness'] = [-0.887, 0, 0.705, -0.867, '#sad', '#disgusting', -0.82, 'wrongness', 'inappropriateness', 'indecency', 'incorrectness', 'indelicacy']
senticnet['impropriety'] = [-0.532, 0, 0.924, -0.599, '#angry', '#disgusting', -0.685, 'wrongness', 'inappropriateness', 'indecency', 'incorrectness', 'indelicacy']
senticnet['improvable'] = [0.779, -0.882, 0, 0.521, '#joyful', '#surprising', 0.727, 'amendable', 'correctable', 'corrigible', 'reformable', 'redeemable']
senticnet['improve'] = [0.977, 0.805, 0, 0.908, '#joyful', '#admirable', 0.897, 'set_example', 'make_better', 'get_better', 'proposition', 'make_right']
senticnet['improve_appearance'] = [0.89, 0.796, 0, 0.74, '#joyful', '#interesting', 0.809, 'look_smart', 'look_neat', 'look_good', 'make_good_impression', 'look_presentable']
senticnet['improve_company'] = [0, 0.312, -0.136, 0.328, '#interesting', '#admirable', 0.168, 'increase', 'efficiency', 'increase_energy', 'work_hard', 'increase_efficiency']
senticnet['improve_health'] = [0.071, 0, 0, 0, '#joyful', '#joyful', 0.024, 'build_muscle', 'become_fit', 'stay_shape', 'exercise', 'good_health']
senticnet['improve_image'] = [0, -0.045, 0, 0.069, '#surprising', '#admirable', 0.038, 'look_better', 'dress_nice', 'change_appearance', 'get_latest_hairstyle', 'groom']
senticnet['improve_knowledge'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'plan_trip', 'desire_social_interaction', 'see_different', 'proselytize', 'buy_airline_ticket']
senticnet['improve_life'] = [0.853, 0.936, 0, 0.949, '#interesting', '#admirable', 0.913, 'educate_others', 'add_knowledge', 'become_smart', 'increase_knowledge', 'expand_mind']
senticnet['improve_look'] = [0.985, 0.931, 0, 0.789, '#joyful', '#interesting', 0.902, 'look_good', 'look_smart', 'improve_appearance', 'look_presentable', 'look_neat']
senticnet['improve_oneself'] = [0.827, 0.913, 0, 0.867, '#interesting', '#admirable', 0.869, 'good_habit', 'competitive_nature', 'competitive', 'fighting_spirit', 'want_to_win']
senticnet['improve_performance'] = [0.906, 0.719, 0, 0.962, '#joyful', '#admirable', 0.862, 'new_idea', 'appreciation', 'insight', 'increase_intelligence', 'inspiration']
senticnet['improve_self-image'] = [0.178, 0.089, -0.082, 0.119, '#joyful', '#admirable', 0.101, 'own_benefit', 'healthy_live', 'keep_body_healthy', 'prolong_life', 'think_clearly']
senticnet['improve_skill'] = [0.896, 0.732, 0, 0.817, '#joyful', '#admirable', 0.815, 'please_teacher', 'find_new', 'pass_exam', 'raise_self_esteem', 'get_degree']
senticnet['improve_vision'] = [-0.079, -0.065, 0.01, -0.11, '#sad', '#disgusting', -0.045, 'pupil', 'love_art', 'learn_evolution', 'use_eye', 'correct_vision']
senticnet['improve_world'] = [0.836, 0.836, 0, 0.72, '#joyful', '#interesting', 0.797, 'make_world_better_place', 'help_others', 'fame', 'personal_growth', 'personal_improvement']
senticnet['improvement'] = [0.925, 0.949, 0, 0.899, '#joyful', '#interesting', 0.924, 'let', 'betterment', 'return', 'permission', 'imperative']
senticnet['improvident'] = [-0.638, 0, 0.867, -0.57, '#sad', '#angry', -0.692, 'myopic', 'short', 'shortsighted', 'unforesightful', 'thriftless']
senticnet['improvise'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'impromptu', 'play_by_ear', 'natural', 'easy_going', 'spontaneous']
senticnet['imprudence'] = [0, 0, 0.929, -0.955, '#angry', '#disgusting', -0.628, 'incaution', 'neglect', 'mindlessness', 'rashness', 'heedlessness']
senticnet['imprudent'] = [-0.925, 0, 0.876, -0.963, '#sad', '#disgusting', -0.921, 'bigmouthed', 'blabby', 'blabbermouthed', 'talkative', 'indiscreet']
senticnet['impuissance'] = [-0.962, 0, 0.531, -0.518, '#sad', '#angry', -0.67, 'impotence', 'weakness', 'unpersuasiveness', 'uninterestingness', 'helplessness']
senticnet['impuissant'] = [-0.941, 0, 0.987, -0.643, '#sad', '#angry', -0.857, 'unable', 'ineffectual', 'ineffective', 'impotent', 'effete']
senticnet['impulse'] = [-0.637, 0, 0.677, -0.948, '#angry', '#disgusting', -0.754, 'motive', 'need', 'motivation', 'abience', 'adience']
senticnet['impulse_shop'] = [-0.034, -0.04, 0.064, -0.071, '#angry', '#disgusting', -0.043, 'buy_clothes', 'spend_money', 'get_grocery', 'window_shop', 'buy_goods']
senticnet['impulse_turbine'] = [-0.976, 0, 0.658, -0.606, '#sad', '#angry', -0.747, 'gas_turbine', 'hydroelectric_turbine', 'turbine', 'reaction_turbine', 'steam_turbine']
senticnet['impulsive'] = [0.631, -0.877, 0, 0.887, '#surprising', '#admirable', 0.798, 'incautious', 'tearaway', 'hotheaded', 'madcap', 'impetuous']
senticnet['impulsiveness'] = [-0.938, 0, 0.672, -0.946, '#sad', '#disgusting', -0.852, 'recklessness', 'foolhardiness', 'rashness', 'trait', 'unthoughtfulness']
senticnet['impunity'] = [0.73, -0.569, 0, 0.621, '#joyful', '#admirable', 0.64, 'amnesty', 'unsusceptibility', 'diplomatic_immunity', 'indemnity', 'exemption']
senticnet['impure'] = [-0.818, 0, 0.668, -0.873, '#sad', '#disgusting', -0.786, 'dirty', 'dingy', 'muddied', 'alloyed', 'adulterate']
senticnet['impureness'] = [0.693, -0.641, 0, 0.895, '#joyful', '#admirable', 0.743, 'debasement', 'dirtiness', 'pollution', 'taint', 'adulteration']
senticnet['impurity'] = [0, 0, 0.983, -0.788, '#angry', '#disgusting', -0.59, 'waste_material', 'dross', 'exhaust', 'garbage', 'corrupt']
senticnet['imputable'] = [0.511, -0.597, 0, 0.576, '#surprising', '#admirable', 0.561, 'due', 'traceable', 'ascribable', 'attributable', 'referable']
senticnet['imputrescible'] = [-0.957, 0, 0.799, -0.673, '#sad', '#angry', -0.81, 'imperishable', 'undestroyable', 'indestructible', 'durable', 'perdurable']
senticnet['in_between'] = [0.043, 0.14, 0.01, 0.245, '#interesting', '#admirable', 0.139, 'center', 'middle', 'in_middle', 'downtown', 'placement']
senticnet['in_charge'] = [0.053, 0.248, -0.185, 0.258, '#interesting', '#admirable', 0.125, 'first', 'dominant_role', 'alpha_male', 'master', 'alpha']
senticnet['in_dearth'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'shortage', 'scarceness', 'insufficient', 'short_fall', 'poverty']
senticnet['in_earnest'] = [0, 0.73, 0, 0.758, '#interesting', '#admirable', 0.496, 'seriously', 'devout', 'earnestness', 'earnestly', 'seriousness']
senticnet['in_middle'] = [0.043, 0.14, 0.01, 0.245, '#interesting', '#admirable', 0.139, 'in_between', 'middle', 'center', 'downtown', 'placement']
senticnet['in_need'] = [0, 0, -0.943, -0.77, '#scared', '#disgusting', -0.571, 'demand', 'yearn', 'need_help', 'want_badly', 'need']
senticnet['in_person'] = [0, 0, -0.753, -0.749, '#scared', '#disgusting', -0.501, 'dead_person', 'corpse', 'cadaver', 'human_chest', 'below_neck']
senticnet['inability'] = [-0.784, 0, 0.707, -0.868, '#sad', '#disgusting', -0.786, 'mental_block', 'uncreativeness', 'stupidity', 'illiteracy', 'analphabetism']
senticnet['inability_host'] = [0, 0, 0.933, -0.866, '#angry', '#disgusting', -0.6, 'mess', 'disgusting', 'dirty_house', 'dirty_kitchen', 'dirty_stuff']
senticnet['inaccessible'] = [0, 0, 0.737, -0.897, '#angry', '#disgusting', -0.545, 'outback', 'trackless', 'pathless', 'roadless', 'untracked']
senticnet['inaccurate'] = [-0.515, 0, 0.502, -0.58, '#sad', '#disgusting', -0.532, 'wrong', 'incorrect', 'wide_of_mark', 'unfaithful', 'faulty']
senticnet['inaction'] = [0, 0, 0.808, -0.973, '#angry', '#disgusting', -0.594, 'idle', 'lazy', 'stay', 'take_easy', 'recline']
senticnet['inactive'] = [0, 0, 0.808, -0.973, '#angry', '#disgusting', -0.594, 'inaction', 'lazy', 'stay', 'idle', 'recline']
senticnet['inactiveness'] = [-0.657, 0, 0.793, -0.817, '#angry', '#disgusting', -0.756, 'halt', 'extinction', 'stagnancy', 'stagnation', 'stasis']
senticnet['inactivity'] = [0, 0, 0, -0.769, '#disgusting', '#disgusting', -0.256, 'coffee_break', 'rest_night', 'count_sheep', 'work_break', 'good_night']
senticnet['inadequacy'] = [-0.513, 0, 0.998, -0.765, '#angry', '#disgusting', -0.759, 'lack_of_quality', 'meagreness', 'poorness', 'scantiness', 'scantness']
senticnet['inadequate'] = [-0.587, 0, 0.996, -0.848, '#angry', '#disgusting', -0.81, 'undermanned', 'understaffed', 'deficient', 'lacking', 'wanting']
senticnet['inadequateness'] = [0.774, -0.827, 0, 0.63, '#joyful', '#surprising', 0.744, 'quality', 'perishability', 'perishableness', 'unsatisfactoriness', 'inadequacy']
senticnet['inadvertent'] = [-0.833, 0, 0.508, -0.796, '#sad', '#disgusting', -0.712, 'unwitting', 'unplanned', 'unintentional', 'accidental', 'unintended']
senticnet['inalienable'] = [0.821, 0.889, 0, 0, '#joyful', '#interesting', 0.57, 'infrangible', 'nontransferable', 'unassignable', 'untransferable', 'inviolable']
senticnet['inanimate'] = [0.03, 0, 0, 0.119, '#joyful', '#admirable', 0.05, 'object', 'abstract', 'wow', 'made_out_of_plastic', 'make_paper']
senticnet['inanimate_object'] = [0, 0, 0.095, 0, '#angry', '#angry', -0.032, 'build_part', 'flat', 'stair', 'large_rock', 'hard_surface']
senticnet['inapplicable'] = [-0.868, 0, 0.894, -0.72, '#sad', '#angry', -0.827, 'irrelevant', 'unsuitable', 'immaterial', 'extraneous', 'orthogonal']
senticnet['inappropriateness'] = [-0.887, 0, 0.705, -0.867, '#sad', '#disgusting', -0.82, 'wrongness', 'improperness', 'indecency', 'incorrectness', 'indelicacy']
senticnet['inapt'] = [-0.766, 0, 0.994, -0.605, '#sad', '#angry', -0.788, 'unfortunate', 'infelicitous', 'inept', 'awkward', 'clumsy']
senticnet['inarticulate'] = [-0.567, 0, 0.509, -0.832, '#sad', '#disgusting', -0.636, 'aphasic', 'aphonic', 'speechless', 'unarticulated', 'dumb']
senticnet['inattention'] = [-0.553, 0, 0.88, -0.756, '#angry', '#disgusting', -0.73, 'disregard', 'distraction', 'inattentiveness', 'neglect', 'heedlessness']
senticnet['inattentive'] = [-0.714, 0, 0.906, -0.934, '#angry', '#disgusting', -0.851, 'absent', 'forgetful', 'distracted', 'distrait', 'scatty']
senticnet['inattentiveness'] = [-0.933, 0, 0.689, -0.851, '#sad', '#disgusting', -0.824, 'neglectfulness', 'carelessness', 'negligence', 'neglect', 'unconscientiousness']
senticnet['inaudible'] = [-0.998, 0, 0.798, -0.716, '#sad', '#angry', -0.837, 'silent', 'voiceless', 'unsounded', 'breathed', 'supersonic']
senticnet['inauspicious'] = [-0.74, 0, 0.982, -0.819, '#angry', '#disgusting', -0.847, 'unfavorable', 'admonishing', 'reproachful', 'reproving', 'untoward']
senticnet['inborn'] = [-0.951, 0, 0.684, -0.762, '#sad', '#disgusting', -0.799, 'innate', 'nurtural', 'nonheritable', 'nontransmissible', 'nonhereditary']
senticnet['inbox'] = [0.788, 0.78, 0, 0, '#joyful', '#interesting', 0.523, 'file_drawer', 'drawer', 'folder', 'organiser', 'blotter']
senticnet['inbuilt'] = [0.716, -0.627, 0, 0.896, '#joyful', '#admirable', 0.746, 'constitutional', 'integral', 'intimate', 'inner', 'intrinsic']
senticnet['incalculable'] = [-0.615, 0, 0.784, -0.84, '#angry', '#disgusting', -0.746, 'indeterminable', 'infinite', 'myriad', 'immeasurable', 'countless']
senticnet['incandescence'] = [0.637, -0.713, 0, 0.932, '#surprising', '#admirable', 0.761, 'glow', 'illumination', 'brightness_level', 'luminescence', 'illuminance']
senticnet['incandescent'] = [-0.838, 0, 0.896, -0.959, '#angry', '#disgusting', -0.898, 'storied', 'glorious', 'historied', 'divine', 'empyreal']
senticnet['incapable'] = [-0.77, 0, 0.639, -0.798, '#sad', '#disgusting', -0.736, 'unpersuadable', 'unsuasible', 'unresponsive', 'resistant', 'insusceptible']
senticnet['incapacitate'] = [-0.591, 0, 0.704, -0.5, '#sad', '#angry', -0.598, 'lay_up', 'modify', 'nobble', 'alter', 'change']
senticnet['incapacitated'] = [-0.95, 0, 0.708, -0.649, '#sad', '#angry', -0.769, 'helpless', 'powerless', 'feeble', 'weak', 'nerveless']
senticnet['incarceration'] = [-0.433, 0.107, -0.426, -0.036, '#sad', '#scared', -0.263, 'send_to_jail', 'go_jail', 'jail_time', 'go_to_prison', 'injustice']
senticnet['incaution'] = [0.991, -0.75, 0, 0.815, '#joyful', '#admirable', 0.852, 'imprudence', 'incautiousness', 'mindlessness', 'rashness', 'heedlessness']
senticnet['incautious'] = [-0.707, 0, -0.849, 0, '#sad', '#scared', -0.519, 'impulsive', 'tearaway', 'hotheaded', 'madcap', 'impetuous']
senticnet['incautiousness'] = [0.991, -0.75, 0, 0.815, '#joyful', '#admirable', 0.852, 'incaution', 'imprudence', 'mindlessness', 'rashness', 'heedlessness']
senticnet['incendiarism'] = [-0.831, 0, 0.711, -0.639, '#sad', '#angry', -0.727, 'inflammation', 'lighting', 'arson', 'burning', 'ignition']
senticnet['incendiary'] = [0, 0, -0.82, -0.728, '#scared', '#disgusting', -0.516, 'flame', 'combustible', 'dangerous', 'flammable', 'heat']
senticnet['incense'] = [0.827, 0, 0, 0, '#joyful', '#joyful', 0.276, 'wrathful', 'wrathfully', 'wroth', 'wrothful', 'lividity']
senticnet['incensed'] = [-0.139, 0.146, 0.623, -0.637, '#angry', '#disgusting', -0.418, 'umbrageous', 'outraged', 'indignant', 'outrage', 'indignation']
senticnet['incentive'] = [0.716, 0.813, 0, 0, '#joyful', '#interesting', 0.51, 'bonus', 'reinforce', 'promotion', 'meritocracy', 'gratification']
senticnet['incertitude'] = [0.595, -0.882, 0, 0.521, '#joyful', '#surprising', 0.666, 'incredulity', 'mental_rejection', 'skepticism', 'mistrust', 'distrust']
senticnet['incessant'] = [0, 0, -0.972, -0.95, '#scared', '#disgusting', -0.641, 'unceasing', 'never-ending', 'constant', 'ceaseless', 'perpetual']
senticnet['incest'] = [0.752, -0.577, 0, 0.967, '#joyful', '#admirable', 0.765, 'criminal_congress', 'extramarital_sex', 'free_love', 'sexual_intercourse', 'intercourse']
senticnet['inch'] = [0, 0, 0.122, 0, '#angry', '#angry', -0.041, 'mile', 'ohm', 'meter', 'ounce', 'length']
senticnet['incident'] = [-0.869, 0, -0.807, 0, '#sad', '#scared', -0.559, 'event', 'occasion', 'now_time', 'present', 'accident']
senticnet['incidental'] = [-0.819, 0, 0.987, -0.641, '#sad', '#angry', -0.816, 'nonessential', 'accidental', 'unessential', 'accessorial', 'adscititious']
senticnet['incinerate_waste'] = [0, 0.728, 0, 0.895, '#interesting', '#admirable', 0.541, 'burn_garbage', 'eliminate_garbage', 'incinerator', 'dump', 'garbage_dump']
senticnet['incinerator'] = [0, 0.733, 0, 0.738, '#interesting', '#admirable', 0.49, 'burn_garbage', 'eliminate_garbage', 'incinerate_waste', 'dump', 'garbage_dump']
senticnet['incipience'] = [0.658, -0.521, 0, 0.626, '#joyful', '#admirable', 0.602, 'point_in_time', 'threshold', 'birth', 'incipiency', 'commencement']
senticnet['incipiency'] = [0.658, -0.521, 0, 0.626, '#joyful', '#admirable', 0.602, 'point_in_time', 'threshold', 'birth', 'commencement', 'incipience']
senticnet['incision'] = [-0.126, -0.022, 0, -0.15, '#sad', '#disgusting', -0.085, 'gash', 'laceration', 'abrasion', 'cut_skin', 'painful_injury']
senticnet['incisiveness'] = [0.632, -0.804, 0, 0.537, '#joyful', '#surprising', 0.658, 'effectiveness', 'trenchancy', 'efficacy', 'efficaciousness', 'power']
senticnet['incite'] = [0, 0, 0.932, -0.787, '#angry', '#disgusting', -0.573, 'instigate', 'fire_up', 'inflame', 'stir_up', 'provoke']
senticnet['inciter'] = [-0.599, 0, 0.79, -0.552, '#sad', '#angry', -0.647, 'troublemaker', 'trouble_maker', 'troubler', 'bad_hat', 'ringleader']
senticnet['inclemency'] = [-0.927, 0, 0.929, -0.566, '#sad', '#angry', -0.807, 'overcast', 'weather', 'raw_weather', 'storminess', 'cloudiness']
senticnet['inclementness'] = [-0.569, 0, 0.515, -0.588, '#sad', '#disgusting', -0.557, 'overcast', 'weather', 'raw_weather', 'storminess', 'cloudiness']
senticnet['inclination'] = [0.976, -0.873, 0, 0.706, '#joyful', '#surprising', 0.852, 'understanding', 'propensity', 'leaning', 'favor', 'proclivity']
senticnet['incline'] = [0, 0.081, 0, 0, '#interesting', '#interesting', 0.027, 'slope', 'steep', 'slant', 'up_hill', 'house_roof']
senticnet['incline_plane'] = [0.023, 0.113, 0.053, 0.153, '#interesting', '#admirable', 0.079, 'high', 'high_land', 'altitude', 'top', 'diagonal']
senticnet['inclined'] = [0.946, -0.728, 0, 0.843, '#joyful', '#admirable', 0.839, 'fond', 'tending', 'disposed', 'partial', 'given']
senticnet['inclose'] = [-0.69, 0, 0.883, -0.912, '#angry', '#disgusting', -0.828, 'stick_in', 'enclose', 'insert', 'feed_in', 'put_in']
senticnet['include'] = [0.04, 0.22, -0.171, 0.362, '#interesting', '#admirable', 0.15, 'come', 'inside', 'allow', 'tow', 'accept']
senticnet['inclusion'] = [0, 0.238, -0.08, 0.357, '#interesting', '#admirable', 0.172, 'go_inside', 'come_together', 'include', 'inside', 'again_and_again']
senticnet['inclusion_body_myositis'] = [-0.873, 0, 0.531, -0.681, '#sad', '#disgusting', -0.695, 'rubor', 'redness', 'dermatomyositis', 'myositis', 'inflammation']
senticnet['incognizable'] = [-0.781, 0, 0.792, -0.616, '#sad', '#angry', -0.73, 'imperceptible', 'incognoscible', 'insensible', 'unobservable', 'indiscernible']
senticnet['incognoscible'] = [-0.781, 0, 0.792, -0.616, '#sad', '#angry', -0.73, 'incognizable', 'imperceptible', 'insensible', 'unobservable', 'indiscernible']
senticnet['incoherent'] = [-0.84, 0, 0.522, -0.989, '#sad', '#disgusting', -0.784, 'unconnected', 'confused', 'scattered', 'disordered', 'garbled']
senticnet['income'] = [-0.045, 0.302, -0.086, 0.131, '#interesting', '#admirable', 0.101, 'earnings', 'money', 'revenue', 'money_pay', 'salary']
senticnet['income_bracket'] = [0.763, -0.677, 0, 0.945, '#joyful', '#admirable', 0.795, 'set', 'bracket', 'tax_bracket', 'income_tax_bracket', 'price_bracket']
senticnet['income_tax'] = [0.559, -0.846, 0, 0.92, '#surprising', '#admirable', 0.775, 'single_tax', 'taxation', 'capital_gains_tax', 'capital_levy', 'departure_tax']
senticnet['income_tax_bracket'] = [0.763, -0.677, 0, 0.945, '#joyful', '#admirable', 0.795, 'set', 'income_bracket', 'tax_bracket', 'bracket', 'price_bracket']
senticnet['incoming'] = [-0.506, 0, 0.975, -0.865, '#angry', '#disgusting', -0.782, 'entrance', 'entering', 'entry', 'ingress', 'irruption']
senticnet['incommode'] = [-0.708, 0, 0.502, -0.518, '#sad', '#disgusting', -0.576, 'distress', 'straiten', 'impact', 'bear_on', 'touch']
senticnet['incommunicado'] = [-0.947, 0, 0.636, -0.745, '#sad', '#disgusting', -0.776, 'incommunicative', 'unpronounceable', 'impassive', 'inexpressive', 'silent']
senticnet['incommunicative'] = [-0.947, 0, 0.636, -0.745, '#sad', '#disgusting', -0.776, 'incommunicado', 'unpronounceable', 'impassive', 'inexpressive', 'silent']
senticnet['incommutability'] = [-0.568, 0, 0.574, -0.695, '#angry', '#disgusting', -0.612, 'unexchangeability', 'irreplaceableness', 'changelessness', 'unchangeability', 'unchangeableness']
senticnet['incomparable'] = [0.816, -0.599, 0, 0.947, '#joyful', '#admirable', 0.787, 'matchless', 'nonpareil', 'one_and_only', 'peerless', 'unmatchable']
senticnet['incompatible'] = [-0.841, 0, 0.722, -0.767, '#sad', '#disgusting', -0.777, 'mismated', 'unsuited', 'unmatched', 'odd', 'mismatched']
senticnet['incompetent'] = [-0.773, 0, 0.503, -0.932, '#sad', '#disgusting', -0.736, 'butcher', 'fuckup', 'slouch', 'bungler', 'blunderer']
senticnet['incompetent_person'] = [-0.536, 0, 0.737, -0.772, '#angry', '#disgusting', -0.682, 'butcher', 'fuckup', 'slouch', 'bungler', 'blunderer']
senticnet['incomplete'] = [0.903, -0.935, 0, 0.996, '#surprising', '#admirable', 0.945, 'sketchy', 'unelaborated', 'partial', 'uncompleted', 'broken']
senticnet['incomplete_fracture'] = [-0.812, 0, 0.745, -0.94, '#sad', '#disgusting', -0.832, 'injury', 'hairline_fracture', 'capillary_fracture', 'fracture', 'simple_fracture']
senticnet['incomprehensible'] = [-0.624, 0, 0.825, -0.738, '#angry', '#disgusting', -0.729, 'unexplainable', 'unaccountable', 'unexplained', 'inscrutable', 'mystifying']
senticnet['incompressibility'] = [-0.676, 0, 0.863, -0.862, '#angry', '#disgusting', -0.8, 'hardness', 'substance', 'firmness', 'consistency', 'consistence']
senticnet['inconceivability'] = [-0.661, 0, 0.984, -0.554, '#sad', '#angry', -0.733, 'impossibility', 'inconceivableness', 'nonexistence', 'nonentity', 'unattainableness']
senticnet['inconceivableness'] = [-0.661, 0, 0.984, -0.554, '#sad', '#angry', -0.733, 'inconceivability', 'impossibility', 'nonexistence', 'nonentity', 'unattainableness']
senticnet['inconclusive'] = [-0.642, 0, 0.576, -0.83, '#sad', '#disgusting', -0.683, 'nisi', 'indeterminate', 'equivocal', 'neck_and_neck', 'nip_and_tuck']
senticnet['inconclusiveness'] = [0.558, -0.763, 0, 0.568, '#surprising', '#admirable', 0.63, 'indefiniteness', 'indeterminateness', 'indefinity', 'indetermination', 'indeterminacy']
senticnet['inconsequence'] = [-0.551, 0, 0.741, -0.768, '#angry', '#disgusting', -0.687, 'illogicality', 'illogicalness', 'illogic', 'invalidity', 'fallaciousness']
senticnet['inconsequent'] = [0.978, -0.905, 0, 0.962, '#joyful', '#admirable', 0.948, 'potty', 'unimportant', 'unimportantial', 'trivial', 'lightweight']
senticnet['inconsequential'] = [-0.819, 0, 0, -0.805, '#sad', '#disgusting', -0.541, 'absurd', 'illogical', 'visceral', 'nonrational', 'unimportant']
senticnet['inconsiderate'] = [-0.816, 0, 0, -0.994, '#sad', '#disgusting', -0.603, 'unthinking', 'thoughtless', 'unreflective', 'unthoughtful', 'selfish']
senticnet['inconsiderateness'] = [0.814, -0.95, 0, 0.918, '#surprising', '#admirable', 0.894, 'inconsideration', 'unkindness', 'thoughtlessness', 'unhelpfulness', 'insensitivity']
senticnet['inconsideration'] = [0.814, -0.95, 0, 0.918, '#surprising', '#admirable', 0.894, 'unkindness', 'inconsiderateness', 'thoughtlessness', 'unhelpfulness', 'insensitivity']
senticnet['inconsistency'] = [-0.813, 0, 0, -0.916, '#sad', '#disgusting', -0.576, 'nonuniformity', 'dissimilarity', 'unsimilarity', 'deviation', 'disparity']
senticnet['inconsistent'] = [-0.971, 0, 0.712, -0.786, '#sad', '#disgusting', -0.823, 'discrepant', 'unreconciled', 'scratchy', 'uneven', 'contradictory']
senticnet['inconstancy'] = [0.667, -0.719, 0, 0.775, '#surprising', '#admirable', 0.72, 'quality', 'disloyalty', 'unfaithfulness', 'falseness', 'faithlessness']
senticnet['inconstant'] = [0, 0, 0.853, -0.777, '#angry', '#disgusting', -0.543, 'mutable', 'false', 'fickle', 'untrue', 'volatile']
senticnet['incontestable'] = [0, -0.752, 0, 0.946, '#surprising', '#admirable', 0.566, 'watertight', 'incontrovertible', 'unanswerable', 'bulletproof', 'unassailable']
senticnet['incontestible'] = [-0.73, 0, 0.864, -0.588, '#sad', '#angry', -0.727, 'watertight', 'incontrovertible', 'unanswerable', 'bulletproof', 'unassailable']
senticnet['incontinence'] = [0.992, -0.808, 0, 0.584, '#joyful', '#surprising', 0.795, 'enuresis', 'urinary_incontinence', 'elimination', 'evacuation', 'excretion']
senticnet['incontinency'] = [-0.763, 0, 0.995, -0.947, '#angry', '#disgusting', -0.902, 'enuresis', 'urinary_incontinence', 'elimination', 'evacuation', 'excretion']
senticnet['incontrovertible'] = [0.831, 0.919, 0, 0, '#joyful', '#interesting', 0.583, 'watertight', 'incontestable', 'unanswerable', 'bulletproof', 'unassailable']
senticnet['inconvenience'] = [-0.895, 0, 0.712, -0.804, '#sad', '#disgusting', -0.804, 'difficultness', 'severity', 'severeness', 'troublesomeness', 'worriment']
senticnet['incorporated'] = [-0.906, 0, 0.533, -0.934, '#sad', '#disgusting', -0.791, 'organized', 'arranged', 'configured', 'corporate', 'reorganized']
senticnet['incorporation'] = [0.887, -0.989, 0, 0.611, '#joyful', '#surprising', 0.829, 'education', 'internalization', 'learning', 'study', 'conditioning']
senticnet['incorporeal'] = [-0.53, 0, 0.637, -0.925, '#angry', '#disgusting', -0.697, 'discorporate', 'unembodied', 'disembodied', 'bodiless', 'unbodied']
senticnet['incorporeality'] = [-0.953, 0, 0.909, -0.974, '#sad', '#disgusting', -0.945, 'unreality', 'insubstantiality', 'quality', 'intangibility', 'intangibleness']
senticnet['incorrect'] = [-0.748, 0, 0, -0.952, '#sad', '#disgusting', -0.567, 'bad_choice', 'hard_to_define', 'tricky', 'wrong', 'bad_action']
senticnet['incorrectness'] = [-0.887, 0, 0.705, -0.867, '#sad', '#disgusting', -0.82, 'wrongness', 'inappropriateness', 'indecency', 'improperness', 'indelicacy']
senticnet['incorrigible'] = [-0.836, 0, 0.855, -0.893, '#angry', '#disgusting', -0.861, 'uncorrectable', 'unreformable', 'unregenerate', 'uncontrollable', 'unmanageable']
senticnet['incorruption'] = [0.741, -0.849, 0, 0.543, '#joyful', '#surprising', 0.711, 'integrity', 'righteousness', 'scrupulousness', 'incorruptness', 'honestness']
senticnet['incorruptness'] = [0.741, -0.849, 0, 0.543, '#joyful', '#surprising', 0.711, 'integrity', 'righteousness', 'scrupulousness', 'honestness', 'incorruption']
senticnet['increase'] = [0, 0.312, -0.136, 0.328, '#interesting', '#admirable', 0.168, 'expansion', 'augment', 'plus', 'heap', 'gain']
senticnet['increase_body_temperature'] = [0, 0, -0.861, -0.84, '#scared', '#disgusting', -0.567, 'much_exercise', 'wear_out_shoes', 'sweat_lot', 'dehydration', 'foot_tired']
senticnet['increase_efficiency'] = [0, 0.312, -0.136, 0.328, '#interesting', '#admirable', 0.168, 'increase', 'efficiency', 'increase_energy', 'work_hard', 'improve_company']
senticnet['increase_energy'] = [0.843, -0.939, 0, 0, '#joyful', '#surprising', 0.594, 'feel_energized', 'feel_better_oneself', 'feel_better', 'think_clearly', 'feel_good_oneself']
senticnet['increase_height'] = [0.066, 0.172, -0.055, 0.191, '#interesting', '#admirable', 0.125, 'pull_up', 'move_up', 'reach_high_place', 'bring_up', 'rise_up']
senticnet['increase_hunger'] = [-0.771, 0, 0.848, -0.806, '#angry', '#disgusting', -0.808, 'replenish_energy', 'satisfy_hunger', 'sustenance', 'feel_hungry', 'stop_hunger']
senticnet['increase_income'] = [-0.034, 0, 0, -0.132, '#sad', '#disgusting', -0.055, 'able_use', 'keep_job', 'get_job_done', 'resolve_dispute', 'transact_business']
senticnet['increase_intelligence'] = [0.111, 0.103, -0.049, -0.063, '#joyful', '#interesting', 0.034, 'improve_performance', 'use_dictionary', 'discover_new', 'increase_knowledge', 'learn']
senticnet['increase_knowledge'] = [0.769, 0.663, 0, 0.948, '#joyful', '#admirable', 0.793, 'gain_knowledge', 'become_smart', 'learn', 'learn_information', 'add_knowledge']
senticnet['increase_metabolism'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'become_healthy', 'big_muscle', 'feel_fit', 'diet', 'weight_loss']
senticnet['increase_money'] = [0, 0.36, -0.129, 0.316, '#interesting', '#admirable', 0.182, 'extra_money', 'investment_return', 'give_back', 'barter', 'money_earn']
senticnet['increase_muscle_mass'] = [0.769, 0, 0, 0, '#joyful', '#joyful', 0.256, 'health', 'become_strong', 'feel_better', 'sporty_person', 'better_health']
senticnet['increase_net_worth'] = [0, 0.966, 0, 0.99, '#interesting', '#admirable', 0.652, 'get_job_done', 'receive_paycheck', 'earn_paycheck', 'support_family', 'enjoy_salary']
senticnet['increase_price'] = [-0.147, -0.051, 0, -0.066, '#sad', '#disgusting', -0.054, 'inefficiency', 'gyroscope', 'ball_bounce', 'loss', 'lose']
senticnet['increase_self-confidence'] = [0.903, 0, 0, 0.786, '#joyful', '#admirable', 0.563, 'little_hair', 'improve_look', 'short_hair', 'look_different', 'wear_nice_clothes']
senticnet['increase_self-esteem'] = [0.317, 0.084, 0, 0.077, '#joyful', '#interesting', 0.159, 'feel_happy', 'better_person', 'desire_succeed', 'feel_proud', 'good_feeling']
senticnet['increase_self_esteem'] = [0.879, 0, 0, 0.742, '#joyful', '#admirable', 0.54, 'success', 'feel_good_oneself', 'increase_self-esteem', 'own_benefit', 'feel_better_oneself']
senticnet['increase_size'] = [0, 0.156, -0.128, 0.172, '#interesting', '#admirable', 0.067, 'get_big', 'get_large', 'growth', 'need_water', 'enlarge']
senticnet['increase_stamina'] = [0, 0, 0, 0.968, '#admirable', '#admirable', 0.323, 'become_physically_fit', 'sweat_lot', 'get_strong', 'wear_out_shoes', 'exercise_dog']
senticnet['increase_strength'] = [0.087, -0.024, 0, 0, '#joyful', '#surprising', 0.037, 'keep_fit', 'keep_healthy', 'strengthen_heart', 'keep_shape', 'fit_person']
senticnet['increase_tax'] = [-0.779, 0, -1.0, 0, '#sad', '#scared', -0.593, 'force', 'like_electricity', 'power', 'form_of_energy', 'watt']
senticnet['increase_understand'] = [0.317, 0.084, 0, 0.077, '#joyful', '#interesting', 0.159, 'increase', 'teach', 'transfer_knowledge', 'share_knowledge', 'increase_vocabulary']
senticnet['increase_value'] = [0, 0.128, 0.046, 0.1, '#interesting', '#admirable', 0.061, 'sell_store', 'ship_goods', 'store_bottle', 'fill_glass', 'lick_finger']
senticnet['increase_vocabulary'] = [0.608, 0.679, 0, 0.56, '#joyful', '#interesting', 0.616, 'learn_universe', 'learn_entertainment', 'find_out_world', 'view_art', 'get_information']
senticnet['increase_wealth'] = [0.839, 0.861, 0, 0.738, '#joyful', '#interesting', 0.813, 'become_rich', 'gain_wealth', 'save_money', 'become_wealthy', 'find_money']
senticnet['increased_heart_rate'] = [-0.856, 0, 0, -0.795, '#sad', '#disgusting', -0.55, 'tired_leg', 'become_exhausted', 'pull_muscle', 'sore_muscle', 'breathlessness']
senticnet['incredulity'] = [0.911, -0.762, 0, 0.802, '#joyful', '#admirable', 0.825, 'doubt', 'incertitude', 'dubiety', 'doubtfulness', 'dubiousness']
senticnet['increment'] = [0.037, 0, 0.026, 0.129, '#joyful', '#admirable', 0.047, 'measurement_unit', 'many_items', 'long', 'circle_part', 'narrow']
senticnet['incriminate'] = [-0.068, 0, -0.099, -0.188, '#scared', '#disgusting', -0.118, 'accuse', 'become_lawyer', 'liar', 'accuse_person', 'blame']
senticnet['incrimination'] = [-0.708, 0, 0.874, -0.75, '#angry', '#disgusting', -0.777, 'blame', 'accusation', 'inculpation', 'complaint', 'imprecation']
senticnet['incubus'] = [0.888, -0.634, 0, 0.892, '#joyful', '#admirable', 0.805, 'daemon', 'daimon', 'devil', 'demon', 'fiend']
senticnet['inculpate'] = [0.789, -0.985, 0, 0.765, '#joyful', '#surprising', 0.846, 'show', 'imply', 'smack', 'incriminate', 'paint_picture']
senticnet['inculpation'] = [-0.708, 0, 0.874, -0.75, '#angry', '#disgusting', -0.777, 'blame', 'incrimination', 'accusation', 'complaint', 'imprecation']
senticnet['inculpative'] = [-0.953, 0, 0.771, -0.677, '#sad', '#angry', -0.8, 'condemnatory', 'condemning', 'accusatory', 'accusing', 'accusive']
senticnet['inculpatory'] = [-0.639, 0, 0.967, -0.674, '#angry', '#disgusting', -0.76, 'condemnatory', 'condemning', 'accusatory', 'accusing', 'accusive']
senticnet['incumbent_on'] = [0.924, -0.551, 0, 0.756, '#joyful', '#admirable', 0.744, 'bounden', 'obligatory', 'de_rigueur', 'compulsory', 'mandatory']
senticnet['incumbrance'] = [-0.939, 0, 0.922, -0.796, '#sad', '#angry', -0.886, 'onus', 'burden', 'encumbrance', 'dead_weight', 'load']
senticnet['incur_debt'] = [-0.943, 0, 0, -0.915, '#sad', '#disgusting', -0.619, 'go_broke', 'receive_change', 'run_out_money', 'compare_price', 'bankruptcy']
senticnet['incursion'] = [0.954, -0.87, 0, 0.583, '#joyful', '#surprising', 0.802, 'penetration', 'air_raid', 'air_attack', 'swoop', 'foray']
senticnet['indebtedness'] = [0.628, -0.607, 0, 0.532, '#joyful', '#surprising', 0.589, 'account_payable', 'payable', 'limited_liability', 'debt', 'arrears']
senticnet['indecency'] = [-0.526, 0, 0.648, -0.967, '#angry', '#disgusting', -0.714, 'improperness', 'outrageousness', 'impropriety', 'immodesty', 'obscenity']
senticnet['indecent'] = [0, 0, 0, -0.959, '#disgusting', '#disgusting', -0.32, 'unethical', 'bad', 'obscene', 'immoral', 'shameless']
senticnet['indecision'] = [-0.71, 0, 0, -0.964, '#sad', '#disgusting', -0.558, 'look_buy', 'window_shop', 'spend_money', 'pay_check', 'impulse_shop']
senticnet['indecisive'] = [0.778, -0.502, 0, 0.517, '#joyful', '#admirable', 0.599, 'on_fence', 'suspensive', 'undecided', 'hesitant', 'hesitating']
senticnet['indecisiveness'] = [0.928, -0.834, 0, 0.656, '#joyful', '#surprising', 0.806, 'wavering', 'doubt', 'incertitude', 'dubiety', 'doubtfulness']
senticnet['indecorous'] = [0, 0, -0.72, -0.838, '#scared', '#disgusting', -0.519, 'uncomely', 'unseemly', 'indecent', 'unbecoming', 'indelicate']
senticnet['indeed'] = [0.072, 0.269, -0.192, 0.29, '#interesting', '#admirable', 0.146, 'obedience', 'demand', 'affirmation', 'proof', 'topic']
senticnet['indefensible'] = [-0.736, 0, 0.846, -0.687, '#sad', '#angry', -0.756, 'inexcusable', 'unwarranted', 'insupportable', 'unjustifiable', 'unwarrantable']
senticnet['indefinite'] = [-0.61, 0, 0.856, -0.826, '#angry', '#disgusting', -0.764, 'unfixed', 'one', 'nebulous', 'indecisive', 'coy']
senticnet['indefinite_quantity'] = [-0.697, 0, 0.74, -0.668, '#sad', '#angry', -0.702, 'large_indefinite_quantity', 'large_indefinite_amount', 'small_indefinite_quantity', 'small_indefinite_amount', 'breakage']
senticnet['indefiniteness'] = [0.558, -0.763, 0, 0.568, '#surprising', '#admirable', 0.63, 'inconclusiveness', 'indeterminateness', 'indefinity', 'indetermination', 'indeterminacy']
senticnet['indefinity'] = [0.558, -0.763, 0, 0.568, '#surprising', '#admirable', 0.63, 'indefiniteness', 'indeterminateness', 'inconclusiveness', 'indetermination', 'indeterminacy']
senticnet['indelible'] = [0, 0.938, 0, 0.935, '#interesting', '#admirable', 0.624, 'inexterminable', 'inextirpable', 'inexpungible', 'inexpungeable', 'ineradicable']
senticnet['indelicacy'] = [-0.698, 0, 0.597, -0.569, '#sad', '#angry', -0.621, 'improperness', 'impropriety', 'raciness', 'spiciness', 'gaminess']
senticnet['indemnification'] = [-0.886, 0, 0.51, -0.916, '#sad', '#disgusting', -0.771, 'atonement', 'expiation', 'punitive_damage', 'exemplary_damages', 'compensation']
senticnet['indemnity'] = [0.73, -0.569, 0, 0.621, '#joyful', '#admirable', 0.64, 'amnesty', 'unsusceptibility', 'diplomatic_immunity', 'exemption', 'impunity']
senticnet['indent'] = [-0.982, 0, 0.959, -0.685, '#sad', '#angry', -0.875, 'expanse', 'margin', 'blank_spaceation', 'blank_spaceion', 'blank_space']
senticnet['indentation'] = [-0.982, 0, 0.959, -0.685, '#sad', '#angry', -0.875, 'expanse', 'margin', 'blank_space', 'indention', 'indent']
senticnet['indention'] = [-0.982, 0, 0.959, -0.685, '#sad', '#angry', -0.875, 'expanse', 'margin', 'indentation', 'blank_space', 'indent']
senticnet['independence'] = [0.887, 0.748, 0, 0.954, '#joyful', '#admirable', 0.863, 'political_action', 'political', 'mediocrity', 'discrimination', 'independent']
senticnet['independent'] = [0.904, 0.881, 0, 0.774, '#joyful', '#interesting', 0.853, 'united_country', 'democracy', 'pledge_allegiance', 'unite', 'free_country']
senticnet['indestructibility'] = [0.8, -0.908, 0, 0.675, '#joyful', '#surprising', 0.794, 'durability', 'tensile_strength', 'continuity', 'persistence', 'changelessness']
senticnet['indestructible'] = [0, 0.927, 0, 0.947, '#interesting', '#admirable', 0.625, 'imputrescible', 'undestroyable', 'imperishable', 'durable', 'perdurable']
senticnet['indeterminable'] = [-0.615, 0, 0.784, -0.84, '#angry', '#disgusting', -0.746, 'incalculable', 'infinite', 'myriad', 'immeasurable', 'countless']
senticnet['indeterminacy'] = [0.558, -0.763, 0, 0.568, '#surprising', '#admirable', 0.63, 'indefiniteness', 'indeterminateness', 'indefinity', 'indetermination', 'inconclusiveness']
senticnet['indeterminate'] = [-0.642, 0, 0.576, -0.83, '#sad', '#disgusting', -0.683, 'nisi', 'inconclusive', 'equivocal', 'neck_and_neck', 'nip_and_tuck']
senticnet['indeterminateness'] = [0.558, -0.763, 0, 0.568, '#surprising', '#admirable', 0.63, 'indefiniteness', 'inconclusiveness', 'indefinity', 'indetermination', 'indeterminacy']
senticnet['indetermination'] = [0.558, -0.763, 0, 0.568, '#surprising', '#admirable', 0.63, 'indefiniteness', 'indeterminateness', 'indefinity', 'inconclusiveness', 'indeterminacy']
senticnet['index'] = [0.074, 0.114, 0, 0.126, '#interesting', '#admirable', 0.105, 'paragraph', 'newspaper_write', 'news_paper', 'newspaper_story', 'chapter']
senticnet['index_card'] = [0, 0.094, 0, 0, '#interesting', '#interesting', 0.031, 'appointment', 'pocket_notebook', 'appointment_book', 'list_appointment', 'ring_binder']
senticnet['index_card_drawer'] = [0, 0.734, 0, 0.706, '#interesting', '#admirable', 0.48, 'cook_book', 'a_lot_of_books', 'bookmark', 'religious_tract', 'old_testament']
senticnet['indian_food'] = [0.026, 0.08, 0.043, 0.064, '#interesting', '#admirable', 0.042, 'curry', 'spicy', 'starchy_food', 'asian', 'staple_food']
senticnet['indicate'] = [0, 0.149, 0.015, 0.194, '#interesting', '#admirable', 0.109, 'reason_why', 'punctuation', 'geometric_object', 'finger_action', 'sport_score']
senticnet['indication'] = [0, 0.151, -0.05, 0.189, '#interesting', '#admirable', 0.097, 'placard', 'red_octagon', 'indicate', 'sign', 'direction']
senticnet['indicator'] = [0, 0.071, 0, 0.143, '#interesting', '#admirable', 0.071, 'post_notice', 'gps', 'way', 'one_way', 'arrow']
senticnet['indictability'] = [-0.985, 0, 0.657, -0.959, '#sad', '#disgusting', -0.867, 'impeachability', 'guiltiness', 'blameworthiness', 'culpability', 'culpableness']
senticnet['indictment'] = [0.654, -0.592, 0, 0.774, '#joyful', '#admirable', 0.673, 'instrument', 'murder_charge', 'murder_indictment', 'true_bill', 'legal_document']
senticnet['indifference'] = [0, 0, 0.709, -0.923, '#angry', '#disgusting', -0.544, 'apathetic', 'unemotionality', 'passionless', 'stolidity', 'phlegm']
senticnet['indifferent'] = [0, 0, 0.952, -0.969, '#angry', '#disgusting', -0.64, 'withdrawal', 'detachment', 'indifferently', 'aloofness', 'apathetic']
senticnet['indifferently'] = [-0.81, 0, -0.892, 0, '#sad', '#scared', -0.567, 'withdrawal', 'detachment', 'apathetic', 'unconcerned', 'unconcern']
senticnet['indigence'] = [-0.733, 0, 0.872, -0.978, '#angry', '#disgusting', -0.861, 'poverty', 'impoverishment', 'poorness', 'beggary', 'mendicancy']
senticnet['indigent'] = [-0.915, 0, 0.724, 0, '#sad', '#angry', -0.546, 'impoverished', 'needy', 'necessitous', 'poverty-stricken', 'destitute']
senticnet['indigestible'] = [-0.774, 0, 0.671, -0.807, '#sad', '#disgusting', -0.751, 'flatulent', 'nondigestible', 'undigested', 'stodgy', 'heavy']
senticnet['indigestion'] = [0, -0.035, -0.049, -0.194, '#scared', '#disgusting', -0.069, 'stomach_ache', 'become_full', 'full_stomach', 'a_little_hungry', 'heartburn']
senticnet['indignant'] = [-0.139, 0.146, 0.623, -0.637, '#angry', '#disgusting', -0.418, 'umbrageous', 'outraged', 'incensed', 'outrage', 'indignation']
senticnet['indignantly'] = [-0.138, 0.145, 0.625, -0.638, '#angry', '#disgusting', -0.419, 'outrage', 'indignation', 'umbrageous', 'outraged', 'incensed']
senticnet['indignation'] = [-0.138, 0.145, 0.625, -0.638, '#angry', '#disgusting', -0.419, 'outrage', 'indignantly', 'umbrageous', 'outraged', 'incensed']
senticnet['indignity'] = [-0.927, 0, 0.699, -0.936, '#sad', '#disgusting', -0.854, 'discourtesy', 'offense', 'outrage', 'scandalization', 'affront']
senticnet['indigo'] = [-0.101, 0, 0, 0, '#sad', '#sad', -0.034, 'cyan', 'aqua', 'water_color', 'yellow', 'violet']
senticnet['indinavir'] = [-0.818, 0, 0.767, -0.936, '#sad', '#disgusting', -0.84, 'antiviral', 'protease_inhibitor', 'nelfinavir', 'ritonavir', 'saquinavir']
senticnet['indirect_expression'] = [-0.89, 0, 0.669, -0.766, '#sad', '#disgusting', -0.775, 'deceit', 'deception', 'misrepresentation', 'equivocation', 'circumlocution']
senticnet['indirectness'] = [-0.629, 0, 0.69, -0.765, '#angry', '#disgusting', -0.695, 'deviousness', 'mediacy', 'mediateness', 'characteristic', 'allusiveness']
senticnet['indiscernible'] = [-0.781, 0, 0.792, -0.616, '#sad', '#angry', -0.73, 'incognizable', 'incognoscible', 'insensible', 'unobservable', 'imperceptible']
senticnet['indiscipline'] = [-0.832, 0, 0.531, -0.595, '#sad', '#disgusting', -0.653, 'indulgence', 'incontinence', 'trait', 'dissoluteness', 'unrestraint']
senticnet['indiscreet'] = [-0.925, 0, 0.876, -0.963, '#sad', '#disgusting', -0.921, 'bigmouthed', 'blabby', 'blabbermouthed', 'talkative', 'imprudent']
senticnet['indiscreetness'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'sagacity', 'sagaciousness', 'discernment', 'judgment', 'gossip']
senticnet['indispose'] = [-0.118, 0.19, 0.604, -0.63, '#angry', '#disgusting', -0.387, 'disinclination', 'disinclined', 'bad_student', 'unfriendly', 'inimical']
senticnet['indisposition'] = [-0.638, 0, 0.584, -0.542, '#sad', '#angry', -0.588, 'resistance', 'disinclination', 'involuntariness', 'temperament', 'hesitancy']
senticnet['indisputability'] = [0.776, -0.667, 0, 0.778, '#joyful', '#admirable', 0.74, 'demonstrability', 'provability', 'positivity', 'positiveness', 'certainty']
senticnet['indisputable'] = [0.928, 0, 0, 0.73, '#joyful', '#admirable', 0.553, 'irrefutable', 'incontestable', 'incontrovertible', 'undeniable', 'final']
senticnet['indistinct'] = [-0.958, 0, 0.892, -0.813, '#sad', '#angry', -0.888, 'blurry', 'foggy', 'hazy', 'muzzy', 'blurred']
senticnet['indistinct_vision'] = [-0.943, 0, 0.855, -1.0, '#sad', '#disgusting', -0.933, 'fear', 'danger', 'trouble', 'scare', 'alien']
senticnet['indistinctness'] = [0.695, -0.833, 0, 0.959, '#surprising', '#admirable', 0.829, 'opaqueness', 'faintness', 'dimness', 'opacity', 'vagueness']
senticnet['individual'] = [0.093, 0.137, -0.079, 0.137, '#interesting', '#admirable', 0.096, 'person', 'alone', 'user', 'multiple_people', 'oneself']
senticnet['individualism'] = [0.618, -0.75, 0, 0.628, '#surprising', '#admirable', 0.665, 'uniqueness', 'singularity', 'specialty', 'special', 'distinctiveness']
senticnet['individuality'] = [0.959, -0.536, 0, 0.772, '#joyful', '#admirable', 0.756, 'uniqueness', 'singularity', 'specialty', 'special', 'distinctiveness']
senticnet['individuation'] = [0.664, -0.903, 0, 0.788, '#surprising', '#admirable', 0.785, 'individualism', 'individuality', 'distinctiveness', 'idiosyncrasy', 'foible']
senticnet['indolence'] = [-0.664, 0, 0.749, -0.549, '#sad', '#angry', -0.654, 'inertia', 'inactiveness', 'inactivity', 'faineance', 'idleness']
senticnet['indolent'] = [0, 0, -0.869, -0.721, '#scared', '#disgusting', -0.53, 'otiose', 'slothful', 'faineant', 'lazy', 'work-shy']
senticnet['indomitable'] = [0, 0.723, 0, 0.758, '#interesting', '#admirable', 0.494, 'insurmountable', 'insuperable', 'inexpugnable', 'unconquerable', 'unsubduable']
senticnet['indoor'] = [0.034, 0.09, 0.039, 0.061, '#interesting', '#admirable', 0.049, 'border', 'limit', 'edge', 'boundary', 'side']
senticnet['indoor_object'] = [0.119, 0, 0, 0, '#joyful', '#joyful', 0.04, 'control', 'technician', 'control_room', 'room', 'tape_player']
senticnet['indorse'] = [0.969, -0.977, 0, 0.946, '#joyful', '#surprising', 0.964, 'okay', 'warrant', 'sanction', 'approve', 'champion']
senticnet['indorser'] = [0.822, -0.928, 0, 0.575, '#joyful', '#surprising', 0.775, 'friend', 'champion', 'supporter', 'protagonist', 'admirer']
senticnet['indubitability'] = [0.783, -0.673, 0, 0.771, '#joyful', '#admirable', 0.742, 'demonstrability', 'provability', 'positivity', 'positiveness', 'certainty']
senticnet['induce_sickness'] = [-0.906, 0, 0.117, -0.937, '#sad', '#disgusting', -0.653, 'disease', 'illness', 'sickness', 'doctor', 'hospital']
senticnet['inducement'] = [-0.997, 0, 0.651, -0.513, '#sad', '#angry', -0.72, 'sending', 'compulsion', 'influence', 'causation', 'trigger']
senticnet['inducive'] = [0.59, -0.599, 0, 0.527, '#joyful', '#surprising', 0.572, 'responsible', 'causative', 'activating', 'tributary', 'motivative']
senticnet['indulge'] = [0.812, 0, 0, 0.813, '#joyful', '#admirable', 0.542, 'pander', 'gratify', 'humor', 'luxuriate', 'spend']
senticnet['indulgence'] = [0.931, -0.847, 0, 0.829, '#joyful', '#surprising', 0.869, 'folly', 'lunacy', 'craziness', 'buffoonery', 'shtik']
senticnet['indulgent'] = [0.558, -0.905, 0, 0.736, '#surprising', '#admirable', 0.733, 'luxurious', 'luxuriant', 'sybaritic', 'voluptuary', 'gay']
senticnet['induration'] = [-0.596, 0, 0.911, -0.877, '#angry', '#disgusting', -0.795, 'osteosclerosis', 'sclerosis', 'disseminated_sclerosis', 'multiple_sclerosis', 'pathology']
senticnet['industriousness'] = [0.799, -0.616, 0, 0.789, '#joyful', '#admirable', 0.735, 'sedulity', 'sedulousness', 'assiduity', 'assiduousness', 'studiousness']
senticnet['industry'] = [0.05, 0.145, 0, 0.174, '#interesting', '#admirable', 0.123, 'manufacture', 'make_product', 'business', 'manufacturer', 'enterprise']
senticnet['indweller'] = [0.9, -0.513, 0, 0.836, '#joyful', '#admirable', 0.75, 'villager', 'inhabitant', 'habitant', 'dweller', 'denizen']
senticnet['inebriant'] = [-0.91, 0, 0.79, -0.685, '#sad', '#angry', -0.795, 'intoxicant', 'alcohol', 'alcoholic_drink', 'alcoholic_beverage', 'rotgut']
senticnet['inebriate'] = [0.645, 0.637, -0.239, 0.299, '#joyful', '#interesting', 0.447, 'gladdened', 'stimulating', 'tickle_pink', 'exalt', 'beatify']
senticnet['inebriation'] = [-0.529, 0, 0.542, -0.938, '#angry', '#disgusting', -0.67, 'intoxication', 'drunkenness', 'sottishness', 'inebriety', 'tipsiness']
senticnet['inebriety'] = [-0.529, 0, 0.542, -0.938, '#angry', '#disgusting', -0.67, 'intoxication', 'drunkenness', 'inebriation', 'sottishness', 'tipsiness']
senticnet['ineffable'] = [0, 0, -0.763, -0.862, '#scared', '#disgusting', -0.542, 'untellable', 'unspeakable', 'indescribable', 'indefinable', 'unutterable']
senticnet['ineffective'] = [-0.941, 0, 0.987, -0.643, '#sad', '#angry', -0.857, 'unable', 'ineffectual', 'impotent', 'impuissant', 'effete']
senticnet['ineffectiveness'] = [-0.507, 0, 0.807, -0.761, '#angry', '#disgusting', -0.692, 'powerlessness', 'impotence', 'impotency', 'inefficacy', 'inefficaciousness']
senticnet['ineffectual'] = [-0.941, 0, 0.987, -0.643, '#sad', '#angry', -0.857, 'unable', 'impotent', 'ineffective', 'impuissant', 'effete']
senticnet['ineffectuality'] = [-0.884, 0, 0.663, -0.768, '#sad', '#disgusting', -0.772, 'powerlessness', 'impotence', 'impotency', 'inefficacy', 'inefficaciousness']
senticnet['ineffectualness'] = [-0.659, 0, 0.855, -0.781, '#angry', '#disgusting', -0.765, 'powerlessness', 'impotence', 'impotency', 'inefficacy', 'inefficaciousness']
senticnet['inefficaciousness'] = [-0.507, 0, 0.807, -0.761, '#angry', '#disgusting', -0.692, 'powerlessness', 'impotence', 'impotency', 'inefficacy', 'ineffectiveness']
senticnet['inefficacy'] = [-0.507, 0, 0.807, -0.761, '#angry', '#disgusting', -0.692, 'powerlessness', 'impotence', 'impotency', 'ineffectiveness', 'inefficaciousness']
senticnet['inefficiency'] = [-0.147, -0.051, 0, -0.066, '#sad', '#disgusting', -0.054, 'increase_price', 'gyroscope', 'ball_bounce', 'loss', 'lose']
senticnet['inelasticity'] = [-0.812, 0, 0.83, -0.978, '#angry', '#disgusting', -0.873, 'deadness', 'rigidity', 'rigidness', 'stiffness', 'physical_property']
senticnet['inelegance'] = [-0.703, 0, 0, -0.729, '#sad', '#disgusting', -0.477, 'tastelessness', 'sleaziness', 'coarseness', 'commonness', 'drabness']
senticnet['ineligible'] = [-0.608, 0, 0.832, -0.537, '#sad', '#angry', -0.659, 'unsuitable', 'undesirable', 'unqualified', 'disqualified', 'unentitled']
senticnet['ineluctability'] = [-0.91, 0, 0.795, -0.94, '#sad', '#disgusting', -0.882, 'sure_thing', 'unavoidability', 'predictability', 'slam_dunk', 'inevitability']
senticnet['inept'] = [-0.766, 0, 0.994, -0.605, '#sad', '#angry', -0.788, 'unfortunate', 'inapt', 'infelicitous', 'awkward', 'clumsy']
senticnet['ineptness'] = [0.983, -0.637, 0, 0.697, '#joyful', '#admirable', 0.772, 'amateurishness', 'inability', 'unskillfulness', 'clumsiness', 'awkwardness']
senticnet['inequality'] = [-0.229, 0, -0.095, -0.165, '#sad', '#disgusting', -0.163, 'difference', 'reject', 'discard', 'divergency', 'gap']
senticnet['inequity'] = [0.871, -0.748, 0, 0.981, '#joyful', '#admirable', 0.867, 'unrighteousness', 'unjustness', 'unfairness', 'wrong', 'wrongfulness']
senticnet['ineradicable'] = [-0.659, 0, 0.61, -0.836, '#sad', '#disgusting', -0.702, 'inexterminable', 'inextirpable', 'inexpungible', 'inexpungeable', 'indelible']
senticnet['inerrable'] = [-0.693, 0, 0.679, -0.898, '#sad', '#disgusting', -0.757, 'infallible', 'inerrant', 'unerring', 'unfailing', 'foolproof']
senticnet['inerrancy'] = [-0.839, 0, 0.648, -0.605, '#sad', '#angry', -0.697, 'infallibility', 'dependability', 'dependableness', 'reliability', 'reliableness']
senticnet['inerrant'] = [-0.693, 0, 0.679, -0.898, '#sad', '#disgusting', -0.757, 'inerrable', 'infallible', 'unerring', 'unfailing', 'foolproof']
senticnet['inert'] = [-0.541, 0, 0.868, -0.968, '#angry', '#disgusting', -0.792, 'inactive', 'unreactive', 'indifferent', 'stable', 'neutral']
senticnet['inert_gas'] = [-0.871, 0, 0.949, -0.809, '#sad', '#angry', -0.876, 'chemical_element', 'element', 'noble_gas', 'atomic_number_54', 'argonon']
senticnet['inertia'] = [-0.705, 0, 0.569, -0.887, '#sad', '#disgusting', -0.72, 'languor', 'passiveness', 'phlegm', 'passivity', 'indolence']
senticnet['inessential'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'minor', 'unimportant', 'petty', 'negligible', 'trivial']
senticnet['inevitability'] = [-0.91, 0, 0.795, -0.94, '#sad', '#disgusting', -0.882, 'ineluctability', 'unavoidability', 'predictability', 'slam_dunk', 'sure_thing']
senticnet['inevitable'] = [-0.804, 0, -0.782, 0, '#sad', '#scared', -0.529, 'time_up', 'expire', 'desirable', 'good_quality', 'life_end']
senticnet['inexact'] = [-0.715, 0, 0.8, -0.693, '#sad', '#angry', -0.736, 'approximative', 'rough', 'approximate', 'loose', 'odd']
senticnet['inexcusable'] = [-0.736, 0, 0.846, -0.687, '#sad', '#angry', -0.756, 'indefensible', 'unwarranted', 'insupportable', 'unjustifiable', 'unwarrantable']
senticnet['inexorable'] = [-0.806, 0, 0.507, -0.763, '#sad', '#disgusting', -0.692, 'adamant', 'inflexible', 'intransigent', 'ironclad', 'brassbound']
senticnet['inexpensive'] = [-0.103, 0.246, -0.178, 0.261, '#interesting', '#admirable', 0.075, 'important', 'cost_nothing', 'capitalize', 'cheap', 'good_quality']
senticnet['inexpensiveness'] = [0.554, -0.726, 0, 0.651, '#surprising', '#admirable', 0.644, 'reasonableness', 'modestness', 'cost', 'cut_rate', 'cut_price']
senticnet['inexperienced'] = [-0.759, 0, 0, -0.85, '#sad', '#disgusting', -0.536, 'unskilled', 'amateur', 'uninitiated', 'uninformed', 'inexpert']
senticnet['inexperienced_person'] = [0.798, -0.519, 0, 0.973, '#joyful', '#admirable', 0.763, 'naif', 'boy_scout', 'dear', 'virgin', 'mortal']
senticnet['inexperient'] = [0.697, -0.875, 0, 0.748, '#surprising', '#admirable', 0.773, 'naive', 'new', 'fledgling', 'young', 'raw']
senticnet['inexpiable'] = [-0.53, 0, 0.901, -0.511, '#sad', '#angry', -0.647, 'unpardonable', 'inexcusable', 'deadly', 'unforgivable', 'mortal']
senticnet['inexplicable'] = [-0.872, 0, 0.681, -0.822, '#sad', '#disgusting', -0.792, 'unexplainable', 'unaccountable', 'unexplained', 'inscrutable', 'mystifying']
senticnet['inexplicit'] = [0.668, -0.577, 0, 0.937, '#joyful', '#admirable', 0.727, 'tacit', 'understood', 'unvoiced', 'silent', 'unspoken']
senticnet['inexplicitness'] = [-0.587, 0, 0.871, -0.705, '#angry', '#disgusting', -0.721, 'elusiveness', 'unclearness', 'ambiguity', 'equivocalness', 'vagueness']
senticnet['inexpressive'] = [-0.947, 0, 0.636, -0.745, '#sad', '#disgusting', -0.776, 'incommunicado', 'unpronounceable', 'impassive', 'incommunicative', 'silent']
senticnet['inexpugnable'] = [-0.738, 0, 0.732, -0.535, '#sad', '#angry', -0.668, 'insurmountable', 'insuperable', 'unconquerable', 'indomitable', 'unsubduable']
senticnet['inexpungeable'] = [-0.659, 0, 0.61, -0.836, '#sad', '#disgusting', -0.702, 'inexterminable', 'inextirpable', 'inexpungible', 'ineradicable', 'indelible']
senticnet['inexpungible'] = [-0.659, 0, 0.61, -0.836, '#sad', '#disgusting', -0.702, 'inexterminable', 'inextirpable', 'ineradicable', 'inexpungeable', 'indelible']
senticnet['inexterminable'] = [-0.659, 0, 0.61, -0.836, '#sad', '#disgusting', -0.702, 'ineradicable', 'inextirpable', 'inexpungible', 'inexpungeable', 'indelible']
senticnet['inextirpable'] = [-0.659, 0, 0.61, -0.836, '#sad', '#disgusting', -0.702, 'inexterminable', 'ineradicable', 'inexpungible', 'inexpungeable', 'indelible']
senticnet['infallibility'] = [0.837, 0, 0, 0.915, '#joyful', '#admirable', 0.584, 'inerrancy', 'reliability', 'reliableness', 'trustworthy', 'sure']
senticnet['infallible'] = [0, 0.743, 0, 0.895, '#interesting', '#admirable', 0.546, 'inerrable', 'inerrant', 'unfailing', 'foolproof', 'proof']
senticnet['infant'] = [-0.043, 0, -0.048, 0, '#sad', '#scared', -0.03, 'new_life', 'small_child', 'baby', 'family', 'kid']
senticnet['infant_feeding'] = [-0.802, 0, 0.724, -0.706, '#sad', '#angry', -0.744, 'nursing', 'schedule_feeding', 'demand_feeding', 'breast_feeding', 'feeding']
senticnet['infant_prodigy'] = [0.529, -0.753, 0, 0.859, '#surprising', '#admirable', 0.714, 'child', 'small_fry', 'tyke', 'tike', 'kid']
senticnet['infantry'] = [-0.033, 0, -0.061, -0.176, '#scared', '#disgusting', -0.09, 'army', 'attacker', 'soldier', 'military', 'samurai']
senticnet['infatuate'] = [0.887, -0.847, 0, 0.819, '#joyful', '#surprising', 0.851, 'arouse', 'elicit', 'enkindle', 'kindle', 'evoke']
senticnet['infatuation'] = [0.988, 0, 0, 0.92, '#joyful', '#admirable', 0.636, 'puppy_love', 'calf_love', 'amatory', 'amorousness', 'amorous']
senticnet['infeasibility'] = [-0.978, 0, 0.675, -0.937, '#sad', '#disgusting', -0.863, 'impracticability', 'unfeasibility', 'inutility', 'uselessness', 'unusefulness']
senticnet['infect'] = [-0.835, 0, -0.828, -0.867, '#sad', '#disgusting', -0.843, 'cause_cold', 'tourism', 'reproduce', 'gland', 'procreate']
senticnet['infected'] = [-0.657, 0, 0.995, -0.625, '#sad', '#angry', -0.759, 'dirty', 'putrefactive', 'putrefacient', 'abscessed', 'contaminative']
senticnet['infection'] = [-0.191, -0.03, -0.151, -0.257, '#sad', '#disgusting', -0.19, 'cancer', 'ill_health', 'cause_sickness', 'terminal_illness', 'threaten']
senticnet['infectious_agent'] = [0.962, -0.898, 0, 0.855, '#joyful', '#surprising', 0.905, 'agent', 'infective_agent', 'satisfier', 'quickener', 'invigorator']
senticnet['infectious_disease'] = [0, 0, -0.768, -0.957, '#scared', '#disgusting', -0.575, 'contagious_disease', 'disease', 'polio', 'sickness', 'malady']
senticnet['infective_agent'] = [0.962, -0.898, 0, 0.855, '#joyful', '#surprising', 0.905, 'infectious_agent', 'agent', 'satisfier', 'quickener', 'invigorator']
senticnet['infelicitous'] = [-0.766, 0, 0.994, -0.605, '#sad', '#angry', -0.788, 'unfortunate', 'inapt', 'inept', 'awkward', 'clumsy']
senticnet['infer'] = [0, 0, -0.913, -0.829, '#scared', '#disgusting', -0.581, 'generalize', 'extrapolate', 'deduce', 'derive', 'guess']
senticnet['inferential'] = [0.734, -0.56, 0, 0.64, '#joyful', '#admirable', 0.645, 'connotative', 'suggestive', 'implicative', 'connotational', 'connotative_of']
senticnet['inferior'] = [0, 0, 0, -0.744, '#disgusting', '#disgusting', -0.248, 'least', 'submission', 'reduction', 'slave', 'envy']
senticnet['inferiority'] = [-0.579, 0, 0.53, -0.639, '#sad', '#disgusting', -0.583, 'low_status', 'lowness', 'backseat', 'lowliness', 'subordinateness']
senticnet['infernal'] = [-0.793, 0, 0.885, -0.768, '#sad', '#angry', -0.815, 'dead_soul', 'mortal', 'zombi', 'zombie', 'living_dead']
senticnet['infernal_region'] = [-0.924, 0, 0.687, -0.75, '#sad', '#disgusting', -0.787, 'hellfire', 'red_region', 'imaginary_place', 'mythical_place', 'fictitious_place']
senticnet['inferno'] = [0, 0, -0.129, -0.092, '#scared', '#disgusting', -0.074, 'flame', 'rapid_oxidation', 'huge_fire', 'cinder', 'fire']
senticnet['infertile'] = [-0.98, 0, 0.441, -0.962, '#sad', '#disgusting', -0.794, 'desert_land', 'barren_land', 'sand', 'barren', 'desert']
senticnet['infertility'] = [-0.738, 0, 0.634, -0.856, '#sad', '#disgusting', -0.743, 'cacogenesis', 'impotence', 'impotency', 'barrenness', 'dysgenesis']
senticnet['infidel'] = [-0.572, 0, 0.584, -0.758, '#angry', '#disgusting', -0.638, 'paynim', 'nonreligious_person', 'idolizer', 'idolater', 'idol_worshiper']
senticnet['infidelity'] = [-0.942, 0, 0.944, -0.906, '#sad', '#angry', -0.931, 'lust', 'pregnant', 'love_oneself', 'care_deeply', 'love']
senticnet['infinite'] = [0, 0.141, 0, 0.185, '#interesting', '#admirable', 0.109, 'infinity', 'interval', 'never_ending', 'all_of_it', 'dimension']
senticnet['infinitude'] = [-0.64, 0, 0.87, -0.745, '#angry', '#disgusting', -0.752, 'large_indefinite_amount', 'piles', 'mess', 'large_number', 'tons']
senticnet['infinity'] = [0, 0.111, 0, 0.127, '#interesting', '#admirable', 0.079, 'infinite', 'none', 'void', 'emptiness', 'nothing']
senticnet['infirmary'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'lazaret', 'lazarette', 'lazar_house', 'pesthouse', 'lazaretto']
senticnet['infirmity'] = [0.528, -0.718, 0, 0.848, '#surprising', '#admirable', 0.698, 'cachexia', 'cachexy', 'wasting', 'softness', 'unfitness']
senticnet['inflame'] = [-0.973, 0, -0.941, 0, '#sad', '#scared', -0.638, 'instigate', 'fire_up', 'incite', 'stir_up', 'sensational']
senticnet['inflammation'] = [-0.998, 0, 0.964, -0.704, '#sad', '#angry', -0.889, 'blepharitis', 'diverticulitis', 'epiglottitis', 'orchitis', 'prostatitis']
senticnet['inflammatory_bowel_disease'] = [-0.855, 0, 0.945, -0.958, '#angry', '#disgusting', -0.919, 'regional_enteritis', 'regional_ileitis', 'ulcerative_colitis', 'rubor', 'redness']
senticnet['inflammatory_disease'] = [-0.756, 0, 0.84, -0.633, '#sad', '#angry', -0.743, 'angina', 'gastroenteritis', 'stomach_flu', 'intestinal_flu', 'pelvic_inflammatory_disease']
senticnet['inflate'] = [0.051, -0.077, 0.043, 0.055, '#surprising', '#admirable', 0.047, 'bounce', 'throw', 'play_catch', 'bounce_up_down', 'play_dog']
senticnet['inflate_tire'] = [-0.089, 0, 0.116, 0, '#sad', '#angry', -0.068, 'circulate_blood', 'scrub_floor', 'grind_grain', 'beat_egg', 'bind_book']
senticnet['inflated'] = [-0.846, 0, 0, -0.763, '#sad', '#disgusting', -0.536, 'pretentious', 'hifalutin', 'snooty', 'highfalutin', 'portentous']
senticnet['inflation'] = [0.982, 0.831, 0, 0.837, '#joyful', '#admirable', 0.883, 'find_job', 'get_job', 'eat_fruit', 'calm_mind', 'get_hired']
senticnet['inflexibility'] = [-0.701, 0, 0.914, -0.727, '#angry', '#disgusting', -0.781, 'unadaptability', 'rigidity', 'rigidness', 'unfitness', 'inability']
senticnet['inflexible'] = [-0.806, 0, 0.507, -0.763, '#sad', '#disgusting', -0.692, 'adamant', 'inexorable', 'intransigent', 'ironclad', 'brassbound']
senticnet['inflict'] = [-0.536, 0, 0.662, -0.886, '#angry', '#disgusting', -0.695, 'intrude', 'obtrude', 'clamp', 'give', 'communicate']
senticnet['inflict_pain'] = [0, 0, 0.837, -0.824, '#angry', '#disgusting', -0.554, 'ouch', 'harm', 'hurt', 'suffer', 'damage']
senticnet['infliction'] = [-0.835, 0, 0.515, -0.913, '#sad', '#disgusting', -0.754, 'protection', 'regimentation', 'taxation', 'trade_protection', 'reimposition']
senticnet['influence'] = [0, 0.236, -0.218, 0.331, '#interesting', '#admirable', 0.116, 'compel', 'intend', 'cause_change', 'take_over', 'permission']
senticnet['influence_public_decision'] = [0, -0.092, 0, 0.08, '#surprising', '#admirable', 0.057, 'examine', 'analyze', 'find_lost_item', 'determine_truth', 'find_truth']
senticnet['influence_worldwide'] = [0.915, 0, 0.724, 0.952, '#joyful', '#admirable', 0.381, 'world_event', 'celebrate', 'olympic_game', 'international_affair', 'magnificent']
senticnet['influential'] = [0.923, -0.546, 0, 0.633, '#joyful', '#admirable', 0.701, 'important', 'prestigious', 'powerful', 'authoritative', 'potent']
senticnet['influential_person'] = [0.979, -0.692, 0, 0.576, '#joyful', '#surprising', 0.749, 'knocker', 'supremo', 'important_person', 'big_cheese', 'personage']
senticnet['influenza'] = [-0.806, 0, -0.73, -0.798, '#sad', '#disgusting', -0.778, 'cripple', 'chicken_pox', 'diabetes', 'disability', 'overpay']
senticnet['inform'] = [0.539, 0.874, 0, 0.843, '#interesting', '#admirable', 0.752, 'gain_information', 'gain_knowledge', 'increase_knowledge', 'learn_much', 'learn']
senticnet['inform_others'] = [0.539, 0.874, 0, 0.843, '#interesting', '#admirable', 0.752, 'transfer_knowledge', 'help_understand', 'tell_other_person', 'inform', 'inform_person']
senticnet['inform_person'] = [0, 0.761, 0, 0.707, '#interesting', '#admirable', 0.489, 'hold_match', 'teach', 'spread_news', 'report_event', 'better_oneself']
senticnet['inform_voter'] = [0, 0.761, 0, 0.707, '#interesting', '#admirable', 0.489, 'inform', 'gather_information', 'information', 'inform_person', 'inform_others']
senticnet['informal'] = [0.096, 0.182, -0.099, 0.198, '#interesting', '#admirable', 0.126, 'female_parent', 'relative', 'kin', 'relate_person', 'aunt_uncle']
senticnet['informal_rod'] = [0.073, -0.022, 0, 0, '#joyful', '#surprising', 0.032, 'fisherman', 'angler', 'archaic_fisher', 'rare_piscator', 'fishing_line']
senticnet['information'] = [0.796, 0.828, 0, 0.916, '#interesting', '#admirable', 0.847, 'report_news', 'inform', 'comprehension', 'knowledge', 'analyze']
senticnet['information_gathering'] = [0.979, 0.93, 0, 0.723, '#joyful', '#interesting', 0.877, 'comprehend', 'acquire_knowledge', 'seek_answer', 'smart', 'comprehension']
senticnet['information_source'] = [0.765, 0, 0, 0.725, '#joyful', '#admirable', 0.497, 'communication_method', 'form_of_communication', 'comment', 'written_language', 'give_info']
senticnet['information_transfer'] = [0.979, 0.93, 0, 0.723, '#joyful', '#interesting', 0.877, 'collaborate', 'tranfer', 'inform_person', 'inform_others', 'information']
senticnet['informational'] = [0.089, -0.017, 0.033, 0.082, '#joyful', '#admirable', 0.052, 'informative', 'epic', 'ephemeral', 'fun_read', 'ads']
senticnet['informative'] = [0.08, 0.153, -0.125, 0.224, '#interesting', '#admirable', 0.111, 'advertisment', 'ads', 'introduction', 'media', 'ephemeral']
senticnet['informatory'] = [0.795, -0.977, 0, 0.679, '#joyful', '#surprising', 0.817, 'advisory', 'consultative', 'consultatory', 'consultive', 'revealing']
senticnet['informed'] = [0.61, -0.983, 0, 0.795, '#surprising', '#admirable', 0.796, 'enlightened', 'conversant', 'hep', 'hip', 'hip_to']
senticnet['informer'] = [-0.808, 0, 0.928, -0.56, '#sad', '#angry', -0.765, 'fink', 'snitch', 'snitcher', 'sneak', 'stoolpigeon']
senticnet['infrangible'] = [-0.805, 0, 0.815, -0.984, '#angry', '#disgusting', -0.868, 'inalienable', 'nontransferable', 'unassignable', 'untransferable', 'inviolable']
senticnet['infrastructure'] = [0.021, 0, 0, 0.058, '#joyful', '#admirable', 0.026, 'architecture', 'route', 'structure', 'car_path', 'building']
senticnet['infrequency'] = [-0.881, 0, 0.732, -0.61, '#sad', '#angry', -0.741, 'paucity', 'insufficiency', 'rareness', 'scarceness', 'dearth']
senticnet['infringe'] = [-0.6, 0, 0.91, -0.51, '#sad', '#angry', -0.673, 'offend', 'violate', 'go_against', 'break', 'transgress']
senticnet['infuriate'] = [-0.127, 0.13, 0.647, -0.648, '#angry', '#disgusting', -0.431, 'exasperating', 'infuriating', 'maddening', 'furiously', 'dudgeon']
senticnet['infuriated'] = [-0.137, 0.145, 0.624, -0.638, '#angry', '#disgusting', -0.418, 'enraged', 'furious', 'maddened', 'angered', 'indignantly']
senticnet['infuriating'] = [-0.127, 0.13, 0.647, -0.648, '#angry', '#disgusting', -0.431, 'infuriate', 'exasperating', 'maddening', 'furiously', 'dudgeon']
senticnet['infuriation'] = [-0.125, 0.127, 0.651, -0.649, '#angry', '#disgusting', -0.433, 'enragement', 'high_dudgeon', 'dudgeon', 'furiously', 'infuriate']
senticnet['ingenious'] = [0.738, -0.965, 0, 0.727, '#joyful', '#surprising', 0.81, 'adroit', 'clever', 'cunning', 'clean', 'neat']
senticnet['ingeniousness'] = [-0.914, 0, 0.874, -0.866, '#sad', '#angry', -0.885, 'resourcefulness', 'imagination', 'creativity', 'creativeness', 'creative_thinking']
senticnet['ingenuity'] = [0.741, 0, 0, 0.86, '#joyful', '#admirable', 0.534, 'imagination', 'creativity', 'creativeness', 'creative_thinking', 'cheerful']
senticnet['ingenuous'] = [0.772, 0, 0, 0.75, '#joyful', '#admirable', 0.507, 'naive', 'innocent', 'childlike', 'guileless', 'trustful']
senticnet['ingenuousness'] = [-0.613, 0, 0.599, -0.571, '#sad', '#angry', -0.594, 'simple_mindedness', 'simpleness', 'naiveness', 'artlessness', 'simplicity']
senticnet['ingest'] = [0.124, 0.129, 0, 0.142, '#interesting', '#admirable', 0.132, 'gulp', 'better_cold', 'consume', 'consumable', 'like_eat']
senticnet['ingest_food'] = [0.055, 0.131, -0.065, 0.121, '#interesting', '#admirable', 0.081, 'masticate', 'consume_nourishment', 'swallow_food', 'satisfy_appetite', 'feed']
senticnet['inglorious'] = [-0.839, 0, 0, -0.843, '#sad', '#disgusting', -0.561, 'disgraceful', 'shameful', 'dishonorably', 'dishonored', 'shame']
senticnet['ingloriously'] = [-0.886, 0, 0, -0.78, '#sad', '#disgusting', -0.555, 'disgraceful', 'shameful', 'dishonorably', 'inglorious', 'dishonored']
senticnet['ingratiate'] = [0.985, -0.759, 0, 0.894, '#joyful', '#admirable', 0.879, 'cozy_up', 'cotton_up', 'shine_up', 'sidle_up', 'play_up']
senticnet['ingratitude'] = [-0.727, 0, 0, -0.982, '#sad', '#disgusting', -0.57, 'ungratefulness', 'feel_for', 'condole_with', 'compassionateness', 'sympathize_with']
senticnet['ingredient'] = [0.04, 0, 0, 0.067, '#joyful', '#admirable', 0.036, 'cook', 'food', 'taste', 'add_flavor', 'tongue']
senticnet['ingress'] = [-0.506, 0, 0.975, -0.865, '#angry', '#disgusting', -0.782, 'entrance', 'entering', 'entry', 'irruption', 'incoming']
senticnet['ingroup'] = [-0.935, 0, 0.586, -0.669, '#sad', '#disgusting', -0.73, 'camp', 'pack', 'clique', 'coterie', 'brain_trust']
senticnet['inhabit'] = [0.051, 0, 0, 0.1, '#joyful', '#admirable', 0.05, 'provide_shelter', 'live', 'get_oxygen', 'raise_family', 'live_city']
senticnet['inhabitant'] = [-0.03, 0.091, 0, 0.154, '#interesting', '#admirable', 0.072, 'small_home', 'live_place', 'new_home', 'medieval', 'place_where_people_live']
senticnet['inhale'] = [0, 0, -0.878, -0.749, '#scared', '#disgusting', -0.542, 'exhale', 'cough', 'respiration', 'involuntary', 'smell_odor']
senticnet['inhale_air'] = [0, 0, -0.104, 0, '#scared', '#scared', -0.035, 'oxygen', 'breathable', 'lighter_water', 'hydrogen', 'air']
senticnet['inharmonious'] = [-0.527, 0, 0.902, -0.735, '#angry', '#disgusting', -0.721, 'discordant', 'dissonant', 'unresolved', 'false', 'disharmonious']
senticnet['inherit'] = [0, 0.769, 0, 0, '#interesting', '#interesting', 0.256, 'get_rich', 'get_money', 'inherit_property', 'benefit', 'enjoy_life']
senticnet['inherit_property'] = [0, 0.769, 0, 0, '#interesting', '#interesting', 0.256, 'get_rich', 'get_money', 'inherit', 'benefit', 'enjoy_life']
senticnet['inhibition'] = [0, 0.171, -0.084, 0.11, '#interesting', '#admirable', 0.066, 'restriction', 'command', 'restraint', 'control', 'direct']
senticnet['inhomogeneous'] = [-0.826, 0, 0.756, -0.516, '#sad', '#angry', -0.699, 'heterogeneous', 'nonuniform', 'assorted', 'sundry', 'mixed']
senticnet['inhospitable'] = [-0.566, 0, 0.814, -0.887, '#angry', '#disgusting', -0.756, 'unfriendly', 'barren', 'bleak', 'desolate', 'wild']
senticnet['inhuman'] = [-0.939, 0, 0.508, -0.582, '#sad', '#disgusting', -0.676, 'nonhuman', 'bloodless', 'apelike', 'anthropoid', 'anthropoidal']
senticnet['inhuman_treatment'] = [-0.875, 0, 0.932, -0.6, '#sad', '#angry', -0.802, 'atrocity', 'maltreatment', 'abuse', 'inhumanity', 'impalement']
senticnet['inhumane'] = [-0.795, 0, 0.691, -0.886, '#sad', '#disgusting', -0.791, 'cold', 'pitiless', 'cruel', 'fell', 'vicious']
senticnet['inhumanity'] = [-0.99, 0, 0.947, -0.883, '#sad', '#angry', -0.94, 'atrociousness', 'barbarousness', 'heinousness', 'atrocity', 'barbarity']
senticnet['inimical'] = [-0.122, 0.193, 0.597, -0.627, '#angry', '#disgusting', -0.384, 'unfriendly', 'unfriendliness', 'disapproval', 'disapprove', 'disapproving']
senticnet['iniquity'] = [-0.522, 0, 0.621, -0.919, '#angry', '#disgusting', -0.687, 'deviltry', 'devilry', 'irreverence', 'foul_play', 'sexual_immorality']
senticnet['initiate'] = [-0.954, 0, 0.735, -0.842, '#sad', '#disgusting', -0.844, 'novice', 'beginner', 'tyro', 'tiro', 'cub']
senticnet['initiation'] = [0.085, 0, 0, 0.089, '#joyful', '#admirable', 0.058, 'steam', 'haze', 'mist', 'misty', 'summer_weather']
senticnet['injection'] = [0, 0, -0.971, -0.705, '#scared', '#disgusting', -0.559, 'sharp_weapon', 'bayonet', 'ammunition', 'spear', 'arrow']
senticnet['injector'] = [0.843, -0.998, 0, 0.706, '#joyful', '#surprising', 0.849, 'gadgetry', 'gimbal', 'contrivance', 'mod_con', 'device']
senticnet['injudiciousness'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'lack_of_judgment', 'lack_of_discreetness', 'lack_of_discernment', 'reckless', 'rentless']
senticnet['injure'] = [0, 0, -0.744, -0.979, '#scared', '#disgusting', -0.574, 'cause_injury', 'slander', 'skin_knee', 'serious_injury', 'maim']
senticnet['injure_oneself'] = [-0.055, -0.049, -0.057, -0.109, '#scared', '#disgusting', -0.057, 'sore_muscle', 'shortness_breath', 'loss_ofbreath', 'pull_muscle', 'breafast']
senticnet['injure_person'] = [-0.998, 0, 0.749, -0.981, '#sad', '#disgusting', -0.909, 'cut', 'hurt', 'pain', 'injury', 'blood']
senticnet['injured'] = [-0.639, 0, 0.503, -0.736, '#sad', '#disgusting', -0.626, 'wounded', 'mangled', 'torn', 'hurt', 'eviscerate']
senticnet['injury'] = [-0.919, -0.851, -0.932, -0.998, '#scared', '#disgusting', -0.666, 'strengthful', 'bruise', 'broken_bone', 'head_injury', 'get_hurt']
senticnet['injustice'] = [-0.942, 0, 0.886, -0.841, '#sad', '#angry', -0.89, 'put_in_jail', 'go_jail', 'go_to_prison', 'send_to_jail', 'jail_time']
senticnet['ink'] = [0.022, -0.057, 0.079, -0.116, '#angry', '#disgusting', -0.039, 'stationery', 'ball_point_pen', 'paper', 'refill', 'notes']
senticnet['ink_cartridge'] = [0.023, 0, 0, 0.066, '#joyful', '#admirable', 0.03, 'ink_paper', 'pencil_paper', 'use_ink', 'pencil_mark', 'type_of_document']
senticnet['ink_paper'] = [0.023, 0, 0, 0.066, '#joyful', '#admirable', 0.03, 'ink_cartridge', 'pencil_paper', 'use_ink', 'pencil_mark', 'type_of_document']
senticnet['inkiness'] = [-0.785, 0, 0.693, -0.691, '#sad', '#angry', -0.723, 'coal_black', 'jet_black', 'pitch_black', 'soot_black', 'achromatic_color']
senticnet['inmate'] = [0, 0, -0.948, -0.912, '#scared', '#disgusting', -0.62, 'jailbird', 'prisoner', 'imprisoned', 'convict', 'captive']
senticnet['inn'] = [0.725, 0.92, 0, 0, '#joyful', '#interesting', 0.548, 'hostel', 'hangout', 'bar', 'tavern', 'pub']
senticnet['innate'] = [-0.951, 0, 0.684, -0.762, '#sad', '#disgusting', -0.799, 'nonheritable', 'nurtural', 'inborn', 'nontransmissible', 'nonhereditary']
senticnet['innate_reflex'] = [0.89, -0.821, 0, 0.776, '#joyful', '#surprising', 0.829, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'babinski']
senticnet['inner'] = [0.716, -0.627, 0, 0.896, '#joyful', '#admirable', 0.746, 'constitutional', 'integral', 'intimate', 'intrinsic', 'inbuilt']
senticnet['inner_peace'] = [0.829, 0.74, 0, 0.94, '#joyful', '#admirable', 0.836, 'strong_relationship', 'run_business', 'good_sense_of_humor', 'world_peace', 'wear_necklace']
senticnet['inner_planet'] = [-0.072, 0, 0.014, 0, '#sad', '#angry', -0.029, 'ground_material', 'abrasive', 'soil_earth', 'cold_night', 'small_rock']
senticnet['innocence'] = [0.751, 0.771, 0, 0, '#joyful', '#interesting', 0.507, 'little_boy', 'youngster', 'youth', 'brat', 'lad']
senticnet['innocent'] = [0.039, 0, 0, 0.066, '#joyful', '#admirable', 0.035, 'small_human', 'small_person', 'young_kid', 'immature', 'small_boy']
senticnet['innovation'] = [0, 0.719, 0, 0.786, '#interesting', '#admirable', 0.502, 'realization', 'figure_out', 'come_conclusion', 'arrive_conclusion', 'resolve_problem']
senticnet['innovativeness'] = [-0.502, 0, 0.733, -0.558, '#angry', '#disgusting', -0.598, 'unconventionality', 'novelty', 'originality', 'freshness', 'ability']
senticnet['innumerableness'] = [-0.852, 0, 0.605, -0.739, '#sad', '#disgusting', -0.732, 'fewness', 'numerousness', 'numerosity', 'number', 'countlessness']
senticnet['input_device'] = [0, 0, 0.076, 0, '#angry', '#angry', -0.025, 'device', 'computer', 'browser', 'number_pad', 'telephone_computer']
senticnet['inquietude'] = [-0.872, 0, -0.79, 0, '#sad', '#scared', -0.554, 'disquietude', 'edginess', 'edgy', 'uptight', 'restive']
senticnet['inquire'] = [-0.103, 0.127, -0.11, 0.174, '#interesting', '#admirable', 0.029, 'query', 'response', 'respond', 'interrogation', 'inquiry']
senticnet['inquirer'] = [-0.623, 0, 0.632, -0.783, '#angry', '#disgusting', -0.679, 'inquisitor', 'enquirer', 'questioner', 'querier', 'asker']
senticnet['inquiry'] = [0, 0.896, 0, 0.978, '#interesting', '#admirable', 0.625, 'question', 'answer', 'query', 'question_start', 'question_answering']
senticnet['inquisition'] = [-0.587, 0, 0.701, -0.979, '#angry', '#disgusting', -0.756, 'interrogatory', 'interview', 'catechism', 'deposition', 'third_degree']
senticnet['inquisitive'] = [0, 0.84, 0, 0.887, '#interesting', '#admirable', 0.576, 'curious', 'seek_information', 'ask_question', 'question', 'question_knowledge']
senticnet['inquisitor'] = [-0.623, 0, 0.632, -0.783, '#angry', '#disgusting', -0.679, 'inquirer', 'enquirer', 'questioner', 'querier', 'asker']
senticnet['inroad'] = [-0.698, 0, 0.752, -0.82, '#angry', '#disgusting', -0.757, 'usurpation', 'trespass', 'encroachment', 'intrusion', 'violation']
senticnet['insalubriousness'] = [-0.754, 0, 0.893, -0.618, '#sad', '#angry', -0.755, 'unwholesomeness', 'morbidness', 'morbidity', 'insalubrity', 'unhealthfulness']
senticnet['insalubrity'] = [-0.754, 0, 0.893, -0.618, '#sad', '#angry', -0.755, 'unwholesomeness', 'morbidness', 'morbidity', 'unhealthfulness', 'insalubriousness']
senticnet['insane'] = [0, 0, 0.729, -0.938, '#angry', '#disgusting', -0.556, 'seek_revenge', 'die', 'take_life', 'threaten', 'cause_death']
senticnet['insane_asylum'] = [-0.753, 0, 0.547, -0.577, '#sad', '#disgusting', -0.626, 'snake_pit', 'booby_hatch', 'crazy_house', 'cuckoo_nest', 'funny_farm']
senticnet['insanity'] = [0, 0, 0.808, -0.754, '#angry', '#disgusting', -0.521, 'prejudice', 'angry_emotion', 'fight', 'mental_disorder', 'dislike']
senticnet['insatiable'] = [-0.728, 0, 0.933, -0.505, '#sad', '#angry', -0.722, 'unsatisfied', 'quenchless', 'unquenchable', 'unsated', 'unsatiated']
senticnet['insatiate'] = [-0.911, 0, 0.803, -0.535, '#sad', '#angry', -0.75, 'unsatisfied', 'quenchless', 'unquenchable', 'unsated', 'unsatiated']
senticnet['inscribe'] = [0.719, 0.757, 0, 0, '#joyful', '#interesting', 0.492, 'matriculate', 'enroll_class', 'enroll_school', 'enroll', 'register']
senticnet['inscrutable'] = [-0.624, 0, 0.825, -0.738, '#angry', '#disgusting', -0.729, 'unexplainable', 'unaccountable', 'unexplained', 'incomprehensible', 'mystifying']
senticnet['insect'] = [0, -0.048, 0.089, -0.091, '#angry', '#disgusting', -0.044, 'bug', 'annoy_bug', 'nuisance_insect', 'fly_insect', 'social_insect']
senticnet['insect_bite'] = [-0.931, 0, 0.631, -0.9, '#sad', '#disgusting', -0.821, 'injury', 'harm', 'hurt', 'mosquito_bite', 'trauma']
senticnet['insect_collection'] = [-0.05, 0.21, -0.072, 0.102, '#interesting', '#admirable', 0.063, 'coin', 'collection', 'butterfly_collection', 'coin_collection', 'album_collection']
senticnet['insect_repellant'] = [0.03, 0.117, 0, 0.084, '#interesting', '#admirable', 0.077, 'object', 'physical_object', 'thin_wood', 'tree_product', 'book_page']
senticnet['insecure'] = [-0.729, 0, -0.767, 0, '#sad', '#scared', -0.499, 'misgiving', 'qualm', 'scruple', 'insecurely', 'insecurity']
senticnet['insecurely'] = [-0.843, 0, -0.94, 0, '#sad', '#scared', -0.594, 'misgiving', 'qualm', 'scruple', 'insecurity', 'insecure']
senticnet['insecurity'] = [-0.721, 0, -0.835, 0, '#sad', '#scared', -0.519, 'misgiving', 'qualm', 'scruple', 'insecurely', 'insecure']
senticnet['insensibility'] = [-0.794, 0, 0.636, -0.756, '#sad', '#disgusting', -0.729, 'insensitiveness', 'tin_ear', 'hardness', 'unfitness', 'unfeelingness']
senticnet['insensible'] = [-0.612, 0, 0.572, -0.839, '#sad', '#disgusting', -0.674, 'numb', 'benumbed', 'anesthetic', 'emotionless', 'asleep']
senticnet['insensitive'] = [-0.043, -0.04, -0.049, -0.046, '#scared', '#disgusting', -0.033, 'blunted', 'dull', 'unsharpened', 'blunt', 'edgeless']
senticnet['insensitiveness'] = [-0.794, 0, 0.636, -0.756, '#sad', '#disgusting', -0.729, 'insensibility', 'tin_ear', 'hardness', 'unfitness', 'unfeelingness']
senticnet['insensitivity'] = [-0.848, 0, 0.547, -0.658, '#sad', '#disgusting', -0.684, 'insensibility', 'tin_ear', 'hardness', 'unfitness', 'unfeelingness']
senticnet['insert'] = [0.043, -0.05, 0.043, 0.204, '#surprising', '#admirable', 0.085, 'flour_water', 'sticky_substance', 'adhesive', 'computer_command', 'tooth_brush']
senticnet['insert_dvd_in_player'] = [-0.086, -0.061, 0.043, -0.185, '#sad', '#disgusting', -0.084, 'press_play', 'turn_on_dvd_player', 'turn_channel', 'buy_popcorn', 'turn_television']
senticnet['inside'] = [0, 0.096, 0, 0.115, '#interesting', '#admirable', 0.07, 'part_of_building', 'architectural_structure', 'place_house', 'live_quarter', 'small_building']
senticnet['inside_body'] = [-0.042, 0.077, -0.092, -0.08, '#scared', '#disgusting', -0.046, 'body', 'corpse', 'normal_human_body', 'dead_person', 'nervous_system']
senticnet['inside_brain'] = [-0.953, 0, -0.926, 0, '#sad', '#scared', -0.626, 'anus', 'stub', 'nervous_system', 'nape', 'under_head']
senticnet['inside_build'] = [0, 0.086, 0.046, 0.133, '#interesting', '#admirable', 0.058, 'house_place', 'empty', 'house_location', 'empty_place', 'land_measurement']
senticnet['inside_egg'] = [0.053, 0.091, 0, 0.152, '#interesting', '#admirable', 0.099, 'baby_chicken', 'hen_baby', 'oval_shape', 'lay_egg', 'hatch']
senticnet['inside_head'] = [0, 0.799, 0, 0.7, '#interesting', '#admirable', 0.5, 'cranium', 'head', 'skull', 'hold_brain', 'face']
senticnet['inside_house'] = [0, 0, 0, 0.092, '#admirable', '#admirable', 0.031, 'room', 'four_walls', 'house_part', 'square_shape', 'house_area']
senticnet['insight'] = [-0.06, -0.028, 0.02, -0.172, '#sad', '#disgusting', -0.075, 'eye_strain', 'new_perspective', 'move_eye', 'gain_insight', 'great_understand']
senticnet['insignia'] = [-0.055, 0.114, -0.044, 0.065, '#interesting', '#admirable', 0.027, 'military_order', 'social_class', 'classification', 'status', 'rank']
senticnet['insignificant'] = [0, -0.869, 0.992, -0.92, '#angry', '#disgusting', -0.348, 'pointless', 'useless', 'small', 'embarrassment', 'futile']
senticnet['insincere'] = [-0.527, 0, 0.651, -0.542, '#angry', '#disgusting', -0.573, 'feigned', 'dissimulative', 'specious', 'hypocritical', 'fulsome']
senticnet['insipid'] = [0, 0, -0.947, -0.897, '#scared', '#disgusting', -0.615, 'flavorless', 'bland', 'jejune', 'vapid', 'flat']
senticnet['insist'] = [0, 0.714, 0, 0.809, '#interesting', '#admirable', 0.508, 'stand_fast', 'maintain', 'assert', 'asseverate', 'postulate']
senticnet['insistent'] = [0, 0, -0.779, -0.843, '#scared', '#disgusting', -0.541, 'crying', 'repetitive', 'exigent', 'instant', 'clamant']
senticnet['insolence'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'rudeness', 'discourtesy', 'rude', 'chutzpah', 'hutzpah']
senticnet['insolent'] = [0, 0, 0.936, -0.702, '#angry', '#disgusting', -0.546, 'undeferential', 'disrespectful', 'undutiful', 'bareface', 'brazen']
senticnet['insolvent'] = [-0.949, 0, 0.551, -0.984, '#sad', '#disgusting', -0.828, 'unfortunate', 'nonstarter', 'underdog', 'bankrupt', 'dud']
senticnet['insomnia'] = [-0.859, 0, 0.802, 0, '#sad', '#angry', -0.554, 'fall_asleep', 'sleepy', 'annoying', 'drowsiness', 'drink_cup_coffee']
senticnet['insouciance'] = [0, 0, 0, -0.742, '#disgusting', '#disgusting', -0.247, 'lightheartedness', 'carefree', 'lightsomeness', 'unworried', 'carefreeness']
senticnet['inspect'] = [0.809, -0.848, 0, 0.697, '#joyful', '#surprising', 0.785, 'review', 'go_over', 'survey', 'perambulate', 'case']
senticnet['inspection'] = [0, 0.203, -0.137, 0.18, '#interesting', '#admirable', 0.082, 'check', 'control', 'examination', 'audit', 'command']
senticnet['inspiration'] = [-0.055, 0.114, -0.044, 0.065, '#interesting', '#admirable', 0.027, 'enlightenment', 'creative', 'new_idea', 'inspire', 'use_mind']
senticnet['inspire'] = [0, 0.956, 0, 0.962, '#interesting', '#admirable', 0.639, 'fascinate', 'recreate', 'joy', 'jubilation', 'tranquility']
senticnet['inspirit'] = [0.692, -0.551, 0, 0.891, '#joyful', '#admirable', 0.711, 'enliven', 'liven', 'liven_up', 'invigorate', 'animate']
senticnet['instability'] = [-0.922, 0, 0.546, -0.523, '#sad', '#angry', -0.664, 'irresponsibility', 'irresponsibleness', 'undependability', 'irreproducibility', 'fallibility']
senticnet['install_window'] = [-0.249, 0, -0.047, -0.121, '#sad', '#disgusting', -0.139, 'collide', 'hold_two_together', 'fall_down_flight_stair', 'window', 'spring_up']
senticnet['instance'] = [0.815, 0.824, 0, 0, '#joyful', '#interesting', 0.546, 'appointment', 'year', 'rendezvous', 'years', 'yesterday']
senticnet['instancy'] = [0.548, -0.622, 0, 0.695, '#surprising', '#admirable', 0.622, 'quickness', 'celerity', 'rapidity', 'rapidness', 'speediness']
senticnet['instant'] = [0, -0.937, 0, 0.757, '#surprising', '#admirable', 0.565, 'feel_presence', 'presence', 'person', 'make_effort', 'currently']
senticnet['instigant'] = [-0.75, 0, 0.631, -0.988, '#sad', '#disgusting', -0.79, 'troublemaker', 'trouble_maker', 'troubler', 'bad_hat', 'ringleader']
senticnet['instigate'] = [0.98, 0.985, 0, 0, '#joyful', '#interesting', 0.655, 'start', 'begin', 'initiate', 'launch', 'institute']
senticnet['instigator'] = [-0.822, 0, 0.889, -0.51, '#sad', '#angry', -0.74, 'troublemaker', 'trouble_maker', 'troubler', 'bad_hat', 'ringleader']
senticnet['instill'] = [0.99, -0.769, 0, 0.571, '#joyful', '#surprising', 0.777, 'add', 'contribute', 'lend', 'breathe', 'impart']
senticnet['instinct'] = [0, 0, -0.964, -0.884, '#scared', '#disgusting', -0.616, 'get_burnt', 'overeat', 'create_smoke', 'animal_instinct', 'rapid_oxidation']
senticnet['instinctive'] = [-0.838, 0, 0.812, -0.92, '#sad', '#disgusting', -0.857, 'natural', 'impulsive', 'intuitive', 'spontaneous', 'unprompted']
senticnet['instinctive_reflex'] = [0.89, -0.821, 0, 0.776, '#joyful', '#surprising', 0.829, 'reflex', 'reflex_response', 'reflex_action', 'babinski', 'innate_reflex']
senticnet['institute'] = [0.075, 0.177, 0, 0.076, '#interesting', '#admirable', 0.109, 'institution', 'wonderful_place_visit', 'establishment', 'corporation', 'establish']
senticnet['institute_civil_action'] = [0, 0, 0, 0.095, '#admirable', '#admirable', 0.032, 'reach_impasse', 'change_society', 'take_oath', 'divide', 'divide_person']
senticnet['institution'] = [0, 0.109, 0, 0.053, '#interesting', '#admirable', 0.054, 'wonderful_place_visit', 'bachelor_degree', 'place_learn', 'educational_institution', 'educational_facility']
senticnet['instruct'] = [0.633, -0.799, 0, 0.935, '#surprising', '#admirable', 0.789, 'reward', 'mentor', 'reinforce', 'spoonfeed', 'lecture']
senticnet['instruction'] = [0, 0.182, -0.064, 0.201, '#interesting', '#admirable', 0.106, 'know_how', 'conclusion', 'omega', 'end_point', 'unit_language']
senticnet['instructions'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'engineer', 'pilot', 'computer', 'control_machine', 'mechanical_room']
senticnet['instructor'] = [-0.042, -0.026, 0, -0.064, '#sad', '#disgusting', -0.027, 'professor', 'lecturer', 'teacher', 'freshman', 'pupil']
senticnet['instrument'] = [0.96, -0.714, 0, 0.529, '#joyful', '#surprising', 0.734, 'medical_instrument', 'optical_instrument', 'scientific_instrument', 'extractor', 'whip']
senticnet['instrument_music'] = [-0.036, -0.009, 0.018, -0.082, '#sad', '#disgusting', -0.042, 'reed_instrument', 'stringed_musical_instrument', 'use_jazz_music', 'musical_instrument', 'listen_music']
senticnet['instrument_of_torture'] = [-0.67, 0, 0.85, -0.599, '#sad', '#angry', -0.706, 'rack', 'boot', 'whip', 'iron_boot', 'iron_heel']
senticnet['instrumental'] = [0.09, -0.012, 0.031, 0.121, '#joyful', '#admirable', 0.064, 'melodic_noise', 'vocal_music', 'lyric', 'lyrics', 'piece_of_music']
senticnet['instruments'] = [0.445, 0.37, -0.142, 0.483, '#joyful', '#admirable', 0.385, 'sing', 'choir_orchestra', 'music_room', 'symphony', 'choir']
senticnet['insubordinate'] = [-0.652, 0, 0.795, -0.96, '#angry', '#disgusting', -0.802, 'contumacious', 'disobedient', 'unruly', 'rebellious', 'mutinous']
senticnet['insubstantial'] = [-0.961, 0, 0.939, -0.605, '#sad', '#angry', -0.835, 'airy', 'shadowy', 'stringy', 'wraithlike', 'ethereal']
senticnet['insubstantiality'] = [-0.953, 0, 0.909, -0.974, '#sad', '#disgusting', -0.945, 'unreality', 'incorporeality', 'quality', 'intangibility', 'intangibleness']
senticnet['insufferable'] = [-0.889, 0, 0.907, -0.847, '#sad', '#angry', -0.881, 'unsupportable', 'unacceptable', 'bitter', 'impossible', 'intolerable']
senticnet['insufficiency'] = [-0.826, 0, 0.899, -0.921, '#angry', '#disgusting', -0.882, 'exiguity', 'sparseness', 'sparsity', 'abstemiousness', 'little']
senticnet['insufficient'] = [-0.767, 0, 0.927, -0.811, '#angry', '#disgusting', -0.835, 'inadequate', 'depleted', 'poor', 'short', 'low']
senticnet['insulate'] = [-0.57, 0, 0.855, -0.957, '#angry', '#disgusting', -0.794, 'soundproof', 'modify', 'alter', 'change', 'weatherstrip']
senticnet['insulin'] = [0.718, 0.849, 0, 0.704, '#joyful', '#interesting', 0.757, 'good_tooth', 'self_confidence', 'big_paycheck', 'good_credit', 'look_beautiful']
senticnet['insulin_shock'] = [-0.724, 0, 0.732, -0.595, '#sad', '#angry', -0.684, 'shock_therapy', 'shock', 'shock_therapy_treatment', 'metrazol_shock', 'metrazol_shock_therapy']
senticnet['insulin_shock_therapy'] = [-0.724, 0, 0.732, -0.595, '#sad', '#angry', -0.684, 'insulin_shock', 'shock_therapy', 'insulin_shock_treatment', 'metrazol_shock', 'metrazol_shock_therapy']
senticnet['insulin_shock_treatment'] = [-0.724, 0, 0.732, -0.595, '#sad', '#angry', -0.684, 'insulin_shock', 'insulin_shock_therapy', 'shock_therapy', 'metrazol_shock', 'metrazol_shock_therapy']
senticnet['insult'] = [-0.945, 0, 0.923, -0.877, '#sad', '#angry', -0.915, 'put_in_jail', 'damage', 'cause_injury', 'send_to_jail', 'hurt_person']
senticnet['insuperable'] = [-0.738, 0, 0.732, -0.535, '#sad', '#angry', -0.668, 'insurmountable', 'unconquerable', 'inexpugnable', 'indomitable', 'unsubduable']
senticnet['insupportable'] = [-0.736, 0, 0.846, -0.687, '#sad', '#angry', -0.756, 'indefensible', 'unwarranted', 'inexcusable', 'unjustifiable', 'unwarrantable']
senticnet['insurance'] = [0.049, 0.139, -0.09, 0.123, '#interesting', '#admirable', 0.074, 'guard', 'safety', 'ford', 'policy', 'protect_home']
senticnet['insure'] = [0.786, 0.7, 0, 0, '#joyful', '#interesting', 0.495, 'bottle_without_cap', 'ridgeback', 'bluetooth', 'run_treadmill', 'complete_thesis']
senticnet['insurgent'] = [-0.801, 0, 0.815, -0.757, '#sad', '#angry', -0.791, 'reformist', 'social_reformer', 'meliorist', 'reformer', 'crusader']
senticnet['insurmountable'] = [-0.738, 0, 0.732, -0.535, '#sad', '#angry', -0.668, 'unconquerable', 'insuperable', 'inexpugnable', 'indomitable', 'unsubduable']
senticnet['insusceptible'] = [-0.77, 0, 0.639, -0.798, '#sad', '#disgusting', -0.736, 'unpersuadable', 'unsuasible', 'unresponsive', 'resistant', 'incapable']
senticnet['intangibility'] = [-0.953, 0, 0.909, -0.974, '#sad', '#disgusting', -0.945, 'unreality', 'insubstantiality', 'quality', 'incorporeality', 'intangibleness']
senticnet['intangible'] = [0.049, 0.23, -0.118, 0.204, '#interesting', '#admirable', 0.122, 'imaginative', 'subjective', 'brain_function', 'imagination', 'thought']
senticnet['intangibleness'] = [-0.953, 0, 0.909, -0.974, '#sad', '#disgusting', -0.945, 'unreality', 'insubstantiality', 'quality', 'intangibility', 'incorporeality']
senticnet['integer'] = [0.045, 0, 0.017, 0.052, '#joyful', '#admirable', 0.027, 'inexpensive', 'good_deal', 'cutlass', 'cheap', 'cost_little_money']
senticnet['integral'] = [0.716, -0.627, 0, 0.896, '#joyful', '#admirable', 0.746, 'constitutional', 'intrinsic', 'intimate', 'inner', 'inbuilt']
senticnet['integrality'] = [0.875, -0.654, 0, 0.861, '#joyful', '#admirable', 0.797, 'completeness', 'work', 'whole_shebang', 'whole_kit_and_caboodle', 'kit_and_caboodle']
senticnet['integrative'] = [-0.938, 0, 0.944, -0.922, '#sad', '#angry', -0.935, 'combinative', 'combinatory', 'consolidative', 'unifying', 'combinatorial']
senticnet['integrity'] = [0, 0, 0, 0.817, '#admirable', '#admirable', 0.272, 'truthful', 'honesty', 'honest', 'abstract_concept', 'good_character']
senticnet['intellect'] = [-0.05, 0.21, -0.072, 0.102, '#interesting', '#admirable', 0.063, 'figure_out', 'brain_activity', 'resolve_problem', 'cognition', 'arrive_conclusion']
senticnet['intellection'] = [0.913, -0.652, 0, 0.89, '#joyful', '#admirable', 0.818, 'reasoning', 'consideration', 'logical_thinking', 'abstract_thought', 'excogitation']
senticnet['intellectual'] = [0.615, -0.935, 0, 0.812, '#surprising', '#admirable', 0.787, 'decipherer', 'intellect', 'cryptanalyst', 'cryptographer', 'cryptologist']
senticnet['intellectual_stimulation'] = [0, 0.142, 0, 0.125, '#interesting', '#admirable', 0.089, 'exercise_mind', 'exercise', 'mind', 'exercise_muscle', 'occupy_mind']
senticnet['intelligence'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'knowledge', 'trivia', 'understand_problem', 'gain_insight', 'solution_to_problem']
senticnet['intelligent'] = [0.995, 0.801, 0, 0.968, '#joyful', '#admirable', 0.921, 'smart', 'smartness', 'curious', 'become_wise', 'comprehend']
senticnet['intelligent_agent'] = [0, 0.717, 0, 0.765, '#interesting', '#admirable', 0.494, 'goal_driven_active_entity', 'artificial_intelligence', 'goal_driven', 'proactive', 'intelligent']
senticnet['intelligent_person'] = [0.086, 0.095, -0.065, 0.066, '#joyful', '#interesting', 0.061, 'married_couple', 'presidential_election', 'grown_up', 'use_binoculars', 'torpedo']
senticnet['intelligentsia'] = [0.594, -0.735, 0, 0.909, '#surprising', '#admirable', 0.746, 'elite', 'clerisy', 'nobility', 'elect', 'aristocracy']
senticnet['intelligible'] = [0.744, -0.766, 0, 0.669, '#joyful', '#surprising', 0.726, 'accessible', 'fathomable', 'approachable', 'perceivable', 'comprehendible']
senticnet['intemperateness'] = [0.987, -0.744, 0, 0.695, '#joyful', '#surprising', 0.809, 'vice', 'drink', 'drinking', 'boozing', 'drunkenness']
senticnet['intend'] = [0, 0.338, -0.137, 0.298, '#interesting', '#admirable', 0.166, 'permission', 'conclusion', 'purpose', 'ask', 'conclude']
senticnet['intense'] = [-0.364, -0.179, -0.205, 0.062, '#sad', '#scared', -0.109, 'excessive', 'extreme', 'nervous', 'tense', 'intense_heat']
senticnet['intense_deisre'] = [0.06, 0.377, -0.302, 0.339, '#interesting', '#admirable', 0.158, 'yearn', 'strong_desire', 'desire', 'demand', 'ask_for']
senticnet['intense_heat'] = [-0.945, 0, 0.112, -0.999, '#sad', '#disgusting', -0.685, 'pain', 'hurt', 'injury', 'heat', 'fire']
senticnet['intensify'] = [0.737, -0.808, 0, 0.611, '#joyful', '#surprising', 0.719, 'compound', 'enhance', 'deepen', 'potentiate', 'heighten']
senticnet['intensifying'] = [0.652, -0.649, 0, 0.953, '#joyful', '#admirable', 0.751, 'heightening', 'thickening', 'aggravating', 'exacerbating', 'deepening']
senticnet['intensity'] = [-0.934, 0, 0.698, -0.857, '#sad', '#disgusting', -0.83, 'candlepower', 'light_intensity', 'acoustic_power', 'sound_pressure_level', 'threshold_level']
senticnet['intensiveness'] = [-0.606, 0, 0.614, -0.946, '#angry', '#disgusting', -0.722, 'badness', 'severity', 'severeness', 'fury', 'wildness']
senticnet['intention'] = [-0.965, 0, 0, -0.946, '#sad', '#disgusting', -0.637, 'unbearable', 'rude', 'short_line', 'time_out', 'consequence']
senticnet['intentness'] = [0.927, -0.922, 0, 0.76, '#joyful', '#surprising', 0.87, 'diligence', 'industriousness', 'singleness', 'assiduity', 'engrossment']
senticnet['inter'] = [-0.027, -0.027, 0.097, -0.033, '#angry', '#disgusting', -0.043, 'boat', 'big_boat', 'rowboat', 'ship', 'military_ship']
senticnet['interact'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'cooperate', 'help_each_other', 'connect', 'face_to_face', 'interaction']
senticnet['interaction'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'suggest', 'hand_out', 'wedding_vow', 'request', 'distribute']
senticnet['intercept'] = [-0.536, 0, 0.884, -0.724, '#angry', '#disgusting', -0.715, 'bug', 'tap', 'wiretap', 'eavesdrop', 'listen']
senticnet['interchangeability'] = [0.53, -0.992, 0, 0.588, '#surprising', '#admirable', 0.703, 'transferability', 'convertibility', 'changeableness', 'changeability', 'permutability']
senticnet['interchangeableness'] = [0.994, -0.589, 0, 0.581, '#joyful', '#surprising', 0.721, 'transferability', 'convertibility', 'changeableness', 'changeability', 'permutability']
senticnet['intercommunicate'] = [0.63, -0.556, 0, 0.946, '#joyful', '#admirable', 0.711, 'complect', 'connect', 'link', 'link_up', 'join']
senticnet['interconnect'] = [0.822, -0.673, 0, 0.943, '#joyful', '#admirable', 0.813, 'intercommunicate', 'connect', 'link', 'link_up', 'join']
senticnet['interconnection'] = [-0.934, 0, 0.931, -0.964, '#sad', '#disgusting', -0.943, 'contact', 'coherence', 'coherency', 'concatenation', 'connectedness']
senticnet['intercourse'] = [0.082, 0, 0, 0, '#joyful', '#joyful', 0.027, 'find_mate', 'work_together', 'fuck', 'become_aroused', 'kiss_partner']
senticnet['interest'] = [0, 0.3, 0, 0, '#interesting', '#interesting', 0.1, 'finance', 'audit', 'bribe', 'fund', 'reward']
senticnet['interest_art'] = [0.539, 0.983, 0, 0.694, '#interesting', '#admirable', 0.739, 'want_entertain', 'see_actor', 'get_entertain', 'idolize_actor', 'experience_different_culture']
senticnet['interest_conversation'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'become_wise', 'interest_subject', 'interesting_topic', 'conversation', 'interest']
senticnet['interest_job'] = [0, 0.943, 0, 0, '#interesting', '#interesting', 0.314, 'know_new', 'gain_understand', 'become_wise', 'discover_new', 'know_world']
senticnet['interest_person'] = [0.962, 0, 0, 0, '#joyful', '#joyful', 0.321, 'cocktail_party', 'social_occasion', 'become_intoxicated', 'network', 'get_sex']
senticnet['interest_subject'] = [0.769, 0.526, 0, 0.845, '#joyful', '#admirable', 0.713, 'intrigue', 'desire_education', 'learn_much', 'gain_knowledge', 'add_knowledge']
senticnet['interesting'] = [0.566, -0.912, 0, 0.599, '#surprising', '#admirable', 0.692, 'intriguing', 'absorbing', 'engrossing', 'fascinating', 'gripping']
senticnet['interesting_show'] = [0.715, 0.717, 0, 0.813, '#interesting', '#admirable', 0.748, 'performance', 'show', 'skilled', 'play', 'great_performance']
senticnet['interesting_story'] = [0.801, 0.779, 0, 0, '#joyful', '#interesting', 0.527, 'child_book', 'good_story', 'something_to_tell', 'scholar', 'nice_ending']
senticnet['interesting_topic'] = [0.5, 0.747, 0, 0.959, '#interesting', '#admirable', 0.735, 'learn', 'desire_information', 'appear_smart', 'thirst_knowledge', 'seek_understanding']
senticnet['interestingness'] = [0.509, -0.678, 0, 0.707, '#surprising', '#admirable', 0.631, 'color', 'newsworthiness', 'shrillness', 'vividness', 'charisma']
senticnet['interfere'] = [-0.99, 0, 0.581, -0.97, '#sad', '#disgusting', -0.847, 'obstruct_justice', 'football_rule', 'block_road', 'hinder', 'obstruction']
senticnet['interference'] = [-0.811, 0, 0, -0.841, '#sad', '#disgusting', -0.551, 'complication', 'confusion', 'disturbance', 'distraction', 'interruption']
senticnet['interfering'] = [-0.997, 0, 0.851, -0.896, '#sad', '#disgusting', -0.915, 'intrusive', 'meddlesome', 'meddling', 'officious', 'busybodied']
senticnet['interior'] = [0, 0.128, -0.122, 0.183, '#interesting', '#admirable', 0.063, 'support_roof', 'furnish', 'ceiling', 'window_door', 'frame']
senticnet['interject'] = [-0.928, 0, 0.722, -0.555, '#sad', '#angry', -0.735, 'block', 'barge_in', 'jam', 'disrupt', 'throw_in']
senticnet['interjection'] = [0, 0.156, -0.067, 0.241, '#interesting', '#admirable', 0.11, 'mixture', 'noisy_place', 'make_go', 'move_vehicle', 'big_car']
senticnet['interleave'] = [0.865, -0.806, 0, 0.52, '#joyful', '#surprising', 0.73, 'set', 'pose', 'lay', 'intersperse', 'put']
senticnet['interlink'] = [0.916, -0.646, 0, 0.715, '#joyful', '#admirable', 0.759, 'intercommunicate', 'connect', 'link', 'link_up', 'join']
senticnet['interlocutor'] = [0.727, -0.622, 0, 0.57, '#joyful', '#surprising', 0.64, 'utterer', 'deipnosophist', 'conversationalist', 'conversational_partner', 'speaker']
senticnet['interloper'] = [-0.978, 0, 0.783, -0.601, '#sad', '#angry', -0.787, 'outsider', 'foreigner', 'intruder', 'stranger', 'trespasser']
senticnet['intermeshed'] = [0.59, -0.967, 0, 0.785, '#surprising', '#admirable', 0.781, 'enmeshed', 'tangled', 'rootbound', 'matted', 'knotty']
senticnet['intermission'] = [0, 0.904, 0, 0, '#interesting', '#interesting', 0.301, 'act', 'part_of_play', 'part_of_movie', 'emote', 'role']
senticnet['intermixture'] = [0.569, -0.807, 0, 0.801, '#surprising', '#admirable', 0.726, 'mincemeat', 'stuffing', 'dressing', 'roux', 'batter']
senticnet['intern'] = [0.932, 0.802, 0, 0, '#joyful', '#interesting', 0.578, 'paper_punch', 'memo_pad', 'white-out', 'paper_clip', 'self_adhesive_label']
senticnet['internal'] = [0, 0.89, 0, 0.719, '#interesting', '#admirable', 0.536, 'power_plant', 'radiation', 'fire_burn', 'chemical_process', 'combustion']
senticnet['internal_combustion'] = [-0.904, 0, 0.825, -0.61, '#sad', '#angry', -0.78, 'flaming', 'deflagration', 'fire', 'flame', 'combustion']
senticnet['internal_combustion_engine'] = [0, -0.035, 0.013, 0.095, '#surprising', '#admirable', 0.039, 'car', 'four_wheels', 'lorry', 'automobile', 'bus']
senticnet['internal_jugular_vein'] = [0.614, -0.89, 0, 0.51, '#joyful', '#surprising', 0.671, 'anterior_jugular_vein', 'external_jugular_vein', 'jugular', 'vein', 'vena']
senticnet['internal_organ'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'chest', 'artery', 'vein', 'blood_vessel', 'under_head']
senticnet['internal_representation'] = [0.693, -0.529, 0, 0.82, '#joyful', '#admirable', 0.681, 'embodiment', 'shape', 'representation', 'mental_representation', 'concrete_representation']
senticnet['internal_secretion'] = [0.672, -0.552, 0, 0.992, '#joyful', '#admirable', 0.739, 'pressor', 'hormone', 'endocrine', 'adrenalin', 'catecholamine']
senticnet['internality'] = [0.995, -0.731, 0, 0.83, '#joyful', '#admirable', 0.852, 'spiritism', 'otherworldliness', 'spirituality', 'spiritualism', 'introversion']
senticnet['internalization'] = [0.887, -0.989, 0, 0.611, '#joyful', '#surprising', 0.829, 'education', 'learning', 'incorporation', 'study', 'conditioning']
senticnet['international'] = [0.043, 0.109, 0, 0.061, '#interesting', '#admirable', 0.071, 'nation_state', 'democratic_country', 'free_country', 'large_country', 'republic']
senticnet['international_affair'] = [0.915, 0, 0.724, 0.952, '#joyful', '#admirable', 0.381, 'influence_worldwide', 'celebrate', 'olympic_game', 'world_event', 'magnificent']
senticnet['international_candle'] = [-0.639, 0, 0.897, -0.915, '#angry', '#disgusting', -0.817, 'cd-rom', 'candlepower_unit', 'candle', 'candela', 'standard_candle']
senticnet['international_highway'] = [0, 0, 0.024, -0.051, '#angry', '#disgusting', -0.025, 'toll_road', 'national_highway', 'superhighway', 'toll_highway', 'motorway']
senticnet['international_space_station'] = [0, 0.765, 0, 0.776, '#interesting', '#admirable', 0.514, 'tunnel', 'cavern', 'stick_wall', 'car_race', 'auction']
senticnet['internationalism'] = [0.946, -0.543, 0, 0.774, '#joyful', '#admirable', 0.754, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['internationality'] = [0.546, -0.965, 0, 0.914, '#surprising', '#admirable', 0.808, 'reach', 'range', 'compass', 'scope', 'orbit']
senticnet['internet'] = [-0.096, -0.036, 0.061, 0, '#sad', '#angry', -0.04, 'bad_reception', 'wifi', 'bad_connection', 'phone_call', 'underground']
senticnet['internet_cafe'] = [0.057, -0.038, 0, 0, '#joyful', '#surprising', 0.032, 'phone_booth', 'office_build', 'office', 'discount_store', 'observatory']
senticnet['internet_connection'] = [0.89, -0.616, 0, 0.757, '#joyful', '#admirable', 0.754, 'turn_computer_on', 'find_computer', 'find_address', 'go_online', 'buy_computer']
senticnet['internet_problem'] = [-0.957, 0, 0.549, -0.993, '#sad', '#disgusting', -0.833, 'bad_connection', 'bad_communication', 'bad_reception', 'absence_of_communication', 'underground']
senticnet['internet_site'] = [0.724, 0.771, 0, 0, '#joyful', '#interesting', 0.498, 'liquor_store', 'tavern', 'pub', 'bar', 'club']
senticnet['internet_user'] = [0, 0.82, 0, 0.834, '#interesting', '#admirable', 0.551, 'computer', 'engineer', 'user', 'computer_user', 'computer_software']
senticnet['interpenetration'] = [0.89, -0.621, 0, 0.548, '#joyful', '#surprising', 0.686, 'breakthrough', 'penetration', 'foray', 'maraud', 'raid']
senticnet['interpolation'] = [-0.551, 0, 0.965, -0.993, '#angry', '#disgusting', -0.836, 'interjection', 'delay', 'insert', 'interposition', 'disruption']
senticnet['interposition'] = [-0.551, 0, 0.965, -0.993, '#angry', '#disgusting', -0.836, 'interjection', 'delay', 'insert', 'disruption', 'interpolation']
senticnet['interpret'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'clarification', 'help_understand', 'ask_question', 'epiphany', 'share_opinion']
senticnet['interpretation'] = [-0.872, 0, 0.762, -0.921, '#sad', '#disgusting', -0.852, 'misreading', 'misconstrual', 'misconstruction', 'imbroglio', 'misinterpretation']
senticnet['interpretative_dance'] = [-0.954, 0, 0.992, -0.633, '#sad', '#angry', -0.86, 'interpretive_dance', 'interpretive_dancing', 'modern_dance', 'interpretative_dancing', 'stage_dancing']
senticnet['interpretative_dancing'] = [-0.954, 0, 0.992, -0.633, '#sad', '#angry', -0.86, 'interpretive_dance', 'interpretive_dancing', 'interpretative_dance', 'modern_dance', 'stage_dancing']
senticnet['interpreted'] = [0.632, -0.612, 0, 0.732, '#joyful', '#admirable', 0.659, 'appreciated', 'apprehended', 'comprehended', 'understood', 'taken']
senticnet['interpreter'] = [0, 0.202, -0.067, 0.291, '#interesting', '#admirable', 0.142, 'vocabulary', 'translate', 'dictionary', 'translation', 'thesaurus']
senticnet['interpretive_dance'] = [-0.954, 0, 0.992, -0.633, '#sad', '#angry', -0.86, 'modern_dance', 'interpretive_dancing', 'interpretative_dance', 'interpretative_dancing', 'stage_dancing']
senticnet['interpretive_dancing'] = [-0.954, 0, 0.992, -0.633, '#sad', '#angry', -0.86, 'interpretive_dance', 'modern_dance', 'interpretative_dance', 'interpretative_dancing', 'stage_dancing']
senticnet['interrogation'] = [-0.874, 0, 0.867, -0.771, '#sad', '#angry', -0.837, 'inquiry', 'exam', 'detention', 'prison', 'thief']
senticnet['interrogator'] = [-0.653, 0, 0.718, -0.732, '#angry', '#disgusting', -0.701, 'inquirer', 'enquirer', 'questioner', 'querier', 'asker']
senticnet['interrogatory'] = [-0.587, 0, 0.701, -0.979, '#angry', '#disgusting', -0.756, 'inquisition', 'interview', 'catechism', 'deposition', 'third_degree']
senticnet['interrupt'] = [-0.874, 0, 0.867, -0.771, '#sad', '#angry', -0.837, 'rude', 'misunderstanding', 'fight', 'look_eye', 'exchange_idea']
senticnet['interruption'] = [0, 0, 0, -0.786, '#disgusting', '#disgusting', -0.262, 'misunderstand', 'persuade', 'feel_strange', 'look_eye', 'keep_secret']
senticnet['interruption_movie'] = [-0.067, 0, 0.01, -0.079, '#sad', '#disgusting', -0.052, 'commercial', 'advertisement', 'watch_tv', 'watch_advertisement', 'watch_commercial']
senticnet['intersection'] = [0.032, 0.116, 0.016, 0, '#joyful', '#interesting', 0.044, 'curb', 'crossroad', 'ring_road', 'lane', 'interstate']
senticnet['intersperse'] = [0.865, -0.806, 0, 0.52, '#joyful', '#surprising', 0.73, 'set', 'pose', 'lay', 'interleave', 'put']
senticnet['interstate'] = [0.04, 0.07, 0, 0, '#joyful', '#interesting', 0.037, 'intersection', 'crossroad', 'parking_lot', 'expressway', 'traffic_artery']
senticnet['interval'] = [0, 0.827, 0, 0.9, '#interesting', '#admirable', 0.576, 'measurement', 'time_interval', 'length', 'time', 'spatial_dimension']
senticnet['interview'] = [0, 0.934, 0, 0.7, '#interesting', '#admirable', 0.545, 'reply', 'remark', 'interrogation', 'question', 'question_answer']
senticnet['interview_day'] = [0, 0.837, 0, 0.846, '#interesting', '#admirable', 0.561, 'talk', 'conversation', 'talk_far_away', 'human_communication', 'communicate']
senticnet['intestinal_flu'] = [-0.756, 0, 0.84, -0.633, '#sad', '#angry', -0.743, 'angina', 'gastroenteritis', 'stomach_flu', 'inflammatory_disease', 'pelvic_inflammatory_disease']
senticnet['intestine'] = [0, 0.717, 0, 0.914, '#interesting', '#admirable', 0.544, 'kidney', 'pancreas', 'liver', 'bone', 'neck']
senticnet['intimacy'] = [0.915, 0.755, 0, 0, '#joyful', '#interesting', 0.557, 'sympathetic', 'confidence', 'adoration', 'closeness', 'grateful']
senticnet['intimate'] = [0.742, 0, 0, 0.905, '#joyful', '#admirable', 0.549, 'wear', 'cover_leg', 'robe', 'make_fashion_statement', 'confidential']
senticnet['intimidate'] = [0, 0, 0.773, -0.888, '#angry', '#disgusting', -0.554, 'humiliate', 'desperate', 'terrible', 'hopeless', 'panic_attack']
senticnet['intimidated'] = [-0.955, 0, -0.821, 0, '#sad', '#scared', -0.592, 'timidly', 'shyly', 'timidity', 'bashfully', 'timorousness']
senticnet['intimidation'] = [0, 0, 0.914, -0.83, '#angry', '#disgusting', -0.581, 'disconcert', 'psychological_terror', 'abase', 'mortify', 'restiveness']
senticnet['intolerable'] = [-0.889, 0, 0.907, -0.847, '#sad', '#angry', -0.881, 'unsupportable', 'unacceptable', 'bitter', 'impossible', 'insufferable']
senticnet['intolerance'] = [-0.22, 0.087, -0.128, -0.221, '#sad', '#disgusting', -0.161, 'illiteracy', 'bigot', 'bad_word', 'kidnap', 'censorship']
senticnet['intolerant'] = [-0.721, 0, -0.825, -0.841, '#scared', '#disgusting', -0.796, 'racism', 'racist', 'xenophobic', 'antisemitism', 'nazism']
senticnet['intoxicant'] = [-0.831, 0, 0.647, -0.946, '#sad', '#disgusting', -0.808, 'hootch', 'pruno', 'alcohol', 'alcoholic_drink', 'alcoholic_beverage']
senticnet['intoxicate'] = [0, 0, 0.773, -0.888, '#angry', '#disgusting', -0.554, 'intoxication', 'inebriate', 'drunkenness', 'drunk', 'become_intoxicated']
senticnet['intoxication'] = [0, 0, -0.825, -0.812, '#scared', '#disgusting', -0.546, 'drunkenness', 'become_drunk', 'drunk', 'drink_beer', 'become_intoxicated']
senticnet['intractability'] = [-0.761, 0, 0.824, -0.868, '#angry', '#disgusting', -0.818, 'mulishness', 'unruliness', 'fractiousness', 'willfulness', 'against_rules']
senticnet['intractable'] = [-0.998, 0, 0.754, -0.503, '#sad', '#angry', -0.752, 'unmalleable', 'stubborn', 'refractory', 'uncontrollable', 'balking']
senticnet['intractableness'] = [-0.774, 0, 0.967, -0.752, '#sad', '#angry', -0.831, 'mulishness', 'unruliness', 'fractiousness', 'willfulness', 'against_rules']
senticnet['intransigence'] = [-0.813, 0, 0.62, -0.981, '#sad', '#disgusting', -0.805, 'stubbornness', 'obstinacy', 'obstinance', 'bullheadedness', 'pigheadedness']
senticnet['intransigency'] = [-0.75, 0, 0.851, -0.802, '#angry', '#disgusting', -0.801, 'stubbornness', 'obstinacy', 'obstinance', 'bullheadedness', 'pigheadedness']
senticnet['intransigent'] = [-0.806, 0, 0.507, -0.763, '#sad', '#disgusting', -0.692, 'adamant', 'inexorable', 'inflexible', 'ironclad', 'brassbound']
senticnet['intrepid'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'intrepidly', 'hardy', 'fearlessness', 'fearlessly', 'unafraid']
senticnet['intrepidity'] = [-0.948, 0, 0.745, -0.979, '#sad', '#disgusting', -0.891, 'nerve', 'fearlessness', 'heart', 'dauntlessness', 'braveness']
senticnet['intrepidly'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'hardy', 'fearlessness', 'fearlessly', 'unafraid', 'unfearing']
senticnet['intricacy'] = [0.632, -0.62, 0, 0.923, '#joyful', '#admirable', 0.725, 'quality', 'complexity', 'elaborateness', 'tapestry', 'complicatedness']
senticnet['intrigue'] = [0.945, 0.996, 0, 0.737, '#joyful', '#interesting', 0.893, 'become_intelligent', 'gain_knowledge', 'increase_knowledge', 'learn', 'desire_education']
senticnet['intriguing'] = [0.566, -0.912, 0, 0.599, '#surprising', '#admirable', 0.692, 'interesting', 'absorbing', 'engrossing', 'fascinating', 'gripping']
senticnet['intrinsic'] = [0.716, -0.627, 0, 0.896, '#joyful', '#admirable', 0.746, 'constitutional', 'integral', 'intimate', 'inner', 'inbuilt']
senticnet['intrinsical'] = [0.524, -0.627, 0, 0.624, '#surprising', '#admirable', 0.592, 'constitutional', 'integral', 'intimate', 'inner', 'inbuilt']
senticnet['introduce'] = [0, 0.946, 0, 0.849, '#interesting', '#admirable', 0.598, 'cope', 'farewell', 'incident', 'propose', 'welcome']
senticnet['introduce_oneself'] = [0.021, 0.093, -0.069, 0.119, '#interesting', '#admirable', 0.055, 'say_hello', 'end_conversation', 'ask_name', 'make_eye_contact', 'say_hi']
senticnet['introduction'] = [0.08, 0.153, -0.125, 0.224, '#interesting', '#admirable', 0.111, 'begin', 'edition', 'prologue', 'start_end', 'false_statement']
senticnet['introductory'] = [-0.569, 0, 0.954, -0.804, '#angry', '#disgusting', -0.776, 'previous', 'above', 'old', 'foregoing', 'preceding']
senticnet['introspection'] = [0.08, 0.153, -0.125, 0.224, '#interesting', '#admirable', 0.111, 'meditation', 'self_contemplation', 'soul_searching', 'self_examination', 'self_observation']
senticnet['introversion'] = [0.995, -0.731, 0, 0.83, '#joyful', '#admirable', 0.852, 'spiritism', 'otherworldliness', 'spirituality', 'spiritualism', 'internality']
senticnet['intrude'] = [-0.732, 0, 0.955, -0.725, '#sad', '#angry', -0.804, 'bother', 'barge_in', 'come_in', 'break_in', 'crash']
senticnet['intrude_on'] = [-0.756, 0, 0.699, -0.809, '#sad', '#disgusting', -0.755, 'raid', 'come_in', 'foray_into', 'enter', 'get_into']
senticnet['intruder'] = [-0.915, 0, 0.221, -0.917, '#sad', '#disgusting', -0.684, 'cheat', 'cheat_on', 'love_triangle', 'have_problem', 'heart_broken']
senticnet['intrusion'] = [-0.698, 0, 0.752, -0.82, '#angry', '#disgusting', -0.757, 'usurpation', 'trespass', 'encroachment', 'inroad', 'violation']
senticnet['intrusive'] = [-0.997, 0, 0.851, -0.896, '#sad', '#disgusting', -0.915, 'interfering', 'meddlesome', 'meddling', 'officious', 'busybodied']
senticnet['intrust'] = [0.546, -0.745, 0, 0.581, '#surprising', '#admirable', 0.624, 'hand', 'commend', 'reach', 'charge', 'give']
senticnet['intuit'] = [-0.523, 0, 0.65, -0.669, '#angry', '#disgusting', -0.614, 'compass', 'apprehend', 'grok', 'get_picture', 'savvy']
senticnet['intuition'] = [-0.04, 0.239, -0.093, 0.203, '#interesting', '#admirable', 0.103, 'make_happen', 'elbow_grease', 'accomplish', 'ask_nicely', 'lunch_break']
senticnet['intuitive'] = [0.649, -0.74, 0, 0.749, '#surprising', '#admirable', 0.713, 'absurd', 'inconsequential', 'illogical', 'visceral', 'nonrational']
senticnet['intumesce'] = [-0.763, 0, 0.656, -0.726, '#sad', '#disgusting', -0.715, 'tumefy', 'swell_up', 'tumesce', 'belly_out', 'swell']
senticnet['intumescence'] = [-0.697, 0, 0.517, -0.619, '#sad', '#disgusting', -0.611, 'hematoma', 'haematoma', 'puffiness', 'swelling', 'lump']
senticnet['intumescency'] = [-0.568, 0, 0.641, -0.95, '#angry', '#disgusting', -0.72, 'hematoma', 'haematoma', 'puffiness', 'swelling', 'lump']
senticnet['inundation'] = [-0.86, 0, 0.503, -0.654, '#sad', '#disgusting', -0.672, 'large_indefinite_quantity', 'large_indefinite_amount', 'deluge', 'flood', 'spate']
senticnet['inured'] = [0.641, -0.577, 0, 0.707, '#joyful', '#admirable', 0.642, 'enured', 'toughened', 'thickened', 'calloused', 'callous']
senticnet['inutility'] = [0.909, -0.731, 0, 0.635, '#joyful', '#surprising', 0.758, 'quality', 'futility', 'impracticality', 'worthlessness', 'impracticability']
senticnet['invade'] = [-0.068, 0, -0.109, -0.185, '#scared', '#disgusting', -0.121, 'go_war', 'ready_troop', 'combat', 'use_military', 'attack_enemy']
senticnet['invader'] = [0.028, 0, 0.026, 0.102, '#joyful', '#admirable', 0.035, 'heavy_object', 'keep_out', 'metal_bar', 'small_room', 'door_handle']
senticnet['invalid'] = [-0.74, 0, 0.991, -0.641, '#sad', '#angry', -0.791, 'unfortunate', 'dyspeptic', 'diseased_person', 'psychoneurotic', 'psychotic']
senticnet['invalidate'] = [-0.594, 0, 0.612, -0.797, '#angry', '#disgusting', -0.668, 'stet', 'set_aside', 'break', 'cancel', 'strike_down']
senticnet['invalidism'] = [-0.932, 0, 0.75, -0.845, '#sad', '#disgusting', -0.842, 'unhealthiness', 'injury', 'affliction', 'biliousness', 'harm']
senticnet['invalidity'] = [-0.551, 0, 0.741, -0.768, '#angry', '#disgusting', -0.687, 'illogicality', 'illogicalness', 'illogic', 'inconsequence', 'fallaciousness']
senticnet['invalidness'] = [-0.685, 0, 0.812, -0.792, '#angry', '#disgusting', -0.763, 'illogicality', 'illogicalness', 'illogic', 'inconsequence', 'fallaciousness']
senticnet['invariability'] = [-0.833, 0, 0.757, -0.655, '#sad', '#angry', -0.748, 'unvariedness', 'invariableness', 'invariance', 'sameness', 'monotony']
senticnet['invariableness'] = [-0.938, 0, 0.749, -0.684, '#sad', '#angry', -0.79, 'unvariedness', 'changelessness', 'unchangeability', 'unchangeableness', 'unchangingness']
senticnet['invariance'] = [-0.756, 0, 0.679, -0.779, '#sad', '#disgusting', -0.738, 'unvariedness', 'changelessness', 'unchangeability', 'unchangeableness', 'unchangingness']
senticnet['invasion'] = [0.849, -0.547, 0, 0.543, '#joyful', '#surprising', 0.646, 'diffusion', 'dispersion', 'scattering', 'spread', 'irradiation']
senticnet['invective'] = [-0.895, 0, 0.955, -0.949, '#angry', '#disgusting', -0.933, 'abuse', 'vilification', 'insult', 'revilement', 'contumely']
senticnet['inveigh'] = [-0.646, 0, 0.663, -0.54, '#sad', '#angry', -0.616, 'quetch', 'kvetch', 'complain', 'sound_off', 'plain']
senticnet['inveigle'] = [0, 0, -0.951, -0.739, '#scared', '#disgusting', -0.563, 'wheedle', 'palaver', 'cajole', 'coax', 'blarney']
senticnet['invent'] = [0.542, -0.609, 0, 0.757, '#surprising', '#admirable', 0.636, 'fabricate', 'manufacture', 'cook_up', 'confabulate', 'make_up']
senticnet['invent_20th_century'] = [0.703, 0.972, 0, 0, '#joyful', '#interesting', 0.558, 'listen_tape', 'study_library', 'guess_answer', 'solve_equation', 'point_out']
senticnet['invention'] = [-0.039, 0.201, -0.137, 0.171, '#interesting', '#admirable', 0.065, 'scientific_statement', 'hypothetical', 'conjecture', 'theory', 'fact']
senticnet['inventiveness'] = [-0.841, 0, 0.741, -0.543, '#sad', '#angry', -0.708, 'resourcefulness', 'imagination', 'creativity', 'creativeness', 'creative_thinking']
senticnet['inventor'] = [0.891, 0.721, 0, 0.921, '#joyful', '#admirable', 0.844, 'expert', 'connoisseur', 'medical_doctor', 'teacher', 'judge']
senticnet['inverse'] = [0.506, -0.567, 0, 0.788, '#surprising', '#admirable', 0.62, 'backward', 'reverse', 'retrograde', 'reflexive', 'retral']
senticnet['inversion'] = [0.807, -0.88, 0, 0.718, '#joyful', '#surprising', 0.802, 'sex', 'gayness', 'sexual_gayness', 'lesbianism', 'sapphism']
senticnet['invertebrate'] = [-0.79, 0, 0.709, -0.854, '#sad', '#disgusting', -0.784, 'animal', 'animate_being', 'ctenophore', 'comb_jelly', 'beast']
senticnet['inverted'] = [-0.652, 0, 0.935, -0.846, '#angry', '#disgusting', -0.811, 'upset', 'turned', 'overturned', 'upturned', 'reversed']
senticnet['invest'] = [-0.077, 0.202, -0.067, 0.164, '#interesting', '#admirable', 0.074, 'transaction', 'give_back', 'exchange_money', 'exchange_goods', 'cash_check']
senticnet['invest_money'] = [0, 0.766, 0, 0.881, '#interesting', '#admirable', 0.549, 'bank_money', 'hold_coin', 'lend_money', 'vault', 'bank_loan']
senticnet['investigate'] = [-0.146, 0, 0, -0.05, '#sad', '#disgusting', -0.065, 'look_fact', 'investigate_fact', 'ask_many_questions', 'think_through', 'ask_question']
senticnet['investigate_fact'] = [-0.242, -0.055, -0.118, -0.096, '#sad', '#scared', -0.134, 'say_eureka', 'think_logically', 'look_fact', 'ask_question', 'research_subject']
senticnet['investigating'] = [0.809, -0.719, 0, 0.708, '#joyful', '#surprising', 0.745, 'tally', 'numeration', 'tap', 'scrutiny', 'testing']
senticnet['investigation'] = [-0.201, 0.129, -0.175, 0.065, '#sad', '#scared', -0.061, 'look_fact', 'deduce', 'say_eureka', 'investigate_fact', 'rational']
senticnet['investigator'] = [0.846, -0.755, 0, 0.69, '#joyful', '#surprising', 0.764, 'experimenter', 'boffin', 'fieldworker', 'postdoc', 'post_doc']
senticnet['investment'] = [0, 0.312, -0.107, 0.207, '#interesting', '#admirable', 0.137, 'business_term', 'loan', 'lend', 'increase_money', 'wealth']
senticnet['investment_return'] = [0, 0.371, -0.133, 0.226, '#interesting', '#admirable', 0.155, 'monetary_gain', 'money_earn', 'financial_gain', 'gain_money', 'extra_money']
senticnet['investor'] = [0, 0.076, 0, 0, '#interesting', '#interesting', 0.025, 'person', 'alive', 'human_being', 'young_man', 'gardener']
senticnet['invigilate'] = [0.585, -0.644, 0, 0.51, '#joyful', '#surprising', 0.58, 'watch_over', 'keep_an_eye_on', 'watch', 'observe', 'follow']
senticnet['invigorate'] = [-0.893, 0, -0.896, 0, '#sad', '#scared', -0.596, 'fall_asleep', 'doze_off', 'drowsiness', 'alter_state_consciousness', 'feel_little_tired']
senticnet['invigorated'] = [0.516, -0.936, 0, 0.802, '#surprising', '#admirable', 0.751, 'rested', 'refreshed', 'rerested', 'untired', 'unwearied']
senticnet['invigorating'] = [0.843, -0.818, 0, 0.624, '#joyful', '#surprising', 0.762, 'exhilarating', 'animating', 'enlivening', 'refreshing', 'restorative']
senticnet['invigoration'] = [0.868, -0.911, 0, 0.862, '#joyful', '#surprising', 0.88, 'chirpiness', 'spirit', 'sprightliness', 'liveliness', 'activity']
senticnet['invigorator'] = [0.962, -0.898, 0, 0.855, '#joyful', '#surprising', 0.905, 'infectious_agent', 'infective_agent', 'satisfier', 'quickener', 'agent']
senticnet['inviolable'] = [0.982, -0.945, 0, 0, '#joyful', '#surprising', 0.642, 'infrangible', 'nontransferable', 'unassignable', 'untransferable', 'inalienable']
senticnet['invisible'] = [-0.519, 0, 0.979, -0.89, '#angry', '#disgusting', -0.796, 'occult', 'concealed', 'nonvisual', 'hidden', 'out_of_sight']
senticnet['invitation'] = [0, 0.852, 0, 0, '#interesting', '#interesting', 0.284, 'streamer', 'tribute', 'salutation', 'gift', 'anniversary_gift']
senticnet['invitation_response'] = [-0.475, 0.169, -0.551, 0.399, '#sad', '#scared', -0.153, 'invitation', 'request', 'tell_why', 'circus_performer', 'show_how']
senticnet['invite'] = [0.06, 0, 0.014, 0.089, '#joyful', '#admirable', 0.045, 'social_skill', 'socialize', 'get_word_out', 'charisma', 'tell_name']
senticnet['invite_dinner'] = [0.867, -0.903, 0, 0, '#joyful', '#surprising', 0.59, 'get_know', 'chat', 'mental_health', 'converse', 'stay_touch']
senticnet['invite_friend'] = [0, 0.709, 0, 0, '#interesting', '#interesting', 0.236, 'buy_drink', 'drink_beer', 'serve_beer', 'pay_tab', 'throw_away_trash']
senticnet['invite_friend_over'] = [0, 0.74, 0, 0, '#interesting', '#interesting', 0.247, 'invite_guest', 'clean_apartment', 'make_joke', 'call_up', 'invite_friend']
senticnet['invite_guest'] = [0, 0, 0, 0.713, '#admirable', '#admirable', 0.238, 'invite_person', 'invite_friend_over', 'buy_dinner', 'put_napkin_lap', 'wrap_up']
senticnet['invite_person'] = [0, 0.71, 0, 0.799, '#interesting', '#admirable', 0.503, 'invite_guest', 'wage_slave', 'make_profit', 'meet_need', 'buy_cheese']
senticnet['invocation'] = [-0.829, 0, 0.72, -0.535, '#sad', '#angry', -0.695, 'conjuration', 'charm', 'spell', 'magic_spell', 'magical_spell']
senticnet['invoice'] = [0, 0.248, -0.073, 0.121, '#interesting', '#admirable', 0.099, 'bill', 'mastercard', 'yellowstone', 'expense', 'owe']
senticnet['involuntariness'] = [-0.638, 0, 0.584, -0.542, '#sad', '#angry', -0.588, 'resistance', 'disinclination', 'indisposition', 'temperament', 'hesitancy']
senticnet['involuntary'] = [-0.052, 0.122, -0.121, 0.129, '#interesting', '#admirable', 0.026, 'bad_odor', 'smell_odor', 'inhale', 'whine', 'blow_nose']
senticnet['involute'] = [0.612, -0.536, 0, 0.532, '#joyful', '#surprising', 0.56, 'convoluted', 'convolute', 'coiled', 'rolled', 'wound']
senticnet['involutional_depression'] = [-0.786, 0, 0.918, -0.963, '#angry', '#disgusting', -0.889, 'unipolar_depression', 'depression', 'depressive_disorder', 'clinical_depression', 'major_depressive_episode']
senticnet['involve'] = [0.026, 0.202, -0.115, 0.165, '#interesting', '#admirable', 0.093, 'upgrade', 'help_find', 'band_together', 'proposition', 'tell_everyone']
senticnet['involvement'] = [0.692, -0.992, 0, 0.614, '#joyful', '#surprising', 0.766, 'intimacy', 'affaire', 'liaison', 'affair', 'sexual_relationship']
senticnet['invulnerable'] = [0.631, -0.589, 0, 0.914, '#joyful', '#admirable', 0.711, 'defendable', 'defensible', 'impregnable', 'secure', 'bombproof']
senticnet['invunerable'] = [0, 0, 0, 0.816, '#admirable', '#admirable', 0.272, 'resitence', 'protection', 'untouchable', 'immunity', 'sacrosanct']
senticnet['inwardness'] = [0.888, -0.505, 0, 0.506, '#joyful', '#admirable', 0.633, 'content', 'quintessence', 'stuff', 'bare_bones', 'hypostasis']
senticnet['iodine'] = [-0.03, 0, 0, -0.085, '#sad', '#disgusting', -0.038, 'lithium', 'mineral', 'potassium', 'magnesium', 'manganese']
senticnet['ionizing_radiation'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'alpha_radiation', 'alpha_ray', 'beta_radiation', 'beta_ray', 'electron_radiation']
senticnet['ipecac'] = [-0.62, 0, 0.983, -0.897, '#angry', '#disgusting', -0.833, 'remedy', 'cure', 'therapeutic', 'curative', 'emetic']
senticnet['ipod'] = [0.159, -0.005, 0.011, 0.079, '#joyful', '#admirable', 0.077, 'ceiling_fan', 'kitchenette', 'technologic', 'formula', 'music']
senticnet['irascibility'] = [-0.124, 0.13, 0.646, -0.64, '#angry', '#disgusting', -0.427, 'quick_temper', 'short_temper', 'irascible', 'choleric', 'ill_temper']
senticnet['irascible'] = [-0.124, 0.13, 0.646, -0.64, '#angry', '#disgusting', -0.427, 'irascibility', 'quick_temper', 'short_temper', 'choleric', 'ill_temper']
senticnet['ire'] = [-0.161, 0.179, 0.568, -0.612, '#angry', '#disgusting', -0.387, 'angrily', 'choler', 'see_red', 'dander', 'hackles']
senticnet['irish_bull'] = [-0.96, 0, 0.812, -0.698, '#sad', '#angry', -0.823, 'rot', 'bunk', 'bunkum', 'buncombe', 'guff']
senticnet['irksome'] = [-0.661, 0, 0.594, -0.675, '#sad', '#disgusting', -0.643, 'boring', 'deadening', 'uninteresting', 'tiresome', 'wearisome']
senticnet['iron'] = [0.706, -0.941, 0, 0.622, '#joyful', '#surprising', 0.756, 'alloy_cast_iron', 'alloy_cast_cast_iron', 'pot_metal', 'cast_iron', 'atomic_number_26']
senticnet['iron_boot'] = [-0.67, 0, 0.85, -0.599, '#sad', '#angry', -0.706, 'rack', 'boot', 'whip', 'instrument_of_torture', 'iron_heel']
senticnet['iron_clothes'] = [0, 0.799, 0, 0, '#interesting', '#interesting', 0.266, 'absorb_moisture', 'sit_on_beach', 'clothes', 'shine_shoes', 'iron_shirt']
senticnet['iron_curtain'] = [-0.765, 0, 0.692, -0.845, '#sad', '#disgusting', -0.767, 'ideological_barrier', 'bamboo_curtain', 'color_bar', 'color_line', 'barrier']
senticnet['iron_heel'] = [-0.67, 0, 0.85, -0.599, '#sad', '#angry', -0.706, 'rack', 'boot', 'whip', 'iron_boot', 'instrument_of_torture']
senticnet['iron_mold'] = [-0.518, 0, 0.937, -0.926, '#angry', '#disgusting', -0.794, 'bloodstain', 'mud_stain', 'discoloration', 'iron_mould', 'oil_stain']
senticnet['iron_mould'] = [-0.518, 0, 0.937, -0.926, '#angry', '#disgusting', -0.794, 'bloodstain', 'mud_stain', 'iron_mold', 'discoloration', 'oil_stain']
senticnet['iron_ore'] = [0.102, 0.078, 0, 0.087, '#joyful', '#admirable', 0.089, 'gold', 'platinum', 'adjustable', 'silver', 'magnetic']
senticnet['iron_shirt'] = [-0.088, 0, 0, 0, '#sad', '#sad', -0.029, 'absorb_moisture', 'sit_on_beach', 'clothes', 'iron_clothes', 'shine_shoes']
senticnet['ironclad'] = [-0.806, 0, 0.507, -0.763, '#sad', '#disgusting', -0.692, 'adamant', 'inexorable', 'intransigent', 'inflexible', 'brassbound']
senticnet['irony'] = [0, 0.917, 0, 0.865, '#interesting', '#admirable', 0.594, 'oat', 'white_rice', 'grain', 'wheat', 'granule']
senticnet['irradiate'] = [0.927, -0.896, 0, 0.604, '#joyful', '#surprising', 0.809, 'vaticinate', 'call', 'enlighten', 'prophesy', 'predict']
senticnet['irradiation'] = [0.789, -0.817, 0, 0.591, '#joyful', '#surprising', 0.732, 'radiotherapy', 'radiation_therapy', 'radiation', 'actinotherapy', 'phototherapy']
senticnet['irrational'] = [0, 0, 0.712, -0.924, '#angry', '#disgusting', -0.545, 'nice', 'good', 'lovely', 'niceness', 'hard_find']
senticnet['irrational_hostility'] = [-0.79, 0, 0.627, -0.816, '#sad', '#disgusting', -0.744, 'taboo', 'tabu', 'tendentiousness', 'bias', 'experimenter_bias']
senticnet['irrational_impulse'] = [0.864, -0.743, 0, 0.978, '#joyful', '#admirable', 0.862, 'passion', 'irrational_motive', 'compulsion', 'motivation', 'need']
senticnet['irrational_motive'] = [0.864, -0.743, 0, 0.978, '#joyful', '#admirable', 0.862, 'passion', 'irrational_impulse', 'compulsion', 'motivation', 'need']
senticnet['irreality'] = [-0.947, 0, 0.925, -0.979, '#sad', '#disgusting', -0.95, 'nonexistence', 'nonentity', 'cloud', 'falseness', 'falsity']
senticnet['irrefutable'] = [0.943, 0.936, 0, 0, '#joyful', '#interesting', 0.626, 'undeniable', 'incontestable', 'incontrovertible', 'indisputable', 'questionable']
senticnet['irregular'] = [-0.583, 0, 0.814, -0.54, '#sad', '#angry', -0.646, 'atypical', 'abnormal', 'vicarious', 'supernormal', 'subnormal']
senticnet['irregularity'] = [-0.596, 0, 0.672, -0.831, '#angry', '#disgusting', -0.7, 'geometrical_asymmetry', 'radial_asymmetry', 'lopsidedness', 'skewness', 'asymmetry']
senticnet['irrelevant'] = [-0.868, 0, 0.894, -0.72, '#sad', '#angry', -0.827, 'inapplicable', 'unsuitable', 'immaterial', 'extraneous', 'orthogonal']
senticnet['irreligious'] = [-0.932, 0, 0.75, -0.645, '#sad', '#angry', -0.776, 'heathen', 'heathenish', 'pagan', 'lapsed', 'nonchurchgoing']
senticnet['irreligiousness'] = [0.905, -0.802, 0, 0.583, '#joyful', '#surprising', 0.763, 'unrighteousness', 'undutifulness', 'godlessness', 'ungodliness', 'impiety']
senticnet['irreplaceableness'] = [-0.568, 0, 0.574, -0.695, '#angry', '#disgusting', -0.612, 'incommutability', 'unexchangeability', 'changelessness', 'unchangeability', 'unchangeableness']
senticnet['irrepressibility'] = [0.546, -0.732, 0, 0.583, '#surprising', '#admirable', 0.62, 'sprightliness', 'spiritedness', 'brio', 'bright', 'delicacy']
senticnet['irrepressible'] = [-0.891, 0, 0.678, -0.62, '#sad', '#angry', -0.73, 'undisciplined', 'anarchic', 'anarchical', 'uncontrolled', 'uncontrollable']
senticnet['irreproducibility'] = [-0.922, 0, 0.546, -0.523, '#sad', '#angry', -0.664, 'irresponsibility', 'irresponsibleness', 'instability', 'undependability', 'fallibility']
senticnet['irresoluteness'] = [-0.526, 0, 0.959, -0.701, '#angry', '#disgusting', -0.729, 'unpredictability', 'indecisiveness', 'indecision', 'trait', 'volatility']
senticnet['irresolution'] = [-0.893, 0, 0.565, -0.76, '#sad', '#disgusting', -0.739, 'hesitation', 'uncertainty', 'doubt', 'incertitude', 'dubiety']
senticnet['irresponsibility'] = [-0.613, 0, 0.516, -0.965, '#sad', '#disgusting', -0.698, 'untrustworthiness', 'untrustiness', 'undependability', 'undependableness', 'unreliability']
senticnet['irresponsible'] = [0, 0, 0.739, -0.927, '#angry', '#disgusting', -0.555, 'freewheeling', 'carefree', 'slaphappy', 'unaccountable', 'loose']
senticnet['irresponsibleness'] = [-0.775, 0, 0.688, -0.529, '#sad', '#angry', -0.664, 'untrustworthiness', 'untrustiness', 'undependability', 'undependableness', 'unreliability']
senticnet['irreverence'] = [-0.522, 0, 0.621, -0.919, '#angry', '#disgusting', -0.687, 'deviltry', 'devilry', 'iniquity', 'foul_play', 'sexual_immorality']
senticnet['irreverent'] = [0.615, -0.572, 0, 0.502, '#joyful', '#surprising', 0.563, 'aweless', 'awless', 'disrespectful', 'sacrilegious', 'blasphemous']
senticnet['irritability'] = [-0.908, 0, 0.647, -0.578, '#sad', '#angry', -0.711, 'ill_humor', 'distemper', 'pet', 'testiness', 'touchiness']
senticnet['irritable'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'bad_tempered', 'nervous', 'neurasthenic', 'cranky', 'testy']
senticnet['irritant'] = [-0.531, 0, 0.86, -0.657, '#angry', '#disgusting', -0.683, 'pain_in_ass', 'pain', 'pain_in_neck', 'annoyance', 'bother']
senticnet['irritate'] = [-0.129, 0, 0.688, -0.681, '#angry', '#disgusting', -0.499, 'offend', 'bothersome', 'pique', 'disgust', 'frustrating']
senticnet['irritated'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['irritating'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['irritation'] = [0, 0, 0.868, -0.98, '#angry', '#disgusting', -0.616, 'annoyance', 'bother', 'irritate', 'mad', 'offend']
senticnet['irrupt'] = [-0.664, 0, 0.982, -0.937, '#angry', '#disgusting', -0.861, 'bother', 'barge_in', 'come_in', 'break_in', 'crash']
senticnet['irruption'] = [-0.506, 0, 0.975, -0.865, '#angry', '#disgusting', -0.782, 'entrance', 'entering', 'entry', 'ingress', 'incoming']
senticnet['islam'] = [0.076, 0.316, -0.182, 0.262, '#interesting', '#admirable', 0.157, 'obey_god', 'dogma', 'evangelist', 'faith', 'believe']
senticnet['island'] = [0, 0.112, 0, 0.137, '#interesting', '#admirable', 0.083, 'near_ocean', 'popular_vacation_destination', 'land_feature', 'ocean_shore', 'oceanside']
senticnet['ism'] = [0.95, -0.772, 0, 0.578, '#joyful', '#surprising', 0.767, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'amoralism']
senticnet['isolate'] = [-0.813, 0, 0, -0.771, '#sad', '#disgusting', -0.528, 'bad_choice', 'treatable', 'wrong', 'anguish', 'mock']
senticnet['isolated'] = [-0.091, 0.156, 0.661, -0.656, '#angry', '#disgusting', -0.417, 'detached', 'set-apart', 'separated', 'distasteful', 'loathly']
senticnet['isolation'] = [-0.165, 0.135, 0.637, -0.69, '#angry', '#disgusting', -0.452, 'scorn', 'wicked', 'dislike', 'set-apart', 'separated']
senticnet['issue'] = [0.648, -0.873, 0, 0.597, '#joyful', '#surprising', 0.706, 'gut_issue', 'content', 'paramount_issue', 'pocketbook_issue', 'quodlibet']
senticnet['italian'] = [0.041, 0, 0, 0.121, '#joyful', '#admirable', 0.054, 'spanish', 'rhetoric', 'idiom', 'syllable', 'language']
senticnet['italian_cuisine'] = [0.06, -0.012, 0, 0, '#joyful', '#surprising', 0.024, 'eat_food', 'restaurant', 'meal', 'slow_food', 'italian_restaurant']
senticnet['italian_dinner'] = [0.974, 0.789, 0, 0.828, '#joyful', '#admirable', 0.864, 'eat_hamburger', 'eat_quickly', 'eat_well', 'eat_apple', 'eat_breakfast']
senticnet['italian_food'] = [0.061, 0.07, -0.056, 0.073, '#interesting', '#admirable', 0.049, 'expensive_food', 'eat_food', 'fine_dining', 'caviar', 'lobster']
senticnet['italian_restaurant'] = [0.068, 0.066, 0.011, -0.034, '#joyful', '#interesting', 0.03, 'trattoria', 'eat_pizza', 'pizzeria', 'restaurant_diner', 'eatery']
senticnet['italic'] = [-0.958, 0, 0.517, -0.536, '#sad', '#disgusting', -0.67, 'copperplate', 'hand', 'minuscule', 'cursive', 'round_hand']
senticnet['itch'] = [0, 0, 0.891, -0.839, '#angry', '#disgusting', -0.577, 'rash', 'scratch', 'measles', 'skin_irritation', 'nip']
senticnet['itchiness'] = [0, -0.042, 0.063, -0.122, '#angry', '#disgusting', -0.048, 'animal_hair', 'scratchy', 'softness', 'fuzzy', 'fur']
senticnet['itching'] = [-0.773, 0, 0.895, -0.733, '#sad', '#angry', -0.8, 'itch', 'urtication', 'itchiness', 'cutaneous_sensation', 'tickle']
senticnet['itchy'] = [0, 0, 0.955, -0.863, '#angry', '#disgusting', -0.606, 'pall', 'dreadful', 'afraid', 'disquiet', 'fright']
senticnet['itchy_skin'] = [-0.968, 0, 0.108, -0.908, '#sad', '#disgusting', -0.661, 'poisonous_fly', 'dangerous_insect', 'dangerous_fly', 'dangerous_animal', 'poisonous']
senticnet['item'] = [0, 0.814, 0, 0.926, '#interesting', '#admirable', 0.58, 'object', 'mass_measure', 'liquid_measurement', 'measure_unit', 'unit']
senticnet['item_clothes'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'formal_clothes', 'woman_clothes', 'girl_clothes', 'woman_garment', 'frilly']
senticnet['item_sell'] = [0, 0.14, 0.028, 0.157, '#interesting', '#admirable', 0.09, 'type_of_store', 'place_buy', 'many_shops', 'sell_stuff', 'math_answer']
senticnet['item_value'] = [-0.031, 0.257, 0, 0.155, '#interesting', '#admirable', 0.127, 'item_worth', 'amount_due', 'value_amount', 'sticker', 'amount_money']
senticnet['item_worth'] = [-0.027, 0.256, 0, 0.166, '#interesting', '#admirable', 0.132, 'item_value', 'like_cost', 'like_price', 'sticker', 'value_amount']
senticnet['ivory'] = [0.085, -0.063, 0, 0, '#joyful', '#surprising', 0.049, 'soap', 'drizzle', 'bubbly', 'solid_water', 'foam']
senticnet['ivy'] = [-0.055, 0, 0, -0.071, '#sad', '#disgusting', -0.042, 'vine', 'green_color', 'green_leave', 'evergreen_tree', 'large_plant']
senticnet['jab'] = [0, 0.77, 0, 0.857, '#interesting', '#admirable', 0.542, 'bell_sound', 'bell_noise', 'piece_of_jewelry', 'syllable', 'fastener']
senticnet['jabot'] = [0.522, -0.824, 0, 0.568, '#surprising', '#admirable', 0.638, 'adornment', 'goffer', 'gauffer', 'ruffle', 'peplum']
senticnet['jacket'] = [-0.027, 0.256, 0, 0.166, '#interesting', '#admirable', 0.132, 'coat', 'shirt', 'garment', 'dress', 'vest']
senticnet['jacking_off'] = [0.89, -0.646, 0, 0.765, '#joyful', '#admirable', 0.767, 'wank', 'frottage', 'masturbation', 'jerking_off', 'hand_job']
senticnet['jackknife'] = [0.818, -0.956, 0, 0.695, '#joyful', '#surprising', 0.823, 'pocket_knife', 'clasp_knife', 'penknife', 'switchblade', 'switchblade_knife']
senticnet['jactitation'] = [-0.887, 0, 0.666, -0.901, '#sad', '#disgusting', -0.818, 'crow', 'crowing', 'bluster', 'bragging', 'vaporing']
senticnet['jade'] = [-0.91, 0, 0.594, -0.531, '#sad', '#angry', -0.678, 'fatigue', 'wear', 'fag', 'tire', 'overfatigue']
senticnet['jag'] = [0, 0, 0.868, -0.991, '#angry', '#disgusting', -0.62, 'sharp_nail', 'sharp', 'sharp_end', 'sharp_point', 'pointy']
senticnet['jaggedness'] = [-0.535, 0, 0.765, -0.942, '#angry', '#disgusting', -0.747, 'unevenness', 'unregularity', 'ruggedness', 'irregularity', 'patchiness']
senticnet['jail'] = [-0.029, 0, -0.092, -0.069, '#scared', '#disgusting', -0.063, 'crack_house', 'prison', 'memorial', 'bowl_alley', 'homeless_shelter']
senticnet['jail_time'] = [-0.735, 0, -0.779, -0.778, '#scared', '#disgusting', -0.764, 'go_to_prison', 'go_jail', 'injustice', 'incarceration', 'send_to_jail']
senticnet['jailbird'] = [0, 0, -0.734, -0.81, '#scared', '#disgusting', -0.515, 'captive', 'prisoner', 'imprisoned', 'convict', 'inmate']
senticnet['jailhouse'] = [0.92, -0.989, 0, 0.776, '#joyful', '#surprising', 0.895, 'lockup', 'holding_cell', 'workhouse', 'bastille', 'hoosegow']
senticnet['jalopy'] = [-0.991, 0, 0.597, -0.547, '#sad', '#angry', -0.712, 'dysphemism', 'car', 'auto', 'automobile', 'machine']
senticnet['jam'] = [-0.61, 0, 0.513, -0.976, '#sad', '#disgusting', -0.7, 'conserve', 'preserve', 'strawberry_jam', 'strawberry_preserves', 'conserves']
senticnet['janitor'] = [0, 0, -0.091, 0, '#scared', '#scared', -0.03, 'specialist', 'truck_driver', 'egalitarian', 'public_servant', 'pioneer']
senticnet['japanese'] = [0.029, 0, 0.011, 0.109, '#joyful', '#admirable', 0.042, 'talkative', 'no_fun', 'verbal', 'discourse', 'orate']
senticnet['japanese_beetle'] = [0, -0.092, 0.119, -0.119, '#angry', '#disgusting', -0.049, 'cucumber_beetle', 'mole_cricket', 'gypsy_moth', 'earwig', 'mosquito']
senticnet['japanese_food'] = [0.958, 0.866, 0, 0, '#joyful', '#interesting', 0.608, 'form_of_food', 'after_lunch', 'food_item', 'raw_fish', 'food']
senticnet['japanese_person'] = [0, 0.068, -0.065, 0.081, '#interesting', '#admirable', 0.028, 'pyramid', 'buckle', 'mexican_restaurant', 'anemone', 'herringbone']
senticnet['jape'] = [0.771, -0.925, 0, 0.696, '#joyful', '#surprising', 0.797, 'humor', 'wow', 'funny', 'dirty_joke', 'dirty_story']
senticnet['japery'] = [0.742, -0.613, 0, 0.924, '#joyful', '#admirable', 0.76, 'folly', 'lunacy', 'craziness', 'indulgence', 'shtik']
senticnet['jar'] = [0.035, -0.015, 0.009, 0.063, '#joyful', '#admirable', 0.035, 'container', 'carton', 'contain', 'hold_cupcake', 'store_dish']
senticnet['jar_against'] = [-0.548, 0, 0.746, -0.544, '#sad', '#angry', -0.613, 'run_into', 'strike', 'hit', 'impinge_on', 'collide_with']
senticnet['jargon'] = [-0.043, -0.021, 0.041, -0.039, '#sad', '#angry', -0.034, 'slang', 'lingo', 'cant', 'chatspeak', 'unusual_language']
senticnet['jarring'] = [-0.937, 0, 0.576, -0.545, '#sad', '#angry', -0.686, 'grating', 'rasping', 'raspy', 'cacophonic', 'gruff']
senticnet['jaundice'] = [-0.566, 0, 0.906, -0.807, '#angry', '#disgusting', -0.76, 'jaundice_of_newborn', 'disease', 'icterus_neonatorum', 'kernicterus', 'symptom']
senticnet['jaundice_of_newborn'] = [-0.647, 0, 0.903, -0.634, '#sad', '#angry', -0.728, 'icterus', 'disease', 'icterus_neonatorum', 'kernicterus', 'symptom']
senticnet['jaundiced'] = [-0.81, 0, 0, -0.947, '#sad', '#disgusting', -0.586, 'homophobic', 'racist', 'discriminatory', 'antiblack', 'unhealthy']
senticnet['jaunt'] = [0, 0, 0.904, -0.804, '#angry', '#disgusting', -0.569, 'outing', 'junket', 'pleasure_trip', 'excursion', 'expedition']
senticnet['jauntiness'] = [0.973, -0.509, 0, 0.612, '#joyful', '#admirable', 0.698, 'chic', 'chicness', 'chichi', 'modishness', 'stylishness']
senticnet['jaunty'] = [0, 0, -0.815, -0.768, '#scared', '#disgusting', -0.528, 'dashing', 'raffish', 'rakish', 'natty', 'dapper']
senticnet['java'] = [0.041, 0.098, 0, 0, '#joyful', '#interesting', 0.046, 'utopia', 'emporium', 'memorial', 'nowhere', 'coffee']
senticnet['jaw'] = [0, -0.026, 0.033, -0.089, '#angry', '#disgusting', -0.032, 'tooth', 'teeth', 'dimple', 'mouth', 'cliche']
senticnet['jawbone'] = [0.651, -0.929, 0, 0.657, '#surprising', '#admirable', 0.746, 'schmooze', 'schmoose', 'shmooze', 'shmoose', 'chew_fat']
senticnet['jawless_fish'] = [-0.542, 0, 0.992, -0.872, '#angry', '#disgusting', -0.802, 'hag', 'osteostracan', 'cephalaspid', 'ostracoderm', 'heterostracan']
senticnet['jawless_vertebrate'] = [-0.786, 0, 0.745, -0.516, '#sad', '#angry', -0.682, 'hag', 'osteostracan', 'cephalaspid', 'ostracoderm', 'heterostracan']
senticnet['jay'] = [0.039, 0.089, -0.081, 0.143, '#interesting', '#admirable', 0.063, 'hen', 'nightingale', 'stork', 'bird', 'rooster']
senticnet['jazz'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'music', 'vapor', 'blues', 'megrim', 'demoralization']
senticnet['jazz_around'] = [0.697, -0.835, 0, 0.911, '#surprising', '#admirable', 0.814, 'range', 'ramble', 'vagabond', 'tramp', 'roam']
senticnet['jazz_club'] = [-0.048, -0.037, -0.047, -0.043, '#sad', '#scared', -0.034, 'country_band', 'bluegrass_band', 'music_class', 'string_quartet', 'music_store']
senticnet['jazz_up'] = [0.513, -0.647, 0, 0.776, '#surprising', '#admirable', 0.645, 'enliven', 'liven', 'liven_up', 'invigorate', 'animate']
senticnet['jealous'] = [0, 0, 0.911, -0.738, '#angry', '#disgusting', -0.55, 'green-eyed', 'green-eyed_monster', 'overjealous', 'avaricious', 'grabby']
senticnet['jealously'] = [0.089, 0.09, 0.81, -0.682, '#angry', '#disgusting', -0.438, 'covetous', 'envious', 'enviously', 'covetously', 'green-eyed']
senticnet['jealousy'] = [0, 0, 0.794, -0.992, '#angry', '#disgusting', -0.595, 'envy', 'resentment', 'grudge', 'greedy', 'jealous']
senticnet['jeans'] = [0, -0.051, 0.088, -0.078, '#angry', '#disgusting', -0.038, 'clothes', 'pair_of_pants', 'shirt', 'slack', 'jacket']
senticnet['jeep'] = [0.75, -0.596, 0, 0.633, '#joyful', '#admirable', 0.66, 'car', 'auto', 'automobile', 'machine', 'motorcar']
senticnet['jeer'] = [-0.732, 0, 0.865, -0.878, '#angry', '#disgusting', -0.825, 'bad_surprise', 'shout', 'abrupt', 'rude', 'mocking']
senticnet['jejuneness'] = [-0.938, 0, 0.906, -0.539, '#sad', '#angry', -0.794, 'juvenility', 'state', 'greenness', 'callowness', 'immatureness']
senticnet['jello'] = [0, 0, -0.1, -0.028, '#scared', '#disgusting', -0.043, 'icebox', 'bottle', 'toothbrush_bristle', 'tan_lotion', 'refrigerator']
senticnet['jelly'] = [0.708, -0.934, 0, 0.764, '#surprising', '#admirable', 0.802, 'dainty', 'delicacy', 'treat', 'gelatin_dessert', 'aspic']
senticnet['jelly_bean'] = [0.027, -0.095, 0, 0, '#joyful', '#surprising', 0.041, 'cookie', 'pudding', 'custard', 'candy', 'muffin']
senticnet['jelly_fish'] = [0, 0, 0.021, -0.053, '#angry', '#disgusting', -0.025, 'driftwood', 'tidal_wave', 'seashell', 'titanic', 'dead_fish']
senticnet['jeopardize'] = [-0.516, 0, 0.92, -0.669, '#angry', '#disgusting', -0.702, 'hazard', 'stake', 'lay_on_line', 'essay', 'assay']
senticnet['jeopardy'] = [-0.955, 0, -0.989, 0, '#sad', '#scared', -0.648, 'question', 'answer', 'question_answering', 'inquiry', 'outcome']
senticnet['jerk'] = [-0.781, 0, 0.726, -0.935, '#sad', '#disgusting', -0.814, 'smile_child', 'child', 'pass_gene', 'young_child', 'dolt']
senticnet['jerk_off'] = [-0.056, 0, -0.068, -0.042, '#sad', '#scared', -0.055, 'masturbate', 'jerk', 'wank', 'die_only_once', 'fight_other']
senticnet['jerking_off'] = [0.89, -0.646, 0, 0.765, '#joyful', '#admirable', 0.767, 'wank', 'frottage', 'jacking_off', 'masturbation', 'hand_job']
senticnet['jerky'] = [-0.569, 0, 0.849, -0.618, '#angry', '#disgusting', -0.679, 'convulsive', 'arrhythmic', 'unsteady', 'spasmodic', 'spastic']
senticnet['jerusalem'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'vatican', 'jewish_community', 'large_city', 'big_city', 'major_city']
senticnet['jest'] = [0.891, -0.6, 0, 0.854, '#joyful', '#admirable', 0.782, 'humor', 'wow', 'funny', 'dirty_joke', 'dirty_story']
senticnet['jester'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'witty_remark', 'cross_talking', 'swordplay', 'wordplay', 'banter']
senticnet['jesus_christ'] = [0.059, 0.234, -0.055, 0.222, '#interesting', '#admirable', 0.153, 'almighty', 'deity', 'nobility', 'omniscient', 'lord']
senticnet['jesus_crucify'] = [-0.833, 0, 0, -0.761, '#sad', '#disgusting', -0.531, 'religious_icon', 'faith', 'religious', 'christian', 'bless']
senticnet['jet'] = [0, -0.806, 0, 0.902, '#surprising', '#admirable', 0.569, 'airplane', 'aeroplane', 'plane', 'aircraft', 'pilot']
senticnet['jet_black'] = [-0.604, 0, 0.895, -0.541, '#sad', '#angry', -0.68, 'coal_black', 'black', 'pitch_black', 'soot_black', 'achromatic_color']
senticnet['jet_fuel'] = [0.937, 0, 0, 0.849, '#joyful', '#admirable', 0.595, 'ticket_counter', 'newspaper_stand', 'luggage_carrier', 'aircraft_roadway', 'timetable']
senticnet['jet_lag'] = [-0.996, 0, 0.986, -0.945, '#sad', '#angry', -0.976, 'travel', 'bad_rest', 'feel_sleepy', 'tired', 'long_trip']
senticnet['jetty'] = [0, -0.777, 0, 0.705, '#surprising', '#admirable', 0.494, 'big_breadbox', 'water_vehicle', 'military_ship', 'ship', 'small_boat']
senticnet['jew'] = [0, -0.009, -0.093, -0.069, '#scared', '#disgusting', -0.051, 'hot_chick', 'atheist', 'computer_user', 'fastener_binder', 'monitor']
senticnet['jew_harp'] = [0.063, 0.089, 0.036, 0.146, '#interesting', '#admirable', 0.087, 'horn', 'antler', 'brass_instrument', 'trumpet', 'crash_cymbal']
senticnet['jewel'] = [0, -0.939, 0, 0.896, '#surprising', '#admirable', 0.612, 'gem', 'expensive_stone', 'precious_stone', 'precious_gem', 'jewelry']
senticnet['jeweled_headdress'] = [-0.626, 0, 0.961, -0.544, '#sad', '#angry', -0.71, 'crown', 'diadem', 'tiara', 'headdress', 'headgear']
senticnet['jewelled_headdress'] = [-0.738, 0, 0.764, -0.538, '#sad', '#angry', -0.68, 'crown', 'diadem', 'tiara', 'headdress', 'headgear']
senticnet['jewellery'] = [0.532, -0.604, 0, 0.875, '#surprising', '#admirable', 0.67, 'gem', 'adornment', 'jewel', 'bead', 'bangle']
senticnet['jewelry'] = [0.656, -0.547, 0, 0.879, '#joyful', '#admirable', 0.694, 'gem', 'adornment', 'jewel', 'bead', 'bangle']
senticnet['jewelry_box'] = [0, 0.177, 0, 0.126, '#interesting', '#admirable', 0.101, 'treasure', 'storage_facility', 'shrine', 'lock_box', 'treasure_chest']
senticnet['jewelry_store'] = [0, 0.133, 0, 0, '#interesting', '#interesting', 0.044, 'card_deck', 'hold_change', 'bank_account', 'coffer', 'wallet']
senticnet['jewish'] = [0.033, 0.335, -0.064, 0.27, '#interesting', '#admirable', 0.191, 'protestant', 'sect', 'christian', 'religious', 'prayer']
senticnet['jewish_community'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'book_story', 'bed', 'seduce', 'fond_memory', 'suburbs']
senticnet['jibe'] = [0.948, 0, 0, 0.998, '#joyful', '#admirable', 0.649, 'ask', 'tell_why', 'permission', 'consent', 'say_yes']
senticnet['jiggle'] = [-0.988, 0, -0.719, 0, '#sad', '#scared', -0.569, 'vibrate', 'convulse', 'tremble', 'back_forth', 'turn_around']
senticnet['jimdandy'] = [0.839, -0.634, 0, 0.83, '#joyful', '#admirable', 0.768, 'nonesuch', 'nonsuch', 'ideal', 'nonpareil', 'apotheosis']
senticnet['jimhickey'] = [0.658, -0.507, 0, 0.667, '#joyful', '#admirable', 0.611, 'nonesuch', 'nonsuch', 'ideal', 'nonpareil', 'apotheosis']
senticnet['jingle'] = [0.163, 0, 0.013, 0.166, '#joyful', '#admirable', 0.105, 'clang', 'chord', 'song', 'rhapsody', 'hymn']
senticnet['jingles'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'holiday', 'big_christmas_tree', 'tree', 'festive_season', 'christmas']
senticnet['jingoism'] = [0.68, -0.962, 0, 0.597, '#joyful', '#surprising', 0.746, 'flag_waving', 'demagoguery', 'appeal', 'prayer', 'entreaty']
senticnet['jingoistic'] = [0.585, -0.7, 0, 0.586, '#surprising', '#admirable', 0.624, 'patriotic', 'ultranationalistic', 'superpatriotic', 'nationalistic', 'chauvinistic']
senticnet['jinks'] = [-0.85, 0, 0.691, -0.821, '#sad', '#disgusting', -0.787, 'jollification', 'high_jollification', 'hijollification', 'high_jinx', 'revel']
senticnet['jinx'] = [0.521, -0.552, 0, 0.657, '#surprising', '#admirable', 0.577, 'bewitch', 'enchant', 'becharm', 'hex', 'witch']
senticnet['jitterbug'] = [0, -0.884, 0, 0.894, '#surprising', '#admirable', 0.593, 'polka', 'trapeze', 'twist', 'flea', 'mosquito']
senticnet['jitteriness'] = [-0.777, 0, -0.884, 0, '#sad', '#scared', -0.554, 'restiveness', 'jumpiness', 'restive', 'nervy', 'jumpy']
senticnet['jitters'] = [-0.085, 0.097, -0.107, -0.103, '#scared', '#disgusting', -0.066, 'rewind', 'hear_funny', 'view_movie', 'see_film', 'use_remote_control']
senticnet['jittery'] = [-0.937, 0, -0.751, 0, '#sad', '#scared', -0.563, 'high-strung', 'uptight', 'restive', 'overstrung', 'nervy']
senticnet['job'] = [0.907, 0, 0, 0.79, '#joyful', '#admirable', 0.566, 'get_accomplish_done', 'task', 'hard_work', 'accomplish', 'find_accomplish']
senticnet['job_action'] = [-0.772, 0, 0.505, -0.503, '#sad', '#angry', -0.593, 'wildcat_strike', 'sympathy_strike', 'sympathetic_strike', 'walkout', 'work_stoppage']
senticnet['job_application'] = [0, 0, 0, 0.075, '#admirable', '#admirable', 0.025, 'application', 'resume', 'respond', 'questionnaire', 'help_understand']
senticnet['job_done'] = [0, 0.183, 0, 0.078, '#interesting', '#admirable', 0.087, 'mediator', 'arbitrator', 'decide_case', 'make_judgment', 'judgment']
senticnet['job_interview_failed'] = [-0.966, 0, 0.414, -0.94, '#sad', '#disgusting', -0.773, 'bad_feeling', 'exam_failed', 'feel_terrible', 'trouble', 'problem']
senticnet['job_offer'] = [-0.023, 0.107, 0, 0.159, '#interesting', '#admirable', 0.081, 'ask_person', 'overprice', 'hire', 'hire_help', 'job']
senticnet['job_pay'] = [-0.053, 0.242, -0.089, 0.113, '#interesting', '#admirable', 0.071, 'money_earn', 'work_for_money', 'monthly_due', 'earnings', 'money_pay']
senticnet['jockey'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'control_horse', 'lead_ropes', 'horse', 'sprinter', 'saddle']
senticnet['jockey_club'] = [0.967, -0.982, 0, 0.64, '#joyful', '#surprising', 0.863, 'club', 'social_club', 'society', 'guild', 'gild']
senticnet['jockeying'] = [-0.836, 0, 0.76, 0, '#sad', '#angry', -0.532, 'cheat', 'chouse', 'screw', 'shaft', 'chicane']
senticnet['jocularity'] = [0.699, 0.622, -0.232, 0.322, '#joyful', '#interesting', 0.47, 'jocundity', 'hilariously', 'screaming', 'hilarious', 'gleefulness']
senticnet['jocund'] = [0.715, 0.617, -0.23, 0.329, '#joyful', '#interesting', 0.477, 'mirthful', 'jovial', 'jolly', 'joviality', 'banter']
senticnet['jocundity'] = [0.699, 0.622, -0.232, 0.322, '#joyful', '#interesting', 0.47, 'jocularity', 'hilariously', 'screaming', 'hilarious', 'gleefulness']
senticnet['jogger'] = [0.1, 0, 0, 0, '#joyful', '#joyful', 0.033, 'bench', 'park_bench', 'stool', 'bar', 'oak']
senticnet['jogging'] = [0, 0.144, -0.079, 0.222, '#interesting', '#admirable', 0.096, 'shoe', 'wear_shoes', 'put_shoes', 'put_on_shoes', 'sport']
senticnet['join'] = [0.12, 0.131, -0.118, 0.257, '#interesting', '#admirable', 0.13, 'come_together', 'connect', 'bring_together', 'gather', 'assemble']
senticnet['join_army'] = [0, -0.983, 0, 0.807, '#surprising', '#admirable', 0.597, 'advance_battle', 'fight_war', 'fight_enemy', 'wage_war', 'storm_fortress']
senticnet['join_band'] = [0.867, 0.949, 0, 0, '#joyful', '#interesting', 0.605, 'join', 'play_in_band', 'play_tune', 'band', 'play_music']
senticnet['join_club'] = [0, 0.148, 0, 0.084, '#interesting', '#admirable', 0.077, 'reply_question', 'laugh_oneself', 'walk_school', 'needy', 'receive_email']
senticnet['join_gym'] = [-0.062, 0, -0.059, 0, '#sad', '#scared', -0.04, 'go_gym', 'check_doctor', 'workout', 'lift_weight', 'eat_balance_diet']
senticnet['join_military'] = [-0.087, 0, -0.062, -0.184, '#sad', '#disgusting', -0.111, 'buy_weapon', 'arm_oneself', 'buy_gun', 'prepare_army', 'declare_war']
senticnet['join_navy'] = [0, 0.988, 0, 0.78, '#interesting', '#admirable', 0.589, 'bloodshed', 'attack', 'conflict', 'violence', 'fire_weapon']
senticnet['join_party'] = [0, 0.719, 0, 0.75, '#interesting', '#admirable', 0.49, 'laugh', 'enjoy_show', 'join', 'become_excited', 'laughter']
senticnet['join_team'] = [0.753, -0.839, 0, 0, '#joyful', '#surprising', 0.531, 'buy_ball', 'form_team', 'gather_team', 'learn_rule', 'find_other_player']
senticnet['join_together'] = [0.136, 0, -0.126, 0.231, '#joyful', '#admirable', 0.08, 'special', 'fuse_together', 'merge', 'event', 'occurrence']
senticnet['joint'] = [0.023, 0.085, -0.045, 0.088, '#interesting', '#admirable', 0.05, 'thigh', 'femur', 'above_leg', 'hip', 'knee']
senticnet['joint_venture'] = [0.59, -0.757, 0, 0.543, '#joyful', '#surprising', 0.63, 'venture', 'sally', 'labor', 'cause', 'risk']
senticnet['joke'] = [0.867, 0.949, 0, 0, '#joyful', '#interesting', 0.605, 'tell_funny_joke', 'tell_joke', 'funny_joke', 'jest', 'witticism']
senticnet['joke_around'] = [0.756, 0.944, 0, 0, '#joyful', '#interesting', 0.567, 'get_laid', 'see_friend', 'social_occasion', 'get_close', 'great_time']
senticnet['joker'] = [-0.918, 0, -0.899, 0, '#sad', '#scared', -0.606, 'demon', 'fool', 'cannibalism', 'jolly', 'treachery']
senticnet['jolity'] = [0.699, 0.62, -0.23, 0.323, '#joyful', '#interesting', 0.471, 'jolliness', 'joviality', 'josh', 'chaff', 'banter']
senticnet['jollification'] = [-0.85, 0, 0.691, -0.821, '#sad', '#disgusting', -0.787, 'jinks', 'high_jinks', 'hijinks', 'high_jinx', 'revel']
senticnet['jolliness'] = [0.699, 0.62, -0.23, 0.323, '#joyful', '#interesting', 0.471, 'joviality', 'jolity', 'josh', 'chaff', 'banter']
senticnet['jolly'] = [0.71, 0.618, -0.23, 0.327, '#joyful', '#interesting', 0.475, 'jovial', 'jocund', 'mirthful', 'joviality', 'jolity']
senticnet['jolly_along'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerfully', 'cheerful', 'jolly_up', 'hearten', 'chirk_up']
senticnet['jolly_up'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerfully', 'cheerful', 'hearten', 'chirk_up', 'embolden']
senticnet['jolt'] = [-0.732, 0, 0.865, -0.878, '#angry', '#disgusting', -0.825, 'shock', 'shake', 'abrupt', 'electric_shock', 'damage']
senticnet['jonah'] = [-0.676, 0, 0.838, -0.86, '#angry', '#disgusting', -0.791, 'unsuccessful_person', 'loser', 'abandoned_person', 'desperate', 'unfortunate']
senticnet['jorum'] = [-0.519, 0, 0.562, -0.699, '#angry', '#disgusting', -0.593, 'fishbowl', 'fish_bowl', 'goldfish_bowl', 'bowl', 'mazer']
senticnet['josh'] = [0.699, 0.62, -0.23, 0.323, '#joyful', '#interesting', 0.471, 'jolliness', 'joviality', 'jolity', 'chaff', 'banter']
senticnet['jostle'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'push', 'ram', 'barge', 'bang', 'shove_around']
senticnet['jot'] = [0, 0.074, 0.026, 0.105, '#interesting', '#admirable', 0.051, 'handwritten', 'scribble', 'music_part', 'written_message', 'calligraphy']
senticnet['jot_down_idea'] = [-0.069, 0, 0.029, -0.048, '#sad', '#disgusting', -0.049, 'make_note', 'write_note', 'make_mark_paper', 'jot_down_note', 'leave_message']
senticnet['jot_down_note'] = [-0.111, -0.043, 0, -0.196, '#sad', '#disgusting', -0.088, 'learn_new_idea', 'study_library', 'pop_up', 'listen_lecture', 'remember_information']
senticnet['journal'] = [0, 0.103, 0, 0.057, '#interesting', '#admirable', 0.053, 'tale', 'narrative', 'print_material', 'small_book', 'newspaper_story']
senticnet['journalism'] = [0, 0.78, 0, 0.839, '#interesting', '#admirable', 0.54, 'cnn', 'weather_prediction', 'daily', 'tv_program', 'journalist']
senticnet['journalist'] = [-0.183, 0.081, -0.187, 0, '#sad', '#scared', -0.096, 'world_event', 'type_of_paper', 'give_info', 'cnn', 'national_event']
senticnet['journey'] = [0, 0.954, 0, 0.702, '#interesting', '#admirable', 0.552, 'quest', 'stunt', 'illusion', 'adventure', 'activity']
senticnet['journey_far'] = [-0.104, 0, 0, -0.05, '#sad', '#disgusting', -0.051, 'free_bird', 'bug_person', 'near_destination', 'fly_around', 'weather_storm']
senticnet['journeyman'] = [0.633, -0.502, 0, 0.59, '#joyful', '#admirable', 0.575, 'craftsman', 'manicurist', 'artisan', 'beautician', 'artificer']
senticnet['jovial'] = [0.715, 0.617, -0.23, 0.329, '#joyful', '#interesting', 0.477, 'jocund', 'mirthful', 'jolly', 'joviality', 'banter']
senticnet['joviality'] = [0.699, 0.62, -0.23, 0.323, '#joyful', '#interesting', 0.471, 'jolliness', 'jolity', 'josh', 'chaff', 'banter']
senticnet['jowl'] = [0.886, -0.997, 0, 0.542, '#joyful', '#surprising', 0.808, 'lantern_jaw', 'lower_jaw', 'mandible', 'mandibula', 'mandibular_bone']
senticnet['joy'] = [0.6, 0, 0, 0, '#joyful', '#joyful', 0.2, 'elation', 'glad', 'satisfaction', 'happy', 'euphoria']
senticnet['joyful'] = [0.95, 0.797, 0, 0.711, '#joyful', '#interesting', 0.819, 'pleased', 'happily', 'merrily', 'mirthfully', 'gayly']
senticnet['joyfully'] = [0.593, 0.647, -0.238, 0.272, '#joyful', '#interesting', 0.425, 'joyously', 'gleefully', 'joyousness', 'joyfulness', 'bonheur']
senticnet['joyfulness'] = [0.593, 0.647, -0.238, 0.272, '#joyful', '#interesting', 0.425, 'joyfully', 'joyously', 'gleefully', 'joyousness', 'bonheur']
senticnet['joyless'] = [-0.742, 0.292, -0.428, -0.064, '#sad', '#scared', -0.314, 'joylessly', 'joylessness', 'dolefulness', 'uncheerful', 'depressing']
senticnet['joylessly'] = [-0.742, 0.292, -0.428, -0.064, '#sad', '#scared', -0.314, 'joyless', 'joylessness', 'dolefulness', 'uncheerful', 'depressing']
senticnet['joylessness'] = [-0.742, 0.292, -0.428, -0.064, '#sad', '#scared', -0.314, 'joyless', 'joylessly', 'dolefulness', 'uncheerful', 'depressing']
senticnet['joyous'] = [0.729, 0, 0, 0.721, '#joyful', '#admirable', 0.483, 'joyful', 'ecstatic', 'rapturous', 'happy', 'jolly']
senticnet['joyously'] = [0.593, 0.647, -0.238, 0.272, '#joyful', '#interesting', 0.425, 'joyfully', 'gleefully', 'joyousness', 'joyfulness', 'bonheur']
senticnet['joyousness'] = [0.593, 0.647, -0.238, 0.272, '#joyful', '#interesting', 0.425, 'joyfully', 'joyously', 'gleefully', 'joyfulness', 'bonheur']
senticnet['jubilance'] = [0.673, 0.631, -0.233, 0.309, '#joyful', '#interesting', 0.46, 'exultingly', 'on_cloud_nine', 'exultation', 'feel_happy', 'walk_on_air']
senticnet['jubilant'] = [0.705, 0.623, -0.228, 0.319, '#joyful', '#interesting', 0.473, 'wallow', 'jubilate', 'exuberant', 'contented', 'exult']
senticnet['jubilantly'] = [0.653, 0.635, -0.244, 0.294, '#joyful', '#interesting', 0.446, 'merrily', 'happily', 'mirthfully', 'gayly', 'blithely']
senticnet['jubilate'] = [0.694, 0.626, -0.231, 0.317, '#joyful', '#interesting', 0.469, 'exuberant', 'exult', 'unworried', 'carefree', 'lightsomeness']
senticnet['jubilation'] = [0.839, 0.838, 0, 0.919, '#joyful', '#admirable', 0.865, 'glee', 'joyful', 'gratify', 'rejoice', 'merrily']
senticnet['judaism'] = [-0.023, 0.283, 0, 0.266, '#interesting', '#admirable', 0.175, 'christianity', 'confessional', 'religious_purpose', 'catholic_church', 'prayer']
senticnet['judge'] = [0, 0.091, 0, 0.064, '#interesting', '#admirable', 0.052, 'juror', 'see_justice_done', 'negotiator', 'arbiter', 'member_jury']
senticnet['judge_decide'] = [-0.088, 0, 0, 0, '#sad', '#sad', -0.029, 'win_case', 'hire_attorney', 'win', 'flip_coin', 'try_win']
senticnet['judge_decision'] = [-0.285, 0.091, -0.243, 0.12, '#sad', '#scared', -0.106, 'bad_behavior', 'retribution', 'consequence', 'bad_action', 'difficulty']
senticnet['judge_jury'] = [0, 0.123, 0, 0.086, '#interesting', '#admirable', 0.07, 'judicial_system', 'gavel', 'arbiter', 'negotiator', 'trial']
senticnet['judge_person'] = [0, 0.192, -0.09, 0.105, '#interesting', '#admirable', 0.069, 'arrest_criminal', 'settle_argument', 'make_judgment', 'consider_fact', 'tell_truth']
senticnet['judgment'] = [0, 0, 0, -0.902, '#disgusting', '#disgusting', -0.301, 'pass_judgment', 'justice', 'decide_case', 'trial', 'determine_guilt_innocence']
senticnet['judicial_system'] = [0, 0.108, 0, 0.066, '#interesting', '#admirable', 0.058, 'judge_jury', 'negotiator', 'trial', 'juror', 'punish_criminal']
senticnet['judiciary'] = [0.952, -0.844, 0, 0.875, '#joyful', '#admirable', 0.89, 'administration', 'governance', 'governing_body', 'establishment', 'brass']
senticnet['judicious'] = [0.625, -0.88, 0, 0.782, '#surprising', '#admirable', 0.762, 'prudent', 'discreet', 'prudential', 'heady', 'circumspect']
senticnet['judiciousness'] = [0.968, -0.878, 0, 0.992, '#joyful', '#admirable', 0.946, 'sagacity', 'sagaciousness', 'care', 'caution', 'discernment']
senticnet['judo'] = [0, 0.108, 0, 0.066, '#interesting', '#admirable', 0.058, 'sport', 'martial_art', 'gymnastics', 'athletics', 'karate']
senticnet['jug_band'] = [-0.507, 0, 0.902, -0.548, '#angry', '#disgusting', -0.652, 'gamelan', 'ensemble', 'pop_group', 'mariachi', 'skiffle_group']
senticnet['jugde'] = [-0.751, 0, -0.857, 0, '#sad', '#scared', -0.536, 'close_case', 'bang_gavel', 'verdict', 'make_judgment', 'give_verdict']
senticnet['juggle'] = [0, 0.931, 0, 0, '#interesting', '#interesting', 0.31, 'football', 'rake_leave', 'spray_paint_grafitti', 'smoke_marijuana', 'play_hide_seek']
senticnet['juggler'] = [0, 0.841, 0, 0.786, '#interesting', '#admirable', 0.542, 'stunt', 'swing', 'juggle', 'heap', 'represent']
senticnet['jugglery'] = [0.623, -0.689, 0, 0.975, '#surprising', '#admirable', 0.762, 'guile', 'trickery', 'chicanery', 'wile', 'shenanigan']
senticnet['jugular'] = [0.614, -0.89, 0, 0.51, '#joyful', '#surprising', 0.671, 'anterior_jugular_vein', 'external_jugular_vein', 'internal_jugular_vein', 'vein', 'vena']
senticnet['juice'] = [0.068, 0, 0, 0, '#joyful', '#joyful', 0.023, 'soft_drink', 'apple_juice', 'cola', 'grape_juice', 'ice_tea']
senticnet['juice_up'] = [0.756, -0.531, 0, 0.523, '#joyful', '#surprising', 0.603, 'enliven', 'liven', 'liven_up', 'invigorate', 'animate']
senticnet['juicy'] = [0.041, 0.069, 0.032, 0.13, '#interesting', '#admirable', 0.069, 'edible_human', 'round_fruit', 'peelable', 'green_fruit', 'nutritious']
senticnet['juju'] = [0.667, -0.869, 0, 0.884, '#surprising', '#admirable', 0.807, 'fetish', 'good_luck_charm', 'object', 'voodoo', 'fetich']
senticnet['juke'] = [-0.825, 0, 0.739, -0.509, '#sad', '#angry', -0.691, 'fake', 'feint', 'maneuver', 'manoeuvre', 'tactical_maneuver']
senticnet['july_fourth'] = [0.927, 0.926, 0, 0, '#joyful', '#interesting', 0.618, 'good_band', 'country_band', 'rock_band', 'band', 'bluegrass_band']
senticnet['jumble'] = [-0.441, -0.138, -0.08, -0.407, '#sad', '#disgusting', -0.263, 'disorder', 'untidy', 'mess', 'heap', 'chaos']
senticnet['jump'] = [-0.057, 0.066, 0, 0.079, '#interesting', '#admirable', 0.029, 'skip', 'jump_high', 'float_through_air', 'jump_over', 'bail_water']
senticnet['jump_air'] = [0, 0, -0.818, -0.716, '#scared', '#disgusting', -0.511, 'mistreat', 'attempt_fly', 'pick_berry', 'eat_worm', 'white_bird']
senticnet['jump_around'] = [0.14, -0.052, 0, 0.092, '#joyful', '#admirable', 0.095, 'swirl', 'relate_music', 'sway', 'dance_move', 'waltz']
senticnet['jump_chance'] = [0.742, 0.995, 0, 0.747, '#interesting', '#admirable', 0.828, 'score_home_run', 'win_game', 'reach_advantage', 'home_run', 'compete_against']
senticnet['jump_fence'] = [-0.994, 0, -0.815, 0, '#sad', '#scared', -0.603, 'jump', 'think_food', 'jump_air', 'jump_high', 'cause_accident']
senticnet['jump_for_joy'] = [0.673, 0.631, -0.233, 0.309, '#joyful', '#interesting', 0.46, 'exultingly', 'on_cloud_nine', 'exultation', 'jubilance', 'happiness']
senticnet['jump_high'] = [-0.955, 0, -0.812, 0, '#sad', '#scared', -0.589, 'jump', 'think_food', 'jump_air', 'jump_fence', 'cause_accident']
senticnet['jump_in_water'] = [-0.032, 0, 0.044, 0, '#sad', '#angry', -0.025, 'put_bath_suit', 'go_water', 'go_pool', 'go_swim_pool', 'know_how_swim']
senticnet['jump_into_water'] = [-0.04, 0.069, 0, 0.075, '#interesting', '#admirable', 0.035, 'go_to_swimming_pool', 'scuba', 'learn_swimming', 'scuba_gear', 'enjoy_nature']
senticnet['jump_jack'] = [-0.049, -0.033, 0.066, 0, '#sad', '#angry', -0.027, 'train_hard', 'enter_marathon', 'fitter', 'strain_muscle', 'expend_energy']
senticnet['jump_off_bridge'] = [-0.077, 0, -0.171, -0.059, '#sad', '#scared', -0.102, 'feel_relieved', 'feel_relief', 'breasigh_relief', 'act_foolish', 'act_silly']
senticnet['jump_off_cliff'] = [0, 0, -0.841, -0.808, '#scared', '#disgusting', -0.55, 'apnea', 'drug_addiction', 'eat_poison', 'drunk_drive', 'execute']
senticnet['jump_out'] = [0, 0, -0.88, -0.788, '#scared', '#disgusting', -0.556, 'surprise_friend', 'show_emotion', 'unexpected', 'blow_out_candle', 'type_of_party']
senticnet['jump_out_of_bridge'] = [0, -0.004, -0.081, -0.085, '#scared', '#disgusting', -0.054, 'lose_consciousness', 'get_involved_in_accident', 'go_coma', 'bungee_jump_high_bridge', 'heart_attack']
senticnet['jump_out_of_window'] = [0, 0, -0.942, -0.811, '#scared', '#disgusting', -0.584, 'get_involved_in_accident', 'bungee_jump_from_high_bridge', 'jump_off_cliff', 'climb_mountain', 'apnea']
senticnet['jump_over'] = [-0.051, 0.199, -0.051, 0.243, '#interesting', '#admirable', 0.113, 'flee', 'jump', 'jump_up', 'step_out', 'skip']
senticnet['jump_over_fence'] = [0, 0, 0, -0.758, '#disgusting', '#disgusting', -0.253, 'live_underground', 'many_different_colors', 'tame', 'eat_rat', 'growl']
senticnet['jump_over_obstacle'] = [0.042, 0.088, 0, 0, '#joyful', '#interesting', 0.043, 'attempt_fly', 'chick', 'aircraft', 'pilot', 'wings']
senticnet['jump_rope'] = [0.925, 0.993, 0, 0.832, '#joyful', '#interesting', 0.917, 'karaoke', 'dance', 'skate', 'dance_samba', 'play_frisbee']
senticnet['jump_trampoline'] = [-0.089, 0, -0.094, -0.051, '#sad', '#scared', -0.078, 'cast_shadow', 'move_wind', 'box_ear', 'fall_dead', 'branch_out']
senticnet['jump_up'] = [-0.081, 0.124, -0.094, 0.176, '#interesting', '#admirable', 0.042, 'jump_over', 'hurry_along', 'mark_territory', 'jump', 'hurry_up']
senticnet['jump_up_and_down'] = [-0.98, 0, 0.594, -0.988, '#sad', '#disgusting', -0.854, 'crazy', 'mad', 'fool', 'mad_scientist', 'mad_person']
senticnet['jump_up_down'] = [-0.183, 0, -0.142, -0.111, '#sad', '#scared', -0.145, 'fly_kite', 'walk_dog', 'skateboard', 'rake_leave', 'ride_roller_coaster']
senticnet['jumpiness'] = [-0.721, 0, -0.762, 0, '#sad', '#scared', -0.494, 'restiveness', 'jitteriness', 'restive', 'nervy', 'jumpy']
senticnet['jumping_bristletail'] = [-0.703, 0, 0.994, -0.99, '#angry', '#disgusting', -0.896, 'insect', 'bristletail', 'silverfish', 'thysanuran_insect', 'machilid']
senticnet['jumpy'] = [0, 0, 0.987, -0.967, '#angry', '#disgusting', -0.651, 'high-strung', 'uptight', 'restive', 'overstrung', 'nervy']
senticnet['junction'] = [0.101, 0.074, 0.03, 0, '#joyful', '#interesting', 0.048, 'gutter', 'homeless_shelter', 'intersection', 'road_sign', 'bowl_alley']
senticnet['juncture'] = [-0.671, 0, 0.97, -0.64, '#sad', '#angry', -0.76, 'joint', 'node', 'articulation', 'join', 'connexion']
senticnet['jungle'] = [0.427, 0.227, 0, 0.37, '#joyful', '#admirable', 0.341, 'forest', 'plant', 'green_plant', 'grass', 'tree']
senticnet['junior'] = [0.101, 0.074, 0.03, 0, '#joyful', '#interesting', 0.048, 'young_man', 'adolescent', 'young_woman', 'kid', 'child']
senticnet['junk'] = [0, -0.016, 0.026, -0.066, '#angry', '#disgusting', -0.025, 'old_paper', 'old_stuff', 'egg_shell', 'food_scrap', 'old_clothes']
senticnet['junk_food'] = [-0.98, 0, 0.594, -0.988, '#sad', '#disgusting', -0.854, 'fast_food', 'deep_fried', 'unhealthy_food', 'reuse_oil', 'fattening_food']
senticnet['junk_heap'] = [-0.875, 0, 0.682, -0.915, '#sad', '#disgusting', -0.824, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'wasteyard']
senticnet['junk_mail'] = [-0.919, 0, 0.751, -0.992, '#sad', '#disgusting', -0.887, 'trash', 'waste', 'garbage', 'rubbish', 'refuse']
senticnet['junk_pile'] = [-0.864, 0, 0.93, -0.701, '#sad', '#angry', -0.832, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'wasteyard']
senticnet['junk_yard'] = [0, 0, 0.01, -0.079, '#angry', '#disgusting', -0.03, 'corner_two_streets', 'street_corner', 'junk_mail', 'street', 'freeway']
senticnet['junkie'] = [0, 0, -0.078, -0.093, '#scared', '#disgusting', -0.057, 'ambulance', 'prosthesis', 'old_lady', 'drug_addicted', 'elderly_person']
senticnet['juror'] = [0, 0.104, 0, 0.075, '#interesting', '#admirable', 0.06, 'judge', 'negotiator', 'see_justice_done', 'arbiter', 'member_jury']
senticnet['jury'] = [0, 0.122, 0, 0.069, '#interesting', '#admirable', 0.064, 'negotiator', 'juror', 'member_jury', 'gavel', 'decide_guilt']
senticnet['just'] = [0.059, 0.274, -0.116, 0.244, '#interesting', '#admirable', 0.154, 'confirmation', 'regulation', 'march_rear', 'fairness', 'tenet']
senticnet['just_fun'] = [0.162, -0.098, 0.089, 0, '#joyful', '#surprising', 0.057, 'taboo', 'creepy', 'enjoyable', 'difficult_play', 'fun']
senticnet['just_in_time'] = [0.039, 0.152, 0, 0.157, '#interesting', '#admirable', 0.116, 'keep_safe', 'drive_safely', 'avoid_problem', 'avoid_accident', 'good_break']
senticnet['justice'] = [0, 0.161, -0.089, 0.09, '#interesting', '#admirable', 0.054, 'punish_criminal', 'trial', 'try_case', 'pass_judgment', 'see_justice_done']
senticnet['justness'] = [0.594, -0.689, 0, 0.824, '#surprising', '#admirable', 0.702, 'natural_virtue', 'temperance', 'justice', 'moderation', 'prudence']
senticnet['juvenile_amaurotic_idiocy'] = [-0.629, 0, 0.987, -0.701, '#angry', '#disgusting', -0.772, 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect', 'congenital_disease']
senticnet['juvenile_rheumatoid_arthritis'] = [-0.899, 0, 0.989, -0.59, '#sad', '#angry', -0.826, 'arthritis', 'psoriatic_arthritis', 'rheumatoid_arthritis', 'autoimmune_disease', 'autoimmune_disorder']
senticnet['juvenility'] = [-0.938, 0, 0.906, -0.539, '#sad', '#angry', -0.794, 'immatureness', 'state', 'greenness', 'callowness', 'jejuneness']
senticnet['kail'] = [-0.569, 0, 0.892, -0.784, '#angry', '#disgusting', -0.748, 'borecole', 'colewort', 'crucifer', 'cole', 'kale']
senticnet['kainogenesis'] = [-0.722, 0, 0.694, -0.508, '#sad', '#angry', -0.641, 'growth', 'growing', 'maturation', 'development', 'ontogeny']
senticnet['kale'] = [0, -0.006, 0.053, -0.037, '#angry', '#disgusting', -0.028, 'broccoli', 'cucumber', 'cabbage', 'lettuce', 'pea']
senticnet['kamikaze'] = [0, 0, 0, -0.947, '#disgusting', '#disgusting', -0.316, 'terrorism', 'brainwash', 'sect', 'military_camp', 'faction']
senticnet['kangaroo'] = [0, 0.161, -0.089, 0.09, '#interesting', '#admirable', 0.054, 'cheetah', 'giraffe', 'caribou', 'mule', 'horse']
senticnet['karaoke'] = [0.925, 0.993, 0, 0.832, '#joyful', '#interesting', 0.917, 'dance_samba', 'dance', 'skate', 'jump_rope', 'play_frisbee']
senticnet['karate'] = [0.532, 0.657, -0.257, 0.268, '#joyful', '#interesting', 0.4, 'sport', 'martial_art', 'gymnastics', 'athletics', 'discipline']
senticnet['karma'] = [0, -0.711, 0, 0.718, '#surprising', '#admirable', 0.476, 'enter_contract', 'believe', 'give_help', 'destiny', 'fate']
senticnet['katana'] = [-0.04, 0.138, -0.085, 0.111, '#interesting', '#admirable', 0.041, 'geometry', 'craft', 'blade_geometry', 'blade', 'collect_item']
senticnet['kayak'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'boat', 'ship', 'large_boat', 'sailboat', 'big_boat']
senticnet['keel'] = [0, 0, 0.034, -0.089, '#angry', '#disgusting', -0.041, 'lifeboat', 'mast', 'bad_man', 'pirate', 'yacht']
senticnet['keel_arch'] = [0.641, -0.569, 0, 0.748, '#joyful', '#admirable', 0.653, 'trefoil_arch', 'ogee_arch', 'pointed_arch', 'drop_arch', 'arch']
senticnet['keel_over'] = [-0.536, 0, 0.752, -0.898, '#angry', '#disgusting', -0.729, 'fall', 'topple', 'descend', 'go_down', 'come_down']
senticnet['keen'] = [0, 0, 0.96, -0.928, '#angry', '#disgusting', -0.629, 'discriminating', 'acute', 'lament', 'knifelike', 'incisive']
senticnet['keenness'] = [0.532, 0.657, -0.257, 0.268, '#joyful', '#interesting', 0.4, 'eagerly', 'eagerness', 'avidity', 'thirstily', 'avidness']
senticnet['keep'] = [0.02, 0.228, -0.145, 0.306, '#interesting', '#admirable', 0.136, 'hold_onto', 'retain', 'upkeep', 'have', 'hold']
senticnet['keep_alive'] = [0.712, 0.935, 0, 0.968, '#interesting', '#admirable', 0.872, 'survival', 'stay_alive', 'sustain_life', 'enjoy_taste', 'make_feel_better']
senticnet['keep_an_eye_on'] = [0.939, -0.574, 0, 0.765, '#joyful', '#admirable', 0.759, 'check_up_on', 'suss_out', 'check_over', 'check_into', 'check']
senticnet['keep_balance'] = [0, -0.817, 0, 0.795, '#surprising', '#admirable', 0.537, 'knee_bend', 'bend_over', 'find_chair', 'bend_knee', 'tie_shoes']
senticnet['keep_bathroom_dry'] = [0.055, 0, 0.397, -0.235, '#angry', '#disgusting', -0.192, 'privacy', 'modesty', 'cover_window', 'worn_improve_vision', 'hold_clothes']
senticnet['keep_beat'] = [0, -0.071, 0.094, -0.093, '#angry', '#disgusting', -0.039, 'make_music', 'create_music', 'play_music', 'annoy_neighbor', 'play_stringed_instrument']
senticnet['keep_body_healthy'] = [0.862, 0, 0, 0.839, '#joyful', '#admirable', 0.567, 'keep_healthy', 'maintain_health', 'improve_self-image', 'get_healthy', 'stay_physically_fit']
senticnet['keep_body_warm'] = [0.756, 0, 0, 0.899, '#joyful', '#admirable', 0.552, 'keep_someone_warm', 'protection_sun', 'outerwear', 'make_fashion_statement', 'winter_clothes']
senticnet['keep_busy'] = [0.927, 0, 0, 0.902, '#joyful', '#admirable', 0.61, 'like_challenge', 'win_money', 'fun', 'profitable', 'get_famous']
senticnet['keep_child_occupy'] = [0.073, 0, 0, 0.083, '#joyful', '#admirable', 0.052, 'entertainment', 'read_fairy_tale', 'pastime', 'enjoyment', 'watch_cartoon']
senticnet['keep_clean'] = [0.073, 0, 0, 0.083, '#joyful', '#admirable', 0.052, 'wash_away_dirt', 'cleanliness', 'remove_dirt', 'get_rid_of_dirt', 'clean_skin']
senticnet['keep_clothes'] = [-0.059, -0.013, 0.062, 0, '#sad', '#angry', -0.036, 'store_dress', 'store_shoes', 'organize_clothes', 'hang_hanger', 'wear_clothes']
senticnet['keep_clothes_clean'] = [0.177, 0.083, 0, 0.166, '#joyful', '#admirable', 0.142, 'soft_skin', 'arm_around_neck', 'make_pretty', 'cover_table', 'clean_cloth']
senticnet['keep_cold'] = [0.151, 0.11, -0.045, 0.11, '#joyful', '#interesting', 0.109, 'cola', 'sprite', 'soft_drink', 'cold_drink', 'cool_drink']
senticnet['keep_cool'] = [0.793, 0, 0, 0.778, '#joyful', '#admirable', 0.524, 'cool_car_engine', 'keep_cold', 'cool_food', 'store_ice', 'store_ice_cream']
senticnet['keep_distant'] = [-0.904, 0, 0.943, -0.985, '#angry', '#disgusting', -0.944, 'kick_out', 'push_out', 'get_out', 'bouncer', 'push']
senticnet['keep_document'] = [0.069, 0, 0, 0, '#joyful', '#joyful', 0.023, 'backup', 'save_file', 'use_computer', 'keep_file', 'file']
senticnet['keep_down'] = [-0.501, 0, 0.936, -0.951, '#angry', '#disgusting', -0.796, 'quash', 'oppress', 'reduce', 'repress', 'subdue']
senticnet['keep_drink_cold'] = [0.069, 0, 0, 0, '#joyful', '#joyful', 0.023, 'store_ice_cream', 'store_meat', 'store_ice', 'keep_cold', 'hold_soda']
senticnet['keep_dry'] = [0.095, 0.204, -0.123, 0.174, '#interesting', '#admirable', 0.117, 'go_outdoors', 'sleep_tent', 'careful', 'pitch_tent', 'warm_up']
senticnet['keep_eye_open'] = [0.828, -0.892, 0, 0, '#joyful', '#surprising', 0.573, 'laugh_out_loud', 'ask_permission', 'tell_others', 'start_laugh', 'laugh']
senticnet['keep_file'] = [0.069, 0, 0, 0, '#joyful', '#joyful', 0.023, 'backup', 'save_file', 'use_computer', 'keep_document', 'file']
senticnet['keep_fit'] = [0.937, 0, 0, 0.782, '#joyful', '#admirable', 0.573, 'fun_exercise', 'athletic', 'recreational', 'get_physically_fit', 'fit_person']
senticnet['keep_food'] = [0, 0.115, 0, 0.106, '#interesting', '#admirable', 0.074, 'sell_food', 'keep_fresh', 'ship_goods', 'keep_safe', 'keep_food_spoil']
senticnet['keep_food_cold'] = [0.071, 0, 0, 0.085, '#joyful', '#admirable', 0.052, 'store_ice', 'store_meat', 'store_ice_cream', 'keep_cold', 'store_liquid']
senticnet['keep_food_cool'] = [0.102, 0.068, 0, 0.147, '#joyful', '#admirable', 0.106, 'keep_food_spoil', 'cool_food', 'store_food', 'keep_food_cold', 'food_storage']
senticnet['keep_food_spoil'] = [0.1, 0.079, 0, 0.13, '#joyful', '#admirable', 0.103, 'keep_food_cool', 'cool_food', 'keep_food_cold', 'store_food', 'store_dish']
senticnet['keep_foot_warm'] = [-0.047, -0.029, 0.075, 0, '#sad', '#angry', -0.031, 'protect_foot', 'walk_upon', 'stand_upon', 'find_garden', 'walk']
senticnet['keep_fresh'] = [0.035, 0.205, -0.104, 0.227, '#interesting', '#admirable', 0.121, 'keep_safe', 'maintain', 'store_vegetable', 'keep_food', 'provision']
senticnet['keep_going'] = [-0.05, 0.2, -0.116, 0.232, '#interesting', '#admirable', 0.089, 'result_injury', 'pull_car', 'never_stop', 'keep_moving', 'movement']
senticnet['keep_hair_place'] = [0, -0.73, 0, 0.944, '#surprising', '#admirable', 0.558, 'protect_head', 'helmet', 'cover_head', 'safety_cap', 'shade_eye']
senticnet['keep_hair_short'] = [-0.073, 0, -0.109, -0.056, '#sad', '#scared', -0.079, 'hair_become_short', 'cold_head', 'little_hair', 'short_hair', 'change_style']
senticnet['keep_hand_warm'] = [0.064, 0, 0, 0.057, '#joyful', '#admirable', 0.04, 'human_hand', 'hand', 'tong', 'finger', 'grasper']
senticnet['keep_healthy'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'stay_physically_fit', 'stay_shape', 'keep_body_healthy', 'build_muscle', 'keep_shape']
senticnet['keep_house_clean'] = [0, 0.733, 0, 0.784, '#interesting', '#admirable', 0.506, 'clean_floor', 'clean_kitchen', 'clean_carpet', 'expect_guest', 'clean_bathroom']
senticnet['keep_in_cage'] = [0, 0, -0.712, -0.917, '#scared', '#disgusting', -0.543, 'shell_animal', 'caged_lion', 'home_animal', 'captivity', 'man_best_friend']
senticnet['keep_in_touch'] = [0.881, 0, 0, 0.724, '#joyful', '#admirable', 0.535, 'communicate_with_others', 'communicate_idea', 'exchange_information', 'social_life', 'communicate_family']
senticnet['keep_job'] = [0.881, 0, 0, 0.724, '#joyful', '#admirable', 0.535, 'job', 'find_job', 'support_family', 'receive_paycheck', 'earn_money']
senticnet['keep_key'] = [0.881, 0, 0, 0.724, '#joyful', '#admirable', 0.535, 'desire_help', 'tear_paper', 'offer_help', 'check_breathe', 'lend_hand']
senticnet['keep_list'] = [0.881, 0, 0, 0.724, '#joyful', '#admirable', 0.535, 'keep_money', 'keep_order', 'keep_house_clean', 'order', 'list']
senticnet['keep_money'] = [0, 0.174, 0, 0.059, '#interesting', '#admirable', 0.078, 'money_holder', 'put_money', 'money_storage', 'require_signature', 'hold_money']
senticnet['keep_moving'] = [-0.05, 0.2, -0.116, 0.232, '#interesting', '#admirable', 0.089, 'result_injury', 'pull_car', 'never_stop', 'keep_going', 'movement']
senticnet['keep_note'] = [-0.028, 0.204, 0, 0.106, '#interesting', '#admirable', 0.094, 'scribble', 'jot', 'record_keep', 'keep_track_expense', 'calligraphy']
senticnet['keep_one_eyes_open'] = [0.509, -0.93, 0, 0.75, '#surprising', '#admirable', 0.73, 'beware', 'look_after', 'keep_one_eyes_peeled', 'keep_one_eyes_skinned', 'watch_out']
senticnet['keep_one_eyes_peeled'] = [0.509, -0.93, 0, 0.75, '#surprising', '#admirable', 0.73, 'beware', 'look_after', 'watch_out', 'keep_one_eyes_skinned', 'keep_one_eyes_open']
senticnet['keep_one_eyes_skinned'] = [0.509, -0.93, 0, 0.75, '#surprising', '#admirable', 0.73, 'beware', 'look_after', 'keep_one_eyes_peeled', 'watch_out', 'keep_one_eyes_open']
senticnet['keep_open_mind'] = [-0.061, -0.056, 0.049, -0.067, '#sad', '#disgusting', -0.04, 'read_article', 'borrow_book', 'use_internet', 'hack', 'use_system_abstract_think']
senticnet['keep_order'] = [0, 0.141, 0, 0.189, '#interesting', '#admirable', 0.11, 'orderly', 'organize', 'order', 'tidy', 'neat_tidy']
senticnet['keep_out'] = [-0.023, 0.083, 0.041, 0.184, '#interesting', '#admirable', 0.068, 'heavy_object', 'metal_bar', 'control_access', 'door_handle', 'use_farm']
senticnet['keep_paper'] = [0, 0.107, 0, 0, '#interesting', '#interesting', 0.036, 'store_document', 'put_paper', 'organize_paper', 'organize_document', 'store_paper']
senticnet['keep_paper_together'] = [0.025, 0.083, 0, 0.06, '#interesting', '#admirable', 0.056, 'organize_document', 'carry_document', 'bind_paper_together', 'carry_paper', 'store_document']
senticnet['keep_peace'] = [0.881, 0, 0, 0.724, '#joyful', '#admirable', 0.535, 'peace', 'defeat_enemy', 'keep_order', 'keep_safe', 'keep_safe_place']
senticnet['keep_pet'] = [0.851, 0, 0, 0.737, '#joyful', '#admirable', 0.529, 'fun_watch', 'a_lot_of_fun', 'love_pet', 'leisure', 'social_event']
senticnet['keep_place'] = [-0.076, -0.034, 0.063, -0.129, '#sad', '#disgusting', -0.078, 'get_front', 'learn_patience', 'big_boat', 'wait_patiently', 'take_turn']
senticnet['keep_promise'] = [0.927, 0, 0, 0.956, '#joyful', '#admirable', 0.628, 'correct_mistake', 'kill_specific_group', 'sail_around_world', 'voice_concern', 'bicycle_across_town']
senticnet['keep_record'] = [0, 0.743, 0, 0.826, '#interesting', '#admirable', 0.523, 'cross_room', 'list_item', 'check_balance', 'strive', 'record']
senticnet['keep_relationship'] = [0, 0.874, 0, 0, '#interesting', '#interesting', 0.291, 'make_promise', 'honest', 'make_commitment', 'keep_promise', 'trust']
senticnet['keep_rhythm'] = [-0.029, -0.107, 0.12, -0.148, '#angry', '#disgusting', -0.063, 'sense_rhythm', 'callus', 'remember_childhood', 'arthritis', 'annoy_neighbor']
senticnet['keep_safe'] = [0, 0.242, -0.105, 0.228, '#interesting', '#admirable', 0.122, 'safekeep', 'store_stuff', 'hold_onto', 'store_dry_goods', 'keep_fresh']
senticnet['keep_safe_place'] = [0.077, 0.306, -0.162, 0.195, '#interesting', '#admirable', 0.139, 'dowry', 'loot', 'safe', 'welfare', 'prize']
senticnet['keep_score'] = [0.077, 0.306, -0.162, 0.195, '#interesting', '#admirable', 0.139, 'enjoy_game', 'win_game', 'try_win', 'play_game', 'win']
senticnet['keep_secret'] = [0, 0, 0, 0.848, '#admirable', '#admirable', 0.283, 'discuss', 'become_friend', 'move_tongue', 'persuade', 'hunt_duck']
senticnet['keep_secret_hide_place'] = [-0.11, 0, 0.02, 0, '#sad', '#angry', -0.043, 'make_tire', 'strike_ball', 'dog_bite', 'broken_bone', 'monitor_heart_rate']
senticnet['keep_shape'] = [0.08, -0.063, 0.045, 0, '#joyful', '#surprising', 0.033, 'strengthen_heart', 'get_physically_fit', 'keep_fit', 'enjoy_outdoors', 'build_endurance']
senticnet['keep_skin_healthy'] = [0.867, 0, 0, 0.951, '#joyful', '#admirable', 0.606, 'stay_healthy', 'maintain_health', 'make_healthy', 'fix_problem', 'do_exercise']
senticnet['keep_someone_out'] = [0.07, 0.182, -0.06, 0.153, '#interesting', '#admirable', 0.115, 'restrict_access', 'control_access', 'lock', 'latch', 'door_knob']
senticnet['keep_someone_warm'] = [0.819, 0, 0, 0.904, '#joyful', '#admirable', 0.574, 'keep_body_warm', 'keep_warm', 'protection_sun', 'protect_body', 'make_fashion_statement']
senticnet['keep_stuff'] = [0, 0.106, -0.084, 0.145, '#interesting', '#admirable', 0.056, 'hold_many', 'store_object', 'decide_want', 'sell_insurance', 'try']
senticnet['keep_time'] = [0, 0.138, 0.077, 0.186, '#interesting', '#admirable', 0.082, 'show_time', 'timekeeper', 'measure', 'measure_time', 'time_measure']
senticnet['keep_tooth_clean'] = [-0.051, -0.017, 0.012, -0.04, '#sad', '#disgusting', -0.029, 'remove_plaque', 'clean_between_tooth', 'close_mouth', 'chew', 'suck']
senticnet['keep_track'] = [0.717, 0.727, 0, 0, '#joyful', '#interesting', 0.481, 'save_information', 'store_music', 'groove', 'music_storage', 'piece_of_music']
senticnet['keep_track_appointment'] = [-0.723, 0, 0, -0.769, '#sad', '#disgusting', -0.497, 'move_mouse', 'reboot', 'type_of_keyboard', 'enter_address', 'edit']
senticnet['keep_track_expense'] = [0, 0.188, 0, 0, '#interesting', '#interesting', 0.063, 'bank_account', 'account', 'bank', 'government_agreement', 'piggy_bank']
senticnet['keep_track_time'] = [0, -0.026, 0.085, -0.094, '#angry', '#disgusting', -0.051, 'time_pass', 'watch_clock', 'tie_score', 'day_period', 'even_out']
senticnet['keep_up_current_event'] = [0.974, -0.991, 0, 0, '#joyful', '#surprising', 0.655, 'understand_current_event', 'know_happen_world', 'take_up_time', 'expand_mind', 'gain_information']
senticnet['keep_warm'] = [0.736, 0, 0, 0.889, '#joyful', '#admirable', 0.542, 'stay_warm', 'keep_warm_winter', 'keep_someone_warm', 'provide_warmth', 'warmth']
senticnet['keep_warm_bed'] = [0.069, 0, 0, 0, '#joyful', '#joyful', 0.023, 'keep_warm_night', 'sleep_under', 'cover_bed', 'sleep', 'use_bed']
senticnet['keep_warm_night'] = [0.069, 0, 0, 0, '#joyful', '#joyful', 0.023, 'cover_bed', 'sleep_under', 'keep_warm_bed', 'cover_furniture', 'use_bed']
senticnet['keep_warm_winter'] = [0.925, 0, 0, 0.775, '#joyful', '#admirable', 0.567, 'stay_warm', 'keep_warm', 'keep_someone_warm', 'provide_warmth', 'warmth']
senticnet['keep_well'] = [0.08, 0.193, -0.165, 0.227, '#interesting', '#admirable', 0.112, 'good_nutrition', 'healthy', 'health', 'long_life', 'live_long_life']
senticnet['keep_word'] = [0.08, 0.193, -0.165, 0.227, '#interesting', '#admirable', 0.112, 'honest', 'serious', 'keep_promise', 'sincere', 'genuine']
senticnet['keep_work'] = [0.791, 0.892, 0, 0.966, '#interesting', '#admirable', 0.883, 'help_others', 'become_better_person', 'increase_intelligence', 'sense_satisfaction', 'develop_talent']
senticnet['keeper'] = [0, 0.825, 0, 0.713, '#interesting', '#admirable', 0.513, 'protect', 'guard', 'secure', 'treasurer', 'safe']
senticnet['keeping'] = [0.614, -0.953, 0, 0.768, '#surprising', '#admirable', 0.778, 'abidance', 'formality', 'honoring', 'line', 'observance']
senticnet['keepsake'] = [0.822, -0.834, 0, 0, '#joyful', '#surprising', 0.552, 'ribbon', 'neckwear', 'round_brush', 'jeans', 'panties']
senticnet['keg'] = [0.161, -0.146, 0.031, -0.104, '#joyful', '#surprising', 0.057, 'case_beer', 'reception', 'champagne', 'beer', 'wine']
senticnet['kempt'] = [0.888, -0.683, 0, 0.914, '#joyful', '#admirable', 0.828, 'tidy', 'groomed', 'sleek', 'pomaded', 'brushed']
senticnet['kennel'] = [0, 0.076, 0.024, 0.137, '#interesting', '#admirable', 0.063, 'animal_home', 'hive', 'lair', 'habitat', 'beehive']
senticnet['kenogenesis'] = [-0.758, 0, 0.847, -0.835, '#angry', '#disgusting', -0.813, 'growth', 'growing', 'maturation', 'development', 'ontogeny']
senticnet['keratoderma_blennorrhagica'] = [-0.848, 0, 0.581, -0.93, '#sad', '#disgusting', -0.786, 'keratosis_blennorrhagica', 'keratosis', 'keratosis_pilaris', 'seborrheic_keratosis', 'verruca']
senticnet['keratosis'] = [-0.848, 0, 0.581, -0.93, '#sad', '#disgusting', -0.786, 'keratosis_blennorrhagica', 'keratoderma_blennorrhagica', 'keratosis_pilaris', 'seborrheic_keratosis', 'verruca']
senticnet['keratosis_blennorrhagica'] = [-0.848, 0, 0.581, -0.93, '#sad', '#disgusting', -0.786, 'keratosis', 'keratoderma_blennorrhagica', 'keratosis_pilaris', 'seborrheic_keratosis', 'verruca']
senticnet['keratosis_pilaris'] = [-0.848, 0, 0.581, -0.93, '#sad', '#disgusting', -0.786, 'keratosis_blennorrhagica', 'keratoderma_blennorrhagica', 'keratosis', 'seborrheic_keratosis', 'verruca']
senticnet['kerchief'] = [0.028, 0.066, 0, 0, '#joyful', '#interesting', 0.031, 'cowhide', 'handkerchief', 'hanky', 'facial_tissue', 'zipper']
senticnet['kerfuffle'] = [-0.794, 0, 0.974, -0.99, '#angry', '#disgusting', -0.919, 'turmoil', 'convulsion', 'tempest', 'disorder', 'earthquake']
senticnet['kerion'] = [-0.964, 0, 0.694, -0.623, '#sad', '#angry', -0.76, 'fungal_infection', 'mycosis', 'ringworm', 'tinea_pedis', 'athlete_foot']
senticnet['kernel'] = [0, 0.07, 0.041, 0.058, '#interesting', '#admirable', 0.029, 'maize', 'wheat_rice', 'grain', 'farm_plant', 'cereal_crop']
senticnet['kernicterus'] = [-0.647, 0, 0.903, -0.634, '#sad', '#angry', -0.728, 'jaundice_of_newborn', 'disease', 'icterus_neonatorum', 'icterus', 'symptom']
senticnet['kerosene'] = [0, 0, -0.08, 0, '#scared', '#scared', -0.027, 'petrol', 'diesel', 'butane', 'fuel', 'gasoline']
senticnet['ketchup'] = [0.876, 0, 0, 0.876, '#joyful', '#admirable', 0.584, 'cottage_cheese', 'blackberry', 'dairy_product', 'drinkable', 'savory']
senticnet['key'] = [0.943, -0.787, 0, 0.571, '#joyful', '#surprising', 0.767, 'master', 'ignition_key', 'latchkey', 'passkey', 'master_key']
senticnet['key_case'] = [0, -0.94, 0, 0.967, '#surprising', '#admirable', 0.636, 'key_chain', 'tote_bag', 'checkbook_cover', 'eyeglass_case', 'glass_case']
senticnet['key_chain'] = [0, -0.862, 0, 0.926, '#surprising', '#admirable', 0.596, 'key_case', 'tote_bag', 'checkbook_cover', 'eyeglass_case', 'glass_case']
senticnet['keychain'] = [0, 0.084, 0, 0, '#interesting', '#interesting', 0.028, 'keyhole', 'clothes_washer', 'briefcase', 'purse', 'clutch_bag']
senticnet['keyhole'] = [0, 0.084, 0, 0, '#interesting', '#interesting', 0.028, 'keychain', 'clothes_washer', 'briefcase', 'purse', 'clutch_bag']
senticnet['keypad'] = [0, -0.917, 0, 0.907, '#surprising', '#admirable', 0.608, 'find_phone_number', 'dial_phone_number', 'pick_up_telephone_receiver', 'dial', 'dial_telephone']
senticnet['khakis'] = [-0.798, 0, 0.599, -0.938, '#sad', '#disgusting', -0.778, 'uniform', 'battle_dress', 'dress_uniform', 'fatigues', 'military_uniform']
senticnet['khan'] = [0.931, -0.745, 0, 0.729, '#joyful', '#surprising', 0.802, 'caravansary', 'caravanserai', 'hostel', 'caravan_inn', 'imaret']
senticnet['kick'] = [0, 0.795, 0, 0.906, '#interesting', '#admirable', 0.567, 'rush', 'catch', 'kick_ball', 'flush', 'boot']
senticnet['kick_ass'] = [0, 0, 0.752, -0.843, '#angry', '#disgusting', -0.532, 'get_hit_by_car', 'meander', 'full_moon', 'step_dog_poop', 'trot']
senticnet['kick_ball'] = [0, 0.754, 0, 0.841, '#interesting', '#admirable', 0.532, 'rush', 'catch', 'kick', 'flush', 'boot']
senticnet['kick_downstairs'] = [-0.772, 0, 0.72, -0.981, '#sad', '#disgusting', -0.824, 'designate', 'depute', 'reduce', 'sideline', 'delegate']
senticnet['kick_in_butt'] = [-0.839, 0, 0.924, -0.79, '#sad', '#angry', -0.851, 'corporal_punishment', 'licking', 'whacking', 'stoning', 'lapidation']
senticnet['kick_out'] = [-0.88, 0, 0.903, -0.504, '#sad', '#angry', -0.762, 'send_down', 'rusticate', 'expel', 'throw_out', 'debar']
senticnet['kick_upstairs'] = [0.586, -0.967, 0, 0.9, '#surprising', '#admirable', 0.818, 'ennoble', 'gentle', 'prefer', 'spot_promote', 'favor']
senticnet['kid'] = [0.121, 0.099, 0, 0.063, '#joyful', '#interesting', 0.094, 'little_child', 'baby', 'child', 'youngster', 'young_child']
senticnet['kid_activity'] = [0.042, 0, 0, 0.109, '#joyful', '#admirable', 0.05, 'game_action', 'form_of_social_interaction', 'fun_activity', 'stage_production', 'child_game']
senticnet['kid_game'] = [0, -0.028, 0, 0.099, '#surprising', '#admirable', 0.042, 'fun_game', 'child_game', 'play_object', 'play_device', 'plaything']
senticnet['kid_play'] = [0.928, -0.802, 0, 0, '#joyful', '#surprising', 0.577, 'child_plaything', 'child_play', 'play_object', 'plaything', 'play_device']
senticnet['kid_room'] = [0.817, -0.737, 0, 0, '#joyful', '#surprising', 0.518, 'fancy_dress', 'shoe_shop', 'girl_room', 'furniture_store', 'toy_box']
senticnet['kid_toy'] = [0.044, -0.033, 0.037, 0.089, '#joyful', '#admirable', 0.043, 'life_like', 'tiny_person', 'mannequin', 'build_block', 'plaything']
senticnet['kidnap'] = [-0.89, -0.714, -0.766, -0.939, '#sad', '#disgusting', -0.627, 'bigot', 'censorship', 'jail_time', 'reprimand', 'intolerance']
senticnet['kidney'] = [0, 0, 0, -0.083, '#disgusting', '#disgusting', -0.028, 'scrotum', 'liver', 'bowel', 'pancreas', 'adam_apple']
senticnet['kidney_bean'] = [0.861, -0.549, 0, 0.976, '#joyful', '#admirable', 0.795, 'common_bean', 'frijol', 'frijole', 'green_bean', 'wax_bean']
senticnet['kidney_disease'] = [0.576, -0.572, 0, 0.768, '#joyful', '#admirable', 0.639, 'uropathy', 'polyuria', 'polycystic_kidney_disease', 'renal_failure', 'kidney_failure']
senticnet['kidney_failure'] = [-0.603, 0, 0.544, -0.539, '#sad', '#angry', -0.562, 'acute_renal_failure', 'acute_kidney_failure', 'chronic_renal_failure', 'chronic_kidney_failure', 'nephrosis']
senticnet['kill'] = [0, 0, -0.881, -0.868, '#scared', '#disgusting', -0.583, 'death_destruction', 'murder', 'defend_oneself', 'kill_enemy', 'get_rid_of_enemy']
senticnet['kill_animal'] = [-0.089, -0.043, 0, -0.132, '#sad', '#disgusting', -0.059, 'target_practice', 'shoot_target', 'shoot_bullet', 'self_defense', 'corner_prey']
senticnet['kill_another_person'] = [0, 0, 0.957, -0.998, '#angry', '#disgusting', -0.652, 'get_rid_of_enemy', 'murder', 'enslave_person', 'defend_oneself', 'death_destruction']
senticnet['kill_brain_cell'] = [0.907, -0.819, 0, 0, '#joyful', '#surprising', 0.575, 'eat_popcorn', 'cry', 'enjoy_show', 'change_channel', 'entertain']
senticnet['kill_bug'] = [-0.058, -0.049, 0.01, -0.113, '#sad', '#disgusting', -0.044, 'potato', 'break', 'toxic_waste', 'tear_apart', 'destroy']
senticnet['kill_cat'] = [-0.961, 0, -0.784, -0.728, '#sad', '#scared', -0.824, 'corner_prey', 'even_odds', 'hunt_game', 'elephant_sit_chest', 'suffocate']
senticnet['kill_chicken'] = [-0.057, 0, -0.147, -0.055, '#sad', '#scared', -0.086, 'question_authority', 'smoke_cigarette', 'battle_disease', 'cook_vegetable', 'prepare_ingredient']
senticnet['kill_consciousness'] = [-0.917, 0, 0.513, -0.932, '#sad', '#disgusting', -0.787, 'die', 'cause_injury', 'kill', 'end_life', 'feel_pain']
senticnet['kill_deer'] = [-0.085, 0, -0.076, 0, '#sad', '#scared', -0.054, 'hunt', 'hunt_game', 'use_gun', 'slay', 'corner_prey']
senticnet['kill_endangered_spieces'] = [-0.941, -0.805, -0.821, -0.758, '#sad', '#scared', -0.572, 'kind_animal', 'cover_fur', 'big_cat', 'bad_eyesight', 'type_of_animal']
senticnet['kill_enemy'] = [0, 0.827, 0, 0.84, '#interesting', '#admirable', 0.556, 'win_war', 'win_battle', 'beat_enemy', 'become_strong', 'become_best']
senticnet['kill_forest'] = [-0.232, -0.095, 0, -0.24, '#sad', '#disgusting', -0.126, 'fallen_tree', 'dangerous', 'woodman', 'wood', 'accident']
senticnet['kill_friend'] = [-0.998, 0, 0.434, -0.904, '#sad', '#disgusting', -0.779, 'friendly_fire', 'fight_war', 'battle', 'attack', 'hurt_wrongly']
senticnet['kill_germ'] = [0.768, -0.631, 0, 0.717, '#joyful', '#admirable', 0.705, 'antibacterial', 'medication', 'antibiotic_drug', 'antibiotic', 'bacitracin']
senticnet['kill_human'] = [0, 0, -0.899, -0.889, '#scared', '#disgusting', -0.596, 'drop_airplane', 'windsurf', 'kill_life', 'destroy_city', 'cut_oneself']
senticnet['kill_human_being'] = [-0.176, -0.15, -0.214, -0.083, '#sad', '#scared', -0.108, 'find_subway_stop', 'find_bank', 'find_farm', 'slander', 'die']
senticnet['kill_insect'] = [0.73, 0, 0, 0, '#joyful', '#joyful', 0.243, 'house_look_better', 'tidiness', 'solve_problem', 'remove_spot', 'kill_spider']
senticnet['kill_life'] = [-0.785, 0, -0.945, 0, '#sad', '#scared', -0.577, 'cut_down', 'destroy_home', 'destroy_city', 'destroy_target', 'cut_down_tree']
senticnet['kill_live_creature'] = [-0.92, 0, 0.996, -0.96, '#angry', '#disgusting', -0.959, 'kill', 'kill_animal', 'bad_person', 'murder', 'kill_person']
senticnet['kill_man'] = [-0.721, 0, 0.623, -0.688, '#sad', '#disgusting', -0.677, 'murder_another_person', 'kill_person', 'kill', 'make_someone_sick', 'commit_murder']
senticnet['kill_mouse'] = [0, -0.016, 0.023, -0.097, '#angry', '#disgusting', -0.035, 'catch_mouse', 'eat_cat_food', 'sleep_long_time', 'dream_with_eyes_open', 'rain_parade']
senticnet['kill_oneself'] = [-0.779, -0.822, -0.879, -0.943, '#scared', '#disgusting', -0.593, 'raise_flag', 'hurt_animal', 'market_product', 'battle_cancer', 'kill_specific_group']
senticnet['kill_other_person'] = [-0.718, 0, -0.802, -0.76, '#scared', '#disgusting', -0.76, 'even_odds', 'hunt_game', 'raise_flag', 'end_life', 'arm_bomb']
senticnet['kill_people'] = [-0.072, -0.054, -0.046, -0.157, '#sad', '#disgusting', -0.074, 'shoot_bullet', 'destroy_home', 'shoot_target', 'target_practice', 'destroy_live']
senticnet['kill_person'] = [-0.917, 0, 0.513, -0.932, '#sad', '#disgusting', -0.787, 'cause_someone_embarrassment', 'cause_bleeding', 'cut_finger', 'beat_person', 'cause_strong_pain']
senticnet['kill_pest'] = [0, 0, -0.869, -0.94, '#scared', '#disgusting', -0.603, 'destroy_target', 'kill', 'murder_another_person', 'destroy_city', 'target_practice']
senticnet['kill_self'] = [-0.29, -0.04, -0.239, -0.114, '#sad', '#scared', -0.201, 'end_life', 'kill', 'take_life', 'call_help', 'capital_punishment']
senticnet['kill_soldier'] = [-0.053, -0.041, 0, -0.196, '#sad', '#disgusting', -0.069, 'make_war', 'conquer_enemy', 'keep_peace', 'settle_disagreement', 'gain_territory']
senticnet['kill_somebody'] = [-0.995, 0, 0.034, -0.967, '#sad', '#disgusting', -0.665, 'kill', 'murder', 'gun', 'kill_person', 'kill_someone']
senticnet['kill_someone'] = [-0.93, 0, 0.408, -0.923, '#sad', '#disgusting', -0.754, 'kill', 'murder', 'kill_person', 'commit_crime', 'crime']
senticnet['kill_specific_group'] = [-0.91, 0, 0, -0.706, '#sad', '#disgusting', -0.539, 'bicycle_across_town', 'hurt_animal', 'mine_diamond', 'dig_grave', 'age_gracefully']
senticnet['kill_spider'] = [0.73, 0, 0, 0, '#joyful', '#joyful', 0.243, 'house_look_better', 'tidiness', 'solve_problem', 'remove_spot', 'kill_insect']
senticnet['kill_time'] = [-0.855, 0, 0, -0.71, '#sad', '#disgusting', -0.522, 'pastime', 'cultural_experience', 'stimulate_mind', 'entertain_oneself', 'escape_reality']
senticnet['killer'] = [-0.065, -0.027, 0, -0.153, '#sad', '#disgusting', -0.064, 'gunshot', 'wound', 'fall_sky', 'lethal', 'fire_bullet']
senticnet['killing'] = [-0.716, 0, 0.748, -0.55, '#sad', '#angry', -0.671, 'casualty', 'fatal_accident', 'fatality', 'violent_death', 'death']
senticnet['killjoy'] = [-0.827, 0, 0.556, -0.867, '#sad', '#disgusting', -0.75, 'worrier', 'fusspot', 'worrywart', 'unwelcome_person', 'party_pooper']
senticnet['kilometer'] = [0, 0.751, 0, 0.897, '#interesting', '#admirable', 0.549, 'distance_measure', 'measure', 'length_measurement', 'meter', 'distance_measurement']
senticnet['kimono'] = [0, -0.048, 0.074, -0.05, '#angry', '#disgusting', -0.025, 'nightgown', 'garment', 'judo', 'stocking', 'apparel']
senticnet['kin'] = [0.936, 0.71, 0, 0, '#joyful', '#interesting', 0.549, 'relate_person', 'relative', 'female_relative', 'female_sibling', 'mom_dad']
senticnet['kind'] = [0.933, 0, 0, 0.946, '#joyful', '#admirable', 0.626, 'kindness', 'love_affection', 'please', 'show_love', 'beloved']
senticnet['kind-hearted'] = [0.56, 0.708, -0.535, 0.514, '#joyful', '#interesting', 0.416, 'kindhearted', 'kind', 'kindheartedness', 'fellow_feeling', 'compatibly']
senticnet['kind-heartedness'] = [0.56, 0.708, -0.535, 0.514, '#joyful', '#interesting', 0.416, 'kind', 'kindhearted', 'kindheartedness', 'fellow_feeling', 'compatibly']
senticnet['kind_animal'] = [-0.751, 0, 0, -0.747, '#sad', '#disgusting', -0.499, 'hound', 'zoo', 'cage_animal', 'hunter', 'animal']
senticnet['kind_food'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'root_vegetable', 'legume', 'japanese_food', 'popular_food', 'food_item']
senticnet['kind_gesture'] = [0.986, 0.762, 0, 0, '#joyful', '#interesting', 0.583, 'card', 'character', 'letter', 'good_movie', 'chance']
senticnet['kind_pet'] = [0, 0, 0, 0.865, '#admirable', '#admirable', 0.288, 'animal', 'specific', 'pet', 'disarray', 'face_other']
senticnet['kind_request'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'ask_permission', 'cup_hand', 'tear_paper', 'laugh_clown', 'love_pet']
senticnet['kindergarden'] = [0.035, -0.015, 0.009, 0.063, '#joyful', '#admirable', 0.035, 'maternity_ward', 'daycare', 'doctor_office', 'gym', 'men_room']
senticnet['kindergarten'] = [0.084, -0.087, 0.025, 0, '#joyful', '#surprising', 0.049, 'fun_pastime', 'stage_production', 'have_fun', 'fun_activity', 'diversion']
senticnet['kindhearted'] = [0.56, 0.708, -0.535, 0.514, '#joyful', '#interesting', 0.416, 'kind-hearted', 'kind-heartedness', 'kindheartedness', 'fellow_feeling', 'compatibly']
senticnet['kindheartedness'] = [0.56, 0.708, -0.535, 0.514, '#joyful', '#interesting', 0.416, 'kind-hearted', 'kindhearted', 'kind-heartedness', 'fellow_feeling', 'compatibly']
senticnet['kindle'] = [0.722, -0.764, 0, 0.946, '#surprising', '#admirable', 0.811, 'arouse', 'elicit', 'enask_for', 'ask_for', 'evoke']
senticnet['kindly'] = [0.552, 0.681, -0.294, 0.297, '#joyful', '#interesting', 0.412, 'charitable', 'good-hearted', 'large-hearted', 'openhearted', 'benevolent']
senticnet['kindness'] = [0, 0, 0, 0.98, '#admirable', '#admirable', 0.327, 'gentleness', 'demand', 'sympathy', 'type_of_bear', 'express_gratitude']
senticnet['kinetic'] = [0.535, -0.586, 0, 0.748, '#surprising', '#admirable', 0.623, 'moving', 'restless', 'afoot', 'ahorse', 'ahorseback']
senticnet['kinetic_energy'] = [0, -0.752, 0, 0.945, '#surprising', '#admirable', 0.566, 'forceful', 'power_source', 'electrical', 'gas_oil', 'electric_power']
senticnet['king'] = [0.044, 0.095, 0, 0.083, '#interesting', '#admirable', 0.074, 'monarch', 'duchess', 'noble', 'duke', 'royal_leader']
senticnet['king_queen'] = [0.057, 0.094, -0.045, 0.136, '#interesting', '#admirable', 0.081, 'blue_blood', 'royalty', 'king', 'monarch', 'regal']
senticnet['kingdom'] = [0.052, 0.113, -0.072, 0.103, '#interesting', '#admirable', 0.065, 'monarchy', 'reign', 'aboriginal', 'royal', 'president']
senticnet['kingly'] = [0.067, 0.134, -0.051, 0.182, '#interesting', '#admirable', 0.111, 'blue_blood', 'regal', 'king_queen', 'royalty', 'royal_person']
senticnet['kink'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'blind_person', 'rubber_duck', 'greedy_person', 'vegetarian', 'foreigner']
senticnet['kinky_sex'] = [0.081, 0.095, 0, 0, '#joyful', '#interesting', 0.059, 'build_tower_out_toy_block', 'a_lot_of_sex', 'play_hockey', 'play_baseball', 'play_football']
senticnet['kinship'] = [0.891, 0.84, 0, 0, '#joyful', '#interesting', 0.577, 'relate_person', 'kin', 'mom_dad', 'brother_sister', 'aunt_uncle']
senticnet['kiosk'] = [0.813, 0.832, 0, 0.874, '#interesting', '#admirable', 0.84, 'ferris_wheel', 'concession_stand', 'food', 'carnival_ride', 'theme_park']
senticnet['kiss'] = [0.973, 0.804, 0, 0, '#joyful', '#interesting', 0.592, 'love_another', 'love_else', 'propose_woman', 'start_family', 'procreate']
senticnet['kiss_girl'] = [-0.127, 0, -0.053, 0, '#sad', '#scared', -0.06, 'wedge_door', 'fancy_girl', 'steal_store', 'visit_grandmother', 'part_of_hair']
senticnet['kiss_of_death'] = [-0.591, 0, 0.505, -0.87, '#sad', '#disgusting', -0.655, 'calamity', 'catastrophe', 'tragedy', 'disaster', 'cataclysm']
senticnet['kiss_other'] = [0.96, 0.884, 0, 0.755, '#joyful', '#interesting', 0.866, 'dance_together', 'sexual_arousal', 'fall_love', 'laugh', 'feel_happy']
senticnet['kiss_partner'] = [-0.027, 0, 0, -0.077, '#sad', '#disgusting', -0.035, 'orgasm', 'sexual_excitement', 'call_dog', 'erection', 'wet_lip']
senticnet['kit'] = [-0.044, -0.035, -0.058, -0.028, '#sad', '#scared', -0.032, 'high_school_band', 'drum_set', 'string_quartet', 'music_shop', 'set']
senticnet['kit_and_caboodle'] = [0.639, -0.827, 0, 0.997, '#surprising', '#admirable', 0.821, 'completeness', 'work', 'whole_shebang', 'whole_entireness', 'entireness']
senticnet['kit_fox'] = [-0.662, 0, 0.992, -0.726, '#angry', '#disgusting', -0.793, 'vixen', 'red_fox', 'fox', 'prairie_fox', 'white_fox']
senticnet['kitchen'] = [0, -0.068, 0, 0, '#surprising', '#surprising', 0.023, 'kitchen_cabinet', 'kitchen_cupboard', 'dishwasher', 'cupboard', 'own_kitchen']
senticnet['kitchen_cabinet'] = [0.03, -0.074, 0, 0, '#joyful', '#surprising', 0.035, 'kitchen_cupboard', 'kitchen', 'cupboard', 'dishwasher', 'own_kitchen']
senticnet['kitchen_cupboard'] = [0.021, -0.061, 0, 0, '#joyful', '#surprising', 0.027, 'own_kitchen', 'cupboard', 'kitchen_cabinet', 'pantry', 'kitchen']
senticnet['kitchen_drawer'] = [0.036, -0.052, 0, 0, '#joyful', '#surprising', 0.029, 'neat', 'cutlery_drawer', 'silverware_drawer', 'dine_table', 'table']
senticnet['kitchen_knife'] = [0.021, -0.061, 0, 0, '#joyful', '#surprising', 0.027, 'kitchen_stuff', 'equipment', 'kitchen_cupboard', 'kitchen_tool', 'pot']
senticnet['kitchen_stuff'] = [0.021, -0.061, 0, 0, '#joyful', '#surprising', 0.027, 'kitchen_tool', 'equipment', 'kitchen_cupboard', 'kitchen_knife', 'pot']
senticnet['kitchen_tool'] = [0.021, -0.061, 0, 0, '#joyful', '#surprising', 0.027, 'kitchen_stuff', 'equipment', 'kitchen_cupboard', 'kitchen_knife', 'pot']
senticnet['kitchen_ware'] = [0.038, 0, 0, 0.089, '#joyful', '#admirable', 0.042, 'food_storage', 'container', 'storage', 'pantry', 'own_kitchen']
senticnet['kitchen_worktop'] = [0.025, 0.084, 0, 0.062, '#interesting', '#admirable', 0.057, 'work_surface', 'worktop', 'surface', 'work', 'wood_worktop']
senticnet['kitchenette'] = [0.159, -0.005, 0.011, 0.079, '#joyful', '#admirable', 0.077, 'ceiling_fan', 'ipod', 'technologic', 'formula', 'music']
senticnet['kite'] = [0.089, -0.18, 0.037, -0.061, '#joyful', '#surprising', 0.057, 'balloon', 'luna_park', 'fielder', 'ballon', 'blimp']
senticnet['kittenish'] = [0.582, -0.783, 0, 0.795, '#surprising', '#admirable', 0.72, 'elfish', 'elvish', 'playful', 'frisky', 'sportive']
senticnet['kitty'] = [-0.032, -0.003, 0.087, -0.057, '#angry', '#disgusting', -0.058, 'dog_fur', 'dog_cat', 'dog_hair', 'pet', 'animal_hair']
senticnet['kleenex'] = [0.057, 0.111, 0, 0.143, '#interesting', '#admirable', 0.104, 'hankie', 'facial_tissue', 'hanky', 'handkerchief', 'tissue']
senticnet['klutz'] = [-0.958, 0, 0.504, -0.777, '#sad', '#disgusting', -0.746, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['knack'] = [0, 0.11, -0.059, 0.081, '#interesting', '#admirable', 0.044, 'skill', 'capacity', 'ability', 'competence', 'expertise']
senticnet['knacker'] = [-0.846, 0, 0.96, -0.91, '#angry', '#disgusting', -0.905, 'housewrecker', 'housebreaker', 'wrecker', 'laborer', 'manual_laborer']
senticnet['knackwurst'] = [0.662, -0.636, 0, 0.628, '#joyful', '#surprising', 0.642, 'sausage', 'knockwurst', 'salami', 'frank', 'hotdog']
senticnet['knavery'] = [0.847, -0.721, 0, 0.927, '#joyful', '#admirable', 0.832, 'wrongdoing', 'treachery', 'perfidy', 'charlatanism', 'treason']
senticnet['knee'] = [0.023, 0.085, -0.045, 0.088, '#interesting', '#admirable', 0.05, 'thigh', 'femur', 'joint', 'hip', 'above_leg']
senticnet['knee_bend'] = [0, -0.99, 0, 0.784, '#surprising', '#admirable', 0.591, 'bend_knee', 'bend_over', 'find_chair', 'keep_balance', 'tie_shoes']
senticnet['knee_breeches'] = [-0.589, 0, 0.757, -0.679, '#angry', '#disgusting', -0.675, 'breeches', 'trunk_hose', 'knee_pants', 'knickerbockers', 'knickers']
senticnet['knee_injury'] = [-0.933, 0, 0.439, -0.934, '#sad', '#disgusting', -0.769, 'injury', 'painful', 'pain', 'fall_down', 'hurt']
senticnet['knee_pants'] = [-0.589, 0, 0.757, -0.679, '#angry', '#disgusting', -0.675, 'breeches', 'knee_breeches', 'trunk_hose', 'knickerbockers', 'knickers']
senticnet['kneel'] = [-0.087, 0.187, -0.057, 0.108, '#interesting', '#admirable', 0.05, 'plan_wedding', 'trust_god', 'believe_god', 'down_knee', 'belief_god']
senticnet['kneel_down'] = [-0.116, -0.08, 0.022, -0.126, '#sad', '#disgusting', -0.061, 'learn_new_idea', 'drink_soda', 'desire_travel', 'complete_sentence', 'take_shit']
senticnet['knick-knack'] = [0, -0.018, 0.025, -0.09, '#angry', '#disgusting', -0.032, 'video_tape', 'bake_pan', 'coffee_mug', 'cookbook', 'movie']
senticnet['knickerbockers'] = [-0.589, 0, 0.757, -0.679, '#angry', '#disgusting', -0.675, 'breeches', 'knee_breeches', 'knee_pants', 'trunk_hose', 'knickers']
senticnet['knickers'] = [-0.589, 0, 0.757, -0.679, '#angry', '#disgusting', -0.675, 'breeches', 'knee_breeches', 'knee_pants', 'knickerbockers', 'trunk_hose']
senticnet['knickknackery'] = [0.629, -0.965, 0, 0.886, '#surprising', '#admirable', 0.827, 'curio', 'oddity', 'curiosity', 'peculiarity', 'oddment']
senticnet['knife'] = [0.825, 0.706, 0, 0, '#joyful', '#interesting', 0.51, 'hatchet', 'gun_knife', 'sword', 'bayonet', 'sharp_weapon']
senticnet['knife_sharp'] = [0, 0, 0.032, -0.079, '#angry', '#disgusting', -0.037, 'blade', 'sharp_edge', 'sharp', 'sharpness', 'edge']
senticnet['knight'] = [0, 0.766, 0, 0.95, '#interesting', '#admirable', 0.572, 'king', 'knight_protection', 'throne', 'noble', 'prince']
senticnet['knight_protection'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'protective_gear', 'metal_ore', 'lightweight_metal', 'metal', 'knight']
senticnet['knighthood'] = [0.976, -0.5, 0, 0.853, '#joyful', '#admirable', 0.776, 'aristocracy', 'elite', 'elite_group', 'noblesse', 'peerage']
senticnet['knit'] = [0, 0.99, 0, 0.905, '#interesting', '#admirable', 0.632, 'sew', 'thread_needle', 'needle_thread', 'use_needle', 'weave']
senticnet['knit_sweater'] = [0, -0.007, 0.047, -0.037, '#angry', '#disgusting', -0.026, 'cover_body', 'make_drape', 'weave', 'weave_cloth', 'make_cloth']
senticnet['knob'] = [0, 0, 0, 0.119, '#admirable', '#admirable', 0.04, 'door_knob', 'handle', 'lock', 'latch', 'hinge']
senticnet['knock'] = [0.085, 0, -0.051, 0.116, '#joyful', '#admirable', 0.05, 'dance_well', 'water_faucet', 'enter_contest', 'dance_type', 'dance_music']
senticnet['knock_against'] = [-0.871, 0, 0.545, -0.534, '#sad', '#angry', -0.65, 'run_into', 'strike', 'hit', 'impinge_on', 'collide_with']
senticnet['knock_door'] = [-0.103, 0, 0, 0, '#sad', '#sad', -0.034, 'erase_pencil_mark', 'smoke_cigar', 'pick_nose', 'make_card', 'cross_bridge']
senticnet['knock_into'] = [-0.943, 0, 0.095, -0.952, '#sad', '#disgusting', -0.663, 'knock', 'break', 'crack_up', 'break_it', 'kick']
senticnet['knock_off'] = [0.887, -0.737, 0, 0.603, '#joyful', '#surprising', 0.742, 'inflate', 'thin', 'downsize', 'subtract', 'trim_back']
senticnet['knocker'] = [0.979, -0.692, 0, 0.576, '#joyful', '#surprising', 0.749, 'big_cheese', 'supremo', 'important_person', 'influential_person', 'personage']
senticnet['knockout_punch'] = [-0.94, 0, 0.863, -0.984, '#sad', '#disgusting', -0.929, 'poke', 'clout', 'lick', 'punch', 'biff']
senticnet['knockwurst'] = [0.662, -0.636, 0, 0.628, '#joyful', '#surprising', 0.642, 'knackwurst', 'sausage', 'salami', 'frank', 'hotdog']
senticnet['knoll'] = [0, 0.093, 0, 0.078, '#interesting', '#admirable', 0.057, 'steep', 'landscape_feature', 'hill_mountain', 'hill', 'incline']
senticnet['knot'] = [0.751, 0, 0, 0.808, '#joyful', '#admirable', 0.52, 'ball_shape', 'geometrical', 'no_edge', 'geometric_shape', 'no_corner']
senticnet['knotty'] = [-0.93, 0, 0.861, -0.504, '#sad', '#angry', -0.765, 'crooked', 'contorted', 'writhed', 'writhen', 'anfractuous']
senticnet['know'] = [0.098, 0.165, -0.134, 0.284, '#interesting', '#admirable', 0.138, 'understand', 'know_fact', 'knowledge', 'great_understand', 'gain_insight']
senticnet['know_answer'] = [0, 0.899, 0, 0.846, '#interesting', '#admirable', 0.582, 'organize_thought', 'scratch_head', 'oral_exam', 'use_word', 'know_talk']
senticnet['know_better'] = [-0.728, 0, -0.853, 0, '#sad', '#scared', -0.527, 'find_another_person', 'help_understand', 'disagree', 'become_politician', 'investigation']
senticnet['know_come'] = [0.157, 0, 0, 0.153, '#joyful', '#admirable', 0.103, 'cake_eat', 'surprise_friend', 'special_event', 'child_birthday', 'special_happen']
senticnet['know_everything'] = [0.31, 0, 0.02, 0.229, '#joyful', '#admirable', 0.173, 'like_job', 'control_weather', 'live_ocean', 'like_play', 'wiseman']
senticnet['know_fact'] = [0.098, 0.165, -0.134, 0.284, '#interesting', '#admirable', 0.138, 'understand', 'great_understand', 'know', 'solution_to_problem', 'gain_insight']
senticnet['know_first'] = [0, 0.8, 0, 0.998, '#interesting', '#admirable', 0.599, 'recognize_pattern', 'solve_mystery', 'gather_fact', 'aware', 'come_conclusion']
senticnet['know_go'] = [-0.041, 0, 0.035, -0.115, '#sad', '#disgusting', -0.064, 'decide_to_go', 'buy_plane_ticket', 'buy_airplane_ticket', 'read_map', 'go_airport']
senticnet['know_happen'] = [-0.072, -0.071, 0.017, -0.251, '#sad', '#disgusting', -0.09, 'learn_current_event', 'understand_current_event', 'keep_up_current_event', 'expand_mind', 'eye_strain']
senticnet['know_happen_world'] = [0, -0.964, 0, 0.932, '#surprising', '#admirable', 0.632, 'learn', 'keep_up_current_event', 'take_up_time', 'understand_current_event', 'gain_knowledge']
senticnet['know_healthy'] = [-0.075, 0, -0.133, 0, '#sad', '#scared', -0.069, 'check_vital_sign', 'nervous_breakdown', 'physical_exam', 'examination', 'epileptic_fit']
senticnet['know_how'] = [0.098, 0.165, -0.134, 0.284, '#interesting', '#admirable', 0.138, 'solution_to_problem', 'find_out', 'know', 'find_answer', 'intelligence']
senticnet['know_how_drive'] = [-0.072, 0, 0.009, 0, '#sad', '#angry', -0.027, 'drive_license', 'start_car_engine', 'check_tire', 'find_car_key', 'put_key_ignition']
senticnet['know_how_play_baseball'] = [0, 0, 0.113, 0, '#angry', '#angry', -0.038, 'step_up_plate', 'find_other_player', 'join_team', 'find_someone_to_play_with', 'ball_player']
senticnet['know_how_read'] = [0, 0.087, 0, 0, '#interesting', '#interesting', 0.029, 'literate', 'learn_how_read', 'learn_read', 'open_up', 'literacy']
senticnet['know_how_spell'] = [0, 0.78, 0, 0.739, '#interesting', '#admirable', 0.506, 'learn_write', 'find_paper', 'language_skill', 'think_write', 'learn_spell']
senticnet['know_how_stock_market_perform'] = [0, -0.115, 0.024, 0.052, '#surprising', '#admirable', 0.048, 'give_plug', 'go_public', 'give_assistance', 'sex_same_gender', 'create_help_other_person']
senticnet['know_how_swim'] = [-0.032, 0, 0.044, 0, '#sad', '#angry', -0.025, 'put_bath_suit', 'go_water', 'go_pool', 'jump_in_water', 'go_swim_pool']
senticnet['know_information'] = [0.8, 0.858, 0, 0.605, '#joyful', '#interesting', 0.754, 'please_teacher', 'study_hard', 'learn_new', 'study_for_exam', 'become_educated']
senticnet['know_language'] = [0, 0.991, 0, 0.843, '#interesting', '#admirable', 0.611, 'convey_information', 'ability_communicate', 'fact_straight', 'know_talk', 'use_language']
senticnet['know_like'] = [0.707, 0.793, 0, 0, '#joyful', '#interesting', 0.5, 'find_out_want', 'go_shopping', 'drive_to_store', 'go_department_store', 'buy_diamond_ring']
senticnet['know_line'] = [0.926, 0.719, 0, 0, '#joyful', '#interesting', 0.548, 'rehearse', 'become_artist', 'go_end', 'become_actor', 'line']
senticnet['know_much'] = [0.945, 0.996, 0, 0.737, '#joyful', '#interesting', 0.893, 'learn', 'become_intelligent', 'seek_answer', 'get_smart', 'become_smart']
senticnet['know_new'] = [0.802, 0.795, 0, 0.839, '#joyful', '#admirable', 0.812, 'learn_much', 'read_out_loud', 'discover_new', 'gain_understand', 'know_world']
senticnet['know_nothing'] = [-0.901, 0, 0.76, -0.871, '#sad', '#disgusting', -0.844, 'analphabet', 'analphabetic', 'functional_illiterate', 'ignoramus', 'illiterate']
senticnet['know_other'] = [0, 0.998, 0, 0.983, '#interesting', '#admirable', 0.66, 'give_hug', 'shake_hand', 'introduce_oneself', 'say_hello', 'sexual_attraction']
senticnet['know_re_healthy'] = [-0.035, 0, -0.087, 0, '#sad', '#scared', -0.041, 'urinate', 'pee', 'empty_bladder', 'soak_hotspring', 'get_front_line']
senticnet['know_result'] = [0, 0, 0.063, -0.112, '#angry', '#disgusting', -0.058, 'solve', 'bored', 'need_information', 'get_information', 'inspiration']
senticnet['know_rule'] = [-0.052, 0.081, 0.021, 0.073, '#interesting', '#admirable', 0.027, 'know', 'find_play', 'learn_rule', 'knowledge_rule', 'join_team']
senticnet['know_start'] = [0, 0.839, 0, 0.769, '#interesting', '#admirable', 0.536, 'scheme', 'plan', 'eureka', 'schedule', 'timetable']
senticnet['know_story'] = [-0.082, -0.049, 0.046, -0.133, '#sad', '#disgusting', -0.071, 'receive_information', 'learn_oneself', 'pass_information', 'express_opinion', 'give_information']
senticnet['know_stuff'] = [-0.052, 0.081, 0.021, 0.073, '#interesting', '#admirable', 0.027, 'study_material', 'study_test', 'revise', 'learn_new', 'find_new']
senticnet['know_subject'] = [0.974, 0.966, 0, 0.938, '#joyful', '#interesting', 0.959, 'learn_much', 'better_understand', 'learn', 'increase_knowledge', 'gain_knowledge']
senticnet['know_subject_well'] = [-0.095, -0.067, 0.04, -0.205, '#sad', '#disgusting', -0.091, 'read_book_subject', 'study_hard', 'review_note', 'study_material', 'use_telescope']
senticnet['know_talk'] = [0, 0.874, 0, 0.801, '#interesting', '#admirable', 0.558, 'convey_information', 'know_language', 'fact_straight', 'ability_communicate', 'use_language']
senticnet['know_time'] = [0.154, 0.086, 0.03, 0.153, '#joyful', '#admirable', 0.121, 'keep_track_time', 'measure_passage_time', 'time_event', 'time_runner', 'time']
senticnet['know_truth'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'intelligence', 'know', 'know_much', 'accumulate_knowledge', 'understand']
senticnet['know_want'] = [0.022, 0.238, -0.081, 0.25, '#interesting', '#admirable', 0.143, 'dumpster_dive', 'search_item', 'make_selection', 'buy_diamond_ring', 'think_about_someone']
senticnet['know_well'] = [0.022, 0.238, -0.081, 0.25, '#interesting', '#admirable', 0.143, 'new_insight', 'aware', 'knowledge', 'know', 'well']
senticnet['know_world'] = [0.022, 0.238, -0.081, 0.25, '#interesting', '#admirable', 0.143, 'know', 'knowledge', 'gain_understand', 'knowledge_subject', 'know_well']
senticnet['knowing'] = [-0.5, 0, 0.775, -0.873, '#angry', '#disgusting', -0.716, 'farsightedness', 'prevision', 'apprehension', 'savvy', 'discernment']
senticnet['knowingness'] = [0.657, -0.88, 0, 0.631, '#joyful', '#surprising', 0.723, 'cognisance', 'feel', 'awareness', 'cognizance', 'consciousness']
senticnet['knowledge'] = [0, 0.801, 0, 0.789, '#interesting', '#admirable', 0.53, 'know', 'understand', 'trivia', 'gain_insight', 'great_understand']
senticnet['knowledge_power'] = [-0.054, 0, 0, -0.106, '#sad', '#disgusting', -0.053, 'pass_test', 'make_parent_happy', 'take_test', 'study_test', 'get_grade']
senticnet['knowledge_rule'] = [-0.052, 0.081, 0.021, 0.073, '#interesting', '#admirable', 0.027, 'know', 'find_play', 'learn_rule', 'know_rule', 'join_team']
senticnet['knowledge_subject'] = [0.772, 0.724, 0, 0, '#joyful', '#interesting', 0.499, 'study_for_exam', 'knowledge', 'know_world', 'revise', 'learn_new']
senticnet['knowledgeable'] = [0.97, 0.707, 0, 0.741, '#joyful', '#admirable', 0.806, 'much_need', 'taken_seriously', 'good_sense_of_humor', 'complement', 'spice_life']
senticnet['known'] = [0.268, 0.231, 0, 0.145, '#joyful', '#interesting', 0.215, 'much_need', 'smooth_skin', 'save_world', 'good_sense_of_humor', 'simplicity']
senticnet['knuckle'] = [0, 0.781, 0, 0.733, '#interesting', '#admirable', 0.505, 'touch', 'thumb', 'rub', 'handmaid', 'grasp']
senticnet['knuckle_under'] = [0.542, -0.575, 0, 0.929, '#surprising', '#admirable', 0.682, 'consent', 'give_in', 'go_for', 'submit', 'accept']
senticnet['knucklehead'] = [-0.668, 0, 0.85, -0.794, '#angry', '#disgusting', -0.771, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['ko_punch'] = [-0.978, 0, 0.83, -0.665, '#sad', '#angry', -0.824, 'poke', 'clout', 'lick', 'punch', 'biff']
senticnet['koala'] = [0, 0.901, 0, 0.702, '#interesting', '#admirable', 0.534, 'monkey', 'marmoset', 'lemur', 'beaver', 'fiance']
senticnet['kooky'] = [0, 0.908, 0, 0.765, '#interesting', '#admirable', 0.558, 'daft', 'balmy', 'barmy', 'bonkers', 'loony']
senticnet['kowtow'] = [-0.106, 0, -0.053, -0.24, '#sad', '#disgusting', -0.133, 'adulate', 'suck_up', 'toady', 'bootlick', 'blandish']
senticnet['kraft'] = [-0.741, 0, 0.907, -0.865, '#angry', '#disgusting', -0.838, 'gift_wrap', 'wrapping_paper', 'wrap_gift', 'butcher_paper', 'paper']
senticnet['kraft_paper'] = [-0.741, 0, 0.907, -0.865, '#angry', '#disgusting', -0.838, 'gift_wrap', 'kraft', 'wrapping_paper', 'butcher_paper', 'paper']
senticnet['krait'] = [-0.517, 0, 0.582, -0.976, '#angry', '#disgusting', -0.692, 'death_adder', 'ophidian', 'serpent', 'elapid', 'taipan']
senticnet['kraurosis'] = [-0.869, 0, 0.738, -0.93, '#sad', '#disgusting', -0.846, 'amyotrophia', 'amyotrophy', 'tabes', 'wasting_away', 'symptom']
senticnet['kudos'] = [0.996, -0.824, 0, 0.569, '#joyful', '#surprising', 0.796, 'superlative', 'compliment', 'testimonial', 'good_word', 'approval']
senticnet['kvetch'] = [-0.747, 0, 0.68, -0.586, '#sad', '#angry', -0.671, 'whiner', 'complainer', 'moaner', 'sniveller', 'crybaby']
senticnet['kwashiorkor'] = [-0.712, 0, 0.74, -0.506, '#sad', '#angry', -0.653, 'malnutrition', 'marasmus', 'avitaminosis', 'hypovitaminosis', 'deficiency_disease']
senticnet['kyphosis'] = [-0.942, 0, 0.87, -0.902, '#sad', '#disgusting', -0.905, 'lordosis', 'spinal_curvature', 'humpback', 'hunchback', 'abnormality']
senticnet['lab'] = [0.03, 0.117, 0, 0.084, '#interesting', '#admirable', 0.077, 'laboratory', 'elementary_school', 'science_class', 'college_class', 'doctor_office']
senticnet['lab_coat'] = [0, 0, -0.055, -0.124, '#scared', '#disgusting', -0.06, 'scientist', 'geology', 'doctor_office', 'protractor', 'coat']
senticnet['lab_rat'] = [0, 0, -0.102, 0, '#scared', '#scared', -0.034, 'lonely_person', 'vegetarian', 'raccoon', 'hermit', 'user']
senticnet['label'] = [0, 0.115, 0.036, 0.207, '#interesting', '#admirable', 0.095, 'total', 'amount', 'merit', 'award', 'excellence']
senticnet['labeler'] = [0.044, 0.08, 0, -0.03, '#joyful', '#interesting', 0.031, 'birthday_card', 'restaurant_bill', 'bake_pan', 'account_book', 'computer_monitor']
senticnet['labial_herpes'] = [-0.964, 0, 0.726, -0.848, '#sad', '#disgusting', -0.846, 'herpes', 'herpes_virus', 'herpes_simplex', 'herpes_simplex_virus', 'virus']
senticnet['labile'] = [0.766, -0.875, 0, 0.666, '#joyful', '#surprising', 0.769, 'oxidizable', 'unstable', 'reactive', 'activated', 'excited']
senticnet['labor'] = [-0.042, 0.136, -0.114, 0.119, '#interesting', '#admirable', 0.033, 'task', 'job', 'hire', 'employment', 'hire_help']
senticnet['labor_pain'] = [-0.735, 0, 0.555, -0.908, '#sad', '#disgusting', -0.733, 'aching', 'dysmenorrhea', 'hurting', 'neuralgia', 'neuralgy']
senticnet['laboratory'] = [-0.042, 0.136, -0.114, 0.119, '#interesting', '#admirable', 0.033, 'computer_lab', 'use_computer', 'lab', 'scientist', 'laborer']
senticnet['laborer'] = [0, 0.126, -0.075, 0.104, '#interesting', '#admirable', 0.052, 'worker', 'occupation', 'blue_collar', 'profession', 'helper']
senticnet['laboriousness'] = [-0.646, 0, 0.928, -0.703, '#angry', '#disgusting', -0.759, 'difficulty', 'arduousness', 'strenuousness', 'effortfulness', 'operoseness']
senticnet['labrocyte'] = [-0.665, 0, 0.877, -0.642, '#sad', '#angry', -0.728, 'mast_cell', 'mastocyte', 'somatic_cell', 'target_cell', 'phagocyte']
senticnet['labyrinthitis'] = [-0.879, 0, 0.773, -0.907, '#sad', '#disgusting', -0.853, 'rubor', 'redness', 'inflammation', 'otitis', 'otitis_interna']
senticnet['lace'] = [-0.713, 0, 0.539, -0.889, '#sad', '#disgusting', -0.714, 'shoe_string', 'shoestring', 'cord', 'bootlace', 'shoelace']
senticnet['lacerate'] = [-0.103, -0.063, 0.02, -0.181, '#sad', '#disgusting', -0.08, 'slash', 'sever', 'chop_wood', 'spread_butter', 'slit']
senticnet['laceration'] = [-0.12, -0.042, 0, -0.178, '#sad', '#disgusting', -0.085, 'cause_bleed', 'open_wind', 'gash', 'lacerate', 'painful_injury']
senticnet['lachrymose'] = [-0.71, 0.312, -0.4, -0.08, '#sad', '#scared', -0.293, 'tearful', 'weeping', 'dolorous', 'tearfulness', 'weepiness']
senticnet['lacing'] = [-0.59, 0, 0.939, -0.767, '#angry', '#disgusting', -0.765, 'liquor', 'spirits', 'booze', 'hard_drink', 'hard_liquor']
senticnet['lack'] = [-0.71, 0.312, -0.4, -0.08, '#sad', '#scared', -0.293, 'lack_energy', 'lack_money', 'lack_of_sleep', 'lack_time', 'lack_light']
senticnet['lack_brightness'] = [-0.078, 0, -0.048, 0, '#sad', '#scared', -0.042, 'lack_interest', 'become_dull', 'boring', 'tedious', 'dark']
senticnet['lack_energy'] = [-0.717, 0, 0, -0.732, '#sad', '#disgusting', -0.483, 'exhaustion', 'get_out_breath', 'tiredness', 'become_wind', 'shin_splint']
senticnet['lack_interest'] = [-0.078, 0, -0.048, 0, '#sad', '#scared', -0.042, 'become_dull', 'lack_brightness', 'boring', 'tedious', 'dark']
senticnet['lack_light'] = [-0.361, -0.065, -0.093, -0.122, '#sad', '#disgusting', -0.17, 'catch_rain', 'cold_weather', 'coldness', 'frozen', 'rainy_day']
senticnet['lack_money'] = [-0.133, 0.068, -0.105, -0.067, '#sad', '#scared', -0.079, 'sell_stock', 'count_money', 'need_money', 'unemployment', 'earn_money']
senticnet['lack_of_attraction'] = [-0.906, 0, 0.877, -0.911, '#sad', '#disgusting', -0.898, 'boring_activity', 'feel_bored', 'feel_tired', 'boring_movie', 'boring_show']
senticnet['lack_of_confident'] = [-0.918, 0, 0.653, -0.957, '#sad', '#disgusting', -0.843, 'feel_down', 'feel_inferior', 'depress', 'unhappy', 'weak']
senticnet['lack_of_discernment'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'lack_of_judgment', 'lack_of_discreetness', 'injudiciousness', 'reckless', 'rentless']
senticnet['lack_of_discreetness'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'lack_of_judgment', 'injudiciousness', 'lack_of_discernment', 'reckless', 'rentless']
senticnet['lack_of_energy'] = [0, 0.887, 0, 0.714, '#interesting', '#admirable', 0.534, 'diet', 'fast_day', 'sacrifice', 'religious', 'avoid_food']
senticnet['lack_of_exercise'] = [-0.061, 0, -0.06, 0, '#sad', '#scared', -0.04, 'high_cholesterol', 'fat', 'lazy', 'fat_guy', 'round']
senticnet['lack_of_food'] = [-0.987, 0, 0.989, -0.933, '#sad', '#angry', -0.97, 'run_out_of_time', 'run_out_of_money', 'almost_finish', 'run_out', 'low_battery']
senticnet['lack_of_judgment'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'injudiciousness', 'lack_of_discreetness', 'lack_of_discernment', 'reckless', 'rentless']
senticnet['lack_of_quality'] = [-0.762, 0, 0.783, -0.935, '#angry', '#disgusting', -0.827, 'insufficiency', 'sparseness', 'sparsity', 'abstemiousness', 'lack_of_quantity']
senticnet['lack_of_quantity'] = [-0.762, 0, 0.783, -0.935, '#angry', '#disgusting', -0.827, 'insufficiency', 'sparseness', 'sparsity', 'abstemiousness', 'lack_of_quality']
senticnet['lack_of_rest'] = [0, 0, 0.933, -0.863, '#angry', '#disgusting', -0.599, 'tired', 'energy_exhaustion', 'need_rest', 'exhausted', 'dead_tired']
senticnet['lack_of_rules'] = [-0.819, -0.715, 0.843, -0.726, '#sad', '#angry', -0.558, 'anarchism', 'fascism', 'despot', 'tyrant', 'nazism']
senticnet['lack_of_sleep'] = [-0.874, 0, 0, -0.765, '#sad', '#disgusting', -0.546, 'tiredness', 'sore_knee', 'tired', 'sleepiness', 'fatigue']
senticnet['lack_of_water'] = [-0.061, 0, 0, -0.037, '#sad', '#disgusting', -0.033, 'friction', 'abrasive', 'dirt', 'sand', 'ground_material']
senticnet['lack_time'] = [-0.399, 0, 0.029, -0.442, '#sad', '#disgusting', -0.29, 'psychosis', 'discomfort', 'anxiety', 'hurt_feeling', 'frustration']
senticnet['lackadaisical'] = [-0.751, 0, 0, -0.823, '#sad', '#disgusting', -0.525, 'languorous', 'languid', 'languor', 'languorously', 'careless']
senticnet['lackey'] = [-0.127, 0, 0, 0, '#sad', '#sad', -0.042, 'get_done', 'free_slave', 'earn_paycheck', 'work_hard', 'finish_task']
senticnet['lacking'] = [-0.587, 0, 0.996, -0.848, '#angry', '#disgusting', -0.81, 'undermanned', 'understaffed', 'deficient', 'inadequate', 'wanting']
senticnet['laconicism'] = [-0.666, 0, 0.812, -0.881, '#angry', '#disgusting', -0.786, 'laconism', 'terseness', 'conciseness', 'concision', 'pithiness']
senticnet['laconism'] = [-0.666, 0, 0.812, -0.881, '#angry', '#disgusting', -0.786, 'terseness', 'laconicism', 'conciseness', 'concision', 'pithiness']
senticnet['lacquer'] = [-0.944, 0, 0.569, -0.721, '#sad', '#disgusting', -0.745, 'bitumastic', 'veneer', 'veneering', 'coating', 'seal']
senticnet['lactase_deficiency'] = [-0.799, 0, 0.949, -0.727, '#sad', '#angry', -0.825, 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect', 'congenital_disease']
senticnet['lactobacillus'] = [-0.998, 0, 0.987, -0.965, '#sad', '#angry', -0.983, 'acidophilus', 'probiotic', 'probiotic_bacterium', 'probiotic_microflora', 'probiotic_flora']
senticnet['lactobacillus_acidophilus'] = [-0.509, 0, 0.656, -0.933, '#angry', '#disgusting', -0.699, 'lactobacillus', 'probiotic', 'probiotic_bacterium', 'probiotic_microflora', 'probiotic_flora']
senticnet['lactose'] = [0.04, 0, 0, 0.144, '#joyful', '#admirable', 0.061, 'liquid', 'fluid', 'potable_liquid', 'white_color', 'like_food']
senticnet['lactose_intolerance'] = [-0.866, 0, 0.76, -0.976, '#sad', '#disgusting', -0.867, 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect', 'congenital_disease']
senticnet['lad'] = [0.029, 0.076, 0, 0, '#joyful', '#interesting', 0.035, 'youngster', 'teenager', 'junior', 'adolescent', 'maturity']
senticnet['laden'] = [-0.834, 0.214, -0.391, -0.108, '#sad', '#scared', -0.373, 'oppressiveness', 'tyrannical', 'downtrodden', 'oppressive', 'tyrannous']
senticnet['ladies_slipper'] = [0.277, 0.161, 0, 0.337, '#joyful', '#admirable', 0.258, 'moccasin_flower', 'nerveroot', 'showy_lady_slipper', 'yellow_lady_slipper', 'clustered_lady_slipper']
senticnet['ladle'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'address_book', 'get_rich', 'blank_check', 'swiss_army_knife', 'whisk']
senticnet['lady'] = [0, 0.98, 0, 0.989, '#interesting', '#admirable', 0.656, 'wench', 'female', 'lesbian', 'princess', 'girl']
senticnet['lady_hair'] = [0.716, 0.859, 0, 0, '#joyful', '#interesting', 0.525, 'beauty_shop', 'beauty_parlor', 'barber_shop', 'hair_salon', 'beauty_salon']
senticnet['lady_like'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'sexy', 'elegant', 'classy', 'slim', 'black_dress']
senticnet['lady_maid'] = [-0.626, 0, 0.649, -0.673, '#angry', '#disgusting', -0.649, 'handmaid', 'handmaiden', 'chambermaid', 'maid', 'parlormaid']
senticnet['lady_of_pleasure'] = [-0.749, 0, 0.69, -0.891, '#sad', '#disgusting', -0.777, 'slattern', 'camp_follower', 'call_girl', 'comfort_woman', 'ianfu']
senticnet['lady_slipper'] = [-0.628, 0, 0.96, -0.853, '#angry', '#disgusting', -0.814, 'moccasin_flower', 'nerveroot', 'showy_lady_slipper', 'yellow_lady_slipper', 'clustered_lady_slipper']
senticnet['lady_underwear'] = [0.803, 0.902, 0, 0, '#joyful', '#interesting', 0.568, 'under_garment', 'undergarment', 'underwear', 'woman_clothes', 'pantie']
senticnet['ladybug'] = [-0.026, -0.077, 0.12, -0.109, '#angry', '#disgusting', -0.059, 'ant', 'gnat', 'gypsy_moth', 'mole_cricket', 'cucumber_beetle']
senticnet['ladylike'] = [0.614, -0.959, 0, 0.537, '#joyful', '#surprising', 0.703, 'mincing', 'twee', 'gentlemanlike', 'gentlemanly', 'refined']
senticnet['lag'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'put_off', 'delay', 'retard', 'postpone', 'procrastination']
senticnet['laggard'] = [-0.648, 0, 0.879, -0.98, '#angry', '#disgusting', -0.836, 'drone', 'poke', 'dawdler', 'straggler', 'lagger']
senticnet['lagger'] = [-0.648, 0, 0.879, -0.98, '#angry', '#disgusting', -0.836, 'drone', 'poke', 'dawdler', 'laggard', 'straggler']
senticnet['lair'] = [0, 0.076, 0.024, 0.137, '#interesting', '#admirable', 0.063, 'kennel', 'hive', 'animal_home', 'habitat', 'beehive']
senticnet['laissez_faire'] = [-0.884, 0, 0.62, -0.619, '#sad', '#angry', -0.708, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['lake'] = [0.954, 0.926, 0, 0, '#joyful', '#interesting', 0.627, 'harpoon', 'gulf', 'armory', 'river', 'bay']
senticnet['lake_river'] = [0, -0.033, 0.053, -0.057, '#angry', '#disgusting', -0.026, 'puddle', 'beach', 'waterfall', 'sandy_beach', 'bay']
senticnet['lallation'] = [-0.846, 0, 0.829, -0.546, '#sad', '#angry', -0.74, 'upset', 'dysarthria', 'dysphonia', 'disorder', 'defect_of_speech']
senticnet['lam'] = [-0.691, 0, 0.998, -0.84, '#angry', '#disgusting', -0.843, 'evasion', 'escape', 'break', 'skedaddle', 'hegira']
senticnet['lamb'] = [0, 0.716, 0, 0.874, '#interesting', '#admirable', 0.53, 'servant', 'goat', 'hog', 'peasant', 'shepherd']
senticnet['lamb_meat'] = [0, -0.036, 0.057, -0.089, '#angry', '#disgusting', -0.037, 'shear', 'bandage', 'ewe', 'mutton', 'seam']
senticnet['lamb_roast'] = [0.783, -0.635, 0, 0.829, '#joyful', '#admirable', 0.749, 'leg_of_lamb', 'gigot', 'joint', 'roast', 'rack_of_lamb']
senticnet['lambaste'] = [0, 0, -0.789, -0.923, '#scared', '#disgusting', -0.571, 'rebuke', 'take_to_task', 'flog', 'call_on_carpet', 'cane']
senticnet['lamborghini'] = [0.755, 0.702, 0, 0, '#joyful', '#interesting', 0.486, 'high_class', 'expensive_car', 'ferrari', 'fancy_car', 'sports_car']
senticnet['lame'] = [0, 0, 0.868, -0.708, '#angry', '#disgusting', -0.525, 'gimpy', 'feeble', 'crippled', 'square', 'halt']
senticnet['lame_duck'] = [0.984, -0.933, 0, 0.927, '#joyful', '#surprising', 0.948, 'elected_official', 'lieutenant_governor', 'selectman', 'selectwoman', 'official']
senticnet['lameness'] = [0.789, -0.998, 0, 0.54, '#joyful', '#surprising', 0.776, 'imperfection', 'imperfectness', 'bugginess', 'defectiveness', 'sickness']
senticnet['lament'] = [-0.853, 0, 0.752, -0.737, '#sad', '#angry', -0.781, 'feel_sorry', 'sadness', 'depression', 'deep_sadness', 'negative_feeling']
senticnet['lamentably'] = [-0.883, 0.174, -0.597, 0, '#sad', '#scared', -0.435, 'deplorably', 'woefully', 'bereaved', 'bereft', 'grief-stricken']
senticnet['lamenter'] = [-0.693, 0, 0.88, -0.927, '#angry', '#disgusting', -0.833, 'unfortunate', 'unfortunate_person', 'weeper', 'pallbearer', 'bearer']
senticnet['lamisil'] = [0.932, -0.56, 0, 0.617, '#joyful', '#admirable', 0.703, 'antifungal', 'antifungal_agent', 'fungicide', 'antimycotic', 'antimycotic_agent']
senticnet['lamp'] = [0.046, -0.03, 0, 0, '#joyful', '#surprising', 0.025, 'light', 'bay_window', 'air_conditioner', 'sky', 'skylight']
senticnet['lampoon'] = [-0.899, 0, -0.802, 0, '#sad', '#scared', -0.567, 'mockery', 'spoof', 'sendup', 'takeoff', 'parody']
senticnet['lance'] = [0.932, -0.521, 0, 0.534, '#joyful', '#admirable', 0.662, 'surgical_knifet', 'catling', 'surgical_knife', 'scalpel', 'knife']
senticnet['lancet'] = [0.932, -0.521, 0, 0.534, '#joyful', '#admirable', 0.662, 'surgical_knife', 'catling', 'lance', 'scalpel', 'knife']
senticnet['land'] = [0.716, -0.51, 0, 0.647, '#joyful', '#admirable', 0.624, 'state', 'nation', 'country', 'ally', 'commonwealth']
senticnet['land_area'] = [0.028, 0.074, 0.025, 0.088, '#interesting', '#admirable', 0.055, 'ground', 'land_mass', 'large_land', 'large_state', 'large_land_mass']
senticnet['land_earth'] = [-0.061, 0, 0, -0.047, '#sad', '#disgusting', -0.036, 'septic_tank', 'spurt', 'crush_ice', 'down_drain', 'brine']
senticnet['land_feature'] = [0, 0.094, 0.03, 0.097, '#interesting', '#admirable', 0.054, 'geographical_feature', 'land_formation', 'land_form', 'geographic_feature', 'landscape_feature']
senticnet['land_fish'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'communication_system', 'fish', 'catch_fish', 'triathlon', 'bait']
senticnet['land_form'] = [0, 0.082, 0.042, 0.058, '#interesting', '#admirable', 0.033, 'land_formation', 'geographical_feature', 'land_feature', 'geographic_feature', 'large_land_mass']
senticnet['land_formation'] = [0, 0.088, 0.045, 0.074, '#interesting', '#admirable', 0.039, 'land_form', 'geographical_feature', 'geographic_feature', 'land_feature', 'landscape_feature']
senticnet['land_ground'] = [0, -0.008, 0.03, -0.049, '#angry', '#disgusting', -0.024, 'full_bladder', 'throw_away_trash', 'hold_liquid', 'drink', 'hold_beverage']
senticnet['land_mass'] = [0.042, 0.082, 0.026, 0, '#joyful', '#interesting', 0.033, 'boundary', 'border', 'territory', 'land_area', 'large_border']
senticnet['land_measurement'] = [0, 0.119, 0.06, 0.158, '#interesting', '#admirable', 0.072, 'area_land', 'plenty', 'measurement', 'area', 'meter']
senticnet['land_moon'] = [0, 0, -0.135, 0, '#scared', '#scared', -0.045, 'womb', 'anus', 'sister_house', 'gone_moon', 'asshole']
senticnet['land_owner'] = [0.02, 0.188, -0.074, 0.196, '#interesting', '#admirable', 0.11, 'laborer', 'blue_collar', 'own_land', 'own_person', 'helper']
senticnet['land_plane'] = [0, 0.119, 0.06, 0.158, '#interesting', '#admirable', 0.072, 'travel_by_airplane', 'travel_abroad', 'pilot', 'plane', 'transport']
senticnet['land_runway'] = [-0.029, 0, 0.042, -0.08, '#angry', '#disgusting', -0.05, 'bus_person', 'travel_across_world', 'arrive_late', 'drop_bomb', 'cool_engine']
senticnet['land_sea'] = [0.885, 0, 0, 0.735, '#joyful', '#admirable', 0.54, 'vast', 'along_beach', 'near_beach', 'big_blue', 'full_water']
senticnet['landed_estate'] = [0.975, -0.789, 0, 0.969, '#joyful', '#admirable', 0.911, 'demesne', 'estate', 'land', 'barony', 'acre']
senticnet['landfill'] = [0.726, 0.931, 0, 0, '#joyful', '#interesting', 0.552, 'dump', 'utility_room', 'trash_bin', 'tool_shed', 'antique_store']
senticnet['landing_field'] = [-0.975, 0, 0.737, -0.979, '#sad', '#disgusting', -0.897, 'flare_path', 'airfield', 'airstrip', 'flying_field', 'field']
senticnet['landing_strip'] = [-0.703, 0, 0.621, -0.632, '#sad', '#disgusting', -0.652, 'flare_path', 'airfield', 'landing_field', 'flying_field', 'field']
senticnet['landmark'] = [0, 0.111, 0, 0.07, '#interesting', '#admirable', 0.06, 'grid_object', 'system_abstract_think', 'eiffel_tower', 'piece_of_information', 'monument']
senticnet['landmass'] = [0, 0.076, 0, 0, '#interesting', '#interesting', 0.025, 'region', 'land', 'land_mass', 'political_unit', 'territory']
senticnet['landrover'] = [0.905, -0.994, 0, 0.704, '#joyful', '#surprising', 0.868, 'car', 'auto', 'automobile', 'machine', 'motorcar']
senticnet['landscape_feature'] = [0, 0.099, 0.035, 0.129, '#interesting', '#admirable', 0.064, 'geographic_feature', 'knoll', 'land_formation', 'land_feature', 'high_land']
senticnet['lane'] = [0, 0, 0.033, -0.045, '#angry', '#disgusting', -0.026, 'boulevard', 'curb', 'thoroughfare', 'intersection', 'avenue']
senticnet['language'] = [0, 0, 0, 0.115, '#admirable', '#admirable', 0.038, 'human_language', 'speech', 'enunciation', 'spoken', 'say']
senticnet['language_barrier'] = [-0.939, 0, -0.998, -0.928, '#sad', '#scared', -0.955, 'barrier', 'shut', 'shut_down', 'close_down', 'obstacle']
senticnet['language_part'] = [0.049, 0.082, -0.047, 0.119, '#interesting', '#admirable', 0.068, 'readable', 'written_text', 'language', 'make_book', 'part_of_speech']
senticnet['language_skill'] = [0.797, 0.967, 0, 0, '#joyful', '#interesting', 0.588, 'learn_write', 'find_paper', 'know_how_spell', 'think_write', 'learn_spell']
senticnet['languid'] = [-0.967, 0, -0.97, 0, '#sad', '#scared', -0.646, 'languorous', 'lackadaisical', 'dreamy', 'languor', 'languorously']
senticnet['languish'] = [-0.876, 0, -0.955, 0, '#sad', '#scared', -0.61, 'waste', 'ache', 'yearn', 'yen', 'pine_away']
senticnet['languor'] = [0.509, 0.65, -0.251, 0.255, '#joyful', '#interesting', 0.388, 'languorous', 'languid', 'lackadaisical', 'dreamy', 'languorously']
senticnet['languorous'] = [0.509, 0.65, -0.251, 0.255, '#joyful', '#interesting', 0.388, 'languid', 'lackadaisical', 'dreamy', 'languor', 'languorously']
senticnet['languorously'] = [0.509, 0.65, -0.251, 0.255, '#joyful', '#interesting', 0.388, 'languorous', 'languid', 'lackadaisical', 'dreamy', 'languor']
senticnet['lantern'] = [0.091, 0, 0.034, 0.049, '#joyful', '#admirable', 0.035, 'heat_source', 'candle', 'heater', 'illuminate_room', 'furnace']
senticnet['lantern_jaw'] = [0.886, -0.997, 0, 0.542, '#joyful', '#surprising', 0.808, 'jowl', 'lower_jaw', 'mandible', 'mandibula', 'mandibular_bone']
senticnet['lap'] = [0.159, 0.068, -0.079, 0.118, '#joyful', '#admirable', 0.089, 'stomach', 'uterus', 'pregnant', 'womb', 'gravid']
senticnet['lapidation'] = [-0.839, 0, 0.924, -0.79, '#sad', '#angry', -0.851, 'kick_in_butt', 'licking', 'whacking', 'stoning', 'corporal_punishment']
senticnet['lapsed'] = [-0.932, 0, 0.75, -0.645, '#sad', '#angry', -0.776, 'heathen', 'heathenish', 'pagan', 'irreligious', 'nonchurchgoing']
senticnet['laptop'] = [0, 0.986, 0, 0.819, '#interesting', '#admirable', 0.602, 'processor', 'browse_web', 'computer_type', 'desktop', 'language']
senticnet['larceny'] = [-0.518, 0, 0.717, -0.758, '#angry', '#disgusting', -0.664, 'raid', 'thieving', 'plunderage', 'embezzlement', 'theft']
senticnet['lard'] = [0.037, 0, 0, 0.063, '#joyful', '#admirable', 0.033, 'food_type', 'food_group', 'carbohydrate', 'starch', 'staple_food']
senticnet['large'] = [0.032, 0.085, 0.049, 0.222, '#interesting', '#admirable', 0.097, 'big', 'wide', 'huge', 'really_big', 'tall']
senticnet['large-hearted'] = [0.552, 0.681, -0.294, 0.297, '#joyful', '#interesting', 0.412, 'charitable', 'good-hearted', 'openhearted', 'benevolent', 'kindly']
senticnet['large_amount'] = [0, 0.208, 0, 0.291, '#interesting', '#admirable', 0.166, 'a_lot', 'abundance', 'large_mass', 'human_mass', 'number_person']
senticnet['large_area'] = [0.026, 0.072, 0.024, 0.101, '#interesting', '#admirable', 0.058, 'large_state', 'large_land', 'political_division', 'land_area', 'big_land']
senticnet['large_area_land'] = [0.026, 0.159, 0, 0, '#joyful', '#interesting', 0.062, 'own_flag', 'large_area', 'political_division', 'large_state', 'region']
senticnet['large_automobile'] = [0.027, 0, 0.026, 0.073, '#joyful', '#admirable', 0.025, 'automatic_car', 'expensive_car', 'limousine', 'means_of_transport', 'roulotte']
senticnet['large_boat'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'big_boat', 'boat', 'small_boat', 'water_vehicle', 'ship']
senticnet['large_body'] = [0, 0.963, 0, 0.746, '#interesting', '#admirable', 0.57, 'water', 'make_up_water', 'cover_water', 'water_spill', 'adenozine']
senticnet['large_breadbox'] = [0, 0.073, 0.009, 0.122, '#interesting', '#admirable', 0.062, 'smart_animal', 'person', 'domestic_animal', 'human', 'big_person']
senticnet['large_build'] = [0, 0.887, 0, 0.787, '#interesting', '#admirable', 0.558, 'architectural_structure', 'build', 'home_build', 'architect', 'build_support']
senticnet['large_building'] = [0, 0.119, 0, 0.095, '#interesting', '#admirable', 0.071, 'building', 'government', 'govern_city', 'government_building', 'accommodation']
senticnet['large_business'] = [0.091, 0.186, 0, 0.211, '#interesting', '#admirable', 0.163, 'business_firm', 'partnership', 'business_organization', 'business_group', 'company']
senticnet['large_car'] = [0.027, 0, 0, 0.146, '#joyful', '#admirable', 0.058, 'long_car', 'big_car', 'machine_transportation', 'car_type', 'work_well']
senticnet['large_cat'] = [-0.025, 0, 0.044, 0, '#sad', '#angry', -0.023, 'fast_person', 'carnivore', 'household_pet', 'big_cat', 'good_pet']
senticnet['large_city'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'jerusalem', 'jewish_community', 'vatican', 'big_city', 'major_city']
senticnet['large_city_shop_mall'] = [0, 0, 0.051, -0.032, '#angry', '#disgusting', -0.028, 'suburban_shop_mall', 'mini_mall', 'corner_shop', 'corner_grocery', 'large_food_store']
senticnet['large_company'] = [0.069, 0.159, 0, 0.167, '#interesting', '#admirable', 0.132, 'business_group', 'group_company', 'business_firm', 'large_business', 'partnership']
senticnet['large_container'] = [0, 0, 0, 0.128, '#admirable', '#admirable', 0.043, 'wooden_spoon', 'caffeine', 'teaspoon', 'container_cup', 'cereal_bowl']
senticnet['large_corporation'] = [0.028, 0.087, 0, 0.085, '#interesting', '#admirable', 0.067, 'corporation', 'expensive_car', 'business', 'large_group', 'motor_vehicle']
senticnet['large_country'] = [0.043, 0.109, 0, 0.061, '#interesting', '#admirable', 0.071, 'nation_state', 'democratic_country', 'free_country', 'international', 'republic']
senticnet['large_crowd'] = [0, 0.952, 0, 0.99, '#interesting', '#admirable', 0.647, 'public', 'crowd', 'entertain_crowd', 'committee', 'audience']
senticnet['large_cup'] = [0.03, 0, 0.022, 0.062, '#joyful', '#admirable', 0.023, 'beer_container', 'hold_drink', 'cool_drink', 'store_ice_cream', 'drink_holder']
senticnet['large_dog'] = [0.956, 0.963, 0, 0.764, '#joyful', '#interesting', 0.894, 'good_weather', 'dog_like', 'type_of_dog', 'future_robot', 'sunny_day']
senticnet['large_eye'] = [-0.034, 0, 0.039, 0, '#sad', '#angry', -0.024, 'fur_keep_warm', 'no_hair', 'sharp_tooth', 'tic', 'stick_out']
senticnet['large_family'] = [0, 0, 0, 0.939, '#admirable', '#admirable', 0.313, 'baby', 'small_child', 'youth', 'quiet_baby', 'deliver_baby']
senticnet['large_food_store'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'large_supermarket', 'food_store', 'convenience_food_store', 'corner_shop', 'corner_grocery']
senticnet['large_group'] = [0.068, 0.129, 0, 0.143, '#interesting', '#admirable', 0.113, 'big_group', 'large_number', 'bunch_person', 'multitude', 'group']
senticnet['large_house'] = [-0.059, 0.116, -0.044, 0.102, '#interesting', '#admirable', 0.038, 'house', 'dwelling', 'multi-story_build', 'rent_out', 'lease']
senticnet['large_indefinite_amount'] = [-0.64, 0, 0.87, -0.745, '#angry', '#disgusting', -0.752, 'infinitude', 'piles', 'mess', 'large_number', 'tons']
senticnet['large_indefinite_quantity'] = [-0.636, 0, 0.708, -0.967, '#angry', '#disgusting', -0.77, 'infinitude', 'piles', 'mess', 'large_number', 'tons']
senticnet['large_integer'] = [0.787, -0.527, 0, 0.806, '#joyful', '#admirable', 0.707, 'gross', 'century', 'grand', 'million', 'billion']
senticnet['large_land'] = [0, 0.067, 0.04, 0.091, '#interesting', '#admirable', 0.039, 'big_land', 'land_area', 'large_area', 'land', 'large_state']
senticnet['large_land_mass'] = [0.042, 0.082, 0.026, 0, '#joyful', '#interesting', 0.033, 'boundary', 'land_mass', 'territory', 'land_area', 'border']
senticnet['large_mammal'] = [0.029, 0, 0.018, 0.059, '#joyful', '#admirable', 0.023, 'domestic_animal', 'wild_animal', 'hoof_mammal', 'big_animal', 'animal']
senticnet['large_mass'] = [0.027, 0.095, 0.011, 0.178, '#interesting', '#admirable', 0.096, 'large_amount', 'human_mass', 'mass_person', 'crowd', 'group_of_people']
senticnet['large_mouse'] = [-0.191, -0.012, -0.093, -0.037, '#sad', '#scared', -0.103, 'easter_bunny', 'cute_animal', 'domestic_pet', 'household_pet', 'red_eye']
senticnet['large_number'] = [0.03, 0.128, 0, 0.124, '#interesting', '#admirable', 0.094, 'large_group', 'big_group', 'push_together', 'mass_person', 'bunch_person']
senticnet['large_person'] = [0.06, 0, 0.037, 0.149, '#joyful', '#admirable', 0.057, 'multiple_people', 'beautiful_well_useful', 'driven_person', 'big', 'large']
senticnet['large_phone_bill'] = [-0.254, -0.159, 0.059, -0.361, '#sad', '#disgusting', -0.172, 'high_phone_bill', 'interrupt', 'boredom', 'phone_line_busy', 'lose_track_time']
senticnet['large_plant'] = [0.02, 0, 0, 0.057, '#joyful', '#admirable', 0.026, 'plant_part', 'small_tree', 'tall_person', 'green_leave', 'leafy']
senticnet['large_rock'] = [0, 0.956, 0, 0.764, '#interesting', '#admirable', 0.573, 'rock_formation', 'big_rock', 'landscape_feature', 'geographic_feature', 'land_formation']
senticnet['large_ship'] = [0.02, 0, 0, 0.057, '#joyful', '#admirable', 0.026, 'ship', 'boat', 'yacht', 'sail_ship', 'cruiser']
senticnet['large_state'] = [0.043, 0, 0, 0.09, '#joyful', '#admirable', 0.044, 'political_division', 'political_unit', 'political_state', 'large_area', 'land_area']
senticnet['large_store'] = [0, 0.862, 0, 0.966, '#interesting', '#admirable', 0.609, 'group_company', 'section', 'business_group', 'industry', 'type_of_store']
senticnet['large_structure'] = [0.049, 0.076, 0.021, 0.158, '#interesting', '#admirable', 0.087, 'structure', 'construction', 'build_structure', 'place_where_people_live', 'jetty']
senticnet['large_supermarket'] = [0, 0.113, 0.041, 0.058, '#interesting', '#admirable', 0.043, 'corner_shop', 'general_store', 'many_shops', 'bazaar', 'goods']
senticnet['large_town'] = [0, 0.977, 0, 0.806, '#interesting', '#admirable', 0.594, 'govern_city', 'city_area', 'city_life', 'large_building', 'downtown']
senticnet['largeness'] = [-0.685, 0, 0.863, -0.694, '#angry', '#disgusting', -0.747, 'pretension', 'artificiality', 'affectedness', 'supernaturalness', 'unnaturalness']
senticnet['laryngostenosis'] = [-0.815, 0, 0.684, -0.813, '#sad', '#disgusting', -0.771, 'rhinostenosis', 'enterostenosis', 'stenosis', 'aortic_stenosis', 'mitral_stenosis']
senticnet['lasagna'] = [0.043, -0.055, 0, 0, '#joyful', '#surprising', 0.033, 'apple_pie', 'a_lot_of_food', 'jelly', 'frozen_food', 'cottage_cheese']
senticnet['lasciviousness'] = [0.626, -0.729, 0, 0.864, '#surprising', '#admirable', 0.74, 'amorousness', 'sexiness', 'amativeness', 'eroticism', 'erotism']
senticnet['laser'] = [0, -0.039, 0.043, -0.113, '#angry', '#disgusting', -0.039, 'torch', 'safety_pin', 'flashlight', 'flare', 'firebomb']
senticnet['lashing'] = [-0.845, 0, 0.557, -0.796, '#sad', '#disgusting', -0.733, 'corporal_punishment', 'whacking', 'whipping', 'tanning', 'flogging']
senticnet['lass'] = [0.95, 0.749, 0, 0, '#joyful', '#interesting', 0.566, 'ball_bounce', 'bicycle_tire', 'tire', 'increase_price', 'gyroscope']
senticnet['lassitude'] = [0.243, 0.632, -0.238, 0.145, '#joyful', '#interesting', 0.261, 'listlessness', 'emotionless', 'unemotionality', 'stolidity', 'phlegm']
senticnet['last'] = [0.033, 0.158, -0.069, 0.145, '#interesting', '#admirable', 0.089, 'finish', 'end', 'finish_complete', 'end_point', 'finalize']
senticnet['last_chance'] = [-0.929, 0, 0.44, -0.943, '#sad', '#disgusting', -0.771, 'chance', 'risk', 'risk_to_lose', 'dangerous', 'danger']
senticnet['last_clue'] = [-0.444, -0.154, 0, -0.364, '#sad', '#disgusting', -0.218, 'loud', 'uncontrollable', 'obsolete', 'light_colored', 'noisy']
senticnet['last_forever'] = [0, 0, 0, -0.881, '#disgusting', '#disgusting', -0.294, 'hunt_fox', 'software_company', 'waste', 'crap', 'useless']
senticnet['last_lifetime'] = [-0.19, 0, -0.133, -0.102, '#sad', '#scared', -0.142, 'hurt', 'trauma', 'maim', 'bleed', 'bloody']
senticnet['last_little'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'bad_quality', 'cheap', 'fragile', 'short', 'feeble']
senticnet['last_long'] = [0.132, 0.212, 0, 0.242, '#interesting', '#admirable', 0.195, 'good_quality', 'premium', 'unbreakable', 'steel', 'strong']
senticnet['last_long_time'] = [0.276, 0.207, -0.141, 0.123, '#joyful', '#interesting', 0.155, 'generate_heat', 'cool_house', 'cool_room', 'warm_house', 'power_engine']
senticnet['last_name'] = [0.044, 0.136, -0.071, 0.182, '#interesting', '#admirable', 0.097, 'river', 'water_stream', 'fast_water', 'water_flow', 'ebb']
senticnet['last_resort'] = [-0.973, 0, 0.84, -0.528, '#sad', '#angry', -0.78, 'pis_aller', 'expedient', 'temporary_expedient', 'makeshift', 'stopgap']
senticnet['lasting'] = [-0.954, 0, 0.808, -0.613, '#sad', '#angry', -0.792, 'everlasting', 'standing', 'imperishable', 'enduring', 'aeonian']
senticnet['lastingness'] = [0.919, -0.653, 0, 0.541, '#joyful', '#surprising', 0.704, 'indestructibility', 'tensile_strength', 'continuity', 'persistence', 'changelessness']
senticnet['latch'] = [0, 0.065, 0, 0.071, '#interesting', '#admirable', 0.045, 'lock', 'restrict_access', 'knob', 'door_knob', 'gate']
senticnet['latch_on'] = [0.51, -0.562, 0, 0.768, '#surprising', '#admirable', 0.613, 'hold', 'clasp', 'cling', 'hold_on', 'hang']
senticnet['latchkey'] = [0.943, -0.787, 0, 0.571, '#joyful', '#surprising', 0.767, 'master', 'ignition_key', 'key', 'passkey', 'master_key']
senticnet['late'] = [-0.088, 0.077, -0.084, 0, '#sad', '#scared', -0.032, 'get_dark', 'part_of_day', 'day_part', 'end_day', 'time_day']
senticnet['late_appointment'] = [-0.265, -0.122, 0.026, -0.35, '#sad', '#disgusting', -0.173, 'pollution', 'lose_temper', 'speeding_ticket', 'blackout', 'crash_car']
senticnet['late_time'] = [-0.048, 0.088, 0.013, 0.069, '#interesting', '#admirable', 0.032, 'end_day', 'part_of_day', 'time_day', 'day_end', 'day_part']
senticnet['late_work'] = [0.042, -0.043, -0.053, -0.144, '#scared', '#disgusting', -0.037, 'slow_heart_beat', 'feel_refreshed', 'gain_energy', 'tired', 'take_breath']
senticnet['latency'] = [0.554, -0.78, 0, 0.792, '#surprising', '#admirable', 0.709, 'prospect', 'chance', 'possibility', 'possibleness', 'potentiality']
senticnet['lateral'] = [-0.92, 0, 0.835, -0.682, '#sad', '#angry', -0.812, 'aerial', 'passing', 'forward_pass', 'passing_pass', 'spot_pass']
senticnet['lateral_epicondylitis'] = [-0.98, 0, 0.678, -0.956, '#sad', '#disgusting', -0.871, 'rubor', 'redness', 'inflammation', 'tennis_elbow', 'epicondylitis']
senticnet['lateral_pass'] = [-0.92, 0, 0.835, -0.682, '#sad', '#angry', -0.812, 'aerial', 'lateral', 'forward_pass', 'passing', 'spot_pass']
senticnet['latest'] = [0, 0.724, 0, 0.897, '#interesting', '#admirable', 0.54, 'relevant', 'up_date', 'happen_now', 'sea_movement', 'contemporary']
senticnet['latest_news'] = [0.088, -0.003, 0, 0, '#joyful', '#surprising', 0.03, 'look_up_information', 'news', 'headlines', 'enter_contest', 'find_newspaper']
senticnet['latex'] = [0, 0, 0, 0.098, '#admirable', '#admirable', 0.033, 'wall_cover', 'two-dimensional', 'cover_wall', 'pigment', 'dye']
senticnet['latex_glove'] = [0, 0, -0.092, -0.18, '#scared', '#disgusting', -0.091, 'syringe', 'medical_record', 'examination_table', 'x-ray_machine', 'medicine']
senticnet['lather'] = [0.914, 0, 0, 0.843, '#joyful', '#admirable', 0.586, 'clean_agent', 'foam', 'bubbly', 'wash_self', 'cleanser']
senticnet['latin_dance'] = [0.116, -0.028, 0.025, 0.156, '#joyful', '#admirable', 0.092, 'dance_move', 'salsa', 'body_movement', 'waltz', 'dance']
senticnet['laud'] = [0.864, 0, 0, 0.943, '#joyful', '#admirable', 0.602, 'respect', 'obedience', 'legal_proceed', 'honor', 'supreme']
senticnet['laudability'] = [0.76, -0.958, 0, 0.506, '#joyful', '#surprising', 0.741, 'goodness', 'praiseworthiness', 'worthiness', 'laudableness', 'quotability']
senticnet['laudableness'] = [0.76, -0.958, 0, 0.506, '#joyful', '#surprising', 0.741, 'goodness', 'praiseworthiness', 'laudability', 'worthiness', 'quotability']
senticnet['laudably'] = [0.575, 0.636, -0.268, 0.318, '#joyful', '#interesting', 0.42, 'admirably', 'praiseworthily', 'commendable', 'look_up_to', 'admirable']
senticnet['laudatory'] = [0.722, -0.981, 0, 0.832, '#surprising', '#admirable', 0.845, 'complimentary', 'praiseful', 'praising', 'encomiastic', 'eulogistic']
senticnet['laugh'] = [0.78, 0.976, 0, 0.823, '#interesting', '#admirable', 0.86, 'laughter', 'make_others_laugh', 'laugh_out_loud', 'make_fun', 'start_laugh']
senticnet['laugh_at'] = [-0.668, 0, 0.809, -0.565, '#sad', '#angry', -0.681, 'blackguard', 'roast', 'ridicule', 'guy', 'satirize']
senticnet['laugh_clown'] = [-0.135, 0, -0.053, -0.033, '#sad', '#scared', -0.074, 'watch_d', 'throw_fit', 'sun_oneself', 'battle_illness', 'honor_parent']
senticnet['laugh_joke'] = [0.786, 0.916, 0, 0.714, '#joyful', '#interesting', 0.805, 'howl_laughter', 'make_someone_laugh', 'entertain', 'express_how_funny', 'comfort_friend']
senticnet['laugh_lot'] = [0.817, 0.78, 0, 0.971, '#joyful', '#admirable', 0.856, 'feel_happy', 'enjoy_performance', 'enjoy_show', 'performance', 'experience_pleasure']
senticnet['laugh_loudly'] = [-0.059, 0, -0.08, -0.087, '#scared', '#disgusting', -0.075, 'listen_story', 'wet_pant', 'correct_mistake', 'act_out', 'laugh_out_loud']
senticnet['laugh_oneself'] = [0.754, 0.975, 0, 0, '#joyful', '#interesting', 0.576, 'page_person', 'welcome_friend', 'needy', 'erase_blackboard', 'come_house']
senticnet['laugh_out_loud'] = [0.701, 0.934, 0, 0.883, '#interesting', '#admirable', 0.839, 'laugh', 'laughter', 'make_others_laugh', 'see_funny', 'tell_others']
senticnet['laughter'] = [0.806, 0.991, 0, 0.933, '#interesting', '#admirable', 0.91, 'laugh', 'have_fun', 'make_fun', 'amusement', 'applause']
senticnet['launch'] = [-0.026, -0.02, 0, -0.122, '#sad', '#disgusting', -0.043, 'rocket', 'sink_ship', 'missile', 'drop_airplane', 'assault']
senticnet['launch_platform'] = [0.215, 0.194, -0.204, 0.279, '#joyful', '#admirable', 0.161, 'launch', 'mast', 'platform', 'gondola', 'ocean']
senticnet['launder'] = [-0.074, 0, 0.026, 0, '#sad', '#angry', -0.033, 'soap_up', 'turn_water', 'fill_bathtub', 'run_bath', 'dispense_water']
senticnet['laundromat'] = [0, 0.093, 0, 0.066, '#interesting', '#admirable', 0.053, 'gallery_open', 'museum', 'antique_store', 'art_show', 'studio']
senticnet['laundry'] = [0.86, 0.78, 0, 0, '#joyful', '#interesting', 0.547, 'clean_clothes', 'basket_laundry', 'laundry_detergent', 'clothes_hanger', 'buy_wash_powder']
senticnet['laundry_detergent'] = [0, 0.095, 0, 0.074, '#interesting', '#admirable', 0.056, 'buy_wash_powder', 'water_soap', 'turn_faucet', 'take_off', 'fill_bathtub_water']
senticnet['laurel_wreath'] = [0.586, -0.651, 0, 0.503, '#joyful', '#surprising', 0.58, 'decoration', 'distinguished_service_cross', 'medal', 'medallion', 'palm']
senticnet['laurels'] = [0.682, -0.705, 0, 0.98, '#surprising', '#admirable', 0.789, 'prize', 'seal_of_approval', 'honorable_mention', 'aliyah', 'cachet']
senticnet['lava'] = [0, 0, -0.925, 0, '#scared', '#scared', -0.308, 'water_flow', 'wind_water', 'water_stream', 'waterway', 'magma']
senticnet['lavatory'] = [0.778, -0.932, 0, 0.578, '#joyful', '#surprising', 0.763, 'flushless_toilet', 'flush_toilet', 'commode', 'potty_seat', 'potty_chair']
senticnet['lavender'] = [0.591, -0.553, 0, 0.514, '#joyful', '#surprising', 0.553, 'violet', 'mauve', 'purple', 'reddish_purple', 'royal_purple']
senticnet['lavish'] = [0, -0.92, 0, 0.783, '#surprising', '#admirable', 0.568, 'shower', 'munificent', 'overgenerous', 'unsparing', 'too-generous']
senticnet['lavishness'] = [0.902, -0.726, 0, 0.919, '#joyful', '#admirable', 0.849, 'preciousness', 'costliness', 'dearness', 'cost', 'expensiveness']
senticnet['law'] = [0, 0.164, 0, 0.129, '#interesting', '#admirable', 0.098, 'legislation', 'edict', 'prosecutor', 'regulation', 'judge_jury']
senticnet['law_enforcement_agency'] = [0.632, -0.965, 0, 0.632, '#joyful', '#surprising', 0.743, 'police', 'police_force', 'constabulary', 'law', 'agency']
senticnet['law_of_diminishing_returns'] = [0.778, -0.818, 0, 0.587, '#joyful', '#surprising', 0.728, 'law_of_effect', 'principle', 'rule', 'law_of_nature', 'distribution_law']
senticnet['law_of_effect'] = [0.778, -0.818, 0, 0.587, '#joyful', '#surprising', 0.728, 'law_of_nature', 'principle', 'rule', 'law_of_diminishing_returns', 'distribution_law']
senticnet['law_of_nature'] = [0.778, -0.818, 0, 0.587, '#joyful', '#surprising', 0.728, 'law_of_effect', 'principle', 'rule', 'law_of_diminishing_returns', 'distribution_law']
senticnet['law_officer'] = [0.74, -0.539, 0, 0.641, '#joyful', '#admirable', 0.64, 'air_marshal', 'sky_marshal', 'lawman', 'marshal', 'peace_officer']
senticnet['lawful'] = [0, 0.767, 0, 0.842, '#interesting', '#admirable', 0.536, 'true', 'rule-governed', 'legitimate', 'licit', 'rightful']
senticnet['lawman'] = [0.74, -0.539, 0, 0.641, '#joyful', '#admirable', 0.64, 'air_marshal', 'sky_marshal', 'marshal', 'law_officer', 'peace_officer']
senticnet['lawn'] = [0, 0.164, 0, 0.129, '#interesting', '#admirable', 0.098, 'garden_shed', 'yard', 'grass', 'lawn_green', 'golf_course']
senticnet['lawn_green'] = [0.175, 0.101, 0.035, 0.195, '#joyful', '#admirable', 0.145, 'leafy_green', 'rabbit_food', 'fruit_plant', 'vegetarian_food', 'green_vegetable']
senticnet['lawsuit'] = [-0.86, 0, -0.768, 0, '#sad', '#scared', -0.543, 'lawyer', 'take_court', 'call_lawyer', 'determine_guilt', 'go_to_court']
senticnet['lawyer'] = [0, 0.124, 0, 0.06, '#interesting', '#admirable', 0.061, 'arbiter', 'negotiator', 'judge_jury', 'gavel', 'prosecutor']
senticnet['lawyer_office'] = [0.054, 0.07, 0, 0.09, '#interesting', '#admirable', 0.071, 'embassy', 'office', 'government_agency', 'workplace', 'desk']
senticnet['lax'] = [-0.569, 0, 0.743, -0.777, '#angry', '#disgusting', -0.696, 'neglectful', 'derelict', 'inattentive', 'delinquent', 'negligent']
senticnet['laxation'] = [-0.897, 0, 0.925, -0.588, '#sad', '#angry', -0.803, 'shit', 'bowel_movement', 'movement', 'dump', 'asshole']
senticnet['laxative'] = [-0.501, 0, 0.582, -0.573, '#angry', '#disgusting', -0.552, 'purgative', 'cathartic', 'physic', 'aperient', 'phenolphthalein']
senticnet['laxity'] = [-0.936, 0, 0.624, -0.599, '#sad', '#angry', -0.72, 'carelessness', 'willful_neglect', 'laxness', 'neglectfulness', 'remissness']
senticnet['laxness'] = [-0.936, 0, 0.624, -0.599, '#sad', '#angry', -0.72, 'carelessness', 'willful_neglect', 'neglectfulness', 'laxity', 'remissness']
senticnet['lay'] = [0.075, 0.091, -0.063, 0.059, '#joyful', '#interesting', 0.054, 'good_night', 'go_room', 'turn_off_computer', 'take_afternoon_nap', 'wind_down']
senticnet['lay_down'] = [0.299, 0.126, 0, 0.207, '#joyful', '#admirable', 0.211, 'inactivity', 'count_sheep', 'shut_eye', 'rest_night', 'bed_sleep']
senticnet['lay_egg'] = [0, -0.06, 0.022, 0.054, '#surprising', '#admirable', 0.031, 'chick', 'wild_bird', 'hatch', 'baby_bird', 'bird_home']
senticnet['lay_off'] = [-0.381, -0.179, 0.051, -0.51, '#sad', '#disgusting', -0.254, 'migraine', 'oneself', 'lose_mind', 'forget_everything', 'varicose_vein']
senticnet['lay_on_line'] = [-0.516, 0, 0.92, -0.669, '#angry', '#disgusting', -0.702, 'hazard', 'stake', 'jeopardize', 'essay', 'assay']
senticnet['lay_up'] = [-0.952, 0, 0.647, -0.523, '#sad', '#angry', -0.707, 'disable', 'modify', 'nobble', 'alter', 'change']
senticnet['layer'] = [0.043, 0, 0, 0.143, '#joyful', '#admirable', 0.062, 'cover_ice', 'soft_sweet', 'bakery_item', 'bake_treat', 'bake_good']
senticnet['lazar_house'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'lazaret', 'lazarette', 'infirmary', 'pesthouse', 'lazaretto']
senticnet['lazaret'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'infirmary', 'infirmaryte', 'lazar_house', 'pesthouse', 'infirmaryto']
senticnet['lazarette'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'lazaret', 'infirmary', 'lazar_house', 'pesthouse', 'lazaretto']
senticnet['lazaretto'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'lazaret', 'lazarette', 'lazar_house', 'pesthouse', 'infirmary']
senticnet['laze'] = [0.08, 0, 0, 0, '#joyful', '#joyful', 0.027, 'nap', 'take_nap', 'lie_down', 'lie_back', 'lay_down']
senticnet['laziness'] = [0, 0, 0.859, -0.955, '#angry', '#disgusting', -0.605, 'fall_asleep', 'bed_time', 'drowsiness', 'take_rest', 'need_relax']
senticnet['lazy'] = [0, 0, 0.9, -0.755, '#angry', '#disgusting', -0.552, 'take_easy', 'lie_back', 'sleepy', 'avoid_commitment', 'recuperate']
senticnet['lazy_person'] = [0, 0, 0.933, -0.863, '#angry', '#disgusting', -0.599, 'dog', 'type_of_dog', 'cat', 'lazy', 'future_robot']
senticnet['lea'] = [-0.907, 0, 0.765, -0.98, '#sad', '#disgusting', -0.884, 'pastureland', 'grazing_land', 'ley', 'pasture', 'common_land']
senticnet['lead'] = [0.524, -0.759, 0, 0.828, '#surprising', '#admirable', 0.704, 'go_onwards', 'go_deep', 'run', 'pass', 'extend']
senticnet['lead_astray'] = [-0.821, 0, 0.55, -0.915, '#sad', '#disgusting', -0.762, 'misdirect', 'deprave', 'vitiate', 'profane', 'demoralize']
senticnet['lead_group'] = [-0.074, 0.316, -0.104, 0.151, '#interesting', '#admirable', 0.096, 'make_decision', 'consider', 'ideology', 'decision', 'rational']
senticnet['lead_off'] = [0.977, -0.697, 0, 0.851, '#joyful', '#admirable', 0.842, 'pervert', 'debauch', 'corrupt', 'subvert', 'debase']
senticnet['lead_on'] = [-0.66, 0, 0.771, -0.954, '#angry', '#disgusting', -0.795, 'delude', 'deceive', 'cozen', 'snooker', 'play_trick_on']
senticnet['lead_pencil'] = [0.892, 0.995, 0, 0, '#joyful', '#interesting', 0.629, 'eraser_holder', 'stick_eraser', 'mechanical_pencil', 'electric_pencil_sharpener', 'classroom_chair']
senticnet['lead_ropes'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'jockey', 'control_horse', 'horse', 'sprinter', 'saddle']
senticnet['lead_team'] = [-0.066, 0, 0, -0.032, '#sad', '#disgusting', -0.033, 'direct_person', 'teacher', 'hard_worker', 'leadership', 'principal']
senticnet['leader'] = [0.035, 0.074, 0, 0, '#joyful', '#interesting', 0.036, 'commander', 'head_guy', 'police_rank', 'chief', 'navy_officer']
senticnet['leadership'] = [0.053, 0.136, 0, 0.057, '#interesting', '#admirable', 0.082, 'boss', 'supervisor', 'leader', 'head_person', 'head_guy']
senticnet['leadership_position'] = [0.033, 0.082, 0, 0, '#joyful', '#interesting', 0.038, 'military_officer', 'head_guy', 'navy_officer', 'navy_leader', 'military_position']
senticnet['leading'] = [0, -0.893, 0, 0.718, '#surprising', '#admirable', 0.537, 'conduce', 'precede', 'leadership', 'starring', 'guide']
senticnet['leaf'] = [0.893, -0.778, 0, 0, '#joyful', '#surprising', 0.557, 'stem', 'evergreen', 'moss', 'branch', 'evergreen_tree']
senticnet['leaf_blight'] = [-0.883, 0, 0.954, -0.875, '#sad', '#angry', -0.904, 'needle_blight', 'needle_cast', 'leaf_cast', 'blight', 'fire_blight']
senticnet['leaf_cast'] = [-0.883, 0, 0.954, -0.875, '#sad', '#angry', -0.904, 'needle_blight', 'needle_cast', 'leaf_blight', 'blight', 'fire_blight']
senticnet['leafy'] = [-0.508, 0, 0.573, -0.893, '#angry', '#disgusting', -0.658, 'petallike', 'bowery', 'foliolate', 'unifoliate', 'bifoliate']
senticnet['leafy_green'] = [0.899, 0.784, 0, 0, '#joyful', '#interesting', 0.561, 'eden', 'adam_and_eve', 'usual_green', 'apple', 'leafy']
senticnet['leafy_vegetable'] = [0.035, 0.104, 0, 0.12, '#interesting', '#admirable', 0.086, 'fruit_vegetable', 'vegetable', 'vegetable_fruit', 'fresh_vegetable', 'vegetarian_food']
senticnet['leak'] = [-0.927, 0, 0, -0.785, '#sad', '#disgusting', -0.571, 'slit', 'laceration', 'welt', 'open_wind', 'cut']
senticnet['leaky'] = [-0.617, 0, 0.732, -0.591, '#sad', '#angry', -0.647, 'drafty', 'draughty', 'porous', 'drippy', 'oozing']
senticnet['lean'] = [0.708, -0.807, 0, 0.747, '#surprising', '#admirable', 0.754, 'move_around', 'tend', 'incline', 'gravitate', 'run']
senticnet['lean_against'] = [0, 0.916, 0, 0.931, '#interesting', '#admirable', 0.616, 'rush_job', 'position_furniture', 'forward_email', 'stand_alone', 'bridge_difference']
senticnet['lean_back'] = [-0.026, -0.016, 0.018, -0.11, '#sad', '#disgusting', -0.046, 'sit_chair', 'sit_upon', 'lie_on_bed', 'take_break', 'sit_down']
senticnet['lean_over'] = [0.078, 0.127, 0.04, -0.062, '#joyful', '#interesting', 0.034, 'make_anger', 'lift_leg', 'keep_balance', 'lean_against', 'fall_off_chair']
senticnet['leaning'] = [0.976, -0.873, 0, 0.706, '#joyful', '#surprising', 0.852, 'understanding', 'propensity', 'inclination', 'favor', 'proclivity']
senticnet['leanness'] = [-0.682, 0, 0.657, -0.836, '#sad', '#disgusting', -0.725, 'insufficiency', 'sparseness', 'sparsity', 'abstemiousness', 'lack_of_quantity']
senticnet['leap'] = [0.052, 0.123, 0, 0.162, '#interesting', '#admirable', 0.112, 'hop', 'jump_air', 'gymnastics', 'plunge', 'jump']
senticnet['learn'] = [0.842, 0.829, 0, 0.888, '#joyful', '#admirable', 0.853, 'learn_new_subject', 'learn_information', 'learn_art', 'make_out_atom', 'educate_oneself']
senticnet['learn_add'] = [0, 0.27, 0.014, 0.133, '#interesting', '#admirable', 0.13, 'add_two_numbers_together', 'add_number_together', 'get_total', 'get_answer', 'sharpen_pencil']
senticnet['learn_art'] = [0.812, -0.873, 0, 0, '#joyful', '#surprising', 0.562, 'enlightenment', 'learn_new_fact', 'experience_new', 'expand_mind', 'eye_strain']
senticnet['learn_book'] = [0.052, 0.123, 0, 0.162, '#interesting', '#admirable', 0.112, 'read_book', 'learn', 'gather_information', 'study', 'gain_information']
senticnet['learn_computer'] = [0.719, 0.757, 0, 0, '#joyful', '#interesting', 0.492, 'gain_knowledge', 'gather_information', 'educate_oneself', 'become_intelligent', 'acquire_knowledge']
senticnet['learn_computer_language'] = [0.918, 0.988, 0, 0, '#joyful', '#interesting', 0.635, 'learn_program_language', 'write_code', 'learn_program', 'a_lot_of_time', 'debug']
senticnet['learn_culture'] = [0.928, 0.513, 0, 0.923, '#joyful', '#admirable', 0.788, 'broaden_horizon', 'find_out_world', 'expand_knowledge', 'learn_history', 'gather_information']
senticnet['learn_current_event'] = [0.822, 0.894, 0, 0.855, '#interesting', '#admirable', 0.857, 'eye_strain', 'become_informed', 'see_ad', 'enlightenment', 'time_waste']
senticnet['learn_dance'] = [0.13, 0.169, -0.071, 0.221, '#interesting', '#admirable', 0.15, 'talk_oneself', 'avoid_pain', 'floss_tooth', 'work_home', 'go_moon']
senticnet['learn_disease'] = [-0.319, 0, -0.31, -0.159, '#sad', '#scared', -0.263, 'find_out_healthy', 'severe_pain', 'concern_health', 'psychoneurosis', 'feel_sick']
senticnet['learn_entertainment'] = [0.13, 0.169, -0.071, 0.221, '#interesting', '#admirable', 0.15, 'learn_universe', 'learn', 'find_out_world', 'view_art', 'get_informed']
senticnet['learn_evolution'] = [0.13, 0.169, -0.071, 0.221, '#interesting', '#admirable', 0.15, 'teach_person', 'teach_student', 'get_high_education', 'obtain_degree', 'listen_teacher']
senticnet['learn_experience'] = [0.721, -0.741, 0, 0, '#joyful', '#surprising', 0.487, 'lose_track_time', 'buy_souvenir', 'learn_foreign_language', 'learn_other_culture', 'extreme_boredom']
senticnet['learn_fact'] = [0.928, 0.754, 0, 0, '#joyful', '#interesting', 0.561, 'get_smart', 'better_grade', 'learn_think', 'gain_insight', 'learn']
senticnet['learn_foreign_language'] = [0.928, 0.754, 0, 0, '#joyful', '#interesting', 0.561, 'new_experience', 'discover_world', 'travel', 'learn_new_language', 'explore']
senticnet['learn_from'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'get_high_education', 'learn_evolution', 'teach_person', 'learn', 'finish_college']
senticnet['learn_game'] = [0.034, -0.063, 0.129, -0.1, '#angry', '#disgusting', -0.044, 'exercise_mind', 'intellectual_stimulation', 'find_play', 'find_friend_play', 'mentally_challenged']
senticnet['learn_history'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'take_up_time', 'learn_culture', 'accumulate_knowledge', 'become_knowledgeable', 'obtain_knowledge']
senticnet['learn_how'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'learn_how_use_keyboard', 'learn_program', 'learn_how_read', 'learn_how_swim', 'learn_how_use_computer']
senticnet['learn_how_read'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'learn_read', 'take_book', 'open_book', 'turn_page', 'literate']
senticnet['learn_how_swim'] = [-0.092, 0, 0, -0.055, '#sad', '#disgusting', -0.049, 'water_garden', 'wear_suit', 'hold_breath', 'remove_clothes', 'water_lawn']
senticnet['learn_how_to_play'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'learn_how', 'listen', 'practice_skill', 'solve', 'participate']
senticnet['learn_how_to_sing'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'find_teacher', 'take_lesson', 'learn_read_music', 'take_music_lesson', 'look_up_word_in_dictionary']
senticnet['learn_how_use_computer'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'learn_how_use_keyboard', 'learn_program', 'learn_how_read', 'learn_how_swim', 'learn_how']
senticnet['learn_how_use_keyboard'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'learn_how', 'learn_program', 'learn_how_read', 'learn_how_swim', 'learn_how_use_computer']
senticnet['learn_in_school'] = [-0.083, -0.07, 0.018, -0.229, '#sad', '#disgusting', -0.087, 'become_educated', 'listen_teacher', 'earn_degree', 'teach', 'further_education']
senticnet['learn_information'] = [0.997, 0.503, 0, 0.523, '#joyful', '#admirable', 0.674, 'increase_knowledge', 'learn', 'gain_knowledge', 'learn_new_subject', 'go_to_school']
senticnet['learn_interest'] = [0.751, 0.6, 0, 0.536, '#joyful', '#interesting', 0.629, 'see_picture', 'better_oneself', 'look_for_information', 'spread_news', 'report_event']
senticnet['learn_knowledge'] = [0.751, 0.6, 0, 0.536, '#joyful', '#interesting', 0.629, 'get_degree', 'desire_education', 'pass_exam', 'become_educated', 'learn_language']
senticnet['learn_language'] = [0.929, 0.861, 0, 0.862, '#joyful', '#admirable', 0.884, 'answer_question', 'teach_other_person', 'understand_better', 'memorize', 'commit_to_memory']
senticnet['learn_lesson'] = [0.929, 0.861, 0, 0.862, '#joyful', '#admirable', 0.884, 'study', 'read_book', 'learn_listen', 'learn_knowledge', 'learn_math']
senticnet['learn_listen'] = [0.929, 0.861, 0, 0.862, '#joyful', '#admirable', 0.884, 'study', 'learn_knowledge', 'learn_language', 'learn_information', 'learn_music']
senticnet['learn_love_another'] = [0.845, 0.923, 0, 0, '#joyful', '#interesting', 0.589, 'sun_oneself', 'throw_fit', 'watch_d', 'battle_illness', 'laugh_clown']
senticnet['learn_material'] = [-0.085, 0, 0, -0.056, '#sad', '#disgusting', -0.047, 'read_lot', 'study_test', 'study_hard', 'take_test', 'knowledge_power']
senticnet['learn_math'] = [0.929, 0.861, 0, 0.862, '#joyful', '#admirable', 0.884, 'learn_add', 'add_number_together', 'increase_knowledge', 'learn_mathematics', 'learn_computer_language']
senticnet['learn_mathematics'] = [0.929, 0.861, 0, 0.862, '#joyful', '#admirable', 0.884, 'learn_math', 'learn_add', 'add_number_together', 'learn_computer_language', 'increase_knowledge']
senticnet['learn_much'] = [0.757, 0, 0, 0, '#joyful', '#joyful', 0.252, 'increase_knowledge', 'gain_knowledge', 'find_information', 'learn', 'add_knowledge']
senticnet['learn_music'] = [0.966, 0.839, 0, 0.848, '#joyful', '#admirable', 0.884, 'learn_play', 'listen', 'sound_beautiful', 'part_of_band', 'entertain_others']
senticnet['learn_new'] = [0.924, 0.941, 0, 0.895, '#joyful', '#interesting', 0.92, 'seek_info', 'become_educated', 'know_information', 'find_new', 'learn']
senticnet['learn_new_fact'] = [0.735, -0.921, 0, 0.609, '#joyful', '#surprising', 0.755, 'better_understand', 'add_knowledge', 'learn', 'become_enlighten', 'increase_knowledge']
senticnet['learn_new_idea'] = [-0.06, -0.038, 0, -0.228, '#sad', '#disgusting', -0.083, 'learn_quickly', 'point_out', 'take_shit', 'pop_up', 'look_picture']
senticnet['learn_new_information'] = [0.671, -0.847, 0, 0.996, '#surprising', '#admirable', 0.838, 'get_information', 'find_out_information', 'gain_information', 'get_knowledge', 'broaden_horizon']
senticnet['learn_new_language'] = [0.714, 0.737, 0, 0.867, '#interesting', '#admirable', 0.773, 'new_experience', 'learn_foreign_language', 'read_article', 'discover_fact', 'better_oneself']
senticnet['learn_new_skill'] = [0.682, 0.912, 0, 0.728, '#interesting', '#admirable', 0.774, 'educate', 'get_education', 'expand_knowledge', 'become_cultured', 'gain_information']
senticnet['learn_new_subject'] = [0.807, 0.54, 0, 0.634, '#joyful', '#admirable', 0.66, 'learn', 'learn_information', 'learn_new_skill', 'gain_knowledge', 'increase_knowledge']
senticnet['learn_new_word'] = [0.792, -0.998, 0, 0.663, '#joyful', '#surprising', 0.818, 'use_mind', 'fantasize', 'inspiration', 'solve', 'information_transfer']
senticnet['learn_news'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'get_news', 'get_informed', 'appreciate_art', 'view_art', 'understand_current_event']
senticnet['learn_oneself'] = [-0.038, -0.024, 0.076, -0.203, '#angry', '#disgusting', -0.098, 'receive_information', 'increase_understand', 'share_knowledge', 'tell_other_person', 'tell_information']
senticnet['learn_other_culture'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'become_cultured', 'view_art', 'stimulate_mind', 'get_informed', 'understand_culture']
senticnet['learn_paint'] = [0.945, 0.736, 0, 0, '#joyful', '#interesting', 0.56, 'face_paint', 'self_satisfaction', 'make_paint', 'frame_picture', 'feel_accomplishment']
senticnet['learn_past'] = [0.743, -0.836, 0, 0, '#joyful', '#surprising', 0.526, 'want_know', 'see_star', 'take_beach', 'learn_history', 'see_far_away']
senticnet['learn_patience'] = [-0.096, -0.016, 0.082, -0.268, '#sad', '#disgusting', -0.143, 'get_front', 'conformist_attitude', 'wait_patiently', 'start_over', 'take_turn']
senticnet['learn_play'] = [0.862, 0.868, 0, 0.86, '#joyful', '#interesting', 0.863, 'perfect_skill', 'lovely_music', 'play_song', 'make_beautiful_music', 'part_of_band']
senticnet['learn_program'] = [0.862, 0.868, 0, 0.86, '#joyful', '#interesting', 0.863, 'learn_program_language', 'learn_computer_language', 'learn_new_skill', 'learn_mathematics', 'learn_math']
senticnet['learn_program_language'] = [0.889, 0.812, 0, 0, '#joyful', '#interesting', 0.567, 'learn_computer_language', 'write_code', 'learn_program', 'a_lot_of_time', 'write_email']
senticnet['learn_quickly'] = [-0.084, -0.044, 0, -0.196, '#sad', '#disgusting', -0.079, 'learn_new_idea', 'take_shit', 'point_out', 'pop_up', 'look_picture']
senticnet['learn_read'] = [0.889, 0.812, 0, 0, '#joyful', '#interesting', 0.567, 'learn_how_read', 'take_book', 'study', 'read_book', 'open_book']
senticnet['learn_read_music'] = [-0.078, 0, 0, 0, '#sad', '#sad', -0.026, 'take_music_lesson', 'take_lesson', 'find_teacher', 'class', 'look_up_word_in_dictionary']
senticnet['learn_rule'] = [0.889, 0.812, 0, 0, '#joyful', '#interesting', 0.567, 'play_game', 'learn_sport', 'join_team', 'knowledge_rule', 'follow_rule']
senticnet['learn_science'] = [0.798, 0.754, 0, 0.779, '#joyful', '#admirable', 0.777, 'learn_subject', 'study_subject', 'memorize', 'commit_to_memory', 'understand_better']
senticnet['learn_skill'] = [0.804, 0.971, 0, 0.989, '#interesting', '#admirable', 0.921, 'word_process', 'learn_new_skill', 'process_data', 'educate', 'give_lecture']
senticnet['learn_somthing_new'] = [0, 0.071, 0.043, 0.067, '#interesting', '#admirable', 0.032, 'go_to_school', 'student', 'teacher', 'use_school', 'hard_surface']
senticnet['learn_spell'] = [0.951, 0.937, 0, 0, '#joyful', '#interesting', 0.629, 'learn_write', 'find_paper', 'language_skill', 'think_write', 'know_how_spell']
senticnet['learn_sport'] = [0.719, 0.757, 0, 0, '#joyful', '#interesting', 0.492, 'get_knowledge', 'self-fulfillment', 'learn_universe', 'expand_knowledge', 'acquire_knowledge']
senticnet['learn_subject'] = [0.798, 0.754, 0, 0.779, '#joyful', '#admirable', 0.777, 'learn_science', 'understand_better', 'study_subject', 'learn_world', 'commit_to_memory']
senticnet['learn_swim'] = [0.02, 0.07, 0.019, 0, '#joyful', '#interesting', 0.024, 'learn_new_skill', 'jump_in_water', 'take_leak', 'go_swim_pool', 'scuba_gear']
senticnet['learn_swimming'] = [-0.04, 0.069, 0, 0.075, '#interesting', '#admirable', 0.035, 'go_to_swimming_pool', 'scuba', 'scuba_gear', 'jump_into_water', 'enjoy_nature']
senticnet['learn_teamwork'] = [0.056, 0.157, 0, 0.154, '#interesting', '#admirable', 0.122, 'enjoy_outdoors', 'competition', 'exercise_entertainment', 'funny_friend', 'entertainment']
senticnet['learn_think'] = [0.098, 0.165, -0.134, 0.284, '#interesting', '#admirable', 0.138, 'gain_insight', 'learn_fact', 'knowledge', 'trivia', 'know']
senticnet['learn_tool'] = [-0.075, 0, 0, 0, '#sad', '#sad', -0.025, 'text_book', 'group_student', 'learn', 'multiple_choices', 'protractor']
senticnet['learn_universe'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'learn_entertainment', 'find_out_world', 'view_art', 'understand_current_event', 'expand_knowledge']
senticnet['learn_walk'] = [-0.159, 0, 0, -0.033, '#sad', '#disgusting', -0.064, 'act_quickly', 'go_park', 'step_forward', 'tie_shoes', 'wear_running_shoes']
senticnet['learn_weakness'] = [0.213, 0.273, -0.136, 0.29, '#interesting', '#admirable', 0.213, 'change_mind', 'weigh_consequence', 'become_politician', 'gather_intelligence', 'good_everyone']
senticnet['learn_world'] = [0.535, 0.531, 0, 0.858, '#joyful', '#admirable', 0.641, 'learn_subject', 'understand_better', 'find_information', 'learn_science', 'swallow_semen']
senticnet['learn_write'] = [0.055, -0.017, 0, 0.106, '#joyful', '#admirable', 0.059, 'attendee', 'pencil_pen', 'agenda', 'find_paper', 'paper_plane']
senticnet['learned'] = [0.786, -0.527, 0, 0.848, '#joyful', '#admirable', 0.72, 'educated', 'semiliterate', 'knowledgeable', 'lettered', 'literate']
senticnet['learned_profession'] = [0.54, -0.712, 0, 0.573, '#surprising', '#admirable', 0.608, 'practice_of_law', 'medicine', 'theology', 'profession', 'law']
senticnet['learner'] = [0.535, 0.531, 0, 0.858, '#joyful', '#admirable', 0.641, 'student', 'absorb_information', 'go_to_school', 'research', 'study']
senticnet['learning'] = [0.887, -0.989, 0, 0.611, '#joyful', '#surprising', 0.829, 'education', 'internalization', 'incorporation', 'study', 'conditioning']
senticnet['learning_disability'] = [0.89, -0.703, 0, 0.643, '#joyful', '#surprising', 0.745, 'dyslexia', 'dyscalculia', 'dysgraphia', 'disorder', 'upset']
senticnet['learning_disorder'] = [0.759, -0.611, 0, 0.703, '#joyful', '#admirable', 0.691, 'dyslexia', 'dyscalculia', 'dysgraphia', 'disorder', 'upset']
senticnet['learning_place'] = [-0.04, -0.003, 0, -0.063, '#sad', '#disgusting', -0.033, 'student_place', 'school_session', 'educational_place', 'place_of_study', 'educational_institution']
senticnet['lease'] = [-0.059, 0.116, -0.044, 0.102, '#interesting', '#admirable', 0.038, 'house', 'dwelling', 'multi-story_build', 'rent_out', 'large_house']
senticnet['leash'] = [-0.052, 0.072, 0.012, 0.066, '#interesting', '#admirable', 0.025, 'pet', 'bell_cat', 'animal', 'dog_tag', 'fur']
senticnet['least'] = [-0.99, 0, 0, -0.709, '#sad', '#disgusting', -0.566, 'a_little', 'little', 'small_amount', 'shortage', 'scarce']
senticnet['least_effort'] = [-0.687, 0, 0.635, -0.547, '#sad', '#angry', -0.623, 'sweat', 'effort', 'elbow_grease', 'exertion', 'travail']
senticnet['least_resistance'] = [-0.759, 0, 0.955, -0.774, '#angry', '#disgusting', -0.829, 'sweat', 'effort', 'elbow_grease', 'exertion', 'travail']
senticnet['leather'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'coat', 'suit', 'armor', 'sweater', 'belt']
senticnet['leather_jacket'] = [0, 0.749, 0, 0.992, '#interesting', '#admirable', 0.58, 'belt', 'zipper', 'backpack', 'pouch', 'bag']
senticnet['leave'] = [0, 0, 0, 0.094, '#admirable', '#admirable', 0.031, 'green_leave', 'large_plant', 'leaf', 'plant_part', 'stem']
senticnet['leave_alone'] = [-0.146, -0.111, 0.105, -0.223, '#sad', '#disgusting', -0.121, 'abandon', 'eaten_shark', 'confine', 'smelly_foot', 'lyme_disease']
senticnet['leave_behind'] = [-0.187, 0.093, -0.171, 0, '#sad', '#scared', -0.088, 'time_out', 'rest_time', 'speeding_ticket', 'put_down', 'mock']
senticnet['leave_build'] = [-0.073, 0.146, -0.078, 0.197, '#interesting', '#admirable', 0.064, 'enter_area', 'go_through', 'hang_door', 'go_build', 'enter_build']
senticnet['leave_country'] = [0.92, 0.976, 0, 0.722, '#joyful', '#interesting', 0.873, 'plan_vacation', 'go_vacation', 'go_somewhere', 'go_outside_even', 'go_pub']
senticnet['leave_document'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'voicemail_message', 'write_note', 'leave_message', 'send_email', 'message']
senticnet['leave_hand'] = [0, 0.097, 0, 0.085, '#interesting', '#admirable', 0.061, 'lunula', 'arm_part', 'cuticle', 'ten_fingers', 'five_fingers']
senticnet['leave_home'] = [-0.168, 0, -0.05, 0, '#sad', '#scared', -0.073, 'leave_house', 'look_map', 'open_front_door', 'decide_to_go', 'book_flight']
senticnet['leave_house'] = [-0.055, 0, 0.028, 0, '#sad', '#angry', -0.028, 'decide_to_go', 'obey_rule', 'open_front_door', 'look_map', 'dress_appropriately']
senticnet['leave_house_first'] = [-0.079, 0, 0.012, 0, '#sad', '#angry', -0.03, 'know_go', 'decide_to_go', 'look_map', 'decide_want_go', 'leave_house']
senticnet['leave_job'] = [0, 0, 0.87, -0.874, '#angry', '#disgusting', -0.581, 'go_away', 'ask_to_leave', 'drive_out', 'chase_away', 'drive_away']
senticnet['leave_leg'] = [0, -0.012, 0.046, -0.07, '#angry', '#disgusting', -0.035, 'bone', 'nipple', 'backbone', 'thigh', 'scrotum']
senticnet['leave_line'] = [-0.04, -0.015, 0.011, -0.069, '#sad', '#disgusting', -0.035, 'stand_in_line', 'wait_line', 'get_line', 'wait', 'stand_queue']
senticnet['leave_message'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'voicemail_message', 'write_note', 'leave_document', 'send_email', 'message']
senticnet['leave_museum'] = [-0.135, -0.06, 0.043, -0.21, '#sad', '#disgusting', -0.109, 'learn_much', 'make_out_atom', 'add_knowledge', 'learn', 'inform']
senticnet['leave_office'] = [-0.783, 0, 0.801, -0.87, '#angry', '#disgusting', -0.818, 'resign', 'renounce', 'step_down', 'abdicate', 'vacate']
senticnet['leave_out'] = [-0.444, -0.154, 0, -0.364, '#sad', '#disgusting', -0.218, 'cause_suffer', 'lose_team', 'loathing', 'disrespect', 'lyme_disease']
senticnet['leave_over'] = [0.056, 0, 0, 0.05, '#joyful', '#admirable', 0.035, 'leftover', 'dusty', 'mayonnaise', 'peanut_butter', 'savory']
senticnet['leave_place'] = [-0.084, 0.092, -0.073, 0.15, '#interesting', '#admirable', 0.028, 'drive_highway', 'push_limit', 'steer_car', 'turn_leave', 'break_down']
senticnet['leave_room'] = [-0.098, -0.008, 0, -0.059, '#sad', '#disgusting', -0.05, 'go_new_place', 'leave_home', 'travel_by_airplane', 'travel_abroad', 'board_airplane']
senticnet['leave_table'] = [-0.072, 0, -0.051, -0.082, '#sad', '#disgusting', -0.068, 'head_class', 'crowd_room', 'seat_chair', 'conduct_experiment', 'page_through_book']
senticnet['leave_theater'] = [0.909, 0.785, 0, 0, '#joyful', '#interesting', 0.565, 'read_credit', 'channel_surf', 'turn_channel', 'eat_pizza', 'change_channel']
senticnet['leave_tip'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'spill_food_clothes', 'drop_food', 'order_food', 'go_restroom', 'order_drink']
senticnet['leave_without_pay'] = [-0.183, 0.138, -0.21, 0.086, '#sad', '#scared', -0.056, 'steal', 'rob', 'shoplift', 'bad_citizen', 'robbery']
senticnet['leave_work'] = [-0.095, 0.072, -0.083, 0, '#sad', '#scared', -0.035, 'quit_job', 'floss_tooth', 'set_clock', 'out_bed', 'sell_vegetable']
senticnet['leaves'] = [0, 0.068, -0.065, 0.081, '#interesting', '#admirable', 0.028, 'flower', 'windflower', 'anemone', 'plant', 'bright_petals']
senticnet['lech'] = [0.789, -0.733, 0, 0.857, '#joyful', '#admirable', 0.793, 'fetishist', 'degenerateer', 'degenerate', 'letch', 'satyr']
senticnet['lecher'] = [0, 0, 0.724, -0.946, '#angry', '#disgusting', -0.557, 'fetishist', 'degenerate', 'lech', 'letch', 'pervert']
senticnet['lecherousness'] = [0.718, -0.726, 0, 0.952, '#surprising', '#admirable', 0.799, 'love', 'aphrodisia', 'concupiscence', 'lustfulness', 'amorousness']
senticnet['lectern'] = [0, 0.214, 0.012, 0.208, '#interesting', '#admirable', 0.137, 'altar', 'confessional', 'church', 'chapel', 'christianity']
senticnet['lecture'] = [0, 0.214, 0.012, 0.208, '#interesting', '#admirable', 0.137, 'lecture_hall', 'lecture_theater', 'lesson', 'conference', 'school_session']
senticnet['lecture_hall'] = [0.981, 0, 0, 0.809, '#joyful', '#admirable', 0.597, 'lecture_theater', 'lecture', 'conference_auditorium', 'read_book', 'text_book']
senticnet['lecture_theater'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'lecture_hall', 'lecture', 'textbook', 'text_book', 'lesson']
senticnet['lecturer'] = [-0.032, -0.007, -0.055, -0.036, '#scared', '#disgusting', -0.039, 'professor', 'teacher', 'instructor', 'student', 'college_student']
senticnet['ledge'] = [0, 0.115, 0, 0, '#interesting', '#interesting', 0.038, 'coordinate', 'middle_road', 'mountain_top', 'coordinator', 'tennis_match']
senticnet['ledger'] = [0.935, 0.758, 0, 0, '#joyful', '#interesting', 0.564, 'pocket_notebook', 'file', 'general_ledger', 'ring_binder', 'address_label']
senticnet['leech'] = [-0.716, 0, 0.605, -0.623, '#sad', '#disgusting', -0.648, 'medicinal_leech', 'horseleech', 'annelid', 'annelid_worm', 'segmented_worm']
senticnet['leer'] = [-0.115, 0, -0.094, 0.082, '#sad', '#scared', -0.042, 'like_see', 'ear', 'facial_expression', 'mouth', 'dimple']
senticnet['leeway'] = [-0.529, 0, 0.561, -0.908, '#angry', '#disgusting', -0.666, 'difference', 'tolerance', 'allowance', 'discrepancy', 'margin']
senticnet['left'] = [0.883, -0.593, 0, 0.533, '#joyful', '#surprising', 0.67, 'hooks', 'meat_hooks', 'maulers', 'right', 'hand']
senticnet['left_over'] = [0.04, 0.084, 0, 0.093, '#interesting', '#admirable', 0.072, 'inactivity', 'remainder', 'work_break', 'count_sheep', 'middle_day']
senticnet['left_right'] = [0.082, 0.08, 0.034, 0.207, '#joyful', '#admirable', 0.112, 'ninety_degree', 'rotate', 'direction', 'octagon', 'leave']
senticnet['leftover'] = [0.037, 0.084, 0, 0, '#joyful', '#interesting', 0.04, 'leave_over', 'charcoal', 'cellulose', 'cane', 'remainder']
senticnet['leg'] = [0.037, 0.084, 0, 0, '#joyful', '#interesting', 0.04, 'ankle', 'hold_canvas', 'toe', 'foot', 'knee']
senticnet['leg_arm'] = [0, 0.072, 0, 0.064, '#interesting', '#admirable', 0.045, 'physique', 'below_neck', 'anatomy', 'human_part', 'hand_foot']
senticnet['leg_cramp'] = [-0.841, 0, 0, -0.78, '#sad', '#disgusting', -0.54, 'breathlessness', 'get_out_breath', 'shortness_breath', 'run_out_breath', 'become_tired']
senticnet['leg_hurt'] = [-0.892, 0, 0, -0.701, '#sad', '#disgusting', -0.531, 'become_exhausted', 'get_injured', 'sprain_ankle', 'cramp', 'pull_muscle']
senticnet['leg_of_lamb'] = [0.783, -0.635, 0, 0.829, '#joyful', '#admirable', 0.749, 'lamb_roast', 'gigot', 'joint', 'roast', 'rack_of_lamb']
senticnet['leg_pain'] = [-0.365, -0.082, 0, -0.327, '#sad', '#disgusting', -0.203, 'disease', 'body_disease', 'need_cure', 'need_doctor', 'varicose_vein']
senticnet['leg_tire'] = [-0.753, 0, 0, -0.786, '#sad', '#disgusting', -0.513, 'foot_hurt', 'feel_tired', 'need_to_rest', 'need_break', 'become_tired']
senticnet['leg_wear'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'clothes', 'high_heel', 'footwear', 'shoe', 'shoe_type']
senticnet['legal'] = [0.1, 0.134, 0.013, 0.124, '#interesting', '#admirable', 0.115, 'law', 'judge_jury', 'supreme_court', 'edict', 'official']
senticnet['legal_action'] = [0.682, -0.673, 0, 0.588, '#joyful', '#surprising', 0.648, 'antitrust_case', 'civil_action', 'counterclaim', 'custody_case', 'lis_pendens']
senticnet['legal_assistant'] = [-0.697, 0, 0.659, -0.696, '#sad', '#disgusting', -0.684, 'help', 'paralegal', 'paraprofessional', 'paramedic', 'paramedical']
senticnet['legal_document'] = [-0.065, 0.234, -0.11, 0.156, '#interesting', '#admirable', 0.072, 'litigation', 'court_action', 'secure', 'hold_change', 'treasurer']
senticnet['legal_instrument'] = [0.868, -0.847, 0, 0.673, '#joyful', '#surprising', 0.796, 'instrument', 'option', 'futures_contract', 'legal_document', 'derivative_instrument']
senticnet['legal_person'] = [0, 0.114, 0, 0.083, '#interesting', '#admirable', 0.066, 'solicitor', 'attorney', 'detective', 'felon', 'liar']
senticnet['legal_proceed'] = [0, 0.168, -0.052, 0.234, '#interesting', '#admirable', 0.117, 'legal_process', 'court_action', 'court_trial', 'nominate', 'trial']
senticnet['legal_process'] = [-0.049, 0.184, -0.085, 0.172, '#interesting', '#admirable', 0.074, 'court_trial', 'trial', 'witness', 'justice', 'judgment']
senticnet['legality'] = [-0.027, 0.164, -0.061, 0.137, '#interesting', '#admirable', 0.071, 'regulation', 'edict', 'march_rear', 'law', 'rule']
senticnet['legatee'] = [-0.653, 0, 0.808, -0.699, '#angry', '#disgusting', -0.72, 'pensionary', 'pensioner', 'devisee', 'beneficiary', 'recipient']
senticnet['legendary'] = [0.898, 0, 0, 0.78, '#joyful', '#admirable', 0.559, 'finite', 'primary', 'fairy_tale', 'descriptive', 'hue']
senticnet['legendary_creature'] = [0, 0.732, 0, 0.934, '#interesting', '#admirable', 0.555, 'mythical_monster', 'mythical_creature', 'unicorn', 'griffins', 'doppelganger']
senticnet['legibility'] = [0.805, -0.62, 0, 0.86, '#joyful', '#admirable', 0.762, 'clearness', 'clarity', 'discernability', 'uncloudedness', 'distinctness']
senticnet['legislation'] = [0, 0.178, -0.044, 0.118, '#interesting', '#admirable', 0.084, 'law', 'edict', 'prosecutor', 'regulation', 'judge_jury']
senticnet['legislature'] = [0.03, 0.124, 0, 0.099, '#interesting', '#admirable', 0.084, 'government', 'rule_government', 'reign', 'legal', 'state_head']
senticnet['legitimate'] = [0.886, -0.778, 0, 0.815, '#joyful', '#admirable', 0.826, 'countenance', 'monetize', 'permit', 'allow', 'let']
senticnet['legs'] = [0, 0.077, 0, 0.081, '#interesting', '#admirable', 0.053, 'limb', 'organ', 'tail', 'arm', 'body_appendage']
senticnet['legume'] = [0.518, -0.519, 0, 0.65, '#surprising', '#admirable', 0.562, 'clematis', 'climber', 'leguminous_plant', 'climbing_fern', 'root_climber']
senticnet['leguminous_plant'] = [0.518, -0.519, 0, 0.65, '#surprising', '#admirable', 0.562, 'clematis', 'legume', 'climber', 'climbing_fern', 'root_climber']
senticnet['leisure'] = [0.793, 0.739, 0, 0, '#joyful', '#interesting', 0.511, 'recreation', 'pastime', 'date_activity', 'leisure_time', 'enjoy_game']
senticnet['leisure_activity'] = [0.117, -0.007, 0, 0, '#joyful', '#surprising', 0.041, 'explore', 'web_surf', 'hobby', 'pastime', 'exploration']
senticnet['leisure_time'] = [0.867, 0.714, 0, 0, '#joyful', '#interesting', 0.527, 'leisure', 'pastime', 'enjoy_beauty', 'mentally_challenged', 'intellectual_stimulation']
senticnet['leisure_wear'] = [-0.927, 0, 0.595, -0.678, '#sad', '#disgusting', -0.733, 'wear', 'wearable', 'clothing', 'article_of_clothing', 'vesture']
senticnet['leisureliness'] = [-0.689, 0, 0.82, -0.968, '#angry', '#disgusting', -0.826, 'dilatoriness', 'deliberateness', 'procrastination', 'rate', 'pace']
senticnet['leisurely'] = [-0.771, 0, 0.855, -0.576, '#sad', '#angry', -0.734, 'unhurried', 'easygoing', 'deliberate', 'easy', 'careful']
senticnet['lemon'] = [-0.622, 0, 0.512, -0.805, '#sad', '#disgusting', -0.646, 'vanilla', 'taste', 'sapidity', 'taste_sensation', 'gustatory_sensation']
senticnet['lemon_juice'] = [0.071, 0, -0.085, -0.09, '#scared', '#disgusting', -0.035, 'gunk', 'rotten_food', 'sour_cream', 'glass_of_milk', 'acid']
senticnet['lemon_peel'] = [-0.952, 0, 0.845, -0.679, '#sad', '#angry', -0.825, 'grapefruit_peel', 'candied_citrus_peel', 'orange_peel', 'candied_fruit', 'succade']
senticnet['lemonade'] = [0.111, 0, 0, 0, '#joyful', '#joyful', 0.037, 'coke', 'cider', 'soda', 'juice', 'cola']
senticnet['lemur'] = [0, 0.969, 0, 0.804, '#interesting', '#admirable', 0.591, 'monkey', 'marmoset', 'fiance', 'beaver', 'koala']
senticnet['lend'] = [-0.058, 0.253, -0.165, 0.209, '#interesting', '#admirable', 0.08, 'donation', 'give_back', 'loan', 'investment', 'given']
senticnet['lend_hand'] = [0, -0.993, 0, 0.918, '#surprising', '#admirable', 0.637, 'work_team', 'dress_oneself', 'move_furniture', 'bus_table', 'win_award']
senticnet['lend_money'] = [0.993, 0.784, 0, 0, '#joyful', '#interesting', 0.592, 'bank_money', 'hold_coin', 'invest_money', 'vault', 'bank_loan']
senticnet['length'] = [0, 0.781, 0, 0.803, '#interesting', '#admirable', 0.528, 'length_measurement', 'measurement', 'imperial_measurement', 'measure', 'spatial_dimension']
senticnet['length_dimension'] = [0, 0.722, 0, 0.721, '#interesting', '#admirable', 0.481, 'dimension', 'size', 'mass_measure', 'width', 'gauge']
senticnet['length_measurement'] = [0, 0.751, 0, 0.907, '#interesting', '#admirable', 0.553, 'meter', 'imperial_measurement', 'length', 'distance_measure', 'measurement_unit']
senticnet['lenience'] = [0.787, -0.885, 0, 0.858, '#surprising', '#admirable', 0.843, 'permissiveness', 'leniency', 'toleration', 'disposition', 'temperament']
senticnet['leniency'] = [0.787, -0.885, 0, 0.858, '#surprising', '#admirable', 0.843, 'lenience', 'permissiveness', 'toleration', 'disposition', 'temperament']
senticnet['lenify'] = [0.644, -0.916, 0, 0.992, '#surprising', '#admirable', 0.851, 'tranquilize', 'tranquillize', 'calm_down', 'quieten', 'calm']
senticnet['lens'] = [0.026, -0.166, -0.05, 0.076, '#surprising', '#admirable', 0.073, 'monocle', 'eyeglass', 'spectacle', 'contact_lens', 'sheer']
senticnet['lentigo'] = [-0.662, 0, 0.911, -0.993, '#angry', '#disgusting', -0.855, 'liver_spot', 'spot', 'freckle', 'macule', 'plague_spot']
senticnet['leopard'] = [-0.033, 0, -0.088, 0, '#sad', '#scared', -0.04, 'lion', 'craven', 'mountain_lion', 'bobcat', 'wolf']
senticnet['lepidote'] = [-0.774, 0, 0.626, -0.786, '#sad', '#disgusting', -0.729, 'bumpy', 'scabrous', 'unsmooth', 'leprose', 'roughish']
senticnet['leprechaun'] = [-0.73, 0, 0.72, -0.936, '#sad', '#disgusting', -0.795, 'imp', 'elf', 'hob', 'gremlin', 'pixie']
senticnet['leprose'] = [-0.774, 0, 0.626, -0.786, '#sad', '#disgusting', -0.729, 'bumpy', 'scabrous', 'lepidote', 'unsmooth', 'roughish']
senticnet['leprosy_bacillus'] = [-0.908, 0, 0.908, -0.538, '#sad', '#angry', -0.785, 'tubercle_bacillus', 'mycobacteria', 'eubacteria', 'eubacterium', 'true_bacteria']
senticnet['leptomeningitis'] = [-0.773, 0, 0.871, -0.64, '#sad', '#angry', -0.761, 'meningitis', 'cerebrospinal_meningitis', 'epidemic_meningitis', 'brain_fever', 'cerebrospinal_fever']
senticnet['lepton'] = [0.02, 0, 0, 0.087, '#joyful', '#admirable', 0.036, 'elementary_particle', 'neutron', 'electron', 'proton', 'subatomic_particle']
senticnet['leresis'] = [0.916, -0.877, 0, 0.79, '#joyful', '#surprising', 0.861, 'garrulity', 'garrulousness', 'loquaciousness', 'loquacity', 'talkativeness']
senticnet['lesbian'] = [0.191, 0.168, -0.162, 0.131, '#joyful', '#interesting', 0.109, 'female', 'lady', 'woman', 'wench', 'bride']
senticnet['lesbianism'] = [0.807, -0.88, 0, 0.718, '#joyful', '#surprising', 0.802, 'sex', 'inversion', 'sexual_inversion', 'gayness', 'sapphism']
senticnet['less'] = [-0.909, 0, 0.278, -0.999, '#sad', '#disgusting', -0.729, 'few', 'little', 'minus_sign', 'negative', 'minus']
senticnet['less_quality'] = [0.057, -0.038, 0, 0, '#joyful', '#surprising', 0.032, 'cheap_stuff', 'save_money', 'discount_store', 'occasions', 'poor_people']
senticnet['lessened'] = [-0.968, 0, 0.624, -0.99, '#sad', '#disgusting', -0.861, 'vitiated', 'dicky', 'dickey', 'impaired', 'diminished']
senticnet['lesser'] = [0, 0.784, 0, 0.918, '#interesting', '#admirable', 0.567, 'numeral', 'list_number', 'smaller', 'measure_unit', 'two_halves']
senticnet['lesser_burdock'] = [0.683, -0.547, 0, 0.568, '#joyful', '#admirable', 0.599, 'subshrub', 'suffrutex', 'common_burdock', 'burdock', 'great_burdock']
senticnet['lesser_centaury'] = [-0.902, 0, 0.726, -0.534, '#sad', '#angry', -0.721, 'broad_leaved_centaury', 'rosita', 'centaury', 'tufted_centaury', 'seaside_centaury']
senticnet['lesson'] = [0.191, 0.168, -0.162, 0.131, '#joyful', '#interesting', 0.109, 'school_session', 'school_class', 'school_course', 'academy', 'college_class']
senticnet['let'] = [-0.074, 0.345, -0.232, 0.395, '#interesting', '#admirable', 0.145, 'permission', 'allow', 'suggest', 'take', 'limit_time']
senticnet['let_body_recover'] = [0.754, 0, 0, 0.718, '#joyful', '#admirable', 0.491, 'feel_refreshed', 'get_rest', 'rejuvenation', 'heal_injury', 'recuperate']
senticnet['let_down'] = [-0.067, 0, -0.164, 0, '#sad', '#scared', -0.077, 'form_sentence', 'go_scuba_dive', 'cry_help', 'smoke_cigar', 'kill_oneself']
senticnet['let_go'] = [-0.037, 0.119, -0.049, 0.156, '#interesting', '#admirable', 0.063, 'water_drip', 'fallen', 'little_water', 'before_fall', 'rain_water']
senticnet['let_go_of'] = [0.693, -0.526, 0, 0.992, '#joyful', '#admirable', 0.737, 'release', 'unlock', 'let_go', 'relinquish', 'disengage']
senticnet['let_heard'] = [0, 0, 0.933, -0.887, '#angry', '#disgusting', -0.607, 'opinioned', 'debate_politics', 'conquer_opponent', 'dicussion', 'debate']
senticnet['let_in'] = [0, 0.175, -0.13, 0.204, '#interesting', '#admirable', 0.083, 'door', 'control_access', 'gate', 'corridor', 'admission']
senticnet['let_know'] = [0, 0, 0.084, -0.061, '#angry', '#disgusting', -0.048, 'make_peace', 'measure_angle', 'make_easy', 'listen_heart', 'solo']
senticnet['let_loose'] = [0.691, -0.973, 0, 0.771, '#surprising', '#admirable', 0.812, 'squeal', 'blate', 'churr', 'honk', 'sibilate']
senticnet['let_off_steam'] = [0.18, -0.014, 0, 0, '#joyful', '#surprising', 0.065, 'reduce_stress', 'recover_illness', 'lower_blood_pressure', 'make_feel_good', 'serenity']
senticnet['let_out'] = [0.602, -0.966, 0, 0.756, '#surprising', '#admirable', 0.775, 'squeal', 'blate', 'churr', 'honk', 'sibilate']
senticnet['let_someone_do'] = [0.031, 0.146, -0.141, 0.191, '#interesting', '#admirable', 0.076, 'tolerant', 'leave_alone', 'group_star', 'orbit', 'outer_space']
senticnet['let_up'] = [-0.927, 0, 0.757, -0.905, '#sad', '#disgusting', -0.863, 'die_away', 'far', 'slack_off', 'abate', 'die']
senticnet['let_win'] = [-0.061, 0, 0, -0.081, '#sad', '#disgusting', -0.047, 'share_feeling', 'reply_question', 'misunderstand', 'look_eye', 'act_out']
senticnet['letch'] = [0, 0, 0.722, -0.787, '#angry', '#disgusting', -0.503, 'fetishist', 'lecher', 'lech', 'degenerate', 'pervert']
senticnet['letdown'] = [-0.831, 0, 0.912, -0.679, '#sad', '#angry', -0.807, 'dissatisfaction', 'displeasure', 'disappointment', 'boredom', 'ennui']
senticnet['lethal'] = [-0.112, -0.027, -0.091, -0.155, '#sad', '#disgusting', -0.11, 'use_war', 'shoot', 'fire_gun', 'shoot_gun', 'ammunition']
senticnet['lethargic'] = [-0.567, 0, 0.577, -0.619, '#angry', '#disgusting', -0.588, 'foggy', 'groggy', 'logy', 'stuporous', 'dazed']
senticnet['lethargy'] = [-0.975, 0, 0.992, -0.866, '#sad', '#angry', -0.944, 'lassitude', 'hibernation', 'torpidity', 'sluggishness', 'physical_condition']
senticnet['letter'] = [0.038, -0.039, 0, 0.079, '#surprising', '#admirable', 0.052, 'sender', 'message', 'note', 'post', 'word']
senticnet['letter_alphabet'] = [0.03, -0.009, 0, 0.089, '#joyful', '#admirable', 0.043, 'grammar', 'alphabet', 'abc', 'letter', 'language']
senticnet['letter_opener'] = [0.976, 0.918, 0, 0, '#joyful', '#interesting', 0.631, 'thumb_tack', 'pin_up_girl', 'glue_stick', 'push_pin', 'pair_of_scissors']
senticnet['letter_scale'] = [0.029, -0.033, 0.066, -0.086, '#angry', '#disgusting', -0.03, 'blotter', 'drawer', 'file_box', 'desk_tray', 'card_case']
senticnet['letter_sign'] = [0.936, 0.749, 0, 0.871, '#joyful', '#admirable', 0.852, 'paint_picture', 'tie-dye', 'paint_house', 'make_patchwork_quilt', 'create_art']
senticnet['letter_slot'] = [0.058, -0.049, 0, 0, '#joyful', '#surprising', 0.036, 'address_label', 'envelope', 'pamphlet', 'mailman', 'postage_stamp']
senticnet['lettered'] = [0.786, -0.527, 0, 0.848, '#joyful', '#admirable', 0.72, 'learned', 'semiliterate', 'knowledgeable', 'educated', 'literate']
senticnet['letterhead'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'letter', 'postman', 'stamp', 'arrive_mail', 'envelope']
senticnet['lettuce'] = [0, -0.006, 0.053, -0.037, '#angry', '#disgusting', -0.028, 'kale', 'cucumber', 'cabbage', 'broccoli', 'pea']
senticnet['leucocyte'] = [0.602, -0.736, 0, 0.942, '#surprising', '#admirable', 0.76, 'leukocyte', 'eosinophil', 'white_blood_cell', 'white_cell', 'white_blood_corpuscle']
senticnet['leukemia'] = [-0.856, 0, 0.949, -0.835, '#sad', '#angry', -0.88, 'disease', 'cancer', 'weak_body', 'death', 'feel_sick']
senticnet['leukocyte'] = [0.602, -0.736, 0, 0.942, '#surprising', '#admirable', 0.76, 'eosinophil', 'leucocyte', 'white_blood_cell', 'white_cell', 'white_blood_corpuscle']
senticnet['level'] = [0, 0.736, 0, 0.86, '#interesting', '#admirable', 0.532, 'yardstick', 'next_level', 'scale', 'measure_tool', 'same_level']
senticnet['level_one'] = [0.039, -0.033, 0, 0, '#joyful', '#surprising', 0.024, 'lower_floor', 'floor', 'ground_floor', 'hallway', 'first_floor']
senticnet['levelheaded'] = [0.843, -0.6, 0, 0.698, '#joyful', '#admirable', 0.714, 'sensible', 'sound', 'healthy', 'commonsense', 'commonsensible']
senticnet['lever'] = [-0.993, 0, 0.66, -0.508, '#sad', '#angry', -0.72, 'bar', 'treadle', 'pry', 'key', 'peavey']
senticnet['leviathan'] = [-0.938, 0, 0.544, -0.778, '#sad', '#disgusting', -0.753, 'mutant', 'variation', 'sport', 'lusus_naturae', 'mutation']
senticnet['levitate'] = [0.037, 0.214, -0.127, 0.237, '#interesting', '#admirable', 0.12, 'raise_up', 'upward_movement', 'move_upward', 'rise_up', 'come_up']
senticnet['levity'] = [0.897, 0, 0, 0, '#joyful', '#joyful', 0.299, 'gratefully', 'appreciatively', 'self-pride', 'conceit', 'self-love']
senticnet['ley'] = [-0.907, 0, 0.765, -0.98, '#sad', '#disgusting', -0.884, 'pastureland', 'grazing_land', 'common_land', 'pasture', 'lea']
senticnet['lgv'] = [-0.546, 0, 0.54, -0.547, '#sad', '#disgusting', -0.544, 'venereal_disease', 'venereal_infection', 'social_disease', 'sexually_transmitted_disease', 'dose']
senticnet['liability'] = [0, 0, 0.967, -0.749, '#angry', '#disgusting', -0.572, 'ratability', 'susceptibility', 'susceptibleness', 'taxability', 'rateability']
senticnet['liaison'] = [0.692, -0.992, 0, 0.614, '#joyful', '#surprising', 0.766, 'intimacy', 'affaire', 'sexual_relationship', 'affair', 'involvement']
senticnet['liar'] = [-0.775, 0, 0.742, -0.801, '#sad', '#disgusting', -0.773, 'lose_election', 'politician', 'government', 'prosecutor', 'elect_person']
senticnet['libation'] = [0.807, -0.92, 0, 0.796, '#joyful', '#surprising', 0.841, 'agape', 'confirmation', 'religious_ritual', 'rite', 'service']
senticnet['libel'] = [0.907, -0.563, 0, 0.721, '#joyful', '#admirable', 0.73, 'assassinate', 'charge', 'accuse', 'malign', 'asperse']
senticnet['liberate'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'break_free', 'set_free', 'relief', 'freedom', 'free_will']
senticnet['liberation'] = [0.847, 0.993, 0, 0, '#joyful', '#interesting', 0.613, 'release_energy', 'release_stress', 'release_tension', 'release', 'relief']
senticnet['libertarian'] = [0.677, -0.529, 0, 0.714, '#joyful', '#admirable', 0.64, 'economic_libertarian', 'civil_libertarian', 'advocate', 'advocator', 'proponent']
senticnet['libertine'] = [-0.544, 0, 0.691, -0.966, '#angry', '#disgusting', -0.734, 'slut', 'trollop', 'adulterer', 'adulteress', 'fornicatress']
senticnet['liberty'] = [0.926, 0.937, 0, 0.975, '#interesting', '#admirable', 0.946, 'monument', 'statue', 'freedom', 'idol', 'sculpture']
senticnet['librarian'] = [0.725, 0, 0, 0.838, '#joyful', '#admirable', 0.521, 'contestant', 'cook_book', 'bookmark', 'a_lot_of_books', 'graduate_student']
senticnet['library'] = [0, 0.076, 0, 0.066, '#interesting', '#admirable', 0.047, 'a_lot_of_books', 'old_testament', 'cook_book', 'magazine', 'librarian']
senticnet['licence'] = [0, 0.757, 0, 0.811, '#interesting', '#admirable', 0.523, 'license', 'drive_license', 'find_car_key', 'start_car_engine', 'put_key_ignition']
senticnet['licenced'] = [-0.784, 0, 0.657, -0.868, '#sad', '#disgusting', -0.77, 'commissioned', 'accredited', 'licensed', 'authorized', 'approved']
senticnet['license'] = [0.673, -0.664, 0, 0.921, '#joyful', '#admirable', 0.753, 'instrument', 'building_permit', 'driver_license', 'driver_licence', 'driving_license']
senticnet['licensed'] = [-0.784, 0, 0.657, -0.868, '#sad', '#disgusting', -0.77, 'commissioned', 'accredited', 'authorized', 'licenced', 'approved']
senticnet['lichen'] = [-0.899, 0, 0.619, -0.827, '#sad', '#disgusting', -0.782, 'lichen_planus', 'lichen_ruber_planus', 'skin_disease', 'disease_of_skin', 'skin_disorder']
senticnet['lichen_planus'] = [-0.899, 0, 0.619, -0.827, '#sad', '#disgusting', -0.782, 'lichen', 'lichen_ruber_planus', 'skin_disease', 'disease_of_skin', 'skin_disorder']
senticnet['lichen_ruber_planus'] = [-0.899, 0, 0.619, -0.827, '#sad', '#disgusting', -0.782, 'lichen_planus', 'lichen', 'skin_disease', 'disease_of_skin', 'skin_disorder']
senticnet['lick'] = [0.074, 0, -0.061, 0.136, '#joyful', '#admirable', 0.05, 'mastication', 'use_mouth', 'enjoy_food', 'masticate', 'savor']
senticnet['lick_finger'] = [-0.044, -0.008, 0.022, -0.077, '#sad', '#disgusting', -0.045, 'walk_exercise', 'lick', 'impulse_shop', 'buy_clothes', 'purchase_food']
senticnet['licking'] = [-0.647, 0, 0.717, -0.983, '#angry', '#disgusting', -0.782, 'debacle', 'lurch', 'whitewash', 'finish', 'failure']
senticnet['lid'] = [0.034, 0.07, 0.057, 0.123, '#interesting', '#admirable', 0.057, 'socket', 'no_sight', 'breakable', 'easy_break', 'easy_tear']
senticnet['lidless'] = [0.805, -0.671, 0, 0.901, '#joyful', '#admirable', 0.792, 'vigilant', 'wakeful', 'watchful', 'fly', 'sleepless']
senticnet['lie'] = [0, 0, -0.805, -0.794, '#scared', '#disgusting', -0.533, 'fallacy', 'falsehood', 'lie_court', 'cover_face', 'dishonesty']
senticnet['lie_around'] = [0.027, 0.104, 0, 0, '#joyful', '#interesting', 0.044, 'turn_aircon_on', 'sit_in_shade', 'take_off_shoes', 'hold_breath', 'sit_still']
senticnet['lie_back'] = [0.924, 0, 0, 0.824, '#joyful', '#admirable', 0.583, 'feel_little_tired', 'take_nap', 'sleepy', 'asleep', 'get_sleep']
senticnet['lie_brick'] = [-0.04, 0.201, -0.111, 0.17, '#interesting', '#admirable', 0.073, 'draw_blueprint', 'help_person', 'fix_car', 'make_better', 'build_house']
senticnet['lie_court'] = [-0.217, 0.16, -0.194, 0.057, '#sad', '#scared', -0.065, 'tell_truth', 'lier', 'find_guilty', 'call_police', 'lie']
senticnet['lie_down'] = [0, 0, 0, -0.089, '#disgusting', '#disgusting', -0.03, 'sleepwalk', 'wear_pyjamas', 'lay_down', 'wind_down', 'close_eye']
senticnet['lie_down_bed'] = [0.165, 0, 0.032, 0.114, '#joyful', '#admirable', 0.082, 'good_sleep', 'shut_eye', 'place_sleep', 'use_bed', 'comfortable_place_sleep']
senticnet['lie_down_close_eye'] = [-0.057, -0.043, 0.054, -0.077, '#sad', '#disgusting', -0.048, 'no_effort', 'take_sleep_pill', 'turn_off_alarm_clock', 'lie_down_bed', 'count_sheep']
senticnet['lie_floor'] = [0, 0.899, 0, 0.826, '#interesting', '#admirable', 0.575, 'live_apartment', 'group_object', 'lean_against', 'hurt_animal', 'eat_animal']
senticnet['lie_on_bed'] = [0.952, 0.889, 0, 0, '#joyful', '#interesting', 0.614, 'sit_down', 'take_break', 'stay_bed', 'sit_chair', 'go_sleep']
senticnet['lie_on_grass'] = [0.737, 0.787, 0, 0.915, '#interesting', '#admirable', 0.813, 'plant_tree', 'pick_flower', 'flower', 'find_flower', 'enjoy_nature']
senticnet['lie_with'] = [0.533, -0.585, 0, 0.814, '#surprising', '#admirable', 0.644, 'have', 'pair', 'take', 'couple', 'fornicate']
senticnet['liege'] = [-0.808, 0, 0.826, -0.629, '#sad', '#angry', -0.754, 'feudal_lord', 'lord', 'master', 'overlord', 'king']
senticnet['liege_lord'] = [-0.808, 0, 0.826, -0.629, '#sad', '#angry', -0.754, 'liege', 'feudal_lord', 'master', 'overlord', 'lord']
senticnet['lier'] = [-0.217, 0.16, -0.194, 0.057, '#sad', '#scared', -0.065, 'tell_truth', 'lie_court', 'find_guilty', 'call_police', 'lie']
senticnet['lieutenant'] = [0.045, 0, 0, 0.088, '#joyful', '#admirable', 0.044, 'leader', 'seaman', 'captain', 'officer', 'traitor']
senticnet['lieutenant_governor'] = [0.984, -0.933, 0, 0.927, '#joyful', '#surprising', 0.948, 'lame_duck', 'elected_official', 'selectman', 'selectwoman', 'official']
senticnet['life'] = [0.993, 0.962, 0, 0.845, '#joyful', '#interesting', 0.933, 'human_experience', 'breathe', 'need_water', 'life_experience', 'life_end']
senticnet['life-long_mate'] = [0.965, 0.775, 0, 0.968, '#joyful', '#admirable', 0.903, 'volume_control', 'two_arms', 'gone_moon', '32_teeth', 'hormone']
senticnet['life_coach'] = [0.865, 0, 0, 0.984, '#joyful', '#admirable', 0.616, 'belt', 'see_well', 'seat_belt', 'lifesaver', 'luck']
senticnet['life_end'] = [-0.132, 0.131, -0.258, 0, '#sad', '#scared', -0.086, 'dead', 'end_life', 'die', 'expire', 'slash_wrist']
senticnet['life_experience'] = [0.993, 0.962, 0, 0.845, '#joyful', '#interesting', 0.933, 'human_experience', 'breathe', 'need_water', 'life', 'life_end']
senticnet['life_form'] = [0.043, 0.117, -0.072, 0.099, '#interesting', '#admirable', 0.062, 'alive', 'live_organism', 'biological_machine', 'live_object', 'species']
senticnet['life_jacket'] = [0.044, -0.033, 0.037, 0.089, '#joyful', '#admirable', 0.043, 'lifebelt', 'save_life', 'lifeguard', 'life_preserver', 'safety_equipment']
senticnet['life_like'] = [0.044, -0.033, 0.037, 0.089, '#joyful', '#admirable', 0.043, 'kid_toy', 'tiny_person', 'mannequin', 'build_block', 'plaything']
senticnet['life_preserver'] = [0.044, -0.033, 0.037, 0.089, '#joyful', '#admirable', 0.043, 'lifebelt', 'save_life', 'lifeguard', 'life_jacket', 'safety_equipment']
senticnet['life_ring'] = [0.928, 0.754, 0, 0, '#joyful', '#interesting', 0.561, 'lifebelt', 'security_belt', 'save_life', 'sailor', 'life_preserver']
senticnet['life_style'] = [0, 0.725, 0, 0.939, '#interesting', '#admirable', 0.555, 'write_book', 'artist', 'publish_book', 'write_with_style', 'fashion_style']
senticnet['lifebelt'] = [0.928, 0.754, 0, 0, '#joyful', '#interesting', 0.561, 'life_ring', 'security_belt', 'save_life', 'sailor', 'life_preserver']
senticnet['lifeboat'] = [0, -0.02, 0.046, -0.111, '#angry', '#disgusting', -0.046, 'sail_ship', 'canoe', 'ship', 'submarine', 'yacht']
senticnet['lifeguard'] = [0, 0, -0.058, -0.074, '#scared', '#disgusting', -0.044, 'chlorine', 'swimmer', 'still_water', 'large_body', 'shallow_water']
senticnet['lifeless'] = [-0.543, 0, -0.408, -0.036, '#sad', '#scared', -0.329, 'die', 'expire', 'kill_self', 'imprison', 'feel_guilt']
senticnet['lifesaver'] = [0.865, 0, 0, 0.984, '#joyful', '#admirable', 0.616, 'belt', 'see_well', 'seat_belt', 'life_coach', 'luck']
senticnet['lifesaving'] = [0.825, -0.636, 0, 0.781, '#joyful', '#admirable', 0.747, 'salvage', 'deliverance', 'redemption', 'salvation', 'recovery']
senticnet['lifestyle'] = [0, 0.095, 0, 0.05, '#interesting', '#admirable', 0.048, 'need_earn_money', 'earn_money', 'responsible', 'perform_service', 'go_work_to_earn_money']
senticnet['lifestyle_change'] = [-0.149, 0, -0.069, -0.187, '#sad', '#disgusting', -0.135, 'head_hurt', 'solution_to_problem', 'know_fact', 'move_eye', 'headache']
senticnet['lifetime'] = [0.086, -0.107, 0.064, 0, '#joyful', '#surprising', 0.043, 'toy', 'ancient_artifact', 'sport_person', 'popular_game', 'bath_toy']
senticnet['lift'] = [0, 0.142, -0.09, 0.183, '#interesting', '#admirable', 0.078, 'arise', 'rise', 'raise_up', 'go_up', 'go_upstairs']
senticnet['lift_car'] = [0.941, 1.0, 0, 0, '#joyful', '#interesting', 0.647, 'enjoy_outdoors', 'exercise_entertainment', 'wear_shorts', 'health_benefit', 'fun']
senticnet['lift_foot'] = [0, 0.787, 0, 0.848, '#interesting', '#admirable', 0.545, 'amplitude', 'step', 'rung', 'bell_ring', 'zigzag']
senticnet['lift_heavy'] = [0, 0.164, -0.063, 0.239, '#interesting', '#admirable', 0.113, 'lift', 'go_up', 'spring_leak', 'haul', 'lift_heavy_object']
senticnet['lift_heavy_object'] = [0.033, 0.104, -0.085, 0.151, '#interesting', '#admirable', 0.068, 'lift_object', 'keep_balance', 'lift', 'lift_heavy', 'step_up']
senticnet['lift_leg'] = [-0.1, 0, -0.07, -0.056, '#sad', '#scared', -0.075, 'travel_through_space', 'fly_around', 'shovel_snow', 'sit_floor', 'smoke_joint']
senticnet['lift_object'] = [-0.03, 0.147, -0.088, 0.189, '#interesting', '#admirable', 0.073, 'spring_leak', 'step_out', 'lift', 'haul', 'move']
senticnet['lift_spirit'] = [0.995, 0, 0, 0.718, '#joyful', '#admirable', 0.571, 'slapstick', 'embarrass_oneself', 'act_silly', 'experience_joy', 'become_happy']
senticnet['lift_up'] = [0.613, 0.678, -0.271, 0.391, '#joyful', '#interesting', 0.47, 'uplift', 'exhilarate', 'urge', 'intoxicate', 'pick_up']
senticnet['lift_weight'] = [-0.062, 0, -0.059, 0, '#sad', '#scared', -0.04, 'go_gym', 'join_gym', 'workout', 'check_doctor', 'eat_balance_diet']
senticnet['light'] = [0.085, 0.107, -0.081, 0, '#joyful', '#interesting', 0.037, 'hot_sun', 'sunbright_light', 'hot', 'hot_day', 'bright_light']
senticnet['light_beam'] = [-0.507, 0, 0.75, -0.951, '#angry', '#disgusting', -0.736, 'beam', 'beam_of_light', 'sunbeam', 'ray', 'ray_of_light']
senticnet['light_bulb'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'illuminate_room', 'give_light', 'light', 'light_source', 'lantern']
senticnet['light_candle'] = [-0.083, 0, -0.088, -0.12, '#scared', '#disgusting', -0.097, 'touch_fire', 'excessive_heat', 'blow_out_match', 'burn_oneself', 'create_light']
senticnet['light_cigar'] = [-0.951, 0, 0.924, -0.937, '#sad', '#disgusting', -0.937, 'cause_mental_illness', 'catch_fire', 'smoke_cigarette', 'age_prematurely', 'light_pipe']
senticnet['light_cigarette'] = [-0.976, 0, 0.621, -0.917, '#sad', '#disgusting', -0.838, 'smoke_cigarette', 'cancer', 'lung_cancer', 'sickness', 'cigarette']
senticnet['light_colored'] = [0.058, 0.141, 0, 0.207, '#interesting', '#admirable', 0.135, 'versatile', 'beautiful', 'delicate', 'fragile', 'delicious']
senticnet['light_dark'] = [0, 0, -0.083, 0, '#scared', '#scared', -0.028, 'burn_material', 'heat_house', 'heat_home', 'make_light', 'burn_fuel']
senticnet['light_diet'] = [-0.637, 0, 0.819, -0.997, '#angry', '#disgusting', -0.818, 'diet', 'soft_diet', 'spoon_food', 'bland_diet', 'ulcer_diet']
senticnet['light_fire'] = [0, 0, -0.849, -0.858, '#scared', '#disgusting', -0.569, 'start_flame_fire', 'make_campfire', 'play_fire', 'start_fire', 'strike_match']
senticnet['light_fixture'] = [0.09, -0.032, 0.015, 0, '#joyful', '#surprising', 0.036, 'tape_player', 'dvd_player', 'tv_set', 'sit_at_theater', 'technician']
senticnet['light_in_sky'] = [0.02, 0.067, 0, 0, '#joyful', '#interesting', 0.029, 'sunrise', 'begin_day', 'afternoon', 'soon', 'part_of_day']
senticnet['light_instrument'] = [-0.031, -0.004, -0.048, -0.144, '#scared', '#disgusting', -0.073, 'medical_instrument', 'cystoscope', 'gastroscope', 'endoscope', 'sigmoidoscope']
senticnet['light_intensity'] = [-0.934, 0, 0.698, -0.857, '#sad', '#disgusting', -0.83, 'candlepower', 'intensity', 'acoustic_power', 'sound_pressure_level', 'threshold_level']
senticnet['light_match'] = [-0.974, 0, 0.707, -0.9, '#sad', '#disgusting', -0.86, 'fire', 'burn', 'flame', 'heat', 'burn_thing']
senticnet['light_metal'] = [0.023, 0, 0, 0.066, '#joyful', '#admirable', 0.03, 'soft_metal', 'light_weight', 'metal_type', 'magnetic', 'lightweight_metal']
senticnet['light_pia_lot_of_light'] = [0.949, 0.952, 0, 0, '#joyful', '#interesting', 0.634, 'blow_out', 'create_light', 'burn_wood', 'burn_paper', 'heat_light']
senticnet['light_pipe'] = [-0.951, 0, 0.924, -0.937, '#sad', '#disgusting', -0.937, 'cause_mental_illness', 'catch_fire', 'smoke_cigarette', 'light_cigar', 'age_prematurely']
senticnet['light_red'] = [-0.051, 0, 0.037, 0, '#sad', '#angry', -0.029, 'color', 'bright_color', 'secondary_color', 'red_apple', 'primary_color']
senticnet['light_reflex'] = [-0.631, 0, 0.891, -0.871, '#angry', '#disgusting', -0.798, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['light_source'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'illuminate_room', 'give_light', 'light', 'light_bulb', 'lantern']
senticnet['light_up'] = [0, 0.745, 0, 0.776, '#interesting', '#admirable', 0.507, 'corrode', 'burn_up', 'burn_heat', 'dig_up', 'heat_up']
senticnet['light_up_room'] = [0.613, 0.678, -0.271, 0.391, '#joyful', '#interesting', 0.47, 'illuminate_room', 'light', 'switch_on_light', 'create_light', 'light_in_sky']
senticnet['light_weight'] = [0.023, 0, 0, 0.066, '#joyful', '#admirable', 0.03, 'soft_metal', 'light_metal', 'metal_type', 'magnetic', 'lightweight_metal']
senticnet['lighted'] = [0.641, -0.733, 0, 0.798, '#surprising', '#admirable', 0.724, 'ablaze', 'aflame', 'afire', 'aflare', 'alight']
senticnet['lighten'] = [0, -0.003, -0.078, -0.061, '#scared', '#disgusting', -0.045, 'bright_flash', 'tornado', 'dynamite_explosion', 'forest_fire', 'lightning']
senticnet['lightening'] = [0.995, -0.533, 0, 0.977, '#joyful', '#admirable', 0.835, 'change_of_state', 'discoloration', 'discolouration', 'whitening', 'change_of_color']
senticnet['lighter'] = [0.215, 0.194, -0.204, 0.279, '#joyful', '#admirable', 0.161, 'use_match', 'gather_kindle', 'combustible_material', 'rub_two_stick_together', 'diligence']
senticnet['lighter_air'] = [0.02, -0.075, 0, 0, '#joyful', '#surprising', 0.032, 'inert_gas', 'gas', 'non-renewable_resource', 'fuel', 'noble_gas']
senticnet['lighter_water'] = [0, 0, -0.104, 0, '#scared', '#scared', -0.035, 'oxygen', 'breathable', 'inhale_air', 'hydrogen', 'air']
senticnet['lightheartedness'] = [0.69, 0.626, -0.234, 0.317, '#joyful', '#interesting', 0.466, 'insouciance', 'carefree', 'lightsomeness', 'unworried', 'carefreeness']
senticnet['lighting'] = [-0.907, 0, 0.209, -0.927, '#sad', '#disgusting', -0.681, 'sun_burn', 'erythema', 'fire', 'burn_skin', 'hurt_skin']
senticnet['lightly_armored'] = [-0.897, 0, 0.945, -0.894, '#sad', '#angry', -0.912, 'bulletproof', 'mailed', 'armored', 'lightly_armoured', 'scaled']
senticnet['lightly_armoured'] = [-0.897, 0, 0.945, -0.894, '#sad', '#angry', -0.912, 'bulletproof', 'mailed', 'lightly_armored', 'armored', 'scaled']
senticnet['lightness'] = [0.672, 0.639, -0.241, 0.314, '#joyful', '#interesting', 0.461, 'enchant', 'euphoriant', 'euphoria', 'comfortably', 'comfortableness']
senticnet['lightning'] = [0, -0.003, -0.078, -0.061, '#scared', '#disgusting', -0.045, 'lighten', 'tornado', 'dynamite_explosion', 'forest_fire', 'bright_flash']
senticnet['lightsomeness'] = [0.69, 0.626, -0.234, 0.317, '#joyful', '#interesting', 0.466, 'lightheartedness', 'insouciance', 'carefree', 'unworried', 'carefreeness']
senticnet['lightweight'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'carbon_fiber', 'aluminium', 'light', 'thin', 'performant']
senticnet['lightweight_metal'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'protective_gear', 'metal_ore', 'knight_protection', 'metal', 'knight']
senticnet['lignite'] = [0.599, -0.879, 0, 0.673, '#surprising', '#admirable', 0.717, 'humic_shale', 'material', 'stuff', 'peat', 'humate']
senticnet['like'] = [0.47, 0.419, -0.318, 0.367, '#joyful', '#interesting', 0.313, 'affection', 'wonderful_feeling', 'pleasant_emotion', 'happy', 'good_emotion']
senticnet['like_art'] = [0.039, 0.09, 0, 0.091, '#interesting', '#admirable', 0.073, 'go_art_museum', 'go_museum', 'go_art_gallery', 'use_eye', 'open_eye']
senticnet['like_beer'] = [0.782, 0, 0, 0.726, '#joyful', '#admirable', 0.503, 'hold_liquor', 'travel_fast_light', 'live_ocean', 'drink_alcohol', 'drink_sea_water']
senticnet['like_boy'] = [-0.147, 0, -0.1, 0, '#sad', '#scared', -0.082, 'draw', 'even_odds', 'raise_flag', 'even_score', 'kill_other_person']
senticnet['like_candy'] = [0.273, 0.226, -0.139, 0.332, '#joyful', '#admirable', 0.231, 'morality', 'good', 'uncommon', 'elusive', 'capitalize']
senticnet['like_car'] = [0, 0.066, -0.058, 0.095, '#interesting', '#admirable', 0.034, 'interjection', 'another_name', 'red_cross', 'traffic_cop', 'gas_electric']
senticnet['like_challenge'] = [0.741, 0.964, 0, 0, '#joyful', '#interesting', 0.568, 'get_famous', 'win_money', 'fun', 'profitable', 'keep_busy']
senticnet['like_compete'] = [0.956, 0.925, 0, 0, '#joyful', '#interesting', 0.627, 'enjoy_challenge', 'fun', 'win_money', 'challenge', 'something_to_do']
senticnet['like_cost'] = [0, 0.266, 0, 0.141, '#interesting', '#admirable', 0.136, 'money_term', 'item_worth', 'like_price', 'sticker', 'amount_charge']
senticnet['like_eat'] = [0.184, 0.159, 0, 0.234, '#joyful', '#admirable', 0.192, 'ingest', 'sip', 'better_cold', 'gulp', 'consumable']
senticnet['like_electricity'] = [0, 0.758, 0, 0.81, '#interesting', '#admirable', 0.523, 'power_source', 'potential', 'hyper', 'create_destroy', 'power']
senticnet['like_exercise'] = [0.867, 0, 0, 0.88, '#joyful', '#admirable', 0.582, 'lose_weight', 'stay_fit', 'fit', 'shape', 'weight_loss']
senticnet['like_flower'] = [0, 0.136, -0.071, 0.107, '#interesting', '#admirable', 0.057, 'plant_yard', 'hang_ceiling', 'small_flower', 'cut_grass', 'garden_plant']
senticnet['like_food'] = [0.098, 0.103, -0.062, 0.134, '#interesting', '#admirable', 0.091, 'bake_bean', 'bake_cake', 'foodstuff', 'pop', 'eat_food']
senticnet['like_girl'] = [0, 0.889, 0, 0.792, '#interesting', '#admirable', 0.56, 'bovine', 'good_friend', 'produce_milk', 'barn_animal', 'make_milk']
senticnet['like_jail'] = [0.098, 0.165, -0.134, 0.284, '#interesting', '#admirable', 0.138, 'assert', 'live_forever', 'live_ocean', 'like_play', 'proclamation']
senticnet['like_job'] = [0.31, 0, 0.02, 0.229, '#joyful', '#admirable', 0.173, 'know_everything', 'control_weather', 'live_ocean', 'like_play', 'wiseman']
senticnet['like_mouse'] = [0, 0.827, 0, 0.791, '#interesting', '#admirable', 0.539, 'secret_agent', 'pointer', 'indicator', 'underground_animal', 'critter']
senticnet['like_movie'] = [0.993, 0.727, 0, 0, '#joyful', '#interesting', 0.573, 'enjoy_movie', 'want_entertain', 'watch_show', 'mindless_entertainment', 'go_date']
senticnet['like_music'] = [0.806, 0.776, 0, 0.761, '#joyful', '#interesting', 0.781, 'entertain_others', 'music_lover', 'relieve_boredom', 'appreciate_music', 'entertain_audience']
senticnet['like_paint'] = [0.032, 0.076, 0.015, 0.068, '#interesting', '#admirable', 0.054, 'artistic', 'create_image', 'wall_hang', 'wall_decoration', 'art_creation']
senticnet['like_play'] = [0.098, 0.165, -0.134, 0.284, '#interesting', '#admirable', 0.138, 'like_jail', 'live_forever', 'live_ocean', 'assert', 'proclamation']
senticnet['like_play_game'] = [0.753, 0.703, 0, 0, '#joyful', '#interesting', 0.485, 'field_ball', 'roll_downhill', 'run_around', 'drive_crazy', 'like_boy']
senticnet['like_poetry'] = [0.93, 0, 0, 0, '#joyful', '#joyful', 0.31, 'greet_card', 'rhyme', 'song_lyric', 'refrain', 'musical_notation']
senticnet['like_read'] = [-0.041, 0.226, -0.143, 0.255, '#interesting', '#admirable', 0.099, 'always_read', 'plot', 'personality_trait', 'animate', 'play_role']
senticnet['like_run'] = [0, 0.916, 0, 0.917, '#interesting', '#admirable', 0.611, 'walk_fast', 'fast_walk', 'walk_quickly', 'run_slowly', 'human_movement']
senticnet['like_sea'] = [-0.038, 0.077, 0.048, 0.091, '#interesting', '#admirable', 0.027, 'near_beach', 'along_beach', 'roller', 'near_sea', 'depth']
senticnet['like_see'] = [0, 0.925, 0, 0.734, '#interesting', '#admirable', 0.553, 'quick_look', 'stop_look', 'approach', 'bad_odor', 'simile']
senticnet['like_sport'] = [0.887, 0, 0, 0, '#joyful', '#joyful', 0.296, 'fun', 'difficult_play', 'enjoy_sport', 'creepy', 'competition']
senticnet['like_taste'] = [0, 0.933, 0, 0.785, '#interesting', '#admirable', 0.573, 'hunger', 'hungry', 'survive', 'stay_alive', 'crave']
senticnet['like_win'] = [0.217, -0.198, 0.096, 0, '#joyful', '#surprising', 0.106, 'sell_beer', 'long_tube', 'fun_place', 'recreational', 'get_hammered']
senticnet['like_women'] = [0.884, 0, 0, 0, '#joyful', '#joyful', 0.295, 'egalitarian', 'partygoer', 'drink', 'have_fun', 'senator']
senticnet['like_write'] = [0, 0.097, 0, 0.092, '#interesting', '#admirable', 0.063, 'urgent', 'classify_ad', 'project', 'review', 'repetition']
senticnet['likeable'] = [0.532, 0.655, -0.259, 0.277, '#joyful', '#interesting', 0.402, 'good_looking', 'like', 'reassuring', 'reassuringly', 'assure']
senticnet['likely'] = [0.062, 0.293, 0.182, 0.316, '#interesting', '#admirable', 0.163, 'different', 'particular', 'outlier', 'strange', 'exclusion']
senticnet['likely_discover_truth'] = [0, 0.814, 0, 0.819, '#interesting', '#admirable', 0.544, 'newbie', 'matrimony', 'contrary', 'inquisitive', 'new_person']
senticnet['likeness'] = [-0.8, 0, 0.758, -0.799, '#sad', '#disgusting', -0.786, 'resemblance', 'comparison', 'equivalence', 'reflection', 'spitting_image']
senticnet['likening'] = [-0.946, 0, 0.904, -0.751, '#sad', '#angry', -0.867, 'confrontation', 'contrast', 'scrutiny', 'collation', 'comparing']
senticnet['liking'] = [0.959, 0, 0, 0.879, '#joyful', '#admirable', 0.613, 'fondness', 'love', 'affection', 'penchant', 'attachment']
senticnet['lilt'] = [0.982, -0.701, 0, 0.527, '#joyful', '#surprising', 0.737, 'sound', 'enounce', 'accent', 'round', 'sibilate']
senticnet['lilting'] = [-0.841, 0, 0.574, -0.668, '#sad', '#disgusting', -0.694, 'cadenced', 'cadent', 'metrical', 'metric', 'rhythmical']
senticnet['limb'] = [0, 0.103, 0, 0.111, '#interesting', '#admirable', 0.071, 'body_extremity', 'projection', 'appendage', 'organ', 'tailpiece']
senticnet['limber_up'] = [-0.089, 0, 0, 0, '#sad', '#sad', -0.03, 'stretch_muscle', 'expend_energy', 'touch_toe', 'stretch', 'move_leg']
senticnet['limbo'] = [0.128, -0.041, 0, 0, '#joyful', '#surprising', 0.056, 'buffet', 'rave', 'auction', 'banquet', 'loose_end']
senticnet['lime'] = [0, -0.015, 0.037, -0.046, '#angry', '#disgusting', -0.023, 'pear', 'green_apple', 'apricot', 'cherry', 'pumpkin']
senticnet['limen'] = [0.575, -0.767, 0, 0.83, '#surprising', '#admirable', 0.724, 'sensation', 'esthesis', 'aesthesis', 'sense_experience', 'sense_impression']
senticnet['limicoline_bird'] = [0.786, -0.82, 0, 0.776, '#joyful', '#surprising', 0.794, 'red_phalarope', 'northern_phalarope', 'shorebird', 'shore_bird', 'phalarope']
senticnet['limit'] = [-0.739, 0, 0, -0.894, '#sad', '#disgusting', -0.544, 'limit_time', 'restrict', 'deadline', 'stint', 'restriction']
senticnet['limit_time'] = [-0.038, 0.255, -0.204, 0.359, '#interesting', '#admirable', 0.124, 'distribute', 'hand_out', 'give', 'suggest', 'donate']
senticnet['limitation'] = [-0.938, 0, 0, -0.859, '#sad', '#disgusting', -0.599, 'narrowness', 'quantification', 'regulation', 'restraint', 'limit']
senticnet['limited'] = [0, 0.756, 0, 0.791, '#interesting', '#admirable', 0.516, 'bounded', 'finite', 'finite_state_machine', 'wall', 'boundary']
senticnet['limited_liability'] = [0.628, -0.607, 0, 0.532, '#joyful', '#surprising', 0.589, 'account_payable', 'payable', 'indebtedness', 'debt', 'arrears']
senticnet['limitless'] = [0, 0.822, 0, 0.942, '#interesting', '#admirable', 0.588, 'heavenly_body', 'star_planet', 'celestial_body', 'around_earth', 'unlimited']
senticnet['limousine'] = [0.028, 0, 0.013, 0.061, '#joyful', '#admirable', 0.025, 'truck', 'vehicle', 'big_car', 'car', 'lorry']
senticnet['limp'] = [0, 0.069, 0.031, 0.149, '#interesting', '#admirable', 0.062, 'walk_part', 'extension', 'foot_action', 'walk_device', 'stand_upon']
senticnet['limpa'] = [0.52, -0.693, 0, 0.639, '#surprising', '#admirable', 0.617, 'black_bread', 'pumpernickel', 'rye_bread', 'bread', 'breadstuff']
senticnet['limpid'] = [0, 0, -0.715, -0.892, '#scared', '#disgusting', -0.536, 'liquid', 'crystal_clear', 'pellucid', 'crystalline', 'lucid']
senticnet['limpidity'] = [0.824, -0.959, 0, 0.513, '#joyful', '#surprising', 0.765, 'clearcutness', 'explicitness', 'preciseness', 'perspicuity', 'perspicuousness']
senticnet['limping'] = [-0.724, 0, 0, -0.915, '#sad', '#disgusting', -0.546, 'gimpiness', 'lameness', 'claudication', 'gimp', 'gameness']
senticnet['line'] = [0.614, -0.953, 0, 0.768, '#surprising', '#admirable', 0.778, 'keeping', 'formality', 'honoring', 'abidance', 'observance']
senticnet['line_of_destiny'] = [0.781, -0.662, 0, 0.666, '#joyful', '#admirable', 0.703, 'crease', 'crinkle', 'wrinkle', 'furrow', 'seam']
senticnet['line_of_fate'] = [0.658, -0.887, 0, 0.932, '#surprising', '#admirable', 0.826, 'crease', 'crinkle', 'wrinkle', 'furrow', 'seam']
senticnet['line_of_heart'] = [0.745, -0.7, 0, 0.714, '#joyful', '#admirable', 0.72, 'crease', 'crinkle', 'wrinkle', 'furrow', 'seam']
senticnet['line_of_inquiry'] = [0.546, -0.666, 0, 0.661, '#surprising', '#admirable', 0.624, 'reasoning', 'logical_thinking', 'abstract_thought', 'casuistry', 'line_of_reasoning']
senticnet['line_of_reasoning'] = [0.546, -0.666, 0, 0.661, '#surprising', '#admirable', 0.624, 'reasoning', 'logical_thinking', 'abstract_thought', 'casuistry', 'line_of_inquiry']
senticnet['line_of_saturn'] = [0.624, -0.83, 0, 0.821, '#surprising', '#admirable', 0.758, 'crease', 'crinkle', 'wrinkle', 'furrow', 'seam']
senticnet['line_place'] = [0.091, 0, 0, 0.327, '#joyful', '#admirable', 0.139, 'address', 'stance', 'location', 'live_area', 'place_where_people_live']
senticnet['line_storm'] = [-0.872, 0, 0.91, -0.78, '#sad', '#angry', -0.854, 'storm', 'thundershower', 'rain', 'rainstorm', 'equinoctial_storm']
senticnet['line_up'] = [0.763, 0.907, 0, 0, '#joyful', '#interesting', 0.557, 'find_end_line', 'come_early', 'find_line', 'take_number', 'wait_patiently']
senticnet['linear'] = [0, 0, 0.94, -0.769, '#angry', '#disgusting', -0.57, 'analog', 'one-dimensional', 'elongate', 'additive', 'analogue']
senticnet['lined'] = [0, 0, 0.914, -0.975, '#angry', '#disgusting', -0.63, 'run_along', 'delineate', 'describe', 'trace', 'draw']
senticnet['linen'] = [0.053, 0.068, -0.052, 0.06, '#interesting', '#admirable', 0.043, 'flag', 'star_stripe', 'velvet', 'nation', 'burlap']
senticnet['linen_chest'] = [0, 0, -0.064, -0.116, '#scared', '#disgusting', -0.06, 'elderly_person', 'hide-a-bed', 'homosexual', 'old_lady', 'dust_mite']
senticnet['linen_cupboard'] = [0, 0.171, -0.056, 0.102, '#interesting', '#admirable', 0.072, 'bed', 'mattress', 'bead', 'bed_cover', 'seduce']
senticnet['ling'] = [0.83, -0.802, 0, 0.969, '#joyful', '#admirable', 0.867, 'water_caltrop', 'water_chestnut', 'water_chestnut_ko', 'aquatic_plant', 'water_plant']
senticnet['ling_ko'] = [0.83, -0.802, 0, 0.969, '#joyful', '#admirable', 0.867, 'water_caltrop', 'ling', 'water_chestnut', 'aquatic_plant', 'water_plant']
senticnet['linger'] = [-0.885, 0, 0.925, -0.556, '#sad', '#angry', -0.789, 'falter', 'waver', 'hesitate', 'boggle', 'dwell_on']
senticnet['lingerie'] = [0, -0.068, 0.092, -0.098, '#angry', '#disgusting', -0.041, 'prescription_medication', 'pantyhose', 'panties', 'sachet', 'pair_of_pants']
senticnet['lingo'] = [-0.043, -0.021, 0.041, -0.039, '#sad', '#angry', -0.034, 'jargon', 'slang', 'cant', 'chatspeak', 'unusual_language']
senticnet['linguistics'] = [0, 0.87, 0, 0.96, '#interesting', '#admirable', 0.61, 'ask_name', 'unfold', 'know_language', 'speak_write', 'subscribe']
senticnet['lining'] = [-0.948, 0, 0.523, -0.801, '#sad', '#disgusting', -0.757, 'refractory', 'protective_cover', 'protective_covering', 'protection', 'brake_lining']
senticnet['link'] = [0.023, 0.173, -0.098, 0.182, '#interesting', '#admirable', 0.093, 'connect', 'connection', 'join', 'dot', 'clasp']
senticnet['link_up'] = [0.63, -0.556, 0, 0.946, '#joyful', '#admirable', 0.711, 'intercommunicate', 'connect', 'link', 'complect', 'join']
senticnet['linoleum'] = [0, 0.894, 0, 0.733, '#interesting', '#admirable', 0.542, 'carpet', 'mat', 'rug', 'furniture', 'pillow_case']
senticnet['lion'] = [0, -0.977, 0, 0, '#surprising', '#surprising', 0.326, 'mountain_cougar', 'skunk', 'cougar', 'tiger', 'lynx']
senticnet['lip_balm'] = [0.03, 0, 0.07, -0.078, '#angry', '#disgusting', -0.039, 'checkbook_holder', 'account_book', 'checkbook_cover', 'highlighter_pen', 'passport_case']
senticnet['lip_reader'] = [-0.691, 0, 0.99, -0.716, '#angry', '#disgusting', -0.799, 'mute', 'mortal', 'deaf_person', 'person', 'individual']
senticnet['lip_service'] = [0.744, -0.891, 0, 0.668, '#joyful', '#surprising', 0.768, 'pretense', 'feigning', 'dissembling', 'pretence', 'crocodile_tears']
senticnet['lip_stick'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'sexual_excitement', 'sexy', 'wet_lip', 'kiss', 'clean_up']
senticnet['liqueur'] = [0.748, -0.524, 0, 0.84, '#joyful', '#admirable', 0.704, 'anisette', 'maraschino', 'ratafia', 'pastis', 'ratafee']
senticnet['liquid'] = [0.048, 0, 0, 0.058, '#joyful', '#admirable', 0.035, 'fluid', 'potable_liquid', 'liquid_beverage', 'beverage', 'coke']
senticnet['liquid_beverage'] = [0.113, 0.093, 0, 0.09, '#joyful', '#interesting', 0.099, 'potable_liquid', 'better_cold', 'cola', 'beverage', 'coke']
senticnet['liquid_body_substance'] = [-0.663, 0, 0.806, -0.955, '#angry', '#disgusting', -0.808, 'gleet', 'humor', 'sanies', 'bodily_fluid', 'body_fluid']
senticnet['liquid_container'] = [0, 0.071, 0, 0.128, '#interesting', '#admirable', 0.066, 'drink_holder', 'recyclable', 'type_of_container', 'drink_container', 'storage_container']
senticnet['liquid_drink'] = [0.948, 0.992, 0, 0.974, '#interesting', '#admirable', 0.971, 'ferment_beverage', 'yogurt', 'fermented_juice', 'healthy_drink', 'alcoholic_drink']
senticnet['liquid_food'] = [0.079, 0.065, 0.013, 0.062, '#joyful', '#interesting', 0.064, 'broth', 'ingest', 'potable_liquid', 'serve_hot', 'porridge']
senticnet['liquid_fuel'] = [0, 0, -0.068, 0, '#scared', '#scared', -0.023, 'greasy', 'car_gas', 'fossil_fuel', 'crude', 'lubrication']
senticnet['liquid_gas'] = [0.039, 0, 0, 0.052, '#joyful', '#admirable', 0.03, 'hot_air', 'fire_hazard', 'type_of_engine', 'warm_air', 'gas']
senticnet['liquid_measure'] = [0.884, 0.877, 0, 0, '#joyful', '#interesting', 0.587, 'liquid_unit', 'amount_water', 'small_size', 'amount_waterment', 'small_amount']
senticnet['liquid_measurement'] = [0, 0.889, 0, 0.874, '#interesting', '#admirable', 0.588, 'liquid_measure', 'imperial_measurement', 'measure_unit', 'volume_measurement', 'liquid_unit']
senticnet['liquid_substance'] = [0.061, 0.118, 0, 0.145, '#interesting', '#admirable', 0.108, 'fluid', 'sip', 'potable_liquid', 'liquid', 'better_cold']
senticnet['liquid_unit'] = [-0.036, 0.107, 0.097, 0.169, '#interesting', '#admirable', 0.048, 'liquid_measure', 'amount_water', 'measure_unit', 'liquid_measurement', 'small_size']
senticnet['liquid_water'] = [0.095, 0, -0.045, 0.062, '#joyful', '#admirable', 0.037, 'photographer', 'water_spray', 'moisture', 'rise_water', 'droplet']
senticnet['liquor'] = [0.186, -0.104, 0.046, 0, '#joyful', '#surprising', 0.081, 'hold_cold_beer', 'whisky', 'alcohol', 'adult_drink', 'cold_beer']
senticnet['liquor_glass'] = [0.776, 0, 0, 0.747, '#joyful', '#admirable', 0.508, 'beer_mug', 'flask', 'beer', 'refill', 'bartender']
senticnet['liquor_store'] = [0.989, 0, 0, 0.81, '#joyful', '#admirable', 0.6, 'tavern', 'bar', 'pub', 'martini', 'brewery']
senticnet['lis_pendens'] = [0.804, -0.993, 0, 0.507, '#joyful', '#surprising', 0.768, 'antitrust_case', 'civil_action', 'counterclaim', 'custody_case', 'action_at_law']
senticnet['lissomeness'] = [0.992, -0.826, 0, 0.901, '#joyful', '#admirable', 0.906, 'gracility', 'grace', 'gracefulness', 'litheness', 'suppleness']
senticnet['list'] = [0.113, 0.126, 0, 0.11, '#joyful', '#interesting', 0.116, 'file', 'pencil_pen', 'document', 'note_pad', 'scrap_paper']
senticnet['list_appointment'] = [0, 0.094, 0, 0, '#interesting', '#interesting', 0.031, 'appointment', 'pocket_notebook', 'appointment_book', 'index_card', 'ring_binder']
senticnet['list_item'] = [0.824, 0.719, 0, 0, '#joyful', '#interesting', 0.514, 'keep_record', 'cross_room', 'check_balance', 'strive', 'record']
senticnet['list_number'] = [0, 0.148, 0.105, 0.187, '#interesting', '#admirable', 0.077, 'arithmetic', 'enumeration', 'numerical', 'addition', 'count']
senticnet['listen'] = [0.089, 0, 0, 0.13, '#joyful', '#admirable', 0.073, 'entertain_others', 'entertain_other_person', 'create_mood', 'hear_beautiful_music', 'use_microphone']
senticnet['listen_advice'] = [-0.088, 0, -0.059, -0.168, '#sad', '#disgusting', -0.105, 'jot_down_note', 'use_telescope', 'become_enlighten', 'study_library', 'learn_new_idea']
senticnet['listen_bird'] = [0.909, 0.983, 0, 0, '#joyful', '#interesting', 0.631, 'play_cd', 'wave_arm', 'smell_odor', 'annoy_other_person', 'age_well']
senticnet['listen_carefully'] = [0, -0.964, 0, 0.732, '#surprising', '#admirable', 0.565, 'pay_attention', 'use_dictionary', 'ask_question', 'move_eye', 'turn_page']
senticnet['listen_cd'] = [0.924, 0.968, 0, 0.876, '#joyful', '#interesting', 0.923, 'turn_radio', 'put_radio', 'listen_news', 'listen', 'ability_hear']
senticnet['listen_classical_music'] = [0.949, -0.951, 0, 0, '#joyful', '#surprising', 0.633, 'fall_asleep', 'sleepy', 'bed_time', 'drink_cup_tea', 'drowsiness']
senticnet['listen_device'] = [0, 0.08, 0.016, 0.098, '#interesting', '#admirable', 0.054, 'organ_body', 'sensory_organ', 'side_face', 'sense_organ', 'hold_glass']
senticnet['listen_good_music'] = [0.854, 0.89, 0, 0, '#joyful', '#interesting', 0.581, 'relax', 'stress_reduction', 'forget_problem', 'read_program', 'listen_classical_music']
senticnet['listen_heart'] = [0, 0.716, 0, 0.741, '#interesting', '#admirable', 0.486, 'make_musical_sound', 'part_of_band', 'play_stringed_instrument', 'make_noise', 'backup']
senticnet['listen_joke'] = [0.799, 0.922, 0, 0.946, '#interesting', '#admirable', 0.889, 'hear_funny', 'emotional_response', 'hear_joke', 'see_funny', 'think_funny']
senticnet['listen_lecture'] = [0, 0.923, 0, 0.922, '#interesting', '#admirable', 0.615, 'learn', 'listen_teacher', 'review_note', 'know_subject', 'better_grade']
senticnet['listen_music'] = [0.853, 0.762, 0, 0.733, '#joyful', '#interesting', 0.783, 'hear_music', 'hear_sing', 'watch_musician_perform', 'see_band', 'listen_radio']
senticnet['listen_music_headphones'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'enjoy_music', 'relax', 'enjoy_fresh_air', 'listen_music', 'favorite_singer']
senticnet['listen_news'] = [0.924, 0.968, 0, 0.876, '#joyful', '#interesting', 0.923, 'hear_sound', 'listen_cd', 'listen', 'turn_radio', 'loose_track_time']
senticnet['listen_orchestra'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'perform_on_stage', 'compose_music', 'play_instrument', 'make_a_lot_of_noise', 'sound_beautiful']
senticnet['listen_pleasure'] = [0.233, -0.203, 0.156, -0.202, '#joyful', '#surprising', 0.026, 'set_mood', 'enjoy_music', 'feel_excited', 'music_lover', 'get_entertain']
senticnet['listen_problem'] = [0, 0, -0.139, 0, '#scared', '#scared', -0.046, 'share_secret', 'make_eye_contact', 'keep_secret', 'look_eye', 'say_hello']
senticnet['listen_radio'] = [0.853, 0.762, 0, 0.733, '#joyful', '#interesting', 0.783, 'hear_music', 'hear_sing', 'watch_musician_perform', 'see_band', 'listen_music']
senticnet['listen_rock_music'] = [0.94, 0.898, 0, 0.945, '#joyful', '#admirable', 0.928, 'experience_pleasure', 'experience_joy', 'visit_parent', 'sleep_through', 'trade_stock']
senticnet['listen_sermon'] = [0.028, 0.234, 0, 0.175, '#interesting', '#admirable', 0.146, 'spirituality', 'religious_purpose', 'good_student', 'prayer', 'christianity']
senticnet['listen_speaker'] = [0.992, 0.857, 0, 0, '#joyful', '#interesting', 0.616, 'offer_opinion', 'review_material', 'inform', 'pay_attention', 'know_subject']
senticnet['listen_story'] = [-0.077, 0, 0, -0.146, '#sad', '#disgusting', -0.074, 'act_out', 'wet_pant', 'laugh_loudly', 'experience_pleasure', 'correct_mistake']
senticnet['listen_tape'] = [0.703, 0.972, 0, 0, '#joyful', '#interesting', 0.558, 'invent_20th_century', 'study_library', 'guess_answer', 'solve_equation', 'point_out']
senticnet['listen_teacher'] = [0.54, 0.55, 0, 0.805, '#interesting', '#admirable', 0.632, 'learn_new_subject', 'learn_information', 'become_educated', 'better_grade', 'learn_fact']
senticnet['listen_to_music'] = [0.813, 0.918, 0, 0, '#joyful', '#interesting', 0.577, 'hear_beautiful_music', 'love_music', 'sound_beautiful', 'appreciate_music', 'play_instrument']
senticnet['listen_well'] = [0.216, -0.122, 0.085, -0.115, '#joyful', '#surprising', 0.046, 'hear_song', 'sing_along', 'earring', 'hear_well', 'tap_foot']
senticnet['listen_witness'] = [-0.045, 0.092, 0, 0.062, '#interesting', '#admirable', 0.036, 'call_witness', 'enter_courtroom', 'hold_trial', 'go_courtroom', 'question_witness']
senticnet['listener'] = [0, 0.081, 0, 0.09, '#interesting', '#admirable', 0.057, 'sensory_organ', 'hold_glass', 'listen_device', 'human_organ', 'sense_organ']
senticnet['listless'] = [-0.952, 0, 0.59, -0.677, '#sad', '#disgusting', -0.74, 'dispirited', 'heartless', 'apathetic', 'bloodless', 'spiritless']
senticnet['listlessness'] = [0.243, 0.632, -0.238, 0.145, '#joyful', '#interesting', 0.261, 'lassitude', 'emotionless', 'unemotionality', 'stolidity', 'phlegm']
senticnet['lite'] = [0.092, 0.07, 0.036, 0.068, '#joyful', '#interesting', 0.065, 'gallon', 'quart', 'pint', 'ounce', 'liquid_measurement']
senticnet['literacy'] = [0.698, -0.714, 0, 0.866, '#surprising', '#admirable', 0.759, 'acquirement', 'skill', 'accomplishment', 'acquisition', 'attainment']
senticnet['literalism'] = [-0.579, 0, 0.791, -0.74, '#angry', '#disgusting', -0.703, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['literalness'] = [0.68, -0.684, 0, 0.907, '#surprising', '#admirable', 0.757, 'materiality', 'concreteness', 'physicalness', 'corporeality', 'corporality']
senticnet['literary_critic'] = [0.811, -0.63, 0, 0.959, '#joyful', '#admirable', 0.8, 'drama_critic', 'theater_critic', 'professional', 'art_critic', 'critic']
senticnet['literary_criticism'] = [0.587, -0.948, 0, 0.659, '#surprising', '#admirable', 0.731, 'critique', 'review', 'explication_de_texte', 'textual_criticism', 'new_criticism']
senticnet['literary_genre'] = [-0.948, 0, 0.718, -0.805, '#sad', '#disgusting', -0.824, 'poetry', 'verse', 'drama', 'prose', 'form']
senticnet['literate'] = [0, 0.087, 0, 0, '#interesting', '#interesting', 0.029, 'know_how_read', 'learn_how_read', 'learn_read', 'open_up', 'literacy']
senticnet['literature'] = [0.036, 0.219, 0, 0.19, '#interesting', '#admirable', 0.148, 'novel', 'fiction', 'classic', 'long_story', 'print_material']
senticnet['lithe'] = [0, 0, -0.926, -0.837, '#scared', '#disgusting', -0.588, 'sylphlike', 'supple', 'lissom', 'slender', 'svelte']
senticnet['litheness'] = [0.992, -0.826, 0, 0.901, '#joyful', '#admirable', 0.906, 'gracility', 'grace', 'lissomeness', 'gracefulness', 'suppleness']
senticnet['lithium'] = [0, 0, -0.973, 0, '#scared', '#scared', -0.324, 'iodine', 'arsenic', 'uranium', 'element', 'manganese']
senticnet['lithophyte'] = [0.704, -0.925, 0, 0.517, '#joyful', '#surprising', 0.715, 'plant', 'flora', 'plant_life', 'rock_plant', 'lithophytic_plant']
senticnet['lithophytic_plant'] = [0.704, -0.925, 0, 0.517, '#joyful', '#surprising', 0.715, 'plant', 'flora', 'plant_life', 'lithophyte', 'rock_plant']
senticnet['litigant'] = [0.071, -0.044, 0, 0, '#joyful', '#surprising', 0.038, 'carpenter', 'vexatious_litigant', 'tape_player', 'copper_wire', 'several_types']
senticnet['litigation'] = [0, 0.255, -0.109, 0.15, '#interesting', '#admirable', 0.099, 'legal_document', 'lawyer', 'court_action', 'see_lawyer', 'lawsuit']
senticnet['litre'] = [0.068, 0, 0.034, 0.076, '#joyful', '#admirable', 0.037, 'gallon', 'liquid_measurement', 'ounce', 'measurement', 'quart']
senticnet['litter'] = [-0.851, 0, 0.683, -0.84, '#sad', '#disgusting', -0.791, 'pack', 'strain', 'biological_group', 'brood', 'animal_group']
senticnet['litterer'] = [-0.564, 0, 0.655, -0.859, '#angry', '#disgusting', -0.693, 'slovenly_woman', 'slut', 'trollop', 'slattern', 'slob']
senticnet['little'] = [-0.99, 0, 0, -0.709, '#sad', '#disgusting', -0.566, 'least', 'a_little', 'small_amount', 'shortage', 'scarce']
senticnet['little_animal'] = [0.911, 0, 0, 0, '#joyful', '#joyful', 0.304, 'small_cat', 'curiosity', 'curious_animal', 'small_animal', 'baby_cat']
senticnet['little_baby'] = [-0.048, 0, 0.029, 0, '#sad', '#angry', -0.026, 'newborn_baby', 'nostalgic', 'baby', 'blind_person', 'youth']
senticnet['little_bite'] = [0.807, 0.763, 0, 0, '#joyful', '#interesting', 0.523, 'broken', 'find_road', 'need_eat_meal', 'small_bite', 'repair']
senticnet['little_boy'] = [-0.127, 0, -0.084, -0.101, '#sad', '#disgusting', -0.104, 'brat', 'youngster', 'youth', 'innocence', 'lad']
senticnet['little_child'] = [0, 0.255, -0.109, 0.15, '#interesting', '#admirable', 0.099, 'young_child', 'kid', 'baby', 'child', 'youngster']
senticnet['little_dense_water'] = [0.1, 0.076, 0, 0.156, '#joyful', '#admirable', 0.111, 'ice_crystal', 'frozen_liquid', 'fragile', 'solid', 'white']
senticnet['little_effort'] = [-0.05, 0, 0.014, -0.039, '#sad', '#disgusting', -0.034, 'take_dump', 'plan_time', 'go_office', 'put_nice_clothes', 'out_bed']
senticnet['little_gem_arborvita'] = [0, -0.009, 0.032, -0.051, '#angry', '#disgusting', -0.025, 'weed', 'shamrock', 'lichen', 'moss', 'most_plants']
senticnet['little_girl'] = [0.738, -0.537, 0, 0.856, '#joyful', '#admirable', 0.71, 'farm_girl', 'flower_girl', 'moppet', 'schoolgirl', 'female']
senticnet['little_grain'] = [0, 0.121, 0.041, 0.12, '#interesting', '#admirable', 0.067, 'yellow_color', 'nutritious', 'cereal_crop', 'small_grain', 'food_grain']
senticnet['little_hair'] = [-0.061, 0, -0.081, -0.062, '#scared', '#disgusting', -0.068, 'cold_head', 'short_hair', 'keep_hair_short', 'hair_become_short', 'new_look']
senticnet['little_horse'] = [0, -0.114, 0.022, 0.06, '#surprising', '#admirable', 0.051, 'donkey', 'small_horse', 'male_cow', 'hoof_animal', 'pony']
senticnet['little_hunger'] = [0.198, 0.15, -0.091, 0, '#joyful', '#interesting', 0.086, 'make_feel_better', 'feel_good', 'good_feeling', 'feel_better', 'peace_mind']
senticnet['little_kid'] = [0.068, 0.069, -0.058, 0.056, '#joyful', '#interesting', 0.045, 'human_offspring', 'young', 'small_adult', 'young_kid', 'small_boy']
senticnet['little_minded'] = [-0.791, 0, 0, -0.953, '#sad', '#disgusting', -0.581, 'idiot', 'douchebag', 'dumb', 'dolt', 'stupid']
senticnet['little_money'] = [-0.813, 0, -0.809, 0, '#sad', '#scared', -0.541, 'run_out_money', 'spend_much_money', 'bankruptcy', 'comparison_shop', 'spend_a_lot_of_money']
senticnet['little_person'] = [0.025, 0.073, -0.052, 0.1, '#interesting', '#admirable', 0.049, 'boy_girl', 'small_kid', 'small_boy', 'young_kid', 'young_people']
senticnet['little_pollution'] = [-0.731, 0, 0, -0.733, '#sad', '#disgusting', -0.488, 'tired_leg', 'traveling_destination', 'get_sweaty', 'sweat_lot', 'polluted']
senticnet['little_potato'] = [-0.699, 0, 0.776, -0.788, '#angry', '#disgusting', -0.754, 'rhizoctinia_disease', 'russet_scab', 'stem_canker', 'rosette', 'plant_disease']
senticnet['little_specific'] = [0.07, 0.151, -0.109, 0.112, '#interesting', '#admirable', 0.075, 'clan', 'happy_together', 'aunt_uncle', 'relative', 'kin']
senticnet['little_terror'] = [-0.967, 0, 0.805, -0.882, '#sad', '#disgusting', -0.885, 'rascal', 'rapscallion', 'scalawag', 'scallywag', 'monkey']
senticnet['little_time'] = [-0.932, 0, 0, -0.902, '#sad', '#disgusting', -0.611, 'late', 'debt', 'deadline', 'stress', 'take_up_time']
senticnet['little_water'] = [0, 0.769, 0, 0.893, '#interesting', '#admirable', 0.554, 'water_drip', 'fallen', 'rain_water', 'water', 'let_go']
senticnet['liturgy'] = [0.762, 0, 0, 0.894, '#joyful', '#admirable', 0.552, 'holy', 'eucharist', 'holy_eucharist', 'holy_sacrament', 'sacrament_of_eucharist']
senticnet['live'] = [0, 0.78, 0, 0.84, '#interesting', '#admirable', 0.54, 'live_city', 'get_oxygen', 'inhabit', 'survive', 'tourism']
senticnet['live_abroad'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'overseas', 'another_country', 'study_abroad', 'elsewhere', 'abroad']
senticnet['live_alone'] = [-0.792, 0, 0, -0.848, '#sad', '#disgusting', -0.547, 'cause_suffer', 'lose_team', 'leave_out', 'disrespect', 'alone']
senticnet['live_animal'] = [0.047, 0.087, 0, 0.08, '#interesting', '#admirable', 0.071, 'social_animal', 'smart_animal', 'omnivore', 'social_creature', 'large_mouse']
senticnet['live_apartment'] = [0.036, 0.138, 0.058, 0.223, '#interesting', '#admirable', 0.113, 'home_sweet_home', 'house', 'rent_room', 'rent_house', 'need_companionship']
senticnet['live_area'] = [0.033, 0.079, 0, 0.177, '#interesting', '#admirable', 0.096, 'live_space', 'live_quarter', 'residence', 'live_place', 'domestic_dwell']
senticnet['live_band'] = [0.752, -0.95, 0, 0, '#joyful', '#surprising', 0.567, 'bluegrass_band', 'string_quartet', 'music_shop', 'country_band', 'high_school_band']
senticnet['live_castle'] = [-0.074, 0, 0, -0.062, '#sad', '#disgusting', -0.045, 'read_book', 'read_magazine', 'read_newspaper', 'read', 'borrow_book']
senticnet['live_city'] = [0.045, 0.078, -0.071, 0.125, '#interesting', '#admirable', 0.059, 'live', 'get_oxygen', 'live_inside', 'reside', 'live_life']
senticnet['live_country'] = [0.172, 0.138, 0, 0.097, '#joyful', '#interesting', 0.136, 'live_good_life', 'healthy_environment', 'native_person', 'live_healthy_life', 'exercise_often']
senticnet['live_creature'] = [0.027, 0.132, -0.06, 0.182, '#interesting', '#admirable', 0.094, 'life_form', 'live_object', 'poisonous_human', 'live_organism', 'alive']
senticnet['live_dangerously'] = [0.054, -0.056, 0, 0, '#joyful', '#surprising', 0.037, 'crash_tree', 'accident', 'fall_butt', 'get_accident', 'hit_tree']
senticnet['live_entity'] = [0, 0.071, 0, 0, '#interesting', '#interesting', 0.024, 'eukaryote', 'human_chest', 'organism', 'system', 'secret_agent']
senticnet['live_environment'] = [0.107, 0.11, -0.084, 0.21, '#interesting', '#admirable', 0.114, 'environment', 'family_live', 'house_yard', 'live_area', 'live_life']
senticnet['live_far_from_home'] = [0, 0, 0, -0.959, '#disgusting', '#disgusting', -0.32, 'immigrant', 'nostalgia', 'long_distance', 'long_distance_relationship', 'miss_parent']
senticnet['live_forever'] = [0.107, 0.11, -0.084, 0.21, '#interesting', '#admirable', 0.114, 'live_healthy_life', 'forever_young', 'elisir', 'live_long', 'live_good_life']
senticnet['live_good_life'] = [0.945, 0.784, 0, 0.847, '#joyful', '#admirable', 0.859, 'eat_fruit', 'accomplish_goal', 'eat_healthy_diet', 'live_country', 'healthy_environment']
senticnet['live_healthy_life'] = [0.906, 0.804, 0, 0.768, '#joyful', '#interesting', 0.826, 'much_energy', 'live_long_healthy_life', 'keep_body_healthy', 'prolong_life', 'strong_body']
senticnet['live_healthy_lifestyle'] = [0.062, 0.097, -0.094, 0.11, '#interesting', '#admirable', 0.058, 'live_long', 'long_life', 'live_long_life', 'out_shape', 'like_exercise']
senticnet['live_house'] = [-0.041, 0.121, -0.073, 0.104, '#interesting', '#admirable', 0.037, 'hot_summer', 'learn_love_another', 'return_home', 'eat_potato', 'crowd_elevator']
senticnet['live_human'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'video_recorder', 'terrier', 'vertebrate', 'elf', 'ice_skater']
senticnet['live_in_mountains'] = [-0.81, 0, -0.901, 0, '#sad', '#scared', -0.57, 'lonely', 'feel_lonely', 'entire', 'body_type', 'alone']
senticnet['live_inside'] = [0.045, 0.078, -0.071, 0.125, '#interesting', '#admirable', 0.059, 'live', 'get_oxygen', 'live_city', 'reside', 'live_life']
senticnet['live_life'] = [0.778, 0, 0, 0.896, '#joyful', '#admirable', 0.558, 'love_else', 'love_another', 'know_re_healthy', 'start_family', 'cause_cold']
senticnet['live_long'] = [0.879, 0.884, 0, 0.979, '#interesting', '#admirable', 0.914, 'live_healthy_lifestyle', 'long_life', 'live_long_life', 'become_strong', 'stay_shape']
senticnet['live_long_happy_life'] = [0.849, 0.79, 0, 0.793, '#joyful', '#admirable', 0.811, 'live_ripe_old_age', 'live_well', 'live_long_healthy_life', 'long_lifespan', 'complement']
senticnet['live_long_healthy_life'] = [0.984, 0.963, 0, 0.878, '#joyful', '#interesting', 0.942, 'live_ripe_old_age', 'live_well', 'long_lifespan', 'live_healthy_life', 'strong_body']
senticnet['live_long_life'] = [0.896, 0.837, 0, 0.825, '#joyful', '#interesting', 0.853, 'live_long', 'long_life', 'live_healthy_lifestyle', 'out_shape', 'live_long_time']
senticnet['live_long_time'] = [0.863, 0.875, 0, 0.935, '#interesting', '#admirable', 0.891, 'live_healthy_lifestyle', 'eat_healthy', 'live_long', 'live_long_life', 'take_vitamin']
senticnet['live_meat'] = [0, -0.013, 0.038, -0.118, '#angry', '#disgusting', -0.048, 'flesh', 'bone', 'skeletal_system', 'muscle', 'shiny_coat']
senticnet['live_object'] = [0.047, 0.149, -0.069, 0.131, '#interesting', '#admirable', 0.086, 'live_organism', 'alive', 'poisonous_human', 'fauna', 'biological_machine']
senticnet['live_ocean'] = [0.907, 0, 0, 0.72, '#joyful', '#admirable', 0.542, 'breaunderwater', 'ocean', 'travel_fast_light', 'like_play', 'drink_sea_water']
senticnet['live_old'] = [-0.045, 0.118, -0.069, 0.102, '#interesting', '#admirable', 0.035, 'a_lot_of_practice', 'race_hare', 'air_tank', 'hide_shell', 'grasp']
senticnet['live_organism'] = [0.03, 0.078, 0, 0.101, '#interesting', '#admirable', 0.07, 'flora', 'live_object', 'species', 'fauna', 'honey_insect']
senticnet['live_peace'] = [0.601, 0.768, 0, 0.941, '#interesting', '#admirable', 0.77, 'fight', 'disagreement', 'argument', 'better_world', 'extreme_fear']
senticnet['live_place'] = [0, 0.082, 0, 0.138, '#interesting', '#admirable', 0.073, 'domestic_dwell', 'dwell_place', 'place_to_live', 'live_quarter', 'place_where_people_live']
senticnet['live_quarter'] = [0.023, 0.074, 0, 0.139, '#interesting', '#admirable', 0.079, 'domestic_dwell', 'live_space', 'live_place', 'dwell_place', 'live_area']
senticnet['live_ripe_old_age'] = [0.981, 0.955, 0, 0.709, '#joyful', '#interesting', 0.882, 'live_long_healthy_life', 'complement', 'live_well', 'long_lifespan', 'strong_body']
senticnet['live_room'] = [-0.067, 0, -0.07, -0.036, '#sad', '#scared', -0.058, 'seat_many_person', 'living_room', 'hotel_room', 'furniture_store', 'loft']
senticnet['live_simply'] = [0.747, 0.856, 0, 0.798, '#interesting', '#admirable', 0.8, 'go_town', 'count_money', 'backup', 'book_hotel_room', 'pay_fee']
senticnet['live_space'] = [0, 0.08, 0, 0.151, '#interesting', '#admirable', 0.077, 'live_quarter', 'live_place', 'live_area', 'domestic_dwell', 'dwell_place']
senticnet['live_underground'] = [0, 0, 0, -0.758, '#disgusting', '#disgusting', -0.253, 'jump_over_fence', 'many_different_colors', 'tame', 'eat_rat', 'growl']
senticnet['live_up_to'] = [0.783, 0.595, -0.209, 0.34, '#joyful', '#interesting', 0.503, 'fulfill', 'fulfillment', 'gloating', 'gloatingly', 'complacency']
senticnet['live_water'] = [0.05, 0, 0.036, 0.103, '#joyful', '#admirable', 0.039, 'swim', 'save_someone_from_drowning', 'hold_fish', 'live_old', 'kayak']
senticnet['live_well'] = [0.289, 0.179, -0.091, 0.276, '#joyful', '#admirable', 0.218, 'live_long_healthy_life', 'live_ripe_old_age', 'live_long_happy_life', 'long_lifespan', 'live_healthy_life']
senticnet['live_wire'] = [0.78, -0.965, 0, 0.636, '#joyful', '#surprising', 0.794, 'goffer', 'gopher', 'actor', 'doer', 'worker']
senticnet['live_with'] = [-0.612, 0, 0.648, -0.904, '#angry', '#disgusting', -0.721, 'endure', 'brook', 'tolerate', 'stomach', 'abide']
senticnet['liveliness'] = [0.586, -0.519, 0, 0.949, '#joyful', '#admirable', 0.685, 'chirpiness', 'spirit', 'sprightliness', 'brio', 'activity']
senticnet['livelong'] = [-0.592, 0, 0.942, -0.758, '#angry', '#disgusting', -0.764, 'sedum', 'herb', 'stonecrop', 'orpine', 'orpin']
senticnet['lively'] = [0.65, -0.614, 0, 0.711, '#joyful', '#admirable', 0.658, 'bouncing', 'scintillating', 'spirited', 'peppy', 'zippy']
senticnet['liven'] = [0.827, -0.556, 0, 0.679, '#joyful', '#admirable', 0.687, 'spirit', 'spirit_up', 'inspirit', 'energize', 'jazz_up']
senticnet['liven_up'] = [0.729, -0.676, 0, 0.821, '#joyful', '#admirable', 0.742, 'spirit', 'spirit_up', 'inspirit', 'energize', 'jazz_up']
senticnet['liver'] = [0, 0, 0, -0.081, '#disgusting', '#disgusting', -0.027, 'bowel', 'scrotum', 'shoulder', 'anus', 'waist']
senticnet['liver_cancer'] = [0.592, -0.738, 0, 0.677, '#surprising', '#admirable', 0.669, 'disease', 'fatty_liver', 'hepatitis', 'liver_disease', 'cancer_of_liver']
senticnet['liver_disease'] = [0.592, -0.738, 0, 0.677, '#surprising', '#admirable', 0.669, 'disease', 'fatty_liver', 'hepatitis', 'liver_cancer', 'cancer_of_liver']
senticnet['liver_fluke'] = [0.688, -0.942, 0, 0.925, '#surprising', '#admirable', 0.852, 'flatworm', 'platyhelminth', 'trematode', 'schistosome', 'blood_fluke']
senticnet['liver_spot'] = [-0.662, 0, 0.911, -0.993, '#angry', '#disgusting', -0.855, 'macule', 'spot', 'freckle', 'lentigo', 'plague_spot']
senticnet['livid'] = [-0.115, 0.115, 0.67, -0.658, '#angry', '#disgusting', -0.443, 'lividity', 'lividly', 'wrathfully', 'wrothful', 'wroth']
senticnet['lividity'] = [-0.115, 0.115, 0.67, -0.658, '#angry', '#disgusting', -0.443, 'lividly', 'livid', 'wrathfully', 'wrothful', 'wroth']
senticnet['lividly'] = [-0.115, 0.115, 0.67, -0.658, '#angry', '#disgusting', -0.443, 'lividity', 'livid', 'wrathfully', 'wrothful', 'wroth']
senticnet['lividness'] = [-0.665, 0, 0.782, -0.529, '#sad', '#angry', -0.659, 'complexion', 'pallidness', 'pallor', 'wanness', 'achromasia']
senticnet['living_dead'] = [-0.793, 0, 0.885, -0.768, '#sad', '#angry', -0.815, 'infernal', 'mortal', 'zombi', 'zombie', 'dead_soul']
senticnet['living_room'] = [-0.067, 0, -0.07, -0.036, '#sad', '#scared', -0.058, 'live_room', 'seat_many_person', 'hotel_room', 'furniture_store', 'loft']
senticnet['living_thing'] = [0.902, 0.772, 0, 0, '#joyful', '#interesting', 0.558, 'body', 'two_ears', 'dog_pet', 'abdomen', 'fur']
senticnet['living_wage'] = [-0.683, 0, 0.688, -0.877, '#angry', '#disgusting', -0.749, 'pay', 'wage', 'earnings', 'remuneration', 'salary']
senticnet['lizard'] = [-0.028, -0.008, -0.052, -0.08, '#scared', '#disgusting', -0.051, 'red-bellied_black_snake', 'poisonous_snake', 'eastern_brown_snake', 'snake', 'shark']
senticnet['llama'] = [-0.535, 0, 0.751, -0.971, '#angry', '#disgusting', -0.752, 'guanaco', 'domestic_llama', 'alpaca', 'artiodactyl', 'artiodactyl_mammal']
senticnet['load'] = [0.044, 0, 0, 0.144, '#joyful', '#admirable', 0.063, 'keep_fresh', 'circular_motion', 'spread', 'creamy', 'round_bread']
senticnet['load_bear'] = [0.154, 0.254, -0.114, 0.316, '#interesting', '#admirable', 0.203, 'support_wall', 'build_support', 'vertical', 'support_roof', 'build_house']
senticnet['load_dock'] = [0, 0.103, 0, 0, '#interesting', '#interesting', 0.034, 'room_temperature', 'car_race', 'sea_level', 'smithsonian', 'auction']
senticnet['load_gun'] = [-0.079, -0.042, -0.054, -0.148, '#sad', '#disgusting', -0.08, 'shoot', 'shoot_gun', 'fire_gun', 'fire_weapon', 'lethal']
senticnet['loaded'] = [0.779, -0.821, 0, 0.66, '#joyful', '#surprising', 0.753, 'homophobic', 'discriminatory', 'racist', 'jaundiced', 'antiblack']
senticnet['loaf'] = [0.028, -0.084, 0.039, 0.055, '#surprising', '#admirable', 0.043, 'food_bake', 'bun', 'bagel', 'toast', 'muffin']
senticnet['loaf_bread'] = [0.026, 0, 0, 0.073, '#joyful', '#admirable', 0.033, 'coupon', 'bottle_water', 'plastic_container', 'carton_milk', 'hand_print']
senticnet['loafer'] = [0.021, -0.043, 0.107, -0.08, '#angry', '#disgusting', -0.041, 'shoe', 'moccasin', 'flip_flop', 'cowboy_boot', 'slipper']
senticnet['loan'] = [-0.052, 0.264, -0.077, 0.147, '#interesting', '#admirable', 0.094, 'wealth', 'extra_money', 'check_account', 'check', 'savings']
senticnet['loathe'] = [0, 0, 0, -0.717, '#disgusting', '#disgusting', -0.239, 'despise', 'disgust', 'animosity', 'brood', 'maleficence']
senticnet['loather'] = [-0.559, 0, 0.689, -0.806, '#angry', '#disgusting', -0.685, 'abominator', 'hater', 'mortal', 'anglophobe', 'person']
senticnet['loathing'] = [0, 0, 0, -1, '#disgusting', '#disgusting', -0.333, 'abhorrence', 'abomination', 'detestation', 'execration', 'odium']
senticnet['loathly'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['loathsome'] = [-0.075, 0.142, 0.685, -0.668, '#angry', '#disgusting', -0.429, 'churn_up', 'gross_out', 'sicken', 'nauseate', 'repel']
senticnet['lobby'] = [0.039, -0.033, 0, 0, '#joyful', '#surprising', 0.024, 'first_floor', 'basement', 'foyer', 'hallway', 'lower_floor']
senticnet['lobster'] = [0.061, 0.07, -0.056, 0.073, '#interesting', '#admirable', 0.049, 'italian_food', 'eat_food', 'fine_dining', 'caviar', 'expensive_food']
senticnet['local'] = [0.123, 0.19, -0.112, 0.183, '#interesting', '#admirable', 0.128, 'local_food', 'zone', 'headquarters', 'from_here', 'urban']
senticnet['local_anesthesia'] = [-0.651, 0, 0.824, -0.869, '#angry', '#disgusting', -0.781, 'put_to_sleep', 'operation', 'general_anesthesia', 'surgery', 'anesthesia']
senticnet['local_food'] = [0.123, 0.19, -0.112, 0.183, '#interesting', '#admirable', 0.128, 'local', 'zone', 'headquarters', 'from_here', 'urban']
senticnet['locate'] = [-0.082, 0.107, -0.05, 0.185, '#interesting', '#admirable', 0.053, 'search', 'seek_out', 'seek', 'reveal', 'concede']
senticnet['locate_information'] = [0.878, 0.723, 0, 0.952, '#joyful', '#admirable', 0.851, 'learn_new', 'seek_info', 'learn_world', 'look_for_information', 'learn_interest']
senticnet['locate_out'] = [-0.082, 0.107, -0.05, 0.185, '#interesting', '#admirable', 0.053, 'search', 'seek', 'locate', 'reveal', 'concede']
senticnet['locate_place'] = [-0.819, 0, 0, -0.91, '#sad', '#disgusting', -0.576, 'pull_off_road', 'carry_luggage', 'get_bus', 'get_plane', 'pack_luggage']
senticnet['location'] = [0.045, 0.136, 0, 0.214, '#interesting', '#admirable', 0.132, 'place', 'address', 'area', 'big_place', 'position']
senticnet['lock'] = [0, 0.069, 0, 0.083, '#interesting', '#admirable', 0.051, 'latch', 'restrict_access', 'knob', 'door_knob', 'gate']
senticnet['lock_box'] = [0, 0.207, -0.052, 0.085, '#interesting', '#admirable', 0.08, 'secure', 'bank_money', 'hold_change', 'vault', 'bank_account']
senticnet['lock_cabinet'] = [-0.061, -0.007, -0.071, -0.187, '#scared', '#disgusting', -0.104, 'gun_store', 'holster', 'arsenal', 'gun_shop', 'war']
senticnet['lock_door'] = [-0.717, 0, 0, -0.981, '#sad', '#disgusting', -0.566, 'dress_occasion', 'leave_house', 'lock_front_door', 'turn_car_off', 'dress_up']
senticnet['lock_front_door'] = [-0.04, -0.036, 0.045, -0.07, '#angry', '#disgusting', -0.04, 'dress_occasion', 'put_clothes', 'try_clothes_before_buy', 'try_new_clothes', 'change_clothes']
senticnet['lock_in'] = [-0.914, 0, 0.576, -0.956, '#sad', '#disgusting', -0.815, 'stop', 'halt', 'cease', 'lock', 'block']
senticnet['lock_up'] = [-0.031, 0, -0.064, -0.053, '#scared', '#disgusting', -0.049, 'drive_car', 'move_car', 'fly_plane', 'take_car_drive', 'go_drive']
senticnet['locker'] = [0, 0.072, 0, 0, '#interesting', '#interesting', 0.024, 'metal_box', 'cash_drawer', 'keyhole', 'clutch_bag', 'case']
senticnet['locker_room'] = [0.868, 0.85, 0, 0, '#joyful', '#interesting', 0.573, 'shoe_store', 'chess_tournament', 'dress_room', 'front_desk', 'prison_cell']
senticnet['locksmith'] = [0, 0.115, 0, 0.105, '#interesting', '#admirable', 0.073, 'farrier', 'miner', 'horseshoer', 'blacksmith', 'smith']
senticnet['lockup'] = [0.816, -0.913, 0, 0.944, '#surprising', '#admirable', 0.891, 'jail', 'jailhouse', 'gaol', 'poky', 'clink']
senticnet['locomotion'] = [0, 0, 0, 0.19, '#admirable', '#admirable', 0.063, 'personal_transport', 'get_around', 'get_somewhere_fast', 'change_location', 'movement']
senticnet['locomotive'] = [0.069, 0.097, 0, 0.172, '#interesting', '#admirable', 0.113, 'type_of_engine', 'liquid_gas', 'warm_air', 'hot_air', 'steamy']
senticnet['locust_tree'] = [-0.856, 0, 0.5, -0.709, '#sad', '#disgusting', -0.688, 'courbaril', 'water_locust', 'swamp_locust', 'honey_locust', 'black_locust']
senticnet['lode'] = [0.614, -0.956, 0, 0.584, '#joyful', '#surprising', 0.718, 'mother_lode', 'champion_lode', 'deposit', 'sedimentation', 'alluviation']
senticnet['lodge'] = [0.058, 0.075, 0, 0.09, '#interesting', '#admirable', 0.074, 'refuge', 'temporary_home', 'shelter', 'mom_house', 'hut']
senticnet['lodging'] = [-0.819, 0, 0.921, -0.803, '#sad', '#angry', -0.848, 'immovability', 'unchanging', 'lodgment', 'permanent', 'fixity']
senticnet['lodgings'] = [0.053, 0.1, 0, 0, '#joyful', '#interesting', 0.051, 'registry_office', 'board_room', 'telephone_booth', 'cubicle', 'reception_area']
senticnet['lodgment'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'grievance', 'accusation', 'plaint', 'allegation', 'accuse']
senticnet['loft'] = [-0.067, 0, -0.07, -0.036, '#sad', '#scared', -0.058, 'live_room', 'living_room', 'hotel_room', 'furniture_store', 'seat_many_person']
senticnet['loftiness'] = [-0.539, 0, 0.993, -0.886, '#angry', '#disgusting', -0.806, 'expansiveness', 'expansivity', 'stateliness', 'impressiveness', 'excellence']
senticnet['lofty'] = [0.964, 0.975, 0, 0, '#joyful', '#interesting', 0.646, 'sublime', 'exalted', 'elevated', 'high-flown', 'grand']
senticnet['log_cabin'] = [0.021, 0, -0.044, -0.06, '#scared', '#disgusting', -0.028, 'igloo', 'chess_tournament', 'another_planet', 'death_row', 'loose_end']
senticnet['log_off'] = [0, 0, 0, 0.911, '#admirable', '#admirable', 0.304, 'find_computer', 'visit_zoo', 'start_computer', 'switch_computer', 'build_computer']
senticnet['log_z'] = [-0.951, 0, 0.788, -0.691, '#sad', '#angry', -0.81, 'catnap', 'sleep_late', 'sleep_in', 'rest', 'practice_bundling']
senticnet['loggerhead'] = [-0.95, 0, 0.698, -0.684, '#sad', '#angry', -0.777, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['logginess'] = [-0.732, 0, 0.596, -0.773, '#sad', '#disgusting', -0.7, 'exhaustion', 'loss_of_strength', 'weariness', 'eyestrain', 'asthenopia']
senticnet['logic'] = [-0.08, 0.25, -0.059, 0.141, '#interesting', '#admirable', 0.084, 'put_two_together', 'think_process', 'analysis', 'brain_function', 'make_right_decision']
senticnet['logical'] = [-0.027, 0.276, -0.063, 0.169, '#interesting', '#admirable', 0.118, 'mathematic', 'test_hypothesis', 'conjecture', 'subject', 'hypothetical']
senticnet['logical_argument'] = [0.715, -0.829, 0, 0.659, '#joyful', '#surprising', 0.734, 'reasoning', 'logical_thinking', 'abstract_thought', 'casuistry', 'line_of_inquiry']
senticnet['logical_fallacy'] = [0.623, -0.532, 0, 0.873, '#joyful', '#admirable', 0.676, 'petitio_principii', 'petitio', 'hysteron_proteron', 'fallacy', 'false_belief']
senticnet['logical_system'] = [0.629, -0.792, 0, 0.758, '#surprising', '#admirable', 0.726, 'system_of_rules', 'symbolic_logic', 'mathematical_logic', 'formal_logic', 'system']
senticnet['logical_thinking'] = [0.651, -0.631, 0, 0.589, '#joyful', '#surprising', 0.624, 'ratiocination', 'logical_argument', 'line_of_reasoning', 'thinking', 'thought']
senticnet['logicality'] = [0.539, -0.771, 0, 0.657, '#surprising', '#admirable', 0.656, 'rationality', 'quality', 'rationalness', 'completeness', 'consistency']
senticnet['logicalness'] = [0.771, -0.6, 0, 0.596, '#joyful', '#surprising', 0.656, 'rationality', 'quality', 'rationalness', 'completeness', 'consistency']
senticnet['logjam'] = [0.829, -0.952, 0, 0.948, '#surprising', '#admirable', 0.91, 'check', 'arrest', 'hitch', 'halt', 'stay']
senticnet['logo'] = [0, 0.868, 0, 0.775, '#interesting', '#admirable', 0.548, 'business_man', 'artwork', 'peace_sign', 'horseback_rider', 'captive']
senticnet['logogram'] = [-0.61, 0, 0.721, -0.683, '#angry', '#disgusting', -0.671, 'character', 'ideogram', 'logograph', 'graph', 'grapheme']
senticnet['logograph'] = [-0.61, 0, 0.721, -0.683, '#angry', '#disgusting', -0.671, 'character', 'logogram', 'ideogram', 'graph', 'grapheme']
senticnet['logomania'] = [-0.898, 0, 0.987, -0.904, '#angry', '#disgusting', -0.93, 'logorrhea', 'cacoethes', 'agromania', 'pyromania', 'necrophilia']
senticnet['logorrhea'] = [-0.898, 0, 0.987, -0.904, '#angry', '#disgusting', -0.93, 'cacoethes', 'logomania', 'agromania', 'pyromania', 'necrophilia']
senticnet['logorrheic'] = [0.94, -0.771, 0, 0, '#joyful', '#surprising', 0.57, 'lovely_music', 'play_instrument', 'dork', 'entertain_other_person', 'learn_play']
senticnet['logy'] = [-0.567, 0, 0.577, -0.619, '#angry', '#disgusting', -0.588, 'foggy', 'groggy', 'lethargic', 'stuporous', 'dazed']
senticnet['lol'] = [0.236, 0, -0.051, 0.149, '#joyful', '#admirable', 0.111, 'guffaw', 'human_noise', 'human_sound', 'funny', 'vocalization']
senticnet['loll'] = [0, 0, -0.943, -0.781, '#scared', '#disgusting', -0.575, 'bum', 'bum_about', 'arse_around', 'droop', 'bum_around']
senticnet['lollipop'] = [0.023, 0.141, -0.131, 0.174, '#interesting', '#admirable', 0.069, 'candy', 'push_wind', 'exhalation', 'breaout', 'mouth_action']
senticnet['london'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'newyork', 'big_city', 'beijing', 'rome', 'tokyo']
senticnet['loneliness'] = [-0.779, 0, 0, -0.784, '#sad', '#disgusting', -0.521, 'unhappiness', 'melancholy', 'shame', 'unhappy', 'sad']
senticnet['lonely'] = [-0.048, 0, -0.127, -0.034, '#sad', '#scared', -0.07, 'live_in_mountains', 'amiable', 'feel_lonely', 'get_laid', 'outgo_personality']
senticnet['lonely_person'] = [-0.741, 0, -0.782, 0, '#sad', '#scared', -0.508, 'workaholic', 'dog_wag_tail', 'shed_tear', 'laugh', 'friendly_fire']
senticnet['loner'] = [-0.703, 0, -0.977, 0, '#sad', '#scared', -0.56, 'significance', 'oneself', 'alone', 'membership', 'number_person']
senticnet['long'] = [0, 0.065, 0.039, 0.142, '#interesting', '#admirable', 0.056, 'length', 'unit_of_measurement', 'length_measurement', 'tall', 'big']
senticnet['long_ago'] = [-0.03, 0.106, -0.056, 0.08, '#interesting', '#admirable', 0.033, 'history', 'past_event', 'school_topic', 'school_subject', 'subject']
senticnet['long_arm'] = [-0.063, -0.031, 0.015, -0.055, '#sad', '#disgusting', -0.034, 'suspend', 'noose', 'hang', 'antenna', 'long_neck']
senticnet['long_beard'] = [0.036, 0, 0.094, -0.055, '#angry', '#disgusting', -0.038, 'unaesthetic', 'need_shave', 'need_beauty_center', 'facial_hair', 'carelessness']
senticnet['long_car'] = [0, -0.019, 0.014, 0.071, '#surprising', '#admirable', 0.025, 'machine_transportation', 'big_car', 'car_truck', 'form_of_public_transportation', 'large_car']
senticnet['long_distance'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'long_distance_relationship', 'distant', 'kilometer', 'length_measurement', 'distance_measure']
senticnet['long_distance_relationship'] = [-0.853, 0, 0, -0.734, '#sad', '#disgusting', -0.529, 'long_distance', 'compass_direction', 'distance', 'away', 'afar']
senticnet['long_focus'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'slow', 'bad_camera', 'focus_time', 'bad_camera_time', 'low_quality_photo']
senticnet['long_focus_time'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'slow', 'long_focus', 'focus_time', 'bad_camera', 'cheap_camera']
senticnet['long_for_relax'] = [0, 0.915, 0, 0, '#interesting', '#interesting', 0.305, 'desire_social_interaction', 'lose_track_time', 'eye_strain', 'extreme_boredom', 'boredom']
senticnet['long_haired_man'] = [0.051, -0.042, 0.016, 0, '#joyful', '#surprising', 0.026, 'man', 'workman', 'hippie', 'compatriot', 'polite_person']
senticnet['long_happy_life'] = [0.888, 0.801, 0, 0.76, '#joyful', '#interesting', 0.816, 'healthy_environment', 'live_long_time', 'live_healthy_lifestyle', 'eat_healthy', 'long_life']
senticnet['long_island'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'sailboat', 'boat', 'rowboat', 'big_boat', 'ship']
senticnet['long_last'] = [0, 0.954, 0, 0.796, '#interesting', '#admirable', 0.583, 'stand_still', 'roll_over', 'stretch_out', 'weather_storm', 'near_destination']
senticnet['long_life'] = [0.824, 0.707, 0, 0, '#joyful', '#interesting', 0.51, 'live_long', 'live_long_life', 'live_healthy_lifestyle', 'longevity', 'healthy']
senticnet['long_lifespan'] = [0.947, 0.919, 0, 0.927, '#joyful', '#admirable', 0.931, 'live_long_healthy_life', 'live_ripe_old_age', 'live_well', 'live_long_happy_life', 'nice_place_to_live']
senticnet['long_line'] = [-0.122, 0.193, 0.597, -0.627, '#angry', '#disgusting', -0.384, 'wait', 'wait_service', 'conformist_attitude', 'carve_niche', 'find_end_line']
senticnet['long_live'] = [0.891, 0.885, 0, 0.956, '#joyful', '#admirable', 0.911, 'live_ripe_old_age', 'live_healthy_life', 'live_long_healthy_life', 'strong_body', 'long_lifespan']
senticnet['long_narrow'] = [0, 0.084, 0.023, 0.167, '#interesting', '#admirable', 0.076, 'empty_place', 'inside_build', 'entrance_room', 'build_part', 'small_room']
senticnet['long_neck'] = [-0.063, -0.031, 0.015, -0.055, '#sad', '#disgusting', -0.034, 'suspend', 'long_arm', 'hang', 'antenna', 'noose']
senticnet['long_queue'] = [-0.054, 0, 0, -0.092, '#sad', '#disgusting', -0.049, 'go_post_office', 'waiting_time', 'queue', 'waste_time', 'stress']
senticnet['long_road'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'suspension_bridge', 'under_bridge', 'roadway', 'county_highway', 'bridge']
senticnet['long_stick'] = [0.058, -0.153, 0.047, 0.11, '#surprising', '#admirable', 0.091, 'twig', 'tree_arm', 'tree_limb', 'tree_part', 'part_of_tree']
senticnet['long_story'] = [0.1, 0.085, 0, 0.093, '#joyful', '#admirable', 0.093, 'narrative', 'bedtime', 'fable', 'bed_time', 'saga']
senticnet['long_suit'] = [0.553, -0.8, 0, 0.908, '#surprising', '#admirable', 0.754, 'strong_suit', 'collection', 'aggregation', 'accumulation', 'assemblage']
senticnet['long_tail'] = [0, -0.01, 0.041, -0.065, '#angry', '#disgusting', -0.032, 'claws', 'paw', 'animal_part', 'sharp_tooth', 'fang']
senticnet['long_term'] = [0.927, 0, 0, 0, '#joyful', '#joyful', 0.309, 'thought', 'brain_function', 'new_think', 'polarize', 'thoughtfulness']
senticnet['long_thin'] = [0, 0.891, 0, 0.985, '#interesting', '#admirable', 0.625, 'piece_of_wood', 'walk_upon', 'stand_upon', 'stand', 'wood_board']
senticnet['long_tooth'] = [0, -0.01, 0.041, -0.065, '#angry', '#disgusting', -0.032, 'big_tooth', 'fang', 'tail', 'sharp_tooth', 'animal_part']
senticnet['long_travel'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'long_distance', 'far_from', 'further', 'far', 'isolated']
senticnet['long_trip'] = [-0.996, 0, 0.986, -0.945, '#sad', '#angry', -0.976, 'travel', 'bad_rest', 'feel_sleepy', 'tired', 'jet_lag']
senticnet['long_tube'] = [0.971, 0, 0, 0.922, '#joyful', '#admirable', 0.631, 'drinking_place', 'metal_stick', 'sell_beer', 'drunkard', 'ale']
senticnet['long_version'] = [0, 0.067, 0, 0.11, '#interesting', '#admirable', 0.059, 'location', 'house_location', 'address', 'surround', 'vicinity']
senticnet['long_waiting_time'] = [-0.983, 0, 0.058, -0.921, '#sad', '#disgusting', -0.654, 'bad_staff', 'cheap_hotel', 'cheap_restaurant', 'unfriendly_staff', 'bad_service']
senticnet['long_wood'] = [0, -0.069, 0.046, 0.09, '#surprising', '#admirable', 0.038, 'piece_of_wood', 'dog', 'adhere', 'dog_fetch', 'fetch']
senticnet['longanimity'] = [0.543, -0.678, 0, 0.553, '#surprising', '#admirable', 0.591, 'good_nature', 'patience', 'good_will', 'forbearance', 'grace']
senticnet['longevity'] = [0.097, 0.099, -0.098, 0.137, '#interesting', '#admirable', 0.078, 'live_long', 'long_life', 'live_healthy_lifestyle', 'increase_muscle_mass', 'feel_healthy']
senticnet['longhand'] = [-0.698, 0, 0.635, -0.935, '#sad', '#disgusting', -0.756, 'copperplate', 'hand', 'minuscule', 'italic', 'round_hand']
senticnet['longing'] = [0.938, -0.552, 0, 0.7, '#joyful', '#admirable', 0.73, 'dissatisfaction', 'disgruntlement', 'dysphoria', 'discontent', 'yearning']
senticnet['longleaf_pine'] = [-0.698, 0, 0.725, -0.89, '#angry', '#disgusting', -0.771, 'ponderosa', 'ponderosa_pine', 'western_yellow_pine', 'bull_pine', 'yellow_pine']
senticnet['longsighted'] = [0.545, -0.599, 0, 0.865, '#surprising', '#admirable', 0.67, 'farseeing', 'farsighted', 'telescopic', 'hyperopic', 'hypermetropic']
senticnet['longsightedness'] = [0.7, -0.628, 0, 0.58, '#joyful', '#surprising', 0.636, 'see_far', 'hyperopia', 'hypermetropia', 'hypermetropy', 'farsightedness']
senticnet['look'] = [-0.043, 0.11, 0, 0.116, '#interesting', '#admirable', 0.061, 'stare', 'glimpse', 'use_eye', 'observe', 'ship_part']
senticnet['look_after'] = [0, 0.775, 0, 0.839, '#interesting', '#admirable', 0.538, 'type_of_bear', 'care', 'kindness', 'watch_over', 'precaution']
senticnet['look_ahead'] = [0, 0, 0, -0.122, '#disgusting', '#disgusting', -0.041, 'native_person', 'futurism', 'republic', 'revolution', 'revolutionary']
senticnet['look_alike'] = [0, 0, 0, -0.847, '#disgusting', '#disgusting', -0.282, 'hairy_leg', 'low_self-esteem', 'damage_car', 'broken_car', 'remove_hair']
senticnet['look_around'] = [0, 0.788, 0, 0.787, '#interesting', '#admirable', 0.525, 'book_flight', 'book_hotel_room', 'board_boat', 'decide_to_go_first', 'go_town']
senticnet['look_art'] = [-0.137, -0.016, 0, -0.135, '#sad', '#disgusting', -0.085, 'see_picture', 'become_enlighten', 'time_consume', 'turn_page', 'use_telescope']
senticnet['look_at'] = [0.777, -0.852, 0, 0.615, '#joyful', '#surprising', 0.748, 'think_about', 'play', 'trifle', 'abstract', 'warm_to']
senticnet['look_at_fearfully'] = [-0.932, 0, 0.096, -0.929, '#sad', '#disgusting', -0.652, 'fear', 'staring', 'afraid_of', 'threat', 'dangerous']
senticnet['look_attractive'] = [0.153, 0.102, -0.075, 0.158, '#joyful', '#admirable', 0.113, 'much_energy', 'think_clearly', 'feel_better_oneself', 'improve_self-image', 'own_benefit']
senticnet['look_away'] = [-0.093, 0, 0.177, -0.232, '#angry', '#disgusting', -0.167, 'verdict', 'give_verdict', 'call_lawyer', 'go_court', 'make_judgment']
senticnet['look_bad'] = [-0.914, 0, 0.879, -0.727, '#sad', '#angry', -0.84, 'clean', 'personal_cleanliness', 'wipe_up_spill', 'expect_guest', 'clean_floor']
senticnet['look_beautiful'] = [0.844, 0.742, 0, 0.844, '#joyful', '#admirable', 0.81, 'self_confidence', 'big_paycheck', 'consistency', 'slogan', 'love_parent']
senticnet['look_behind'] = [-0.101, 0, 0, 0, '#sad', '#sad', -0.034, 'read_cover', 'spread_out', 'upgrade', 'deflate', 'scan']
senticnet['look_best'] = [0.223, 0.129, -0.144, 0.176, '#joyful', '#admirable', 0.128, 'improve_look', 'increase_self-confidence', 'look_good', 'look_attractive', 'feel_better_oneself']
senticnet['look_better'] = [0.028, -0.015, 0, 0.087, '#joyful', '#admirable', 0.043, 'improve_image', 'dress_nice', 'get_latest_hairstyle', 'change_appearance', 'groom']
senticnet['look_buy'] = [-0.03, -0.046, 0.07, -0.115, '#angry', '#disgusting', -0.056, 'buy', 'check_price', 'acquire_goods', 'make_purchase', 'get_need']
senticnet['look_carefully'] = [-0.09, 0, 0, 0, '#sad', '#sad', -0.03, 'watch_carefully', 'watch_out', 'observe', 'look', 'stare']
senticnet['look_catalog'] = [0.065, 0.073, 0, 0, '#joyful', '#interesting', 0.046, 'head_start', 'make_selection', 'good_credit', 'find_out_want', 'save_money']
senticnet['look_clock'] = [0.723, 0.964, 0, 0, '#joyful', '#interesting', 0.562, 'chew_pencil', 'get_nervous', 'make_mistake', 'move_pawn', 'plan_ahead']
senticnet['look_closely'] = [0, 0.943, 0, 0.811, '#interesting', '#admirable', 0.585, 'understand_idea', 'help_another_person', 'deflate', 'upgrade', 'try_understand']
senticnet['look_clue'] = [0, 0.937, 0, 0.884, '#interesting', '#admirable', 0.607, 'think_past', 'figure_out', 'consider_option', 'gather_fact', 'resolve_problem']
senticnet['look_cool'] = [0, 0.15, 0, 0.095, '#interesting', '#admirable', 0.082, 'feel_faint', 'exercise_much', 'exercise_regularly', 'need_new_clothes', 'moderation']
senticnet['look_detail'] = [0, -0.092, 0, 0.08, '#surprising', '#admirable', 0.057, 'examine', 'analyze', 'observe', 'determine_truth', 'find_truth']
senticnet['look_different'] = [0, -0.747, 0, 0.908, '#surprising', '#admirable', 0.552, 'increase_self-confidence', 'little_hair', 'improve_look', 'look_good', 'look_neat']
senticnet['look_down'] = [0, 0, 0, -0.979, '#disgusting', '#disgusting', -0.326, 'reach_high_shelf', 'fall', 'take_photo', 'break_neck', 'step_up']
senticnet['look_down_on'] = [-0.026, 0, 0, -0.067, '#sad', '#disgusting', -0.031, 'snobby', 'snooty', 'snob', 'french', 'full_of_shit']
senticnet['look_evidence'] = [0, 0.737, 0, 0.967, '#interesting', '#admirable', 0.568, 'sit_jury', 'consider_fact', 'come_decision', 'find_out_fact', 'examine_evidence']
senticnet['look_eye'] = [-0.083, 0, -0.102, -0.079, '#sad', '#scared', -0.088, 'make_eye_contact', 'move_tongue', 'dry_mouth', 'share_feeling', 'misunderstand']
senticnet['look_fact'] = [-0.253, 0, -0.171, 0, '#sad', '#scared', -0.141, 'investigate_fact', 'investigate', 'say_eureka', 'ask_many_questions', 'investigation']
senticnet['look_for'] = [0.43, 0.657, -0.285, 0.244, '#joyful', '#interesting', 0.349, 'try_to_find', 'expectancy', 'amour_propre', 'self-love', 'conceit']
senticnet['look_for_information'] = [0, 0.825, 0, 0, '#interesting', '#interesting', 0.275, 'search_information', 'find_porn', 'find_out_new', 'check_email', 'need_information']
senticnet['look_for_job'] = [0.928, 0.778, 0, 0, '#joyful', '#interesting', 0.569, 'change_work', 'change_job', 'change_life', 'go_interview', 'new_job']
senticnet['look_forward'] = [0, 0.917, 0, 0, '#interesting', '#interesting', 0.306, 'enjoy_entertainment', 'recommend', 'expand_horizon', 'inspiration', 'view_art']
senticnet['look_glass'] = [0, 0.069, 0.025, 0.074, '#interesting', '#admirable', 0.039, 'pane', 'glass', 'look', 'see_thru', 'clear']
senticnet['look_good'] = [0.906, 0.715, 0, 0.796, '#joyful', '#admirable', 0.806, 'improve_look', 'improve_appearance', 'look_smart', 'look_attractive', 'look_presentable']
senticnet['look_great'] = [0.879, 0.949, 0, 0.821, '#joyful', '#interesting', 0.883, 'hot_summer', 'steal_store', 'hang_closet', 'crowd_elevator', 'appear_beautiful']
senticnet['look_in_mirror'] = [0.084, 0.419, -0.18, 0.278, '#interesting', '#admirable', 0.2, 'beauty', 'cut_hair', 'style_hair', 'look_out_window', 'try_clothes']
senticnet['look_into'] = [0.803, -0.815, 0, 0.903, '#surprising', '#admirable', 0.84, 'probe', 'study', 'research', 'search', 'explore']
senticnet['look_job'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'write_resume', 'ready_work', 'fill_out_application', 'go_interview', 'go_job']
senticnet['look_like'] = [0.084, 0.419, -0.18, 0.278, '#interesting', '#admirable', 0.2, 'form_government', 'political_system', 'star_wars', 'unity', 'government_person']
senticnet['look_map'] = [-0.079, 0, 0.012, 0, '#sad', '#angry', -0.03, 'know_go', 'decide_to_go', 'leave_house_first', 'decide_want_go', 'leave_house']
senticnet['look_menu'] = [-0.051, -0.026, 0.046, -0.08, '#sad', '#disgusting', -0.05, 'read_menu', 'use_restroom', 'use_fork', 'order_menu', 'fee_child']
senticnet['look_neat'] = [0.065, 0, 0.01, 0.049, '#joyful', '#admirable', 0.035, 'look_smart', 'improve_appearance', 'short_hair', 'change_hair_style', 'get_new_hairstyle']
senticnet['look_newspaper'] = [-0.13, -0.004, 0, -0.067, '#sad', '#disgusting', -0.064, 'sharpen_pencil', 'select_topic', 'use_paper', 'run_out_ink', 'use_pencil']
senticnet['look_nice'] = [0.99, 0.821, 0, 0.836, '#joyful', '#admirable', 0.882, 'make_good_impression', 'improve_appearance', 'look_smart', 'social_acceptance', 'look_neat']
senticnet['look_night_sky'] = [0.356, 0.09, 0, 0.26, '#joyful', '#admirable', 0.235, 'good_lover', 'sanity', 'cherish', 'run_business', 'remission']
senticnet['look_oneself_in_mirror'] = [-0.1, 0.069, -0.102, 0, '#sad', '#scared', -0.044, 'see_doctor', 'visit_doctor', 'blood_test', 'go_doctor', 'go_see_doctor']
senticnet['look_out'] = [-0.074, 0.079, 0, 0.129, '#interesting', '#admirable', 0.045, 'look_outside', 'see_out', 'look_through', 'see_through', 'open_close']
senticnet['look_out_window'] = [-0.113, -0.016, 0, -0.136, '#sad', '#disgusting', -0.078, 'page_through_book', 'check_oneself_mirror', 'turn_light', 'turn_off_engine', 'borrow_book_from_library']
senticnet['look_outside'] = [-0.074, 0.079, 0, 0.129, '#interesting', '#admirable', 0.045, 'look_out', 'see_out', 'look_through', 'see_through', 'open_close']
senticnet['look_over'] = [0.843, 0, 0, 0.822, '#joyful', '#admirable', 0.555, 'skim_through', 'read_cover', 'take_look', 'read_through', 'read_fast']
senticnet['look_picture'] = [0.865, 0.805, 0, 0, '#joyful', '#interesting', 0.557, 'see_ad', 'turn_page', 'take_shit', 'eye_strain', 'move_eye']
senticnet['look_presentable'] = [0.824, 0.86, 0, 0.983, '#interesting', '#admirable', 0.889, 'look_smart', 'social_acceptance', 'improve_appearance', 'improve_look', 'look_good']
senticnet['look_pretty'] = [0.991, 0, 0, 0.847, '#joyful', '#admirable', 0.613, 'look_neat', 'look_smart', 'look_good', 'improve_look', 'look_different']
senticnet['look_price'] = [0.036, 0.232, -0.057, 0.192, '#interesting', '#admirable', 0.134, 'money_spend', 'achievable', 'purchase', 'establish_credit', 'pay_debt']
senticnet['look_round'] = [0.021, 0.081, 0.017, 0.113, '#interesting', '#admirable', 0.066, 'aspect', 'perspective', 'viewfinder', 'scenic', 'look_through']
senticnet['look_scary'] = [0.103, -0.065, 0.013, 0.13, '#joyful', '#admirable', 0.095, 'make_assumption', 'type_of_credit_card', 'elusive', 'tangible', 'morality']
senticnet['look_scenery'] = [0.78, 0.787, 0, 0, '#joyful', '#interesting', 0.522, 'get_tired_leg', 'shift_gear', 'become_tired', 'tired_leg', 'see_neighbor']
senticnet['look_sexy'] = [0, 0.926, 0, 0.721, '#interesting', '#admirable', 0.549, 'become_friend', 'start_conversation', 'say_hello', 'eye_contact', 'talk_another_person']
senticnet['look_sky'] = [0.043, 0, 0, 0.057, '#joyful', '#admirable', 0.033, 'blow_horn', 'cross_bridge', 'skip', 'leave_place', 'shoulder_burden']
senticnet['look_smart'] = [0.941, 0, 0, 0.856, '#joyful', '#admirable', 0.599, 'look_neat', 'improve_appearance', 'look_presentable', 'improve_look', 'look_good']
senticnet['look_stylish'] = [-0.063, -0.048, 0.094, 0, '#sad', '#angry', -0.036, 'keep_foot_warm', 'protect_foot', 'high_heel', 'walk_upon', 'stand_upon']
senticnet['look_through'] = [0, 0.795, 0, 0.829, '#interesting', '#admirable', 0.541, 'look_out', 'see_out', 'look_outside', 'see_through', 'window_cover']
senticnet['look_through_binoculars'] = [0.854, 0.975, 0, 0.926, '#interesting', '#admirable', 0.918, 'go_kiss', 'kiss', 'valentine_day', 'find_love', 'procreate']
senticnet['look_to'] = [-0.867, 0, 0.609, -0.5, '#sad', '#angry', -0.659, 'look_forward', 'await', 'look_for', 'hang_on', 'expect']
senticnet['look_truth'] = [0, 0.835, 0, 0.972, '#interesting', '#admirable', 0.602, 'resolve_conflict', 'look_through', 'serve_jury', 'register_vote', 'look_evidence']
senticnet['look_unattractive'] = [-0.031, 0.157, 0.698, -0.661, '#angry', '#disgusting', -0.411, 'fat', 'overweight', 'fatty', 'unhealthy', 'eat_too_much']
senticnet['look_up'] = [0, 0.073, 0, 0, '#interesting', '#interesting', 0.024, 'open_mind', 'absorb_information', 'remember_fact', 'use_dictionary', 'turn_page']
senticnet['look_up_dictionary_word'] = [0, 0.873, 0, 0, '#interesting', '#interesting', 0.291, 'read_science_book', 'borrow_book_from_library', 'read_book', 'study_science', 'prepare_exam']
senticnet['look_up_information'] = [0.088, -0.003, 0, 0, '#joyful', '#surprising', 0.03, 'find_newspaper', 'news', 'headlines', 'enter_contest', 'latest_news']
senticnet['look_up_phone_number'] = [0, -0.034, 0.135, -0.042, '#angry', '#disgusting', -0.048, 'telephone_number', 'read_email', 'find_phone_number', 'pass_information', 'give_information']
senticnet['look_up_to'] = [0.575, 0.636, -0.268, 0.318, '#joyful', '#interesting', 0.42, 'laudably', 'admirably', 'praiseworthily', 'commendable', 'admirable']
senticnet['look_up_word_in_dictionary'] = [0, 0.758, 0, 0, '#interesting', '#interesting', 0.253, 'read_science_book', 'master_skill', 'miss_bus', 'act_up', 'question_teacher']
senticnet['looker'] = [0.723, -0.763, 0, 0.674, '#joyful', '#surprising', 0.72, 'cheerer', 'gawker', 'percipient', 'rubberneck', 'starer']
senticnet['looking'] = [0.833, 0.82, 0, 0, '#joyful', '#interesting', 0.551, 'view', 'peek', 'stare', 'lookout', 'sight']
senticnet['looking_at'] = [0.684, -0.582, 0, 0.647, '#joyful', '#admirable', 0.638, 'view', 'peek', 'stare', 'lookout', 'sight']
senticnet['looking_glass'] = [0.584, -0.627, 0, 0.815, '#surprising', '#admirable', 0.675, 'cheval_glass', 'car_mirror', 'hand_glass', 'hand_mirror', 'mirror']
senticnet['lookout'] = [0.521, -0.546, 0, 0.691, '#surprising', '#admirable', 0.586, 'view', 'peek', 'stare', 'looking', 'sight']
senticnet['looks_like_new'] = [0, 0.07, 0, 0.067, '#interesting', '#admirable', 0.046, 'clean', 'polish', 'shiny', 'car_wash', 'sexy_girl']
senticnet['loom'] = [0.056, 0.105, 0.786, -0.681, '#angry', '#disgusting', -0.435, 'huffishness', 'sulkiness', 'sulk', 'hover', 'bulk_large']
senticnet['loon'] = [-0.997, 0, 0.804, -0.523, '#sad', '#angry', -0.775, 'addlehead', 'birdbrain', 'ape', 'misfit', 'mortal']
senticnet['looney'] = [-0.648, 0, 0.781, -0.743, '#angry', '#disgusting', -0.724, 'weirdo', 'crazy', 'loony', 'lunatic', 'nutcase']
senticnet['loony'] = [-0.648, 0, 0.781, -0.743, '#angry', '#disgusting', -0.724, 'weirdo', 'crazy', 'lunatic', 'looney', 'nutcase']
senticnet['loony_bin'] = [-0.532, 0, 0.874, -0.637, '#angry', '#disgusting', -0.681, 'asylum', 'mental_hospital', 'psychiatric_hospital', 'mental_institution', 'mental_home']
senticnet['loop'] = [0.745, 0.785, 0, 0, '#joyful', '#interesting', 0.51, 'hockey_puck', 'hockey_stick', 'disk', 'puck', 'bullseye']
senticnet['loophole'] = [0, 0, 0.762, -0.852, '#angry', '#disgusting', -0.538, 'ambiguity', 'prevarication', 'equivocation', 'unclearness', 'equivocalness']
senticnet['loose'] = [-0.098, -0.076, 0.052, -0.089, '#sad', '#disgusting', -0.054, 'try_win', 'roll_dice', 'win', 'try_best', 'sore_knee']
senticnet['loose_change'] = [0.834, 0.99, 0, 0, '#joyful', '#interesting', 0.608, 'spare_change', 'coin_slot', 'checkbook_cover', 'paper_bill', 'banknote']
senticnet['loose_end'] = [0, 0, -0.06, -0.038, '#scared', '#disgusting', -0.033, 'another_planet', 'death_row', 'car_race', 'auction', 'mortuary']
senticnet['loose_money'] = [-0.04, -0.072, 0.117, -0.119, '#angry', '#disgusting', -0.068, 'gamble_money', 'win_money', 'play_rule', 'winner_loser', 'play_fun']
senticnet['loose_tooth'] = [-0.92, 0, 0.794, -0.935, '#sad', '#disgusting', -0.883, 'tooth_pain', 'pain', 'feel_terrible', 'scared', 'painful']
senticnet['loose_track_time'] = [-0.032, -0.047, 0.146, -0.185, '#angry', '#disgusting', -0.105, 'move_finger', 'miss_call', 'miss_out', 'part_of_band', 'make_noise']
senticnet['loosen_muscle'] = [0.072, 0, 0.013, 0.124, '#joyful', '#admirable', 0.061, 'shrinkage', 'remove_spot', 'relieve_tension', 'remove_stain', 'tidiness']
senticnet['loosen_up'] = [-0.519, 0, 0.738, -0.834, '#angry', '#disgusting', -0.697, 'relax', 'sit_back', 'unbend', 'unwind', 'decompress']
senticnet['looseness'] = [0.664, -0.883, 0, 0.732, '#surprising', '#admirable', 0.76, 'mobility', 'portability', 'movability', 'play', 'unsteadiness']
senticnet['loosening'] = [-0.978, 0, 0.856, -0.631, '#sad', '#angry', -0.822, 'laxation', 'change', 'tune', 'accommodation', 'modification']
senticnet['looser'] = [0.896, 0.849, 0, 0, '#joyful', '#interesting', 0.582, 'meet_new_person', 'pick_up_woman', 'get_wasted', 'drink_beer', 'get_drink']
senticnet['loot'] = [0, 0, 0.89, -0.982, '#angry', '#disgusting', -0.624, 'peso', 'bribe', 'mastercard', 'profit', 'finance']
senticnet['lopsided'] = [-0.889, 0, -0.758, 0, '#sad', '#scared', -0.549, 'skew-whiff', 'awry', 'wonky', 'askew', 'cockeyed']
senticnet['lopsidedness'] = [-0.596, 0, 0.672, -0.831, '#angry', '#disgusting', -0.7, 'geometrical_irregularity', 'radial_asymmetry', 'asymmetry', 'skewness', 'irregularity']
senticnet['loquacious'] = [0.949, -0.694, 0, 0.992, '#joyful', '#admirable', 0.878, 'chatty', 'gabby', 'garrulous', 'voluble', 'talky']
senticnet['loquaciousness'] = [0.664, -0.941, 0, 0.613, '#joyful', '#surprising', 0.739, 'outspokenness', 'frankness', 'garrulity', 'garrulousness', 'communicativeness']
senticnet['loquacity'] = [0.916, -0.877, 0, 0.79, '#joyful', '#surprising', 0.861, 'garrulity', 'garrulousness', 'loquaciousness', 'leresis', 'talkativeness']
senticnet['lord'] = [0.059, 0.153, -0.051, 0.144, '#interesting', '#admirable', 0.102, 'duchess', 'baron', 'king', 'duke', 'noble']
senticnet['lordliness'] = [0.841, -0.568, 0, 0.654, '#joyful', '#admirable', 0.688, 'dignity', 'gravitas', 'comportment', 'personal_manner', 'manner']
senticnet['lordosis'] = [-0.942, 0, 0.87, -0.902, '#sad', '#disgusting', -0.905, 'spinal_curvature', 'kyphosis', 'humpback', 'hunchback', 'abnormality']
senticnet['lordship'] = [0.742, -0.927, 0, 0.564, '#joyful', '#surprising', 0.744, 'imperium', 'potency', 'power_of_appointment', 'carte_blanche', 'command']
senticnet['lore'] = [0.95, -0.863, 0, 0.947, '#joyful', '#admirable', 0.92, 'content', 'old_wives_tale', 'folklore', 'cognitive_content', 'mental_object']
senticnet['lorry'] = [0.028, 0, 0.013, 0.061, '#joyful', '#admirable', 0.025, 'truck', 'vehicle', 'limousine', 'car', 'big_car']
senticnet['lose'] = [-0.87, -0.66, 0.98, -0.76, '#sad', '#angry', -0.65, 'tired', 'gyroscope', 'increase_price', 'ball_bounce', 'sore_knee']
senticnet['lose_a_lot_of_money'] = [-0.882, 0, -0.966, -0.794, '#sad', '#scared', -0.881, 'team_lose', 'foolish', 'hit_baseball_bat', 'winner_loser', 'lose_game']
senticnet['lose_article'] = [-0.929, 0, 0.228, -0.91, '#sad', '#disgusting', -0.689, 'lose_file', 'mistake', 'lose_document', 'error', 'lose_something']
senticnet['lose_balance'] = [0, 0, -0.743, -0.821, '#scared', '#disgusting', -0.521, 'fall_down', 'fall_over', 'trip_fall', 'fall', 'take_photo']
senticnet['lose_ball'] = [0, -0.066, 0.077, -0.109, '#angry', '#disgusting', -0.04, 'punch_bag', 'increase_price', 'ball_bounce', 'tired_iron', 'buy_ball']
senticnet['lose_battle'] = [-0.126, -0.034, -0.103, -0.184, '#sad', '#disgusting', -0.126, 'military_action', 'beaten', 'victory_defeat', 'defeat', 'win_battle']
senticnet['lose_blood'] = [0.046, 0.117, 0.772, -0.676, '#angry', '#disgusting', -0.428, 'die', 'die_in_war', 'lose_war', 'get_hit', 'kamikaze']
senticnet['lose_consciousness'] = [-0.957, 0, 0.549, -0.993, '#sad', '#disgusting', -0.833, 'lose_track_of_time', 'memory_loss', 'bad_memory', 'sickness', 'become_old']
senticnet['lose_control'] = [-0.203, -0.119, -0.047, -0.209, '#sad', '#disgusting', -0.113, 'hangover', 'alcoholism', 'throw_up', 'forgetfulness', 'bee_sting']
senticnet['lose_credibility'] = [0, 0, 0, -0.94, '#disgusting', '#disgusting', -0.313, 'screw_up', 'feel_stressed', 'bad_feeling', 'complication', 'without_money']
senticnet['lose_document'] = [-0.929, 0, 0.228, -0.91, '#sad', '#disgusting', -0.689, 'lose_file', 'mistake', 'lose_article', 'error', 'lose_something']
senticnet['lose_election'] = [-0.049, 0.168, -0.079, 0.09, '#interesting', '#admirable', 0.043, 'elect_official', 'elect_person', 'prime_minister', 'politician', 'country_leader']
senticnet['lose_energy'] = [0, 0, 0, -0.847, '#disgusting', '#disgusting', -0.282, 'get_old', 'grow_older', 'old', 'become_old', 'lose_health']
senticnet['lose_file'] = [-0.929, 0, 0.228, -0.91, '#sad', '#disgusting', -0.689, 'lose_article', 'mistake', 'lose_document', 'error', 'lose_something']
senticnet['lose_focus'] = [-0.081, -0.031, 0.043, -0.124, '#sad', '#disgusting', -0.072, 'poor_strategy', 'bad_luck', 'lose', 'lose_game', 'miss_point']
senticnet['lose_foot'] = [0, 0, -0.903, 0, '#scared', '#scared', -0.301, 'almost_fall', 'skid', 'stumble', 'reach_high_shelf', 'trip']
senticnet['lose_friend'] = [-0.734, 0, 0, -0.735, '#sad', '#disgusting', -0.49, 'black_eye', 'censorship', 'complication', 'get_hurt', 'schizophrenia']
senticnet['lose_game'] = [-0.081, -0.031, 0.043, -0.124, '#sad', '#disgusting', -0.072, 'poor_strategy', 'bad_luck', 'lose', 'lose_focus', 'miss_point']
senticnet['lose_hair'] = [-0.962, 0, 0.278, -0.983, '#sad', '#disgusting', -0.741, 'need_cure', 'take_medicine', 'spend_money', 'stress', 'anxiety']
senticnet['lose_health'] = [0, 0, 0, -0.847, '#disgusting', '#disgusting', -0.282, 'get_old', 'grow_older', 'old', 'lose_energy', 'become_old']
senticnet['lose_it'] = [0.957, -0.926, 0, 0.577, '#joyful', '#surprising', 0.82, 'behave', 'dissolve', 'die', 'fall_apart', 'go_to_pieces']
senticnet['lose_item'] = [-0.032, 0.2, -0.052, 0.073, '#interesting', '#admirable', 0.063, 'storage_box', 'sex_toy', 'old_sock', 'homosexual', 'peace_quiet']
senticnet['lose_job'] = [-0.126, 0, 0, -0.251, '#sad', '#disgusting', -0.126, 'die_young', 'go_scuba_dive', 'go_insane', 'feel_stupid', 'feel_ashamed']
senticnet['lose_key'] = [-0.164, 0, -0.06, -0.072, '#sad', '#disgusting', -0.099, 'master_new_skill', 'master_skill', 'chair_committee', 'wrong_another_person', 'honor_parent']
senticnet['lose_life'] = [-0.973, 0, 0.061, -0.908, '#sad', '#disgusting', -0.647, 'end_of_life', 'pass_away', 'death', 'stop_living', 'die_person']
senticnet['lose_memory'] = [-0.154, -0.054, 0, -0.06, '#sad', '#disgusting', -0.053, 'bad_grade', 'loss', 'loose', 'sore_knee', 'get_tired']
senticnet['lose_mind'] = [-0.972, 0, 0.7, -0.964, '#sad', '#disgusting', -0.879, 'go_insane', 'punch_face', 'feel_bad', 'feel_stupid', 'become_angry']
senticnet['lose_money'] = [-0.856, 0, 0.814, -0.915, '#sad', '#disgusting', -0.862, 'buy_chip', 'shuffle_card', 'go_broke', 'lose', 'go_debt']
senticnet['lose_place'] = [-0.152, 0, 0, -0.149, '#sad', '#disgusting', -0.1, 'start_over', 'wait_patiently', 'find_line_stand', 'act_bored', 'find_line']
senticnet['lose_qualification'] = [0, 0, 0, -0.773, '#disgusting', '#disgusting', -0.258, 'stress', 'want_pass_class', 'fail', 'complete_course', 'become_stressed']
senticnet['lose_sleep'] = [-0.913, 0, 0.849, -0.92, '#sad', '#disgusting', -0.894, 'feel_stupid', 'buy_stock', 'finish_task', 'lose_temper', 'stress']
senticnet['lose_something'] = [-0.929, 0, 0.228, -0.91, '#sad', '#disgusting', -0.689, 'lose_file', 'mistake', 'lose_document', 'error', 'lose_article']
senticnet['lose_soul'] = [-0.242, 0, -0.242, -0.047, '#sad', '#scared', -0.177, 'porpoise', 'titanic', 'seahorse', 'many_fishes', 'sea_wee']
senticnet['lose_team'] = [-0.708, 0, 0.736, 0, '#sad', '#angry', -0.481, 'cause_suffer', 'leave_out', 'sadness', 'disrespect', 'lyme_disease']
senticnet['lose_temper'] = [-0.922, 0, 0.845, -0.885, '#sad', '#disgusting', -0.884, 'lose_game', 'lose_sleep', 'break_leg', 'blackout', 'become_angry']
senticnet['lose_territory'] = [-0.111, 0, 0.033, -0.324, '#sad', '#disgusting', -0.156, 'conquer_enemy', 'lose_war', 'hitler', 'go_war', 'enslave_person']
senticnet['lose_time'] = [-0.708, 0, 0.824, -0.93, '#angry', '#disgusting', -0.821, 'monotony', 'bad_karma', 'coworker', 'kill_time', 'lay_off']
senticnet['lose_track_of_time'] = [-0.952, 0, 0.825, -0.981, '#sad', '#disgusting', -0.919, 'car_accident', 'accident', 'motorbike_accident', 'lose_consciousness', 'sport_accident']
senticnet['lose_track_time'] = [-0.751, 0, 0.876, -0.942, '#angry', '#disgusting', -0.856, 'boredom', 'get_excited', 'extreme_boredom', 'bored', 'eye_strain']
senticnet['lose_wallet'] = [-0.809, 0, 0.718, -0.797, '#sad', '#disgusting', -0.775, 'walk_exercise', 'push_cart', 'go_debt', 'pay_dinner', 'spend_much_money']
senticnet['lose_war'] = [-0.986, 0, 0.782, -0.878, '#sad', '#disgusting', -0.882, 'beaten', 'loss', 'lose_battle', 'military_action', 'terrify']
senticnet['lose_weight'] = [0, 0, 0, 0.071, '#admirable', '#admirable', 0.024, 'get_shape', 'stay_fit', 'weight_loss', 'maintain_health', 'get_healthy']
senticnet['lose_your_balance'] = [-0.97, 0, 0.977, -0.991, '#angry', '#disgusting', -0.979, 'fall', 'fall_down', 'knee_injury', 'injury', 'hurt']
senticnet['loser'] = [-0.87, -0.66, 0.98, -0.76, '#sad', '#angry', -0.65, 'boring', 'dumb', 'dull', 'get_bored', 'get_drink']
senticnet['loss'] = [-0.815, 0, 0.884, -0.87, '#angry', '#disgusting', -0.856, 'lose_war', 'beaten', 'cost_fortune', 'bad_grade', 'military_action']
senticnet['loss_of_consciousness'] = [-0.036, 0, -0.197, -0.111, '#scared', '#disgusting', -0.115, 'become_unconscious', 'hit_oneself_head', 'stop_move', 'unconsciousness', 'stop_think']
senticnet['loss_of_strength'] = [-0.732, 0, 0.596, -0.773, '#sad', '#disgusting', -0.7, 'exhaustion', 'weariness', 'logginess', 'eyestrain', 'asthenopia']
senticnet['loss_ofawareness'] = [-0.171, -0.005, -0.159, -0.169, '#sad', '#disgusting', -0.165, 'bang_head', 'fall_ground', 'concussion', 'serious_accident', 'loss_ofbreath']
senticnet['loss_ofbreath'] = [-0.048, 0, -0.128, -0.075, '#scared', '#disgusting', -0.084, 'break_leg', 'fall_ground', 'loss_ofawareness', 'fall_down', 'breafast']
senticnet['loss_offreedom'] = [-0.357, 0, -0.278, 0, '#sad', '#scared', -0.212, 'lower_standard_live', 'overpopulation', 'marry_kid', 'quiet_baby', 'cum']
senticnet['loss_oflife'] = [-0.816, 0, -0.711, -0.8, '#sad', '#disgusting', -0.776, 'death', 'kill_oneself', 'serious_injury', 'die', 'fall_dead']
senticnet['loss_ofmemory'] = [-0.17, -0.024, 0, -0.264, '#sad', '#disgusting', -0.137, 'paralysis', 'head_hurt', 'headache', 'relieve_pain', 'make_sad']
senticnet['loss_ofmoney'] = [-0.082, -0.032, 0, -0.12, '#sad', '#disgusting', -0.057, 'salivation', 'world_hunger', 'salivate', 'weight_gain', 'buy_steak']
senticnet['lost'] = [0, 0, -0.943, -0.77, '#scared', '#disgusting', -0.571, 'need_information', 'need_help', 'need_know', 'ignorant', 'needy_person']
senticnet['lost_and_found'] = [0, 0.086, -0.069, 0.12, '#interesting', '#admirable', 0.046, 'odds', 'misplace', 'sea_level', 'load_dock', 'room_temperature']
senticnet['lost_cause'] = [-0.603, 0, 0.694, -0.96, '#angry', '#disgusting', -0.752, 'movement', 'cause', 'campaign', 'crusade', 'drive']
senticnet['lost_in_nature'] = [0, 0.085, 0, 0.059, '#interesting', '#admirable', 0.048, 'find', 'lake', 'trekking', 'find_lake', 'wear_shoes']
senticnet['lost_money'] = [-0.873, -0.794, 0.729, -0.976, '#sad', '#disgusting', -0.595, 'bankruptcy', 'empty_pocket', 'cashless', 'hobo', 'debt']
senticnet['lost_pet'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'find_animal', 'wild_horse', 'animal', 'doghouse', 'find_dog']
senticnet['lot'] = [0, 0.108, 0.029, 0.09, '#interesting', '#admirable', 0.056, 'quantity', 'amount', 'rate', 'allotment', 'pound']
senticnet['lotion'] = [0, 0.086, -0.069, 0.12, '#interesting', '#admirable', 0.046, 'gel_toothpaste', 'tartar_control_toothpaste', 'fluoride_mouthwash', 'toothpaste', 'hair_lotion']
senticnet['lottery'] = [0, 0.75, 0, 0.961, '#interesting', '#admirable', 0.57, 'box_office', 'movie', 'cctv', 'cinema', 'movie_theater']
senticnet['louche'] = [0.725, -0.886, 0, 0.508, '#joyful', '#surprising', 0.706, 'disreputable', 'seedy', 'discredited', 'sleazy', 'discreditable']
senticnet['loud'] = [0.043, 0, 0, 0.112, '#joyful', '#admirable', 0.052, 'loud_sound', 'loudness', 'loud_soft', 'loud_noise', 'audio']
senticnet['loud_cry'] = [-0.065, -0.013, -0.099, 0, '#sad', '#scared', -0.05, 'loud_shout', 'freak_out', 'loud_yell', 'groan', 'clamor']
senticnet['loud_music'] = [-0.95, 0, -0.736, -0.736, '#sad', '#scared', -0.807, 'make_noise', 'high_volume', 'loudly', 'noise', 'loud']
senticnet['loud_noise'] = [0, 0, -0.964, -0.718, '#scared', '#disgusting', -0.561, 'loud_sound', 'noise', 'decibel', 'clamor', 'loud']
senticnet['loud_shout'] = [-0.05, -0.008, -0.06, 0, '#sad', '#scared', -0.034, 'loud_yell', 'loud_cry', 'freak_out', 'human_noise', 'noise']
senticnet['loud_soft'] = [0, 0.963, 0, 0.835, '#interesting', '#admirable', 0.599, 'audible', 'human_sound', 'vocalization', 'audio', 'loudness']
senticnet['loud_sound'] = [0.056, -0.019, 0.036, 0.073, '#joyful', '#admirable', 0.037, 'amplifier', 'stereo', 'tuner', 'speaker', 'steam_engine']
senticnet['loud_yell'] = [0, 0, -0.966, -0.709, '#scared', '#disgusting', -0.558, 'loudness', 'vibration', 'echo', 'detect', 'decibel']
senticnet['loudly'] = [-0.95, 0, -0.736, -0.736, '#sad', '#scared', -0.807, 'make_noise', 'high_volume', 'loud_music', 'noise', 'loud']
senticnet['loudness'] = [0, 0.918, 0, 0.791, '#interesting', '#admirable', 0.57, 'decibel', 'noise', 'loud_soft', 'sound', 'audio']
senticnet['loudspeaker'] = [-0.046, -0.028, 0.089, -0.142, '#angry', '#disgusting', -0.083, 'vacuum_cleaner', 'steam_locomotive', 'collector', 'siren', 'activist']
senticnet['lounge'] = [0.944, 0, 0, 0.966, '#joyful', '#admirable', 0.637, 'waiter', 'bar_service', 'beverage_service', 'concierge', 'minibar']
senticnet['lounge_chair'] = [0.052, 0.119, 0, 0.141, '#interesting', '#admirable', 0.104, 'cinema', 'theater', 'seat', 'chair', 'row_seat']
senticnet['lounger'] = [-0.76, 0, 0.941, -0.518, '#sad', '#angry', -0.74, 'wear', 'lounging_pajama', 'lounging_pyjama', 'wearable', 'loungewear']
senticnet['loungewear'] = [-0.76, 0, 0.941, -0.518, '#sad', '#angry', -0.74, 'wear', 'lounging_pajama', 'lounging_pyjama', 'wearable', 'lounger']
senticnet['lounging_pajama'] = [-0.76, 0, 0.941, -0.518, '#sad', '#angry', -0.74, 'wear', 'loungewear', 'lounging_pyjama', 'wearable', 'lounger']
senticnet['lounging_pyjama'] = [-0.76, 0, 0.941, -0.518, '#sad', '#angry', -0.74, 'wear', 'lounging_pajama', 'loungewear', 'wearable', 'lounger']
senticnet['louse'] = [0, 0, 0.941, -0.834, '#angry', '#disgusting', -0.592, 'gnat', 'flea', 'mosquito', 'muzzle', 'mite']
senticnet['lousiness'] = [-0.841, 0, 0.767, -0.996, '#sad', '#disgusting', -0.868, 'pediculosis_capitis', 'head_lice', 'pediculosis_corporis', 'pediculosis_pubis', 'crabs']
senticnet['lousy'] = [-0.923, 0, 0.256, -0.986, '#sad', '#disgusting', -0.722, 'low_quality', 'bad_quality', 'failure', 'poor_quality', 'defective']
senticnet['louvre'] = [0, 0.838, 0, 0.906, '#interesting', '#admirable', 0.581, 'smithsonian', 'car_race', 'room_temperature', 'auction', 'another_planet']
senticnet['lovable'] = [0.936, -0.815, 0, 0.83, '#joyful', '#admirable', 0.86, 'cherubic', 'lovely', 'adorable', 'endearing', 'angelic']
senticnet['love'] = [1, 0, 0, 1, '#joyful', '#admirable', 0.667, 'lust', 'love_another_person', 'sexuality', 'beloved', 'show_empathy']
senticnet['love_affection'] = [0.94, 0, 0, 0.84, '#joyful', '#admirable', 0.593, 'kind', 'kindness', 'look_after', 'show_love', 'express_gratitude']
senticnet['love_animal'] = [-0.081, -0.004, 0, -0.042, '#sad', '#disgusting', -0.04, 'fix_breakfast', 'salt_food', 'prepare_breakfast', 'bone_chicken', 'set_table']
senticnet['love_another'] = [-0.027, 0.118, -0.097, 0.207, '#interesting', '#admirable', 0.067, 'kiss', 'end_happily', 'love_else', 'commit', 'flirt']
senticnet['love_another_person'] = [0.892, 0, 0, 0.813, '#joyful', '#admirable', 0.568, 'lust', 'feel_love', 'love', 'care_deeply', 'show_empathy']
senticnet['love_art'] = [0.706, 0.791, 0, 0.746, '#interesting', '#admirable', 0.748, 'go_museum', 'obtain_information', 'sightsee', 'learn_culture', 'bring_friend']
senticnet['love_back'] = [0.74, 0.928, 0, 0, '#joyful', '#interesting', 0.556, 'show_empathy', 'warm_fuzzy_feeling', 'love_oneself', 'become_aroused', 'say_welcome']
senticnet['love_child'] = [0, 0, -0.068, -0.069, '#scared', '#disgusting', -0.046, 'baby', 'quiet_baby', 'marry_kid', 'loss_offreedom', 'cum']
senticnet['love_city'] = [0.713, 0.825, 0, 0.907, '#interesting', '#admirable', 0.815, 'romance', 'love', 'love_story', 'get_rid_of_enemy', 'romeo_and_juliet']
senticnet['love_each_other'] = [0.77, 0.742, 0, 0, '#joyful', '#interesting', 0.504, 'happy_time', 'annual_celebration', 'new_relationship', 'retirement', 'party_time']
senticnet['love_else'] = [-0.027, 0.118, -0.097, 0.207, '#interesting', '#admirable', 0.067, 'kiss', 'love_another', 'end_happily', 'commit', 'flirt']
senticnet['love_family'] = [0.802, 0, 0, 0.739, '#joyful', '#admirable', 0.514, 'cherish', 'love_another_person', 'brotherhood', 'run_business', 'wear_necklace']
senticnet['love_feast'] = [0.544, -0.677, 0, 0.653, '#surprising', '#admirable', 0.625, 'get_together', 'bee', 'social_affair', 'company', 'function']
senticnet['love_god'] = [0.933, 0.967, 0, 0, '#joyful', '#interesting', 0.633, 'religion', 'great_love', 'get_help', 'religious_belief', 'hope']
senticnet['love_line'] = [0.924, -0.764, 0, 0.728, '#joyful', '#surprising', 0.805, 'crease', 'crinkle', 'wrinkle', 'furrow', 'seam']
senticnet['love_music'] = [0.52, 0.666, -0.261, 0.269, '#joyful', '#interesting', 0.398, 'like_music', 'hear_beautiful_music', 'sound_beautiful', 'beautiful_music', 'record_music']
senticnet['love_one'] = [0.735, 0, 0, 0.846, '#joyful', '#admirable', 0.527, 'orphan', 'become_parent', 'take_child', 'have_much', 'progeny']
senticnet['love_oneself'] = [0, 0.949, 0, 0.856, '#interesting', '#admirable', 0.602, 'show_empathy', 'find_woman', 'care_deeply', 'love_back', 'become_aroused']
senticnet['love_other'] = [0.741, 0, 0, 0.989, '#joyful', '#admirable', 0.577, 'complement', 'live_ripe_old_age', 'taken_seriously', 'remission', 'much_need']
senticnet['love_others'] = [0.117, -0.083, -0.056, 0, '#joyful', '#surprising', 0.048, 'make_love_spouse', 'dance_together', 'kiss', 'give_flower', 'feel_joy']
senticnet['love_parent'] = [0.945, 0, 0, 0.831, '#joyful', '#admirable', 0.592, 'world_peace', 'run_business', 'strong_relationship', 'cherish', 'express_gratitude']
senticnet['love_person'] = [0.731, 0, 0, 0.974, '#joyful', '#admirable', 0.568, 'cotton', 'silk', 'wool', 'fleece', 'cotton_boll']
senticnet['love_pet'] = [0.867, 0.802, 0, 0.793, '#joyful', '#interesting', 0.821, 'borrow_book_from_library', 'bicycle_school', 'succeed_school', 'solve_equation', 'master_skill']
senticnet['love_story'] = [0.713, 0.825, 0, 0.907, '#interesting', '#admirable', 0.815, 'romance', 'love', 'romeo_and_juliet', 'get_rid_of_enemy', 'love_city']
senticnet['love_triangle'] = [-0.915, 0, 0.221, -0.917, '#sad', '#disgusting', -0.684, 'cheat', 'cheat_on', 'intruder', 'have_problem', 'heart_broken']
senticnet['loveable'] = [0.721, -0.546, 0, 0.824, '#joyful', '#admirable', 0.697, 'cherubic', 'lovely', 'adorable', 'endearing', 'angelic']
senticnet['lovebird'] = [0.971, -0.598, 0, 0.768, '#joyful', '#admirable', 0.779, 'parakeet', 'parrakeet', 'parroket', 'paraquet', 'paroquet']
senticnet['loved'] = [0.59, -0.815, 0, 0.571, '#joyful', '#surprising', 0.659, 'preferred', 'wanted', 'admired', 'darling', 'precious']
senticnet['loveless'] = [-0.565, 0, 0.578, -0.744, '#angry', '#disgusting', -0.629, 'cold', 'frigid', 'unloving', 'detached', 'unaffectionate']
senticnet['lovelorn'] = [-0.859, 0, 0.655, -0.672, '#sad', '#disgusting', -0.729, 'unloved', 'unbeloved', 'bereft', 'estranged', 'disinherited']
senticnet['lovely'] = [0.725, 0.775, 0, 0.725, '#joyful', '#interesting', 0.742, 'nice_look', 'uneducated', 'nice', 'gorgeous', 'contrary']
senticnet['lovely_music'] = [0.758, -0.751, 0, 0.683, '#joyful', '#surprising', 0.731, 'produce_musical_sound', 'play_tune', 'play_jazz', 'play_in_band', 'play_song']
senticnet['lover'] = [0.767, 0, 0, 0.893, '#joyful', '#admirable', 0.553, 'man_wife', 'foreplay', 'companion', 'find_mate', 'cherish']
senticnet['lovesome'] = [0, 0.821, 0, 0.997, '#interesting', '#admirable', 0.606, 'fond', 'affectionate', 'anticipate', 'apathetically', 'listlessness']
senticnet['loving'] = [0.494, 0.673, -0.269, 0.25, '#joyful', '#interesting', 0.383, 'adorably', 'lovingly', 'fondly', 'endearingly', 'devotedness']
senticnet['lovingly'] = [0.494, 0.673, -0.269, 0.25, '#joyful', '#interesting', 0.383, 'adorably', 'loving', 'fondly', 'endearingly', 'devotedness']
senticnet['lovingness'] = [0.528, 0.673, -0.275, 0.272, '#joyful', '#interesting', 0.399, 'caring', 'warmheartedness', 'amorousness', 'amative', 'amorous']
senticnet['low'] = [-0.774, 0.248, -0.455, 0, '#sad', '#scared', -0.327, 'down', 'grim', 'gloomful', 'darkness', 'somberness']
senticnet['low-spirited'] = [-0.784, 0.266, -0.45, -0.052, '#sad', '#scared', -0.34, 'downhearted', 'depressed', 'down_in_mouth', 'dispirited', 'downcast']
senticnet['low-spiritedness'] = [-0.752, 0.288, -0.434, -0.058, '#sad', '#scared', -0.319, 'dejectedness', 'dispiritedness', 'lowness', 'downheartedness', 'cheerless']
senticnet['low_battery'] = [-0.987, 0, 0.989, -0.933, '#sad', '#angry', -0.97, 'run_out_of_time', 'run_out_of_money', 'lack_of_food', 'run_out', 'almost_finish']
senticnet['low_blood_pressure'] = [-0.852, 0, -0.788, 0, '#sad', '#scared', -0.547, 'faint', 'blood_pressure', 'feel_sick', 'feel_dizzy', 'fear']
senticnet['low_blow'] = [-0.583, 0, 0.831, -0.543, '#sad', '#angry', -0.652, 'abuse', 'vilification', 'insult', 'revilement', 'contumely']
senticnet['low_down'] = [-0.294, 0.076, -0.118, 0.104, '#sad', '#scared', -0.077, 'lower_down', 'look_down', 'turn_down', 'cold_night', 'go_down']
senticnet['low_down_volume'] = [-0.294, 0.076, -0.118, 0.104, '#sad', '#scared', -0.077, 'low_down', 'lower_down', 'noise', 'cold_night', 'diminish']
senticnet['low_experience'] = [0, 0, 0.937, 0, '#angry', '#angry', -0.312, 'dumb', 'idiot', 'newbie', 'stupid', 'asshole']
senticnet['low_level'] = [-0.129, -0.058, 0, -0.134, '#sad', '#disgusting', -0.068, 'diminish', 'reduce', 'lower', 'lower_music', 'decrease']
senticnet['low_note'] = [-0.038, -0.05, 0.071, -0.07, '#angry', '#disgusting', -0.043, 'chamber_music', 'stressful_situation', 'make_sound', 'blare', 'annoy_neighbor']
senticnet['low_pay_work'] = [0, 0, -0.066, -0.037, '#scared', '#disgusting', -0.034, 'day_job', 'much_work', 'coworker', 'wage_slavery', 'pay_child_support']
senticnet['low_quality'] = [-0.923, 0, 0.256, -0.986, '#sad', '#disgusting', -0.722, 'lousy', 'bad_quality', 'failure', 'poor_quality', 'defective']
senticnet['low_quality_photo'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'slow', 'long_focus', 'focus_time', 'long_focus_time', 'bad_camera']
senticnet['low_self-esteem'] = [-0.757, 0, 0.733, -0.856, '#sad', '#disgusting', -0.782, 'ice_cream_melt', 'pimple', 'worm_intestine', 'chicken_pox', 'groin']
senticnet['low_status'] = [-0.875, 0, 0.818, -0.557, '#sad', '#angry', -0.75, 'inferiority', 'lower_status', 'lower_rank', 'status', 'position']
senticnet['low_temperature'] = [-0.909, 0, 0.512, -0.8, '#sad', '#disgusting', -0.74, 'pressor', 'chill', 'frostiness', 'cool', 'gelidity']
senticnet['lowball'] = [0.998, -0.961, 0, 0.91, '#joyful', '#surprising', 0.956, 'gauge', 'guess', 'approximate', 'estimate', 'judge']
senticnet['lowbrow'] = [0.849, -0.897, 0, 0.924, '#surprising', '#admirable', 0.89, 'philistine', 'nonintellectual', 'nonintellectualed', 'mindless', 'uncultivated']
senticnet['lowbrowed'] = [0.849, -0.897, 0, 0.924, '#surprising', '#admirable', 0.89, 'philistine', 'lowbrow', 'nonintellectual', 'mindless', 'uncultivated']
senticnet['lower'] = [-0.129, -0.058, 0, -0.134, '#sad', '#disgusting', -0.068, 'diminish', 'reduce', 'decrease', 'decrease_music', 'low_level']
senticnet['lower_blood_pressure'] = [0.765, 0.922, 0, 0, '#joyful', '#interesting', 0.562, 'feel_better', 'renew_energy', 'feel_energized', 'feel_refreshed', 'feel_energetic']
senticnet['lower_body'] = [-0.04, 0, 0.059, 0, '#sad', '#angry', -0.033, 'human_limb', 'two_feet', 'thigh', 'ten_toes', 'body_limb']
senticnet['lower_body_temperature'] = [-0.724, 0, -0.909, 0, '#sad', '#scared', -0.544, 'faint', 'get_cold', 'cold', 'get_sick', 'sick']
senticnet['lower_down'] = [-0.294, 0.076, -0.118, 0.104, '#sad', '#scared', -0.077, 'low_down', 'low_down_volume', 'noise', 'cold_night', 'diminish']
senticnet['lower_expectation'] = [-0.964, 0, 0, -0.879, '#sad', '#disgusting', -0.614, 'erase_blackboard', 'master_skill', 'laugh_oneself', 'speak_english', 'state_fact']
senticnet['lower_floor'] = [0.039, -0.033, 0, 0, '#joyful', '#surprising', 0.024, 'first_floor', 'basement', 'foyer', 'hallway', 'lobby']
senticnet['lower_jaw'] = [0.886, -0.997, 0, 0.542, '#joyful', '#surprising', 0.808, 'jowl', 'lantern_jaw', 'mandible', 'mandibula', 'mandibular_bone']
senticnet['lower_limit'] = [-0.956, 0, 0.781, -0.732, '#sad', '#angry', -0.823, 'small_indefinite_quantity', 'small_indefinite_amount', 'peak', 'skeleton', 'extremum']
senticnet['lower_music'] = [-0.129, -0.058, 0, -0.134, '#sad', '#disgusting', -0.068, 'diminish', 'reduce', 'lower', 'decrease', 'low_level']
senticnet['lower_price'] = [0.808, 0, 0, 0.826, '#joyful', '#admirable', 0.545, 'good_price', 'transaction', 'discount', 'good_deal', 'money_transfer']
senticnet['lower_rank'] = [-0.654, 0, 0.809, -0.747, '#angry', '#disgusting', -0.737, 'low_status', 'lowness', 'backseat', 'lowliness', 'subordinateness']
senticnet['lower_standard'] = [-0.837, 0, 0, -0.77, '#sad', '#disgusting', -0.536, 'hurt_animal', 'box_ear', 'smoke_cigar', 'kill_specific_group', 'bridge_difference']
senticnet['lower_standard_live'] = [0.024, 0.167, -0.046, 0.123, '#interesting', '#admirable', 0.089, 'cum', 'find_mate', 'consideration', 'ovary', 'pregnant']
senticnet['lower_status'] = [-0.724, 0, 0.612, -0.997, '#sad', '#disgusting', -0.778, 'low_status', 'lowness', 'backseat', 'lowliness', 'subordinateness']
senticnet['lower_stress'] = [0.747, 0.855, 0, 0, '#joyful', '#interesting', 0.534, 'pleasure', 'use_energy', 'good_fun', 'stress_reduction', 'relieve_stress']
senticnet['lower_tax'] = [0.825, 0, 0, 0.703, '#joyful', '#admirable', 0.509, 'pay_toll', 'drive_upon', 'drive', 'access', 'drive_quickly']
senticnet['lower_temperature'] = [0.413, 0.239, -0.091, 0.137, '#joyful', '#interesting', 0.233, 'reduce_temperature', 'remove_heat', 'cool_room', 'rich_house', 'nice_house']
senticnet['lowerclassman'] = [-0.723, 0, 0.842, -0.82, '#angry', '#disgusting', -0.795, 'junior', 'undergraduate', 'undergrad', 'freshman', 'fresher']
senticnet['lowliness'] = [-0.579, 0, 0.53, -0.639, '#sad', '#disgusting', -0.583, 'low_status', 'lowness', 'backseat', 'inferiority', 'subordinateness']
senticnet['lowly'] = [-0.983, 0, 0.505, -0.832, '#sad', '#disgusting', -0.773, 'unskilled', 'bungled', 'botched', 'fumbling', 'bungling']
senticnet['lowness'] = [-0.752, 0.288, -0.434, -0.058, '#sad', '#scared', -0.319, 'dejectedness', 'dispiritedness', 'low-spiritedness', 'downheartedness', 'cheerless']
senticnet['loyal'] = [0, 0.811, 0, 0.808, '#interesting', '#admirable', 0.54, 'household_animal', 'house_animal', 'good_pet', 'house_pet', 'home_animal']
senticnet['loyalty'] = [0.997, 0.796, 0, 0.89, '#joyful', '#admirable', 0.894, 'devotion', 'bravery', 'adoration', 'zeal', 'charm']
senticnet['lubricant'] = [0, 0, 0, 0.882, '#admirable', '#admirable', 0.294, 'auto_mechanic', 'oil', 'fuel', 'motor', 'car_gas']
senticnet['lubrication'] = [0, 0, -0.068, 0, '#scared', '#scared', -0.023, 'greasy', 'car_gas', 'fossil_fuel', 'liquid_fuel', 'crude']
senticnet['lubricity'] = [0.842, -0.603, 0, 0.581, '#joyful', '#surprising', 0.675, 'amorousness', 'sexiness', 'amativeness', 'eroticism', 'erotism']
senticnet['lucid'] = [-0.024, 0.158, 0, 0.066, '#interesting', '#admirable', 0.067, 'hallucinate', 'night_vision', 'dream', 'imaginative', 'imaginary']
senticnet['lucid_dream'] = [0, 0.902, 0, 0.8, '#interesting', '#admirable', 0.567, 'hallucinate', 'fall_out_bed', 'dream', 'asleep', 'rest_dream']
senticnet['lucidity'] = [0.978, -0.521, 0, 0.962, '#joyful', '#admirable', 0.82, 'clearcutness', 'explicitness', 'preciseness', 'perspicuity', 'perspicuousness']
senticnet['lucidness'] = [0.8, -0.641, 0, 0.945, '#joyful', '#admirable', 0.795, 'clearcutness', 'explicitness', 'preciseness', 'perspicuity', 'perspicuousness']
senticnet['luck'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'good_luck', 'fame', 'prosperity', 'credit', 'generosity']
senticnet['luck_it'] = [0.893, -0.606, 0, 0.758, '#joyful', '#admirable', 0.752, 'try', 'assay', 'essay', 'go_for_broke', 'run_risk']
senticnet['luck_out'] = [0.61, -0.666, 0, 0.512, '#joyful', '#surprising', 0.596, 'deliver_goods', 'succeed', 'win', 'bring_home_bacon', 'come_through']
senticnet['luckiness'] = [0.808, -0.835, 0, 0.548, '#joyful', '#surprising', 0.73, 'successfulness', 'boon', 'prosperity', 'circumstances', 'blessing']
senticnet['lucky'] = [0.994, 0.862, 0, 0.899, '#joyful', '#admirable', 0.918, 'meet_another_person', 'sit_rock_chair', 'come_house', 'drink_tea', 'quit_work']
senticnet['lucrative'] = [0.998, -0.54, 0, 0.856, '#joyful', '#admirable', 0.798, 'profitable', 'moneymaking', 'gainful', 'paying', 'paid']
senticnet['lucre'] = [0.685, -0.58, 0, 0.56, '#joyful', '#surprising', 0.608, 'profit', 'net_income', 'net', 'net_profit', 'fast_buck']
senticnet['lucubrate'] = [0.777, -0.663, 0, 0.839, '#joyful', '#admirable', 0.76, 'elaborate', 'illustrate', 'expatiate', 'exposit', 'enlarge']
senticnet['ludicrous'] = [0, 0, 0.817, -0.789, '#angry', '#disgusting', -0.535, 'ridiculous', 'cockeyed', 'derisory', 'absurd', 'farcical']
senticnet['luggage'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'hand_baggage', 'baggage', 'passenger_ticket', 'ticket_counter', 'baggage_trunk']
senticnet['luggage_carrier'] = [0.073, 0.097, -0.059, -0.031, '#joyful', '#interesting', 0.027, 'newspaper_stand', 'jet_fuel', 'ticket_counter', 'aircraft_roadway', 'firetruck']
senticnet['luggage_compartment'] = [0, 0.248, -0.073, 0.121, '#interesting', '#admirable', 0.099, 'gym_locker', 'observatory', 'prison_cell', 'luggage_store', 'garage_sale']
senticnet['luggage_store'] = [0, 0.248, -0.073, 0.121, '#interesting', '#admirable', 0.099, 'gym_locker', 'observatory', 'prison_cell', 'luggage_compartment', 'garage_sale']
senticnet['luggage_trolley'] = [0.848, 0, 0, 0.921, '#joyful', '#admirable', 0.59, 'porter', 'beverage_service', 'bar_service', 'concierge', 'minibar']
senticnet['lull'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'calml', 'quiet', 'soothing', 'assuasive', 'tranquillize']
senticnet['lullaby'] = [0.845, 0.789, 0, 0.806, '#joyful', '#admirable', 0.813, 'vocal_music', 'melody', 'sound_make', 'tune', 'lyric']
senticnet['lumber'] = [0.024, -0.046, 0, 0, '#joyful', '#surprising', 0.023, 'stump', 'plank', 'timber', 'wood_pulp', 'mahogany']
senticnet['lumberyard'] = [-0.075, 0.228, 0.019, 0.089, '#interesting', '#admirable', 0.074, 'home_depot', 'carpet_store', 'furniture_store', 'front_porch', 'shoe_shop']
senticnet['luminance'] = [0.969, -0.873, 0, 0.687, '#joyful', '#surprising', 0.843, 'glow', 'illumination', 'incandescence', 'luminescence', 'illuminance']
senticnet['luminescence'] = [-0.925, 0, 0.734, -0.51, '#sad', '#angry', -0.723, 'chemiluminescence', 'light', 'bioluminescence', 'visible_light', 'visible_radiation']
senticnet['luminosity'] = [0.897, -0.745, 0, 0.833, '#joyful', '#admirable', 0.825, 'glow', 'illumination', 'incandescence', 'luminescence', 'illuminance']
senticnet['luminousness'] = [0.693, -0.678, 0, 0.508, '#joyful', '#surprising', 0.626, 'glow', 'illumination', 'incandescence', 'luminescence', 'illuminance']
senticnet['lummox'] = [0, 0, -0.756, -0.851, '#scared', '#disgusting', -0.536, 'oaf', 'clod', 'goon', 'stumblebum', 'lout']
senticnet['lump'] = [-0.926, 0, 0.783, -0.511, '#sad', '#angry', -0.74, 'clot', 'coagulum', 'gob', 'clew', 'agglomeration']
senticnet['lumpy'] = [-0.737, 0, 0.904, -0.531, '#sad', '#angry', -0.724, 'acromegalic', 'shapeless', 'unshapely', 'deformed', 'malformed']
senticnet['luna_park'] = [0.089, -0.18, 0.037, -0.061, '#joyful', '#surprising', 0.057, 'balloon', 'ballon', 'fielder', 'kite', 'blimp']
senticnet['lunacy'] = [0.931, -0.847, 0, 0.829, '#joyful', '#surprising', 0.869, 'folly', 'buffoonery', 'craziness', 'indulgence', 'shtik']
senticnet['lunate_bone'] = [-0.744, 0, 0.598, -0.756, '#sad', '#disgusting', -0.699, 'carpal', 'semilunar_bone', 'carpal_bone', 'triquetral', 'triquetral_bone']
senticnet['lunatic'] = [-0.648, 0, 0.781, -0.743, '#angry', '#disgusting', -0.724, 'weirdo', 'crazy', 'loony', 'looney', 'nutcase']
senticnet['lunch'] = [0.078, 0, 0, 0, '#joyful', '#joyful', 0.026, 'cafe', 'buy_sandwich', 'eat_food', 'buy_food', 'finish_job']
senticnet['lunch_box'] = [0, 0, 0, 0.93, '#admirable', '#admirable', 0.31, 'yogurt', 'ferment_beverage', 'healthy_drink', 'ice_cream', 'healthy_snack']
senticnet['lunch_break'] = [0.776, 0.721, 0, 0, '#joyful', '#interesting', 0.499, 'employment', 'prepare_event', 'dig_ground', 'work', 'become_wage-slave']
senticnet['luncheon_voucher'] = [0.921, -0.571, 0, 0.962, '#joyful', '#admirable', 0.818, 'book_token', 'meal_ticket', 'coupon', 'twofer', 'commercial_document']
senticnet['lung'] = [0, 0.737, 0, 0.829, '#interesting', '#admirable', 0.522, 'atmosphere', 'bird_fly', 'thunder_storm', 'air_breathe', 'breathe']
senticnet['lung_cancer'] = [0.048, -0.034, -0.055, -0.149, '#scared', '#disgusting', -0.041, 'smoke', 'smoke_tobacco', 'cigar', 'cigarette_smoke', 'tobacco_product']
senticnet['lunge'] = [-0.056, 0.119, -0.103, 0.159, '#interesting', '#admirable', 0.04, 'shrug', 'push', 'progress', 'advance', 'lift_object']
senticnet['lunitidal_interval'] = [0.861, -0.788, 0, 0.911, '#joyful', '#admirable', 0.853, 'round', 'pause', 'space', 'time_interval', 'break']
senticnet['lunkhead'] = [-0.737, 0, 0.624, -0.652, '#sad', '#disgusting', -0.671, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['lunula'] = [0, 0.097, 0, 0.085, '#interesting', '#admirable', 0.061, 'leave_hand', 'arm_part', 'cuticle', 'ten_fingers', 'five_fingers']
senticnet['lurch'] = [-0.647, 0, 0.717, -0.983, '#angry', '#disgusting', -0.782, 'debacle', 'licking', 'whitewash', 'finish', 'failure']
senticnet['lure'] = [0.02, 0.162, 0, 0.062, '#interesting', '#admirable', 0.081, 'catch', 'trap', 'ambush', 'bait_trap', 'decoy']
senticnet['lurking_place'] = [0.803, -0.893, 0, 0.94, '#surprising', '#admirable', 0.879, 'hiding_place', 'spot', 'drop', 'hideaway', 'den']
senticnet['luscious'] = [0.962, -0.898, 0, 0, '#joyful', '#surprising', 0.62, 'toothsome', 'delectable', 'juicy', 'red-hot', 'voluptuous']
senticnet['lush'] = [0.556, -0.791, 0, 0.755, '#surprising', '#admirable', 0.701, 'rummy', 'alcoholic', 'alky', 'dipsomaniac', 'boozer']
senticnet['lust'] = [0, 0, 0.909, -0.774, '#angry', '#disgusting', -0.561, 'love', 'love_another_person', 'beloved', 'passion', 'sexuality']
senticnet['luster'] = [0.65, -0.618, 0, 0.703, '#joyful', '#admirable', 0.657, 'gleaming', 'effulgence', 'polish', 'glow', 'burnish']
senticnet['lustfulness'] = [0.718, -0.726, 0, 0.952, '#surprising', '#admirable', 0.799, 'love', 'aphrodisia', 'lecherousness', 'concupiscence', 'amorousness']
senticnet['lustrous'] = [0.577, -0.696, 0, 0.645, '#surprising', '#admirable', 0.639, 'shining', 'polished', 'shiny', 'bright', 'burnished']
senticnet['lusus_naturae'] = [-0.938, 0, 0.544, -0.778, '#sad', '#disgusting', -0.753, 'mutant', 'variation', 'sport', 'leviathan', 'mutation']
senticnet['luxuria'] = [0.69, -0.644, 0, 0.825, '#joyful', '#admirable', 0.72, 'lust', 'mortal_sin', 'sinning', 'pride', 'superbia']
senticnet['luxuriant'] = [0.558, -0.905, 0, 0.736, '#surprising', '#admirable', 0.733, 'luxurious', 'indulgent', 'sybaritic', 'voluptuary', 'gay']
senticnet['luxuriate'] = [0.547, -0.947, 0, 0.74, '#surprising', '#admirable', 0.745, 'sap', 'expend', 'indulge', 'use_up', 'spend']
senticnet['luxurious'] = [0.558, -0.905, 0, 0.736, '#surprising', '#admirable', 0.733, 'indulgent', 'luxuriant', 'sybaritic', 'voluptuary', 'gay']
senticnet['luxury'] = [0.757, 0.882, 0, 0.78, '#interesting', '#admirable', 0.806, 'riches', 'immoral', 'richness', 'fame', 'wealthy']
senticnet['lye'] = [0.096, 0, 0, 0, '#joyful', '#joyful', 0.032, 'bubbly', 'clean_agent', 'lather', 'cleanser', 'foam']
senticnet['lyme_disease'] = [-0.436, -0.143, -0.068, -0.365, '#sad', '#disgusting', -0.242, 'brain_tumor', 'suffer_fool', 'lose_team', 'cause_suffer', 'disrespect']
senticnet['lymph'] = [0.737, 0.793, 0, 0, '#joyful', '#interesting', 0.51, 'breast_pocket', 'exoskeleton', 'forehead', 'toward', 'squint']
senticnet['lymphedema'] = [-0.998, 0, 0.605, -0.764, '#sad', '#disgusting', -0.789, 'angioedema', 'atrophedema', 'giant_hives', 'periodic_edema', 'dropsy']
senticnet['lynx'] = [0, -0.977, 0, 0, '#surprising', '#surprising', 0.326, 'mountain_lion', 'skunk', 'lion', 'tiger', 'cougar']
senticnet['lyophilization'] = [-0.641, 0, 0.612, -0.848, '#sad', '#disgusting', -0.7, 'chilling', 'frost', 'freeze', 'icing', 'cooling']
senticnet['lyophilized'] = [0.789, -0.58, 0, 0.715, '#joyful', '#admirable', 0.695, 'desiccated', 'aged', 'preserved', 'cured', 'candied']
senticnet['lyrate_leaf'] = [-0.666, 0, 0.971, -0.753, '#angry', '#disgusting', -0.797, 'simple_leaf', 'needle', 'elliptic_leaf', 'hastate_leaf', 'obovate_leaf']
senticnet['lyric'] = [0.091, -0.032, 0.058, 0.077, '#joyful', '#admirable', 0.047, 'lyrics', 'melody', 'piece_of_music', 'song_lyric', 'rhythm']
senticnet['lyrical'] = [0.704, -0.502, 0, 0.923, '#joyful', '#admirable', 0.71, 'mellifluous', 'mellisonant', 'dulcet', 'melodic', 'honeyed']
senticnet['lyricism'] = [0.609, -0.615, 0, 0.592, '#joyful', '#surprising', 0.605, 'spirit', 'rabidity', 'rabidness', 'sprightliness', 'ebullience']
senticnet['lyrics'] = [0.071, -0.01, 0.048, 0.078, '#joyful', '#admirable', 0.037, 'song_lyric', 'melody', 'lyric', 'piece_of_music', 'song']
senticnet['lysergic_acid_diethylamide'] = [-0.735, 0, 0.944, -0.942, '#angry', '#disgusting', -0.874, 'psychedelic_drug', 'mescaline', 'peyote', 'phencyclidine', 'drug']
senticnet['machete'] = [0.951, 0.809, 0, 0, '#joyful', '#interesting', 0.587, 'dagger', 'cut_tool', 'blade', 'vaccination', 'knife']
senticnet['machilid'] = [-0.703, 0, 0.994, -0.99, '#angry', '#disgusting', -0.896, 'insect', 'bristletail', 'silverfish', 'jumping_bristletail', 'thysanuran_insect']
senticnet['machine'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'biological_machine', 'social_creature', 'live_creature', 'live_object', 'alive']
senticnet['machine_gun'] = [0.939, 0.834, 0, 0, '#joyful', '#interesting', 0.591, 'handgun', 'weapon', 'firearm', 'cannon', 'rifle']
senticnet['machine_metal'] = [0, 0.161, 0, 0.174, '#interesting', '#admirable', 0.112, 'bridge_river', 'travel_abroad', 'board_plane', 'travel_by_airplane', 'carry_book']
senticnet['machine_part'] = [-0.091, 0, 0, 0, '#sad', '#sad', -0.03, 'market_product', 'eat_pasta', 'use_drug', 'speak_english', 'forward_email']
senticnet['machine_transportation'] = [0, -0.01, 0, 0.065, '#surprising', '#admirable', 0.025, 'big_car', 'large_car', 'long_car', 'car_truck', 'form_of_transportation']
senticnet['machinery'] = [0, 0.774, 0, 0.844, '#interesting', '#admirable', 0.539, 'mechanical_device', 'move_part', 'machine', 'work_well', 'make_car']
senticnet['machinist'] = [0, 0.105, -0.053, 0.068, '#interesting', '#admirable', 0.04, 'mechanic', 'manufacturer', 'factory', 'machinery', 'make_car']
senticnet['mackerel_shark'] = [-0.54, 0, 0.983, -0.911, '#angry', '#disgusting', -0.811, 'elasmobranch', 'selachian', 'hammerhead', 'cow_shark', 'shark']
senticnet['macrophage'] = [0.702, -0.524, 0, 0.958, '#joyful', '#admirable', 0.728, 'somatic_cell', 'vegetative_cell', 'fixed_phagocyte', 'phagocyte', 'free_phagocyte']
senticnet['macular_degeneration'] = [0.671, -0.561, 0, 0.685, '#joyful', '#admirable', 0.639, 'degeneration', 'attack', 'obsolescence', 'process', 'physical_process']
senticnet['maculated'] = [0, 0, -0.788, -0.875, '#scared', '#disgusting', -0.554, 'foul', 'sully', 'defile', 'tarnish', 'stain']
senticnet['macule'] = [-0.662, 0, 0.911, -0.993, '#angry', '#disgusting', -0.855, 'liver_spot', 'spot', 'freckle', 'lentigo', 'plague_spot']
senticnet['macushla'] = [0.591, -0.769, 0, 0.66, '#surprising', '#admirable', 0.673, 'darling', 'pet', 'favorite', 'favourite', 'dearie']
senticnet['mad'] = [0, 0, 0.839, -0.875, '#angry', '#disgusting', -0.571, 'rage', 'resentment', 'temper', 'malice', 'animosity']
senticnet['mad_cow_disease'] = [0, 0, -0.779, -0.7, '#scared', '#disgusting', -0.493, 'toothache', 'diarrhoea', 'ice_cream_melt', 'flab', 'bad_hair_day']
senticnet['mad_person'] = [-0.927, 0, 0.553, -0.913, '#sad', '#disgusting', -0.798, 'mad_scientist', 'fool', 'mad', 'crazy', 'mental_disease']
senticnet['mad_scientist'] = [-0.986, 0, 0.349, -0.905, '#sad', '#disgusting', -0.747, 'fool', 'mad', 'crazy', 'mental_disease', 'mental_problem']
senticnet['madam'] = [0.964, -0.811, 0, 0.926, '#joyful', '#admirable', 0.9, 'girl', 'gentlewoman', 'grande_dame', 'dame', 'lady']
senticnet['madcap'] = [0.631, -0.877, 0, 0.887, '#surprising', '#admirable', 0.798, 'impulsive', 'tearaway', 'hotheaded', 'incautious', 'impetuous']
senticnet['maddened'] = [-0.137, 0.145, 0.624, -0.638, '#angry', '#disgusting', -0.418, 'enraged', 'furious', 'infuriated', 'angered', 'indignantly']
senticnet['maddening'] = [-0.127, 0.13, 0.647, -0.648, '#angry', '#disgusting', -0.431, 'infuriate', 'exasperating', 'infuriating', 'furiously', 'dudgeon']
senticnet['made_of_glass'] = [0.998, 0, 0, 0.871, '#joyful', '#admirable', 0.623, 'drink_wine', 'wine_opener', 'good_wine', 'wine_glass', 'wine_bottle']
senticnet['made_out_of_plastic'] = [-0.054, 0.092, 0, 0.132, '#interesting', '#admirable', 0.057, 'recycle', 'thrown_out', 'find_car', 'make_out_cloth', 'find_kitchen']
senticnet['madhouse'] = [-0.673, 0, 0.931, -0.772, '#angry', '#disgusting', -0.792, 'asylum', 'mental_hospital', 'psychiatric_hospital', 'mental_institution', 'mental_home']
senticnet['madman'] = [-0.061, -0.003, -0.092, 0, '#sad', '#scared', -0.05, 'capoeira', 'trouble', 'agony', 'cause_problem', 'river_stream']
senticnet['madnep'] = [0.861, -0.879, 0, 0.597, '#joyful', '#surprising', 0.779, 'herb', 'cultivated_parsnip', 'wild_parsnip', 'pastinaca_sativa', 'herbaceous_plant']
senticnet['madness'] = [0, 0, -0.92, -0.884, '#scared', '#disgusting', -0.601, 'temper', 'disgust', 'offend', 'despise', 'animosity']
senticnet['madonna'] = [0.057, 0.141, -0.064, 0.162, '#interesting', '#admirable', 0.099, 'belongings', 'singer', 'personal_item', 'guarantee', 'stuff']
senticnet['mafia'] = [-0.856, 0, 0.749, -0.998, '#sad', '#disgusting', -0.868, 'suck_up', 'toady', 'bootlick', 'kowtow', 'court_favor']
senticnet['magazine'] = [0, 0.076, 0, 0.066, '#interesting', '#admirable', 0.047, 'library', 'old_testament', 'cook_book', 'a_lot_of_books', 'librarian']
senticnet['magazine_newspaper'] = [0.021, 0, 0, 0.076, '#joyful', '#admirable', 0.032, 'newspaper_story', 'newspaper_write', 'newspaper_article', 'article', 'editorial']
senticnet['magazine_rack'] = [0.886, 0, 0, 0.964, '#joyful', '#admirable', 0.617, 'dentist_chair', 'sofa', 'couch', 'sofa_bed', 'mattress']
senticnet['maggot'] = [0, 0, 0.109, -0.034, '#angry', '#disgusting', -0.048, 'small_fly', 'insect', 'annoy_bug', 'parasite', 'tiny_insect']
senticnet['magic'] = [0.793, -0.953, 0, 0, '#joyful', '#surprising', 0.582, 'play_ping_pong', 'musical_device', 'school_play', 'stunt', 'family_activity']
senticnet['magic_spell'] = [-0.829, 0, 0.72, -0.535, '#sad', '#angry', -0.695, 'invocation', 'charm', 'spell', 'conjuration', 'magical_spell']
senticnet['magic_trick'] = [0.818, 0.913, 0, 0.825, '#interesting', '#admirable', 0.852, 'greeting', 'blackjack', 'pass_card', 'credit', 'play_blackjack']
senticnet['magical'] = [0, 0.71, 0, 0.763, '#interesting', '#admirable', 0.491, 'character', 'play_person', 'personality_trait', 'illusion', 'fool']
senticnet['magical_spell'] = [-0.829, 0, 0.72, -0.535, '#sad', '#angry', -0.695, 'invocation', 'charm', 'spell', 'magic_spell', 'conjuration']
senticnet['magician'] = [0, 0.918, 0, 0, '#interesting', '#interesting', 0.306, 'partygoer', 'invitation', 'halloween', 'clown', 'alcohol']
senticnet['magma'] = [0, 0, -0.925, 0, '#scared', '#scared', -0.308, 'water_flow', 'wind_water', 'water_stream', 'waterway', 'lava']
senticnet['magnanimous'] = [0.075, 0.252, -0.147, 0.186, '#interesting', '#admirable', 0.122, 'tall_play_basketball', 'niceness', 'altruistic', 'kindness', 'type_of_bear']
senticnet['magnate'] = [0, 0, -0.747, -0.893, '#scared', '#disgusting', -0.547, 'king', 'baron', 'business_leader', 'mogul', 'big_businessman']
senticnet['magnesium'] = [-0.03, 0, 0, -0.085, '#sad', '#disgusting', -0.038, 'lithium', 'mineral', 'potassium', 'iodine', 'manganese']
senticnet['magnet'] = [0.057, 0, 0.012, 0.08, '#joyful', '#admirable', 0.042, 'rust', 'foil', 'tin', 'thin_metal', 'aluminium']
senticnet['magnetic'] = [0.102, 0.078, 0, 0.087, '#joyful', '#admirable', 0.089, 'gold', 'platinum', 'iron_ore', 'silver', 'adjustable']
senticnet['magnetic_attraction'] = [0.538, -0.721, 0, 0.606, '#surprising', '#admirable', 0.622, 'attraction', 'opposites_attract_each_other', 'complementary', 'attract', 'magnetism']
senticnet['magnetic_force'] = [0.538, -0.721, 0, 0.606, '#surprising', '#admirable', 0.622, 'magnetic_attraction', 'magnetism', 'opposites_attract_each_other', 'complementary', 'attraction']
senticnet['magnetism'] = [0.08, 0, 0.035, 0.093, '#joyful', '#admirable', 0.046, 'elements', 'silver', 'strong_material', 'tin_aluminium', 'physical_phenomenon']
senticnet['magnificence'] = [0.85, -0.724, 0, 0.989, '#joyful', '#admirable', 0.854, 'excellence', 'stateliness', 'loftiness', 'expansivity', 'expansiveness']
senticnet['magnificent'] = [0.915, 0, 0.724, 0.952, '#joyful', '#admirable', 0.381, 'influence_worldwide', 'celebrate', 'olympic_game', 'international_affair', 'world_event']
senticnet['magnifier'] = [0.057, 0, 0.012, 0.08, '#joyful', '#admirable', 0.042, 'see_better', 'glasses', 'become_gigantic', 'magnify', 'contact_lens']
senticnet['magnify'] = [0.057, 0, 0.012, 0.08, '#joyful', '#admirable', 0.042, 'see_better', 'glasses', 'become_gigantic', 'magnifier', 'contact_lens']
senticnet['magnify_glass'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'rub_two_stick_together', 'strike_match', 'light_cigarette', 'light_match', 'cigarette_lighter']
senticnet['magnitude'] = [0.052, 0.109, 0.086, 0.116, '#interesting', '#admirable', 0.064, 'size', 'unit', 'ounce', 'measure', 'measurement']
senticnet['magnolia'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'tree', 'willow', 'evergreen', 'elm', 'cedar']
senticnet['magus'] = [0.594, -0.549, 0, 0.518, '#joyful', '#surprising', 0.554, 'exorcist', 'enchanter', 'necromancer', 'sorceress', 'witch_doctor']
senticnet['mahogany'] = [0, -0.072, 0, 0, '#surprising', '#surprising', 0.024, 'lumber', 'plank', 'board', 'cedar', 'birch']
senticnet['maid'] = [-0.626, 0, 0.649, -0.673, '#angry', '#disgusting', -0.649, 'handmaid', 'handmaiden', 'chambermaid', 'lady_maid', 'parlormaid']
senticnet['maiden'] = [-0.81, 0, 0.885, -0.923, '#angry', '#disgusting', -0.873, 'miss', 'girl', 'damsel', 'demoiselle', 'damoiselle']
senticnet['mail'] = [0, 0.975, 0, 0.857, '#interesting', '#admirable', 0.611, 'send', 'food_delivery', 'delivery', 'postal_service', 'package']
senticnet['mail_delivery'] = [-0.025, 0.122, -0.047, 0.188, '#interesting', '#admirable', 0.079, 'delivery', 'mail', 'post_notice', 'hitch', 'placard']
senticnet['mail_fraud'] = [-0.914, 0, 0.85, -0.766, '#sad', '#angry', -0.843, 'fraud_in_fact', 'positive_fraud', 'fraud', 'swindle', 'rig']
senticnet['mail_package'] = [0, -0.124, 0, 0.105, '#surprising', '#admirable', 0.076, 'desk_drawer', 'hang_wall', 'stationery_store', 'postoffice', 'desk']
senticnet['mailbox'] = [0.06, 0, 0, 0.059, '#joyful', '#admirable', 0.04, 'traffic_signal', 'electrical_circuit', 'parking_lot', 'hand_luggage', 'message_board']
senticnet['mailed'] = [-0.897, 0, 0.945, -0.894, '#sad', '#angry', -0.912, 'bulletproof', 'armored', 'lightly_armored', 'lightly_armoured', 'scaled']
senticnet['mailman'] = [0.031, 0, 0, 0.093, '#joyful', '#admirable', 0.041, 'letter_slot', 'postal_counter', 'mailbox', 'letter_scale', 'envelope']
senticnet['maim'] = [-0.143, -0.025, -0.143, -0.147, '#sad', '#scared', -0.136, 'cause_injury', 'stab', 'bloody', 'terminate', 'injure']
senticnet['maimer'] = [-0.736, 0, 0.55, -0.753, '#sad', '#disgusting', -0.68, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['main'] = [0.02, 0.109, -0.051, 0.091, '#interesting', '#admirable', 0.056, 'military_order', 'native_american', 'rank', 'general', 'chief']
senticnet['main_artery'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'artery', 'skeletal_system', 'groin', 'neck', 'muscle']
senticnet['main_course'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'stew', 'cream_soup', 'soup', 'ragout', 'goulash']
senticnet['main_entrance'] = [0.028, 0, 0, 0.051, '#joyful', '#admirable', 0.026, 'entranceway', 'doorway', 'entrance', 'entryway', 'corridor']
senticnet['main_traffic_artery'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'traffic_artery', 'thruway', 'flight_terminal', 'round_trip_ticket', 'semi-truck']
senticnet['mainstay'] = [-0.775, 0, 0.967, -0.705, '#sad', '#angry', -0.816, 'champion', 'friend', 'supporter', 'protagonist', 'admirer']
senticnet['maintain'] = [0, 0.217, -0.107, 0.199, '#interesting', '#admirable', 0.103, 'hold_onto', 'keep_fresh', 'take_care', 'keep_safe', 'retain']
senticnet['maintain_balance'] = [0.764, 0, 0, 0.865, '#joyful', '#admirable', 0.543, 'take_photo', 'fall', 'fall_over', 'go_downhill', 'fall_butt']
senticnet['maintain_good_health'] = [0, 0.809, 0, 0.878, '#interesting', '#admirable', 0.562, 'stay_healthy', 'do_exercise', 'eat_healthily', 'eat_well', 'stay_fit']
senticnet['maintain_health'] = [0, 0.814, 0, 0.775, '#interesting', '#admirable', 0.53, 'check_health', 'determine_health', 'stay_well', 'diagnose_illness', 'eat_well']
senticnet['maintain_muscle_strength'] = [0.84, 0.76, 0, 0.894, '#joyful', '#admirable', 0.831, 'keep_skin_healthy', 'stay_healthy', 'stay_fit', 'maintain_good_health', 'eat_healthily']
senticnet['maintain_relationship'] = [0.792, 0.803, 0, 0.646, '#joyful', '#interesting', 0.747, 'relay_information', 'share_information', 'spread_knowledge', 'understand_culture', 'share_knowledge']
senticnet['maintenance'] = [0, 0.173, -0.106, 0.173, '#interesting', '#admirable', 0.08, 'clean_often', 'neatness', 'responsible', 'make_look_good', 'tidy_up']
senticnet['maize'] = [0, 0.074, 0.032, 0.058, '#interesting', '#admirable', 0.033, 'wheat_corn', 'kernel', 'farm_plant', 'wheat_rice', 'wheat']
senticnet['majestic'] = [0.078, 0.111, 0.014, 0.221, '#interesting', '#admirable', 0.132, 'beautiful_well_useful', 'big', 'large', 'tall', 'driven_person']
senticnet['major'] = [0.921, 0, 0, 0.961, '#joyful', '#admirable', 0.627, 'president', 'chief', 'respect', 'act_wisely', 'write_law']
senticnet['major_affective_disorder'] = [-0.656, 0, 0.915, -0.852, '#angry', '#disgusting', -0.808, 'manic_disorder', 'bipolar_disorder', 'manic_depression', 'manic_depressive_illness', 'depression']
senticnet['major_city'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'jerusalem', 'jewish_community', 'large_city', 'big_city', 'vatican']
senticnet['major_depressive_episode'] = [-0.786, 0, 0.918, -0.963, '#angry', '#disgusting', -0.889, 'unipolar_depression', 'depression', 'depressive_disorder', 'clinical_depression', 'involutional_depression']
senticnet['majority'] = [0.059, 0.105, -0.069, 0.099, '#interesting', '#admirable', 0.065, 'clique', 'big_group', 'multitude', 'group', 'several_people']
senticnet['make'] = [0.127, 0.069, 0.029, 0.16, '#joyful', '#admirable', 0.109, 'bourgeois', 'construct', 'set_down', 'basic_human_need', 'build_process']
senticnet['make_a_lot_of_money'] = [0.97, 0.729, 0, 0.946, '#joyful', '#admirable', 0.882, 'become_famous', 'become_rich', 'money', 'good_job', 'great_carrier']
senticnet['make_a_lot_of_noise'] = [-0.077, -0.065, 0.037, -0.099, '#sad', '#disgusting', -0.049, 'compose_music', 'make_noise', 'sound_alarm', 'strum', 'make_drawing']
senticnet['make_anger'] = [-0.133, -0.121, 0.15, -0.32, '#angry', '#disgusting', -0.161, 'chew_tobacco', 'lean_over', 'moan', 'blow', 'fall_down_flight_stair']
senticnet['make_angry'] = [-0.944, 0, 0.129, -0.971, '#sad', '#disgusting', -0.681, 'trouble', 'anger', 'angry_man', 'annoy', 'fight']
senticnet['make_apple'] = [0.105, 0.226, -0.083, 0.176, '#interesting', '#admirable', 0.141, 'keep_someone_out', 'hold_onto', 'glass', 'drink_cup', 'retention']
senticnet['make_appointment'] = [-0.082, 0, 0, -0.083, '#sad', '#disgusting', -0.055, 'schedule_appointment', 'put_nice_clothes', 'schedule_appointment_doctor', 'go_hair_salon', 'make_doctor_appointment']
senticnet['make_appointment_with_doctor'] = [0, 0, -0.922, 0, '#scared', '#scared', -0.307, 'doctor_appointment', 'call_doctor', 'make_doctor_appointment', 'find_doctor', 'turn_head_cough']
senticnet['make_arrangement'] = [-0.065, 0.176, -0.07, 0.125, '#interesting', '#admirable', 0.055, 'schedule_time', 'decide_want_go', 'pack_luggage', 'talk_to_travel_agent', 'decide_to_go']
senticnet['make_assumption'] = [0.085, 0.101, 0, 0.235, '#interesting', '#admirable', 0.14, 'look_scary', 'elusive', 'morality', 'type_of_credit_card', 'free_stuff']
senticnet['make_baby'] = [0.97, 0.729, 0, 0.946, '#joyful', '#admirable', 0.882, 'become_pregnant', 'give_birth_child', 'sexual_intercourse', 'find_partner', 'make_love']
senticnet['make_ball'] = [0.905, 0.892, 0, 0, '#joyful', '#interesting', 0.599, 'make_coat', 'tie', 'overcoat', 'make_out_leather', 't-shirt']
senticnet['make_beautiful'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'creative_expression', 'pastime', 'self_expression', 'date_activity', 'artistic_expression']
senticnet['make_beautiful_music'] = [0.821, 0.98, 0, 0.869, '#interesting', '#admirable', 0.89, 'make_music', 'produce_musical_sound', 'create_music', 'play_stringed_instrument', 'play_music']
senticnet['make_believe'] = [0.821, 0.98, 0, 0.869, '#interesting', '#admirable', 0.89, 'fun_child', 'play', 'child_play', 'make_child_laugh', 'delight_audience']
senticnet['make_better'] = [0.973, 0.709, 0, 0.827, '#joyful', '#admirable', 0.836, 'make_right', 'improve', 'again_and_again', 'proposition', 'tell_everyone']
senticnet['make_better_world'] = [0.643, 0.69, 0, 0.874, '#interesting', '#admirable', 0.736, 'give_assistance', 'create_help_other_person', 'forgive', 'please_parent', 'comfort_friend']
senticnet['make_big'] = [0.952, 0.842, 0, 0.878, '#joyful', '#admirable', 0.891, 'enlarge', 'flourish', 'get_big', 'get_large', 'expand']
senticnet['make_book'] = [0, 0.077, 0, 0.068, '#interesting', '#admirable', 0.048, 'document', 'file', 'paper_write', 'readable', 'newspaper_write']
senticnet['make_bow'] = [0.05, 0.114, -0.079, 0.131, '#interesting', '#admirable', 0.072, 'towel_off', 'dry_off', 'love_oneself', 'find_woman', 'sex']
senticnet['make_bread'] = [0.732, -0.907, 0, 0, '#joyful', '#surprising', 0.546, 'bake_cake', 'cook_dinner', 'cook_meal', 'cook_curry', 'follow_recipe']
senticnet['make_breakfast'] = [0.769, 0, 0, 0, '#joyful', '#joyful', 0.256, 'appetite', 'enjoy_meal', 'put_food_into_mouth', 'prepare_meal', 'prepare_breakfast']
senticnet['make_building'] = [0, 0.081, 0.018, 0.133, '#interesting', '#admirable', 0.065, 'home_build', 'construction', 'construct_building', 'find_suburb', 'architect']
senticnet['make_cake'] = [0.061, 0, 0, 0.078, '#joyful', '#admirable', 0.046, 'fry_fish', 'fry_egg', 'season_meal', 'season_dish', 'fry_chicken']
senticnet['make_call'] = [0, 0, 0, 0.141, '#admirable', '#admirable', 0.047, 'phone_conversation', 'use_phone', 'telephone_ring', 'call', 'say']
senticnet['make_campfire'] = [0, 0, -0.849, -0.858, '#scared', '#disgusting', -0.569, 'start_flame_fire', 'play_fire', 'light_fire', 'start_fire', 'strike_match']
senticnet['make_car'] = [0, 0.096, 0, 0.123, '#interesting', '#admirable', 0.073, 'make_goods', 'machinery', 'make_product', 'make_stuff', 'weld']
senticnet['make_card'] = [-0.102, 0, 0, 0, '#sad', '#sad', -0.034, 'write_computer_program', 'laugh_oneself', 'book_reservation', 'mind_store', 'come_house']
senticnet['make_change'] = [-0.1, 0.272, -0.147, 0.15, '#interesting', '#admirable', 0.058, 'give_change', 'settle_bill', 'pay_back', 'owe_money', 'collect_money']
senticnet['make_cheese'] = [-0.035, -0.046, 0.102, -0.113, '#angry', '#disgusting', -0.068, 'unlimited', 'limitless', 'star_planet', 'orbit_earth', 'void']
senticnet['make_child_laugh'] = [0.05, -0.108, 0, 0, '#joyful', '#surprising', 0.053, 'amuse_child', 'child_play', 'make_believe', 'play_marble', 'play']
senticnet['make_choice'] = [-0.081, 0.283, -0.094, 0.17, '#interesting', '#admirable', 0.093, 'select', 'make_decision', 'decision', 'decide', 'consider']
senticnet['make_clean'] = [-0.664, 0, 0.663, -0.728, '#sad', '#disgusting', -0.685, 'scavenge', 'vacuum', 'preen', 'modify', 'dust']
senticnet['make_clear'] = [0.548, -0.867, 0, 0.938, '#surprising', '#admirable', 0.784, 'elaborate', 'clear', 'crystallize', 'clear_up', 'elucidate']
senticnet['make_cloth'] = [0, -0.04, 0.126, -0.054, '#angry', '#disgusting', -0.047, 'make_shirt', 'make_clothes', 'cloth', 'article_clothes', 'apparel']
senticnet['make_clothes'] = [0.025, -0.057, 0.129, -0.066, '#angry', '#disgusting', -0.038, 'make_cloth', 'make_dress', 'make_shirt', 'clothes', 'apparel']
senticnet['make_coat'] = [0.026, -0.061, 0.094, -0.065, '#angry', '#disgusting', -0.024, 'overcoat', 'jacket', 'coat', 'outerwear', 'winter_clothes']
senticnet['make_coffee'] = [0, 0.874, 0, 0, '#interesting', '#interesting', 0.291, 'piss', 'relieve_oneself', 'make_ice', 'wash_dish', 'water_plant']
senticnet['make_comfortable'] = [0.97, 0.753, 0, 0.832, '#joyful', '#admirable', 0.852, 'sleep_back', 'sit_rock_chair', 'embarrass_oneself', 'share_secret', 'lift_spirit']
senticnet['make_commitment'] = [0, 0.874, 0, 0, '#interesting', '#interesting', 0.291, 'make_promise', 'honest', 'keep_relationship', 'keep_promise', 'trust']
senticnet['make_comparison'] = [0.972, 0.851, 0, 0, '#joyful', '#interesting', 0.608, 'put_bid', 'come_warranty', 'customer_service', 'define', 'comparison']
senticnet['make_compost'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'fancy_girl', 'date_girl', 'wedge_door', 'kiss_girl', 'become_man']
senticnet['make_confused'] = [0, -0.038, -0.079, -0.179, '#scared', '#disgusting', -0.073, 'make_drunk', 'cloud_judgment', 'set_on_fire', 'confuse', 'drug']
senticnet['make_connection'] = [0, -0.045, 0.053, -0.086, '#angry', '#disgusting', -0.031, 'keep_job', 'have_something_to_do', 'career_advancement', 'make_money', 'responsible']
senticnet['make_contact'] = [0.037, 0.122, -0.099, 0.215, '#interesting', '#admirable', 0.092, 'sensual', 'feel_action', 'hand_action', 'hand_movement', 'extend_arm']
senticnet['make_copy'] = [0, 0.161, 0, 0.188, '#interesting', '#admirable', 0.116, 'replicate', 'computer_command', 'imitation', 'output', 'type_of_paper']
senticnet['make_crowd_wave'] = [0.924, 0.968, 0, 0.876, '#joyful', '#interesting', 0.923, 'win_game', 'score', 'score_touchdown', 'pride', 'score_goal']
senticnet['make_cry'] = [-0.261, -0.053, -0.169, -0.165, '#sad', '#scared', -0.181, 'play_hard', 'bring_joy', 'drive_crazy', 'end_relationship', 'learn_lesson']
senticnet['make_curry'] = [0.94, -0.854, 0, 0, '#joyful', '#surprising', 0.598, 'curry_powder', 'cook_dinner', 'cook_meal', 'cook_curry', 'powder']
senticnet['make_deal'] = [-0.025, 0.188, -0.125, 0.192, '#interesting', '#admirable', 0.077, 'negotiate', 'receive_money', 'negotiation', 'monetary_gain', 'financial_transaction']
senticnet['make_deals'] = [0, 0.926, 0, 0.824, '#interesting', '#admirable', 0.583, 'see_know', 'talk_person', 'make_hotel_reservation', 'conduct_business', 'send_information']
senticnet['make_decision'] = [0, 0.953, 0, 0.81, '#interesting', '#admirable', 0.588, 'rational', 'make_choice', 'consider_option', 'arrive_conclusion', 'come_decision']
senticnet['make_difference'] = [0.201, 0.159, 0, 0.207, '#joyful', '#admirable', 0.189, 'accomplish_goal', 'reach_goal', 'make_world_better_place', 'make_good_decision', 'self_esteem']
senticnet['make_dinner'] = [0.989, 0.803, 0, 0, '#joyful', '#interesting', 0.597, 'supermarket', 'buy_grocery', 'compare_price', 'purchase_grocery', 'buy_meat']
senticnet['make_do'] = [-0.795, 0, 0.974, -0.839, '#angry', '#disgusting', -0.869, 'manage', 'make_out', 'cope', 'get_by', 'fend']
senticnet['make_doctor_appointment'] = [-0.089, 0, -0.125, -0.132, '#scared', '#disgusting', -0.115, 'schedule_appointment_doctor', 'wear_clean_underwear', 'make_appointment_with_doctor', 'doctor_appointment', 'call_doctor']
senticnet['make_drape'] = [-0.076, 0, 0.047, 0, '#sad', '#angry', -0.041, 'cover_body', 'knit_sweater', 'weave', 'tie_bow', 'organize_clothes']
senticnet['make_drawing'] = [0, 0.716, 0, 0.741, '#interesting', '#admirable', 0.486, 'backup', 'play_orchestra', 'annoy_mom', 'play_music', 'play_in_band']
senticnet['make_dress'] = [0.743, -0.893, 0, 0, '#joyful', '#surprising', 0.545, 'make_clothes', 'make_cloth', 'wear', 'dress', 'make_suit']
senticnet['make_drunk'] = [0, 0, 0, -0.827, '#disgusting', '#disgusting', -0.276, 'burn_skin', 'char', 'dry_wet_clothes', 'burn', 'cloud_judgment']
senticnet['make_easy'] = [0, 0.716, 0, 0.741, '#interesting', '#admirable', 0.486, 'backup', 'dork', 'perform_of_music', 'remember_childhood', 'make_sound']
senticnet['make_eat'] = [-0.027, 0.224, -0.07, 0.116, '#interesting', '#admirable', 0.081, 'provide_food', 'money_charge', 'satiate_hunger', 'fee', 'payment']
senticnet['make_effort'] = [-0.073, 0.18, -0.086, 0.188, '#interesting', '#admirable', 0.07, 'make_happen', 'resume', 'attempt', 'question_ask', 'obligation']
senticnet['make_egg'] = [0.03, 0, 0, 0.091, '#joyful', '#admirable', 0.04, 'part_of_meal', 'produce_egg', 'good_eat', 'nugget', 'yum']
senticnet['make_enemy'] = [-0.09, 0, -0.092, -0.205, '#scared', '#disgusting', -0.129, 'conflict', 'declare_war', 'find_enemy', 'violence', 'big_fight']
senticnet['make_error'] = [-0.276, 0.072, 0, -0.123, '#sad', '#disgusting', -0.109, 'make_mistake', 'count_finger', 'face_music', 'gather_data', 'fail_test']
senticnet['make_eye_contact'] = [0.021, 0.093, -0.069, 0.119, '#interesting', '#admirable', 0.055, 'say_hello', 'end_conversation', 'introduce_oneself', 'ask_name', 'say_hi']
senticnet['make_fabric'] = [-0.027, 0, 0.068, 0, '#sad', '#angry', -0.032, 'make_cloth', 'make_clothes', 'clothes_fabric', 'make_shirt', 'cloth_material']
senticnet['make_face'] = [-0.08, -0.04, -0.104, -0.103, '#scared', '#disgusting', -0.082, 'wave_hand', 'act_silly', 'offend_other_person', 'embarrass_oneself', 'wet_pant']
senticnet['make_factory'] = [0.039, 0.188, -0.097, 0.226, '#interesting', '#admirable', 0.119, 'build_process', 'factory_output', 'make_goods', 'make', 'make_stuff']
senticnet['make_false_accusation'] = [-0.9, 0, 0.009, -0.935, '#sad', '#disgusting', -0.615, 'tell_lie', 'lie', 'false_accusation', 'tell_untruth', 'dishonesty']
senticnet['make_fashion_statement'] = [0.742, 0, 0, 0.905, '#joyful', '#admirable', 0.549, 'stockings', 'intimate', 'robe', 'cover_leg', 'leg']
senticnet['make_feel_angry'] = [0, 0, 0.937, 0, '#angry', '#angry', -0.312, 'disappointment', 'become_angry', 'disappoint', 'sit_dark', 'silliness']
senticnet['make_feel_bad'] = [-0.146, -0.052, 0, -0.158, '#sad', '#disgusting', -0.084, 'make_noise', 'make_sound', 'annoy_neighbor', 'part_of_band', 'remember_childhood']
senticnet['make_feel_better'] = [0.99, 0.823, 0, 0.735, '#joyful', '#interesting', 0.849, 'feel_good', 'feel_satisfaction', 'good_feeling', 'happiness', 'little_hunger']
senticnet['make_feel_good'] = [0.995, 0.801, 0, 0.968, '#joyful', '#admirable', 0.921, 'feel_good_oneself', 'long_life', 'healthy', 'support_cause', 'feel_better_oneself']
senticnet['make_feel_happy'] = [0.211, -0.128, 0, -0.042, '#joyful', '#surprising', 0.099, 'give_pleasure', 'comedian', 'fun', 'enjoyable', 'get_happy']
senticnet['make_fire'] = [0.025, 0, -0.054, -0.056, '#scared', '#disgusting', -0.028, 'create_flame', 'create_fire', 'burn_finger', 'gather_wood', 'light_cigarette']
senticnet['make_fist'] = [-0.105, -0.046, 0.095, -0.331, '#sad', '#disgusting', -0.162, 'angry_emotion', 'black_eye', 'whack', 'taunt', 'arrogance']
senticnet['make_flour'] = [0.036, -0.06, 0.037, 0.05, '#surprising', '#admirable', 0.036, 'bake', 'make_grain', 'bake_food', 'pot_roast', 'eaten']
senticnet['make_food'] = [-0.026, 0.073, 0.025, 0.054, '#interesting', '#admirable', 0.025, 'cook_meal', 'make_bread', 'follow_recipe', 'cook_curry', 'cook_meat']
senticnet['make_food_taste_better'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'heat_food', 'roast_meat', 'cook_food', 'cook_rice', 'cook_hamburger']
senticnet['make_fool_of_yourself'] = [-0.906, 0, 0.3, -0.952, '#sad', '#disgusting', -0.719, 'get_drunk', 'helpless', 'feel_embarrassed', 'shameful', 'disreputable']
senticnet['make_friend'] = [0.048, -0.08, 0.036, 0, '#joyful', '#surprising', 0.031, 'meet_person', 'meet_friend', 'chit_chat', 'meet_girl', 'socialize']
senticnet['make_friend_happy'] = [0.997, 0.868, 0, 0.987, '#joyful', '#admirable', 0.951, 'say_thank_you', 'get_present', 'oral_sex', 'make_happy', 'gift']
senticnet['make_fruit'] = [0.101, 0.174, 0, 0.271, '#interesting', '#admirable', 0.182, 'serve_cold', 'tasty_good', 'delicious', 'high_calorie', 'soft_sweet']
senticnet['make_fun'] = [-0.166, -0.019, -0.176, -0.17, '#scared', '#disgusting', -0.164, 'make_others_laugh', 'laugh', 'mean_person', 'tell_others', 'satirist']
senticnet['make_furniture'] = [0.074, 0.138, 0, 0.104, '#interesting', '#admirable', 0.105, 'aesthetics', 'please_eye', 'reflect_light', 'yellow_orange', 'decorative']
senticnet['make_gesture'] = [-0.085, 0, 0.015, 0, '#sad', '#angry', -0.033, 'use_hand_gesture', 'unusual_face', 'move_tongue', 'make_unusual_face', 'share_idea']
senticnet['make_gift'] = [0.17, -0.087, 0, -0.059, '#joyful', '#surprising', 0.066, 'amuse_oneself', 'give_pleasure', 'celebrate_holiday', 'make_feel_happy', 'get_reaction']
senticnet['make_go'] = [0.021, 0.098, -0.096, 0.247, '#interesting', '#admirable', 0.09, 'run_car', 'car_steer', 'passenger_car', 'car_action', 'car_movement']
senticnet['make_goal'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'score', 'victorious', 'lift_car', 'silly', 'win']
senticnet['make_gold'] = [0, 0.08, 0, 0.246, '#interesting', '#admirable', 0.109, 'jewel', 'piece_of_jewelry', 'bell_sound', 'get_rich', 'jewelry']
senticnet['make_good_decision'] = [0.256, 0.174, 0, 0.296, '#joyful', '#admirable', 0.242, 'feel_important', 'feel_smart', 'others_understand', 'good_memory', 'mentally_challenged']
senticnet['make_good_impression'] = [0.082, 0, -0.068, 0.129, '#joyful', '#admirable', 0.048, 'look_nice', 'improve_appearance', 'hygiene', 'impress_other_person', 'social_acceptance']
senticnet['make_goods'] = [0, 0.125, 0, 0.18, '#interesting', '#admirable', 0.102, 'make_product', 'make_stuff', 'assembly_line', 'build_process', 'manufacture']
senticnet['make_grain'] = [0.752, -0.959, 0, 0, '#joyful', '#surprising', 0.57, 'bake_food', 'eaten', 'make_flour', 'bake', 'require_good_health']
senticnet['make_hair_look_nice'] = [-0.025, 0, 0.068, 0, '#sad', '#angry', -0.031, 'arrange_hair', 'comb_hair', 'fix_hair', 'groom_hair', 'style_hair']
senticnet['make_happen'] = [-0.066, 0.223, -0.091, 0.187, '#interesting', '#admirable', 0.084, 'obligation', 'make_effort', 'task', 'accomplish', 'job_offer']
senticnet['make_happy'] = [0.997, 0.99, 0, 0.735, '#joyful', '#interesting', 0.907, 'express_love', 'show_affection', 'show_love', 'feel_obligated', 'say_thank_you']
senticnet['make_headway'] = [0.819, -0.875, 0, 0.902, '#surprising', '#admirable', 0.865, 'tally', 'steal', 'score', 'hit', 'rack_up']
senticnet['make_healthy'] = [0.124, 0.072, -0.079, 0.152, '#joyful', '#admirable', 0.09, 'keep_body_healthy', 'healthy', 'own_benefit', 'keep_skin_healthy', 'stay_physically_fit']
senticnet['make_hole'] = [-0.742, 0, 0.938, 0, '#sad', '#angry', -0.56, 'kill_people', 'violent_person', 'destroy_home', 'stab', 'elephant_sit_chest']
senticnet['make_home'] = [-0.104, 0.235, -0.127, 0.246, '#interesting', '#admirable', 0.083, 'love', 'settle_down', 'build_house', 'family_nest', 'buy_furniture']
senticnet['make_hot'] = [0.043, 0.13, -0.08, 0.105, '#interesting', '#admirable', 0.066, 'necessary_live', 'human_fuel', 'flatulence', 'often_red', 'plasma']
senticnet['make_hotel_reservation'] = [0, 0.926, 0, 0.824, '#interesting', '#admirable', 0.583, 'see_know', 'talk_person', 'conduct_business', 'call_mom', 'send_information']
senticnet['make_house_look_better'] = [-0.069, 0, 0, -0.073, '#sad', '#disgusting', -0.047, 'stop_bleed', 'make_look_better', 'change_color', 'sit_bench', 'fee_animal']
senticnet['make_ice'] = [0.029, 0, 0.042, -0.072, '#angry', '#disgusting', -0.028, 'fry_fish', 'make_coffee', 'clean_fish', 'piss', 'relieve_oneself']
senticnet['make_joke'] = [0.184, -0.107, -0.068, 0.104, '#joyful', '#surprising', 0.109, 'sense_of_humor', 'good_joke', 'plan_party', 'good_mood', 'tell_joke']
senticnet['make_judgment'] = [-0.03, 0.158, -0.054, 0.075, '#interesting', '#admirable', 0.05, 'go_court', 'decide_case', 'examine_evidence', 'question_witness', 'serve_jury']
senticnet['make_laugh'] = [0.123, -0.113, 0.011, -0.092, '#joyful', '#surprising', 0.044, 'give_pleasure', 'spread_happiness', 'good_time', 'amuse', 'comedian']
senticnet['make_law'] = [0.853, 0.936, 0, 0.949, '#interesting', '#admirable', 0.913, 'form_government', 'type_of_government', 'star_wars', 'constitution', 'govern']
senticnet['make_life_better'] = [0.853, 0.936, 0, 0.949, '#interesting', '#admirable', 0.913, 'improve_life', 'good_life', 'finish_college', 'serenity', 'make_life_easy']
senticnet['make_life_easy'] = [0.034, 0.067, 0, 0.098, '#interesting', '#admirable', 0.066, 'perform_task', 'job_offer', 'hire_help', 'present_bill', 'job']
senticnet['make_light'] = [0, 0, -0.083, 0, '#scared', '#scared', -0.028, 'burn_material', 'heat_house', 'heat_home', 'burn_fuel', 'light_dark']
senticnet['make_list'] = [0.034, 0.067, 0, 0.098, '#interesting', '#admirable', 0.066, 'drive_to_store', 'list', 'plan', 'go_shopping', 'organize']
senticnet['make_little_hungry'] = [0.825, 0.9, 0, 0, '#joyful', '#interesting', 0.575, 'become_fat', 'stomach_ache', 'get_fat', 'feel_rejuvenated', 'feel_full']
senticnet['make_live'] = [0, 0.1, 0, 0, '#interesting', '#interesting', 0.033, 'support_family', 'get_job_done', 'earn_money', 'make_money', 'need_earn_money']
senticnet['make_look_better'] = [0.969, -0.868, 0, 0.631, '#joyful', '#surprising', 0.823, 'assuage', 'perfect', 'fructify', 'relieve', 'sublimate']
senticnet['make_look_good'] = [0, 0.737, 0, 0.775, '#interesting', '#admirable', 0.504, 'get_rid_of_dirt', 'expect_guest', 'disinfect', 'cleanliness', 'hygiene']
senticnet['make_loud_noise'] = [-0.956, 0, 0, -0.951, '#sad', '#disgusting', -0.636, 'strum', 'make_noise', 'low_note', 'make_sound', 'keep_beat']
senticnet['make_love'] = [0.97, 0.729, 0, 0.946, '#joyful', '#admirable', 0.882, 'fuck', 'give_birth_child', 'sexual_intercourse', 'find_partner', 'become_pregnant']
senticnet['make_love_spouse'] = [0.085, -0.198, 0, 0, '#joyful', '#surprising', 0.094, 'make_someone_laugh', 'entertain_person', 'enjoy_together', 'love_others', 'laugh_joke']
senticnet['make_mad'] = [-0.096, -0.022, -0.052, -0.181, '#sad', '#disgusting', -0.102, 'taunt', 'violent_person', 'get_hurt', 'warmonger', 'death_penalty']
senticnet['make_mark'] = [-0.067, 0, 0.029, 0, '#sad', '#angry', -0.032, 'pick_out', 'push_button', 'separate', 'slash', 'cut_food']
senticnet['make_mark_paper'] = [-0.085, 0, 0, 0, '#sad', '#sad', -0.028, 'make_mark', 'write_paper', 'witting', 'become_dull', 'write_note']
senticnet['make_meal'] = [0, 0.105, 0.015, 0.068, '#interesting', '#admirable', 0.053, 'animal_eat', 'able_eat', 'bait_trap', 'eat_rice', 'provide_food']
senticnet['make_merry'] = [0.592, -0.929, 0, 0.703, '#surprising', '#admirable', 0.741, 'racket', 'revel', 'make_whoopie', 'roister', 'make_happy']
senticnet['make_mess'] = [-0.784, 0, 0.805, -0.944, '#angry', '#disgusting', -0.844, 'prepare_snack', 'make_pot_coffee', 'play_pool', 'gather_friend', 'meet_another_person']
senticnet['make_mess_of_something'] = [-0.99, 0, 0.165, -0.903, '#sad', '#disgusting', -0.686, 'mess', 'trouble', 'have_problem', 'problem', 'stress']
senticnet['make_metal'] = [0, 0.781, 0, 0.938, '#interesting', '#admirable', 0.573, 'magnetic', 'heavy_element', 'solid_room_temperature', 'ore', 'tin']
senticnet['make_milk'] = [0.849, 0.956, 0, 0, '#joyful', '#interesting', 0.602, 'bovine', 'good_friend', 'like_girl', 'barn_animal', 'produce_milk']
senticnet['make_mistake'] = [-0.816, 0, 0.809, -0.866, '#sad', '#disgusting', -0.83, 'make_error', 'count_finger', 'keep_word', 'become_frustrated', 'guess_answer']
senticnet['make_model'] = [-0.115, 0, 0.022, -0.091, '#sad', '#disgusting', -0.076, 'pick_out', 'hard_work', 'cut_food', 'produce_product', 'circulate_blood']
senticnet['make_money'] = [0.024, 0.097, 0, 0, '#joyful', '#interesting', 0.04, 'earn_money', 'make_live', 'entrepreneur', 'get_job_done', 'need_earn_money']
senticnet['make_move'] = [0, 0.951, 0, 0.83, '#interesting', '#admirable', 0.594, 'bounce_up_down', 'throw', 'play_catch', 'play', 'toss']
senticnet['make_movie'] = [0.137, 0.105, -0.089, 0.214, '#joyful', '#admirable', 0.122, 'art', 'ideal', 'good_memory', 'strive', 'own_space']
senticnet['make_music'] = [0.793, 0.811, 0, 0.908, '#interesting', '#admirable', 0.837, 'create_music', 'play_music', 'produce_musical_sound', 'play_orchestra', 'play_tune']
senticnet['make_musical_sound'] = [0.793, 0.811, 0, 0.908, '#interesting', '#admirable', 0.837, 'play_orchestra', 'play_music', 'play_tune', 'create_music', 'make_music']
senticnet['make_musicr'] = [0.032, 0.092, 0, 0.075, '#interesting', '#admirable', 0.066, 'rock_group', 'music_player', 'eclectic', 'musical_group', 'guitar_player']
senticnet['make_new'] = [0.793, 0.811, 0, 0.908, '#interesting', '#admirable', 0.837, 'make_new_friend', 'embellish', 'make_beautiful', 'become_beautiful', 'adorn']
senticnet['make_new_friend'] = [0.746, 0, 0, 0.907, '#joyful', '#admirable', 0.551, 'foreplay', 'enjoy_company', 'new_friendship', 'friendship', 'companionship']
senticnet['make_newspaper'] = [0, 0, 0, 0.122, '#admirable', '#admirable', 0.041, 'pencil_mark', 'make_book', 'handmade', 'script', 'written_text']
senticnet['make_noise'] = [-0.031, -0.066, 0.079, -0.111, '#angry', '#disgusting', -0.052, 'make_sound', 'part_of_band', 'make_music', 'keep_beat', 'play_music']
senticnet['make_note'] = [-0.073, 0, 0.026, -0.058, '#sad', '#disgusting', -0.052, 'write_note', 'jot_down_idea', 'take_note_class', 'write', 'note']
senticnet['make_offer'] = [0.705, 0.712, 0, 0, '#joyful', '#interesting', 0.472, 'price_goods', 'charge_credit_card', 'deal_card', 'sell_car', 'sign_agreement']
senticnet['make_oneself_feel_better'] = [0.901, -0.963, 0, 0, '#joyful', '#surprising', 0.621, 'make_someone_happy', 'feel_obligated', 'spread_happiness', 'happiness', 'comedian']
senticnet['make_oneself_happy'] = [0.793, 0.811, 0, 0.908, '#interesting', '#admirable', 0.837, 'show_care', 'make_others_happy', 'make_happy', 'feel_obligated', 'express_appreciation']
senticnet['make_other_person_laugh'] = [0, -0.036, 0, 0.094, '#surprising', '#admirable', 0.043, 'commercial', 'sitcom', 'presentation', 'satire', 'funny']
senticnet['make_others_happy'] = [0.748, 0.786, 0, 0.715, '#joyful', '#interesting', 0.75, 'make_oneself_happy', 'time_relax', 'feel_obligated', 'make_gift', 'generosity']
senticnet['make_others_laugh'] = [0.748, 0.786, 0, 0.715, '#joyful', '#interesting', 0.75, 'make_fun', 'entertain', 'clown', 'make_others_happy', 'laugh']
senticnet['make_out'] = [0.748, 0.786, 0, 0.715, '#joyful', '#interesting', 0.75, 'sex', 'one_night_stand', 'enjoy', 'meet_new_friend', 'party']
senticnet['make_out_atom'] = [-0.09, -0.085, 0.048, -0.253, '#sad', '#disgusting', -0.102, 'atom', 'learn', 'learn_new_subject', 'know_happen_world', 'learn_information']
senticnet['make_out_cloth'] = [-0.054, 0.092, 0, 0.132, '#interesting', '#admirable', 0.057, 'recycle', 'thrown_out', 'find_car', 'made_out_of_plastic', 'find_kitchen']
senticnet['make_out_date'] = [0.817, 0.78, 0, 0.971, '#joyful', '#admirable', 0.856, 'enjoy_performance', 'laugh_lot', 'go_date', 'feel_happy', 'see_show']
senticnet['make_out_fabric'] = [0, 0, 0, 0.078, '#admirable', '#admirable', 0.026, 'star_stripe', 'wave_wind', 'make_fabric', 'red_white_blue', 'emblem']
senticnet['make_out_leather'] = [0, -0.963, 0, 0.95, '#surprising', '#admirable', 0.638, 'make_coat', 'tie', 'overcoat', 'make_ball', 't-shirt']
senticnet['make_out_metal'] = [0, 0, 0, 0.089, '#admirable', '#admirable', 0.03, 'foil', 'lightweight_metal', 'rusty_metal', 'metal_type', 'metallic_element']
senticnet['make_out_paper'] = [-0.203, 0, 0, 0, '#sad', '#sad', -0.068, 'print_paper', 'written_paper', 'thrown_away', 'further_knowledge', 'recycle']
senticnet['make_out_rubber'] = [0, 0.823, 0, 0.791, '#interesting', '#admirable', 0.538, 'spherical_shape', 'use_sport', 'bouncy', 'three_dimensional', 'fill_air']
senticnet['make_outline'] = [0.809, 0.721, 0, 0, '#joyful', '#interesting', 0.51, 'use_word', 'run_out_ink', 'proofread', 'learn_spell', 'think_creatively']
senticnet['make_paint'] = [0.165, 0.069, 0.028, 0.057, '#joyful', '#interesting', 0.088, 'buy_paint', 'stir_paint_brush', 'wall_art', 'stir_paint', 'pick_up_brush']
senticnet['make_paper'] = [-0.024, 0.109, -0.055, 0.111, '#interesting', '#admirable', 0.047, 'find_library', 'read_human', 'find_car', 'find_hotel', 'find_kitchen']
senticnet['make_paper_airplane'] = [0, 0.93, 0, 0.952, '#interesting', '#admirable', 0.627, 'paper_airplane', 'make_mark_paper', 'write_note', 'witting', 'make_note']
senticnet['make_parent_happy'] = [0.936, 0.749, 0, 0.871, '#joyful', '#admirable', 0.852, 'get_married', 'finish_college', 'have_good_job', 'have_good_carrier', 'support_family']
senticnet['make_patchwork_quilt'] = [0.936, 0.749, 0, 0.871, '#joyful', '#admirable', 0.852, 'paint_picture', 'tie-dye', 'paint_house', 'create_art', 'letter_sign']
senticnet['make_payment'] = [0, 0.724, 0, 0.762, '#interesting', '#admirable', 0.495, 'buy_stuff', 'buy_item', 'check_price', 'comparison_shop', 'return_goods']
senticnet['make_peace'] = [-0.055, -0.007, 0.083, -0.134, '#angry', '#disgusting', -0.088, 'make_a_lot_of_noise', 'listen_orchestra', 'compose_music', 'play_piano', 'make_noise']
senticnet['make_person'] = [0.132, 0.115, -0.063, 0.121, '#joyful', '#admirable', 0.102, 'man_wife', 'survival_species', 'make_baby', 'lover', 'horny']
senticnet['make_person_upset'] = [-0.92, 0, 0.917, -0.956, '#sad', '#disgusting', -0.931, 'fight', 'war', 'battle', 'attack', 'conflict']
senticnet['make_pie'] = [0.728, 0.713, 0, 0.715, '#joyful', '#admirable', 0.719, 'bake_cake', 'birthday_gift', 'love', 'make_food', 'eat_pie']
senticnet['make_plan'] = [0.728, 0.713, 0, 0.715, '#joyful', '#admirable', 0.719, 'good_plan', 'organize', 'plan', 'make_list', 'write_note']
senticnet['make_point'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'learn_game', 'spread_information', 'convey_idea', 'surf_internet', 'fantasize']
senticnet['make_pollution'] = [-0.92, 0, 0.917, -0.956, '#sad', '#disgusting', -0.931, 'ozone_hole', 'polluted_air', 'pollution', 'create_pollution', 'pollution_factory']
senticnet['make_popcorn'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'watch_movie', 'eat_snack', 'popcorn', 'have_fun', 'prepare_food']
senticnet['make_porn'] = [0, 0, 0.937, -0.879, '#angry', '#disgusting', -0.605, 'deal_drug', 'sell_new_book', 'go_off_strike', 'go_public', 'open_business']
senticnet['make_pot_coffee'] = [-0.102, -0.056, 0.032, -0.09, '#sad', '#disgusting', -0.056, 'prepare_snack', 'learn_listen', 'talk_other', 'borrow_book_from_library', 'drink_tea']
senticnet['make_potato'] = [0, 0, -0.933, -0.748, '#scared', '#disgusting', -0.56, 'drink_a_lot_of_alcohol', 'drink_a_lot_of_booze', 'get_drunk', 'drink_much', 'drunk']
senticnet['make_presentation'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'teach_student', 'prepare_lesson', 'presentation', 'explain_subject', 'use_computer']
senticnet['make_pretty'] = [0.024, 0, 0.017, 0.151, '#joyful', '#admirable', 0.053, 'cover_table', 'pretty', 'make_up', 'remove_paint', 'paint_nail']
senticnet['make_product'] = [0, 0.15, 0, 0.181, '#interesting', '#admirable', 0.11, 'make_goods', 'make_stuff', 'produce_goods', 'manufacture', 'factory_output']
senticnet['make_profit'] = [-0.066, 0.166, 0, 0.095, '#interesting', '#admirable', 0.065, 'transact_business', 'exchange_money', 'provide_employment', 'pay_service', 'make_rich']
senticnet['make_progress'] = [0.783, 0.744, 0, 0.791, '#joyful', '#admirable', 0.773, 'talk_oneself', 'stay_touch_friend', 'discuss_issue', 'spread_word', 'check_oneself_mirror']
senticnet['make_promise'] = [0, 0.868, 0, 0.935, '#interesting', '#admirable', 0.601, 'give_word', 'make_commitment', 'rely', 'offer_solace', 'post_letter']
senticnet['make_purchase'] = [0, 0.868, 0, 0.935, '#interesting', '#admirable', 0.601, 'buy_item', 'check_price', 'buy_stuff', 'buy_goods', 'buy_happiness']
senticnet['make_quilt'] = [0.054, -0.052, 0.101, -0.097, '#angry', '#disgusting', -0.031, 'make_clothes', 'under_garment', 'make_suit', 'piece_of_clothing', 'make_dress']
senticnet['make_reservation'] = [0, 0.889, 0, 0.977, '#interesting', '#admirable', 0.622, 'pay_fee', 'bring_money', 'take_friend_out', 'make_sure_money', 'bring_cash']
senticnet['make_rich'] = [0, 0.078, 0, 0.099, '#interesting', '#admirable', 0.059, 'exchange_money', 'buy_sell', 'sell', 'acquire_goods', 'sell_goods']
senticnet['make_right'] = [0, 0.263, -0.216, 0.319, '#interesting', '#admirable', 0.122, 'make_better', 'improve', 'consent', 'neediness', 'tell_everyone']
senticnet['make_right_decision'] = [0, 0.982, 0, 0.791, '#interesting', '#admirable', 0.591, 'put_two_together', 'reach_conclusion', 'think', 'analysis', 'come_up_new_idea']
senticnet['make_rule'] = [-0.044, 0.113, 0, 0.174, '#interesting', '#admirable', 0.081, 'decision_making', 'talkative', 'speak', 'call_person', 'verbal']
senticnet['make_run'] = [0.856, 0, 0, 0.97, '#joyful', '#admirable', 0.609, 'combustion', 'chemical_process', 'potential_energy', 'radiation', 'electricity']
senticnet['make_sad'] = [-0.916, 0, 0.886, -0.954, '#sad', '#disgusting', -0.919, 'pain', 'hurt', 'sadness', 'ache', 'sore']
senticnet['make_sale'] = [0.079, 0.132, -0.108, 0.216, '#interesting', '#admirable', 0.106, 'draw_diagram', 'form_of_communication', 'tell_love', 'explain_detail', 'tell']
senticnet['make_sandwich'] = [0.119, 0, 0, 0, '#joyful', '#joyful', 0.04, 'create_food', 'stuff_face', 'make_toast', 'snack', 'fill_stomach']
senticnet['make_scarf'] = [0.101, -0.117, 0.157, -0.143, '#angry', '#disgusting', -0.027, 'make_sweater', 'make_clothes', 'sweater', 'make_cloth', 'make_shirt']
senticnet['make_selection'] = [0, 0.125, 0, 0.105, '#interesting', '#admirable', 0.077, 'go_shopping', 'go_department_store', 'go_to_shopping_mall', 'moolah', 'drive_to_store']
senticnet['make_sense'] = [-0.122, 0.239, -0.074, 0.203, '#interesting', '#admirable', 0.082, 'acknowledge', 'clarify', 'reason', 'give_hint', 'speak_up']
senticnet['make_sex'] = [0.705, 0.967, 0, 0, '#joyful', '#interesting', 0.557, 'have_fun', 'enjoy_sex', 'need_companionship', 'sit_rock_chair', 'watch_sunset']
senticnet['make_shirt'] = [0, -0.04, 0.126, -0.054, '#angry', '#disgusting', -0.047, 'make_cloth', 'make_clothes', 'cloth', 'article_clothes', 'apparel']
senticnet['make_shop_list'] = [0.705, 0.967, 0, 0, '#joyful', '#interesting', 0.557, 'shop_list', 'write_note', 'make_list', 'go_shopping', 'go_to_supermarket']
senticnet['make_sick'] = [-0.94, 0, 0.991, 0, '#sad', '#angry', -0.644, 'result_death', 'make_someone_upset', 'make_someone_sick', 'murder_another_person', 'socialist']
senticnet['make_sign'] = [-0.04, 0, 0, -0.042, '#sad', '#disgusting', -0.027, 'delay_payment', 'become_dull', 'write_paper', 'write', 'make_mark_paper']
senticnet['make_sketch'] = [-0.029, 0.111, 0, 0.05, '#interesting', '#admirable', 0.044, 'sketch', 'use_crayon', 'draw', 'doodle', 'pencil_art']
senticnet['make_small'] = [0.866, 0.997, 0, 0, '#joyful', '#interesting', 0.621, 'hide', 'shy', 'embarrassed', 'small', 'psychological_terror']
senticnet['make_smile'] = [0.143, -0.12, -0.087, -0.082, '#joyful', '#surprising', 0.031, 'hospitable', 'amuse_oneself', 'get_reaction', 'lift_spirit', 'celebrate_special_occasion']
senticnet['make_someone_happy'] = [0.802, 0.744, 0, 0.827, '#joyful', '#admirable', 0.791, 'spread_happiness', 'make_oneself_feel_better', 'give_gift', 'comedian', 'give_pleasure']
senticnet['make_someone_laugh'] = [0.853, 0.901, 0, 0.98, '#interesting', '#admirable', 0.911, 'have_fun', 'break_silence', 'laugh_joke', 'entertain_person', 'howl_laughter']
senticnet['make_someone_sad'] = [-0.308, -0.029, -0.09, -0.301, '#sad', '#disgusting', -0.223, 'investigate_fact', 'mind_boggle', 'lifestyle_change', 'head_hurt', 'think_logically']
senticnet['make_someone_sick'] = [-0.721, 0, 0.623, -0.688, '#sad', '#disgusting', -0.677, 'murder_another_person', 'kill_person', 'kill', 'kill_man', 'commit_murder']
senticnet['make_someone_upset'] = [-0.273, -0.094, -0.132, -0.155, '#sad', '#disgusting', -0.155, 'destroy_target', 'result_death', 'murder_another_person', 'destroy_city', 'kill']
senticnet['make_sound'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'noisy', 'noise_pollution', 'blaring', 'shouting', 'loud']
senticnet['make_speech'] = [-0.039, 0.087, -0.08, 0.11, '#interesting', '#admirable', 0.026, 'verbal', 'say', 'discourse', 'verbalize', 'speech']
senticnet['make_sport'] = [0, 0, 0, 0.077, '#admirable', '#admirable', 0.026, 'eat_right', 'eat_healthy_food', 'drink_plenty_water', 'take_vitamin', 'exercise']
senticnet['make_statement'] = [0, 0.763, 0, 0.889, '#interesting', '#admirable', 0.551, 'tell', 'breath_sigh_relief', 'compromise', 'speak_out', 'discuss']
senticnet['make_steel'] = [0.066, 0, 0.027, 0.054, '#joyful', '#admirable', 0.031, 'power_engine', 'dense', 'make_metal', 'make_out_metal', 'magnetism']
senticnet['make_strong'] = [0.072, 0.094, 0, 0.149, '#interesting', '#admirable', 0.105, 'go_to_gym', 'bodybuilding', 'do_exercise', 'aerobic_exercise', 'eat_healthy_food']
senticnet['make_stuff'] = [-0.039, 0.168, 0, 0.228, '#interesting', '#admirable', 0.119, 'make', 'make_product', 'make_goods', 'factory_output', 'creation']
senticnet['make_suit'] = [-0.039, 0.168, 0, 0.228, '#interesting', '#admirable', 0.119, 'clothes', 'woman_dress', 'piece_of_clothing', 'make_clothes', 'robe']
senticnet['make_sure'] = [0.072, 0.094, 0, 0.149, '#interesting', '#admirable', 0.105, 'ask_person', 'make_happen', 'accomplish', 'job_offer', 'present_bill']
senticnet['make_sure_enough_money'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'bring_cash', 'make_sure_money', 'find_wallet', 'go_supermarket', 'find_shop']
senticnet['make_sure_money'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'bring_cash', 'find_shop', 'find_wallet', 'go_supermarket', 'make_sure_enough_money']
senticnet['make_sweater'] = [0.101, -0.117, 0.157, -0.143, '#angry', '#disgusting', -0.027, 'make_scarf', 'make_clothes', 'sweater', 'make_cloth', 'make_shirt']
senticnet['make_tea'] = [-0.084, 0, 0, -0.032, '#sad', '#disgusting', -0.039, 'salt_food', 'chicken', 'brown_hamburger', 'fry_chicken', 'bone_chicken']
senticnet['make_telephone_call'] = [0, 0.978, 0, 0.788, '#interesting', '#admirable', 0.589, 'call_phone', 'meet_at_coffee_shop', 'call_person', 'use_telephone', 'call_telephone']
senticnet['make_terrorist_attack'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'plan_terrorist_attack', 'terrorist', 'bomb', 'attack', 'terrorist_attack']
senticnet['make_things_work'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'optimism', 'triumph', 'achievement', 'success', 'victory']
senticnet['make_throw_up'] = [0, 0.099, -0.045, 0.111, '#interesting', '#admirable', 0.055, 'cause_headache', 'blind', 'big_rat', 'chipmunk', 'grizzly']
senticnet['make_time'] = [-0.047, 0.132, 0, 0.057, '#interesting', '#admirable', 0.047, 'patience', 'motivation', 'open_eye', 'free_time', 'leave_home']
senticnet['make_tire'] = [-0.116, -0.096, 0.038, -0.15, '#sad', '#disgusting', -0.069, 'injury', 'physical_injury', 'strengthful', 'strike_ball', 'leg_hurt']
senticnet['make_toast'] = [-0.088, -0.046, 0.023, -0.076, '#sad', '#disgusting', -0.047, 'toast', 'bread_crumb', 'messy', 'bread', 'spoilage']
senticnet['make_toy'] = [-0.027, -0.051, -0.058, -0.055, '#scared', '#disgusting', -0.03, 'motor_oil', 'castor', 'engine', 'emission', 'bristle']
senticnet['make_tree'] = [0, -0.036, 0, 0.094, '#surprising', '#admirable', 0.043, 'cut_lumber', 'cut_tree', 'chop_tree', 'cut_down', 'make_wood']
senticnet['make_unusual_face'] = [-0.085, 0, 0.015, 0, '#sad', '#angry', -0.033, 'use_hand_gesture', 'unusual_face', 'move_tongue', 'make_gesture', 'share_idea']
senticnet['make_up'] = [0, 0.202, -0.107, 0.241, '#interesting', '#admirable', 0.112, 'abstract', 'tell_everyone', 'always_read', 'choice', 'explanation']
senticnet['make_up_idea'] = [0, 0.202, -0.107, 0.241, '#interesting', '#admirable', 0.112, 'make_out_atom', 'learn', 'learn_new_subject', 'know_happen_world', 'learn_information']
senticnet['make_up_mind'] = [-0.037, 0.149, 0, 0.071, '#interesting', '#admirable', 0.061, 'become_lawyer', 'examine_evidence', 'decide_case', 'consider_evidence', 'judgment']
senticnet['make_up_person'] = [-0.039, 0.141, -0.082, 0.108, '#interesting', '#admirable', 0.043, 'prohibitionist_society', 'overrate', 'use_game_chess', 'find_airplane', 'use_garden']
senticnet['make_up_powder'] = [0, 0.745, 0, 0.825, '#interesting', '#admirable', 0.523, 'white_substance', 'food_ingredient', 'white_grain', 'white_powder', 'granulate']
senticnet['make_up_story'] = [0, 0.153, -0.08, 0.131, '#interesting', '#admirable', 0.068, 'use_imagination', 'mental_activity', 'make_up_idea', 'imagine', 'remember_event']
senticnet['make_up_water'] = [0, 0, 0, 0.186, '#admirable', '#admirable', 0.062, 'go_green', 'water', 'beautiful', 'big', 'cover_water']
senticnet['make_use'] = [0.904, 0.819, 0, 0, '#joyful', '#interesting', 0.574, 'use', 'operate', 'handle', 'do_it_yourself', 'activate']
senticnet['make_war'] = [-0.073, -0.049, -0.063, -0.201, '#sad', '#disgusting', -0.096, 'conquer_enemy', 'protect_country', 'go_war', 'use_military', 'kill_soldier']
senticnet['make_well'] = [0, 0.225, -0.093, 0.142, '#interesting', '#admirable', 0.091, 'trustworthy', 'assurance', 'importance', 'impermanent', 'derivation']
senticnet['make_whoopie'] = [0.592, -0.929, 0, 0.703, '#surprising', '#admirable', 0.741, 'racket', 'revel', 'roister', 'make_merry', 'make_happy']
senticnet['make_wine'] = [-0.077, -0.026, 0, -0.131, '#sad', '#disgusting', -0.061, 'drink_wine', 'food_poison', 'spill_food_clothes', 'order_food', 'eat_salad']
senticnet['make_wish'] = [0, 0.091, -0.053, 0.073, '#interesting', '#admirable', 0.037, 'privately', 'hold_liquid', 'brew', 'rinse_dish', 'find_toilet']
senticnet['make_wood'] = [0, -0.036, 0, 0.094, '#surprising', '#admirable', 0.043, 'cut_lumber', 'cut_tree', 'chop_tree', 'cut_down', 'make_tree']
senticnet['make_wool'] = [0, -0.01, 0.051, -0.038, '#angry', '#disgusting', -0.026, 'animal_hair', 'animal_fur', 'pelt', 'strand', 'fur']
senticnet['make_work'] = [0, 0.913, 0, 0.855, '#interesting', '#admirable', 0.589, 'collect_debt', 'buy_tool', 'negotiate_contract', 'buy_gas', 'increase_net_worth']
senticnet['make_world_better_place'] = [0.79, 0.745, 0, 0.927, '#joyful', '#admirable', 0.821, 'help_others', 'improve_world', 'ego_boost', 'make_money', 'help_person']
senticnet['makeover'] = [0.944, -0.603, 0, 0.756, '#joyful', '#admirable', 0.768, 'beauty_treatment', 'beautification', 'manicure', 'pedicure', 'facial']
senticnet['maker'] = [0, 0.233, -0.079, 0.113, '#interesting', '#admirable', 0.089, 'structure', 'construction_worker', 'peasant', 'functionary', 'builder']
senticnet['makeshift'] = [-0.973, 0, 0.84, -0.528, '#sad', '#angry', -0.78, 'pis_aller', 'last_resort', 'temporary_expedient', 'expedient', 'stopgap']
senticnet['malacca'] = [0.609, -0.744, 0, 0.716, '#surprising', '#admirable', 0.69, 'city', 'malaysian_city', 'asia', 'old_city', 'colony']
senticnet['malacca_cane'] = [0.609, -0.744, 0, 0.716, '#surprising', '#admirable', 0.69, 'malacca', 'cane', 'swagger_stick', 'sword_cane', 'sword_stick']
senticnet['maladroit'] = [-0.61, 0, 0.533, -0.971, '#sad', '#disgusting', -0.705, 'bungling', 'bumbling', 'butterfingered', 'inept', 'handless']
senticnet['malady'] = [-0.858, 0, -0.998, -0.746, '#sad', '#scared', -0.867, 'polio', 'ailment', 'sickness', 'illness', 'disease']
senticnet['malaria'] = [-0.882, 0, -0.843, -0.956, '#sad', '#disgusting', -0.894, 'polio', 'infectious_disease', 'malady', 'sickness', 'ailment']
senticnet['malarkey'] = [-0.611, 0, 0.981, -0.983, '#angry', '#disgusting', -0.858, 'pious_platitude', 'nothingness', 'jazz', 'talk', 'malarky']
senticnet['malarky'] = [-0.611, 0, 0.981, -0.983, '#angry', '#disgusting', -0.858, 'pious_platitude', 'nothingness', 'jazz', 'malarkey', 'talk']
senticnet['malathion_poisoning'] = [-0.98, 0, 0.717, -0.515, '#sad', '#angry', -0.737, 'parathion_poisoning', 'pesticide_poisoning', 'toxic_condition', 'poisoning', 'intoxication']
senticnet['malcontent'] = [-0.88, 0, 0.718, -0.923, '#sad', '#disgusting', -0.84, 'ungratified', 'disaffected', 'discontented', 'unsatisfied', 'restless']
senticnet['maldives'] = [0, 0.112, 0, 0.137, '#interesting', '#admirable', 0.083, 'popular_vacation_destination', 'near_ocean', 'land_feature', 'ocean_shore', 'oceanside']
senticnet['male'] = [0, 0.884, 0, 0.726, '#interesting', '#admirable', 0.537, 'man_child', 'bloke', 'member_of_family', 'male_person', 'guy']
senticnet['male_and_female'] = [0, 0.954, 0, 0.969, '#interesting', '#admirable', 0.641, 'man_and_woman', 'couple', 'male_human', 'sing_microphone', 'male_person']
senticnet['male_chauvinism'] = [-0.684, 0, 0.949, -0.63, '#sad', '#angry', -0.754, 'chauvinism', 'sexism', 'antifeminism', 'sexual_discrimination', 'discrimination']
senticnet['male_chicken'] = [0.026, 0.069, 0, 0, '#joyful', '#interesting', 0.032, 'chicken_egg', 'chicken_soup', 'chick', 'chicken', 'quail']
senticnet['male_child'] = [0.631, -0.526, 0, 0.942, '#joyful', '#admirable', 0.7, 'altar_boy', 'cub', 'ball_boy', 'bat_boy', 'lad']
senticnet['male_cow'] = [0, -0.021, 0, 0.06, '#surprising', '#admirable', 0.027, 'baby_cow', 'donkey', 'little_horse', 'hoof_animal', 'animal']
senticnet['male_human'] = [0, 0.882, 0, 0.768, '#interesting', '#admirable', 0.55, 'man_and_woman', 'couple', 'male_and_female', 'sing_microphone', 'male_person']
senticnet['male_name'] = [0, 0.141, 0, 0.084, '#interesting', '#admirable', 0.075, 'jot', 'mark', 'symbol', 'doodle', 'scribble']
senticnet['male_parent'] = [0, 0.942, 0, 0.962, '#interesting', '#admirable', 0.635, 'male_relative', 'special_person', 'family_member', 'mother_brother', 'family_relationship_term']
senticnet['male_person'] = [0, 0.917, 0, 0.775, '#interesting', '#admirable', 0.564, 'male', 'man_child', 'bloke', 'male_human', 'masculine']
senticnet['male_relative'] = [0, 0.875, 0, 0.764, '#interesting', '#admirable', 0.546, 'male_parent', 'family_member', 'mother_brother', 'family_relationship_term', 'familial_relationship']
senticnet['maledict'] = [-0.691, 0, 0.917, -0.981, '#angry', '#disgusting', -0.863, 'call_down', 'stir', 'call_forth', 'conjure', 'bring_up']
senticnet['malefactor'] = [-0.716, 0, 0.669, -0.943, '#sad', '#disgusting', -0.776, 'toughie', 'accessory', 'highbinder', 'hoodlum', 'thug']
senticnet['malefic'] = [-0.041, 0.166, 0.684, -0.657, '#angry', '#disgusting', -0.405, 'maleficence', 'malign', 'maliciously', 'spitefulness', 'maliciousness']
senticnet['maleficence'] = [-0.041, 0.166, 0.684, -0.657, '#angry', '#disgusting', -0.405, 'malign', 'malefic', 'maliciously', 'spitefulness', 'maliciousness']
senticnet['maleficent'] = [-0.634, 0, 0.674, -0.756, '#angry', '#disgusting', -0.688, 'baneful', 'evil', 'baleful', 'malevolent', 'malign']
senticnet['malevolence'] = [-0.058, 0.181, 0.656, -0.645, '#angry', '#disgusting', -0.393, 'malignity', 'malevolently', 'loathing', 'execration', 'abhor']
senticnet['malevolency'] = [-0.945, 0, 0.897, -0.932, '#sad', '#disgusting', -0.925, 'cattiness', 'bitchiness', 'spitefulness', 'cruelness', 'evil']
senticnet['malevolent'] = [-0.046, 0.17, 0.676, -0.654, '#angry', '#disgusting', -0.402, 'maliciously', 'spitefulness', 'maliciousness', 'maleficence', 'malefic']
senticnet['malevolent_program'] = [-0.867, 0, 0.769, -0.888, '#sad', '#disgusting', -0.841, 'trojan', 'trojan_horse', 'virus', 'worm', 'computer_virus']
senticnet['malevolently'] = [-0.058, 0.181, 0.656, -0.645, '#angry', '#disgusting', -0.393, 'malignity', 'malevolence', 'loathing', 'execration', 'abhor']
senticnet['malformation'] = [-0.765, 0, 0.754, -0.567, '#sad', '#angry', -0.695, 'affliction', 'pigeon_breast', 'chicken_breast', 'clubfoot', 'talipes']
senticnet['malformed'] = [-0.737, 0, 0.904, -0.531, '#sad', '#angry', -0.724, 'acromegalic', 'shapeless', 'lumpy', 'deformed', 'unshapely']
senticnet['malfunction'] = [-0.123, 0.079, -0.124, 0, '#sad', '#scared', -0.056, 'pour_water', 'collide', 'wear_bath_suit', 'sit_in_shade', 'feel_heat']
senticnet['malfunctioning'] = [-0.732, 0, 0.787, -0.662, '#sad', '#angry', -0.727, 'wrong', 'haywire', 'bad', 'out_of_whack', 'amiss']
senticnet['malice'] = [-0.933, 0, 0.7, -0.762, '#sad', '#disgusting', -0.798, 'despise', 'aggression', 'disgust', 'scorn', 'hostility']
senticnet['malicious'] = [-0.887, 0, 0.864, -0.725, '#sad', '#angry', -0.825, 'vixenish', 'venomous', 'bitchy', 'catty', 'cattish']
senticnet['malicious_gossip'] = [-0.709, 0, 0.965, -0.535, '#sad', '#angry', -0.736, 'earful', 'scuttlebutt', 'talk_of_town', 'talk', 'scandal']
senticnet['malicious_mischief'] = [-0.738, 0, 0.547, -0.69, '#sad', '#disgusting', -0.658, 'devilment', 'roguery', 'mischief', 'shenanigan', 'deviltry']
senticnet['maliciously'] = [-0.041, 0.164, 0.685, -0.658, '#angry', '#disgusting', -0.407, 'maliciousness', 'spitefulness', 'maleficence', 'malefic', 'malign']
senticnet['maliciousness'] = [-0.041, 0.164, 0.685, -0.658, '#angry', '#disgusting', -0.407, 'maliciously', 'spitefulness', 'maleficence', 'malefic', 'malign']
senticnet['malign'] = [-0.041, 0.166, 0.684, -0.657, '#angry', '#disgusting', -0.405, 'maleficence', 'malefic', 'maliciously', 'spitefulness', 'maliciousness']
senticnet['malignant_hypertension'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'illness', 'ill', 'tension', 'bad_health', 'hypertension']
senticnet['malignity'] = [-0.058, 0.181, 0.656, -0.645, '#angry', '#disgusting', -0.393, 'malevolence', 'malevolently', 'loathing', 'execration', 'abhor']
senticnet['malignment'] = [-0.969, 0, 0.766, -0.96, '#sad', '#disgusting', -0.898, 'calumniation', 'traducement', 'hatchet_job', 'defamation', 'calumny']
senticnet['mall'] = [0, 0.932, 0, 0.856, '#interesting', '#admirable', 0.596, 'harvest_fall', 'find_mall', 'require_good_health', 'eaten', 'grown_soil']
senticnet['mallard'] = [0.114, 0, 0, 0, '#joyful', '#joyful', 0.038, 'can_fly', 'vulture', 'pigeon', 'bird', 'most_birds']
senticnet['malleability'] = [0.64, -0.95, 0, 0.639, '#joyful', '#surprising', 0.743, 'pliability', 'whip', 'bendability', 'flexibleness', 'plasticity']
senticnet['malleable'] = [0.118, -0.06, 0.075, 0.086, '#joyful', '#admirable', 0.063, 'soft_hard', 'dance_type', 'attract', 'adjust', 'pedal']
senticnet['mallee'] = [-0.605, 0, 0.787, -0.909, '#angry', '#disgusting', -0.767, 'white_mallee', 'congoo_mallee', 'black_mallee', 'black_sally', 'black_gum']
senticnet['mallet'] = [0.056, 0.107, 0, 0.09, '#interesting', '#admirable', 0.084, 'religious_fanatic', 'maul', 'door_knob', 'mailman', 'court_trial']
senticnet['mallow'] = [-0.714, 0, 0.983, -0.628, '#sad', '#angry', -0.775, 'bush', 'musk_mallow', 'mus_rose', 'common_mallow', 'tall_mallow']
senticnet['malnourished'] = [-0.604, 0, 0.766, -0.746, '#angry', '#disgusting', -0.705, 'unfed', 'underfed', 'undernourished', 'starved', 'starving']
senticnet['malnutrition'] = [-0.712, 0, 0.74, -0.506, '#sad', '#angry', -0.653, 'kwashiorkor', 'marasmus', 'avitaminosis', 'hypovitaminosis', 'deficiency_disease']
senticnet['malodor'] = [-0.635, 0, 0.523, -0.982, '#sad', '#disgusting', -0.713, 'niff', 'pong', 'smell', 'odor', 'olfactory_sensation']
senticnet['malodorous'] = [-0.868, 0, 0.644, -0.886, '#sad', '#disgusting', -0.799, 'frowsty', 'fetid', 'foetid', 'smelly', 'stinking']
senticnet['malodorousness'] = [-0.757, 0, 0.803, -0.541, '#sad', '#angry', -0.7, 'body_odor', 'aroma', 'scent', 'olfactory_property', 'smell']
senticnet['malodourous'] = [-0.522, 0, 0.952, -0.969, '#angry', '#disgusting', -0.814, 'frowsty', 'fetid', 'foetid', 'smelly', 'stinking']
senticnet['maltreatment'] = [-0.8, 0, 0.875, -0.745, '#sad', '#angry', -0.807, 'inhuman_treatment', 'cruelty', 'child_neglect', 'mistreatment', 'child_abuse']
senticnet['mammal'] = [0, -0.101, 0, 0, '#surprising', '#surprising', 0.034, 'animal', 'cage', 'reptile', 'wildlife', 'zoo']
senticnet['mammal_family'] = [-0.04, 0, 0, -0.05, '#sad', '#disgusting', -0.03, 'bad_luck', 'tundra', 'artic', 'damn', 'bad_mood']
senticnet['mammary_gland'] = [0.059, 0, 0.042, 0.055, '#joyful', '#admirable', 0.024, 'warm_blood', 'hairy', 'hairy_animal', 'nipple', 'woodland_creature']
senticnet['mammoth'] = [0, 0.081, 0.03, 0.126, '#interesting', '#admirable', 0.059, 'apple_tree', 'bald_eagle', 'roadway_square', 'rosebush', 'philadelphia']
senticnet['mammoth_ice'] = [0, -0.007, 0.038, -0.037, '#angry', '#disgusting', -0.023, 'earthworm', 'compost', 'fallen_leaf', 'detritus', 'worm']
senticnet['man'] = [0, 0, 0, -0.074, '#disgusting', '#disgusting', -0.025, 'army_fighter', 'army_person', 'sailor', 'fighter', 'workfighter']
senticnet['man-made'] = [0, 0.763, 0, 0.984, '#interesting', '#admirable', 0.582, 'dead', 'hard', 'power_electricity', 'hand_made', 'little_dense_water']
senticnet['man_and_woman'] = [0.159, 0.068, -0.079, 0.118, '#joyful', '#admirable', 0.089, 'gender', 'human_being', 'male_and_female', 'humanity', 'sexuality']
senticnet['man_back_pocket'] = [0, 0.092, 0, 0, '#interesting', '#interesting', 0.031, 'pocket', 'pant_back_pocket', 'back_pocket', 'purse', 'clothes_washer']
senticnet['man_best_friend'] = [0, 0, -0.712, -0.917, '#scared', '#disgusting', -0.543, 'shell_animal', 'caged_lion', 'home_animal', 'captivity', 'keep_in_cage']
senticnet['man_child'] = [0, 0.81, 0, 0.75, '#interesting', '#admirable', 0.52, 'special_person', 'male_parent', 'member_of_family', 'boys', 'male']
senticnet['man_clothes'] = [0.977, 0.967, 0, 0, '#joyful', '#interesting', 0.648, 'slack', 'shirt', 'article_clothes', 'leg_wear', 'clothes']
senticnet['man_made'] = [-0.7, 0, 0.77, -0.754, '#angry', '#disgusting', -0.741, 'fake', 'unnatural', 'artificial', 'artificial_sea', 'artificial_taste']
senticnet['man_make'] = [0, 0.1, 0.018, 0.217, '#interesting', '#admirable', 0.1, 'water_passage', 'artificial', 'waterway', 'wide', 'thing']
senticnet['man_of_cloth'] = [-0.677, 0, 0.994, -0.503, '#sad', '#angry', -0.725, 'altar_boy', 'reverend', 'thurifer', 'clergyman', 'acolyte']
senticnet['man_pocket'] = [0.838, 0.896, 0, 0, '#joyful', '#interesting', 0.578, 'back_pocket', 'pant_pocket', 'coin_purse', 'checkbook', 'pocket']
senticnet['man_post'] = [0.766, 0.926, 0, 0, '#joyful', '#interesting', 0.564, 'marry_man', 'service_car', 'date_woman', 'oil_hinge', 'dig_grave']
senticnet['man_purse'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'purse', 'pocket', 'wallet', 'woman_purse', 'bag']
senticnet['man_ship'] = [-0.029, 0.203, -0.093, 0.171, '#interesting', '#admirable', 0.084, 'take_charge', 'file_complaint', 'courageous', 'oversee', 'obey_law']
senticnet['man_spacecraft'] = [0, 0.989, 0, 0.757, '#interesting', '#admirable', 0.582, 'gather_berry', 'hang_picture_on_wall', 'think_future', 'wave_flag', 'chair_committee']
senticnet['man_wife'] = [0.132, 0.115, -0.063, 0.121, '#joyful', '#admirable', 0.102, 'make_person', 'survival_species', 'make_baby', 'lover', 'horny']
senticnet['manage'] = [0.781, -0.797, 0, 0.816, '#surprising', '#admirable', 0.798, 'deliver_goods', 'succeed', 'win', 'bring_home_bacon', 'come_through']
senticnet['manage_money'] = [0, 0.8, 0, 0.979, '#interesting', '#admirable', 0.593, 'cashless', 'bill_pay', 'pay_purchase', 'charge_money', 'pay_item']
senticnet['manageability'] = [0.637, -0.911, 0, 0.757, '#surprising', '#admirable', 0.768, 'tractability', 'manageableness', 'docility', 'obedience', 'amenability']
senticnet['manageable'] = [0.5, -0.9, 0, 0.525, '#surprising', '#admirable', 0.642, 'administrable', 'controllable', 'governable', 'steerable', 'dirigible']
senticnet['manageableness'] = [0.637, -0.911, 0, 0.757, '#surprising', '#admirable', 0.768, 'manageability', 'tractability', 'docility', 'obedience', 'amenability']
senticnet['management'] = [0, 0.941, 0, 0.966, '#interesting', '#admirable', 0.636, 'ambassador', 'supervisor', 'boss', 'master', 'ceo']
senticnet['manager'] = [-0.029, 0, 0, -0.079, '#sad', '#disgusting', -0.036, 'chairperson', 'investigator', 'slut', 'seeker', 'commuter']
senticnet['manchester'] = [-0.024, -0.005, -0.049, 0, '#sad', '#scared', -0.023, 'medikit', 'medical_build', 'ghetto', 'metropolitan_city', 'new_york_city']
senticnet['mandatory'] = [0, 0.298, -0.219, 0.312, '#interesting', '#admirable', 0.13, 'must', 'necessary', 'requirement', 'needful', 'compel']
senticnet['mandible'] = [0.886, -0.997, 0, 0.542, '#joyful', '#surprising', 0.808, 'jowl', 'lower_jaw', 'lantern_jaw', 'mandibula', 'mandibular_bone']
senticnet['mandibula'] = [0.886, -0.997, 0, 0.542, '#joyful', '#surprising', 0.808, 'jowl', 'lower_jaw', 'mandible', 'lantern_jaw', 'lantern_jawr_bone']
senticnet['mandibular_bone'] = [0.886, -0.997, 0, 0.542, '#joyful', '#surprising', 0.808, 'jowl', 'lower_jaw', 'mandible', 'mandibula', 'lantern_jaw']
senticnet['mane'] = [0.039, 0.086, 0, 0, '#joyful', '#interesting', 0.042, 'leopard', 'most_cats', 'lynx', 'only_mammal', 'hare']
senticnet['maneuver'] = [-0.825, 0, 0.739, -0.509, '#sad', '#angry', -0.691, 'fake', 'juke', 'feint', 'manoeuvre', 'tactical_feint']
senticnet['manga'] = [0, 0.991, 0, 0.814, '#interesting', '#admirable', 0.602, 'anime', 'cartoon', 'radio-control_helicopter', 'beat_off', 'see_someone_play_game']
senticnet['manganese'] = [0, 0, -0.973, 0, '#scared', '#scared', -0.324, 'iodine', 'lithium', 'uranium', 'element', 'arsenic']
senticnet['mangle'] = [-0.624, 0, 0.756, -0.626, '#angry', '#disgusting', -0.669, 'vitiate', 'mar', 'maul', 'deface', 'impair']
senticnet['mangled'] = [-0.639, 0, 0.503, -0.736, '#sad', '#disgusting', -0.626, 'wounded', 'injured', 'torn', 'hurt', 'eviscerate']
senticnet['mangler'] = [-0.804, 0, 0.858, -0.754, '#sad', '#angry', -0.805, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['mango'] = [0.889, 0, 0, 0.988, '#joyful', '#admirable', 0.626, 'green_apple', 'apricot', 'lime', 'peach', 'cherry']
senticnet['manhole_cover'] = [0.104, -0.112, 0, -0.046, '#joyful', '#surprising', 0.057, 'reception', 'disco', 'confetti', 'dance_club', 'balloon']
senticnet['mania'] = [-0.997, 0, 0.693, -0.633, '#sad', '#angry', -0.774, 'logorrhea', 'logomania', 'agromania', 'pyromania', 'necrophilia']
senticnet['maniac'] = [-0.742, 0, 0.604, -0.881, '#sad', '#disgusting', -0.742, 'weirdo', 'crazy', 'loony', 'looney', 'nutcase']
senticnet['manic_depression'] = [-0.617, 0, 0.527, -0.573, '#sad', '#disgusting', -0.572, 'affective_disorder', 'major_affective_disorder', 'emotional_disorder', 'emotional_disturbance', 'cyclothymia']
senticnet['manic_depressive_illness'] = [-0.517, 0, 0.9, -0.681, '#angry', '#disgusting', -0.699, 'affective_disorder', 'major_affective_disorder', 'emotional_disorder', 'emotional_disturbance', 'cyclothymia']
senticnet['manic_disorder'] = [-0.907, 0, 0.543, -0.912, '#sad', '#disgusting', -0.787, 'affective_disorder', 'major_affective_disorder', 'emotional_disorder', 'emotional_disturbance', 'hysteria']
senticnet['manicure'] = [0.944, -0.603, 0, 0.756, '#joyful', '#admirable', 0.768, 'makeover', 'beautification', 'beauty_treatment', 'pedicure', 'facial']
senticnet['manicurist'] = [0.633, -0.502, 0, 0.59, '#joyful', '#admirable', 0.575, 'craftsman', 'beautician', 'artisan', 'journeyman', 'artificer']
senticnet['manifestation'] = [0.565, -0.792, 0, 0.959, '#surprising', '#admirable', 0.772, 'ebullition', 'cry', 'reflection', 'acting_out', 'explosion']
senticnet['manipulable'] = [0.841, -0.576, 0, 0.891, '#joyful', '#admirable', 0.769, 'tamable', 'tameable', 'ductile', 'malleable', 'docile']
senticnet['manipulate'] = [-0.156, 0, -0.114, -0.091, '#sad', '#scared', -0.12, 'forget', 'become_depressed', 'prove_point', 'share_secret', 'misunderstand']
senticnet['mankind'] = [0, 0.901, 0, 0.937, '#interesting', '#admirable', 0.613, 'gender', 'humankind', 'person', 'pedophile', 'guardian']
senticnet['manly'] = [0, 0.851, 0, 0.902, '#interesting', '#admirable', 0.584, 'strength', 'strong', 'physical_strength', 'athlete', 'muscle']
senticnet['manna_grass'] = [-0.766, 0, 0.513, -0.722, '#sad', '#disgusting', -0.667, 'foxtail', 'foxtail_grass', 'meadow_grass', 'sweet_grass', 'wood_meadowgrass']
senticnet['mannequin'] = [0, -0.087, 0, 0, '#surprising', '#surprising', 0.029, 'toy', 'stuff_animal', 'dummy', 'doll', 'action_figure']
senticnet['manner'] = [0.101, 0.237, -0.231, 0.236, '#interesting', '#admirable', 0.114, 'etiquette', 'politeness', 'suspicion', 'obedience', 'please']
senticnet['manner_of_speaking'] = [-0.896, 0, 0.697, -0.517, '#sad', '#angry', -0.703, 'tone_of_voice', 'tone', 'catch', 'address', 'tongue']
senticnet['manoeuvre'] = [0.043, 0.127, -0.068, 0.268, '#interesting', '#admirable', 0.123, 'rotate_movement', 'drive_car', 'movement', 'car_action', 'motion']
senticnet['manor'] = [0.049, 0.16, 0, 0.155, '#interesting', '#admirable', 0.121, 'castle', 'palace', 'medieval', 'aristocrat', 'throne']
senticnet['manpower'] = [0.814, -0.878, 0, 0.918, '#surprising', '#admirable', 0.87, 'ship_company', 'company', 'work_force', 'workforce', 'full_complement']
senticnet['mansion'] = [0, 0.105, 0, 0.076, '#interesting', '#admirable', 0.06, 'palace', 'big_house', 'castle', 'bungalow', 'terrace']
senticnet['mantle'] = [0.053, -0.093, 0, 0, '#joyful', '#surprising', 0.049, 'timber', 'firewood', 'stump', 'kindle', 'lumber']
senticnet['mantra'] = [0.022, 0.123, 0.038, 0.129, '#interesting', '#admirable', 0.079, 'hymn', 'written_music', 'walk_beach', 'lyric', 'piece_of_music']
senticnet['manual_dexterity'] = [0.703, -0.8, 0, 0.691, '#joyful', '#surprising', 0.731, 'skillfulness', 'touch', 'dexterity', 'adeptness', 'sleight']
senticnet['manual_laborer'] = [-0.846, 0, 0.96, -0.91, '#angry', '#disgusting', -0.905, 'housewrecker', 'housebreaker', 'knacker', 'laborer', 'wrecker']
senticnet['manufactory'] = [0.692, -0.53, 0, 0.68, '#joyful', '#admirable', 0.634, 'rolling_mill', 'factory', 'mill', 'manufacturing_plant', 'steel_factory']
senticnet['manufacture'] = [0, 0.21, -0.064, 0.245, '#interesting', '#admirable', 0.13, 'factory_output', 'production', 'make_goods', 'make_product', 'make']
senticnet['manufacture_plant'] = [0, 0.09, 0, 0.135, '#interesting', '#admirable', 0.075, 'make_goods', 'make_product', 'build_process', 'assembly_line', 'construction']
senticnet['manufacturer'] = [0.059, 0.152, 0, 0.15, '#interesting', '#admirable', 0.12, 'industry', 'enterprise', 'corporation', 'business', 'factory']
senticnet['manufacturing_plant'] = [0.692, -0.53, 0, 0.68, '#joyful', '#admirable', 0.634, 'rolling_mill', 'factory', 'mill', 'steel_factory', 'manufactory']
senticnet['manure'] = [-0.028, -0.014, 0, -0.088, '#sad', '#disgusting', -0.034, 'dung', 'muck', 'shit', 'dog_poop', 'crap']
senticnet['manus'] = [0.569, -0.69, 0, 0.817, '#surprising', '#admirable', 0.692, 'hooks', 'meat_hooks', 'maulers', 'right', 'left']
senticnet['many_animals'] = [0.02, 0.071, 0, 0.069, '#interesting', '#admirable', 0.053, 'cute_animal', 'little_animal', 'chihuahua', 'panda', 'small_creature']
senticnet['many_books'] = [-0.046, 0, -0.116, 0, '#sad', '#scared', -0.054, 'book', 'almost_always', 'book_genre', 'saga', 'book_poetry']
senticnet['many_chemicals'] = [0, 0, -0.735, -0.865, '#scared', '#disgusting', -0.533, 'dangerous_item', 'many_cultures', 'venomous', 'many_countries', 'dangerous']
senticnet['many_children'] = [0.068, 0, 0, 0, '#joyful', '#joyful', 0.023, 'little_kid', 'clan', 'bald', 'newborn', 'little_person']
senticnet['many_cities'] = [0.077, 0.125, 0, 0.076, '#joyful', '#interesting', 0.093, 'urban', 'group_of_people', 'community', 'big_city_life', 'metropolis']
senticnet['many_countries'] = [0, 0.771, 0, 0.959, '#interesting', '#admirable', 0.577, 'many_chemicals', 'many_cultures', 'venomous', 'dangerous_item', 'dangerous']
senticnet['many_cultures'] = [0, 0.873, 0, 0.806, '#interesting', '#admirable', 0.56, 'many_chemicals', 'dangerous_item', 'venomous', 'many_countries', 'dangerous']
senticnet['many_different'] = [0.123, 0.148, -0.111, 0.294, '#interesting', '#admirable', 0.151, 'hold_object', 'hold', 'grasp', 'multiple_purposes', 'hold_many']
senticnet['many_different_colors'] = [0, 0, 0, -0.758, '#disgusting', '#disgusting', -0.253, 'jump_over_fence', 'live_underground', 'tame', 'eat_rat', 'growl']
senticnet['many_different_kinds'] = [-0.04, -0.021, 0.027, -0.031, '#sad', '#disgusting', -0.026, 'precious_metal', 'olympic_medal', 'shiny_metal', 'bloodstone', 'valuable_metal']
senticnet['many_different_types'] = [0.093, 0, 0.011, 0.106, '#joyful', '#admirable', 0.063, 'roadway_square', 'many_types', 'type', 'many_kinds', 'bee']
senticnet['many_different_ways'] = [0.098, 0.165, -0.134, 0.284, '#interesting', '#admirable', 0.138, 'know', 'great_understand', 'trivia', 'understand', 'know_fact']
senticnet['many_feathers'] = [0.02, 0.078, 0, 0, '#joyful', '#interesting', 0.033, 'beak', 'bird_mouth', 'plume', 'wing', 'water_bird']
senticnet['many_feathers_beak'] = [0.02, 0.078, 0, 0, '#joyful', '#interesting', 0.033, 'beak', 'bird_mouth', 'wing', 'many_feathers', 'water_bird']
senticnet['many_fishes'] = [0, 0.719, 0, 0.843, '#interesting', '#admirable', 0.521, 'porpoise', 'horizon', 'seahorse', 'sea_wee', 'mermaid']
senticnet['many_floors'] = [0.021, 0.069, 0.067, 0.086, '#interesting', '#admirable', 0.036, 'wall_street', 'old_time', 'old_object', 'item_sell', 'school_subject']
senticnet['many_forms'] = [0.828, 0, 0, 0.871, '#joyful', '#admirable', 0.566, 'lyrics', 'melody', 'musical_sound', 'musical_note', 'music_note']
senticnet['many_fruits'] = [0.02, -0.056, 0, 0, '#joyful', '#surprising', 0.025, 'buy_fruit', 'peach', 'cherry', 'pineapple', 'tomato']
senticnet['many_games'] = [0, 0, 0, 0.096, '#admirable', '#admirable', 0.032, 'game_chess', 'game', 'form_of_gambling', 'consider_good_luck', 'play_marble']
senticnet['many_homes'] = [-0.027, -0.004, 0.022, -0.036, '#sad', '#disgusting', -0.027, 'fancy_house', 'outside_house', 'front_house', 'abide', 'atrium']
senticnet['many_humans'] = [-0.06, 0, -0.046, 0, '#sad', '#scared', -0.035, 'small_dog', 'red-bellied_black_snake', 'eastern_brown_snake', 'wiener_dog', 'puma']
senticnet['many_insects'] = [0, -0.034, 0.077, -0.066, '#angry', '#disgusting', -0.036, 'grasshopper', 'cutworm', 'scorpion', 'beetle', 'ant']
senticnet['many_items'] = [0.041, 0.093, 0.085, 0.133, '#interesting', '#admirable', 0.061, 'count', 'set', 'part_of_whole', 'small_group', 'total_number']
senticnet['many_kinds'] = [0.093, 0, 0.011, 0.106, '#joyful', '#admirable', 0.063, 'roadway_square', 'many_types', 'type', 'many_different_types', 'bee']
senticnet['many_pages'] = [0.067, 0.153, -0.054, 0.111, '#interesting', '#admirable', 0.092, 'book_newspaper', 'record_event', 'pen_and_paper', 'world_event', 'current_event']
senticnet['many_people'] = [0.068, 0.126, -0.062, 0.117, '#interesting', '#admirable', 0.083, 'crowd', 'happy_together', 'human_group', 'relate_person', 'parent_child']
senticnet['many_plants'] = [0.081, -0.032, 0, 0, '#joyful', '#surprising', 0.038, 'blossom', 'bloom', 'pollen', 'poppy', 'bouquet']
senticnet['many_products'] = [0, 0.079, -0.135, -0.123, '#scared', '#disgusting', -0.06, 'rubbish', 'short_circuit', 'store_trash', 'hold_trash', 'put_trash']
senticnet['many_purposes'] = [0.734, 0.912, 0, 0, '#joyful', '#interesting', 0.549, 'use_hunt', 'rifle', 'revolver', 'gun', 'hydrogen_bomb']
senticnet['many_rooms'] = [0.063, 0, 0, 0.05, '#joyful', '#admirable', 0.038, 'indoor', 'foyer', 'room', 'hotel', 'ceiling_fan']
senticnet['many_shades'] = [-0.059, 0, 0.012, 0, '#sad', '#angry', -0.024, 'pigment', 'green_yellow', 'water_color', 'tint', 'red_blue']
senticnet['many_shops'] = [0, 0.113, 0.041, 0.058, '#interesting', '#admirable', 0.043, 'corner_shop', 'general_store', 'bazaar', 'large_supermarket', 'goods']
senticnet['many_species'] = [0, 0, 0, -0.801, '#disgusting', '#disgusting', -0.267, 'hairball', 'clog', 'waste_water', 'stench', 'false_tooth']
senticnet['many_sports'] = [0.976, 0, 0, 0.779, '#joyful', '#admirable', 0.585, 'ball_game', 'verbosity', 'scrabble', 'sport_play', 'checker']
senticnet['many_steps'] = [0.022, -0.117, 0.014, 0.057, '#surprising', '#admirable', 0.061, 'wood', 'ruff', 'franchise', 'stump', 'timber']
senticnet['many_stores'] = [0, 0.8, 0, 0.969, '#interesting', '#admirable', 0.59, 'department_store', 'clothes_store', 'woman_closet', 'store', 'clothes_drawer']
senticnet['many_types'] = [0.726, 0, 0, 0.75, '#joyful', '#admirable', 0.492, 'many_different_types', 'many_forms', 'thunder', 'wicket', 'jitterbug']
senticnet['many_uses'] = [0, 0, -0.068, 0, '#scared', '#scared', -0.023, 'make_tree', 'solid_fuel', 'slick', 'many_types', 'many_items']
senticnet['many_windows'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'unix', 'window', 'solaris', 'train_window', 'doorway']
senticnet['many_words'] = [0.769, 0.806, 0, 0, '#joyful', '#interesting', 0.525, 'vocabulary', 'read_material', 'book_genre', 'book_library', 'definition']
senticnet['many_yards'] = [0, 0.066, 0.048, 0.08, '#interesting', '#admirable', 0.033, 'ecosystem', 'measure_distance', 'distance_measurement', 'mow', 'length']
senticnet['many_years'] = [0, 0, 0, 0.7, '#admirable', '#admirable', 0.233, 'old', 'years', 'elderly', 'teen', 'annual']
senticnet['map'] = [0.087, 0.08, 0.013, 0, '#joyful', '#interesting', 0.051, 'neighborhood_map', 'billboard', 'underground_neighborhood_map', 'advertise_panel', 'restaurant_entrance']
senticnet['maple'] = [0.032, 0.075, 0, 0, '#joyful', '#interesting', 0.036, 'aperitif', 'fondue', 'crop', 'graze', 'kernel']
senticnet['mar'] = [-0.879, 0, 0.881, -0.731, '#sad', '#angry', -0.83, 'fingerblotk', 'blemish', 'blot', 'defect', 'blotch']
senticnet['maraschino'] = [0.693, -0.945, 0, 0.713, '#surprising', '#admirable', 0.784, 'anisette', 'cordial', 'ratafia', 'pastis', 'ratafee']
senticnet['marasmus'] = [-0.712, 0, 0.74, -0.506, '#sad', '#angry', -0.653, 'kwashiorkor', 'malnutrition', 'avitaminosis', 'hypovitaminosis', 'deficiency_disease']
senticnet['marathon'] = [0, 0, 0, 0.108, '#admirable', '#admirable', 0.036, 'fast', 'flee', 'sprint', 'race', 'good_form_exercise']
senticnet['marathon_runner'] = [-0.045, -0.037, 0, -0.167, '#sad', '#disgusting', -0.058, 'crazy', 'damage_body', 'crazy_person', 'threat', 'max']
senticnet['maraud'] = [-0.933, 0, 0.722, -0.663, '#sad', '#angry', -0.773, 'penetration', 'air_raid', 'air_attack', 'swoop', 'incursion']
senticnet['marble_bones_disease'] = [-0.707, 0, 0.64, -0.605, '#sad', '#angry', -0.651, 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect', 'congenital_disease']
senticnet['marbles'] = [0, 0.077, 0.039, 0.154, '#interesting', '#admirable', 0.064, 'dome', 'round_figure', 'almond', 'round_ball', 'sphere']
senticnet['marcel'] = [-0.974, 0, 0.567, -0.598, '#sad', '#disgusting', -0.713, 'coif', 'coiffure', 'hairdo', 'hairstyle', 'hair_style']
senticnet['march_rear'] = [0.035, 0.197, -0.071, 0.194, '#interesting', '#admirable', 0.118, 'edict', 'law', 'regulation', 'order', 'legislation']
senticnet['mare_nest'] = [-0.855, 0, 0.583, -0.716, '#sad', '#disgusting', -0.718, 'muddle', 'fuddle', 'rummage', 'welter', 'clutter']
senticnet['margin'] = [0.022, 0.243, 0, 0.176, '#interesting', '#admirable', 0.147, 'tip', 'bottom_line', 'extra_money', 'profile', 'sharpness']
senticnet['marginal'] = [-0.546, 0, 0.739, -0.643, '#angry', '#disgusting', -0.643, 'unremunerative', 'idle', 'lean', 'dead', 'unprofitable']
senticnet['marginocephalian'] = [-0.927, 0, 0.64, -0.529, '#sad', '#angry', -0.699, 'perching_bird', 'percher', 'thyreophoran', 'animal_order', 'euronithopod']
senticnet['mariachi'] = [-0.507, 0, 0.902, -0.548, '#angry', '#disgusting', -0.652, 'gamelan', 'jug_band', 'pop_group', 'ensemble', 'skiffle_group']
senticnet['marihuana'] = [-0.946, 0, 0.517, -0.757, '#sad', '#disgusting', -0.74, 'narcotic', 'bhang', 'cannabis', 'marijuana', 'soft_drug']
senticnet['marijuana'] = [0.962, 0, 0, 0, '#joyful', '#joyful', 0.321, 'cannabis', 'pleasure_garden', 'trellis', 'mushroom', 'cabbage']
senticnet['marine'] = [0, 0, -0.06, -0.085, '#scared', '#disgusting', -0.048, 'sergent', 'military', 'warrior', 'army_person', 'military_force']
senticnet['marine_animal'] = [0.052, 0.066, 0, 0.106, '#interesting', '#admirable', 0.075, 'shell_fish', 'seafood', 'sometimes', 'ocean_animal', 'crustacean']
senticnet['marine_mammal'] = [0.024, 0.102, -0.068, 0.074, '#interesting', '#admirable', 0.044, 'dolphin', 'large_mammal', 'pack_animal', 'mammal', 'smart_creature']
senticnet['mariner'] = [0.587, -0.67, 0, 0.729, '#surprising', '#admirable', 0.662, 'sea_lawyer', 'seaman', 'tar', 'old_salt', 'seafarer']
senticnet['marital_status'] = [-0.641, 0, 0.752, -0.681, '#angry', '#disgusting', -0.691, 'widowhood', 'marriage', 'matrimony', 'union', 'spousal_relationship']
senticnet['marjoram'] = [0.632, -0.933, 0, 0.928, '#surprising', '#admirable', 0.831, 'herb', 'oregano', 'origanum', 'pot_origanum', 'wild_origanum']
senticnet['mark'] = [-0.026, 0.155, -0.072, 0.123, '#interesting', '#admirable', 0.06, 'male_name', 'symbol', 'punctuation', 'put_ink_paper', 'font']
senticnet['mark_exam'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'review', 'double_check', 'spelling', 'correct_homework', 'check_spelling']
senticnet['mark_paper'] = [-0.08, 0, 0, 0, '#sad', '#sad', -0.027, 'make_note', 'doodle', 'write_note', 'make_mark_paper', 'write_book']
senticnet['mark_piece_of_paper'] = [-0.049, -0.022, -0.048, -0.042, '#sad', '#scared', -0.039, 'write_paper', 'become_dull', 'doodle', 'make_mark_paper', 'witting']
senticnet['mark_territory'] = [-0.121, 0, -0.066, -0.033, '#sad', '#scared', -0.073, 'follow_person', 'stay_in_house', 'cause_accident', 'sense_fear', 'guide_blind']
senticnet['marked'] = [0.837, -0.898, 0, 0.869, '#surprising', '#admirable', 0.868, 'outstanding', 'bold', 'conspicuous', 'prominent', 'striking']
senticnet['marker'] = [0.031, 0.08, 0.023, 0.069, '#interesting', '#admirable', 0.052, 'pencil', 'graphical_representation', 'photo', 'icon', 'quill_brush']
senticnet['markert'] = [0.031, 0.08, 0.023, 0.069, '#interesting', '#admirable', 0.052, 'pencil', 'pencil_art', 'pencil_sharpener', 'paper_clip', 'electric_pencil_sharpener']
senticnet['market'] = [0, 0.071, 0.009, 0.104, '#interesting', '#admirable', 0.055, 'retail_store', 'supermarket', 'grocery_store', 'farmer_market', 'own_freezer']
senticnet['market_product'] = [0.957, 0.804, 0, 0, '#joyful', '#interesting', 0.587, 'bridge_difference', 'speak_english', 'stand_alone', 'deal_card_player', 'forward_email']
senticnet['marketer'] = [0.814, -0.582, 0, 0.646, '#joyful', '#admirable', 0.681, 'seller', 'cosmetician', 'vender', 'vendor', 'trafficker']
senticnet['marketplace'] = [0.838, 0.75, 0, 0.708, '#joyful', '#interesting', 0.765, 'festival', 'party', 'banquet', 'big_event', 'rock_concert']
senticnet['markhor'] = [-0.51, 0, 0.845, -0.993, '#angry', '#disgusting', -0.783, 'bezoar_goat', 'pasang', 'wild_goat', 'goat', 'ibex']
senticnet['marking'] = [-0.912, 0, 0.796, -0.872, '#sad', '#disgusting', -0.86, 'hatch', 'hatching', 'crosshatch', 'hachure', 'shading']
senticnet['marking_pen'] = [0.022, 0, 0.015, 0.096, '#joyful', '#admirable', 0.034, 'pencil', 'pen', 'highlighter', 'pencil_sharpener', 'write_instrument']
senticnet['marksman'] = [0.757, -0.507, 0, 0.861, '#joyful', '#admirable', 0.708, 'rifleman', 'deadeye', 'sniper', 'shot', 'shooter']
senticnet['marksmanship'] = [0.93, -0.952, 0, 0.909, '#joyful', '#surprising', 0.93, 'acquirement', 'skill', 'accomplishment', 'acquisition', 'attainment']
senticnet['marmite'] = [0, -0.068, 0, 0, '#surprising', '#surprising', 0.023, 'cookie', 'bagel', 'biscuit', 'custard', 'muffin']
senticnet['marmoset'] = [0, 0.766, 0, 0.986, '#interesting', '#admirable', 0.584, 'monkey', 'fiance', 'lemur', 'beaver', 'koala']
senticnet['maroon'] = [-0.028, 0, 0.035, -0.079, '#angry', '#disgusting', -0.047, 'color', 'dark_color', 'warm_color', 'secondary_color', 'color_rainbow']
senticnet['marred'] = [-0.85, 0, 0.804, -0.855, '#sad', '#disgusting', -0.836, 'scarred', 'flyblown', 'blemished', 'acned', 'pimpled']
senticnet['marriage'] = [0.812, 0.982, 0, 0.777, '#joyful', '#interesting', 0.857, 'marry', 'marry_person', 'affair', 'infidelity', 'vow']
senticnet['marriage_ceremony'] = [0, 0.802, 0, 0.936, '#interesting', '#admirable', 0.579, 'decorate_oneself', 'wedding_ceremony', 'propose_marriage', 'engage', 'engagement']
senticnet['marriage_of_convenience'] = [0.612, -0.883, 0, 0.526, '#joyful', '#surprising', 0.674, 'marriage', 'matrimony', 'union', 'spousal_relationship', 'wedlock']
senticnet['married'] = [0.715, 0, 0, 0.793, '#joyful', '#admirable', 0.503, 'marry', 'hook_up_with', 'wed', 'conjoin', 'get_hitched_with']
senticnet['married_couple'] = [0, 0.702, 0, 0.782, '#interesting', '#admirable', 0.495, 'intelligent_person', 'grown_up', 'love', 'couple', 'offer_solace']
senticnet['married_person'] = [0.905, -0.515, 0, 0.913, '#joyful', '#admirable', 0.778, 'spouse', 'partner', 'helpmate', 'mate', 'better_half']
senticnet['marry'] = [0.916, 0.9, 0, 0.933, '#joyful', '#admirable', 0.916, 'marriage', 'infidelity', 'love', 'get_married', 'love_oneself']
senticnet['marry_kid'] = [0, 0.824, 0, 0.766, '#interesting', '#admirable', 0.53, 'loss_offreedom', 'quiet_baby', 'carry_baby', 'cum', 'lower_standard_live']
senticnet['marry_man'] = [0.889, 0.799, 0, 0, '#joyful', '#interesting', 0.563, 'service_car', 'date_woman', 'oil_hinge', 'man_post', 'date_man']
senticnet['marry_person'] = [0.916, 0.9, 0, 0.933, '#joyful', '#admirable', 0.916, 'marry', 'marriage', 'marriage_ceremony', 'wedding_ceremony', 'propose_marriage']
senticnet['mars'] = [0.959, 0.705, 0, 0, '#joyful', '#interesting', 0.555, 'another_planet', 'far_away', 'discover_universe', 'astrology', 'alien']
senticnet['marsh_cress'] = [0.758, -0.975, 0, 0.851, '#surprising', '#admirable', 0.861, 'watercress', 'yellow_watercress', 'mountain_watercress', 'common_watercress', 'great_yellowcress']
senticnet['marshal'] = [0.74, -0.539, 0, 0.641, '#joyful', '#admirable', 0.64, 'air_marshal', 'sky_marshal', 'lawman', 'law_officer', 'peace_officer']
senticnet['marshalship'] = [0.664, -0.867, 0, 0.975, '#surprising', '#admirable', 0.835, 'spot', 'berth', 'position', 'post', 'office']
senticnet['martial_art'] = [0.731, 0, 0, 0.972, '#joyful', '#admirable', 0.568, 'gymnastics', 'judo', 'jump_around', 'go_underwater', 'athletics']
senticnet['martian'] = [0.799, 0.701, 0, 0, '#joyful', '#interesting', 0.5, 'ufo', 'milky', 'space_junk', 'galaxy', 'solar_system']
senticnet['martini'] = [0.772, 0, 0, 0.729, '#joyful', '#admirable', 0.5, 'liquor_store', 'tavern', 'drinking_place', 'mix_drink', 'bar']
senticnet['marvel'] = [0.836, 0.728, 0, 0.911, '#joyful', '#admirable', 0.825, 'amazingly', 'surprisedly', 'astonishingly', 'surprised', 'surprising']
senticnet['marvelous'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'terrific', 'wondrously', 'tremendous', 'awesome', 'wondrous']
senticnet['marvelously'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'terrific', 'wondrously', 'tremendous', 'marvelous', 'wondrous']
senticnet['masculine'] = [0.074, 0.151, -0.097, 0.119, '#interesting', '#admirable', 0.082, 'small_man', 'male_person', 'male_child', 'gender', 'man_child']
senticnet['mash_potato'] = [0.084, -0.054, 0, -0.044, '#joyful', '#surprising', 0.031, 'entree', 'feast', 'satiation', 'breakfast', 'supper']
senticnet['mask'] = [0.108, -0.044, 0.043, 0.065, '#joyful', '#admirable', 0.058, 'sunglasses', 'glass', 'carnival_mask', 'drink_cup', 'focus_light']
senticnet['masking'] = [-0.586, 0, 0.568, -0.973, '#sad', '#disgusting', -0.709, 'aesthesis', 'taste', 'threshold', 'perception', 'limen']
senticnet['masquerade'] = [-0.768, 0, 0.672, -0.887, '#sad', '#disgusting', -0.776, 'attire', 'garb', 'dress', 'fancy_dress', 'costume']
senticnet['mass'] = [0.029, 0.178, 0, 0.204, '#interesting', '#admirable', 0.137, 'volume_measurement', 'tons', 'large_amount', 'size', 'heavy_weight']
senticnet['mass_hysteria'] = [-0.35, 0, -0.23, -0.112, '#sad', '#scared', -0.231, 'get_erection', 'wet_clothes', 'pain_suffer', 'obsessive_compulsive_disorder', 'catch_cold']
senticnet['mass_measure'] = [0, 0.152, 0.074, 0.207, '#interesting', '#admirable', 0.095, 'measure', 'size', 'measure_unit', 'measure_pound', 'heaviness']
senticnet['mass_murder'] = [-0.582, 0, 0.687, -0.777, '#angry', '#disgusting', -0.682, 'murder', 'slaying', 'bloodbath', 'bloodshed', 'bloodletting']
senticnet['mass_person'] = [0.086, 0.077, 0.026, 0.117, '#joyful', '#admirable', 0.085, 'big_group', 'group_of_people', 'large_number', 'bunch_person', 'large_group']
senticnet['mass_production'] = [0.086, 0.077, 0.026, 0.117, '#joyful', '#admirable', 0.085, 'production', 'business', 'company', 'employment', 'occupation']
senticnet['massacre'] = [-0.975, 0, 0.914, -0.993, '#sad', '#disgusting', -0.961, 'murder', 'slaying', 'bloodbath', 'bloodshed', 'bloodletting']
senticnet['massage'] = [0, 0.702, 0, 0.804, '#interesting', '#admirable', 0.502, 'sensual', 'hand_action', 'feel_action', 'touch', 'hand_movement']
senticnet['massage_parlor'] = [0.754, -0.823, 0, 0.947, '#surprising', '#admirable', 0.841, 'whorehouse', 'brothel', 'bordello', 'bagnio', 'house_of_prostitution']
senticnet['massive'] = [0.039, 0, 0.012, 0.298, '#joyful', '#admirable', 0.108, 'wide', 'really_big', 'large', 'huge', 'big']
senticnet['mast'] = [0, 0.798, 0, 0.97, '#interesting', '#admirable', 0.589, 'yacht', 'tree', 'dock', 'find_sea', 'pirate']
senticnet['mast_cell'] = [-0.665, 0, 0.877, -0.642, '#sad', '#angry', -0.728, 'somatic_cell', 'mastocyte', 'labrocyte', 'target_cell', 'phagocyte']
senticnet['master'] = [0.036, 0.111, -0.05, 0.054, '#interesting', '#admirable', 0.05, 'despot', 'supervisor', 'chief', 'commander', 'earl']
senticnet['master_and_commander'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'role', 'alpha_male', 'dominant', 'dominant_role', 'sergeant']
senticnet['master_bedroom'] = [0, -0.028, -0.083, -0.059, '#scared', '#disgusting', -0.038, 'mattress', 'sleep_furniture', 'cradle', 'small_bed', 'pillow']
senticnet['master_control'] = [0.764, 0, 0, 0.703, '#joyful', '#admirable', 0.489, 'stair_down', 'christian_fundamentalist', 'master', 'stair_rail', 'control']
senticnet['master_key'] = [0.943, -0.787, 0, 0.571, '#joyful', '#surprising', 0.767, 'master', 'ignition_key', 'latchkey', 'passkey', 'key']
senticnet['master_new_skill'] = [0.967, 0.867, 0, 0.947, '#joyful', '#admirable', 0.927, 'master_skill', 'lose_key', 'chair_committee', 'think_issue', 'solve_equation']
senticnet['master_skill'] = [0.985, 0.775, 0, 0.948, '#joyful', '#admirable', 0.903, 'master_new_skill', 'erase_blackboard', 'lose_key', 'solve_equation', 'lower_expectation']
senticnet['mastercard'] = [0, 0.258, -0.083, 0.119, '#interesting', '#admirable', 0.098, 'invoice', 'bill', 'owe', 'bribe', 'yellowstone']
senticnet['masterful'] = [0.835, -0.687, 0, 0.9, '#joyful', '#admirable', 0.807, 'skilled', 'masterly', 'virtuoso', 'skillful', 'skill']
senticnet['masterly'] = [0.835, -0.687, 0, 0.9, '#joyful', '#admirable', 0.807, 'masterful', 'skilled', 'virtuoso', 'skillful', 'skill']
senticnet['mastermind'] = [0.812, -0.563, 0, 0.748, '#joyful', '#admirable', 0.708, 'founder', 'beginner', 'founding_father', 'father', 'pioneer']
senticnet['masticate'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'piece_of_meat', 'flavorful', 'choose_eat', 'mouth', 'big_mouth']
senticnet['mastication'] = [0, 0, 0, 0.086, '#admirable', '#admirable', 0.029, 'masticate', 'chew', 'swallow_food', 'swallow', 'ingest_food']
senticnet['mastocyte'] = [-0.665, 0, 0.877, -0.642, '#sad', '#angry', -0.728, 'mast_cell', 'somatic_cell', 'labrocyte', 'target_cell', 'phagocyte']
senticnet['masturbate'] = [0, 0.123, 0, 0.116, '#interesting', '#admirable', 0.08, 'dry_off', 'hang_up_towel', 'towel_off', 'dry_oneself', 'fuck']
senticnet['masturbation'] = [0.89, -0.646, 0, 0.765, '#joyful', '#admirable', 0.767, 'wank', 'frottage', 'jacking_off', 'jerking_off', 'hand_job']
senticnet['mat'] = [0.029, 0.087, 0.065, 0.137, '#interesting', '#admirable', 0.063, 'archway', 'arch', 'aisle', 'passageway', 'walkway']
senticnet['match'] = [0.087, 0.113, -0.087, 0, '#joyful', '#interesting', 0.038, 'find_matchbox', 'strike_against', 'cigarette_lighter', 'matchbox', 'use_lighter']
senticnet['match_point'] = [0, 0.257, -0.133, 0.306, '#interesting', '#admirable', 0.143, 'sport', 'tennis', 'set_point', 'violent_action', 'tennis_term']
senticnet['matchbox'] = [0.087, 0.113, -0.087, 0, '#joyful', '#interesting', 0.038, 'find_match', 'strike_against', 'cigarette_lighter', 'match', 'use_lighter']
senticnet['matchless'] = [0.816, -0.599, 0, 0.947, '#joyful', '#admirable', 0.787, 'incomparable', 'nonpareil', 'one_and_only', 'peerless', 'unmatchable']
senticnet['mate'] = [0.1, 0.216, -0.185, 0.22, '#interesting', '#admirable', 0.117, 'a_lot_of_sex', 'find_woman', 'sexual_intercourse', 'warm_fuzzy_feeling', 'make_love']
senticnet['mateless'] = [-0.73, 0, 0.729, -0.981, '#sad', '#disgusting', -0.813, 'unwed', 'unwedded', 'divorced', 'unmarried', 'widowed']
senticnet['material'] = [-0.055, -0.004, 0.031, -0.036, '#sad', '#disgusting', -0.039, 'pigment', 'many_shades', 'cyan', 'green_yellow', 'cobalt']
senticnet['material_type'] = [0, 0.742, 0, 0.875, '#interesting', '#admirable', 0.539, 'type_of_material', 'fabric_type', 'soft_white', 'cloth_fabric', 'cloth_material']
senticnet['materialistic'] = [0.913, -0.635, 0, 0.961, '#joyful', '#admirable', 0.836, 'worldly', 'mercenary', 'mundane', 'material', 'economic']
senticnet['materiality'] = [0.68, -0.684, 0, 0.907, '#surprising', '#admirable', 0.757, 'concreteness', 'literalness', 'physicalness', 'corporeality', 'corporality']
senticnet['materialize'] = [-0.643, 0, 0.657, -0.847, '#angry', '#disgusting', -0.716, 'pass_off', 'fall_out', 'come_out', 'occur', 'appear']
senticnet['maternal_quality'] = [0.585, -0.885, 0, 0.615, '#surprising', '#admirable', 0.695, 'motherliness', 'parental_quality', 'quality', 'maternalism', 'fatherliness']
senticnet['maternalism'] = [0.585, -0.885, 0, 0.615, '#surprising', '#admirable', 0.695, 'motherliness', 'maternal_quality', 'quality', 'parental_quality', 'fatherliness']
senticnet['maternity'] = [0.1, 0.216, -0.185, 0.22, '#interesting', '#admirable', 0.117, 'female', 'maternity_ward', 'motherhood', 'woman', 'mother']
senticnet['maternity_ward'] = [0.1, 0.216, -0.185, 0.22, '#interesting', '#admirable', 0.117, 'maternity', 'birth', 'become_mom', 'hospital', 'have_baby']
senticnet['math'] = [0, 0.725, 0, 0.779, '#interesting', '#admirable', 0.501, 'calculus', 'algebra', 'algebraematics', 'algebra_equation', 'algebraematical_function']
senticnet['math_action'] = [-0.024, 0.08, 0.042, 0.102, '#interesting', '#admirable', 0.039, 'mathematical_operation', 'math_equation', 'math_process', 'math_operation', 'mathematical_term']
senticnet['math_answer'] = [0, 0.276, -0.122, 0.296, '#interesting', '#admirable', 0.15, 'put_together', 'outcome', 'factory_output', 'item_sell', 'result']
senticnet['math_book'] = [0, 0.969, 0, 0.957, '#interesting', '#admirable', 0.642, 'architect_office', 'science_lab', 'math_class', 'band_room', 'bluegrass_band']
senticnet['math_camp'] = [0, 0.802, 0, 0.942, '#interesting', '#admirable', 0.581, 'ceremony', 'graduation', 'graduation_ceremony', 'open_gift', 'football_game']
senticnet['math_class'] = [0, 0.934, 0, 0.772, '#interesting', '#admirable', 0.569, 'math_book', 'science_lab', 'architect_office', 'band_room', 'bluegrass_band']
senticnet['math_equation'] = [0, 0.84, 0, 0.896, '#interesting', '#admirable', 0.579, 'calculus', 'math', 'mathematics', 'algebra', 'mathematical_function']
senticnet['math_exercises'] = [0.031, 0.07, 0.025, 0.07, '#interesting', '#admirable', 0.049, 'use_computer', 'use_technology', 'calculator', 'study_math', 'use_calculator']
senticnet['math_function'] = [-0.031, 0.127, -0.055, 0.141, '#interesting', '#admirable', 0.061, 'math_operation', 'mathematical', 'math_process', 'math_action', 'mathematical_operation']
senticnet['math_homework'] = [0.997, 0.928, 0, 0, '#joyful', '#interesting', 0.642, 'study', 'do_homework', 'student', 'attend_class', 'write']
senticnet['math_operation'] = [-0.032, 0.085, 0.016, 0.114, '#interesting', '#admirable', 0.05, 'math_process', 'math_action', 'mathematical_operation', 'math_function', 'math_equation']
senticnet['math_problem'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'component', 'part_of_whole', 'fragment', 'segment', 'small_unit']
senticnet['math_process'] = [-0.047, 0.121, 0.009, 0.143, '#interesting', '#admirable', 0.069, 'math_operation', 'math_action', 'mathematical_operation', 'mathematical_term', 'math_equation']
senticnet['math_relate'] = [0, 0.799, 0, 0.752, '#interesting', '#admirable', 0.517, 'exact', 'math', 'math_subject', 'mathematical_term', 'calculation']
senticnet['math_subject'] = [0, 0.112, 0, 0.097, '#interesting', '#admirable', 0.07, 'math_relate', 'exact', 'school_study', 'median', 'method']
senticnet['math_term'] = [0, 0.172, 0.072, 0.13, '#interesting', '#admirable', 0.077, 'add', 'mathematical_operation', 'equal', 'sum', 'math_action']
senticnet['mathematic'] = [-0.027, 0.276, -0.063, 0.169, '#interesting', '#admirable', 0.118, 'logical', 'test_hypothesis', 'conjecture', 'subject', 'hypothetical']
senticnet['mathematic_sign'] = [0, 0.982, 0, 0.859, '#interesting', '#admirable', 0.614, 'electrical_unit', 'sea_movement', 'sine', 'fast_water', 'ocean_movement']
senticnet['mathematical'] = [-0.039, 0.117, 0, 0.102, '#interesting', '#admirable', 0.06, 'math_operation', 'math_function', 'math_process', 'math_action', 'mathematical_operation']
senticnet['mathematical_function'] = [0, 0.725, 0, 0.942, '#interesting', '#admirable', 0.556, 'calculus', 'math', 'mathematics', 'math_equation', 'algebra']
senticnet['mathematical_logic'] = [0.629, -0.792, 0, 0.758, '#surprising', '#admirable', 0.726, 'system_of_rules', 'symbolic_logic', 'logical_system', 'formal_logic', 'system']
senticnet['mathematical_model'] = [0, 0.775, 0, 0.865, '#interesting', '#admirable', 0.547, 'computer', 'limited', 'finite', 'machine', 'finite_state_machine']
senticnet['mathematical_operation'] = [0.934, 0.768, 0, 0, '#joyful', '#interesting', 0.567, 'math_action', 'math_equation', 'mathematical_function', 'math_process', 'math_operation']
senticnet['mathematical_skill'] = [0.993, 0.956, 0, 0, '#joyful', '#interesting', 0.65, 'remember', 'cogitate', 'contemplate', 'remember_phone_number', 'think']
senticnet['mathematical_term'] = [-0.072, 0.092, 0.032, 0.094, '#interesting', '#admirable', 0.027, 'math_action', 'mathematical_operation', 'math_process', 'math_equation', 'math_operation']
senticnet['mathematics'] = [0, 0.731, 0, 0.917, '#interesting', '#admirable', 0.549, 'math', 'algebra', 'calculus', 'physic', 'chemistry']
senticnet['maths'] = [-0.04, 0.097, 0.06, 0.146, '#interesting', '#admirable', 0.048, 'vector', 'ratio', 'length_measurement', 'measurement_unit', 'unit_of_measurement']
senticnet['matriculate'] = [0.087, 0.248, -0.194, 0.31, '#interesting', '#admirable', 0.15, 'enroll', 'enroll_school', 'enroll_class', 'pay_tuition', 'start_college']
senticnet['matrimony'] = [0.087, 0.248, -0.194, 0.31, '#interesting', '#admirable', 0.15, 'holy_matrimony', 'behavior', 'new_person', 'become_parent', 'wedding']
senticnet['matrix'] = [0.757, -0.635, 0, 0.501, '#joyful', '#surprising', 0.631, 'panoply', 'row', 'table', 'tabular_array', 'array']
senticnet['matted'] = [0.59, -0.967, 0, 0.785, '#surprising', '#admirable', 0.781, 'enmeshed', 'intermeshed', 'rootbound', 'tangled', 'knotty']
senticnet['matter'] = [0, 0.846, 0, 0.974, '#interesting', '#admirable', 0.607, 'molecule', 'neutron', 'hydrogen', 'proton', 'substance']
senticnet['matter_lot'] = [0.946, 0, 0, 0.934, '#joyful', '#admirable', 0.627, 'important', 'dangerous_activity', 'person', 'stockholder', 'matter']
senticnet['matter_to'] = [0.803, -0.74, 0, 0.917, '#joyful', '#admirable', 0.82, 'fascinate', 'intrigue', 'bear_on', 'touch', 'concern']
senticnet['mattress'] = [0, 0.171, -0.056, 0.102, '#interesting', '#admirable', 0.072, 'bed', 'bead', 'linen_cupboard', 'bed_cover', 'seduce']
senticnet['maturate'] = [0.7, -0.646, 0, 0.953, '#joyful', '#admirable', 0.766, 'find', 'ripen', 'find_oneself', 'grow_up', 'develop']
senticnet['maturation'] = [-0.595, 0, 0.983, -0.675, '#angry', '#disgusting', -0.751, 'growth', 'growing', 'caenogenesis', 'development', 'ontogeny']
senticnet['mature'] = [0.568, -0.796, 0, 0.804, '#surprising', '#admirable', 0.723, 'age', 'get_on', 'senesce', 'dote', 'maturate']
senticnet['matured'] = [0.909, 0.983, 0, 0, '#joyful', '#interesting', 0.631, 'old', 'elderly', 'ripped', 'age_well', 'mentality']
senticnet['maturity'] = [0, 0.075, 0, 0.159, '#interesting', '#admirable', 0.078, 'many_plants', 'blossom', 'development', 'poppy', 'tree_item']
senticnet['maturity_date'] = [0.863, -0.55, 0, 0.653, '#joyful', '#admirable', 0.689, 'day', 'maturity', 'date', 'due_date', 'birthday']
senticnet['maudlin'] = [0, 0, -0.753, -0.986, '#scared', '#disgusting', -0.58, 'kitschy', 'mawkish', 'drippy', 'hokey', 'bathetic']
senticnet['maul'] = [-0.624, 0, 0.756, -0.626, '#angry', '#disgusting', -0.669, 'vitiate', 'mar', 'deface', 'mangle', 'impair']
senticnet['maulers'] = [0.883, -0.593, 0, 0.533, '#joyful', '#surprising', 0.67, 'hooks', 'meat_hooks', 'hand', 'right', 'left']
senticnet['mauve'] = [0.591, -0.553, 0, 0.514, '#joyful', '#surprising', 0.553, 'violet', 'purple', 'lavender', 'reddish_purple', 'royal_purple']
senticnet['maverick'] = [0.742, -0.965, 0, 0.58, '#joyful', '#surprising', 0.762, 'dissident', 'beat', 'bohemian', 'recusant', 'enfant_terrible']
senticnet['max'] = [0, 0.075, 0, 0.159, '#interesting', '#admirable', 0.078, 'maximum', 'highest', 'utmost', 'top', 'most']
senticnet['maximum'] = [0.052, 0, 0, 0.322, '#joyful', '#admirable', 0.125, 'a_lot', 'abundance', 'plenty', 'superlative', 'comparative']
senticnet['mayonaise'] = [0.041, -0.071, 0.034, 0, '#joyful', '#surprising', 0.026, 'butter', 'bagel', 'pie', 'noodle', 'muffin']
senticnet['mayonnaise'] = [-0.086, -0.075, 0.029, -0.178, '#sad', '#disgusting', -0.073, 'sour_milk', 'moldy_food', 'horseradish', 'box_cereal', 'bottle_water']
senticnet['mayor'] = [0.079, 0.152, -0.061, 0, '#joyful', '#interesting', 0.057, 'president', 'rogue', 'supervisor', 'ambassador', 'leader']
senticnet['mayweed'] = [0.782, -0.695, 0, 0.684, '#joyful', '#surprising', 0.72, 'composite_plant', 'stinking_composite_plant', 'stinking_chamomile', 'dog_fennel', 'oxeye_daisy']
senticnet['mazer'] = [-0.519, 0, 0.562, -0.699, '#angry', '#disgusting', -0.593, 'fishbowl', 'fish_bowl', 'goldfish_bowl', 'jorum', 'bowl']
senticnet['mazurka'] = [-0.744, 0, 0.501, -0.99, '#sad', '#disgusting', -0.745, 'farandole', 'folk_dance', 'polka', 'morris_dance', 'morris_dancing']
senticnet['mc_donald'] = [0.06, -0.012, 0, 0, '#joyful', '#surprising', 0.024, 'eat_food', 'restaurant', 'meal', 'fast', 'fast_food']
senticnet['mcardle_disease'] = [-0.688, 0, 0.898, -0.973, '#angry', '#disgusting', -0.853, 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect', 'congenital_disease']
senticnet['meadow'] = [0.026, 0, 0, 0.073, '#joyful', '#admirable', 0.033, 'state_park', 'arboretum', 'park', 'grass', 'backyard']
senticnet['meadow_buttercup'] = [-0.808, 0, 0.632, -0.71, '#sad', '#disgusting', -0.717, 'herb', 'buttercup', 'tall_buttercup', 'tall_crowfoot', 'tall_field_buttercup']
senticnet['meadow_grass'] = [-0.766, 0, 0.513, -0.722, '#sad', '#disgusting', -0.667, 'foxtail', 'foxtail_grass', 'manna_grass', 'sweet_grass', 'wood_meadowgrass']
senticnet['meadow_saxifrage'] = [-0.565, 0, 0.848, -0.801, '#angry', '#disgusting', -0.738, 'herb', 'yellow_mountain_saxifrage', 'breakstone', 'mossy_saxifrage', 'western_saxifrage']
senticnet['meadowgrass'] = [-0.868, 0, 0.737, -0.551, '#sad', '#angry', -0.719, 'foxtail', 'foxtail_grass', 'manna_grass', 'sweet_grass', 'wood_meadowgrass']
senticnet['meager'] = [-0.949, 0, 0.952, -0.838, '#sad', '#angry', -0.913, 'miserable', 'scanty', 'exiguous', 'spare', 'hardscrabble']
senticnet['meagerly'] = [-0.929, 0, 0.503, -0.626, '#sad', '#disgusting', -0.686, 'miserable', 'scanty', 'exiguous', 'spare', 'hardscrabble']
senticnet['meagre'] = [-0.934, 0, 0.863, -0.514, '#sad', '#angry', -0.77, 'miserable', 'scanty', 'exiguous', 'spare', 'hardscrabble']
senticnet['meagreness'] = [-0.939, 0, 0.884, -0.785, '#sad', '#angry', -0.869, 'insufficiency', 'sparseness', 'sparsity', 'abstemiousness', 'lack_of_quantity']
senticnet['meal'] = [0.062, 0, 0.027, 0.055, '#joyful', '#admirable', 0.03, 'porridge', 'appetizer', 'broth', 'hamburger', 'hearty']
senticnet['meal_served'] = [0.751, 0.987, 0, 0, '#joyful', '#interesting', 0.579, 'meet_friend', 'eat_out', 'enjoy_food', 'give_party', 'satisfy_hunger']
senticnet['meal_ticket'] = [0.921, -0.571, 0, 0.962, '#joyful', '#admirable', 0.818, 'book_token', 'coupon', 'luncheon_voucher', 'twofer', 'commercial_document']
senticnet['meal_time'] = [0.146, 0.114, -0.058, 0.129, '#joyful', '#admirable', 0.11, 'dinner', 'table_set', 'dinner_table', 'dinner_meal', 'meal']
senticnet['mealy'] = [0, 0, -0.946, -0.987, '#scared', '#disgusting', -0.644, 'coarse-grained', 'gritty', 'grainy', 'farinaceous', 'granular']
senticnet['mean'] = [0.961, 0.877, 0, 0, '#joyful', '#interesting', 0.613, 'cruel', 'petition', 'anti', 'exclamation', 'bad']
senticnet['mean_life'] = [0.219, 0.158, -0.092, 0.164, '#joyful', '#admirable', 0.15, 'nice_place_to_live', 'complement', 'reliability', 'calm_mind', 'best_life']
senticnet['mean_person'] = [0, 0, 0.974, -0.915, '#angry', '#disgusting', -0.63, 'conquer_enemy', 'go_war', 'gain_territory', 'blown_up', 'make_war']
senticnet['meander'] = [0, 0.778, 0, 0.959, '#interesting', '#admirable', 0.579, 'trot', 'step_out', 'step_aside', 'progress', 'enter_place']
senticnet['meaning'] = [0, 0.869, 0, 0.887, '#interesting', '#admirable', 0.585, 'protect_from_sun', 'shade', 'concealer', 'corrector', 'sunglasses']
senticnet['meaningful'] = [0.738, -0.525, 0, 0.775, '#joyful', '#admirable', 0.679, 'significant', 'meaning', 'purposeful', 'substantive', 'pregnant']
senticnet['meaningless'] = [-0.78, 0, 0.783, -0.621, '#sad', '#angry', -0.728, 'insignificant', 'mindless', 'empty', 'nonsense', 'vacuous']
senticnet['meaninglessness'] = [0.863, -0.856, 0, 0.541, '#joyful', '#surprising', 0.753, 'balderdash', 'piffle', 'content', 'empty_words', 'empty_talk']
senticnet['meanness'] = [0, 0, 0.906, -0.974, '#angry', '#disgusting', -0.627, 'anger', 'screw_up', 'disrespect', 'hear_bad_news', 'car_wreck']
senticnet['means_of_transport'] = [0.027, 0, 0.026, 0.073, '#joyful', '#admirable', 0.025, 'large_automobile', 'expensive_car', 'limousine', 'automatic_car', 'roulotte']
senticnet['means_of_transportation'] = [0, -0.01, 0, 0.067, '#surprising', '#admirable', 0.026, 'form_of_transportation', 'know_how_drive', 'find_car_key', 'long_car', 'machine_transportation']
senticnet['measles'] = [-0.812, 0, 0.9, -0.825, '#angry', '#disgusting', -0.846, 'infectious_disease', 'polio', 'malady', 'sickness', 'itch']
senticnet['measure'] = [0, 0.1, 0.097, 0.155, '#interesting', '#admirable', 0.053, 'spatial_dimension', 'imperial_measurement', 'length', 'measurement', 'measurement_unit']
senticnet['measure_angle'] = [0, -0.042, 0.094, -0.101, '#angry', '#disgusting', -0.051, 'make_musical_sound', 'make_music', 'play_orchestra', 'play_music', 'annoy_mom']
senticnet['measure_degree'] = [0.062, 0.082, 0.047, 0, '#joyful', '#interesting', 0.032, 'celsius', 'temperature_measure', 'measure_heat', 'temperature_measurement', 'heat_measure']
senticnet['measure_device'] = [0, 0.084, 0.076, 0.144, '#interesting', '#admirable', 0.051, 'measurement_tool', 'measure_tool', 'measure_inch', 'measure', 'length']
senticnet['measure_distance'] = [0, 0.951, 0, 0.906, '#interesting', '#admirable', 0.619, 'distance_measurement', 'distance_measure', 'length_measurement', 'kilometer', 'meter']
senticnet['measure_heat'] = [0.062, 0.082, 0.047, 0, '#joyful', '#interesting', 0.032, 'celsius', 'temperature_measure', 'measure_degree', 'temperature_measurement', 'heat_measure']
senticnet['measure_inch'] = [0, 0.084, 0.076, 0.144, '#interesting', '#admirable', 0.051, 'measurement_tool', 'measure_tool', 'measure_device', 'measure', 'length']
senticnet['measure_ingredient'] = [0, -0.01, 0.014, -0.102, '#angry', '#disgusting', -0.035, 'burp', 'prepare_ingredient', 'say_grace', 'add_spice', 'swallow_food']
senticnet['measure_length'] = [0, 0.763, 0, 0.958, '#interesting', '#admirable', 0.574, 'length_measurement', 'measure', 'meter', 'size_up', 'measurement_unit']
senticnet['measure_liquid'] = [0.025, 0, 0.016, 0.067, '#joyful', '#admirable', 0.025, 'liquid', 'ferment_beverage', 'carbonate_drink', 'serve_wine', 'good_drink']
senticnet['measure_passage_time'] = [0.154, 0.086, 0.03, 0.153, '#joyful', '#admirable', 0.121, 'keep_track_time', 'know_time', 'time_event', 'time_runner', 'time']
senticnet['measure_person'] = [0.755, 0.994, 0, 0, '#joyful', '#interesting', 0.583, 'stay_young', 'cycle', 'era', 'many_years', 'know_time']
senticnet['measure_pound'] = [0, 0.138, 0.077, 0.186, '#interesting', '#admirable', 0.082, 'weight_measurement', 'heavy_weight', 'mass_measure', 'measurement_device', 'heaviness']
senticnet['measure_time'] = [0, 0.138, 0.077, 0.186, '#interesting', '#admirable', 0.082, 'show_time', 'timekeeper', 'measure', 'keep_time', 'time_measure']
senticnet['measure_tool'] = [0, 0.121, 0.054, 0.158, '#interesting', '#admirable', 0.075, 'measurement_tool', 'measure_inch', 'measure_device', 'yardstick', 'measurement_device']
senticnet['measure_unit'] = [0, 0.122, 0.111, 0.162, '#interesting', '#admirable', 0.058, 'count', 'total_number', 'imperial_measurement', 'mass_measure', 'list_number']
senticnet['measureless'] = [-0.808, 0, 0.761, -0.705, '#sad', '#angry', -0.758, 'illimitable', 'limitless', 'immeasurable', 'unmeasured', 'abysmal']
senticnet['measurement'] = [0, 0.097, 0.093, 0.142, '#interesting', '#admirable', 0.049, 'spatial_dimension', 'length', 'measure', 'imperial_measurement', 'measurement_unit']
senticnet['measurement_device'] = [0, 0.125, 0.074, 0.097, '#interesting', '#admirable', 0.049, 'weigh', 'balance', 'proportion', 'measure_pound', 'weight_measurement']
senticnet['measurement_tool'] = [0, 0.093, 0.061, 0.147, '#interesting', '#admirable', 0.06, 'measure_tool', 'measure_device', 'measure_inch', 'yardstick', 'measure_pound']
senticnet['measurement_unit'] = [0, 0.097, 0.088, 0.142, '#interesting', '#admirable', 0.05, 'imperial_measurement', 'length_measurement', 'measure', 'unit_of_measurement', 'measurement']
senticnet['meat'] = [0.719, 0.896, 0, 0, '#joyful', '#interesting', 0.538, 'slice_meat', 'toast', 'make_flour', 'bake_bread', 'bread']
senticnet['meat_cut'] = [0.039, -0.009, 0.018, 0.075, '#joyful', '#admirable', 0.035, 'high_protein', 'red_meat', 'pig_meat', 'food_item', 'dairy_product']
senticnet['meat_eater'] = [0, 0, -0.071, 0, '#scared', '#scared', -0.024, 'reptile', 'animal', 'predator', 'alligator', 'river']
senticnet['meat_hooks'] = [0.883, -0.593, 0, 0.533, '#joyful', '#surprising', 0.67, 'hooks', 'hand', 'maulers', 'right', 'left']
senticnet['meat_vegetable'] = [0.07, 0.084, 0.023, 0, '#joyful', '#interesting', 0.044, 'hearty', 'porridge', 'hot_liquid', 'liquid_food', 'broth']
senticnet['meatloaf'] = [0.028, -0.073, 0, 0, '#joyful', '#surprising', 0.034, 'casserole', 'delicious_meal', 'hot_dog_bun', 'hamburger', 'hot_dog']
senticnet['mechanic'] = [0.87, 0.822, 0, 0.717, '#joyful', '#interesting', 0.803, 'mechanical', 'mechanical_device', 'mechanical_pencil', 'mechanic_engineer', 'mechanical_object']
senticnet['mechanic_engineer'] = [0.87, 0.822, 0, 0.717, '#joyful', '#interesting', 0.803, 'mechanical', 'mechanical_device', 'mechanical_pencil', 'mechanic', 'mechanical_object']
senticnet['mechanical'] = [0, 0.805, 0, 0.895, '#interesting', '#admirable', 0.567, 'mechanical_device', 'move_part', 'device', 'make_metal', 'ore']
senticnet['mechanical_device'] = [0, -0.004, 0, 0.097, '#surprising', '#admirable', 0.034, 'mechanism', 'mechanical', 'move_part', 'device', 'machinery']
senticnet['mechanical_graphite_pencil'] = [0.031, 0.08, 0.023, 0.069, '#interesting', '#admirable', 0.052, 'marker', 'graphite_pencil', 'pen', 'pencil', 'stamp_pad']
senticnet['mechanical_object'] = [0.87, 0.822, 0, 0.717, '#joyful', '#interesting', 0.803, 'mechanical', 'mechanical_device', 'mechanical_pencil', 'mechanic_engineer', 'mechanic']
senticnet['mechanical_pencil'] = [0.818, 0.827, 0, 0, '#joyful', '#interesting', 0.548, 'marker', 'stamp_pad', 'pen', 'graphite_pencil', 'memo_pad']
senticnet['mechanical_piano'] = [-0.988, 0, 0.614, -0.905, '#sad', '#disgusting', -0.836, 'grand', 'upright', 'grand_piano', 'piano', 'player_piano']
senticnet['mechanical_room'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'engineer', 'pilot', 'computer', 'instructions', 'control_machine']
senticnet['mechanism'] = [0.028, 0, 0, 0.131, '#joyful', '#admirable', 0.053, 'mechanical_device', 'complex_machine', 'human_invention', 'machine', 'device']
senticnet['medal'] = [0.87, 0.822, 0, 0.717, '#joyful', '#interesting', 0.803, 'gold', 'bronze', 'alloy', 'titanium', 'copper']
senticnet['medallion'] = [0.02, 0.085, -0.056, 0.085, '#interesting', '#admirable', 0.045, 'gold', 'silver', 'medal', 'carat', 'chrome']
senticnet['meddler'] = [-0.641, 0, 0.71, -0.953, '#angry', '#disgusting', -0.768, 'buttinsky', 'unwelcome_person', 'killjoy', 'backseat_driver', 'busybody']
senticnet['meddlesome'] = [-0.997, 0, 0.851, -0.896, '#sad', '#disgusting', -0.915, 'interfering', 'intrusive', 'meddling', 'officious', 'busybodied']
senticnet['meddling'] = [-0.997, 0, 0.851, -0.896, '#sad', '#disgusting', -0.915, 'interfering', 'meddlesome', 'intrusive', 'officious', 'busybodied']
senticnet['media'] = [0, 0.078, 0, 0.143, '#interesting', '#admirable', 0.074, 'written', 'medium', 'print_medium', 'storage_device', 'readable']
senticnet['mediacy'] = [-0.629, 0, 0.69, -0.765, '#angry', '#disgusting', -0.695, 'deviousness', 'indirectness', 'mediateness', 'characteristic', 'allusiveness']
senticnet['median'] = [0.109, 0.132, 0.085, 0.148, '#interesting', '#admirable', 0.101, 'middle', 'mathematical_term', 'average', 'mathematical_operation', 'in_middle']
senticnet['median_nerve'] = [-0.413, 0, -0.284, -0.058, '#sad', '#scared', -0.252, 'numbness', 'carpal_tunnel_syndrome', 'weakness', 'pain', 'muscle_damage']
senticnet['mediateness'] = [-0.629, 0, 0.69, -0.765, '#angry', '#disgusting', -0.695, 'deviousness', 'mediacy', 'indirectness', 'characteristic', 'allusiveness']
senticnet['mediator'] = [0.796, 0.776, 0, 0, '#joyful', '#interesting', 0.524, 'job_done', 'arbitrator', 'consider_evidence', 'determine_guilt_innocence', 'become_judge']
senticnet['medic'] = [-0.026, 0.082, -0.122, -0.191, '#scared', '#disgusting', -0.086, 'soldier', 'good_man', 'warrior', 'enemy', 'terrorist']
senticnet['medical'] = [0, 0.852, 0, 0.958, '#interesting', '#admirable', 0.603, 'better_others', 'better_others_person', 'trustworthy', 'doctor_patient', 'treat_illness']
senticnet['medical_aid'] = [-0.628, 0, 0.987, -0.742, '#angry', '#disgusting', -0.786, 'disinfection', 'treatment', 'hospice', 'digitalization', 'bloodletting']
senticnet['medical_build'] = [-0.024, -0.005, -0.049, 0, '#sad', '#scared', -0.023, 'medikit', 'manchester', 'ghetto', 'metropolitan_city', 'new_york_city']
senticnet['medical_care'] = [0.371, 0.243, -0.123, 0.301, '#joyful', '#admirable', 0.264, 'good_parent', 'live_long_healthy_life', 'wellness', 'live_ripe_old_age', 'live_well']
senticnet['medical_checkup'] = [0.934, -0.884, 0, 0.797, '#joyful', '#surprising', 0.872, 'scan', 'checkup', 'scrutiny', 'medical_examination', 'medical_exam']
senticnet['medical_condition'] = [-0.793, 0, -0.846, 0, '#sad', '#scared', -0.546, 'electric_current', 'human_condition', 'sometimes_painful', 'ailment', 'difficult_problem']
senticnet['medical_diagnosis'] = [0.94, -0.625, 0, 0.929, '#joyful', '#admirable', 0.831, 'prospect', 'diagnosis', 'check_up', 'medical_prognosis', 'prognosis']
senticnet['medical_doctor'] = [-0.04, 0, -0.142, -0.099, '#scared', '#disgusting', -0.094, 'physician', 'nurse', 'doctor', 'connoisseur', 'surgeon']
senticnet['medical_equipment'] = [0, 0.108, 0.01, 0.121, '#interesting', '#admirable', 0.073, 'use_screwdriver', 'tool', 'study_physic', 'take_pulse', 'garden_implement']
senticnet['medical_exam'] = [-0.05, 0, -0.115, 0, '#sad', '#scared', -0.055, 'medical_procedure', 'operation', 'spasm', 'cure', 'dissection']
senticnet['medical_examination'] = [-0.032, 0, -0.085, 0, '#sad', '#scared', -0.039, 'write', 'write_poem', 'sign_contract', 'medical_exam', 'make_shop_list']
senticnet['medical_instrument'] = [0, 0.995, 0, 0.849, '#interesting', '#admirable', 0.615, 'treatment', 'cystoscope', 'gastroscope', 'otoscope', 'panendoscope']
senticnet['medical_kit'] = [-0.063, -0.03, 0, -0.172, '#sad', '#disgusting', -0.068, 'seam', 'needle_thread', 'sew_term', 'stitch', 'bandage']
senticnet['medical_office'] = [-0.032, 0, -0.15, -0.141, '#scared', '#disgusting', -0.108, 'doctor_office', 'clinic', 'hospital', 'medical_school', 'nurse']
senticnet['medical_person'] = [0, 0.934, 0, 0.817, '#interesting', '#admirable', 0.584, 'trustworthy', 'medical', 'doctor_patient', 'heal_disease', 'human_truthful']
senticnet['medical_problem'] = [-0.213, 0.118, -0.224, -0.059, '#sad', '#scared', -0.126, 'ailment', 'malady', 'sleep_disorder', 'polio', 'human_condition']
senticnet['medical_procedure'] = [0, 0.723, 0, 0.847, '#interesting', '#admirable', 0.523, 'cure', 'operation', 'doctor_surgery', 'treatment', 'medicine']
senticnet['medical_professional'] = [0, 0.936, 0, 0.879, '#interesting', '#admirable', 0.605, 'medical_person', 'heal_disease', 'specialist', 'trustworthy', 'vocation']
senticnet['medical_prognosis'] = [0.94, -0.625, 0, 0.929, '#joyful', '#admirable', 0.831, 'prospect', 'diagnosis', 'check_up', 'medical_diagnosis', 'prognosis']
senticnet['medical_record'] = [-0.041, 0, -0.144, -0.121, '#scared', '#disgusting', -0.102, 'syringe', 'latex_glove', 'examination_table', 'cure', 'medicine']
senticnet['medical_school'] = [0, 0.95, 0, 0.971, '#interesting', '#admirable', 0.64, 'pass_exam', 'become_nurse', 'become_doctor', 'go_to_school', 'study_medicine']
senticnet['medical_science'] = [0.701, -0.633, 0, 0.929, '#joyful', '#admirable', 0.754, 'pathology', 'medicine', 'medical_specialty', 'radiology', 'serology']
senticnet['medical_scientist'] = [0.904, -0.93, 0, 0.639, '#joyful', '#surprising', 0.824, 'toxicologist', 'epidemiologist', 'immunologist', 'serologist', 'scientist']
senticnet['medical_specialty'] = [0.701, -0.633, 0, 0.929, '#joyful', '#admirable', 0.754, 'pathology', 'medicine', 'medical_science', 'radiology', 'serology']
senticnet['medical_test'] = [0.05, -0.036, 0.014, 0, '#joyful', '#surprising', 0.024, 'angler', 'card_type', 'man', 'test', 'workman']
senticnet['medical_therapy'] = [0.722, 0.865, 0, 0.748, '#interesting', '#admirable', 0.778, 'vaccination', 'vaccine', 'doctor', 'medicine', 'hospital']
senticnet['medicament'] = [0.701, -0.767, 0, 0.904, '#surprising', '#admirable', 0.791, 'curative', 'heal', 'medicine', 'get_cured', 'take_care']
senticnet['medication'] = [0, 0.862, 0, 0.8, '#interesting', '#admirable', 0.554, 'antibiotic', 'cure', 'medicine', 'ibuprofen', 'analgesic']
senticnet['medicinal_drug'] = [0.564, -0.772, 0, 0.862, '#surprising', '#admirable', 0.733, 'curative', 'heal', 'medicine', 'get_cured', 'take_care']
senticnet['medicinal_leech'] = [-0.716, 0, 0.605, -0.623, '#sad', '#disgusting', -0.648, 'leech', 'horseleech', 'annelid', 'annelid_worm', 'segmented_worm']
senticnet['medicine'] = [0, 0.731, 0, 0.946, '#interesting', '#admirable', 0.559, 'sleep_drug', 'analgesic', 'ibuprofen', 'antibiotic', 'cure']
senticnet['medicine_cabinet'] = [-0.025, -0.039, -0.054, -0.121, '#scared', '#disgusting', -0.054, 'drugstore', 'bathroom_cabinet', 'pharmacy', 'medicine_chest', 'own_bathroom']
senticnet['medicine_chest'] = [-0.036, -0.018, -0.085, -0.161, '#scared', '#disgusting', -0.088, 'medicine_cabinet', 'drugstore', 'pharmacy', 'bathroom_cabinet', 'first-aid_kit']
senticnet['medieval'] = [0.021, 0.119, 0, 0.129, '#interesting', '#admirable', 0.09, 'manor', 'palace', 'castle', 'tower', 'chess_game']
senticnet['medieval_time'] = [-0.035, 0, -0.132, -0.086, '#scared', '#disgusting', -0.084, 'underworld', 'war', 'arsenal', 'samurai', 'war_zone']
senticnet['medikit'] = [-0.024, -0.005, -0.049, 0, '#sad', '#scared', -0.023, 'medical_build', 'manchester', 'ghetto', 'metropolitan_city', 'new_york_city']
senticnet['mediocrity'] = [0, 0.85, 0, 0.764, '#interesting', '#admirable', 0.538, 'exclusion', 'pugilist', 'abduction', 'citation', 'betterment']
senticnet['meditate'] = [0, 0, 0, 0.729, '#admirable', '#admirable', 0.243, 'drink_cup_coffee', 'read_good_book', 'feel_little_tired', 'toss_turn', 'get_sleep']
senticnet['meditation'] = [0.088, 0.135, 0, 0, '#joyful', '#interesting', 0.074, 'watch_others', 'meditate', 'imagine', 'mantra', 'dance_music']
senticnet['meditative'] = [0, 0.748, 0, 0.966, '#interesting', '#admirable', 0.571, 'pondering', 'ruminative', 'broody', 'contemplative', 'think']
senticnet['medium'] = [0.039, 0.083, 0, 0.186, '#interesting', '#admirable', 0.103, 'media', 'grammar_part', 'output', 'description', 'ads']
senticnet['meek'] = [0.625, -0.501, 0, 0.822, '#joyful', '#admirable', 0.649, 'docile', 'tame', 'yielding', 'sheeplike', 'sheepish']
senticnet['meekness'] = [-0.771, 0, -0.813, 0, '#sad', '#scared', -0.528, 'submission', 'self-deprecating', 'self-depreciation', 'humbleness', 'demeaning']
senticnet['meet'] = [0.62, -0.917, 0, 0.766, '#surprising', '#admirable', 0.768, 'accommodate', 'satisfy', 'fulfill', 'conform_to', 'please']
senticnet['meet_another_person'] = [0.994, 0.862, 0, 0.899, '#joyful', '#admirable', 0.918, 'lucky', 'sit_rock_chair', 'come_house', 'drink_tea', 'quit_work']
senticnet['meet_at_coffee_shop'] = [0, 0, 0, 0.077, '#admirable', '#admirable', 0.026, 'find_person', 'contact_friend', 'arrange_meet', 'chat', 'call_phone']
senticnet['meet_family'] = [0.101, -0.237, 0.031, 0.105, '#surprising', '#admirable', 0.137, 'finish_work', 'go_home', 'relax_time', 'go_to_sleep', 'end_day']
senticnet['meet_famous_person'] = [0.878, 0, 0, 0.782, '#joyful', '#admirable', 0.553, 'eat_together', 'feel_pleasure', 'show_love', 'gain_respect', 'hug']
senticnet['meet_friend'] = [0.048, -0.08, 0.036, 0, '#joyful', '#surprising', 0.031, 'meet_person', 'chit_chat', 'make_friend', 'meet_girl', 'socialize']
senticnet['meet_friend_for_lunch'] = [0.751, 0.987, 0, 0, '#joyful', '#interesting', 0.579, 'eat_pudding', 'eat_food', 'serve_meal', 'eat_out', 'consume_nourishment']
senticnet['meet_friends'] = [0.751, 0.987, 0, 0, '#joyful', '#interesting', 0.579, 'meet_new_friend', 'friend', 'go_outdoors', 'have_fun', 'meet_friend_for_lunch']
senticnet['meet_girl'] = [0.05, -0.059, 0, 0.054, '#surprising', '#admirable', 0.054, 'flirt', 'make_friend', 'meet_friend', 'enjoy_company_friend', 'meet_interesting_person']
senticnet['meet_girl_of_your_dream'] = [0.751, 0.987, 0, 0, '#joyful', '#interesting', 0.579, 'meet_girl', 'flirt', 'hold_breath', 'meet_interesting_person', 'fall_in_love']
senticnet['meet_girl_of_your_dreams'] = [-0.088, -0.013, 0.017, -0.064, '#sad', '#disgusting', -0.052, 'jump_air', 'run_far', 'pick_berry', 'monitor_heart_rate', 'pick_flower']
senticnet['meet_goal'] = [0.792, 0.874, 0, 0, '#joyful', '#interesting', 0.555, 'make_money', 'receive_money', 'get_job_done', 'make_live', 'support_family']
senticnet['meet_greet'] = [0, 0, 0, 0.768, '#admirable', '#admirable', 0.256, 'offer_help', 'desire_help', 'reply_question', 'lower_expectation', 'erase_blackboard']
senticnet['meet_interesting_person'] = [0.05, -0.059, 0, 0.054, '#surprising', '#admirable', 0.054, 'flirt', 'make_friend', 'meet_friend', 'enjoy_company_friend', 'meet_girl']
senticnet['meet_member_opposite_sex'] = [0.716, 0, 0, 0.718, '#joyful', '#admirable', 0.478, 'social_interaction', 'get_drunk', 'get_hammered', 'good_time', 'get_to_know_person']
senticnet['meet_need'] = [0.027, 0.259, -0.212, 0.255, '#interesting', '#admirable', 0.11, 'help_person', 'meeting', 'helpful', 'bring_food', 'ask_politely']
senticnet['meet_neighbor'] = [0, 0.097, 0, 0.059, '#interesting', '#admirable', 0.052, 'say_hi', 'neighbor', 'talk_neighbor', 'see_neighbor', 'help_neighbor']
senticnet['meet_new_friend'] = [0.713, 0.879, 0, 0, '#joyful', '#interesting', 0.531, 'win_loose', 'restore_energy', 'blow_off_steam', 'meet_others', 'feel_rejuvenated']
senticnet['meet_new_person'] = [0.797, 0, 0, 0.892, '#joyful', '#admirable', 0.563, 'become_drunk', 'get_wasted', 'act_stupid', 'pick_up_woman', 'drunkenness']
senticnet['meet_old_friend'] = [-0.111, -0.045, 0, -0.104, '#sad', '#disgusting', -0.057, 'get_lose', 'arrive_late', 'get_stick_traffic', 'honk_horn', 'plan_day']
senticnet['meet_other_person'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'meet_new_person', 'celebrate_wedding', 'get_drink', 'social_interaction', 'meet_member_opposite_sex']
senticnet['meet_others'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'good_time', 'get_know', 'make_new_friend', 'get_to_know_person', 'social_interaction']
senticnet['meet_people'] = [0.985, 0, 0, 0.931, '#joyful', '#admirable', 0.639, 'get_social_contact', 'go_party', 'go_out', 'expand_horizon', 'cultural_experience']
senticnet['meet_person'] = [0.048, -0.08, 0.036, 0, '#joyful', '#surprising', 0.031, 'chit_chat', 'meet_friend', 'make_friend', 'meet_girl', 'socialize']
senticnet['meet_place'] = [0.092, 0, 0, 0, '#joyful', '#joyful', 0.031, 'open_night', 'metal_stick', 'hangout', 'water_hole', 'place_to_drink']
senticnet['meet_up'] = [0.12, -0.192, 0, -0.096, '#joyful', '#surprising', 0.072, 'social_gathering', 'bash', 'radical', 'gathering', 'get_together']
senticnet['meet_woman'] = [0.081, -0.058, 0, -0.032, '#joyful', '#surprising', 0.036, 'drink_alcohol', 'consume_alcoholic_beverage', 'drink_much', 'hit_bottle', 'drink_liquor']
senticnet['meeting'] = [0.044, 0.08, -0.078, 0.095, '#interesting', '#admirable', 0.047, 'group_meet', 'diplomacy', 'head_committee', 'proverb', 'show_how']
senticnet['megahit'] = [0.916, -0.934, 0, 0.674, '#joyful', '#surprising', 0.841, 'smash', 'bang', 'smasher', 'strike', 'hit']
senticnet['megalomania'] = [0.618, -0.594, 0, 0.773, '#joyful', '#admirable', 0.662, 'insanity', 'psychosis', 'psychopathy', 'psychological_state', 'psychological_condition']
senticnet['megrim'] = [-0.849, 0.205, -0.484, -0.035, '#sad', '#scared', -0.388, 'depressed', 'sadness', 'blues', 'feel_blue', 'demoralization']
senticnet['melancholiac'] = [-0.645, 0, 0.854, -0.861, '#angry', '#disgusting', -0.787, 'melancholic', 'sick_person', 'diseased_person', 'sufferer', 'depressive']
senticnet['melancholic'] = [-0.747, 0.292, -0.428, -0.064, '#sad', '#scared', -0.316, 'lowness', 'dispiritedness', 'low-spiritedness', 'dejectedness', 'downheartedness']
senticnet['melancholy'] = [-0.952, 0, 0, -0.985, '#sad', '#disgusting', -0.646, 'unhappy', 'sorrow', 'guilty', 'grim', 'heartache']
senticnet['meliorate'] = [0.526, -0.86, 0, 0.932, '#surprising', '#admirable', 0.773, 'assuage', 'perfect', 'fructify', 'relieve', 'sublimate']
senticnet['meliorist'] = [-0.715, 0, 0.967, -0.683, '#sad', '#angry', -0.788, 'dry', 'insurgent', 'militant', 'passive_resister', 'demonstrator']
senticnet['mellifluous'] = [0.704, -0.502, 0, 0.923, '#joyful', '#admirable', 0.71, 'melodic', 'mellisonant', 'dulcet', 'lyrical', 'honeyed']
senticnet['mellisonant'] = [0.704, -0.502, 0, 0.923, '#joyful', '#admirable', 0.71, 'mellifluous', 'melodic', 'dulcet', 'lyrical', 'honeyed']
senticnet['mellowness'] = [0.593, -0.658, 0, 0.711, '#surprising', '#admirable', 0.654, 'sweetness_and_light', 'condescension', 'condescendingness', 'affability', 'friendliness']
senticnet['melodic'] = [0.704, -0.502, 0, 0.923, '#joyful', '#admirable', 0.71, 'mellifluous', 'mellisonant', 'dulcet', 'lyrical', 'honeyed']
senticnet['melodic_noise'] = [0.104, -0.011, 0.012, 0.141, '#joyful', '#admirable', 0.081, 'instrumental', 'audio', 'vocal_music', 'lyric', 'universal_language']
senticnet['melodic_theme'] = [0.953, -0.704, 0, 0.83, '#joyful', '#admirable', 0.829, 'tune', 'melody', 'variation', 'air', 'strain']
senticnet['melody'] = [0.879, -0.965, 0, 0.7, '#joyful', '#surprising', 0.848, 'music', 'flourish', 'melodic_theme', 'musical_theme', 'signature']
senticnet['melt'] = [0.975, 0.753, 0, 0, '#joyful', '#interesting', 0.576, 'carve', 'char', 'last_long_time', 'heat', 'fire_product']
senticnet['melt_away'] = [-0.183, -0.007, -0.18, 0, '#sad', '#scared', -0.119, 'pulverise', 'violent_action', 'smash', 'hit_hard', 'pulverize']
senticnet['member'] = [0.112, 0.117, -0.07, 0.114, '#interesting', '#admirable', 0.091, 'social_group', 'association', 'team_up', 'group_of_people', 'human_group']
senticnet['member_jury'] = [0.031, 0.107, 0, 0.065, '#interesting', '#admirable', 0.068, 'negotiator', 'juror', 'jury', 'judge', 'see_justice_done']
senticnet['member_of_family'] = [0, 0.971, 0, 0.893, '#interesting', '#admirable', 0.621, 'special_person', 'male_parent', 'man_child', 'boys', 'male']
senticnet['membership'] = [0.02, 0.24, -0.114, 0.267, '#interesting', '#admirable', 0.138, 'organize_group', 'come_together', 'bring_together', 'business_group', 'business_firm']
senticnet['meme'] = [0, 0.331, -0.099, 0.242, '#interesting', '#admirable', 0.158, 'spread_idea', 'importance', 'tenet', 'culture', 'idea']
senticnet['memento'] = [-0.098, 0, -0.11, 0, '#sad', '#scared', -0.069, 'funeral_celebration', 'memorial', 'funeral', 'funerary', 'cry']
senticnet['memo'] = [0, 0, 0, 0.091, '#admirable', '#admirable', 0.03, 'correspondence', 'handwritten', 'written_message', 'written_communication', 'write_note']
senticnet['memo_pad'] = [0, 0.094, 0, 0, '#interesting', '#interesting', 0.031, 'highlighter_pen', 'notepad', 'appointment_book', 'pocket_notebook', 'address_label']
senticnet['memorial'] = [0.072, 0.126, 0, 0, '#joyful', '#interesting', 0.066, 'subway_station', 'war_memorial', 'utopia', 'mortuary', 'hero']
senticnet['memorization'] = [-0.072, 0.216, -0.063, 0.087, '#interesting', '#admirable', 0.056, 'recall', 'recollection', 'idea', 'brain_activity', 'memory']
senticnet['memorize'] = [0.798, 0.754, 0, 0.779, '#joyful', '#admirable', 0.777, 'good_memory', 'learn_science', 'study_subject', 'learn_subject', 'understand_better']
senticnet['memory'] = [-0.072, 0.216, -0.063, 0.087, '#interesting', '#admirable', 0.056, 'recall', 'recollection', 'idea', 'brain_activity', 'memorization']
senticnet['memory_image'] = [-0.768, 0, 0.629, -0.718, '#sad', '#disgusting', -0.705, 'memory_picture', 'afterimage', 'aftersensation', 'image', 'mental_image']
senticnet['memory_loss'] = [-0.957, 0, 0.549, -0.993, '#sad', '#disgusting', -0.833, 'lose_track_of_time', 'bad_memory', 'lose_consciousness', 'have_accident', 'car_accident']
senticnet['memory_picture'] = [-0.768, 0, 0.629, -0.718, '#sad', '#disgusting', -0.705, 'memory_image', 'afterimage', 'aftersensation', 'image', 'mental_image']
senticnet['men_club'] = [0.103, 0, 0, 0, '#joyful', '#joyful', 0.034, 'restaurant', 'brewery', 'club', 'pool_hall', 'strip_club']
senticnet['men_room'] = [0.035, -0.015, 0.009, 0.063, '#joyful', '#admirable', 0.035, 'maternity_ward', 'daycare', 'doctor_office', 'gym', 'kindergarden']
senticnet['menace'] = [0, 0, 0.765, -0.727, '#angry', '#disgusting', -0.497, 'danger', 'misbehavior', 'unsafe', 'hazard', 'reprimand']
senticnet['menacing'] = [-0.524, 0, 0.71, -0.942, '#angry', '#disgusting', -0.725, 'atrocious', 'horrific', 'alarming', 'minacious', 'minatory']
senticnet['menage'] = [-0.857, 0, 0.968, -0.895, '#angry', '#disgusting', -0.907, 'family', 'household', 'house', 'home', 'broken_home']
senticnet['menagerie'] = [-0.025, 0, 0, -0.054, '#sad', '#disgusting', -0.026, 'butt', 'foreign_country', 'ass', 'way', 'out_door']
senticnet['mend'] = [-0.075, 0, 0, 0, '#sad', '#sad', -0.025, 'use_needle', 'doctor_tool', 'sew_term', 'embroidery', 'seam']
senticnet['mendicancy'] = [-0.733, 0, 0.872, -0.978, '#angry', '#disgusting', -0.861, 'poverty', 'impoverishment', 'poorness', 'beggary', 'indigence']
senticnet['menial'] = [-0.851, 0, 0.938, -0.879, '#angry', '#disgusting', -0.889, 'servant', 'lackey', 'flunky', 'flunkey', 'familiar']
senticnet['meningitis'] = [-0.773, 0, 0.871, -0.64, '#sad', '#angry', -0.761, 'leptomeningitis', 'cerebrospinal_meningitis', 'epidemic_meningitis', 'brain_fever', 'cerebrospinal_fever']
senticnet['meniscus'] = [-0.536, 0, 0.982, -0.671, '#angry', '#disgusting', -0.73, 'gristle', 'semilunar_cartilage', 'fibrocartilage', 'hyaline_cartilage', 'arytenoid']
senticnet['mensal_line'] = [0.603, -0.982, 0, 0.807, '#surprising', '#admirable', 0.797, 'crease', 'crinkle', 'wrinkle', 'furrow', 'seam']
senticnet['menstruation'] = [0, -0.041, 0.018, 0.165, '#surprising', '#admirable', 0.063, 'know_time', 'timekeeper', 'taste_sweet', 'tell_time', 'comfort_friend']
senticnet['mental'] = [-0.034, 0.21, -0.059, 0.093, '#interesting', '#admirable', 0.07, 'intellect', 'new_think', 'eureka', 'idea', 'cognition']
senticnet['mental_activity'] = [0, 0.851, 0, 0.898, '#interesting', '#admirable', 0.583, 'imaginative', 'use_imagination', 'use_brain', 'arrive_conclusion', 'eureka']
senticnet['mental_block'] = [-0.784, 0, 0.707, -0.868, '#sad', '#disgusting', -0.786, 'inability', 'uncreativeness', 'stupidity', 'illiteracy', 'analphabetism']
senticnet['mental_case'] = [-0.707, 0, 0.624, -0.653, '#sad', '#disgusting', -0.661, 'sick_person', 'diseased_person', 'sufferer', 'claustrophobe', 'hysteric']
senticnet['mental_condition'] = [0.775, -0.636, 0, 0.68, '#joyful', '#admirable', 0.697, 'birth_trauma', 'psychological_state', 'psychological_condition', 'mental_state', 'psychic_trauma']
senticnet['mental_confusion'] = [-0.506, 0, 0.85, -0.828, '#angry', '#disgusting', -0.728, 'confusion', 'disarray', 'bafflement', 'confusedness', 'muddiness']
senticnet['mental_defectiveness'] = [-0.505, 0, 0.912, -0.65, '#angry', '#disgusting', -0.689, 'feeblemindedness', 'slowness', 'mental_retardation', 'backwardness', 'subnormality']
senticnet['mental_deficiency'] = [-0.556, 0, 0.522, -0.531, '#sad', '#disgusting', -0.536, 'slowness', 'mental_retardation', 'backwardness', 'subnormality', 'retardation']
senticnet['mental_disease'] = [-0.955, 0, 0.902, -0.917, '#sad', '#disgusting', -0.925, 'sadness', 'crazy_mind', 'mental_problem', 'depression', 'disease']
senticnet['mental_disorder'] = [-0.726, 0, -0.866, -0.839, '#scared', '#disgusting', -0.81, 'intolerance', 'extreme_fear', 'psychosis', 'insanity', 'impend_danger']
senticnet['mental_disturbance'] = [-0.742, 0, 0.893, -0.582, '#sad', '#angry', -0.739, 'encopresis', 'upset', 'psychosomatic_disorder', 'conversion_disorder', 'conversion_reaction']
senticnet['mental_exercise'] = [0.795, 0, 0, 0.811, '#joyful', '#admirable', 0.535, 'hobby', 'use_mind', 'contemplation', 'use_brain', 'learn_new_word']
senticnet['mental_faculty'] = [0.526, -0.741, 0, 0.862, '#surprising', '#admirable', 0.71, 'understanding', 'intellect', 'ability', 'retentiveness', 'retentivity']
senticnet['mental_health'] = [0.178, -0.02, 0.072, 0.138, '#joyful', '#admirable', 0.088, 'get_know', 'stay_touch', 'human_contact', 'invite_dinner', 'communicate_family']
senticnet['mental_home'] = [-0.608, 0, 0.685, -0.662, '#angry', '#disgusting', -0.652, 'snake_pit', 'booby_hatch', 'crazy_house', 'cuckoo_nest', 'funny_farm']
senticnet['mental_hospital'] = [-0.577, 0, 0.548, -0.525, '#sad', '#angry', -0.55, 'snake_pit', 'booby_hatch', 'crazy_house', 'cuckoo_nest', 'funny_farm']
senticnet['mental_illness'] = [-0.33, 0.159, -0.325, -0.049, '#sad', '#scared', -0.182, 'go_to_jail', 'put_in_jail', 'conceal_evidence', 'retribution', 'incarceration']
senticnet['mental_image'] = [-0.768, 0, 0.629, -0.718, '#sad', '#disgusting', -0.705, 'memory_picture', 'afterimage', 'aftersensation', 'image', 'memory_image']
senticnet['mental_institution'] = [-0.965, 0, 0.656, -0.513, '#sad', '#angry', -0.711, 'snake_pit', 'booby_hatch', 'crazy_house', 'cuckoo_nest', 'funny_farm']
senticnet['mental_object'] = [0.95, -0.863, 0, 0.947, '#joyful', '#admirable', 0.92, 'content', 'old_wives_tale', 'folklore', 'cognitive_content', 'lore']
senticnet['mental_problem'] = [-0.955, 0, 0.902, -0.917, '#sad', '#disgusting', -0.925, 'sadness', 'mental_disease', 'crazy_mind', 'depression', 'disease']
senticnet['mental_rejection'] = [0.738, -0.833, 0, 0.981, '#surprising', '#admirable', 0.851, 'doubt', 'incertitude', 'dubiety', 'doubtfulness', 'dubiousness']
senticnet['mental_representation'] = [0.693, -0.529, 0, 0.82, '#joyful', '#admirable', 0.681, 'embodiment', 'shape', 'representation', 'concrete_representation', 'internal_representation']
senticnet['mental_retardation'] = [-0.745, 0, 0.893, -0.792, '#angry', '#disgusting', -0.81, 'moronity', 'mental_deficiency', 'imbecility', 'stupidity', 'mental_defectiveness']
senticnet['mental_state'] = [0, 0.706, 0, 0.928, '#interesting', '#admirable', 0.545, 'thought', 'mind', 'inside_head', 'thoughtfulness', 'brain_function']
senticnet['mental_strain'] = [-0.976, 0, 0.969, -0.504, '#sad', '#angry', -0.816, 'nervousness', 'tenseness', 'tension', 'nerves', 'stress']
senticnet['mentality'] = [0.909, 0.983, 0, 0, '#joyful', '#interesting', 0.631, 'old', 'elderly', 'ripped', 'matured', 'age_well']
senticnet['mentally_challenged'] = [-0.97, 0, -0.978, -0.847, '#sad', '#scared', -0.932, 'intellectual_stimulation', 'enjoy_beauty', 'exercise_mind', 'leisure_time', 'time_think']
senticnet['mentation'] = [0.634, -0.84, 0, 0.719, '#surprising', '#admirable', 0.731, 'reasoning', 'consideration', 'logical_thinking', 'abstract_thought', 'excogitation']
senticnet['mention'] = [0, 0.203, -0.113, 0.28, '#interesting', '#admirable', 0.123, 'remark', 'reply', 'comment', 'statement', 'idiom']
senticnet['mentor'] = [-0.108, 0.068, -0.129, -0.116, '#scared', '#disgusting', -0.095, 'change_life', 'housewife', 'know_well', 'finish_college', 'get_high_education']
senticnet['menu'] = [0.146, 0.095, -0.046, 0, '#joyful', '#interesting', 0.065, 'paper_menu', 'diner', 'cafe', 'restaurant', 'dine_room']
senticnet['mercenary'] = [0.913, -0.635, 0, 0.961, '#joyful', '#admirable', 0.836, 'materialistic', 'worldly', 'mundane', 'material', 'economic']
senticnet['merchandise'] = [0, 0.076, 0, 0, '#interesting', '#interesting', 0.025, 'goods', 'vendor', 'trolley', 'shopper', 'grocery']
senticnet['merchant'] = [0, 0.17, 0, 0.101, '#interesting', '#admirable', 0.09, 'seller', 'trade', 'bazaar', 'stock_market', 'wall_street']
senticnet['merciful'] = [0.803, 0, 0, 0.789, '#joyful', '#admirable', 0.531, 'mercifully', 'mercifulness', 'ruth', 'commiseration', 'commiserate']
senticnet['mercifully'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'merciful', 'mercifulness', 'ruth', 'commiseration', 'commiserate']
senticnet['mercifulness'] = [0.879, 0, 0, 0.986, '#joyful', '#admirable', 0.622, 'mercifully', 'merciful', 'ruth', 'commiseration', 'commiserate']
senticnet['merciless'] = [0, 0, 0.748, -0.917, '#angry', '#disgusting', -0.555, 'cut_throat', 'bowelless', 'tigerish', 'pitiless', 'unkind']
senticnet['mercilessness'] = [-0.709, 0, 0, -0.989, '#sad', '#disgusting', -0.566, 'unkind', 'ruthlessness', 'cruelly', 'pitilessness', 'unassertively']
senticnet['mercy'] = [0.76, 0.72, 0, 0.744, '#joyful', '#admirable', 0.741, 'forgiveness', 'concerned', 'pity', 'excusable', 'forgivable']
senticnet['mere'] = [0, 0.087, 0, 0.071, '#interesting', '#admirable', 0.053, 'pond', 'lake', 'pacific_ocean', 'small_lake', 'atlantic_ocean']
senticnet['meretricious'] = [0, -0.965, 0, 0.906, '#surprising', '#admirable', 0.624, 'garish', 'flashy', 'trashy', 'cheap', 'brassy']
senticnet['merge'] = [0, 0.894, 0, 0.819, '#interesting', '#admirable', 0.571, 'sharp_end', 'sharpness', 'sharp_corner', 'geometric_object', 'point']
senticnet['merging'] = [-0.773, 0, 0.914, -0.501, '#sad', '#angry', -0.729, 'confluence', 'conflux', 'blending', 'homogenization', 'combination']
senticnet['merit'] = [0.732, 0.91, 0, 0.789, '#interesting', '#admirable', 0.81, 'value', 'like_price', 'worth', 'amount_charge', 'like_cost']
senticnet['merit_badge'] = [0.844, -0.572, 0, 0.576, '#joyful', '#admirable', 0.664, 'blue_ribbon', 'cordon_bleu', 'allegory', 'stripe', 'badge']
senticnet['meritocracy'] = [0.716, 0.813, 0, 0, '#joyful', '#interesting', 0.51, 'bonus', 'reinforce', 'promotion', 'incentive', 'gratification']
senticnet['merlin'] = [0, 0, 0, 0.951, '#admirable', '#admirable', 0.317, 'doctor', 'nurse', 'doctor_surgery', 'surgeon', 'doctor_office']
senticnet['mermaid'] = [0.053, 0.073, -0.065, 0.104, '#interesting', '#admirable', 0.055, 'disney', 'autumn_leaf', 'horizon', 'aquatic_life', 'fisherman']
senticnet['merrily'] = [0.653, 0.635, -0.244, 0.294, '#joyful', '#interesting', 0.446, 'jubilantly', 'happily', 'mirthfully', 'gayly', 'blithely']
senticnet['merriment'] = [0.918, 0.476, -0.197, 0.417, '#joyful', '#interesting', 0.538, 'cheery', 'gaiety', 'festal', 'playfulness', 'pridefulness']
senticnet['merry'] = [0.883, 0.921, 0, 0.798, '#joyful', '#interesting', 0.867, 'glad', 'mirth', 'merriment', 'festal', 'gaiety']
senticnet['merry_andrew'] = [0.821, -0.994, 0, 0.572, '#joyful', '#surprising', 0.796, 'clown', 'buffoon', 'goof', 'goofball', 'zany']
senticnet['merry_go_round'] = [0.813, 0.832, 0, 0.874, '#interesting', '#admirable', 0.84, 'ferris_wheel', 'roller-coaster', 'concession_stand', 'carnival_ride', 'carny']
senticnet['merrymaking'] = [-0.695, 0, 0.844, -0.963, '#angry', '#disgusting', -0.834, 'jinks', 'high_jinks', 'hijinks', 'high_jinx', 'revel']
senticnet['mesalliance'] = [-0.615, 0, 0.668, -0.817, '#angry', '#disgusting', -0.7, 'misalliance', 'marriage', 'matrimony', 'union', 'spousal_relationship']
senticnet['mescaline'] = [-0.735, 0, 0.944, -0.942, '#angry', '#disgusting', -0.874, 'lysergic_acid_diethylamide', 'psychedelic_drug', 'peyote', 'phencyclidine', 'drug']
senticnet['mesh'] = [0.5, -0.762, 0, 0.814, '#surprising', '#admirable', 0.692, 'net', 'network', 'grillwork', 'grillworking', 'grillworkwork']
senticnet['meshing'] = [0.5, -0.762, 0, 0.814, '#surprising', '#admirable', 0.692, 'net', 'network', 'mesh', 'grillwork', 'meshwork']
senticnet['meshwork'] = [0.5, -0.762, 0, 0.814, '#surprising', '#admirable', 0.692, 'net', 'network', 'mesh', 'meshing', 'grillwork']
senticnet['mesmerized'] = [0.998, -0.75, 0, 0.695, '#joyful', '#surprising', 0.814, 'bewitched', 'ensorcelled', 'fascinated', 'hypnotized', 'enchanted']
senticnet['mess'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'destroyed_home', 'destroyed_city', 'burned_thing', 'after_fire', 'count_damage']
senticnet['mess_around'] = [-0.901, 0, 0.31, -0.915, '#sad', '#disgusting', -0.709, 'waste', 'garbage', 'trash', 'rubbish', 'refuse']
senticnet['mess_up'] = [0, 0, 0.87, -0.874, '#angry', '#disgusting', -0.581, 'appear_dumb', 'kneel_down', 'mess', 'goof', 'miss_out']
senticnet['message'] = [0, 0, 0, 0.162, '#admirable', '#admirable', 0.054, 'note', 'announcement', 'snail_mail', 'unit_language', 'correspondence']
senticnet['message_board'] = [0.022, 0, 0.011, 0.07, '#joyful', '#admirable', 0.027, 'creationism', 'post_notice', 'mail_delivery', 'astrology', 'artificial']
senticnet['messiness'] = [-0.787, 0, 0.854, -0.9, '#angry', '#disgusting', -0.847, 'muss', 'untidiness', 'mess', 'muddle', 'disorderliness']
senticnet['messy'] = [-0.088, -0.046, 0.023, -0.076, '#sad', '#disgusting', -0.047, 'toast', 'make_toast', 'bread_crumb', 'bread', 'spoilage']
senticnet['messy_room'] = [0, 0, 0.837, -0.87, '#angry', '#disgusting', -0.569, 'chaos', 'crowd', 'favorite', 'assortment', 'bunch']
senticnet['metabolism'] = [0.755, -0.713, 0, 0.972, '#joyful', '#admirable', 0.813, 'digest', 'digestion', 'grow_up', 'grow_healthy', 'healthy_lifestyle']
senticnet['metal'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'protective_gear', 'knight_protection_ore', 'lightweight_knight_protection', 'knight_protection', 'knight']
senticnet['metal_alloy'] = [0.024, 0, 0, 0.05, '#joyful', '#admirable', 0.025, 'metal_container', 'thin_metal', 'common_name', 'metal_type', 'silver_metal']
senticnet['metal_bar'] = [0.028, 0, 0.026, 0.102, '#joyful', '#admirable', 0.035, 'heavy_object', 'keep_out', 'invader', 'small_room', 'door_handle']
senticnet['metal_box'] = [0.069, 0.152, 0, 0.088, '#interesting', '#admirable', 0.103, 'secure', 'money_collector', 'safe', 'hold_change', 'hold_coin']
senticnet['metal_coin'] = [0, 0.066, 0.041, 0.054, '#interesting', '#admirable', 0.026, 'old_coin', 'coin', 'money', 'monetary_unit', 'down_payment']
senticnet['metal_container'] = [0.038, 0, 0, 0.082, '#joyful', '#admirable', 0.04, 'common_name', 'thin_metal', 'metal_type', 'food_container', 'tin']
senticnet['metal_cylinder'] = [0.078, 0, 0, 0.162, '#joyful', '#admirable', 0.08, 'metal_container', 'cylinder', 'food_container', 'storage_container', 'tin']
senticnet['metal_detector'] = [0.069, 0.152, 0, 0.088, '#interesting', '#admirable', 0.103, 'security', 'safe_zone', 'security_airport', 'security_area', 'security_system']
senticnet['metal_money'] = [0, 0.094, 0.085, 0.091, '#interesting', '#admirable', 0.033, 'small_currency', 'penny_dime', 'small_coin', 'money_coin', 'small_money']
senticnet['metal_ore'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'protective_gear', 'knight_protection', 'lightweight_metal', 'metal', 'knight']
senticnet['metal_rod'] = [0.085, -0.068, 0, -0.047, '#joyful', '#surprising', 0.035, 'rod', 'mortar', 'screwdriver', 'chisel', 'knife']
senticnet['metal_stick'] = [0.181, -0.124, 0.061, 0.075, '#joyful', '#surprising', 0.106, 'hangout', 'drinking_place', 'place_to_drink', 'bart', 'water_hole']
senticnet['metal_type'] = [0.024, 0, 0, 0.05, '#joyful', '#admirable', 0.025, 'metal_container', 'thin_metal', 'metal_alloy', 'common_name', 'silver_metal']
senticnet['metallic_element'] = [0, 0, 0, 0.089, '#admirable', '#admirable', 0.03, 'foil', 'lightweight_metal', 'rusty_metal', 'metal_type', 'make_out_metal']
senticnet['metamorphosis'] = [0.642, -0.585, 0, 0.751, '#joyful', '#admirable', 0.659, 'change', 'become_better', 'change_aspect', 'look_better', 'become_bigger']
senticnet['metaphor'] = [0.066, 0.079, 0, 0.142, '#interesting', '#admirable', 0.096, 'never_end', 'time_reference', 'duration', 'calendar_event', 'general_time']
senticnet['metastability'] = [0.949, -0.552, 0, 0.595, '#joyful', '#admirable', 0.699, 'constancy', 'monotony', 'invariance', 'changelessness', 'unchangeability']
senticnet['meter'] = [0, 0.951, 0, 0.721, '#interesting', '#admirable', 0.557, 'distance_measure', 'length_measurement', 'distance_measurement', 'kilodistance_measurement', 'imperial_measurement']
senticnet['method'] = [-0.044, 0.182, -0.081, 0.139, '#interesting', '#admirable', 0.065, 'scientific', 'hypothesis', 'hypothetical', 'subject', 'science_term']
senticnet['meticulosity'] = [0.512, -0.945, 0, 0.5, '#joyful', '#surprising', 0.652, 'scrupulousness', 'carefulness', 'diligence', 'meticulousness', 'painstakingness']
senticnet['meticulous'] = [0.682, -0.525, 0, 0.613, '#joyful', '#admirable', 0.607, 'nice', 'fastidious', 'dainty', 'prissy', 'pernickety']
senticnet['meticulousness'] = [0.512, -0.945, 0, 0.5, '#joyful', '#surprising', 0.652, 'scrupulousness', 'carefulness', 'diligence', 'painstakingness', 'meticulosity']
senticnet['metrazol_shock'] = [-0.724, 0, 0.732, -0.595, '#sad', '#angry', -0.684, 'insulin_shock', 'insulin_shock_therapy', 'insulin_shock_treatment', 'shock_therapy', 'shock']
senticnet['metrazol_shock_therapy'] = [-0.724, 0, 0.732, -0.595, '#sad', '#angry', -0.684, 'insulin_shock', 'insulin_shock_therapy', 'insulin_shock_treatment', 'metrazol_shock', 'shock_therapy']
senticnet['metric'] = [0, 0.203, 0.036, 0.204, '#interesting', '#admirable', 0.124, 'amount', 'count', 'total', 'quantity', 'total_amount']
senticnet['metrical'] = [-0.841, 0, 0.574, -0.668, '#sad', '#disgusting', -0.694, 'cadenced', 'cadent', 'rhythmical', 'metric', 'lilting']
senticnet['metro'] = [0, 0.823, 0, 0.98, '#interesting', '#admirable', 0.601, 'bus', 'tram', 'train', 'transport', 'transportation']
senticnet['metropolis'] = [0.089, 0, 0, 0.13, '#joyful', '#admirable', 0.073, 'beautiful_place', 'county', 'good_view', 'complex_structure', 'populate_area']
senticnet['metropolitan_city'] = [-0.024, -0.005, -0.049, 0, '#sad', '#scared', -0.023, 'medikit', 'manchester', 'ghetto', 'medical_build', 'new_york_city']
senticnet['mettlesome'] = [0, -0.795, 0, 1.0, '#surprising', '#admirable', 0.598, 'spirited', 'gamey', 'game', 'gritty', 'gamy']
senticnet['mew'] = [0.028, 0, 0.027, 0.101, '#joyful', '#admirable', 0.034, 'animal_dwell', 'bee_home', 'live_place', 'dwell_place', 'place_to_live']
senticnet['mexican_restaurant'] = [0, 0.068, -0.065, 0.081, '#interesting', '#admirable', 0.028, 'pyramid', 'buckle', 'japanese_person', 'anemone', 'herringbone']
senticnet['mezzanine'] = [0.077, 0.073, 0.013, -0.028, '#joyful', '#interesting', 0.036, 'registry_office', 'radio_studio', 'book', 'conference_auditorium', 'book_office']
senticnet['microbe'] = [0, 0, 0, -0.088, '#disgusting', '#disgusting', -0.029, 'tiny_organism', 'microscopic', 'amoeba', 'heron', 'germ']
senticnet['microorganism'] = [0.854, 0.862, 0, 0, '#joyful', '#interesting', 0.572, 'earthworm', 'bacterium', 'germ', 'bug', 'cutworm']
senticnet['microphage'] = [0.772, -0.561, 0, 0.824, '#joyful', '#admirable', 0.719, 'neutrophil', 'leukocyte', 'leucocyte', 'white_blood_cell', 'white_cell']
senticnet['microphone_boom'] = [0.803, 0, 0, 0.955, '#joyful', '#admirable', 0.586, 'sound_control_room', 'beat_box', 'ticket_taker', 'speaker', 'contralto']
senticnet['microscope'] = [0, 0.07, 0, 0.063, '#interesting', '#admirable', 0.044, 'peep', 'glimpse', 'see', 'stare', 'observation']
senticnet['microscopic'] = [0, 0.065, 0.021, 0.052, '#interesting', '#admirable', 0.032, 'amoeba', 'tiny_organism', 'microbe', 'heron', 'single_celled']
senticnet['midden'] = [-0.689, 0, 0.517, -0.591, '#sad', '#disgusting', -0.599, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'wasteyard']
senticnet['middle'] = [0.064, 0.156, 0, 0.199, '#interesting', '#admirable', 0.14, 'in_middle', 'median', 'center', 'in_between', 'average']
senticnet['middle_day'] = [0.179, 0.096, 0, 0.141, '#joyful', '#admirable', 0.139, 'inactivity', 'work_break', 'tea_break', 'stay_calm', 'bed_sleep']
senticnet['middle_road'] = [0, 0.098, 0, 0, '#interesting', '#interesting', 0.033, 'car_race', 'smithsonian', 'loose_end', 'room_temperature', 'another_planet']
senticnet['middlebrow'] = [0.966, -0.508, 0, 0.601, '#joyful', '#admirable', 0.692, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['midget'] = [0, 0, -0.055, -0.056, '#scared', '#disgusting', -0.037, 'human', 'delusional', 'use_illegal_drug', 'busy_person', 'carpenter']
senticnet['midway'] = [0.084, -0.058, 0.013, 0, '#joyful', '#surprising', 0.043, 'carnival_ride', 'carny', 'fortune_teller', 'horseback', 'ferris_wheel']
senticnet['midweek'] = [0, 0.707, 0, 0.848, '#interesting', '#admirable', 0.518, 'friday', 'monday', 'fortnight', 'weekend', 'day_of_week']
senticnet['mien'] = [0.82, -0.851, 0, 0.939, '#surprising', '#admirable', 0.87, 'dignity', 'gravitas', 'lordliness', 'personal_manner', 'manner']
senticnet['miff'] = [-0.85, 0, 0.564, -0.924, '#sad', '#disgusting', -0.779, 'botheration', 'impatience', 'snit', 'bummer', 'pinprick']
senticnet['miffed'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'galling', 'annoying', 'vexatious', 'teasing']
senticnet['migraine'] = [-0.737, 0, -0.859, -0.72, '#sad', '#scared', -0.772, 'lay_off', 'oneself', 'pain_suffer', 'lose_mind', 'forget_everything']
senticnet['milch_cow'] = [0.546, -0.969, 0, 0.533, '#joyful', '#surprising', 0.683, 'dairy_cattle', 'dairy_cow', 'ayrshire', 'milk_cow', 'milcher']
senticnet['milcher'] = [0.546, -0.969, 0, 0.533, '#joyful', '#surprising', 0.683, 'dairy_cattle', 'dairy_cow', 'milch_cow', 'milk_cow', 'ayrshire']
senticnet['mild'] = [-0.028, 0, 0, -0.081, '#sad', '#disgusting', -0.036, 'hurricane', 'tropical_storm', 'breeze', 'weather_element', 'atmospheric_phenomenon']
senticnet['mildew'] = [-0.931, 0, 0.997, -0.506, '#sad', '#angry', -0.811, 'decay', 'spoiling', 'mold', 'mould', 'souring']
senticnet['mildness'] = [0.646, -0.698, 0, 0.609, '#joyful', '#surprising', 0.651, 'good_manners', 'personal_manner', 'courtesy', 'comportment', 'mien']
senticnet['mile'] = [-0.705, 0, 0, -0.878, '#sad', '#disgusting', -0.528, 'far', 'distant', 'distance', 'distance_measure', 'kilometer']
senticnet['militant'] = [-0.934, 0, 0.86, -0.907, '#sad', '#disgusting', -0.9, 'dry', 'insurgent', 'crusader', 'passive_resister', 'demonstrator']
senticnet['militarism'] = [0.729, -0.561, 0, 0.785, '#joyful', '#admirable', 0.692, 'ideology', 'hawkishness', 'warmongering', 'war_advocacy', 'political_orientation']
senticnet['military'] = [0.955, 0.831, 0, 0, '#joyful', '#interesting', 0.595, 'attacker', 'army', 'samurai', 'infantry', 'military_force']
senticnet['military_action'] = [-0.199, 0, -0.119, -0.051, '#sad', '#scared', -0.123, 'lose_battle', 'give_up', 'beaten', 'lose_war', 'defeat']
senticnet['military_base'] = [0, 0, -0.071, -0.175, '#scared', '#disgusting', -0.082, 'crime_scene', 'police_station', 'battlefield', 'war_museum', 'roadblock']
senticnet['military_camp'] = [0, 0, 0, -0.947, '#disgusting', '#disgusting', -0.316, 'terrorism', 'kamikaze', 'sect', 'brainwash', 'faction']
senticnet['military_capability'] = [-0.841, 0, 0.86, -0.732, '#sad', '#angry', -0.811, 'strength', 'sea_power', 'military_strength', 'military_posture', 'posture']
senticnet['military_division'] = [0.913, 0.998, 0, 0, '#joyful', '#interesting', 0.637, 'army', 'soldier_group', 'military_force', 'military', 'army_position']
senticnet['military_force'] = [0.031, 0.079, 0, 0, '#joyful', '#interesting', 0.037, 'army_unit', 'attacker', 'soldier_group', 'army', 'military']
senticnet['military_group'] = [-0.032, 0.092, 0.051, 0.077, '#interesting', '#admirable', 0.029, 'classification', 'military_division', 'placement', 'nobleman', 'ordinal']
senticnet['military_installation'] = [0, 0.072, 0, 0, '#interesting', '#interesting', 0.024, 'counselor', 'rest_place', 'temporary_house', 'summer_vacation', 'hunt_fish']
senticnet['military_machine'] = [-0.596, 0, 0.665, -0.522, '#sad', '#angry', -0.594, 'military', 'armed_forces', 'armed_services', 'military_reserve', 'war_machine']
senticnet['military_officer'] = [0.027, 0.075, 0, 0, '#joyful', '#interesting', 0.034, 'leadership_position', 'navy_rank', 'military_position', 'navy_leader', 'army_officer']
senticnet['military_order'] = [0, 0.121, 0, 0.068, '#interesting', '#admirable', 0.063, 'rank', 'army_position', 'army_boss', 'general', 'hierarchy']
senticnet['military_position'] = [0, 0.086, 0, 0, '#interesting', '#interesting', 0.029, 'army_position', 'military_rank', 'army_rank', 'military_officer', 'high_rank']
senticnet['military_posture'] = [-0.841, 0, 0.86, -0.732, '#sad', '#angry', -0.811, 'strength', 'military_capability', 'military_strength', 'sea_power', 'posture']
senticnet['military_press'] = [-0.753, 0, 0.794, -0.585, '#sad', '#angry', -0.711, 'jerk', 'snatch', 'weightlift', 'clean', 'bench_press']
senticnet['military_rank'] = [0.024, 0.072, 0, 0, '#joyful', '#interesting', 0.032, 'high_rank', 'army_rank', 'army_boss', 'military_position', 'army_leader']
senticnet['military_reserve'] = [-0.596, 0, 0.665, -0.522, '#sad', '#angry', -0.594, 'military', 'armed_forces', 'armed_services', 'military_machine', 'war_machine']
senticnet['military_retreat'] = [-0.375, 0.11, -0.218, -0.068, '#sad', '#scared', -0.184, 'retreat', 'downgrade', 'lose_battle', 'lose_war', 'retrocede']
senticnet['military_service'] = [0, 0.734, 0, 0.89, '#interesting', '#admirable', 0.541, 'hire_help', 'recruit', 'police_work', 'job', 'career']
senticnet['military_ship'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'ship', 'big_boat', 'water_vehicle', 'boat', 'navy']
senticnet['military_strength'] = [-0.841, 0, 0.86, -0.732, '#sad', '#angry', -0.811, 'strength', 'military_capability', 'sea_power', 'military_posture', 'posture']
senticnet['military_uniform'] = [-0.798, 0, 0.599, -0.938, '#sad', '#disgusting', -0.778, 'uniform', 'battle_dress', 'dress_uniform', 'fatigues', 'khakis']
senticnet['military_unit'] = [-0.636, 0, 0.575, -0.598, '#sad', '#disgusting', -0.603, 'force', 'trainband', 'militia', 'military_force', 'military_group']
senticnet['militia'] = [-0.636, 0, 0.575, -0.598, '#sad', '#disgusting', -0.603, 'force', 'trainband', 'military_unit', 'military_force', 'military_group']
senticnet['milk'] = [0.951, -0.97, 0, 0.639, '#joyful', '#surprising', 0.853, 'smoothie', 'drinking_water', 'nutrient', 'beverage', 'refresher']
senticnet['milk_cow'] = [0.546, -0.969, 0, 0.533, '#joyful', '#surprising', 0.683, 'dairy_cattle', 'dairy_cow', 'milch_cow', 'ayrshire', 'milcher']
senticnet['milk_drink'] = [0.106, 0, -0.101, 0.16, '#joyful', '#admirable', 0.055, 'tremble', 'jiggle', 'vibrate', 'convulse', 'back_forth']
senticnet['milk_intolerance'] = [-0.812, 0, 0.965, -0.636, '#sad', '#angry', -0.804, 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect', 'congenital_disease']
senticnet['milk_product'] = [0.037, 0, 0, 0.067, '#joyful', '#admirable', 0.035, 'veal', 'dairy', 'salad_dress', 'ranch', 'food_group']
senticnet['milk_vetch'] = [-0.943, 0, 0.608, -0.954, '#sad', '#disgusting', -0.835, 'wild_licorice', 'wild_liquorice', 'alpine_milk_vetch', 'purple_milk_vetch', 'woody_plant']
senticnet['milkwort'] = [-0.706, 0, 0.769, -0.703, '#sad', '#angry', -0.726, 'subshrub', 'suffrutex', 'senega', 'orange_milkwort', 'yellow_milkwort']
senticnet['milky'] = [0.052, 0, 0, 0.094, '#joyful', '#admirable', 0.049, 'orbit_around_sun', 'enormous', 'god_creation', 'god_creation_galaxy', 'nasa']
senticnet['milky_galaxy'] = [0.052, 0, 0, 0.094, '#joyful', '#admirable', 0.049, 'orbit_around_sun', 'enormous', 'milky', 'god_creation', 'nasa']
senticnet['mill'] = [-0.055, 0, 0, -0.075, '#sad', '#disgusting', -0.043, 'favorite', 'grind', 'crowd', 'several_people', 'considerable']
senticnet['millennium'] = [0.906, -0.627, 0, 0.941, '#joyful', '#admirable', 0.825, 'honeymoon', 'heyday', 'time', 'efflorescence', 'period']
senticnet['million'] = [0, 0.243, 0, 0.122, '#interesting', '#admirable', 0.122, 'value', 'peso', 'dollar_sign', 'a_lot_of_money', 'cost']
senticnet['millstone'] = [0.053, -0.035, 0, 0, '#joyful', '#surprising', 0.029, 'wheel', 'gear', 'boulder', 'pulley', 'slide']
senticnet['mimic'] = [-0.132, 0, 0, -0.25, '#sad', '#disgusting', -0.127, 'intend', 'copycat', 'imitation', 'copy', 'heap']
senticnet['mimicker'] = [-0.969, 0, 0.81, -0.986, '#sad', '#disgusting', -0.922, 'mimic', 'beguiler', 'slicker', 'imitator', 'deceiver']
senticnet['minacious'] = [-0.524, 0, 0.71, -0.942, '#angry', '#disgusting', -0.725, 'atrocious', 'horrific', 'menacing', 'alarming', 'minatory']
senticnet['minatory'] = [-0.524, 0, 0.71, -0.942, '#angry', '#disgusting', -0.725, 'atrocious', 'horrific', 'menacing', 'minacious', 'alarming']
senticnet['mince'] = [-0.082, -0.043, -0.05, -0.153, '#sad', '#disgusting', -0.081, 'pork', 'brisket', 'cleaver', 'chop', 'cut']
senticnet['mincemeat'] = [0.87, -0.856, 0, 0.94, '#joyful', '#admirable', 0.889, 'concoction', 'stuffing', 'dressing', 'roux', 'batter']
senticnet['mincing'] = [0.614, -0.959, 0, 0.537, '#joyful', '#surprising', 0.703, 'refined', 'twee', 'gentlemanlike', 'gentlemanly', 'ladylike']
senticnet['mind'] = [-0.04, 0.253, -0.133, 0.136, '#interesting', '#admirable', 0.072, 'thought', 'brain', 'mental_state', 'inside_head', 'idea']
senticnet['mind_blowing'] = [0.709, 0.977, 0, 0.795, '#interesting', '#admirable', 0.827, 'feel_happy', 'astonished', 'good_feeling', 'happiness', 'feel_amazed']
senticnet['mind_boggle'] = [-0.132, 0, 0, -0.25, '#sad', '#disgusting', -0.127, 'head_hurt', 'introspection', 'lifestyle_change', 'headache', 'move_eye']
senticnet['mind_child'] = [-0.036, 0, 0, -0.084, '#sad', '#disgusting', -0.04, 'egg_shell', 'baby', 'old_paper', 'glass', 'heron']
senticnet['mind_control'] = [0, 0.933, 0, 0.74, '#interesting', '#admirable', 0.558, 'contradiction', 'fundamentalist', 'vicar', 'pastor', 'gospel']
senticnet['mind_power'] = [0.034, 0.161, -0.05, 0.172, '#interesting', '#admirable', 0.106, 'mental', 'psychical', 'psychologist', 'psychic', 'mind']
senticnet['mind_reader'] = [0.9, -0.882, 0, 0.687, '#joyful', '#surprising', 0.823, 'escapologist', 'escape_expert', 'conjurer', 'telepathist', 'performer']
senticnet['mind_state'] = [0, 0.958, 0, 0.782, '#interesting', '#admirable', 0.58, 'human_emotion', 'contagious', 'good_emotion', 'sentiment', 'happiness']
senticnet['mind_store'] = [0.895, 0.832, 0, 0, '#joyful', '#interesting', 0.576, 'explain_everything', 'deal_card_player', 'forward_email', 'stand_alone', 'bridge_difference']
senticnet['mindful'] = [0.709, -0.613, 0, 0.762, '#joyful', '#admirable', 0.695, 'careful', 'heedful', 'resonant', 'evocative', 'redolent']
senticnet['mindless'] = [0, 0, 0.919, -0.746, '#angry', '#disgusting', -0.555, 'stupid', 'silly', 'goofy', 'dumb', 'foolish']
senticnet['mindless_entertainment'] = [0.953, -0.955, 0, 0, '#joyful', '#surprising', 0.636, 'zone_out', 'watch_show', 'want_entertain', 'see_actor', 'experience_different_culture']
senticnet['mindlessness'] = [0.991, -0.75, 0, 0.815, '#joyful', '#admirable', 0.852, 'incaution', 'incautiousness', 'imprudence', 'rashness', 'heedlessness']
senticnet['mine'] = [-0.939, 0, 0.87, -0.979, '#sad', '#disgusting', -0.929, 'blow_thing_up', 'bomb', 'weapon', 'gun', 'bullet']
senticnet['mine_diamond'] = [0.781, 0.87, 0, 0, '#joyful', '#interesting', 0.55, 'bicycle_across_town', 'dig_grave', 'kill_specific_group', 'age_gracefully', 'storm_out_room']
senticnet['mine_gold'] = [0.836, 0.976, 0, 0, '#joyful', '#interesting', 0.604, 'smoke_joint', 'shovel_snow', 'fly_around', 'blow_away', 'forward_email']
senticnet['mine_ore'] = [0.071, 0.079, 0, 0.075, '#interesting', '#admirable', 0.075, 'elements', 'tin', 'magnetic', 'hard_plastic', 'hard_material']
senticnet['miner'] = [0, 0.918, 0, 0.771, '#interesting', '#admirable', 0.563, 'worker', 'personnel', 'blacksmith', 'helper', 'slave']
senticnet['mineral'] = [0.555, -0.994, 0, 0.851, '#surprising', '#admirable', 0.8, 'quartz', 'cerussite', 'white_lead_ore', 'cobaltite', 'molybdenite']
senticnet['mineral_deficiency'] = [-0.543, 0, 0.92, -0.843, '#angry', '#disgusting', -0.769, 'dearth', 'demand', 'deficiency', 'famine', 'need']
senticnet['minginess'] = [0.858, -0.636, 0, 0.961, '#joyful', '#admirable', 0.818, 'closeness', 'parsimony', 'parsimoniousness', 'meanness', 'miserliness']
senticnet['mini_mall'] = [0, 0, 0.051, -0.032, '#angry', '#disgusting', -0.028, 'large_city_shop_mall', 'suburban_shop_mall', 'corner_shop', 'corner_grocery', 'large_food_store']
senticnet['mini_van'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'cable_car', 'baggage_compartment', 'subway', 'amusement_park', 'terminal']
senticnet['minibar'] = [0.999, 0.904, 0, 0, '#joyful', '#interesting', 0.634, 'alcohol', 'porter', 'concierge', 'beer_mug', 'bar_stool']
senticnet['minimum'] = [-0.831, 0, 0.513, -0.869, '#sad', '#disgusting', -0.738, 'small_indefinite_quantity', 'small_indefinite_amount', 'peak', 'skeleton', 'extremum']
senticnet['minister'] = [0.039, 0.252, -0.045, 0.197, '#interesting', '#admirable', 0.148, 'pope', 'evangelist', 'rector', 'church_head', 'saint']
senticnet['ministration'] = [0.794, -0.544, 0, 0.507, '#joyful', '#surprising', 0.615, 'solace', 'assist', 'help', 'assistance', 'mercy']
senticnet['mink'] = [-0.582, 0, 0.517, -0.593, '#sad', '#disgusting', -0.564, 'fox', 'pelt', 'seal', 'astrakhan', 'bearskin']
senticnet['minnow'] = [0, -0.022, 0.044, -0.085, '#angry', '#disgusting', -0.036, 'haddock', 'mermaid', 'fish_rod', 'tidal_wave', 'dryad']
senticnet['minor'] = [-0.877, 0, -0.765, 0, '#sad', '#scared', -0.547, 'expiable', 'excusable', 'forgivable', 'venial', 'pardonable']
senticnet['minor_injury'] = [-0.863, 0, 0, -0.909, '#sad', '#disgusting', -0.591, 'knee_injury', 'injure', 'accident', 'twist_ankle', 'get_injured']
senticnet['minor_planet'] = [0.889, 0, 0, 0.829, '#joyful', '#admirable', 0.573, 'stuff_use_calculation', 'ridgeback', 'written_programmer', 'low_blood_pressure', 'competitive_activity']
senticnet['minor_surgery'] = [-0.52, 0, 0.906, -0.679, '#angry', '#disgusting', -0.702, 'operation', 'surgery', 'surgical_operation', 'surgical_procedure', 'surgical_process']
senticnet['minor_tranquilizer'] = [-0.866, 0, 0.646, -0.888, '#sad', '#disgusting', -0.8, 'tranquilizer', 'put_to_sleep', 'antianxiety_drug', 'anxiolytic', 'anxiolytic_drug']
senticnet['mint'] = [0.062, 0.115, 0, 0, '#joyful', '#interesting', 0.059, 'lettuce', 'spinach', 'herb', 'baby_flower', 'cabbage']
senticnet['minus'] = [-0.046, 0.171, 0, 0.194, '#interesting', '#admirable', 0.106, 'mass_measure', 'numerical', 'liquid_unit', 'lack', 'total_number']
senticnet['minus_sign'] = [-0.909, 0, 0.278, -0.999, '#sad', '#disgusting', -0.729, 'few', 'little', 'less', 'negative', 'minus']
senticnet['minuscule'] = [-0.958, 0, 0.517, -0.536, '#sad', '#disgusting', -0.67, 'copperplate', 'hand', 'cursive', 'italic', 'round_hand']
senticnet['minute'] = [0.1, 0.085, 0, 0.093, '#joyful', '#admirable', 0.093, 'watch', 'clock', 'hour', 'hourglass', 'stopwatch']
senticnet['minute_pendulum'] = [0.036, -0.04, 0, 0, '#joyful', '#surprising', 0.025, 'minute', 'second', 'hour', 'stopwatch', 'pendulum']
senticnet['minute_second'] = [0.036, -0.04, 0, 0, '#joyful', '#surprising', 0.025, 'minute', 'pendulum', 'hour', 'stopwatch', 'second']
senticnet['miracle'] = [0.816, -0.837, 0, 0.7, '#joyful', '#surprising', 0.784, 'zeus', 'gasp', 'pardon', 'invisible', 'ceremony']
senticnet['miracle_play'] = [0.734, -0.604, 0, 0.612, '#joyful', '#admirable', 0.65, 'theater_of_absurd', 'playlet', 'drama', 'morality_play', 'mystery_play']
senticnet['mirage'] = [-0.947, 0, 0.866, -0.912, '#sad', '#disgusting', -0.908, 'movement', 'apparent_motion', 'motion', 'apparent_movement', 'optical_illusion']
senticnet['mire'] = [-0.71, 0, 0.704, -0.891, '#sad', '#disgusting', -0.768, 'soil', 'mud', 'dirt', 'bleaching_clay', 'bleaching_earth']
senticnet['mirror'] = [0.584, -0.627, 0, 0.815, '#surprising', '#admirable', 0.675, 'cheval_glass', 'car_mirror', 'hand_glass', 'hand_mirror', 'looking_glass']
senticnet['mirth'] = [0.807, 0.76, 0, 0.704, '#joyful', '#interesting', 0.757, 'rejoice', 'joyful', 'jovial', 'jocund', 'mirthful']
senticnet['mirthful'] = [0.715, 0.617, -0.23, 0.329, '#joyful', '#interesting', 0.477, 'jocund', 'jovial', 'jolly', 'joviality', 'banter']
senticnet['mirthfully'] = [0.653, 0.635, -0.244, 0.294, '#joyful', '#interesting', 0.446, 'merrily', 'jubilantly', 'happily', 'gayly', 'blithely']
senticnet['mirthfulness'] = [0.695, 0.623, -0.231, 0.319, '#joyful', '#interesting', 0.469, 'uproarious', 'hilariously', 'hilarious', 'screaming', 'uproariously']
senticnet['misadventure'] = [-0.627, 0, 0.507, -0.727, '#sad', '#disgusting', -0.62, 'accident', 'misfortune', 'bad_luck', 'near_miss', 'derailment']
senticnet['misalliance'] = [-0.615, 0, 0.668, -0.817, '#angry', '#disgusting', -0.7, 'mesalliance', 'marriage', 'matrimony', 'union', 'spousal_relationship']
senticnet['misanthropic'] = [-0.254, 0.301, 0.351, -0.51, '#angry', '#disgusting', -0.271, 'misanthropical', 'discouraging', 'outrageous', 'horrid', 'queasy']
senticnet['misanthropical'] = [-0.254, 0.301, 0.351, -0.51, '#angry', '#disgusting', -0.271, 'misanthropic', 'discouraging', 'outrageous', 'horrid', 'queasy']
senticnet['misanthropy'] = [-0.091, 0.201, 0.613, -0.628, '#angry', '#disgusting', -0.377, 'misopedia', 'misology', 'misogamy', 'misoneism', 'hatefully']
senticnet['misappropriation'] = [-0.751, 0, 0.982, -0.895, '#angry', '#disgusting', -0.876, 'raid', 'thieving', 'plunderage', 'larceny', 'theft']
senticnet['misbehave'] = [0, 0, 0.933, -0.887, '#angry', '#disgusting', -0.607, 'jump_chance', 'reach_advantage', 'conquer_opponent', 'debate_politics', 'fool_around']
senticnet['misbehavior'] = [-0.503, 0.112, -0.388, 0.066, '#sad', '#scared', -0.238, 'bad_behavior', 'retribution', 'mischief', 'correct_behavior', 'bad_child']
senticnet['miscalculate'] = [-0.738, 0, 0.527, -0.728, '#sad', '#disgusting', -0.664, 'underestimate', 'err', 'overrate', 'mistake', 'misjudge']
senticnet['miscalculation'] = [-0.509, 0, 0.762, -0.891, '#angry', '#disgusting', -0.721, 'error', 'fault', 'backfire', 'mistake', 'boomerang']
senticnet['miscarry'] = [-0.628, 0, 0.784, -0.868, '#angry', '#disgusting', -0.76, 'bodge', 'botch_up', 'flub', 'ball_up', 'bollix']
senticnet['mischance'] = [-0.912, 0, 0.905, -0.787, '#sad', '#angry', -0.868, 'pity', 'shame', 'mishap', 'misfortune', 'misadventure']
senticnet['mischief'] = [-0.397, 0.11, -0.376, 0.152, '#sad', '#scared', -0.17, 'misbehavior', 'cause_problem', 'trouble', 'bad_behavior', 'problem']
senticnet['mischievousness'] = [0.738, -0.895, 0, 0.634, '#joyful', '#surprising', 0.756, 'rascality', 'monkey_business', 'roguishness', 'deviltry', 'devilry']
senticnet['misconception'] = [-0.701, 0, 0.533, -0.627, '#sad', '#disgusting', -0.62, 'erroneous_belief', 'error', 'misunderstanding', 'hallucination', 'fancy']
senticnet['misconduct'] = [-0.635, 0, 0.728, -0.588, '#sad', '#angry', -0.65, 'usurpation', 'inroad', 'wrongdoing', 'wrongful_conduct', 'actus_reus']
senticnet['misconstrual'] = [-0.872, 0, 0.762, -0.921, '#sad', '#disgusting', -0.852, 'misreading', 'misinterpretation', 'misconstruction', 'imbroglio', 'interpretation']
senticnet['misconstruction'] = [-0.872, 0, 0.762, -0.921, '#sad', '#disgusting', -0.852, 'misreading', 'misconstrual', 'misinterpretation', 'imbroglio', 'interpretation']
senticnet['misconstrue'] = [0, 0, -0.921, -0.928, '#scared', '#disgusting', -0.616, 'misapprehend', 'amiss', 'misinterpret', 'misunderstand', 'misconceive']
senticnet['miscount'] = [-0.602, 0, 0.673, -0.915, '#angry', '#disgusting', -0.73, 'count', 'numeration', 'tally', 'counting', 'enumeration']
senticnet['miscreant'] = [-0.515, 0, 0.571, -0.593, '#angry', '#disgusting', -0.56, 'scapegrace', 'black_sheep', 'degenerate', 'wretch', 'pervert']
senticnet['misdeed'] = [-0.838, 0, 0.898, -0.589, '#sad', '#angry', -0.775, 'devilment', 'roguery', 'mischief', 'shenanigan', 'indecency']
senticnet['misdemean'] = [-0.815, 0, 0.964, -0.621, '#sad', '#angry', -0.8, 'act_up', 'move', 'fall_from_grace', 'carry_on', 'act']
senticnet['misdirect'] = [-0.903, 0, 0.888, -0.516, '#sad', '#angry', -0.769, 'suborn', 'modify', 'poison', 'lead_astray', 'alter']
senticnet['miserable'] = [-0.806, 0, 0.987, -0.857, '#angry', '#disgusting', -0.883, 'sorrowfully', 'dolefully', 'ruefulness', 'doleful', 'wretched']
senticnet['miserably'] = [-0.727, 0.304, -0.418, -0.073, '#sad', '#scared', -0.305, 'suffering', 'pitiable', 'piteous', 'hapless', 'pitiful']
senticnet['miserliness'] = [0.858, -0.636, 0, 0.961, '#joyful', '#admirable', 0.818, 'closeness', 'parsimony', 'parsimoniousness', 'meanness', 'minginess']
senticnet['misery'] = [-0.776, 0, 0.797, -0.735, '#sad', '#angry', -0.769, 'unhappiness', 'sorrow', 'remorse', 'melancholy', 'guilt']
senticnet['misestimation'] = [-0.51, 0, 0.674, -0.858, '#angry', '#disgusting', -0.681, 'error', 'fault', 'backfire', 'mistake', 'boomerang']
senticnet['misfit'] = [-0.997, 0, 0.804, -0.523, '#sad', '#angry', -0.775, 'addlehead', 'birdbrain', 'ape', 'loon', 'mortal']
senticnet['misfortunate'] = [-0.727, 0.304, -0.418, -0.073, '#sad', '#scared', -0.305, 'suffering', 'miserably', 'pitiable', 'piteous', 'hapless']
senticnet['misfortune'] = [-0.912, 0, 0.905, -0.787, '#sad', '#angry', -0.868, 'pity', 'shame', 'mishap', 'mischance', 'misadventure']
senticnet['misgauge'] = [-0.577, 0, 0.666, -0.668, '#angry', '#disgusting', -0.637, 'approximate', 'guess', 'gauge', 'estimate', 'judge']
senticnet['misgiving'] = [-0.982, 0, -0.759, 0, '#sad', '#scared', -0.58, 'qualm', 'scruple', 'insecurely', 'insecurity', 'insecure']
senticnet['misgovernment'] = [-0.825, 0, 0.575, -0.923, '#sad', '#disgusting', -0.774, 'governing', 'administration', 'government', 'governance', 'government_activity']
senticnet['misguide'] = [-0.781, 0, 0.704, -0.914, '#sad', '#disgusting', -0.8, 'direct', 'take', 'lead', 'conduct', 'guide']
senticnet['misguided'] = [0, 0, -0.803, -0.83, '#scared', '#disgusting', -0.544, 'misdirect', 'lead_astray', 'mislead', 'misadvise', 'ill-conceived']
senticnet['mishap'] = [-0.912, 0, 0.905, -0.787, '#sad', '#angry', -0.868, 'pity', 'shame', 'misfortune', 'mischance', 'misadventure']
senticnet['mishegaas'] = [0.579, -0.582, 0, 0.99, '#surprising', '#admirable', 0.717, 'folly', 'lunacy', 'craziness', 'indulgence', 'foolery']
senticnet['mishegoss'] = [0.807, -0.832, 0, 0.688, '#joyful', '#surprising', 0.776, 'folly', 'lunacy', 'craziness', 'indulgence', 'foolery']
senticnet['misinform'] = [-0.977, 0, 0.737, -0.555, '#sad', '#angry', -0.756, 'deceive', 'sandbag', 'betray', 'lead_astray', 'tergiversate']
senticnet['misinterpretation'] = [-0.872, 0, 0.762, -0.921, '#sad', '#disgusting', -0.852, 'misreading', 'misconstrual', 'misconstruction', 'imbroglio', 'interpretation']
senticnet['misjudge'] = [-0.738, 0, 0.527, -0.728, '#sad', '#disgusting', -0.664, 'underestimate', 'err', 'overrate', 'mistake', 'miscalculate']
senticnet['mislead'] = [-0.742, 0, 0.741, -0.925, '#sad', '#disgusting', -0.803, 'loathing', 'unattractive', 'bad_luck', 'feel_stressed', 'screw_up']
senticnet['misleader'] = [-0.642, 0, 0.962, -0.683, '#angry', '#disgusting', -0.762, 'beguiler', 'slicker', 'leader', 'deceiver', 'cheat']
senticnet['mismarry'] = [-0.838, 0, 0.64, -0.536, '#sad', '#angry', -0.671, 'marry', 'get_married', 'wed', 'conjoin', 'hook_up_with']
senticnet['mismatched'] = [-0.841, 0, 0.722, -0.767, '#sad', '#disgusting', -0.777, 'mismated', 'unsuited', 'unmatched', 'odd', 'incompatible']
senticnet['mismate'] = [-0.942, 0, 0.805, -0.934, '#sad', '#disgusting', -0.894, 'couple', 'pair', 'twin', 'match', 'mate']
senticnet['mismated'] = [-0.841, 0, 0.722, -0.767, '#sad', '#disgusting', -0.777, 'mismatched', 'unsuited', 'unmatched', 'odd', 'incompatible']
senticnet['misocainea'] = [-0.072, 0.192, 0.634, -0.635, '#angry', '#disgusting', -0.383, 'murderously', 'amuck', 'murderousness', 'amok', 'misogyny']
senticnet['misogamist'] = [-0.868, 0, 0.818, -0.966, '#sad', '#disgusting', -0.884, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['misogamy'] = [-0.082, 0.202, 0.615, -0.627, '#angry', '#disgusting', -0.374, 'misopedia', 'misology', 'misoneism', 'misanthropy', 'misogynism']
senticnet['misogynic'] = [-0.075, 0.195, 0.629, -0.633, '#angry', '#disgusting', -0.381, 'misogyny', 'misogynism', 'murderousness', 'amuck', 'amok']
senticnet['misogynism'] = [-0.075, 0.195, 0.629, -0.633, '#angry', '#disgusting', -0.381, 'misogynic', 'misogyny', 'murderousness', 'amuck', 'amok']
senticnet['misogyny'] = [-0.075, 0.195, 0.629, -0.633, '#angry', '#disgusting', -0.381, 'misogynic', 'misogynism', 'murderousness', 'amuck', 'amok']
senticnet['misology'] = [-0.082, 0.202, 0.615, -0.627, '#angry', '#disgusting', -0.374, 'misopedia', 'misogamy', 'misoneism', 'misanthropy', 'misogynism']
senticnet['misoneism'] = [-0.08, 0.2, 0.619, -0.629, '#angry', '#disgusting', -0.376, 'misopedia', 'misogamy', 'misology', 'misanthropy', 'misogyny']
senticnet['misopedia'] = [-0.082, 0.202, 0.615, -0.627, '#angry', '#disgusting', -0.374, 'misology', 'misogamy', 'misoneism', 'misanthropy', 'misogynism']
senticnet['misplace'] = [-0.171, 0.131, -0.207, 0.097, '#sad', '#scared', -0.05, 'lost_and_found', 'tv_series', 'bad_situation', 'odds', 'risk']
senticnet['mispronunciation'] = [0.524, -0.751, 0, 0.932, '#surprising', '#admirable', 0.736, 'accent', 'assibilation', 'sibilation', 'pronunciation', 'homophony']
senticnet['misreading'] = [-0.872, 0, 0.762, -0.921, '#sad', '#disgusting', -0.852, 'misinterpretation', 'misconstrual', 'misconstruction', 'imbroglio', 'interpretation']
senticnet['misreckoning'] = [-0.916, 0, 0.943, -0.81, '#sad', '#angry', -0.89, 'error', 'fault', 'backfire', 'mistake', 'boomerang']
senticnet['misremember'] = [-0.775, 0, 0.981, -0.522, '#sad', '#angry', -0.759, 'trip_up', 'stumble', 'misjudge', 'err', 'fall_for']
senticnet['misrepresent'] = [-0.609, 0, 0.813, -0.529, '#sad', '#angry', -0.65, 'warp', 'dissemble', 'feign', 'sham', 'pretend']
senticnet['misrepresentation'] = [-0.582, 0, 0.516, -0.795, '#sad', '#disgusting', -0.631, 'humbug', 'pretence', 'evasion', 'feigning', 'dissembling']
senticnet['misrule'] = [-0.682, 0, 0.809, -0.831, '#angry', '#disgusting', -0.774, 'governing', 'administration', 'government', 'governance', 'government_activity']
senticnet['miss'] = [-0.955, 0, 0.733, -0.989, '#sad', '#disgusting', -0.892, 'miss_bus', 'miss_flight', 'miss_coincidence', 'miss_out', 'miss_train']
senticnet['miss_appointment'] = [-0.91, 0, 0.71, -0.845, '#sad', '#disgusting', -0.822, 'quiet_mind', 'lower_standard', 'sleep_bed', 'think_future', 'sit_rock_chair']
senticnet['miss_ball'] = [-0.07, -0.06, 0.068, -0.086, '#sad', '#disgusting', -0.055, 'race_other', 'try_best', 'loose', 'sore_knee', 'lose_game']
senticnet['miss_bus'] = [-0.183, 0, -0.059, -0.082, '#sad', '#disgusting', -0.108, 'borrow_book_from_library', 'study_library', 'solve_equation', 'guess_answer', 'love_pet']
senticnet['miss_call'] = [-0.032, -0.047, 0.146, -0.185, '#angry', '#disgusting', -0.105, 'move_finger', 'loose_track_time', 'miss_out', 'part_of_band', 'make_noise']
senticnet['miss_coincidence'] = [-0.955, 0, 0.733, -0.989, '#sad', '#disgusting', -0.892, 'miss_bus', 'miss_flight', 'miss', 'miss_out', 'miss_train']
senticnet['miss_dead_friend'] = [-0.968, 0, 0.093, -0.997, '#sad', '#disgusting', -0.686, 'miss_one_person', 'nostalgia', 'miss_dead_person', 'miss_out', 'miss_dead_parent']
senticnet['miss_dead_parent'] = [-0.968, 0, 0.093, -0.997, '#sad', '#disgusting', -0.686, 'miss_one_person', 'nostalgia', 'miss_dead_person', 'miss_dead_friend', 'miss_out']
senticnet['miss_dead_person'] = [-0.968, 0, 0.093, -0.997, '#sad', '#disgusting', -0.686, 'miss_one_person', 'nostalgia', 'miss_out', 'miss_dead_friend', 'miss_dead_parent']
senticnet['miss_flight'] = [-0.955, 0, 0.733, -0.989, '#sad', '#disgusting', -0.892, 'miss_bus', 'miss', 'miss_coincidence', 'miss_out', 'miss_train']
senticnet['miss_one_person'] = [-0.968, 0, 0.093, -0.997, '#sad', '#disgusting', -0.686, 'miss_out', 'nostalgia', 'miss_dead_person', 'miss_dead_friend', 'miss_dead_parent']
senticnet['miss_other_half'] = [0.196, -0.141, 0.086, -0.124, '#joyful', '#surprising', 0.042, 'meet_member_opposite_sex', 'get_to_know_person', 'meet_new_person', 'get_hammered', 'celebrate_occasion']
senticnet['miss_out'] = [-0.968, 0, 0.093, -0.997, '#sad', '#disgusting', -0.686, 'miss_one_person', 'nostalgia', 'miss_dead_person', 'miss_dead_friend', 'miss_dead_parent']
senticnet['miss_parent'] = [0, 0, 0, -0.959, '#disgusting', '#disgusting', -0.32, 'immigrant', 'nostalgia', 'long_distance', 'long_distance_relationship', 'live_far_from_home']
senticnet['miss_point'] = [-0.081, -0.031, 0.043, -0.124, '#sad', '#disgusting', -0.072, 'poor_strategy', 'bad_luck', 'lose', 'lose_focus', 'lose_game']
senticnet['miss_red_light'] = [-0.921, 0, 0.833, -0.973, '#sad', '#disgusting', -0.909, 'accident', 'drive_fast', 'car_accident', 'big_car_accident', 'break_rule']
senticnet['miss_someone'] = [-0.993, 0, 0.673, -0.928, '#sad', '#disgusting', -0.865, 'sadness', 'boredom', 'become_sad', 'lose_job', 'lose_money']
senticnet['miss_train'] = [-0.955, 0, 0.733, -0.989, '#sad', '#disgusting', -0.892, 'miss_bus', 'miss_flight', 'miss_coincidence', 'miss_out', 'miss']
senticnet['miss_work'] = [0, -0.013, -0.066, -0.061, '#scared', '#disgusting', -0.038, 'sleep', 'sleep_upon', 'miss_bus', 'avoid_work', 'get_sleep']
senticnet['missed'] = [-0.991, 0, 0.797, -0.569, '#sad', '#angry', -0.786, 'dark', 'impenetrable', 'lost', 'uncomprehensible', 'unfathomable']
senticnet['missile'] = [0, 0, -0.849, -0.99, '#scared', '#disgusting', -0.613, 'explosive', 'projectile', 'nuclear_bomb', 'ammunition', 'dynamite']
senticnet['missing'] = [-0.988, 0, 0.801, -0.667, '#sad', '#angry', -0.819, 'lacking', 'wanting', 'nonextant', 'absent', 'nonexistent']
senticnet['mission'] = [0, 0, 0, 0.75, '#admirable', '#admirable', 0.25, 'make_happen', 'military_service', 'objective', 'hardship', 'set_instruction']
senticnet['mission_accomplished'] = [0, 0.083, 0, 0.148, '#interesting', '#admirable', 0.077, 'achieve_goal', 'maintenance', 'clean_often', 'vacuum_carpet', 'achievement']
senticnet['missionary_post'] = [-0.549, 0, 0.863, -0.76, '#angry', '#disgusting', -0.724, 'denomination', 'committee', 'citizens_committee', 'mission', 'ngo']
senticnet['misspell'] = [-0.886, 0, 0, -0.787, '#sad', '#disgusting', -0.558, 'mistake', 'error', 'grammar_mistake', 'poor_english', 'bad_writing']
senticnet['misstep'] = [-0.699, 0, 0.941, -0.759, '#angry', '#disgusting', -0.8, 'flub', 'blunder', 'blooper', 'bungle', 'botch']
senticnet['missy'] = [-0.744, 0, 0.877, -0.975, '#angry', '#disgusting', -0.865, 'miss', 'girl', 'chachka', 'young_lady', 'young_woman']
senticnet['mist'] = [0, 0, -0.739, -0.792, '#scared', '#disgusting', -0.51, 'hard_see', 'rain_fall', 'dew', 'rain', 'dizzy']
senticnet['mistake'] = [-0.746, 0, 0.876, -0.863, '#angry', '#disgusting', -0.828, 'problem', 'grammar_mistake', 'error', 'trouble', 'misspell']
senticnet['mistaking'] = [-0.527, 0, 0.502, -0.895, '#sad', '#disgusting', -0.641, 'misreading', 'misconstrual', 'misconstruction', 'imbroglio', 'interpretation']
senticnet['mister'] = [0.072, 0.098, 0, 0, '#joyful', '#interesting', 0.057, 'title', 'leader', 'head', 'chief', 'commander']
senticnet['mistreat'] = [-0.856, 0, 0.749, -0.998, '#sad', '#disgusting', -0.868, 'cold_foot', 'eat_worm', 'farm_bird', 'yellow_animal', 'biped']
senticnet['mistreatment'] = [-0.894, 0, 0.643, -0.884, '#sad', '#disgusting', -0.807, 'maltreatment', 'abuse', 'vexation', 'harassment', 'disregard']
senticnet['mistrust'] = [0, 0, 0, -0.904, '#disgusting', '#disgusting', -0.301, 'cause_suffer', 'disrespect', 'lose_team', 'bad_luck', 'leave_out']
senticnet['misty'] = [0.085, 0, 0, 0.089, '#joyful', '#admirable', 0.058, 'steam', 'haze', 'mist', 'initiation', 'summer_weather']
senticnet['misunderstand'] = [-0.874, 0, 0.867, -0.771, '#sad', '#angry', -0.837, 'persuade', 'misunderstanding', 'interrupt', 'look_eye', 'exchange_idea']
senticnet['misunderstanding'] = [-0.983, 0, 0.983, -0.701, '#sad', '#angry', -0.889, 'exchange_idea', 'persuade', 'dry_mouth', 'increase_understand', 'share_idea']
senticnet['misuse'] = [-0.994, 0, 0.827, -0.636, '#sad', '#angry', -0.819, 'substance_abuse', 'drug_abuse', 'habit', 'usage', 'use']
senticnet['mite'] = [-0.033, -0.075, 0.093, -0.127, '#angry', '#disgusting', -0.059, 'gnat', 'ladybug', 'bed_bug', 'ant', 'mosquito']
senticnet['mitigated'] = [-0.793, 0, 0.817, -0.538, '#sad', '#angry', -0.716, 'alleviated', 'eased', 'relieved', 'lessened', 'quenched']
senticnet['mitigation'] = [-0.798, 0, 0.651, -0.757, '#sad', '#disgusting', -0.735, 'defense', 'vindication', 'extenuation', 'exculpation', 'defence']
senticnet['mitral_stenosis'] = [-0.815, 0, 0.684, -0.813, '#sad', '#disgusting', -0.771, 'rhinostenosis', 'enterostenosis', 'laryngostenosis', 'aortic_stenosis', 'stenosis']
senticnet['mitt'] = [0.526, -0.705, 0, 0.607, '#surprising', '#admirable', 0.613, 'hooks', 'meat_hooks', 'maulers', 'right', 'left']
senticnet['mitten'] = [0.915, 0.738, 0, 0, '#joyful', '#interesting', 0.551, 'strap', 'man_clothes', 'bra', 'gauntlet', 'tie']
senticnet['mix'] = [0.83, -0.798, 0, 0, '#joyful', '#surprising', 0.543, 'jiggle', 'vibrate', 'prop_up', 'blend', 'ferment']
senticnet['mix_drink'] = [0.735, 0.944, 0, 0, '#joyful', '#interesting', 0.56, 'liquor_store', 'tavern', 'drinking_place', 'martini', 'bar']
senticnet['mix_metal'] = [0.024, 0.108, 0, 0.144, '#interesting', '#admirable', 0.092, 'make_out_metal', 'door_opener', 'both_functional_decorative', 'hardware', 'ore']
senticnet['mix_tracks'] = [0.067, 0.193, 0, 0.294, '#interesting', '#admirable', 0.185, 'compose_music', 'placement', 'small_group', 'combine_sound', 'location']
senticnet['mix_up'] = [-0.569, 0, 0.738, -0.615, '#angry', '#disgusting', -0.641, 'addle', 'muddle', 'puddle', 'assemble', 'piece']
senticnet['mixed'] = [-0.826, 0, 0.756, -0.516, '#sad', '#angry', -0.699, 'inhomogeneous', 'nonuniform', 'assorted', 'sundry', 'heterogeneous']
senticnet['mixed_bag'] = [-0.625, 0, 0.988, -0.591, '#sad', '#angry', -0.735, 'motley', 'mixture', 'variety', 'assortment', 'alphabet_soup']
senticnet['mixed_metal'] = [0.04, 0, 0.017, 0.056, '#joyful', '#admirable', 0.026, 'platinum', 'silver', 'alloy', 'titanium', 'heavy_element']
senticnet['mixture'] = [0.027, 0.15, 0, 0.22, '#interesting', '#admirable', 0.132, 'interjection', 'large_corporation', 'move_vehicle', 'blend', 'ford']
senticnet['mizzle'] = [-0.837, 0, 0.87, -0.978, '#angry', '#disgusting', -0.895, 'precipitate', 'rain_down', 'shower_down', 'spit', 'patter']
senticnet['moa'] = [-0.681, 0, 0.956, -0.909, '#angry', '#disgusting', -0.849, 'giant_moa', 'anomalopteryx', 'ratite', 'ratite_bird', 'flightless_bird']
senticnet['moan'] = [-0.11, -0.024, -0.112, -0.117, '#scared', '#disgusting', -0.105, 'scream', 'gasp', 'groan', 'hurt_feeling', 'make_anger']
senticnet['moaner'] = [-0.747, 0, 0.68, -0.586, '#sad', '#angry', -0.671, 'whiner', 'complainer', 'kvetch', 'sniveller', 'crybaby']
senticnet['moat'] = [0.048, 0, 0.009, 0.06, '#joyful', '#admirable', 0.033, 'pier', 'rich_person', 'squirt', 'puddle', 'dryad']
senticnet['mob'] = [-0.11, -0.024, -0.112, -0.117, '#scared', '#disgusting', -0.105, 'crowd', 'mass', 'crush', 'throng', 'group']
senticnet['mobbing'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'boss_around', 'violence', 'physical_pain', 'psychological_terror', 'bully']
senticnet['mobile'] = [0.11, 0.073, 0, 0.205, '#joyful', '#admirable', 0.129, 'basic_unit', 'microscopic', 'carry_around', 'hold_place', 'tiny_organism']
senticnet['mobile_phone'] = [0.054, 0, 0.035, 0.066, '#joyful', '#admirable', 0.028, 'phone', 'telephone', 'cellphone', 'telephone_room', 'pay_phone']
senticnet['mobility'] = [0, 0, 0, 0.144, '#admirable', '#admirable', 0.048, 'go_elsewhere', 'transport_person', 'get_around', 'locomotion', 'trucking']
senticnet['moccasin'] = [0.878, 0.979, 0, 0, '#joyful', '#interesting', 0.619, 'shoe', 'flip_flop', 'slipper', 'casual_shoes', 'footwear']
senticnet['moccasin_flower'] = [0.277, 0.161, 0, 0.337, '#joyful', '#admirable', 0.258, 'ladies_slipper', 'nerveroot', 'showy_lady_slipper', 'yellow_lady_slipper', 'clustered_lady_slipper']
senticnet['mock'] = [-0.432, 0.065, -0.326, 0, '#sad', '#scared', -0.231, 'wrong', 'bad_choice', 'unsafe', 'reprimand', 'caution']
senticnet['mocked'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'teased', 'tormented', 'bothered', 'annoyed', 'ridiculed']
senticnet['mocking'] = [-0.732, 0, 0.865, -0.878, '#angry', '#disgusting', -0.825, 'jeer', 'shout', 'abrupt', 'rude', 'bad_surprise']
senticnet['mod_con'] = [0.843, -0.998, 0, 0.706, '#joyful', '#surprising', 0.849, 'gadgetry', 'gimbal', 'injector', 'contrivance', 'device']
senticnet['modality'] = [0.785, -0.995, 0, 0.981, '#surprising', '#admirable', 0.92, 'ear', 'absolute_pitch', 'perfect_pitch', 'audition', 'sense_audition']
senticnet['mode_of_transport'] = [0, 0.736, 0, 0.736, '#interesting', '#admirable', 0.491, 'form_of_transportation', 'vehicle_type', 'means_of_transportation', 'mode_transportation', 'machine_transportation']
senticnet['mode_transportation'] = [0.181, 0, 0.034, 0.203, '#joyful', '#admirable', 0.117, 'fast_car', 'form_of_transportation', 'means_of_transportation', 'machine_transportation', 'car_model']
senticnet['model'] = [0, 0.934, 0, 0.807, '#interesting', '#admirable', 0.58, 'clothes_style', 'fancy_clothes', 'frilly', 'glamour', 'style']
senticnet['modem'] = [0.074, 0.069, 0.036, 0.055, '#joyful', '#interesting', 0.054, 'computer', 'browser', 'efficient', 'telephone_computer', 'computer_manufacturer']
senticnet['moderate'] = [0.861, 0.856, 0, 0, '#joyful', '#interesting', 0.572, 'check', 'hold', 'hold_in', 'abnegate', 'control']
senticnet['moderating'] = [0.761, -0.751, 0, 0.77, '#joyful', '#admirable', 0.761, 'analgesic', 'analgetic', 'anodyne', 'weakening', 'alleviative']
senticnet['moderation'] = [0.056, 0.157, 0, 0.154, '#interesting', '#admirable', 0.122, 'exercise', 'exercise_regularly', 'live_healthy_life', 'exercise_often', 'exercise_much']
senticnet['modern'] = [0.923, 0, 0, 0.885, '#joyful', '#admirable', 0.603, 'timely', 'right_now', 'up_date', 'art', 'contemporary']
senticnet['modern_dance'] = [-0.954, 0, 0.992, -0.633, '#sad', '#angry', -0.86, 'interpretive_dance', 'interpretive_dancing', 'interpretative_dance', 'interpretative_dancing', 'stage_dancing']
senticnet['modern_home'] = [0, 0.105, 0, 0.076, '#interesting', '#admirable', 0.06, 'house', 'mansion', 'high_rise_building', 'home', 'block_flat']
senticnet['modern_times'] = [0.86, -0.794, 0, 0.93, '#joyful', '#admirable', 0.861, 'time', 'present_times', 'modern_world', 'contemporary_world', 'period']
senticnet['modern_world'] = [0.86, -0.794, 0, 0.93, '#joyful', '#admirable', 0.861, 'modern_times', 'present_times', 'time', 'contemporary_world', 'period']
senticnet['modest'] = [0.907, 0, 0, 0.708, '#joyful', '#admirable', 0.538, 'minor', 'meek', 'low', 'humble', 'small']
senticnet['modestness'] = [0.686, -0.631, 0, 0.959, '#joyful', '#admirable', 0.759, 'propriety', 'properness', 'correctitude', 'modesty', 'decency']
senticnet['modesty'] = [0.027, 0, 0.102, -0.044, '#angry', '#disgusting', -0.04, 'protect_rain', 'make_dress', 'cover_table', 'keep_someone_warm', 'protect_body']
senticnet['modicum'] = [-0.63, 0, 0.791, -0.681, '#angry', '#disgusting', -0.701, 'little', 'pinch', 'small_indefinite_amount', 'dreg', 'indefinite_quantity']
senticnet['modification'] = [-0.978, 0, 0.856, -0.631, '#sad', '#angry', -0.822, 'laxation', 'change', 'tune', 'accommodation', 'loosening']
senticnet['modifier'] = [0.033, 0.234, -0.084, 0.274, '#interesting', '#admirable', 0.152, 'change', 'transform', 'adjust', 'precise', 'versatile']
senticnet['modify'] = [-0.5, 0, 0.598, -0.809, '#angry', '#disgusting', -0.636, 'temper', 'corrupt', 'cushion', 'syncopate', 'spoil']
senticnet['modishness'] = [0.547, -0.927, 0, 0.667, '#surprising', '#admirable', 0.714, 'elegance', 'jauntiness', 'rakishness', 'nattiness', 'dapperness']
senticnet['module'] = [0.939, -0.517, 0, 0.537, '#joyful', '#admirable', 0.664, 'understanding', 'intellect', 'ability', 'retentiveness', 'retentivity']
senticnet['modus_operandi'] = [0.544, -0.915, 0, 0.941, '#surprising', '#admirable', 0.8, 'rut', 'groove', 'rat_race', 'procedure', 'process']
senticnet['moistener'] = [0, -0.037, 0.05, -0.142, '#angry', '#disgusting', -0.052, 'electric_razor', 'shampoo_conditioner', 'hair_brush', 'tartar_control_toothpaste', 'gel_toothpaste']
senticnet['moisture'] = [0, -0.037, 0.05, -0.142, '#angry', '#disgusting', -0.052, 'humidity', 'wetness', 'damp', 'humid', 'dank']
senticnet['moisturize_skin'] = [0.095, -0.043, 0.04, 0, '#joyful', '#surprising', 0.033, 'cleanse_body', 'feel_clean', 'smell_clean', 'wash_person', 'feel_fresh']
senticnet['mojo'] = [0.7, -0.628, 0, 0.58, '#joyful', '#surprising', 0.636, 'white_magic', 'thaumaturgy', 'juju', 'conjuration', 'supernaturalism']
senticnet['molasses'] = [-0.089, 0.106, 0, 0.125, '#interesting', '#admirable', 0.047, 'sugar', 'treacle', 'black_treacle', 'add_sugar', 'sugar_substitute']
senticnet['mold'] = [0.933, -0.836, 0, 0.826, '#joyful', '#surprising', 0.865, 'influence', 'determine', 'shape', 'carry_weight', 'regulate']
senticnet['moldy_bread'] = [-0.174, -0.074, 0, -0.175, '#sad', '#disgusting', -0.092, 'rotten_fruit', 'bathroom_wall', 'compost_pile', 'wet_towel', 'fallen_tree']
senticnet['moldy_everywhere'] = [-0.027, -0.02, 0.031, -0.037, '#angry', '#disgusting', -0.025, 'bathroom_wall', 'fallen_tree', 'rotten_fruit', 'wet_towel', 'moldy_bread']
senticnet['moldy_food'] = [-0.089, -0.083, 0.036, -0.19, '#sad', '#disgusting', -0.077, 'bottle_water', 'old_newspaper', 'sour_milk', 'horseradish', 'plastic_container']
senticnet['mole'] = [0, 0, -0.073, 0, '#scared', '#scared', -0.024, 'nymph', 'impairment_person', 'nightly_ritual', 'rabbit', 'squirrel']
senticnet['mole_cricket'] = [0, -0.095, 0.123, -0.119, '#angry', '#disgusting', -0.049, 'gypsy_moth', 'japanese_beetle', 'cucumber_beetle', 'mosquito', 'earwig']
senticnet['molecule'] = [0, 0.184, -0.051, 0.179, '#interesting', '#admirable', 0.104, 'hygroscope', 'hold_water', 'antiquate', 'absorb_water', 'tangent']
senticnet['molest'] = [-0.593, 0.162, 0.221, -0.503, '#sad', '#disgusting', -0.385, 'annoy', 'harass', 'provoke', 'beset', 'chivvy']
senticnet['moll'] = [0.834, -0.806, 0, 0.889, '#joyful', '#admirable', 0.843, 'felon', 'crook', 'malefactor', 'outlaw', 'criminal']
senticnet['mollify'] = [0.942, -0.976, 0, 0.554, '#joyful', '#surprising', 0.824, 'tranquilize', 'tranquillize', 'calm_down', 'quieten', 'calm']
senticnet['mollycoddler'] = [0.503, -0.678, 0, 0.651, '#surprising', '#admirable', 0.611, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['molybdenite'] = [0.555, -0.994, 0, 0.851, '#surprising', '#admirable', 0.8, 'quartz', 'cerussite', 'white_lead_ore', 'cobaltite', 'mineral']
senticnet['mom'] = [0.774, 0, 0, 0.727, '#joyful', '#admirable', 0.5, 'bride', 'girl', 'flower_girl', 'daughter', 'grandmother']
senticnet['mom_dad'] = [0, 0.763, 0, 0.759, '#interesting', '#admirable', 0.507, 'mother_father', 'father_mother', 'parent_child', 'brother_sister', 'relate_person']
senticnet['mom_house'] = [0.032, 0.08, 0, 0.068, '#interesting', '#admirable', 0.06, 'way', 'menagerie', 'another_place', 'habitat', 'home']
senticnet['mommy'] = [0.793, 0, 0, 0.845, '#joyful', '#admirable', 0.546, 'adopt_child', 'father_child', 'mother_child', 'kinship', 'father_son']
senticnet['monarch'] = [0.051, 0.077, 0, 0.091, '#interesting', '#admirable', 0.073, 'king', 'royal_leader', 'emperor', 'duchess', 'royalty']
senticnet['monarchal'] = [-0.551, 0, 0.931, -0.74, '#angry', '#disgusting', -0.741, 'totalitarian', 'authoritarian', 'dictatorial', 'despotic', 'undemocratic']
senticnet['monarchy'] = [0.059, 0.092, 0, 0.107, '#interesting', '#admirable', 0.086, 'royalty', 'monarch', 'throne', 'emperor', 'king_queen']
senticnet['monastery'] = [0.026, 0.244, 0, 0.205, '#interesting', '#admirable', 0.158, 'capital_build', 'temple', 'confession', 'chapel', 'church']
senticnet['monday'] = [-0.888, 0, 0, -0.78, '#sad', '#disgusting', -0.556, 'friday', 'day_of_week', 'decade', 'sadness', 'slack']
senticnet['monday_morning'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'monday', 'feel_tired', 'set_alarm', 'go_to_work', 'traffic_jam']
senticnet['monetary'] = [0, 0.285, 0, 0.191, '#interesting', '#admirable', 0.159, 'like_cost', 'item_worth', 'payment_amount', 'sticker', 'money_amount']
senticnet['monetary_amount'] = [-0.03, 0.251, 0, 0.164, '#interesting', '#admirable', 0.128, 'money_value', 'money_amount', 'money_term', 'monetary', 'monetary_value']
senticnet['monetary_gain'] = [0.702, 0.972, 0, 0.751, '#interesting', '#admirable', 0.808, 'financial_gain', 'earnings', 'investment_return', 'money_earn', 'income']
senticnet['monetary_resource'] = [0.534, -0.868, 0, 0.736, '#surprising', '#admirable', 0.713, 'funds', 'finances', 'escrow_funds', 'cash_in_hand', 'pecuniary_resource']
senticnet['monetary_unit'] = [0, 0.096, 0.072, 0.088, '#interesting', '#admirable', 0.037, 'form_of_money', 'money_unit', 'currency_unit', 'american_coin', 'small_coin']
senticnet['monetary_value'] = [0, 0.238, 0.021, 0.152, '#interesting', '#admirable', 0.123, 'money_value', 'money_amount', 'worth', 'monetary_amount', 'like_cost']
senticnet['monetize'] = [0.886, -0.778, 0, 0.815, '#joyful', '#admirable', 0.826, 'countenance', 'legitimate', 'permit', 'allow', 'let']
senticnet['money'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'down_payment', 'take_out_loan', 'cash', 'wealthy', 'bring_wallet']
senticnet['money_amount'] = [-0.026, 0.245, 0.012, 0.153, '#interesting', '#admirable', 0.12, 'money_value', 'sticker', 'dollar_sign', 'value_amount', 'monetary_amount']
senticnet['money_bank'] = [0.92, 0.976, 0, 0, '#joyful', '#interesting', 0.632, 'bring_wallet', 'money_credit', 'moolah', 'good_credit', 'enough_money']
senticnet['money_buy'] = [0.046, 0.071, 0, 0.066, '#interesting', '#admirable', 0.061, 'go_grocery_store', 'go_supermarket', 'provide_family', 'sell_sandwich', 'plan_meal']
senticnet['money_change'] = [0, 0.119, 0.07, 0.104, '#interesting', '#admirable', 0.051, 'small_coin', 'money_coin', 'small_money', 'small_change', 'small_currency']
senticnet['money_charge'] = [-0.063, 0.295, -0.089, 0.17, '#interesting', '#admirable', 0.104, 'money_payment', 'amount_due', 'payment_amount', 'amount_owe', 'account_term']
senticnet['money_clip'] = [0.024, 0.146, 0.015, 0, '#joyful', '#interesting', 0.052, 'bank_vault', 'hold_change', 'wallet', 'bank_account', 'billfold']
senticnet['money_coin'] = [0, 0.134, 0.065, 0.135, '#interesting', '#admirable', 0.068, 'small_coin', 'small_money', 'small_currency', 'money_change', 'metal_money']
senticnet['money_collector'] = [0.03, 0.187, 0.018, 0.115, '#interesting', '#admirable', 0.105, 'money_keeper', 'hold_coin', 'money_hold', 'money_place', 'money_holder']
senticnet['money_credit'] = [-0.825, 0, 0, 0, '#sad', '#sad', -0.275, 'moolah', 'plan_advance', 'bind_agreement', 'ask_money', 'bring_wallet']
senticnet['money_due'] = [-0.973, 0, 0, -0.718, '#sad', '#disgusting', -0.564, 'account_term', 'money_owe', 'amount_owe', 'money', 'money_loss']
senticnet['money_earn'] = [0.806, 0.776, 0, 0.761, '#joyful', '#interesting', 0.781, 'job_pay', 'extra_money', 'investment_return', 'financial_gain', 'monetary_gain']
senticnet['money_exchange'] = [-0.078, 0.314, -0.115, 0.229, '#interesting', '#admirable', 0.117, 'send_money', 'give_cash', 'financial_transaction', 'currency_exchange', 'money']
senticnet['money_hold'] = [0.023, 0.215, 0, 0.128, '#interesting', '#admirable', 0.122, 'money_place', 'money_storage', 'money_holder', 'wallet', 'put_money']
senticnet['money_holder'] = [0.026, 0.194, 0, 0.097, '#interesting', '#admirable', 0.106, 'money_storage', 'keep_money', 'put_money', 'money_hold', 'money_place']
senticnet['money_inside'] = [0, 0.136, 0.017, 0.065, '#interesting', '#admirable', 0.061, 'hold_money', 'check_account', 'teller', 'money_storage', 'savings']
senticnet['money_involve'] = [-0.037, 0.238, 0, 0.137, '#interesting', '#admirable', 0.113, 'price_high', 'money_pay', 'monetary_amount', 'money_payment', 'monetary_value']
senticnet['money_keeper'] = [0.034, 0.196, 0, 0.119, '#interesting', '#admirable', 0.116, 'money_place', 'money_collector', 'money_holder', 'money_hold', 'hold_coin']
senticnet['money_loss'] = [-0.834, 0.214, -0.391, -0.108, '#sad', '#scared', -0.373, 'account_term', 'money_payment', 'amount_owe', 'amount_pay', 'amount_due']
senticnet['money_make'] = [0.96, 0.937, 0, 0.747, '#joyful', '#interesting', 0.881, 'monetary_gain', 'financial_gain', 'business_term', 'earnings', 'earn_income']
senticnet['money_maker'] = [0.024, 0.297, -0.058, 0.186, '#interesting', '#admirable', 0.15, 'savings_account', 'enterprise', 'business', 'corporation', 'business_term']
senticnet['money_owe'] = [0.702, 0.772, 0, 0.963, '#interesting', '#admirable', 0.812, 'money_due', 'amount_owe', 'account_term', 'money_payment', 'money_loss']
senticnet['money_pay'] = [0.914, 0.816, 0, 0.732, '#joyful', '#interesting', 0.821, 'money', 'earnings', 'repay', 'money_owe', 'income']
senticnet['money_payment'] = [0.858, 0.706, 0, 0.709, '#joyful', '#admirable', 0.758, 'payment_amount', 'amount_owe', 'account_term', 'money_charge', 'amount_due']
senticnet['money_place'] = [0.021, 0.212, 0, 0.11, '#interesting', '#admirable', 0.114, 'money_hold', 'money_holder', 'money_storage', 'money_keeper', 'bank']
senticnet['money_relate'] = [-0.093, 0.333, -0.11, 0.201, '#interesting', '#admirable', 0.11, 'percentage', 'payment_amount', 'money_loss', 'money_charge', 'money_payment']
senticnet['money_save'] = [0, 0.316, 0, 0.232, '#interesting', '#admirable', 0.183, 'lower_price', 'good_deal', 'money_transfer', 'good_price', 'money_relate']
senticnet['money_spend'] = [-0.028, 0.218, -0.061, 0.074, '#interesting', '#admirable', 0.068, 'spend', 'pay_money', 'purchase', 'owe_money', 'pay_goods']
senticnet['money_storage'] = [0.026, 0.202, 0.017, 0.104, '#interesting', '#admirable', 0.105, 'money_holder', 'money_hold', 'money_place', 'keep_money', 'hold_money']
senticnet['money_term'] = [-0.025, 0.265, 0, 0.16, '#interesting', '#admirable', 0.133, 'payment_amount', 'amount_charge', 'amount_due', 'monetary_amount', 'money_amount']
senticnet['money_ticket'] = [-0.069, 0, 0, 0, '#sad', '#sad', -0.023, 'purchase_ticket', 'buy_ticket_theater', 'buy_ticket', 'use_ticket', 'book_ticket']
senticnet['money_transfer'] = [-0.083, 0.313, -0.096, 0.199, '#interesting', '#admirable', 0.111, 'repay', 'money', 'money_pay', 'transfer', 'earnings']
senticnet['money_unit'] = [0, 0.145, 0.061, 0.112, '#interesting', '#admirable', 0.065, 'currency_unit', 'monetary_unit', 'form_of_money', 'american_coin', 'american_money']
senticnet['money_value'] = [0, 0.245, 0.016, 0.156, '#interesting', '#admirable', 0.128, 'money_amount', 'monetary_value', 'monetary_amount', 'worth', 'sticker']
senticnet['money_wallet'] = [0, 0.146, 0, 0, '#interesting', '#interesting', 0.049, 'life-long_mate', 'volume_control', 'belly_button', 'work_to_earn_money', 'two_ears']
senticnet['moneymaking'] = [0.679, -0.757, 0, 0.658, '#joyful', '#surprising', 0.698, 'acquisition', 'heritage', 'purchase', 'assumption', 'restitution']
senticnet['mongolianism'] = [-0.985, 0, 0.897, -0.948, '#sad', '#disgusting', -0.943, 'trisomy', 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder']
senticnet['mongolism'] = [-0.675, 0, 0.973, -0.504, '#sad', '#angry', -0.717, 'trisomy', 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder']
senticnet['monition'] = [0.543, -0.986, 0, 0.554, '#surprising', '#admirable', 0.694, 'rebuke', 'reproof', 'reproval', 'reprehension', 'reprimand']
senticnet['monitor'] = [0, 0.102, 0.016, 0.076, '#interesting', '#admirable', 0.054, 'computer_part', 'system', 'motherboard', 'pencil_pen', 'cpu']
senticnet['monitor_heart_rate'] = [-0.105, -0.029, 0, -0.071, '#sad', '#disgusting', -0.049, 'collapse', 'stand_around', 'perspire', 'hit_car', 'strike_out']
senticnet['monk'] = [0.025, 0.246, 0, 0.226, '#interesting', '#admirable', 0.166, 'pastor', 'church_head', 'protestant', 'prayer', 'religion']
senticnet['monkey'] = [0, 0.768, 0, 0.818, '#interesting', '#admirable', 0.529, 'fiance', 'marmoset', 'lemur', 'beaver', 'koala']
senticnet['monkey_business'] = [0.738, -0.895, 0, 0.634, '#joyful', '#surprising', 0.756, 'rascality', 'mischievousness', 'roguishness', 'deviltry', 'devilry']
senticnet['monkey_wrench'] = [-0.129, -0.095, 0.015, -0.097, '#sad', '#disgusting', -0.049, 'broken_car', 'work_well', 'damage_car', 'need_fix', 'car_wheel']
senticnet['monochromacy'] = [-0.743, 0, 0.793, -0.625, '#sad', '#angry', -0.72, 'visual_impairment', 'visual_defect', 'vision_defect', 'visual_disorder', 'color_blindness']
senticnet['monocle'] = [0, -0.028, 0.048, -0.058, '#angry', '#disgusting', -0.026, 'telescope', 'read_glass', 'eyeglass', 'camera', 'binoculars']
senticnet['monolithic'] = [-0.929, 0, 0.859, -0.64, '#sad', '#angry', -0.809, 'undistributed', 'undiversified', 'unanimous', 'whole', 'solid']
senticnet['monopoly'] = [-0.788, 0, 0.993, 0, '#sad', '#angry', -0.594, 'verbosity', 'type_of_game', 'scrabble', 'fun_game', 'sport_play']
senticnet['monosemy'] = [0.981, -0.767, 0, 0.733, '#joyful', '#surprising', 0.827, 'lucidness', 'clarity', 'clearness', 'lucidity', 'pellucidity']
senticnet['monospaced_font'] = [-0.986, 0, 0.969, -0.957, '#sad', '#angry', -0.971, 'face', 'font', 'fount', 'typeface', 'case']
senticnet['monotony'] = [-0.169, -0.079, -0.057, -0.202, '#sad', '#disgusting', -0.116, 'repetitive_task', 'lose_time', 'much_work', 'work_much', 'advertise_company']
senticnet['monsoon'] = [-0.195, -0.105, 0.041, -0.233, '#sad', '#disgusting', -0.121, 'hailstone', 'cold_hot', 'snow', 'dandruff', 'rain']
senticnet['monster'] = [0, 0, 0.995, -0.858, '#angry', '#disgusting', -0.618, 'savage', 'ogre', 'demon', 'devil', 'demoniac']
senticnet['monstrosity'] = [-0.652, 0, 0.645, -0.53, '#sad', '#angry', -0.609, 'mutant', 'variation', 'sport', 'leviathan', 'mutation']
senticnet['monstrously'] = [-0.852, 0, 0.958, 0, '#sad', '#angry', -0.603, 'horrifying', 'atrocious', 'dreadfully', 'horrifyingly', 'horrified']
senticnet['month'] = [0, 0, -0.116, 0, '#scared', '#scared', -0.039, 'year', 'week', 'century', 'reckon', 'november']
senticnet['monthly'] = [-0.085, 0.244, -0.09, 0.141, '#interesting', '#admirable', 0.07, 'monthly_pay', 'monthly_payment', 'money_owe', 'money_pay', 'repay']
senticnet['monthly_due'] = [-0.053, 0.249, -0.061, 0.133, '#interesting', '#admirable', 0.089, 'earnings', 'money_pay', 'rent', 'income', 'give_money']
senticnet['monthly_pay'] = [-0.089, 0.298, -0.144, 0.185, '#interesting', '#admirable', 0.083, 'money_due', 'rent', 'repay', 'money_owe', 'revenue']
senticnet['monthly_payment'] = [0, 0.289, -0.115, 0.17, '#interesting', '#admirable', 0.115, 'monthly_pay', 'money_owe', 'money_pay', 'monthly', 'monthly_due']
senticnet['monument'] = [0.029, 0.175, 0, 0.09, '#interesting', '#admirable', 0.098, 'liberty', 'statue', 'cemetery', 'city_hall', 'sculpture']
senticnet['moo'] = [0, 0.115, 0, 0.105, '#interesting', '#admirable', 0.073, 'yellow_green', 'pink', 'vintage', 'black_white', 'beautiful_well_useful']
senticnet['mooch'] = [0.866, -0.917, 0, 0.893, '#surprising', '#admirable', 0.892, 'freeload', 'cadge', 'grub', 'sponge', 'bum']
senticnet['mood'] = [0, 1, 0, 0, '#interesting', '#interesting', 0.333, 'interest', 'interesting', 'attention', 'strong_emotion', 'emotion']
senticnet['moodiness'] = [-0.973, 0, 0.848, -0.586, '#sad', '#angry', -0.802, 'moroseness', 'sullenness', 'ill_humor', 'glumness', 'distemper']
senticnet['moolah'] = [-0.825, 0, 0, 0, '#sad', '#sad', -0.275, 'ask_money', 'plan_advance', 'bind_agreement', 'money_credit', 'bring_wallet']
senticnet['moon'] = [0, -0.946, 0, 0.845, '#surprising', '#admirable', 0.597, 'galaxy', 'universe', 'planetary', 'sun', 'dwarf_planet']
senticnet['moon_blindness'] = [-0.68, 0, 0.517, -0.709, '#sad', '#disgusting', -0.635, 'visual_impairment', 'visual_defect', 'vision_defect', 'visual_disorder', 'avitaminosis']
senticnet['moon_curser'] = [-0.875, 0, 0.6, -0.764, '#sad', '#disgusting', -0.746, 'criminal', 'outlaw', 'malefactor', 'felon', 'crook']
senticnet['moon_gravity'] = [0, 0, -1, -1, '#scared', '#disgusting', -0.667, 'coercion', 'force', 'volt', 'watt', 'power_source']
senticnet['moon_star'] = [-0.096, 0, -0.066, 0, '#sad', '#scared', -0.054, 'night', 'darkness', 'sun_down', 'dusk', 'day_end']
senticnet['moonlight'] = [0.042, 0.126, -0.065, 0.165, '#interesting', '#admirable', 0.089, 'sparkle', 'shiny', 'shinny', 'gray', 'shine']
senticnet['mop'] = [0.72, -0.764, 0, 0.695, '#joyful', '#surprising', 0.726, 'clean_up', 'blot', 'wipe_up', 'suck_up', 'sponge_up']
senticnet['mop_floor'] = [0.84, 0, 0, 0.901, '#joyful', '#admirable', 0.58, 'mow_grass', 'meet_need', 'clean_sink', 'help_person', 'bring_food']
senticnet['mop_up'] = [0.72, -0.764, 0, 0.695, '#joyful', '#surprising', 0.726, 'suck_up', 'blot', 'wipe_up', 'mop', 'sponge_up']
senticnet['mope'] = [-0.094, 0, 0, 0, '#sad', '#sad', -0.031, 'unicycle', 'truck', 'lorry', 'vehicle', 'vehicle_type']
senticnet['moppet'] = [0.738, -0.537, 0, 0.856, '#joyful', '#admirable', 0.71, 'farm_girl', 'flower_girl', 'little_girl', 'schoolgirl', 'female']
senticnet['moral_philosophy'] = [0.601, -0.846, 0, 0.872, '#surprising', '#admirable', 0.773, 'bioethics', 'hedonism', 'philosophy', 'casuistry', 'eudemonism']
senticnet['moral_principle'] = [0.841, -0.657, 0, 0.645, '#joyful', '#surprising', 0.714, 'precept', 'rule', 'caveat_emptor', 'higher_law', 'hypothetical_imperative']
senticnet['moral_sense'] = [0.714, -0.583, 0, 0.667, '#joyful', '#admirable', 0.655, 'morality', 'wee_small_voice', 'small_voice', 'voice_of_conscience', 'sense_of_shame']
senticnet['moralist'] = [0.922, -0.949, 0, 0.965, '#surprising', '#admirable', 0.945, 'utilitarian', 'egalitarian', 'equalitarian', 'elitist', 'philosopher']
senticnet['morality'] = [0, 0.189, 0, 0.177, '#interesting', '#admirable', 0.122, 'good', 'like_candy', 'elusive', 'uncommon', 'versatile']
senticnet['morality_play'] = [0.734, -0.604, 0, 0.612, '#joyful', '#admirable', 0.65, 'theater_of_absurd', 'playlet', 'miracle_play', 'drama', 'mystery_play']
senticnet['morals'] = [-0.652, 0, 0.683, -0.727, '#angry', '#disgusting', -0.687, 'motive', 'need', 'motivation', 'conscience', 'scruple']
senticnet['moratorium'] = [0.976, -0.719, 0, 0.863, '#joyful', '#admirable', 0.853, 'hold', 'delay', 'wait', 'time_lag', 'postponement']
senticnet['morbid'] = [-0.754, 0, 0.909, -0.968, '#angry', '#disgusting', -0.877, 'noisome', 'unhealthy', 'unwholesome', 'nauseating', 'nauseous']
senticnet['morbidity'] = [-0.754, 0, 0.893, -0.618, '#sad', '#angry', -0.755, 'unwholesomeness', 'morbidness', 'unhealthfulness', 'insalubrity', 'insalubriousness']
senticnet['morbidness'] = [-0.754, 0, 0.893, -0.618, '#sad', '#angry', -0.755, 'unwholesomeness', 'unhealthfulness', 'morbidity', 'insalubrity', 'insalubriousness']
senticnet['mordant'] = [-0.773, 0, 0.537, -0.649, '#sad', '#disgusting', -0.653, 'grim', 'saturnine', 'sardonic', 'sarcastic', 'black']
senticnet['more_easy_life'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'relaxation', 'feel_relieved', 'feel_released', 'pressure_go_away', 'feel_relief']
senticnet['morgan_le_fay'] = [-0.751, 0, 0.559, -0.88, '#sad', '#disgusting', -0.73, 'fairy', 'faery', 'faerie', 'fay', 'sprite']
senticnet['morgue'] = [-0.06, 0.09, -0.148, -0.157, '#scared', '#disgusting', -0.092, 'casket', 'coffin', 'grave', 'headstone', 'bury_person']
senticnet['morion'] = [-0.595, 0, 0.887, -0.715, '#angry', '#disgusting', -0.732, 'armet', 'basinet', 'casque', 'heaume', 'helmet']
senticnet['mormon'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'apple_tree', 'rosebush', 'snake', 'fox', 'ferret']
senticnet['morning'] = [0.991, -0.811, 0, 0, '#joyful', '#surprising', 0.601, 'breakfast', 'dry_fruit', 'carton_milk', 'wheat', 'box_cereal']
senticnet['morning_food'] = [0.832, -0.996, 0, 0, '#joyful', '#surprising', 0.609, 'food_item', 'bake_product', 'eatable', 'sweet_treat', 'bake_good']
senticnet['moron'] = [0, 0, 0.728, -0.783, '#angry', '#disgusting', -0.504, 'challenge_oneself', 'increase_body_temperature', 'like_compete', 'get_excited', 'sense_accomplishment']
senticnet['moronity'] = [-0.563, 0, 0.735, -0.64, '#angry', '#disgusting', -0.646, 'slowness', 'mental_retardation', 'backwardness', 'subnormality', 'retardation']
senticnet['morose'] = [0, 0, -0.835, -0.703, '#scared', '#disgusting', -0.513, 'moody', 'dour', 'glum', 'dark', 'glowering']
senticnet['moroseness'] = [-0.959, 0, 0.694, -0.949, '#sad', '#disgusting', -0.867, 'sullenness', 'ill_nature', 'crabbiness', 'crabbedness', 'crankiness']
senticnet['morosoph'] = [0.794, -0.781, 0, 0.822, '#joyful', '#admirable', 0.799, 'saphead', 'muggins', 'tomfool', 'fool', 'sap']
senticnet['morphia'] = [0.627, -0.72, 0, 0.974, '#surprising', '#admirable', 0.774, 'analgesic', 'apomorphine', 'anodyne', 'painkiller', 'pain_pill']
senticnet['morphine'] = [0, 0, -0.116, -0.204, '#scared', '#disgusting', -0.107, 'codeine', 'drug', 'phenobarbital', 'analgesic', 'sleep_drug']
senticnet['morris_dance'] = [-0.744, 0, 0.501, -0.99, '#sad', '#disgusting', -0.745, 'farandole', 'mazurka', 'polka', 'folk_dance', 'morris_dancing']
senticnet['morris_dancing'] = [-0.744, 0, 0.501, -0.99, '#sad', '#disgusting', -0.745, 'farandole', 'mazurka', 'polka', 'morris_dance', 'folk_dance']
senticnet['morse_code'] = [0.144, -0.111, 0.013, -0.032, '#joyful', '#surprising', 0.07, 'dance', 'old_dance', 'slow_dance', 'enter_contest', 'stout']
senticnet['mortal'] = [0, 0, -0.753, -0.749, '#scared', '#disgusting', -0.501, 'reaper', 'dead', 'cadaver', 'dead_person', 'end_life']
senticnet['mortal_sin'] = [0.69, -0.644, 0, 0.825, '#joyful', '#admirable', 0.72, 'lust', 'luxuria', 'sinning', 'pride', 'superbia']
senticnet['mortality'] = [-0.877, 0, 0.744, -0.54, '#sad', '#angry', -0.72, 'temporariness', 'transience', 'transiency', 'transitoriness', 'impermanence']
senticnet['mortar'] = [0, 0, -0.71, -0.873, '#scared', '#disgusting', -0.528, 'cannon', 'explosive', 'firearm', 'pistol', 'machine_gun']
senticnet['mortgage'] = [-0.061, 0.287, -0.083, 0.116, '#interesting', '#admirable', 0.086, 'money_transfer', 'loan', 'cash_pay', 'wealth', 'income']
senticnet['mortification'] = [-0.992, 0, -0.763, 0, '#sad', '#scared', -0.585, 'uncomfortableness', 'self-consciousness', 'self-conscious', 'confusedly', 'discombobulation']
senticnet['mortified'] = [-0.931, 0, -0.891, 0, '#sad', '#scared', -0.607, 'humiliated', 'mortifying', 'self-hatred', 'self-disgust', 'shameful']
senticnet['mortify'] = [-0.709, 0, -0.739, 0, '#sad', '#scared', -0.483, 'abase', 'embarrassed', 'self-hatred', 'self-disgust', 'humiliated']
senticnet['mortifying'] = [-0.718, 0, -0.934, 0, '#sad', '#scared', -0.551, 'humiliated', 'mortified', 'self-hatred', 'self-disgust', 'shameful']
senticnet['mortuary'] = [0, 0, -0.05, -0.034, '#scared', '#disgusting', -0.028, 'grandma_house', 'game_room', 'old_folk_home', 'computer_lab', 'chess_tournament']
senticnet['mos'] = [0.042, 0.225, -0.108, 0.191, '#interesting', '#admirable', 0.117, 'social_creature', 'sect', 'hypocrite', 'sentient', 'jewish']
senticnet['mosh_pit'] = [0.26, 0, 0, 0.089, '#joyful', '#admirable', 0.116, 'balcony_rail', 'movie_theater_seat', 'row_seat', 'usher', 'sticky_floor']
senticnet['mosque'] = [0, 0.224, 0, 0.197, '#interesting', '#admirable', 0.14, 'church', 'temple', 'cathedral', 'chapel', 'confession']
senticnet['mosquito'] = [0, -0.094, 0.128, -0.129, '#angry', '#disgusting', -0.054, 'gnat', 'mole_cricket', 'gypsy_moth', 'flea', 'cucumber_beetle']
senticnet['mosquito_bite'] = [0, 0, 0.752, -0.888, '#angry', '#disgusting', -0.547, 'enjoy_fresh_air', 'look_scenery', 'become_tired', 'dog_bark', 'leg_hurt']
senticnet['moss'] = [0.734, -0.912, 0, 0, '#joyful', '#surprising', 0.549, 'stem', 'evergreen', 'leaf', 'branch', 'evergreen_tree']
senticnet['mossy_saxifrage'] = [-0.565, 0, 0.848, -0.801, '#angry', '#disgusting', -0.738, 'herb', 'yellow_mountain_saxifrage', 'meadow_saxifrage', 'breakstone', 'western_saxifrage']
senticnet['most'] = [0, 0.075, 0, 0.159, '#interesting', '#admirable', 0.078, 'maximum', 'highest', 'utmax', 'top', 'max']
senticnet['most_animals'] = [-0.047, 0, 0.01, -0.066, '#sad', '#disgusting', -0.041, 'vertebrate', 'feline', 'pet', 'tiger', 'dog_cat']
senticnet['most_balls'] = [0.035, -0.108, 0.026, 0, '#joyful', '#surprising', 0.039, 'helium_balloon', 'dart_board', 'ball', 'roller_coaster', 'horseshoe']
senticnet['most_birds'] = [0.114, 0, 0, 0, '#joyful', '#joyful', 0.038, 'mallard', 'vulture', 'pigeon', 'bird', 'can_fly']
senticnet['most_cars'] = [0, 0, 0, 0.103, '#admirable', '#admirable', 0.034, 'fancy_car', 'old_car', 'expensive_car', 'car_model', 'car']
senticnet['most_cats'] = [0.039, 0.086, 0, 0, '#joyful', '#interesting', 0.042, 'leopard', 'only_mammal', 'lynx', 'mane', 'hare']
senticnet['most_children'] = [-0.06, 0, 0.01, 0, '#sad', '#angry', -0.023, 'youth', 'young_child', 'small_child', 'lad', 'toddler']
senticnet['most_dogs'] = [-0.037, 0, 0.049, 0, '#sad', '#angry', -0.029, 'need_care', 'baby_dog', 'baby_need', 'young_animal', 'dog']
senticnet['most_good'] = [0.11, -0.291, -0.112, 0.509, '#surprising', '#admirable', 0.266, 'better_good', 'really_good', 'high_quality', 'exceptional', 'well_done']
senticnet['most_homes'] = [0, 0.149, 0, 0, '#interesting', '#interesting', 0.05, 'home', 'time_limit', 'fourth', 'monthly', 'modern_home']
senticnet['most_plants'] = [0.94, 0.933, 0, 0, '#joyful', '#interesting', 0.624, 'porcupine', 'plant', 'poisonous_plant', 'yellow_flower', 'lichen']
senticnet['mote'] = [0, -0.028, 0.091, -0.07, '#angry', '#disgusting', -0.044, 'ladybug', 'mite', 'pinhead', 'gnat', 'flea']
senticnet['motel_room'] = [0, 0, 0, -0.07, '#disgusting', '#disgusting', -0.023, 'downstairs', 'appliance_store', 'apartment', 'shack', 'neighbor_house']
senticnet['moth'] = [0, -0.079, 0.098, -0.108, '#angry', '#disgusting', -0.042, 'japanese_beetle', 'cucumber_beetle', 'mole_cricket', 'gypsy_moth', 'caterpillar']
senticnet['mother'] = [0.108, -0.044, 0.043, 0.065, '#joyful', '#admirable', 0.058, 'family', 'love_back', 'carry_baby', 'father', 'change_diaper']
senticnet['mother_brother'] = [0, 0.932, 0, 0.762, '#interesting', '#admirable', 0.565, 'familial_relationship', 'family_relation', 'sibling', 'family_member', 'male_parent']
senticnet['mother_child'] = [0, 0.969, 0, 0.755, '#interesting', '#admirable', 0.575, 'father_child', 'father_son', 'father_offspring', 'human_offspring', 'descendant']
senticnet['mother_father'] = [0, 0.782, 0, 0.891, '#interesting', '#admirable', 0.558, 'father_mother', 'mom_dad', 'parent_child', 'brother_sister', 'granddaughter']
senticnet['mother_fucker'] = [-0.667, 0, 0.595, -0.837, '#sad', '#disgusting', -0.7, 'bastard', 'dickhead', 'disagreeable_person', 'motherfucker', 'son_of_bitch']
senticnet['mother_lode'] = [0.614, -0.956, 0, 0.584, '#joyful', '#surprising', 0.718, 'lode', 'champion_lode', 'deposit', 'sedimentation', 'alluviation']
senticnet['mother_wit'] = [0.639, -0.563, 0, 0.622, '#joyful', '#admirable', 0.608, 'road_sense', 'sagacity', 'sagaciousness', 'logic', 'nous']
senticnet['mother_womb'] = [0.706, 0, 0, 0, '#joyful', '#joyful', 0.235, 'birth', 'new_baby', 'born', 'birthday', 'thanksgiving']
senticnet['motherboard'] = [0, 0.102, 0.016, 0.076, '#interesting', '#admirable', 0.054, 'computer_part', 'system', 'cpu', 'pencil_pen', 'monitor']
senticnet['motherfucker'] = [-0.357, -0.135, -0.056, -0.384, '#sad', '#disgusting', -0.221, 'bastard', 'idiot', 'asshole', 'fuck', 'dick']
senticnet['motherhood'] = [0.1, 0.216, -0.185, 0.22, '#interesting', '#admirable', 0.117, 'female', 'maternity_ward', 'maternity', 'woman', 'mother']
senticnet['motherland'] = [0, 0.19, -0.066, 0.093, '#interesting', '#admirable', 0.072, 'pride', 'revolution', 'patriot', 'patriotism', 'homeland']
senticnet['motherliness'] = [0.585, -0.885, 0, 0.615, '#surprising', '#admirable', 0.695, 'parental_quality', 'maternal_quality', 'quality', 'maternalism', 'fatherliness']
senticnet['mothproof'] = [-0.9, 0, 0.657, -0.644, '#sad', '#angry', -0.734, 'soundproof', 'imperviable', 'resistant', 'proof', 'greaseproof']
senticnet['motilin'] = [0.685, -0.898, 0, 0.765, '#surprising', '#admirable', 0.783, 'gastrointestinal_hormone', 'gastrin', 'cholecystokinin', 'secretin', 'ghrelin']
senticnet['motility'] = [0.536, -0.569, 0, 0.567, '#surprising', '#admirable', 0.557, 'recreation', 'diversion', 'move', 'eurhythmics', 'movement']
senticnet['motion'] = [0, 0.095, -0.072, 0.237, '#interesting', '#admirable', 0.087, 'movement', 'dance_move', 'move', 'manoeuvre', 'push']
senticnet['motion_picture'] = [0, -0.039, -0.095, -0.053, '#scared', '#disgusting', -0.036, 'play_in_theater', 'film', 'fake_tooth', 'tooth', 'movie']
senticnet['motion_sickness'] = [0, 0, -0.711, -0.974, '#scared', '#disgusting', -0.562, 'get_heard', 'ignore_distraction', 'get_fight', 'loss_ofmemory', 'break_leg']
senticnet['motionless'] = [-0.829, 0, 0.99, -0.872, '#angry', '#disgusting', -0.897, 'nonmoving', 'rigid', 'inactive', 'still', 'static']
senticnet['motivate'] = [0.997, 0.748, 0, 0.969, '#joyful', '#admirable', 0.905, 'car_action', 'steer_car', 'passenger_car', 'cheer_up', 'control_car']
senticnet['motivation'] = [0.702, 0, 0, 0.787, '#joyful', '#admirable', 0.496, 'effort', 'go_meet', 'make_time', 'ambition', 'preparation']
senticnet['motivative'] = [0.59, -0.599, 0, 0.527, '#joyful', '#surprising', 0.572, 'responsible', 'inducive', 'activating', 'tributary', 'causative']
senticnet['motivator'] = [0.674, -0.787, 0, 0.793, '#surprising', '#admirable', 0.751, 'rational_motive', 'incentive', 'inducement', 'motivation', 'need']
senticnet['motive'] = [-0.052, 0.27, -0.164, 0.245, '#interesting', '#admirable', 0.1, 'purpose', 'reason', 'explanation', 'forethought', 'question_start']
senticnet['motley'] = [-0.625, 0, 0.988, -0.591, '#sad', '#angry', -0.735, 'alphabet_soup', 'mixture', 'variety', 'assortment', 'mixed_bag']
senticnet['motocyele_race'] = [0.856, 0.928, 0, 0.828, '#joyful', '#interesting', 0.871, 'champion', 'competition', 'win_race', 'professional', 'award']
senticnet['motor'] = [0.67, -0.912, 0, 0.805, '#surprising', '#admirable', 0.796, 'electric_motor', 'engine', 'stepper', 'stepping_motor', 'machine']
senticnet['motor_oil'] = [0, -0.075, 0, 0, '#surprising', '#surprising', 0.025, 'paint', 'internal_combustion_engine', 'trunks', 'bicycle_storage_area', 'engine']
senticnet['motor_vehicle'] = [0, -0.019, 0, 0.064, '#surprising', '#admirable', 0.028, 'car_gas', 'car_power', 'fossil_fuel', 'run_car', 'car_engine']
senticnet['motorbike'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'fuel', 'car', 'fossil_fuel', 'transport', 'natural_resource']
senticnet['motorbike_accident'] = [-0.952, 0, 0.046, -0.978, '#sad', '#disgusting', -0.659, 'fall_down', 'lose_consciousness', 'car_accident', 'have_accident', 'accident']
senticnet['motorcade'] = [0, 0, -0.048, -0.075, '#scared', '#disgusting', -0.041, 'good_band', 'band', 'kit', 'procession', 'oblivion']
senticnet['motorcar'] = [-0.512, 0, 0.552, -0.659, '#angry', '#disgusting', -0.574, 'car', 'auto', 'automobile', 'machine', 'gas_guzzler']
senticnet['motorcycle'] = [-0.063, 0.122, -0.046, 0.113, '#interesting', '#admirable', 0.042, 'taxi', 'bus', 'tram', 'airplane', 'plane']
senticnet['motortruck'] = [0.65, -0.634, 0, 0.629, '#joyful', '#surprising', 0.638, 'camion', 'rig', 'wrecker', 'dump_truck', 'dumper']
senticnet['motorway'] = [0.559, -0.983, 0, 0.501, '#joyful', '#surprising', 0.681, 'autobahn', 'autostrada', 'turnpike', 'toll_road', 'highway']
senticnet['mould'] = [-0.073, 0, 0, -0.074, '#sad', '#disgusting', -0.049, 'paint', 'use_tool', 'cartoon_character', 'use_oil_paint', 'buy_paint']
senticnet['mouldy'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'poison', 'rotten', 'disgusting', 'taste_awful', 'green_bread']
senticnet['mouldy_bread'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'green_bread', 'rotten', 'disgusting', 'taste_awful', 'mouldy']
senticnet['mound'] = [-0.77, 0, 0.588, -0.801, '#sad', '#disgusting', -0.72, 'heap', 'agglomerate', 'piles', 'funeral_pyre', 'cumulation']
senticnet['mount_ever'] = [0.032, 0.198, 0, 0.104, '#interesting', '#admirable', 0.111, 'nowhere', 'utopia', 'international_space_station', 'limbo', 'emporium']
senticnet['mountain'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'find_mountain', 'find', 'enjoy_nature', 'beautiful_view', 'enjoy_view']
senticnet['mountain_climb'] = [0, 0.166, -0.134, 0.275, '#interesting', '#admirable', 0.102, 'climb_mountain', 'climb', 'chop_down_tree', 'reflect_water', 'store_garage']
senticnet['mountain_climber'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'good_view', 'summit', 'great_view', 'guru', 'powerful_man']
senticnet['mountain_dew'] = [0.714, 0.763, 0, 0, '#joyful', '#interesting', 0.492, 'lemonade', 'soda', 'sprite', 'coke', 'cola']
senticnet['mountain_goat'] = [0, 0.102, 0, 0, '#interesting', '#interesting', 0.034, 'frostbite', 'eskimo', 'weather_event', 'glacier', 'coldness']
senticnet['mountain_lion'] = [0, -0.977, 0, 0, '#surprising', '#surprising', 0.326, 'cougar', 'skunk', 'lion', 'tiger', 'lynx']
senticnet['mountain_sheep'] = [-0.799, 0, 0.667, -0.668, '#sad', '#disgusting', -0.711, 'argali', 'argal', 'urial', 'white_sheep', 'wild_sheep']
senticnet['mountain_side'] = [0.781, 0.947, 0, 0, '#joyful', '#interesting', 0.576, 'incline_plane', 'angle', 'facet', 'apex', 'height']
senticnet['mountain_top'] = [0, 0.077, 0, 0, '#interesting', '#interesting', 0.026, 'middle_road', 'expedition', 'mountain', 'limbo', 'death_row']
senticnet['mountain_watercress'] = [0.758, -0.975, 0, 0.851, '#surprising', '#admirable', 0.861, 'marsh_cress', 'yellow_watercress', 'watercress', 'common_watercress', 'great_yellowcress']
senticnet['mountaineer'] = [0, 0.076, 0, 0.063, '#interesting', '#admirable', 0.046, 'up_hill', 'elevation', 'up_mountain', 'ascend', 'upwards']
senticnet['mountebank'] = [0.857, -0.659, 0, 0.869, '#joyful', '#admirable', 0.795, 'slicker', 'beguiler', 'quack', 'phrenologist', 'craniologist']
senticnet['mounted'] = [0.613, -0.532, 0, 0.932, '#joyful', '#admirable', 0.692, 'buttony', 'ruffled', 'fringed', 'tessellated', 'adorned']
senticnet['mourn'] = [-0.479, 0.105, -0.431, -0.06, '#sad', '#scared', -0.288, 'mourner', 'bury_dead', 'a_lot_of_flowers', 'casket', 'bury_dead_person']
senticnet['mourner'] = [-0.311, 0.099, -0.358, -0.092, '#sad', '#scared', -0.221, 'mourn', 'a_lot_of_flowers', 'casket', 'bury_dead', 'bury_person']
senticnet['mournful'] = [-0.875, 0.184, -0.587, 0, '#sad', '#scared', -0.426, 'self-pity', 'sorrowful', 'deplorably', 'woefully', 'lamentably']
senticnet['mournful_widow'] = [-0.827, 0, 0.619, -0.941, '#sad', '#disgusting', -0.796, 'sweet_scabious', 'pincushion_flower', 'scabiosa', 'field_scabious', 'flower']
senticnet['mournfully'] = [-0.894, 0.16, -0.612, 0.055, '#sad', '#scared', -0.43, 'truthfulness', 'sorrowfulness', 'mournfulness', 'heartrending', 'heartbreaking']
senticnet['mournfulness'] = [-0.894, 0.16, -0.612, 0.055, '#sad', '#scared', -0.43, 'mournfully', 'ruthfulness', 'sorrowfulness', 'heartrending', 'heartbreaking']
senticnet['mourning'] = [-0.884, 0.175, -0.599, 0, '#sad', '#scared', -0.436, 'bereaved', 'grief-stricken', 'sorrowing', 'bereft', 'grieving']
senticnet['mouse'] = [-0.55, 0, 0.955, -0.96, '#angry', '#disgusting', -0.822, 'house_mouse', 'harvest_mouse', 'field_mouse', 'fieldmouse', 'nude_mouse']
senticnet['mousse'] = [0.032, -0.141, 0, 0, '#joyful', '#surprising', 0.058, 'cake', 'custard', 'brownie', 'cookie', 'doughnut']
senticnet['mouth'] = [0, -0.749, 0, 0.78, '#surprising', '#admirable', 0.51, 'facial_expression_movement', 'kiss', 'show_tooth', 'expression', 'facial_expression']
senticnet['mouth_action'] = [0.045, 0.128, -0.06, 0.222, '#interesting', '#admirable', 0.112, 'mouth_movement', 'use_mouth', 'breaout', 'exhalation', 'bad_odor']
senticnet['mouth_activity'] = [0.075, 0.127, 0, 0.211, '#interesting', '#admirable', 0.138, 'eat_action', 'ingest', 'consume', 'consumable', 'sweet_sour']
senticnet['mouth_move'] = [0, 0, 0, 0.164, '#admirable', '#admirable', 0.055, 'verbal_communication', 'use_voice', 'human_communication', 'spoken', 'speech']
senticnet['mouth_movement'] = [0.033, 0.102, -0.082, 0.224, '#interesting', '#admirable', 0.092, 'use_mouth', 'mouth_action', 'express_feeling', 'verbal', 'beckon']
senticnet['mouth_noise'] = [0, 0, 0, 0.139, '#admirable', '#admirable', 0.046, 'vocal_sound', 'vocalization', 'vocal_cord', 'mouth_sound', 'audible']
senticnet['mouth_off'] = [0.775, -0.585, 0, 0.616, '#joyful', '#admirable', 0.659, 'utter', 'talk', 'speak', 'mouth', 'verbalize']
senticnet['mouth_open'] = [0, 0, -0.858, -0.934, '#scared', '#disgusting', -0.597, 'need_to_rest', 'sleepiness', 'stop_activity', 'rest_up', 'sleepy']
senticnet['mouth_part'] = [0.037, 0.076, 0, 0.091, '#interesting', '#admirable', 0.068, 'face_part', 'facial_feature', 'facial_part', 'facial_organ', 'near_mouth']
senticnet['mouth_sound'] = [0, 0, 0, 0.12, '#admirable', '#admirable', 0.04, 'mouth_noise', 'vocal_sound', 'vocal_cord', 'vocalization', 'verbal_communication']
senticnet['mouthwash'] = [0.859, 0, 0, 0.737, '#joyful', '#admirable', 0.532, 'fluoride_mouthwash', 'hair_conditioner', 'sculpt_gel', 'dandruff_shampoo', 'hair_gel']
senticnet['movability'] = [0.664, -0.883, 0, 0.732, '#surprising', '#admirable', 0.76, 'mobility', 'portability', 'looseness', 'play', 'unsteadiness']
senticnet['movableness'] = [0.994, -0.591, 0, 0.544, '#joyful', '#surprising', 0.71, 'mobility', 'portability', 'looseness', 'play', 'unsteadiness']
senticnet['move'] = [0.047, 0.178, -0.095, 0.277, '#interesting', '#admirable', 0.136, 'haul', 'movement', 'locomotion', 'go_around', 'move_ahead']
senticnet['move_action'] = [0, 0.146, -0.057, 0.275, '#interesting', '#admirable', 0.121, 'body_movement', 'movement', 'upward_movement', 'move_ahead', 'foot_motion']
senticnet['move_ahead'] = [0, 0.205, -0.084, 0.314, '#interesting', '#admirable', 0.145, 'forward_movement', 'go_forward', 'pace', 'go_ahead', 'movement']
senticnet['move_air'] = [0.116, 0.129, -0.058, 0.053, '#joyful', '#interesting', 0.08, 'air_movement', 'circulate_air', 'blown', 'blow_air', 'windy']
senticnet['move_another_place'] = [0.04, 0.144, -0.074, 0.122, '#interesting', '#admirable', 0.077, 'taxi_cab', 'rut', 'foreign_country', 'another_place', 'transit']
senticnet['move_arm'] = [0, 0, 0, 0.148, '#admirable', '#admirable', 0.049, 'arm_movement', 'raise_arm', 'movement', 'human_motion', 'hand_gesture']
senticnet['move_around'] = [0.065, 0, 0, 0.17, '#joyful', '#admirable', 0.078, 'movement', 'body_movement', 'locomotion', 'personal_transport', 'move_action']
senticnet['move_away'] = [-0.023, 0.112, 0, 0.158, '#interesting', '#admirable', 0.082, 'pull_car', 'movement', 'carry_book', 'go_away', 'spring_leak']
senticnet['move_back'] = [-0.73, 0, 0.64, -0.764, '#sad', '#disgusting', -0.711, 'retreat', 'retrograde', 'back_up', 'move', 'give_up']
senticnet['move_between_floor_build'] = [-0.049, 0, -0.076, -0.095, '#scared', '#disgusting', -0.073, 'get_floor_another', 'go_up_down', 'climb_up', 'go_upstairs', 'escape_fire']
senticnet['move_between_floor_building'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'walk_up', 'get_floor_another', 'go_upstairs', 'go_up_down', 'climb_up']
senticnet['move_body'] = [-0.035, 0.106, 0, 0.125, '#interesting', '#admirable', 0.065, 'push_up', 'healthy_activity', 'use_muscle', 'active', 'stamina']
senticnet['move_car'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'out_car', 'avoid_fall', 'drive_car', 'take_car_drive', 'go_drive']
senticnet['move_eye'] = [-0.122, -0.045, 0.013, -0.258, '#sad', '#disgusting', -0.116, 'eye_strain', 'turn_page', 'learn', 'look_at', 'add_knowledge']
senticnet['move_fast'] = [0, 0, 0, 0.12, '#admirable', '#admirable', 0.04, 'go_fast', 'get_somewhere_fast', 'personal_transport', 'locomotion', 'change_location']
senticnet['move_finger'] = [-0.059, 0, 0.079, -0.081, '#angry', '#disgusting', -0.073, 'press_key', 'loose_track_time', 'help_remember', 'tune_instrument', 'listen']
senticnet['move_foot'] = [0, 0.078, 0.027, 0.196, '#interesting', '#admirable', 0.082, 'foot_movement', 'foot_action', 'pace', 'stride', 'foot_motion']
senticnet['move_forward'] = [-0.086, 0.102, 0, 0.153, '#interesting', '#admirable', 0.056, 'move_foot', 'use_foot', 'foot_motion', 'move_ahead', 'like_run']
senticnet['move_furniture'] = [0.98, -0.884, 0, 0, '#joyful', '#surprising', 0.621, 'work_team', 'dress_oneself', 'bus_table', 'lend_hand', 'win_award']
senticnet['move_hand'] = [-0.035, 0.104, -0.048, 0.171, '#interesting', '#admirable', 0.064, 'hand_gesture', 'sea_movement', 'arm_movement', 'ocean_movement', 'goodbye']
senticnet['move_head'] = [0.042, 0.141, -0.094, 0.1, '#interesting', '#admirable', 0.063, 'make_eye_contact', 'discuss', 'nod_head', 'share_idea', 'become_friend']
senticnet['move_house'] = [0.921, 0.728, 0, 0, '#joyful', '#interesting', 0.55, 'expand_horizon', 'learn_other_culture', 'improve_knowledge', 'stimulate_mind', 'couch_potato']
senticnet['move_leg'] = [-0.082, -0.026, 0.046, 0, '#sad', '#angry', -0.034, 'put_sneaker', 'bring_dog', 'use_foot', 'trip_fall_down', 'hurt_toe']
senticnet['move_liquid'] = [0, 0.089, -0.063, 0.24, '#interesting', '#admirable', 0.089, 'water_motion', 'water_movement', 'ebb', 'movement_of_water', 'sea_movement']
senticnet['move_mouse'] = [-0.05, 0.168, -0.045, 0.263, '#interesting', '#admirable', 0.112, 'reboot', 'prepare_report', 'type_of_keyboard', 'keep_track_appointment', 'use_computer']
senticnet['move_object'] = [0, 0.187, -0.121, 0.275, '#interesting', '#admirable', 0.114, 'pull_car', 'car_action', 'move_stuff', 'haul', 'move']
senticnet['move_out'] = [-0.735, 0, -0.777, 0, '#sad', '#scared', -0.504, 'step_out', 'walk_away', 'step_aside', 'climb_ladder', 'open_mailbox']
senticnet['move_part'] = [0.028, 0, 0, 0.131, '#joyful', '#admirable', 0.053, 'mechanical_device', 'mechanism', 'complex_machine', 'human_invention', 'device']
senticnet['move_pawn'] = [-0.876, 0, -0.714, 0, '#sad', '#scared', -0.53, 'chew_pencil', 'get_nervous', 'make_mistake', 'look_clock', 'plan_ahead']
senticnet['move_person'] = [0.077, 0.126, 0, 0.225, '#interesting', '#admirable', 0.143, 'trucking', 'car_action', 'transport_person', 'personal_transport', 'locomotion']
senticnet['move_place_another'] = [0, 0.073, 0, 0.056, '#interesting', '#admirable', 0.043, 'yoga', 'eat_healthy_diet', 'exercise_much', 'change_color', 'make_look_better']
senticnet['move_quickly'] = [0, 0.07, -0.049, 0.195, '#interesting', '#admirable', 0.072, 'like_run', 'fast_walk', 'human_movement', 'vigorous_activity', 'move_forward']
senticnet['move_rhythm_music'] = [0.168, -0.118, 0.097, -0.067, '#joyful', '#surprising', 0.041, 'relate_music', 'done_person', 'waltz', 'ballroom_dance', 'sway']
senticnet['move_sidewalk'] = [0.868, -0.975, 0, 0, '#joyful', '#surprising', 0.614, 'baggage', 'passenger_ticket', 'air_ticket', 'hand_luggage', 'aircraft_roadway']
senticnet['move_slowly'] = [-0.09, 0.098, -0.05, 0.148, '#interesting', '#admirable', 0.035, 'jump', 'skip', 'pull_car', 'open_mailbox', 'bail_water']
senticnet['move_stuff'] = [0, 0.187, -0.121, 0.275, '#interesting', '#admirable', 0.114, 'pull_car', 'car_action', 'move_object', 'haul', 'move']
senticnet['move_tongue'] = [-0.085, 0, 0.019, -0.034, '#sad', '#disgusting', -0.046, 'make_unusual_face', 'become_friend', 'dry_mouth', 'share_feeling', 'use_hand_gesture']
senticnet['move_up'] = [0.032, 0.159, -0.052, 0.188, '#interesting', '#admirable', 0.109, 'ascend', 'move_upward', 'go_up', 'move_upwards', 'go_high']
senticnet['move_upward'] = [0.046, 0.211, -0.097, 0.245, '#interesting', '#admirable', 0.135, 'go_up', 'ascend', 'raise_up', 'upward_movement', 'move_up']
senticnet['move_upwards'] = [0.034, 0.13, -0.065, 0.148, '#interesting', '#admirable', 0.082, 'go_high', 'ascend', 'move_up', 'move_upward', 'step_up']
senticnet['move_vehicle'] = [0, 0.156, -0.067, 0.241, '#interesting', '#admirable', 0.11, 'mixture', 'noisy_place', 'make_go', 'interjection', 'big_car']
senticnet['move_water'] = [0.034, 0, 0, 0.128, '#joyful', '#admirable', 0.054, 'water_movement', 'movement_of_water', 'water_motion', 'water_transport', 'fast_water']
senticnet['move_wind'] = [-0.026, 0, -0.069, -0.071, '#scared', '#disgusting', -0.055, 'branch_out', 'flower_spring', 'shade_sun', 'fall_dead', 'memory_loss']
senticnet['movement'] = [0, 0.141, -0.058, 0.27, '#interesting', '#admirable', 0.118, 'keep_moving', 'move_action', 'move_ahead', 'go_forward', 'motion']
senticnet['movement_of_water'] = [0, 0, 0, 0.125, '#admirable', '#admirable', 0.042, 'backstroke', 'freestyle', 'move_water', 'water_motion', 'water_movement']
senticnet['movement_place_another'] = [0.706, -0.823, 0, 0, '#joyful', '#surprising', 0.51, 'go_fast_walk', 'tire', 'enjoy_fresh_air', 'enjoy_nature', 'compete_race']
senticnet['movement_towards'] = [0, 0.336, -0.161, 0.388, '#interesting', '#admirable', 0.188, 'take_over', 'let', 'proceed', 'given', 'go_ahead']
senticnet['movie'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'cinema', 'cctv', 'show', 'theater', 'film']
senticnet['movie_actor'] = [0.764, 0.961, 0, 0, '#joyful', '#interesting', 0.575, 'idol', 'fun', 'see_actor', 'vip', 'fan']
senticnet['movie_genre'] = [0, 0.951, 0, 0, '#interesting', '#interesting', 0.317, 'genre', 'fictional', 'action_movie', 'personality_trait', 'cinderella']
senticnet['movie_house'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'cinema', 'movie_theater', 'movie', 'drive-in_movie', 'theater']
senticnet['movie_picture'] = [0.952, 0, 0, 0.741, '#joyful', '#admirable', 0.564, 'like_electricity', 'take_over', 'essential', 'high_class', 'hypnotic']
senticnet['movie_screen'] = [0.788, -0.979, 0, 0, '#joyful', '#surprising', 0.589, 'row_seat', 'sticky_floor', 'movie_theater_seat', 'theater_seat', 'stage_entrance']
senticnet['movie_set'] = [0, -0.954, 0, 0.8, '#surprising', '#admirable', 0.585, 'show', 'cinema', 'performance', 'theater', 'stage_play']
senticnet['movie_star'] = [0, 0.813, 0, 0.717, '#interesting', '#admirable', 0.51, 'actor', 'preview', 'entertainer', 'thespian', 'performance']
senticnet['movie_studio'] = [0, 0.07, 0, 0.071, '#interesting', '#admirable', 0.047, 'television_station', 'record_studio', 'film_studio', 'studio', 'tv_station']
senticnet['movie_theater'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'theater', 'drive-in_movie', 'watch_movie', 'cinema', 'movie']
senticnet['movie_theater_seat'] = [0, -0.012, -0.068, -0.042, '#scared', '#disgusting', -0.033, 'theater_seat', 'movie_screen', 'theater_box', 'sticky_floor', 'row_seat']
senticnet['movie_ticket'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'theater_ticket', 'go_to_cinema', 'watch_movie', 'enjoy_movie', 'have_fun']
senticnet['movie_title'] = [0.773, 0.796, 0, 0, '#joyful', '#interesting', 0.523, 'movie', 'wet_air', 'condense_water', 'vapor_water', 'hazy']
senticnet['moviegoer'] = [0, 0, -0.082, -0.045, '#scared', '#disgusting', -0.042, 'ticket_taker', 'preview', 'sticky_floor', 'projector', 'row_seat']
senticnet['moving'] = [0.535, -0.586, 0, 0.748, '#surprising', '#admirable', 0.623, 'kinetic', 'restless', 'afoot', 'ahorse', 'ahorseback']
senticnet['moving_picture'] = [-0.859, 0, 0.514, -0.739, '#sad', '#disgusting', -0.704, 'flick', 'movie', 'film', 'picture', 'cinema_verite']
senticnet['mow'] = [-0.99, 0, 0.986, 0, '#sad', '#angry', -0.659, 'green_stuff', 'grass', 'greenery', 'tree_flower', 'many_plants']
senticnet['mow_grass'] = [-0.09, 0, 0, 0, '#sad', '#sad', -0.03, 'mop_floor', 'absorb_moisture', 'sit_on_beach', 'scrub_floor', 'cut_grass']
senticnet['mow_lawn'] = [0, 0.086, 0, 0, '#interesting', '#interesting', 0.029, 'swim_ocean', 'weight_lift', 'sit_in_shade', 'cut_grass', 'trust_friend']
senticnet['much_big_human'] = [0.026, 0, 0.012, 0.099, '#joyful', '#admirable', 0.038, 'large_area', 'large_state', 'political_division', 'region', 'place']
senticnet['much_child'] = [-0.062, 0.2, -0.1, 0.168, '#interesting', '#admirable', 0.069, 'orphan', 'take_child', 'offspring', 'progeny', 'become_parent']
senticnet['much_energy'] = [0.226, 0.11, -0.065, 0.178, '#joyful', '#admirable', 0.15, 'think_clearly', 'look_attractive', 'improve_self-image', 'live_healthy_life', 'keep_body_healthy']
senticnet['much_exercise'] = [0, 0, 0, 0.968, '#admirable', '#admirable', 0.323, 'physical_exertion', 'wear_out_shoes', 'become_physically_fit', 'vigorous_exercise', 'strain_muscle']
senticnet['much_fat'] = [-0.079, 0, -0.141, -0.142, '#scared', '#disgusting', -0.121, 'constipation', 'cigarette_smoke', 'bigot', 'cancer', 'lung_cancer']
senticnet['much_food'] = [-0.056, 0, -0.137, -0.123, '#scared', '#disgusting', -0.105, 'doctor', 'nurse', 'cure', 'doctor_office', 'merlin']
senticnet['much_fun'] = [0.797, 0.717, 0, 0.905, '#joyful', '#admirable', 0.806, 'have_fun', 'fun_time', 'radical', 'nativity', 'social_gathering']
senticnet['much_information'] = [0, 0.974, 0, 0.946, '#interesting', '#admirable', 0.64, 'student', 'serious_student', 'information', 'graduate_student', 'hard_worker']
senticnet['much_money'] = [0.861, 0.803, 0, 0.961, '#joyful', '#admirable', 0.875, 'wealthy', 'take_out_loan', 'money', 'need_money', 'down_payment']
senticnet['much_need'] = [0.366, 0.206, 0, 0.355, '#joyful', '#admirable', 0.309, 'taken_seriously', 'knowledgeable', 'complement', 'good_sense_of_humor', 'spice_life']
senticnet['much_sun'] = [-0.983, 0, 0.685, -0.994, '#sad', '#disgusting', -0.887, 'burn_skin', 'ultraviolet', 'erythema', 'skin_cancer', 'pain']
senticnet['much_water'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'small_ocean', 'water_mass', 'water_molecule', 'water_body', 'water_feature']
senticnet['much_work'] = [-0.103, -0.013, 0, -0.177, '#sad', '#disgusting', -0.089, 'stress', 'quit_job', 'hate_boss', 'hate_colleague', 'need_holiday']
senticnet['muck'] = [-0.028, -0.014, 0, -0.088, '#sad', '#disgusting', -0.034, 'dung', 'manure', 'shit', 'dog_poop', 'crap']
senticnet['muck_up'] = [-0.971, 0, 0.922, -0.533, '#sad', '#angry', -0.809, 'muddy_up', 'begrime', 'foul', 'blemish', 'smear']
senticnet['muckheap'] = [-0.511, 0, 0.883, -0.858, '#angry', '#disgusting', -0.751, 'heap', 'agglomerate', 'piles', 'mound', 'cumulation']
senticnet['muckhill'] = [-0.548, 0, 0.502, -0.667, '#sad', '#disgusting', -0.572, 'heap', 'agglomerate', 'piles', 'mound', 'cumulation']
senticnet['mucous_substance'] = [0, 0, 0, -0.964, '#disgusting', '#disgusting', -0.321, 'thick_substance', 'viscous_substance', 'phlegm', 'disgusting', 'disgust']
senticnet['mucus'] = [0, 0, -0.05, -0.052, '#scared', '#disgusting', -0.034, 'jaw', 'mouth', 'dimple', 'nose', 'cheek']
senticnet['mud'] = [-0.71, 0, 0.704, -0.891, '#sad', '#disgusting', -0.768, 'soil', 'mire', 'dirt', 'bleaching_clay', 'bleaching_earth']
senticnet['mud_flat'] = [-0.87, 0, 0.875, -0.92, '#angry', '#disgusting', -0.888, 'tract', 'piece_of_land', 'piece_of_ground', 'parcel_of_land', 'parcel']
senticnet['mud_stain'] = [-0.518, 0, 0.937, -0.926, '#angry', '#disgusting', -0.794, 'bloodstain', 'discoloration', 'iron_mold', 'iron_mould', 'oil_stain']
senticnet['muddied'] = [-0.818, 0, 0.668, -0.873, '#sad', '#disgusting', -0.786, 'dirty', 'dingy', 'impure', 'alloyed', 'adulterate']
senticnet['muddiness'] = [-0.506, 0, 0.85, -0.828, '#angry', '#disgusting', -0.728, 'confusion', 'disarray', 'mental_confusion', 'confusedness', 'bafflement']
senticnet['muddle'] = [-0.787, 0, 0.854, -0.9, '#angry', '#disgusting', -0.847, 'muss', 'untidiness', 'mess', 'disorderliness', 'messiness']
senticnet['muddy'] = [-0.93, 0, 0.897, -0.923, '#sad', '#disgusting', -0.917, 'dirty', 'soil', 'begrime', 'grime', 'colly']
senticnet['muddy_up'] = [-0.967, 0, 0.646, -0.627, '#sad', '#angry', -0.747, 'dirty', 'soil', 'begrime', 'grime', 'colly']
senticnet['mudhif'] = [0.846, -0.665, 0, 0.941, '#joyful', '#admirable', 0.817, 'hut', 'hovel', 'hutch', 'shack', 'shanty']
senticnet['muff'] = [0.57, -0.566, 0, 0.888, '#joyful', '#admirable', 0.675, 'wearable', 'wear', 'hand_wear', 'glove', 'clothing']
senticnet['muffin'] = [0.048, -0.083, 0, 0, '#joyful', '#surprising', 0.044, 'cookie', 'pudding', 'pie', 'candy', 'bagel']
senticnet['muffle'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'surprise', 'suspense', 'bandage', 'blindfolded', 'blindfold']
senticnet['muffled'] = [0, 0, -0.822, -0.831, '#scared', '#disgusting', -0.551, 'repress', 'mute', 'strangle', 'smother', 'stifle']
senticnet['mug'] = [0.214, 0.258, -0.09, 0.2, '#joyful', '#interesting', 0.194, 'cup', 'carafe', 'pitcher', 'container_cup', 'glasses']
senticnet['muggins'] = [0.934, -0.578, 0, 0.767, '#joyful', '#admirable', 0.76, 'morosoph', 'simpleton', 'flibbertigibbet', 'foolish_woman', 'simple']
senticnet['mugwort'] = [-0.669, 0, 0.811, -0.781, '#angry', '#disgusting', -0.754, 'subshrub', 'suffrutex', 'old_woman', 'wormwood', 'southernwood']
senticnet['mule'] = [0, 0, 0, 0.071, '#admirable', '#admirable', 0.024, 'two_horses', 'horse', 'barb', 'buddhist', 'ride_horse']
senticnet['mulish'] = [0, 0, -0.901, 0, '#scared', '#scared', -0.3, 'obstinate', 'persistent', 'pigheaded', 'stubborn', 'headstrong']
senticnet['mulishness'] = [-0.761, 0, 0.824, -0.868, '#angry', '#disgusting', -0.818, 'intractability', 'unruliness', 'fractiousness', 'willfulness', 'against_rules']
senticnet['mull_over'] = [-0.943, 0, 0.866, -0.929, '#sad', '#disgusting', -0.913, 'think_too_much', 'anxiety', 'hate_somebody', 'bad_feeling', 'bad_memory']
senticnet['multi-story_build'] = [-0.059, 0.116, -0.044, 0.102, '#interesting', '#admirable', 0.038, 'house', 'dwelling', 'lease', 'rent_out', 'large_house']
senticnet['multifaceted'] = [-0.562, 0, 0.931, -0.665, '#angry', '#disgusting', -0.719, 'varying', 'various', 'variable', 'versatile', 'varied']
senticnet['multifariousness'] = [-0.646, 0, 0.773, -0.686, '#angry', '#disgusting', -0.702, 'diverseness', 'heterogeneity', 'diversity', 'variety', 'nonuniformity']
senticnet['multiple'] = [0, 0.198, -0.05, 0.217, '#interesting', '#admirable', 0.122, 'duplicate', 'many_kinds', 'set', 'twice', 'contrary']
senticnet['multiple_choices'] = [-0.066, 0.18, 0, 0.143, '#interesting', '#admirable', 0.086, 'grade', 'evaluation', 'final', 'final_exam', 'school_grade']
senticnet['multiple_entry'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'theme_park', 'short_cut', 'save_time', 'combo_pass', 'ticket']
senticnet['multiple_neuritis'] = [-0.652, 0, 0.873, -0.637, '#sad', '#angry', -0.721, 'polyneuritis', 'neuritis', 'rubor', 'redness', 'inflammation']
senticnet['multiple_people'] = [0.053, 0.106, 0, 0.092, '#interesting', '#admirable', 0.084, 'mass_person', 'big_group', 'bunch_person', 'push_together', 'team_up']
senticnet['multiple_purposes'] = [0, 0, 0, 0.861, '#admirable', '#admirable', 0.287, 'wrap_around', 'hold_object', 'carry', 'haul', 'spring_leak']
senticnet['multiple_sclerosis'] = [-0.718, 0, 0.85, -0.823, '#angry', '#disgusting', -0.797, 'sclerosis', 'induration', 'degenerative_disorder', 'autoimmune_disease', 'autoimmune_disorder']
senticnet['multiple_voting'] = [0.611, -0.829, 0, 0.737, '#surprising', '#admirable', 0.726, 'choice', 'option', 'veto', 'balloting', 'block_vote']
senticnet['multiplication'] = [0, 0.814, 0, 0.937, '#interesting', '#admirable', 0.584, 'subtraction', 'add', 'mathematical_operation', 'equal', 'arithmetic']
senticnet['multiply'] = [-0.059, 0.131, 0.038, 0.129, '#interesting', '#admirable', 0.054, 'add', 'addition', 'separate', 'navigation', 'halve']
senticnet['multitude'] = [0.044, 0.075, 0.019, 0.081, '#interesting', '#admirable', 0.06, 'big_group', 'clique', 'several_people', 'throng', 'group']
senticnet['mum'] = [0, 0.78, 0, 0.713, '#interesting', '#admirable', 0.498, 'family_member', 'sibling', 'parent', 'female_relative', 'relative']
senticnet['mumble'] = [0, 0.129, 0.017, 0.183, '#interesting', '#admirable', 0.098, 'pronounce', 'redo', 'description', 'again_and_again', 'ponder']
senticnet['mumbo_jumbo'] = [-0.614, 0, 0.738, -0.803, '#angry', '#disgusting', -0.718, 'babbling', 'double_talk', 'gibber', 'babble', 'lallation']
senticnet['mumification_necrosis'] = [-0.682, 0, 0.916, -0.912, '#angry', '#disgusting', -0.837, 'dry_gangrene', 'cold_gangrene', 'slough', 'mummification', 'pathology']
senticnet['mummery'] = [-0.817, 0, 0.65, -0.657, '#sad', '#disgusting', -0.708, 'meaninglessness', 'nonsense', 'bunk', 'nonsensicality', 'hokum']
senticnet['mummification'] = [-0.682, 0, 0.916, -0.912, '#angry', '#disgusting', -0.837, 'dry_gangrene', 'cold_gangrene', 'mumification_necrosis', 'slough', 'pathology']
senticnet['mumps'] = [0, 0, -0.966, -0.757, '#scared', '#disgusting', -0.574, 'ridiculous', 'ill_health', 'terminal_illness', 'flu', 'chicken_pox']
senticnet['munch'] = [-0.037, -0.007, 0.04, -0.038, '#angry', '#disgusting', -0.036, 'eat_rice', 'eat_food_off', 'want_eat', 'eat', 'full_stomach']
senticnet['munchkin'] = [0.95, -0.731, 0, 0, '#joyful', '#surprising', 0.56, 'crystal_clear', 'blue_sky', 'imaginary', 'water_sky', 'blue_color']
senticnet['mundane'] = [-0.79, 0, 0, -0.731, '#sad', '#disgusting', -0.507, 'dull', 'boring', 'tedious', 'monotonous', 'tiresome']
senticnet['mundaneness'] = [0.741, -0.748, 0, 0.666, '#joyful', '#surprising', 0.718, 'commonplaceness', 'mundanity', 'prosiness', 'prosaicness', 'ordinariness']
senticnet['mundanity'] = [0.741, -0.748, 0, 0.666, '#joyful', '#surprising', 0.718, 'mundaneness', 'commonplaceness', 'prosiness', 'prosaicness', 'ordinariness']
senticnet['mung'] = [-0.705, 0, 0.606, -0.723, '#sad', '#disgusting', -0.678, 'common_bean', 'soya', 'goa_bean', 'soya_bean', 'bean']
senticnet['mung_bean'] = [-0.705, 0, 0.606, -0.723, '#sad', '#disgusting', -0.678, 'common_bean', 'soya', 'goa_bean', 'bean', 'mung']
senticnet['munificent'] = [0, 0, -0.819, -0.888, '#scared', '#disgusting', -0.569, 'unsparing', 'overgenerous', 'lavish', 'too-generous', 'unstinted']
senticnet['mural'] = [0.047, 0, 0, 0.055, '#joyful', '#admirable', 0.034, 'painting', 'sculpture', 'oil_painting', 'tapestry', 'artwork']
senticnet['murder'] = [-0.129, -0.035, -0.128, -0.147, '#sad', '#disgusting', -0.123, 'death_destruction', 'kill', 'get_rid_of_enemy', 'destroy_live', 'defend_oneself']
senticnet['murder_another_person'] = [0, 0, 0.794, -0.939, '#angry', '#disgusting', -0.578, 'kill', 'make_someone_sick', 'destroy_target', 'kill_person', 'result_death']
senticnet['murder_charge'] = [0.654, -0.592, 0, 0.774, '#joyful', '#admirable', 0.673, 'instrument', 'indictment', 'murder_indictment', 'true_bill', 'legal_document']
senticnet['murder_indictment'] = [0.654, -0.592, 0, 0.774, '#joyful', '#admirable', 0.673, 'instrument', 'murder_charge', 'indictment', 'true_bill', 'legal_document']
senticnet['murder_suspect'] = [0.964, -0.577, 0, 0.827, '#joyful', '#admirable', 0.789, 'mortal', 'suspect', 'robbery_suspect', 'rape_suspect', 'person']
senticnet['murder_weapon'] = [-0.963, 0, -0.777, -0.701, '#sad', '#scared', -0.814, 'choose_victim', 'alibi', 'use_military', 'shoot_person', 'homicide']
senticnet['murderer'] = [-0.063, 0, -0.125, -0.194, '#scared', '#disgusting', -0.127, 'kill_another_person', 'get_rid_of_enemy', 'enslave_person', 'hitler', 'go_war']
senticnet['murderously'] = [-0.072, 0.192, 0.634, -0.635, '#angry', '#disgusting', -0.383, 'amuck', 'amok', 'murderousness', 'misocainea', 'misogyny']
senticnet['murderousness'] = [-0.072, 0.192, 0.634, -0.635, '#angry', '#disgusting', -0.383, 'murderously', 'amuck', 'amok', 'misocainea', 'misogyny']
senticnet['murine_typhus'] = [0.579, -0.81, 0, 0.833, '#surprising', '#admirable', 0.741, 'typhus', 'rat_typhus', 'urban_typhus', 'endemic_typhus', 'rickettsial_disease']
senticnet['murky'] = [-0.823, 0, 0, -0.911, '#sad', '#disgusting', -0.578, 'water', 'atmosphere', 'banal', 'bland', 'go_lake']
senticnet['murphy'] = [0.532, -0.682, 0, 0.984, '#surprising', '#admirable', 0.733, 'potato', 'white_potato', 'chips', 'spud', 'tater']
senticnet['mus_rose'] = [-0.714, 0, 0.983, -0.628, '#sad', '#angry', -0.775, 'bush', 'musk_mallow', 'mallow', 'common_mallow', 'tall_mallow']
senticnet['muscle'] = [0.228, 0.123, -0.099, 0, '#joyful', '#interesting', 0.084, 'bone', 'neck', 'shoulder', 'skeletal_system', 'bone_human']
senticnet['muscle_ache'] = [-0.12, -0.014, 0, -0.095, '#sad', '#disgusting', -0.067, 'become_fatigued', 'fatigue', 'lack_energy', 'tiredness', 'exhaustion']
senticnet['muscle_cramp'] = [-0.078, -0.046, 0, -0.1, '#sad', '#disgusting', -0.044, 'shortness_breath', 'breathlessness', 'big_muscle', 'increase_metabolism', 'cramp']
senticnet['muscle_damage'] = [-0.413, 0, -0.284, -0.058, '#sad', '#scared', -0.252, 'numbness', 'median_nerve', 'weakness', 'pain', 'carpal_tunnel_syndrome']
senticnet['muscle_pain'] = [-0.114, -0.086, 0.028, -0.188, '#sad', '#disgusting', -0.081, 'injury', 'contusion', 'broken_bone', 'leg_hurt', 'blister']
senticnet['muscle_spasm'] = [-0.56, 0, 0.981, -0.676, '#angry', '#disgusting', -0.739, 'tenesmus', 'blepharospasm', 'twitch', 'twitching', 'vellication']
senticnet['muscleman'] = [-0.902, 0, 0.522, -0.746, '#sad', '#disgusting', -0.723, 'hooligan', 'ruffian', 'roughneck', 'rowdy', 'yob']
senticnet['muscular'] = [0.055, 0, 0.033, 0.088, '#joyful', '#admirable', 0.037, 'good_shape', 'train_hard', 'fit', 'out_shape', 'shape']
senticnet['muscular_dystrophy'] = [-0.687, 0, 0.908, -0.682, '#sad', '#angry', -0.759, 'myotonic_muscular_dystrophy', 'myotonic_dystrophy', 'myotonia_atrophica', 'distal_muscular_dystrophy', 'genetic_disease']
senticnet['muse'] = [0, 0, -0.782, -0.99, '#scared', '#disgusting', -0.591, 'goddess', 'think_over', 'chew_over', 'ponder', 'meditate']
senticnet['museum'] = [0.086, -0.107, 0.064, 0, '#joyful', '#surprising', 0.043, 'art_piece', 'lifetime', 'ancient_artifact', 'vintage', 'collectibles']
senticnet['museum_ticket'] = [0.035, 0.078, 0.025, 0, '#joyful', '#interesting', 0.029, 'coin_slot', 'transit_ticket', 'passenger_ticket', 'train_ticket', 'token_slot']
senticnet['mush'] = [0.825, -0.916, 0, 0.626, '#joyful', '#surprising', 0.789, 'treacle', 'glop', 'sentimentalism', 'slop', 'formulation']
senticnet['mushroom'] = [0.962, 0, 0, 0, '#joyful', '#joyful', 0.321, 'marijuana', 'pleasure_garden', 'trellis', 'cannabis', 'cabbage']
senticnet['mushroom_poisoning'] = [-0.534, 0, 0.678, -0.73, '#angry', '#disgusting', -0.647, 'malady', 'food_poisoning', 'botulism', 'ptomaine', 'ptomaine_poisoning']
senticnet['mushy'] = [0, 0, -0.731, -0.877, '#scared', '#disgusting', -0.536, 'mawkish', 'drippy', 'hokey', 'bathetic', 'maudlin']
senticnet['music'] = [0.937, 0, 0, 0, '#joyful', '#joyful', 0.312, 'band_play', 'classical', 'composer', 'songwriter', 'rock_band']
senticnet['music_album'] = [0.853, 0, 0, 0.747, '#joyful', '#admirable', 0.533, 'listen_cd', 'turn_on_radio', 'play_music', 'play_tune', 'play_cd']
senticnet['music_band'] = [-0.038, 0.095, 0, 0.103, '#interesting', '#admirable', 0.053, 'play_in_band', 'play_music', 'play_tune', 'make_music', 'play_orchestra']
senticnet['music_class'] = [-0.048, -0.037, -0.047, -0.043, '#sad', '#scared', -0.034, 'country_band', 'bluegrass_band', 'jazz_club', 'string_quartet', 'music_store']
senticnet['music_concert'] = [-0.045, -0.043, -0.045, -0.05, '#sad', '#scared', -0.032, 'high_school_band', 'music_shop', 'drum_set', 'string_quartet', 'music_store']
senticnet['music_dance'] = [0.184, -0.139, 0.037, 0, '#joyful', '#surprising', 0.095, 'form_of_music', 'style_music', 'lyric', 'popular_music', 'universal_language']
senticnet['music_genre'] = [0.969, 0.99, 0, 0, '#joyful', '#interesting', 0.653, 'music_type', 'type_of_music', 'small_boulder', 'valuable_gem', 'rock_music']
senticnet['music_group'] = [0.241, 0.185, -0.114, 0.16, '#joyful', '#interesting', 0.157, 'eclectic', 'rock_group', 'musical_group', 'sound_nice', 'rolling_stone']
senticnet['music_hall'] = [0.91, 0.841, 0, 0, '#joyful', '#interesting', 0.584, 'record_studio', 'auditorium', 'concert_hall', 'studio', 'tv_station']
senticnet['music_lover'] = [0.806, 0.776, 0, 0.761, '#joyful', '#interesting', 0.781, 'appreciate_music', 'entertainment', 'see_performance', 'listen_pleasure', 'relieve_boredom']
senticnet['music_note'] = [0.056, -0.019, 0.036, 0.073, '#joyful', '#admirable', 0.037, 'song', 'musical_note', 'amplifier', 'chord', 'lyrics']
senticnet['music_part'] = [0, 0.074, 0.026, 0.105, '#interesting', '#admirable', 0.051, 'handwritten', 'scribble', 'jot', 'written_message', 'calligraphy']
senticnet['music_play'] = [0, 0, 0.048, -0.035, '#angry', '#disgusting', -0.028, 'electric_guitar', 'use_party', 'orchestra_play', 'party', 'howler']
senticnet['music_player'] = [0.032, 0.092, 0, 0.075, '#interesting', '#admirable', 0.066, 'rock_group', 'eclectic', 'make_musicr', 'musical_group', 'guitar_player']
senticnet['music_room'] = [0.76, 0.824, 0, 0, '#joyful', '#interesting', 0.528, 'music_store', 'music_shop', 'band_room', 'string_quartet', 'musical_instrument_store']
senticnet['music_school'] = [-0.042, -0.007, -0.051, 0, '#sad', '#scared', -0.029, 'old_movie', 'civic_center', 'opus_house', 'choir', 'concert']
senticnet['music_sheet'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'sand_paper', 'measure_angle', 'generate_sound', 'read_music', 'low_note']
senticnet['music_shop'] = [0.768, 0, 0, 0, '#joyful', '#joyful', 0.256, 'music_store', 'music_lover', 'music', 'buy_music_album', 'buy_guitar']
senticnet['music_sound'] = [0.786, -0.912, 0, 0, '#joyful', '#surprising', 0.566, 'guitar_string', 'musical_sound', 'piece_of_music', 'musical_term', 'music_note']
senticnet['music_storage'] = [0.768, 0, 0, 0, '#joyful', '#joyful', 0.256, 'music_room', 'store_music', 'music_lover', 'music', 'save_information']
senticnet['music_store'] = [0.768, 0, 0, 0, '#joyful', '#joyful', 0.256, 'music_shop', 'string_quartet', 'musical_instrument_store', 'music_room', 'high_school_band']
senticnet['music_studio'] = [0, 0.705, 0, 0.786, '#interesting', '#admirable', 0.497, 'music_room', 'band_room', 'music_store', 'musical_instrument_store', 'music_shop']
senticnet['music_tone'] = [0.03, 0.07, 0.018, 0.124, '#interesting', '#admirable', 0.069, 'musical_term', 'musical_notation', 'music_sound', 'musical_note', 'piece_of_music']
senticnet['music_type'] = [0.879, 0.706, 0, 0, '#joyful', '#interesting', 0.528, 'type_of_music', 'pop_music', 'written_music', 'lyric', 'piece_of_music']
senticnet['musical'] = [0.022, 0, 0, 0.109, '#joyful', '#admirable', 0.044, 'instrumental', 'singer', 'hip_hop', 'melodic_noise', 'music_player']
senticnet['musical_composition'] = [0.053, -0.019, 0, 0, '#joyful', '#surprising', 0.024, 'science_fiction', 'stereo', 'contralto', 'radio', 'music']
senticnet['musical_device'] = [0.793, -0.953, 0, 0, '#joyful', '#surprising', 0.582, 'play_ping_pong', 'magic', 'school_play', 'stunt', 'family_activity']
senticnet['musical_group'] = [0.089, 0, 0, 0.13, '#joyful', '#admirable', 0.073, 'jazz', 'rock_group', 'guitar_player', 'pluck', 'beautiful_music']
senticnet['musical_instrument'] = [-0.036, -0.009, 0.018, -0.082, '#sad', '#disgusting', -0.042, 'reed_instrument', 'stringed_use_jazz_music', 'instrument_music', 'use_jazz_music', 'listen_music']
senticnet['musical_instrument_store'] = [0, -0.748, 0, 0.872, '#surprising', '#admirable', 0.54, 'string_quartet', 'music_store', 'band_room', 'music_shop', 'high_school_band']
senticnet['musical_interval'] = [-0.652, 0, 0.681, -0.943, '#angry', '#disgusting', -0.759, 'tone', 'whole_tone', 'step', 'whole_step', 'semitone']
senticnet['musical_notation'] = [0.995, 0, 0, 0.776, '#joyful', '#admirable', 0.59, 'musical_symbol', 'musical_term', 'music_sound', 'music_part', 'musical_note']
senticnet['musical_note'] = [0.056, 0, 0.046, 0.094, '#joyful', '#admirable', 0.035, 'music_note', 'lyrics', 'musical_term', 'song', 'melody']
senticnet['musical_organization'] = [0.552, -0.61, 0, 0.588, '#surprising', '#admirable', 0.583, 'barbershop_quartet', 'string_quartet', 'string_quartette', 'quartette', 'musical_group']
senticnet['musical_performance'] = [0.584, -0.783, 0, 0.546, '#joyful', '#surprising', 0.638, 'acting', 'performing_art', 'dancing', 'dance', 'terpsichore']
senticnet['musical_sound'] = [0.923, 0.747, 0, 0, '#joyful', '#interesting', 0.557, 'music_sound', 'guitar_string', 'piece_of_music', 'musical_term', 'music_note']
senticnet['musical_symbol'] = [0.767, 0.785, 0, 0, '#joyful', '#interesting', 0.517, 'music_part', 'musical_notation', 'music_sound', 'piece_of_music', 'musical_term']
senticnet['musical_term'] = [0.705, 0, 0, 0.884, '#joyful', '#admirable', 0.53, 'music_sound', 'musical_sound', 'piece_of_music', 'guitar_string', 'music_note']
senticnet['musical_theme'] = [0.802, -0.67, 0, 0.687, '#joyful', '#admirable', 0.72, 'tune', 'melody', 'variation', 'air', 'strain']
senticnet['musing'] = [-0.845, 0, -0.766, 0, '#sad', '#scared', -0.537, 'pondering', 'think', 'broody', 'contemplative', 'meditative']
senticnet['musk_mallow'] = [-0.714, 0, 0.983, -0.628, '#sad', '#angry', -0.775, 'bush', 'mallow', 'mus_rose', 'common_mallow', 'tall_mallow']
senticnet['muss'] = [-0.787, 0, 0.854, -0.9, '#angry', '#disgusting', -0.847, 'disorderliness', 'untidiness', 'mess', 'muddle', 'messiness']
senticnet['mussel'] = [0, 0, -0.071, 0, '#scared', '#scared', -0.024, 'seal', 'walrus', 'otter', 'alligator', 'whale']
senticnet['mussitate'] = [-0.628, 0, 0.885, -0.664, '#angry', '#disgusting', -0.726, 'talk', 'utter', 'speak', 'mouth', 'verbalize']
senticnet['mussy'] = [-0.852, 0, 0.985, -0.71, '#sad', '#angry', -0.849, 'messy', 'untidy', 'disheveled', 'dirty', 'frowzled']
senticnet['must'] = [0.022, 0.34, -0.292, 0.317, '#interesting', '#admirable', 0.129, 'requirement', 'ought', 'necessary', 'needful', 'demand']
senticnet['must_eat'] = [0.91, 0.859, 0, 0, '#joyful', '#interesting', 0.59, 'need_eat', 'hungry', 'provide_family', 'money_buy', 'put_food_table']
senticnet['must_pay'] = [0, 0.24, -0.063, 0.112, '#interesting', '#admirable', 0.096, 'money_owe', 'amount_owe', 'money_pay', 'money_payment', 'money_term']
senticnet['mustang'] = [0, 0.072, 0, 0.09, '#interesting', '#admirable', 0.054, 'equine', 'wild_animal', 'rodent', 'primate', 'high_animal']
senticnet['mustard_agent'] = [-0.903, 0, 0.529, -0.842, '#sad', '#disgusting', -0.758, 'nerve_gas', 'nerve_agent', 'mustard_gas', 'poison_gas', 'blistering_agent']
senticnet['mustard_gas'] = [-0.903, 0, 0.529, -0.842, '#sad', '#disgusting', -0.758, 'nerve_gas', 'nerve_agent', 'poison_gas', 'mustard_agent', 'blistering_agent']
senticnet['mutability'] = [0.772, -0.731, 0, 0.958, '#joyful', '#admirable', 0.82, 'quality', 'changeability', 'mutableness', 'changefulness', 'exchangeability']
senticnet['mutable'] = [0.896, -0.663, 0, 0.667, '#joyful', '#admirable', 0.742, 'changeful', 'distortable', 'reversible', 'adjustable', 'unstable']
senticnet['mutableness'] = [0.772, -0.731, 0, 0.958, '#joyful', '#admirable', 0.82, 'quality', 'mutability', 'changeability', 'changefulness', 'exchangeability']
senticnet['mutant'] = [-0.975, 0, 0.677, -0.955, '#sad', '#disgusting', -0.869, 'stunt', 'game', 'animate_being', 'invertebrate', 'varmint']
senticnet['mutation'] = [-0.938, 0, 0.544, -0.778, '#sad', '#disgusting', -0.753, 'mutant', 'variation', 'sport', 'leviathan', 'lusus_naturae']
senticnet['mute'] = [-0.946, 0, 0, 0, '#sad', '#sad', -0.315, 'drive_recklessly', 'discord', 'deaf', 'deny', 'oneself']
senticnet['muted'] = [0, 0, -0.935, -0.886, '#scared', '#disgusting', -0.607, 'dull', 'muffle', 'tone_down', 'hushed', 'softened']
senticnet['mutilate'] = [-0.593, 0, 0.537, -0.532, '#sad', '#angry', -0.554, 'murder', 'falsify', 'mangle', 'misrepresent', 'belie']
senticnet['mutilator'] = [-0.867, 0, 0.793, -0.931, '#sad', '#disgusting', -0.864, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['mutinous'] = [-0.652, 0, 0.795, -0.96, '#angry', '#disgusting', -0.802, 'contumacious', 'disobedient', 'unruly', 'rebellious', 'insubordinate']
senticnet['mutt'] = [-0.726, 0, 0.619, -0.861, '#sad', '#disgusting', -0.735, 'dog', 'feist', 'fice', 'pariah_dog', 'domestic_dog']
senticnet['mutter'] = [-0.524, 0, 0.607, -0.549, '#angry', '#disgusting', -0.56, 'bewail', 'bemoan', 'quetch', 'scold', 'gripe']
senticnet['mutton'] = [0, -0.036, 0.057, -0.089, '#angry', '#disgusting', -0.037, 'lamb_meat', 'bandage', 'ewe', 'shear', 'seam']
senticnet['muttonhead'] = [-0.816, 0, 0.871, -0.679, '#sad', '#angry', -0.789, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['mutual_benefit'] = [0.847, 0.806, 0, 0, '#joyful', '#interesting', 0.551, 'win_win_situation', 'agreement', 'win_game', 'convenience', 'win']
senticnet['mutual_resemblance'] = [-0.886, 0, 0.813, -0.578, '#sad', '#angry', -0.759, 'affinity', 'resemblance', 'alikeness', 'likeness', 'similitude']
senticnet['mutual_understand'] = [0.147, 0.241, -0.222, 0.455, '#interesting', '#admirable', 0.207, 'request', 'consent', 'give_answer', 'tell', 'proclamation']
senticnet['mutuality'] = [-0.819, 0, 0.931, -0.777, '#sad', '#angry', -0.842, 'mutualness', 'reciprocity', 'complementarity', 'correlation', 'correlativity']
senticnet['mutualness'] = [-0.819, 0, 0.931, -0.777, '#sad', '#angry', -0.842, 'reciprocity', 'mutuality', 'complementarity', 'correlation', 'correlativity']
senticnet['muumuu'] = [-0.531, 0, 0.569, -0.776, '#angry', '#disgusting', -0.625, 'pinafore', 'pinny', 'dirndl', 'gown', 'dress']
senticnet['muzzle'] = [0, -0.101, 0.126, -0.161, '#angry', '#disgusting', -0.062, 'flea', 'louse', 'gnat', 'mosquito', 'whisker']
senticnet['muzzy'] = [-0.958, 0, 0.892, -0.813, '#sad', '#angry', -0.888, 'blurry', 'foggy', 'hazy', 'indistinct', 'blurred']
senticnet['mycobacteria'] = [-0.908, 0, 0.908, -0.538, '#sad', '#angry', -0.785, 'tubercle_bacillus', 'leprosy_bacillus', 'eubacteria', 'eubacterium', 'true_bacteria']
senticnet['mycobacterium'] = [-0.607, 0, 0.721, -0.575, '#sad', '#angry', -0.634, 'tubercle_bacillus', 'leprosy_bacillus', 'eubacteria', 'eubacterium', 'true_bacteria']
senticnet['mycosis'] = [-0.859, 0, 0.549, -0.938, '#sad', '#disgusting', -0.782, 'coccidioidomycosis', 'coccidiomycosis', 'valley_fever', 'desert_rheumatism', 'cryptococcosis']
senticnet['myelatelia'] = [-0.538, 0, 0.626, -0.863, '#angry', '#disgusting', -0.676, 'imperfection', 'imperfectness', 'defect', 'birth_defect', 'congenital_anomaly']
senticnet['myocardiopathy'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'heart_problem', 'ill', 'illness', 'heart_disease', 'rheumatic_heart_disease']
senticnet['myoma'] = [-0.704, 0, 0.639, -0.56, '#sad', '#angry', -0.634, 'fibroma', 'adenoma', 'chondroma', 'enchondroma', 'benign_tumor']
senticnet['myope'] = [-0.638, 0, 0.625, -0.989, '#sad', '#disgusting', -0.751, 'aphakic', 'blind_person', 'visually_impaired_person', 'mortal', 'hyperope']
senticnet['myopic'] = [-0.638, 0, 0.867, -0.57, '#sad', '#angry', -0.692, 'improvident', 'short', 'shortsighted', 'unforesightful', 'thriftless']
senticnet['myositis'] = [-0.873, 0, 0.531, -0.681, '#sad', '#disgusting', -0.695, 'rubor', 'redness', 'dermatomyositis', 'inclusion_body_myositis', 'inflammation']
senticnet['myotonia_atrophica'] = [-0.586, 0, 0.724, -0.757, '#angry', '#disgusting', -0.689, 'myotonic_muscular_dystrophy', 'myotonic_dystrophy', 'dystrophy', 'distal_muscular_dystrophy', 'genetic_disease']
senticnet['myotonic_dystrophy'] = [-0.586, 0, 0.724, -0.757, '#angry', '#disgusting', -0.689, 'myotonic_muscular_dystrophy', 'dystrophy', 'myotonia_atrophica', 'distal_muscular_dystrophy', 'genetic_disease']
senticnet['myotonic_muscular_dystrophy'] = [-0.586, 0, 0.724, -0.757, '#angry', '#disgusting', -0.689, 'dystrophy', 'myotonic_dystrophy', 'myotonia_atrophica', 'distal_muscular_dystrophy', 'genetic_disease']
senticnet['myriad'] = [0, 0.907, 0, 0.767, '#interesting', '#admirable', 0.558, 'indeterminable', 'infinite', 'incalculable', 'immeasurable', 'countless']
senticnet['mysterious'] = [0, 0.066, -0.061, 0.088, '#interesting', '#admirable', 0.031, 'foggy', 'hazy', 'cloudy', 'wet_air', 'evaporate']
senticnet['mystery'] = [-0.885, 0, -0.888, 0, '#sad', '#scared', -0.591, 'riddle', 'obituary', 'editorial', 'news_story', 'article']
senticnet['mystery_play'] = [0.734, -0.604, 0, 0.612, '#joyful', '#admirable', 0.65, 'theater_of_absurd', 'playlet', 'miracle_play', 'morality_play', 'drama']
senticnet['mystic'] = [0.291, 0.27, -0.12, 0, '#joyful', '#interesting', 0.147, 'unknown', 'seeker', 'add_knowledge', 'deep_thinker', 'sense_of_fulfillment']
senticnet['mystification'] = [-0.805, 0, 0.795, -0.813, '#sad', '#disgusting', -0.804, 'confusion', 'disarray', 'mental_confusion', 'confusedness', 'muddiness']
senticnet['mystify'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'surprise', 'baffle', 'stupefy', 'dumbfound', 'stupefaction']
senticnet['mystifying'] = [-0.624, 0, 0.825, -0.738, '#angry', '#disgusting', -0.729, 'unexplainable', 'unaccountable', 'unexplained', 'inscrutable', 'incomprehensible']
senticnet['myth'] = [0, 0, -0.707, -0.895, '#scared', '#disgusting', -0.534, 'fable', 'story', 'saga', 'long_story', 'classic']
senticnet['mythical'] = [0, 0, -0.088, 0, '#scared', '#scared', -0.029, 'fable', 'story', 'dictionary', 'saga', 'fairy_story']
senticnet['mythical_being'] = [-0.805, 0, 0.747, -0.748, '#sad', '#disgusting', -0.767, 'mythical_monster', 'mythical_creature', 'hero', 'houri', 'halcyon']
senticnet['mythical_creature'] = [0, 0, -0.074, 0, '#scared', '#scared', -0.025, 'creature', 'vertebrate', 'beast', 'arthropod', 'arachnid']
senticnet['mythical_monster'] = [-0.651, 0, 0.505, -0.919, '#sad', '#disgusting', -0.692, 'hellhound', 'mythical_being', 'dragon', 'roc', 'amphisbaena']
senticnet['mythical_place'] = [-0.924, 0, 0.687, -0.75, '#sad', '#disgusting', -0.787, 'hellfire', 'red_region', 'imaginary_place', 'infernal_region', 'fictitious_place']
senticnet['nacho'] = [-0.873, 0, 0, -0.898, '#sad', '#disgusting', -0.59, 'person', 'stockholder', 'commit_crime', 'guilty_person', 'criminal']
senticnet['nag'] = [0, 0, 0.737, -0.864, '#angry', '#disgusting', -0.534, 'annoy', 'skin_rash', 'bother', 'irritation', 'great_dane']
senticnet['nagger'] = [-0.718, 0, 0.972, -0.625, '#sad', '#angry', -0.772, 'scold', 'nag', 'scolder', 'harridan', 'common_scold']
senticnet['naif'] = [0.798, -0.519, 0, 0.973, '#joyful', '#admirable', 0.763, 'inexperienced_person', 'boy_scout', 'dear', 'virgin', 'mortal']
senticnet['nail'] = [0, 0.078, 0.027, 0.196, '#interesting', '#admirable', 0.082, 'heel', 'ankle', 'toe', 'foot_massage', 'foot']
senticnet['nail-biting'] = [0, 0, 0, -0.968, '#disgusting', '#disgusting', -0.323, 'suspenseful', 'suspensive', 'cliff-hanging', 'apathetically', 'concern']
senticnet['nail_down'] = [0.747, -0.635, 0, 0.755, '#joyful', '#admirable', 0.712, 'deliver_goods', 'succeed', 'win', 'bring_home_bacon', 'come_through']
senticnet['nailrod'] = [0.656, -0.632, 0, 0.844, '#joyful', '#admirable', 0.711, 'bullrush', 'bulrush', 'cattail', 'reed_mace', 'reedmace']
senticnet['naive'] = [0, 0, 0.957, -0.857, '#angry', '#disgusting', -0.605, 'ingenuous', 'gullible', 'artless', 'childlike', 'guileless']
senticnet['naive_person'] = [0, 0, 0.894, -0.825, '#angry', '#disgusting', -0.573, 'young_child', 'child', 'youth', 'small_child', 'pass_gene']
senticnet['naiveness'] = [-0.613, 0, 0.599, -0.571, '#sad', '#angry', -0.594, 'simple_mindedness', 'simpleness', 'ingenuousness', 'artlessness', 'simplicity']
senticnet['naivete'] = [-0.596, 0, 0.834, -0.721, '#angry', '#disgusting', -0.717, 'simple_mindedness', 'simpleness', 'ingenuousness', 'artlessness', 'simplicity']
senticnet['naivety'] = [-0.705, 0, 0.64, -0.828, '#sad', '#disgusting', -0.724, 'simple_mindedness', 'simpleness', 'ingenuousness', 'artlessness', 'simplicity']
senticnet['naked'] = [-0.031, 0, 0, -0.044, '#sad', '#disgusting', -0.025, 'take_clothes_off', 'remove_clothes', 'naked_woman', 'turn_water', 'take_off_clothes']
senticnet['naked_eye'] = [0.753, -0.647, 0, 0.556, '#joyful', '#surprising', 0.652, 'oculus_dexter', 'stemma', 'eye', 'peeper', 'oculus_sinister']
senticnet['naked_woman'] = [0, 0, 0, -0.073, '#disgusting', '#disgusting', -0.024, 'driftwood', 'sea_shell', 'scenic_view', 'shore', 'tidal_wave']
senticnet['nakedness'] = [-0.947, 0, 0.991, -0.656, '#sad', '#angry', -0.865, 'birthday_suit', 'raw', 'altogether', 'nude', 'undress']
senticnet['name'] = [0, 0.933, 0, 0.814, '#interesting', '#admirable', 0.582, 'native', 'native_australia', 'royal', 'title', 'alias']
senticnet['name_baby'] = [0.796, 0.974, 0, 0, '#joyful', '#interesting', 0.59, 'name_child', 'name', 'baby', 'child', 'become_dad']
senticnet['name_child'] = [0.813, 0.873, 0, 0, '#joyful', '#interesting', 0.562, 'name_baby', 'name', 'baby', 'child', 'become_dad']
senticnet['name_dog'] = [-0.103, 0.075, -0.129, -0.08, '#sad', '#scared', -0.079, 'think_future', 'gather_berry', 'hang_picture_on_wall', 'die_only_once', 'see_star_night']
senticnet['name_dropper'] = [-0.97, 0, 0.728, -0.785, '#sad', '#disgusting', -0.828, 'beguiler', 'slicker', 'faker', 'ringer', 'deceiver']
senticnet['name_planet'] = [0.045, 0, 0, 0.051, '#joyful', '#admirable', 0.032, 'perfect_sphere', 'pour_hot_coffee_mug', 'planet_earth', 'alkaline', 'wrest']
senticnet['name_state'] = [0.08, 0, -0.071, 0.133, '#joyful', '#admirable', 0.047, 'state_america', 'state', 'usa', 'united_states', 'large_state']
senticnet['name_street'] = [-0.036, 0.149, -0.063, 0.14, '#interesting', '#admirable', 0.063, 'live_house', 'sell_house', 'address', 'house_location', 'part_of_company']
senticnet['naming'] = [0.904, -0.588, 0, 0.736, '#joyful', '#admirable', 0.743, 'denotative', 'appellative', 'designative', 'extensional', 'referent']
senticnet['nanism'] = [-0.816, 0, 0.96, -0.969, '#angry', '#disgusting', -0.915, 'pycnodysostosis', 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect']
senticnet['nanotechnology'] = [0.2, 0.154, -0.08, 0.166, '#joyful', '#admirable', 0.147, 'college_class', 'class', 'school_course', 'technology', 'topic']
senticnet['nap'] = [0.929, -0.928, 0, 0, '#joyful', '#surprising', 0.619, 'lie_back', 'feel_little_tired', 'asleep', 'laze', 'take_asleep']
senticnet['nape'] = [0, 0, -0.06, -0.063, '#scared', '#disgusting', -0.041, 'neck', 'adam_apple', 'henchman', 'shoulder', 'head']
senticnet['napkin'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'wipe', 'wipe_mouth', 'clean_mouth', 'oral_cleaning', 'toothbrush']
senticnet['napping'] = [-0.926, 0, 0.659, -0.814, '#sad', '#disgusting', -0.8, 'unripe', 'unready', 'off_guard', 'off_one_guard', 'off_his_guard']
senticnet['narcolepsy'] = [-0.032, -0.037, -0.084, -0.236, '#scared', '#disgusting', -0.105, 'sleep_apnea', 'free_sex', 'stupidity', 'embarrassment', 'seizure']
senticnet['narcotic'] = [0, 0, -0.942, -0.729, '#scared', '#disgusting', -0.557, 'sleep_drug', 'palliative', 'ibuprofen', 'analgesic', 'phenobarbital']
senticnet['nark'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['narrative'] = [0.1, 0.085, 0, 0.093, '#joyful', '#admirable', 0.093, 'bed_time', 'bedtime', 'fable', 'long_story', 'saga']
senticnet['narrow'] = [-0.956, 0, 0.159, -0.941, '#sad', '#disgusting', -0.685, 'narrow_road', 'poky', 'tight', 'clenched', 'cramped']
senticnet['narrow_down'] = [0.519, -0.554, 0, 0.746, '#surprising', '#admirable', 0.606, 'concretize', 'peg_down', 'nail_down', 'narrow', 'pin_down']
senticnet['narrow_road'] = [-0.956, 0, 0.159, -0.941, '#sad', '#disgusting', -0.685, 'road', 'narrow', 'poky', 'dark_road', 'rough_road']
senticnet['narrowing'] = [0.592, -0.913, 0, 0.61, '#surprising', '#admirable', 0.705, 'folding', 'angulation', 'change_of_shape', 'elongation', 'fold']
senticnet['narrowness'] = [0.047, -0.107, 0.026, -0.046, '#joyful', '#surprising', 0.027, 'paper', 'fasten_paper_together', 'bind_paper_together', 'piece_of_paper', 'keep_paper_together']
senticnet['nasa'] = [0.052, 0, 0, 0.094, '#joyful', '#admirable', 0.049, 'orbit_around_sun', 'enormous', 'milky', 'milky_galaxy', 'god_creation']
senticnet['nasal_twang'] = [-0.719, 0, 0.998, -0.647, '#sad', '#angry', -0.788, 'tone', 'quality', 'twang', 'nasality', 'timber']
senticnet['nasality'] = [-0.719, 0, 0.998, -0.647, '#sad', '#angry', -0.788, 'tone', 'quality', 'twang', 'nasal_twang', 'timber']
senticnet['nasalize'] = [0.63, -0.971, 0, 0.626, '#joyful', '#surprising', 0.742, 'pronounce', 'enounce', 'say', 'sound_out', 'enunciate']
senticnet['nastiness'] = [-0.687, 0, 0.529, -0.694, '#sad', '#disgusting', -0.637, 'unsanitariness', 'filth', 'filthiness', 'dunghill', 'sanitary_condition']
senticnet['nasty'] = [0, 0, 0.831, -0.822, '#angry', '#disgusting', -0.551, 'smelly', 'bad_smell', 'cruel', 'hazardous', 'uppercase_bug']
senticnet['nation'] = [0.716, -0.51, 0, 0.647, '#joyful', '#admirable', 0.624, 'state', 'ally', 'country', 'land', 'commonwealth']
senticnet['nation-wide'] = [0.041, 0.122, -0.082, 0.171, '#interesting', '#admirable', 0.084, 'nation', 'govern_city', 'national', 'large_town', 'big_city_life']
senticnet['nation_state'] = [0.044, 0.133, -0.086, 0.087, '#interesting', '#admirable', 0.059, 'republic', 'nation', 'democratic_country', 'free_country', 'democracy']
senticnet['national'] = [0.041, 0.122, -0.082, 0.171, '#interesting', '#admirable', 0.084, 'nation', 'govern_city', 'nation-wide', 'large_town', 'big_city_life']
senticnet['national_event'] = [-0.183, 0.081, -0.187, 0, '#sad', '#scared', -0.096, 'world_event', 'type_of_paper', 'give_info', 'cnn', 'journalist']
senticnet['national_highway'] = [0, 0, 0.024, -0.051, '#angry', '#disgusting', -0.025, 'toll_road', 'toll_highway', 'superhighway', 'intertoll_highway', 'motorway']
senticnet['national_interstate_highway'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'thruway', 'round_trip_ticket', 'farecard', 'traffic_artery', 'move_sidewalk']
senticnet['national_leader'] = [0.838, -0.589, 0, 0.945, '#joyful', '#admirable', 0.791, 'elder_statesman', 'stateswoman', 'politician', 'politico', 'pol']
senticnet['nationalism'] = [0.553, -0.728, 0, 0.752, '#surprising', '#admirable', 0.678, 'jingoism', 'trueness', 'loyalty', 'chauvinism', 'superpatriotism']
senticnet['nationalistic'] = [0.585, -0.7, 0, 0.586, '#surprising', '#admirable', 0.624, 'jingoistic', 'ultrapatriotic', 'superpatriotic', 'patriotic', 'chauvinistic']
senticnet['nationality'] = [0, -0.953, 0, 0.973, '#surprising', '#admirable', 0.642, 'clean_shoes', 'black_stuff', 'paint_nail', 'ethnicity', 'black_goo']
senticnet['native'] = [0, 0.917, 0, 0.868, '#interesting', '#admirable', 0.595, 'name', 'name_australia', 'royal', 'title', 'alias']
senticnet['native_american'] = [0.052, 0.099, 0, 0.067, '#interesting', '#admirable', 0.073, 'police_rank', 'head_guy', 'chief', 'leader', 'commander']
senticnet['native_australia'] = [0.066, 0.12, -0.104, 0.121, '#interesting', '#admirable', 0.068, 'form_government', 'kingdom', 'united_country', 'political_entity', 'aboriginal']
senticnet['native_orange'] = [-0.573, 0, 0.721, -0.775, '#angry', '#disgusting', -0.69, 'bush', 'native_pomegranate', 'caper_tree', 'caper', 'common_caper']
senticnet['native_person'] = [0.172, 0.138, 0, 0.097, '#joyful', '#interesting', 0.136, 'live_good_life', 'healthy_environment', 'live_country', 'live_healthy_life', 'exercise_often']
senticnet['native_pomegranate'] = [-0.573, 0, 0.721, -0.775, '#angry', '#disgusting', -0.69, 'bush', 'caper', 'caper_tree', 'native_orange', 'common_caper']
senticnet['nativity'] = [0.132, -0.08, -0.074, 0.067, '#joyful', '#surprising', 0.068, 'fun_time', 'party_time', 'saturday', 'holiday', 'annual_celebration']
senticnet['natter'] = [0.981, -0.902, 0, 0.756, '#joyful', '#surprising', 0.88, 'schmooze', 'schmoose', 'shmooze', 'shmoose', 'jawbone']
senticnet['nattiness'] = [0.853, -0.764, 0, 0.966, '#joyful', '#admirable', 0.861, 'elegance', 'jauntiness', 'rakishness', 'chicness', 'dapperness']
senticnet['natty'] = [0, 0, -0.933, -0.86, '#scared', '#disgusting', -0.598, 'rakish', 'dashing', 'jaunty', 'dapper', 'raffish']
senticnet['natural'] = [0.063, 0.065, 0.035, 0.078, '#interesting', '#admirable', 0.057, 'white', 'same_answer', 'come_off', 'organic', 'general_term']
senticnet['natural_action'] = [-0.643, 0, 0.938, -0.521, '#sad', '#angry', -0.701, 'extinction', 'adiabatic_process', 'hardening', 'decay', 'absorption']
senticnet['natural_air'] = [0.046, -0.03, 0, 0, '#joyful', '#surprising', 0.025, 'breeze', 'sea_view', 'bay_window', 'seashore', 'sand']
senticnet['natural_disaster'] = [-0.028, 0, 0, -0.081, '#sad', '#disgusting', -0.036, 'hurricane', 'atmospheric_phenomenon', 'flood', 'weather_element', 'tropical_storm']
senticnet['natural_endowment'] = [0.889, -0.522, 0, 0.634, '#joyful', '#admirable', 0.682, 'genius', 'raw_talent', 'flair', 'bent', 'knack']
senticnet['natural_event'] = [-0.737, 0, 0.591, -0.681, '#sad', '#disgusting', -0.67, 'whammy', 'happening', 'occurrence', 'occurrent', 'setback']
senticnet['natural_fabric'] = [0.069, 0.112, 0, 0.167, '#interesting', '#admirable', 0.116, 'plant_material', 'clothes_material', 'natural_fiber', 'boll', 'fabric_type']
senticnet['natural_fiber'] = [0.069, 0.112, 0, 0.167, '#interesting', '#admirable', 0.116, 'plant_material', 'clothes_material', 'boll', 'natural_fabric', 'fabric_type']
senticnet['natural_gas'] = [0, 0.929, 0, 0.886, '#interesting', '#admirable', 0.605, 'soft_wood', 'wood', 'fiberglass', 'glass', 'franchise']
senticnet['natural_history'] = [0.701, -0.778, 0, 0.659, '#joyful', '#surprising', 0.713, 'discipline', 'study', 'subject', 'science', 'natural_science']
senticnet['natural_history_museum'] = [0, 0.087, -0.07, 0.1, '#interesting', '#admirable', 0.039, 'institution', 'tundra', 'children_story', 'smithsonian_institution', 'cartoon']
senticnet['natural_material'] = [0.035, 0.088, 0.031, 0.113, '#interesting', '#admirable', 0.068, 'cultivate_yard', 'same_answer', 'poisonous_human', 'juicy', 'organic']
senticnet['natural_object'] = [0.566, -0.553, 0, 0.776, '#joyful', '#admirable', 0.632, 'whole', 'black_body', 'blackbody', 'full_radiator', 'stone']
senticnet['natural_order'] = [-0.731, 0, 0.884, -0.601, '#sad', '#angry', -0.739, 'world', 'universe', 'existence', 'creation', 'cosmos']
senticnet['natural_phenomenon'] = [-0.176, -0.073, 0, -0.159, '#sad', '#disgusting', -0.087, 'snow_storm', 'rain_snow', 'rainy', 'cold_hot', 'weather_type']
senticnet['natural_process'] = [-0.848, 0, 0.617, -0.935, '#sad', '#disgusting', -0.8, 'extinction', 'adiabatic_process', 'hardening', 'decay', 'absorption']
senticnet['natural_resource'] = [0.136, 0, -0.05, 0.099, '#joyful', '#admirable', 0.062, 'hyper', 'carbohydrate', 'calorie', 'create_destroy', 'necessary_live']
senticnet['natural_science'] = [0.701, -0.778, 0, 0.659, '#joyful', '#surprising', 0.713, 'discipline', 'study', 'subject', 'natural_history', 'science']
senticnet['natural_state'] = [-0.905, 0, 0.667, -0.994, '#sad', '#disgusting', -0.855, 'primitiveness', 'crudeness', 'crudity', 'primitivism', 'rudeness']
senticnet['natural_virtue'] = [0.594, -0.689, 0, 0.824, '#surprising', '#admirable', 0.702, 'justness', 'temperance', 'justice', 'moderation', 'prudence']
senticnet['natural_world'] = [0, 0.784, 0, 0.859, '#interesting', '#admirable', 0.548, 'plato', 'brown_hair', 'wild_nature', 'feature', 'stick_out']
senticnet['naturalize'] = [0.506, -0.599, 0, 0.896, '#surprising', '#admirable', 0.667, 'explicate', 'clarify', 'clear_up', 'elucidate', 'rede']
senticnet['nature'] = [0.083, -0.036, 0, 0, '#joyful', '#surprising', 0.04, 'good_view', 'bird_droppings', 'slate', 'gable', 'homeowner']
senticnet['naught'] = [-0.554, 0, 0.882, -0.735, '#angry', '#disgusting', -0.724, 'null', 'zero', 'bugger_all', 'zip', 'nothing']
senticnet['naughty'] = [0, 0, 0.874, -0.976, '#angry', '#disgusting', -0.617, 'foolish', 'unwanted', 'bad_luck', 'pollute_air', 'sexy']
senticnet['nausea'] = [0, 0, -0.878, -0.969, '#scared', '#disgusting', -0.616, 'disgust', 'offend', 'despise', 'isolation', 'malice']
senticnet['nauseant'] = [-0.992, 0, 0.923, -0.973, '#sad', '#disgusting', -0.963, 'remedy', 'cure', 'therapeutic', 'curative', 'ipecac']
senticnet['nauseate'] = [-0.071, 0.137, 0.693, -0.671, '#angry', '#disgusting', -0.433, 'sicken', 'repel', 'gross_out', 'loathsome', 'churn_up']
senticnet['nauseated'] = [-0.062, 0.128, 0.707, -0.677, '#angry', '#disgusting', -0.439, 'sickish', 'turn_stomach', 'vile', 'sickening', 'noisome']
senticnet['nauseating'] = [-0.062, 0.128, 0.707, -0.677, '#angry', '#disgusting', -0.439, 'sickish', 'turn_stomach', 'vile', 'sickening', 'noisome']
senticnet['nauseatingness'] = [-0.522, 0, 0.703, -0.718, '#angry', '#disgusting', -0.648, 'distastefulness', 'taste_property', 'disgustingness', 'unsavoriness', 'unpalatability']
senticnet['nauseous'] = [-0.062, 0.128, 0.707, -0.677, '#angry', '#disgusting', -0.439, 'sickish', 'turn_stomach', 'vile', 'sickening', 'noisome']
senticnet['nautilus'] = [-0.523, 0, 0.728, -0.926, '#angry', '#disgusting', -0.726, 'octopod', 'cephalopod', 'cephalopod_mollusk', 'paper_octopod', 'octopus']
senticnet['nave'] = [0.029, 0.11, 0, 0.092, '#interesting', '#admirable', 0.077, 'party', 'use_party', 'special_happen', 'happy_occasion', 'special_moment']
senticnet['navigable'] = [0, 0, 0.869, -0.884, '#angry', '#disgusting', -0.584, 'passable', 'negotiable', 'surmountable', 'climbable', 'traversable']
senticnet['navigate'] = [0.746, 0, 0, 0.729, '#joyful', '#admirable', 0.492, 'journey', 'adventure', 'quest', 'find', 'travel']
senticnet['navigation'] = [-0.031, 0.127, 0.041, 0.15, '#interesting', '#admirable', 0.068, 'mathematical_operation', 'math_process', 'math_action', 'mathematical_term', 'math_operation']
senticnet['navy'] = [-0.031, 0.127, 0.041, 0.15, '#interesting', '#admirable', 0.068, 'army_rank', 'army_leader', 'navy_rank', 'army_navy', 'navy_leader']
senticnet['navy_cross'] = [0.899, -0.799, 0, 0.691, '#joyful', '#surprising', 0.796, 'decoration', 'laurel_wreath', 'medal', 'medallion', 'palm']
senticnet['navy_leader'] = [0.041, 0.095, 0, 0, '#joyful', '#interesting', 0.045, 'leadership_position', 'navy_officer', 'head_person', 'police_rank', 'head_guy']
senticnet['navy_officer'] = [0.041, 0.095, 0, 0, '#joyful', '#interesting', 0.045, 'leadership_position', 'head_guy', 'head_person', 'police_rank', 'navy_leader']
senticnet['navy_rank'] = [0.028, 0.067, 0, 0, '#joyful', '#interesting', 0.032, 'military_officer', 'navy_leader', 'navy_officer', 'leadership_position', 'military_position']
senticnet['naysayer'] = [-0.973, 0, 0.62, -0.727, '#sad', '#disgusting', -0.773, 'obstructor', 'obstructer', 'technophobe', 'obstructionist', 'resister']
senticnet['nazi'] = [0.052, 0, 0, 0.069, '#joyful', '#admirable', 0.04, 'philanthropist', 'healthy_person', 'man', 'pervert', 'compatriot']
senticnet['nazism'] = [-0.819, -0.715, 0.843, -0.726, '#sad', '#angry', -0.558, 'lack_of_rules', 'fascism', 'despot', 'tyrant', 'anarchism']
senticnet['ne_plus_ultra'] = [-0.725, 0, 0.71, -0.507, '#sad', '#angry', -0.647, 'finish', 'culture', 'dream', 'state', 'cultivation']
senticnet['neap'] = [0.632, -0.613, 0, 0.525, '#joyful', '#surprising', 0.59, 'sea_level', 'high_tide', 'springtide', 'direct_tide', 'tide']
senticnet['neap_tide'] = [0.632, -0.613, 0, 0.525, '#joyful', '#surprising', 0.59, 'high_tide', 'neap', 'springtide', 'direct_tide', 'tide']
senticnet['near'] = [0.56, 0.555, -0.215, 0.44, '#joyful', '#interesting', 0.447, 'close', 'easy', 'togetherness', 'capture', 'gay']
senticnet['near_beach'] = [0.746, 0.728, 0, 0, '#joyful', '#interesting', 0.491, 'vast', 'along_beach', 'big_blue', 'land_sea', 'full_water']
senticnet['near_completion'] = [0.445, 0.37, -0.142, 0.483, '#joyful', '#admirable', 0.385, 'almost_complete', 'near', 'mission_accomplished', 'sufficient', 'absolute']
senticnet['near_conclusion'] = [-0.059, 0.169, -0.085, 0.146, '#interesting', '#admirable', 0.057, 'understand', 'direction', 'near_end', 'end', 'begin']
senticnet['near_destination'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'board_boat', 'almost_there', 'board_ship', 'return_home', 'appear_beautiful']
senticnet['near_end'] = [-0.041, 0.074, 0.019, 0.071, '#interesting', '#admirable', 0.028, 'sharpness', 'sharp_end', 'sharp_corner', 'straight_line', 'edge']
senticnet['near_miss'] = [-0.627, 0, 0.507, -0.727, '#sad', '#disgusting', -0.62, 'accident', 'misfortune', 'bad_luck', 'misadventure', 'derailment']
senticnet['near_mouth'] = [0.037, 0.076, 0, 0.091, '#interesting', '#admirable', 0.068, 'face_part', 'facial_feature', 'facial_part', 'facial_organ', 'mouth_part']
senticnet['near_nose'] = [0, 0.066, 0.028, 0.106, '#interesting', '#admirable', 0.048, 'face_feature', 'facial_part', 'facial_organ', 'part_of_face', 'face_part']
senticnet['near_ocean'] = [0, 0.112, 0, 0.137, '#interesting', '#admirable', 0.083, 'island', 'popular_vacation_destination', 'land_feature', 'ocean_shore', 'oceanside']
senticnet['near_sea'] = [0.047, 0.11, 0, 0, '#joyful', '#interesting', 0.052, 'cover_sand', 'sandy', 'sand_rock', 'near_beach', 'beach']
senticnet['near_thing'] = [0.649, -0.858, 0, 0.947, '#surprising', '#admirable', 0.818, 'rejection', 'escape', 'avoidance', 'aversion', 'averting']
senticnet['near_tv'] = [-0.062, 0, -0.045, 0, '#sad', '#scared', -0.036, 'turn_on_tv', 'switch_tv', 'turn_television', 'rend_video', 'wear_glass']
senticnet['nearby'] = [0.128, 0.103, 0, 0.208, '#joyful', '#admirable', 0.146, 'complex_structure', 'vicinity', 'no_edge', 'circular', 'three_dimensions']
senticnet['neat'] = [0.985, 0, 0, 0.754, '#joyful', '#admirable', 0.58, 'tidy_up', 'tidy', 'neatness', 'expect_guest', 'personal_cleanliness']
senticnet['neat_tidy'] = [0.04, 0.184, -0.059, 0.262, '#interesting', '#admirable', 0.142, 'arrange', 'neatness', 'neat', 'organize', 'tidy_up']
senticnet['neaten'] = [0.971, -0.535, 0, 0.665, '#joyful', '#admirable', 0.724, 'tidy', 'tidy_up', 'clean_up', 'houseclean', 'straighten']
senticnet['neatness'] = [0.052, 0.147, 0, 0.151, '#interesting', '#admirable', 0.117, 'neat_tidy', 'neat', 'tidy_up', 'organize', 'tidy']
senticnet['nebulous'] = [-0.61, 0, 0.856, -0.826, '#angry', '#disgusting', -0.764, 'unfixed', 'one', 'indefinite', 'indecisive', 'coy']
senticnet['necessary'] = [0.055, 0.356, -0.268, 0.336, '#interesting', '#admirable', 0.16, 'requirement', 'must', 'needful', 'necessity', 'want_badly']
senticnet['necessary_life'] = [0, 0.985, 0, 0.892, '#interesting', '#admirable', 0.626, 'essential_human_life', 'warm_air', 'vitality', 'flatulence', 'power_source']
senticnet['necessary_live'] = [0.135, 0.144, -0.065, 0.16, '#interesting', '#admirable', 0.125, 'human_fuel', 'sweet_sour', 'eat', 'lighter_water', 'solid_liquid']
senticnet['necessitarian'] = [-0.55, 0, 0.58, -0.982, '#angry', '#disgusting', -0.704, 'fatalist', 'determinist', 'predestinarian', 'predestinationist', 'philosopher']
senticnet['necessity'] = [0.044, 0.297, -0.253, 0.281, '#interesting', '#admirable', 0.123, 'necessary', 'requirement', 'want_badly', 'strong_desire', 'needful']
senticnet['neck'] = [0.228, 0.123, -0.099, 0, '#joyful', '#interesting', 0.084, 'muscle', 'bone', 'shoulder', 'skeletal_system', 'bone_human']
senticnet['neck_and_neck'] = [-0.642, 0, 0.576, -0.83, '#sad', '#disgusting', -0.683, 'nisi', 'indeterminate', 'equivocal', 'inconclusive', 'nip_and_tuck']
senticnet['neckband'] = [0.942, -0.61, 0, 0.908, '#joyful', '#admirable', 0.82, 'adornment', 'cigar_band', 'hatband', 'stripe', 'pinstripe']
senticnet['necklace'] = [0.048, 0, 0, 0.093, '#joyful', '#admirable', 0.047, 'ring', 'ring_loudly', 'diamond_ring', 'wedding_ring', 'jewelry']
senticnet['neckwear'] = [0.78, -0.925, 0, 0, '#joyful', '#surprising', 0.568, 'lingerie', 'gay_person', 'jeans', 't-shirt', 'underwear']
senticnet['necromancer'] = [0.594, -0.549, 0, 0.518, '#joyful', '#surprising', 0.554, 'exorcist', 'enchanter', 'magus', 'sorceress', 'witch_doctor']
senticnet['necromancy'] = [-0.565, 0, 0.512, -0.908, '#sad', '#disgusting', -0.662, 'magic', 'thaumaturgy', 'enchantment', 'witchcraft', 'witchery']
senticnet['necrophilia'] = [-0.898, 0, 0.987, -0.904, '#angry', '#disgusting', -0.93, 'logorrhea', 'logomania', 'agromania', 'pyromania', 'cacoethes']
senticnet['need'] = [-0.84, 0, -0.879, 0, '#sad', '#scared', -0.573, 'necessity', 'demand', 'requirement', 'yearn', 'want_badly']
senticnet['need_beauty_center'] = [0.036, 0, 0.094, -0.055, '#angry', '#disgusting', -0.038, 'unaesthetic', 'need_shave', 'facial_hair', 'long_beard', 'carelessness']
senticnet['need_break'] = [-0.901, 0, 0.862, 0, '#sad', '#angry', -0.588, 'abandonment', 'need_to_rest', 'leg_tire', 'catch_breath', 'spare']
senticnet['need_buy'] = [-0.079, 0, 0.01, 0, '#sad', '#angry', -0.03, 'spend_money', 'purchase_goods', 'buy_milk', 'spend_a_lot_of_money', 'buy_many']
senticnet['need_care'] = [0.144, 0.134, -0.045, 0.238, '#joyful', '#admirable', 0.157, 'puppy', 'vulnerable', 'baby_dog', 'young_animal', 'newborn']
senticnet['need_clean'] = [-0.063, -0.024, 0.042, 0, '#sad', '#angry', -0.027, 'dirty', 'feel_dirty', 'shrinkage', 'fight_fire', 'fall_mud']
senticnet['need_communicate'] = [0.988, 0.77, 0, 0, '#joyful', '#interesting', 0.586, 'send_card', 'send_flower', 'yearly_celebration', 'show_care', 'send_gift']
senticnet['need_companionship'] = [-0.801, 0, -0.778, -0.993, '#sad', '#disgusting', -0.857, 'break', 'amount_nothing', 'ease_pain', 'break_up', 'wait_forever']
senticnet['need_cure'] = [-0.943, 0, 0.891, -0.939, '#sad', '#disgusting', -0.924, 'allergy', 'symptom', 'allergy_symptom', 'sick', 'cause_allergy']
senticnet['need_doctor'] = [-0.365, -0.082, 0, -0.327, '#sad', '#disgusting', -0.203, 'disease', 'body_disease', 'need_cure', 'varicose_vein', 'leg_pain']
senticnet['need_done'] = [0, 0.825, 0, 0.943, '#interesting', '#admirable', 0.589, 'help_person', 'show_appreciation', 'share_others', 'volunteer', 'help_others']
senticnet['need_earn_money'] = [0, 0.077, 0, 0, '#interesting', '#interesting', 0.026, 'earn_money', 'earn_wage', 'need_money', 'support_family', 'need_make_money']
senticnet['need_eat'] = [-0.857, 0, -0.818, 0, '#sad', '#scared', -0.558, 'need_food', 'hunger', 'hungry', 'eat_meat', 'desire_eat']
senticnet['need_eat_meal'] = [0.807, 0.763, 0, 0, '#joyful', '#interesting', 0.523, 'broken', 'little_bite', 'find_road', 'small_bite', 'repair']
senticnet['need_exercise'] = [0, 0, 0.033, -0.096, '#angry', '#disgusting', -0.043, 'restless', 'train_dog', 'tired', 'feel_energetic', 'need_fresh_air']
senticnet['need_fix'] = [0, 0, -0.943, -0.77, '#scared', '#disgusting', -0.571, 'engine_issue', 'broken_car', 'flat_tyre', 'broken_shelf', 'broken_engine']
senticnet['need_food'] = [0, 0, 0.883, -0.767, '#angry', '#disgusting', -0.55, 'hangry', 'a_little_hungry', 'become_little_hungry', 'angry', 'become_hungry']
senticnet['need_fresh_air'] = [-0.045, -0.045, 0.056, -0.1, '#angry', '#disgusting', -0.052, 'exercise', 'exercise_regularly', 'car_repair', 'excercise', 'strong_muscle']
senticnet['need_glass'] = [-0.839, 0, -0.978, 0, '#sad', '#scared', -0.606, 'snot', 'top_face', 'glass', 'stick_out', 'face']
senticnet['need_go_bathroom'] = [-0.037, 0, 0, -0.143, '#sad', '#disgusting', -0.06, 'hope_peace', 'bicycle_school', 'battle_illness', 'laugh_clown', 'honor_parent']
senticnet['need_go_somewhere'] = [0, -0.011, 0.046, -0.055, '#angry', '#disgusting', -0.03, 'go_some_place', 'get_to_destination', 'use_gas', 'get_somewhere', 'get_into_place']
senticnet['need_grocery'] = [-0.792, 0, -0.924, -0.708, '#sad', '#scared', -0.808, 'make_breakfast', 'feel_hunger', 'famine', 'order_lunch', 'fix_dinner']
senticnet['need_help'] = [-0.864, 0, -0.753, 0, '#sad', '#scared', -0.539, 'uncertainty', 'help_out', 'give_help', 'help', 'demand']
senticnet['need_holiday'] = [-0.103, -0.013, 0, -0.177, '#sad', '#disgusting', -0.089, 'stress', 'quit_job', 'hate_boss', 'hate_colleague', 'much_work']
senticnet['need_information'] = [0, 0, -0.943, -0.77, '#scared', '#disgusting', -0.571, 'lost', 'need_help', 'need_know', 'ignorant', 'needy_person']
senticnet['need_job'] = [0.986, 0, 0, 0, '#joyful', '#joyful', 0.329, 'become_rich', 'gain_wealth', 'buy_land', 'become_wealthy', 'need_make_money']
senticnet['need_know'] = [0, 0, -0.943, -0.77, '#scared', '#disgusting', -0.571, 'lost', 'need_help', 'need_information', 'ignorant', 'needy_person']
senticnet['need_love'] = [0.067, 0.358, -0.249, 0.426, '#interesting', '#admirable', 0.201, 'need_care', 'need_help', 'consent', 'request', 'neediness']
senticnet['need_make_money'] = [0.06, 0.181, 0, 0.056, '#joyful', '#interesting', 0.099, 'need_money', 'need_earn_money', 'earn_wage', 'arrive_mail', 'earn_money']
senticnet['need_medicine'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'heart_disease', 'heart_attack', 'cholesterol', 'blocked_artery', 'cardiac_drug']
senticnet['need_money'] = [0.77, 0, 0, 0.996, '#joyful', '#admirable', 0.589, 'balance_check_account', 'bind_agreement', 'absolutely', 'ask_money', 'earn_wage']
senticnet['need_new_clothes'] = [0, 0.15, 0, 0.095, '#interesting', '#admirable', 0.082, 'feel_faint', 'exercise_much', 'exercise_regularly', 'look_cool', 'moderation']
senticnet['need_new_job'] = [-0.955, 0, 0.164, -0.975, '#sad', '#disgusting', -0.698, 'fired', 'unemployed', 'become_poor', 'need_money', 'terminate_someone_employment']
senticnet['need_oil'] = [0, 0.084, 0, 0.124, '#interesting', '#admirable', 0.069, 'animal_sound', 'sound', 'repetitive', 'audio', 'noise']
senticnet['need_oxygen_burn'] = [0, 0.088, 0, 0, '#interesting', '#interesting', 0.029, 'breathe', 'minor_planet', 'human_memory', 'row_house', 'convenience_store']
senticnet['need_pee'] = [-0.901, 0, -0.831, 0, '#sad', '#scared', -0.577, 'important_message', 'alarm', 'alert', 'sensation', 'hear_noise']
senticnet['need_protect'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'bear', 'wild_animal', 'lion', 'nature', 'wild_life']
senticnet['need_relax'] = [0, 0, -0.943, -0.77, '#scared', '#disgusting', -0.571, 'need_rest', 'feel_tired', 'sleepiness', 'stress', 'feel_sleepy']
senticnet['need_rest'] = [-0.077, 0, -0.171, -0.059, '#sad', '#scared', -0.102, 'fall_asleep', 'doze_off', 'drowsiness', 'lack_of_sleep', 'feel_little_tired']
senticnet['need_shave'] = [0.036, 0, 0.094, -0.055, '#angry', '#disgusting', -0.038, 'unaesthetic', 'facial_hair', 'need_beauty_center', 'long_beard', 'carelessness']
senticnet['need_snacks'] = [-0.792, 0, -0.924, -0.708, '#sad', '#scared', -0.808, 'feel_weak', 'famine', 'feel_hunger', 'order_food', 'pain_in_stomach']
senticnet['need_to_buy'] = [0.055, 0.141, 0, 0.101, '#interesting', '#admirable', 0.099, 'need_buy', 'comparison_shop', 'buy_new', 'check_price', 'desire']
senticnet['need_to_rest'] = [-0.887, 0, 0, -0.891, '#sad', '#disgusting', -0.593, 'rest_up', 'sleepy', 'sleepiness', 'leg_tire', 'stop_activity']
senticnet['need_water'] = [0, 0.156, -0.128, 0.172, '#interesting', '#admirable', 0.067, 'get_big', 'get_large', 'growth', 'increase_size', 'enlarge']
senticnet['needful'] = [0, 0.324, 0.267, 0.345, '#interesting', '#admirable', 0.134, 'must', 'requirement', 'necessary', 'want_badly', 'essential']
senticnet['neediness'] = [0.067, 0.358, -0.249, 0.426, '#interesting', '#admirable', 0.201, 'need_care', 'need_help', 'consent', 'request', 'need_love']
senticnet['needle'] = [0, 0, 0.736, -0.89, '#angry', '#disgusting', -0.542, 'needle_thread', 'stitch', 'suture', 'pin', 'without_space']
senticnet['needle_blight'] = [-0.883, 0, 0.954, -0.875, '#sad', '#angry', -0.904, 'leaf_blight', 'needle_cast', 'leaf_cast', 'blight', 'fire_blight']
senticnet['needle_cast'] = [-0.883, 0, 0.954, -0.875, '#sad', '#angry', -0.904, 'needle_blight', 'leaf_blight', 'leaf_cast', 'blight', 'fire_blight']
senticnet['needle_prick'] = [-0.767, 0, 0.757, 0, '#sad', '#angry', -0.508, 'use_needle', 'clothes_repair', 'woven', 'embroidery', 'thread_needle']
senticnet['needle_thread'] = [-0.054, -0.012, 0.012, -0.101, '#sad', '#disgusting', -0.052, 'sew_term', 'use_needle', 'bandage', 'seam', 'stitch']
senticnet['needless'] = [-0.718, 0, 0.711, 0, '#sad', '#angry', -0.476, 'vain', 'unnecessary', 'idle', 'useless', 'pointless']
senticnet['needlework'] = [-0.038, 0, 0, -0.053, '#sad', '#disgusting', -0.03, 'needle_thread', 'use_needle', 'sew_term', 'sow', 'embroidery']
senticnet['needy'] = [-0.105, 0, -0.066, 0, '#sad', '#scared', -0.057, 'come_house', 'laugh_oneself', 'welcome_friend', 'captain_boat', 'receive_email']
senticnet['needy_person'] = [0, 0, -0.943, -0.77, '#scared', '#disgusting', -0.571, 'lost', 'need_help', 'need_know', 'ignorant', 'need_information']
senticnet['negate'] = [-0.618, 0, 0.723, -0.748, '#angry', '#disgusting', -0.696, 'controvert', 'refute', 'rebut', 'falsify', 'confute']
senticnet['negation'] = [-0.905, 0, 0.92, -0.968, '#angry', '#disgusting', -0.931, 'negative', 'bad', 'difficulty', 'cant', 'badness']
senticnet['negative'] = [-0.905, 0, 0.92, -0.968, '#angry', '#disgusting', -0.931, 'negation', 'bad', 'difficulty', 'cant', 'badness']
senticnet['negative_feeling'] = [-0.906, 0, 0.881, -0.843, '#sad', '#angry', -0.877, 'bad_feeling', 'feel_sorry', 'deep_sadness', 'lament', 'anguish']
senticnet['negative_reaction'] = [0, 0, 0.94, -0.88, '#angry', '#disgusting', -0.607, 'entertain', 'laugh', 'enjoy_show', 'eat_popcorn', 'negative_feeling']
senticnet['negative_reinforcer'] = [0.583, -0.826, 0, 0.574, '#joyful', '#surprising', 0.661, 'stimulant', 'positive_reinforcing_stimulus', 'positive_reinforcer', 'negative_reinforcing_stimulus', 'reinforcer']
senticnet['negative_reinforcing_stimulus'] = [0.583, -0.826, 0, 0.574, '#joyful', '#surprising', 0.661, 'stimulant', 'positive_reinforcing_stimulus', 'positive_reinforcer', 'reinforcer', 'negative_reinforcer']
senticnet['negative_response'] = [-0.91, 0, 0.969, -0.91, '#sad', '#angry', -0.93, 'negative', 'rude_reply', 'rude_answer', 'rude_person', 'rude_man']
senticnet['negative_stimulus'] = [-0.634, 0, 0.741, -0.611, '#sad', '#angry', -0.662, 'sorrow', 'pain_in_ass', 'pain', 'pain_in_neck', 'vexation']
senticnet['negativist'] = [-0.527, 0, 0.95, -0.788, '#angry', '#disgusting', -0.755, 'skeptic', 'sceptic', 'doubter', 'defeatist', 'pessimist']
senticnet['neglect'] = [-0.949, 0, 0.923, -0.984, '#sad', '#disgusting', -0.952, 'heap', 'push', 'accept', 'bring', 'lunge']
senticnet['neglect_chore'] = [-0.716, 0, 0.738, 0, '#sad', '#angry', -0.485, 'laugh', 'change_channel', 'distract', 'see_commercial', 'kill_brain_cell']
senticnet['neglected'] = [-0.774, 0, -0.93, 0, '#sad', '#scared', -0.568, 'pretermit', 'omit', 'drop', 'leave_out', 'miss']
senticnet['neglectful'] = [-0.569, 0, 0.743, -0.777, '#angry', '#disgusting', -0.696, 'negligent', 'derelict', 'inattentive', 'delinquent', 'lax']
senticnet['neglectfulness'] = [-0.936, 0, 0.624, -0.599, '#sad', '#angry', -0.72, 'carelessness', 'willful_neglect', 'laxness', 'laxity', 'remissness']
senticnet['negligence'] = [-0.691, 0, 0.516, -0.966, '#sad', '#disgusting', -0.724, 'criminal_negligence', 'culpable_negligence', 'evasion', 'dereliction', 'contributory_negligence']
senticnet['negligent'] = [-0.569, 0, 0.743, -0.777, '#angry', '#disgusting', -0.696, 'neglectful', 'derelict', 'inattentive', 'delinquent', 'lax']
senticnet['negligible'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'minor', 'unimportant', 'inessential', 'petty', 'trivial']
senticnet['negociate'] = [0.911, -0.714, 0, 0.552, '#joyful', '#surprising', 0.726, 'deliver_goods', 'succeed', 'win', 'bring_home_bacon', 'come_through']
senticnet['negotiable'] = [-0.996, 0, 0.641, -0.765, '#sad', '#disgusting', -0.801, 'navigable', 'passable', 'surmountable', 'climbable', 'traversable']
senticnet['negotiate'] = [-0.082, 0.27, -0.112, 0.14, '#interesting', '#admirable', 0.072, 'transact_business', 'make_profit', 'sell_stock', 'business_agreement', 'receive_money']
senticnet['negotiate_contract'] = [-0.037, 0.177, -0.077, 0.207, '#interesting', '#admirable', 0.09, 'buy_gas', 'ask_person', 'settle', 'economic_activity', 'ask_politely']
senticnet['negotiation'] = [-0.025, 0.188, -0.125, 0.192, '#interesting', '#admirable', 0.077, 'negotiate', 'receive_money', 'make_deal', 'monetary_gain', 'financial_transaction']
senticnet['negotiator'] = [0, 0.133, 0, 0.088, '#interesting', '#admirable', 0.074, 'juror', 'decide_guilt', 'become_judge', 'arbiter', 'jury']
senticnet['neigh'] = [0.027, 0.077, 0, 0.138, '#interesting', '#admirable', 0.081, 'hoof_mammal', 'hoof_animal', 'bovine', 'smart_animal', 'critter']
senticnet['neighbor'] = [0.07, 0.105, -0.07, 0.058, '#joyful', '#interesting', 0.054, 'neighborhood', 'resident', 'neighbour', 'ceiling_fan', 'tenant']
senticnet['neighbor_house'] = [0, 0, 0, -0.07, '#disgusting', '#disgusting', -0.023, 'downstairs', 'appliance_store', 'apartment', 'shack', 'motel_room']
senticnet['neighborhood'] = [0.07, 0.105, -0.07, 0.058, '#joyful', '#interesting', 0.054, 'neighbor', 'resident', 'neighbour', 'ceiling_fan', 'tenant']
senticnet['neighborhood_map'] = [0.087, 0.08, 0.013, 0, '#joyful', '#interesting', 0.051, 'map', 'billboard', 'underground_map', 'advertise_panel', 'restaurant_entrance']
senticnet['neighbour'] = [0.07, 0.105, -0.07, 0.058, '#joyful', '#interesting', 0.054, 'neighborhood', 'resident', 'neighbor', 'ceiling_fan', 'tenant']
senticnet['nelfinavir'] = [-0.818, 0, 0.767, -0.936, '#sad', '#disgusting', -0.84, 'antiviral', 'indinavir', 'protease_inhibitor', 'ritonavir', 'saquinavir']
senticnet['neonate'] = [-0.514, 0, 0.747, -0.944, '#angry', '#disgusting', -0.735, 'stillborn_infant', 'premature_baby', 'preterm_baby', 'premature_infant', 'preterm_infant']
senticnet['neophyte'] = [0, 0, -0.983, -0.891, '#scared', '#disgusting', -0.625, 'freshman', 'newcomer', 'starter', 'fledgeling', 'entrant']
senticnet['nephritis'] = [-0.848, 0, 0.608, -0.523, '#sad', '#angry', -0.66, 'glomerulonephritis', 'nephrosis', 'kidney_disease', 'renal_disorder', 'nephropathy']
senticnet['nephropathy'] = [0.676, -0.762, 0, 0.801, '#surprising', '#admirable', 0.746, 'uropathy', 'polyuria', 'polycystic_kidney_disease', 'renal_failure', 'kidney_failure']
senticnet['nephrosis'] = [-0.603, 0, 0.544, -0.539, '#sad', '#angry', -0.562, 'acute_renal_failure', 'acute_kidney_failure', 'chronic_renal_failure', 'chronic_kidney_failure', 'kidney_failure']
senticnet['nerd'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'geek', 'book_worm', 'loser', 'underdog', 'computer_lover']
senticnet['nerve'] = [0.021, 0, -0.054, -0.035, '#scared', '#disgusting', -0.023, 'liver', 'pancreas', 'two_eyes', 'forehead', 'diaphragm']
senticnet['nerve_agent'] = [-0.903, 0, 0.529, -0.842, '#sad', '#disgusting', -0.758, 'nerve_gas', 'poison_gas', 'mustard_gas', 'mustard_agent', 'blistering_agent']
senticnet['nerve_gas'] = [-0.903, 0, 0.529, -0.842, '#sad', '#disgusting', -0.758, 'poison_gas', 'nerve_agent', 'mustard_gas', 'mustard_agent', 'blistering_agent']
senticnet['nerve_pathway'] = [0.683, -0.918, 0, 0.679, '#joyful', '#surprising', 0.76, 'pathway', 'corpus_callosum', 'commissure', 'tract', 'nerve_tract']
senticnet['nerve_tract'] = [0.683, -0.918, 0, 0.679, '#joyful', '#surprising', 0.76, 'pathway', 'corpus_callosum', 'nerve_pathway', 'tract', 'commissure']
senticnet['nerveless'] = [-0.95, 0, 0.708, -0.649, '#sad', '#angry', -0.769, 'helpless', 'incapacitated', 'feeble', 'weak', 'powerless']
senticnet['nerveroot'] = [0.277, 0.161, 0, 0.337, '#joyful', '#admirable', 0.258, 'moccasin_flower', 'ladies_slipper', 'showy_lady_slipper', 'yellow_lady_slipper', 'clustered_lady_slipper']
senticnet['nerves'] = [-0.729, 0, 0.526, -0.63, '#sad', '#disgusting', -0.628, 'mental_strain', 'nervous_strain', 'strain', 'jitters', 'screaming_meemies']
senticnet['nervous'] = [0, 0, 0.926, 0, '#angry', '#angry', -0.309, 'nervousness', 'stage_fright', 'embarrassment', 'upset', 'impatient']
senticnet['nervous_breakdown'] = [-0.075, 0, -0.133, 0, '#sad', '#scared', -0.069, 'check_vital_sign', 'know_healthy', 'physical_exam', 'examination', 'epileptic_fit']
senticnet['nervous_strain'] = [-0.649, 0, 0.782, -0.643, '#sad', '#angry', -0.691, 'nervousness', 'tenseness', 'tension', 'nerves', 'stress']
senticnet['nervous_system'] = [-0.042, 0.077, -0.092, -0.08, '#scared', '#disgusting', -0.046, 'body', 'inside_body', 'normal_human_body', 'dead_person', 'corpse']
senticnet['nervousness'] = [0, 0, 0.941, 0, '#angry', '#angry', -0.314, 'embarrassment', 'nervous', 'shame', 'worry', 'angst']
senticnet['nervy'] = [-0.864, 0, -0.727, 0, '#sad', '#scared', -0.53, 'high-strung', 'uptight', 'restive', 'overstrung', 'jumpy']
senticnet['nest'] = [0.831, 0.98, 0, 0, '#joyful', '#interesting', 0.604, 'atmosphere', 'wings', 'bird_fly', 'feather', 'flight']
senticnet['nest_table'] = [0.805, 0.851, 0, 0, '#joyful', '#interesting', 0.552, 'cork', 'rod', 'beam', 'wand', 'i-beam']
senticnet['nestle'] = [0.995, -0.698, 0, 0.528, '#joyful', '#surprising', 0.74, 'grasp', 'hug', 'embracement', 'snuggle', 'grip']
senticnet['net'] = [0, -0.042, 0.113, -0.047, '#angry', '#disgusting', -0.039, 'reel', 'fish_rod', 'swimsuit', 'volleyball', 'fish_pole']
senticnet['net_income'] = [0.685, -0.58, 0, 0.56, '#joyful', '#surprising', 0.608, 'profit', 'fast_buck', 'net', 'net_profit', 'lucre']
senticnet['net_profit'] = [0.685, -0.58, 0, 0.56, '#joyful', '#surprising', 0.608, 'profit', 'net_income', 'net', 'fast_buck', 'lucre']
senticnet['nether_region'] = [-0.72, 0, 0.759, -0.548, '#sad', '#angry', -0.676, 'hellfire', 'red_region', 'imaginary_place', 'mythical_place', 'fictitious_place']
senticnet['nettle'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['nettle_rash'] = [-0.634, 0, 0.591, -0.873, '#sad', '#disgusting', -0.699, 'hypersensitivity_reaction', 'rash', 'efflorescence', 'roseola', 'skin_rash']
senticnet['nettled'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['nettlesome'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['network'] = [0.808, -0.793, 0, 0, '#joyful', '#surprising', 0.534, 'get_to_know_person', 'get_know', 'get_together_friend', 'social_interaction', 'meet_new_person']
senticnet['neuralgia'] = [-0.547, 0, 0.543, -0.63, '#sad', '#disgusting', -0.573, 'hurting', 'pain', 'trigeminal_neuralgia', 'tic_douloureux', 'sciatica']
senticnet['neuralgy'] = [-0.648, 0, 0.924, -0.791, '#angry', '#disgusting', -0.788, 'hurting', 'pain', 'trigeminal_neuralgia', 'tic_douloureux', 'sciatica']
senticnet['neurasthenic'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'bad_tempered', 'nervous', 'cranky', 'irritable', 'testy']
senticnet['neuritis'] = [-0.652, 0, 0.873, -0.637, '#sad', '#angry', -0.721, 'polyneuritis', 'multiple_neuritis', 'rubor', 'redness', 'inflammation']
senticnet['neurosis'] = [-0.788, 0, 0.542, -0.711, '#sad', '#disgusting', -0.68, 'hysterical_neurosis', 'hysteria', 'mental_disorder', 'mental_disturbance', 'psychological_disorder']
senticnet['neurotic'] = [0, 0, -0.736, -0.847, '#scared', '#disgusting', -0.528, 'make_look_good', 'tidy_up', 'expect_guest', 'neatness', 'neat']
senticnet['neuroticism'] = [-0.896, 0, 0.706, -0.768, '#sad', '#disgusting', -0.79, 'hysterical_neurosis', 'hysteria', 'mental_disorder', 'mental_disturbance', 'psychological_disorder']
senticnet['neuter'] = [-0.035, -0.03, 0.094, -0.058, '#angry', '#disgusting', -0.052, 'eight_legs', 'itch', 'scratch', 'nip', 'rash']
senticnet['neutered'] = [0.945, -0.861, 0, 0.802, '#joyful', '#surprising', 0.869, 'cut', 'altered', 'castrated', 'emasculated', 'gelded']
senticnet['neutral'] = [-0.902, 0, 0.859, -0.958, '#sad', '#disgusting', -0.906, 'mortal', 'stakeholder', 'person', 'individual', 'someone']
senticnet['neutron'] = [0, 0.768, 0, 0.745, '#interesting', '#admirable', 0.504, 'proton', 'proton_neutron', 'electron', 'lepton', 'subatomic_particle']
senticnet['neutrophil'] = [0.772, -0.561, 0, 0.824, '#joyful', '#admirable', 0.719, 'microphage', 'leukocyte', 'leucocyte', 'white_blood_cell', 'white_cell']
senticnet['neutrophile'] = [0.566, -0.729, 0, 0.528, '#joyful', '#surprising', 0.608, 'microphage', 'leukocyte', 'leucocyte', 'white_blood_cell', 'white_cell']
senticnet['never_die'] = [0, 0, 0, 0.816, '#admirable', '#admirable', 0.272, 'immortality', 'live_forever', 'immortal', 'eternal_life', 'everlasting_life']
senticnet['never_end'] = [0, 0.117, -0.055, 0.18, '#interesting', '#admirable', 0.081, 'unending', 'constant', 'frequently', 'previous', 'calendar_event']
senticnet['never_ending'] = [0, 0.141, 0, 0.185, '#interesting', '#admirable', 0.109, 'infinity', 'interval', 'infinite', 'all_of_it', 'dimension']
senticnet['never_fail'] = [0.025, 0.237, -0.073, 0.297, '#interesting', '#admirable', 0.162, 'ready', 'efficient', 'get_ready', 'preparedness', 'born_ready']
senticnet['never_go_out'] = [0.11, 0.209, 0, 0.238, '#interesting', '#admirable', 0.186, 'use_condom', 'abstinence', 'prevent_conception', 'gnaw', 'choke']
senticnet['never_stop'] = [0, 0.338, -0.162, 0.355, '#interesting', '#admirable', 0.177, 'redo', 'inclusion', 'repeatedly', 'again_and_again', 'repeat']
senticnet['new'] = [0.047, 0.171, -0.107, 0.212, '#interesting', '#admirable', 0.108, 'novelty', 'relevant', 'contemporary', 'timely', 'never_end']
senticnet['new_baby'] = [0.758, 0.773, 0, 0, '#joyful', '#interesting', 0.51, 'party_time', 'holiday', 'annual_celebration', 'birthday', 'special_day']
senticnet['new_beginning'] = [0, -0.289, -0.114, 0.258, '#surprising', '#admirable', 0.144, 'change', 'quick_change', 'surprise', 'change_quickly', 'wow']
senticnet['new_buildings'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'traffic_rule', 'develop_city', 'bicycle_area', 'good_transportation', 'control_road']
senticnet['new_caledonia'] = [-0.029, 0.075, 0, 0.059, '#interesting', '#admirable', 0.035, 'human_memory', 'transportation_device', 'courthouse_look_public_record', 'minor_planet', 'poo']
senticnet['new_car'] = [0.914, 0.774, 0, 0, '#joyful', '#interesting', 0.563, 'steal_car', 'find_wallet', 'make_sure_enough_money', 'take_money', 'find_shop']
senticnet['new_chapter'] = [0, 0.276, -0.138, 0.309, '#interesting', '#admirable', 0.149, 'end_point', 'start', 'commence', 'inclusion', 'start_adventure']
senticnet['new_computer'] = [0.819, 0.841, 0, 0, '#joyful', '#interesting', 0.553, 'computer', 'browser', 'calculator', 'efficient', 'gift']
senticnet['new_criticism'] = [0.587, -0.948, 0, 0.659, '#surprising', '#admirable', 0.731, 'critique', 'review', 'explication_de_texte', 'textual_criticism', 'literary_criticism']
senticnet['new_experience'] = [0.731, 0.772, 0, 0, '#joyful', '#interesting', 0.501, 'learn_foreign_language', 'open_mind', 'study_history', 'learn_new_language', 'gain_experience']
senticnet['new_friendship'] = [0.971, 0.751, 0, 0.896, '#joyful', '#admirable', 0.873, 'arousal', 'foreplay', 'warm_fuzzy_feeling', 'become_aroused', 'erection']
senticnet['new_hair_style'] = [0.034, 0, 0, 0.085, '#joyful', '#admirable', 0.04, 'new_style', 'hair_long', 'feel_stylish', 'haircut', 'change_hair_style']
senticnet['new_hairstyle'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'new_life', 'new_look', 'go_to_hairdresser', 'go_get_haircut', 'change_clothes']
senticnet['new_home'] = [-0.03, 0.091, 0, 0.154, '#interesting', '#admirable', 0.072, 'small_home', 'live_place', 'inhabitant', 'medieval', 'place_where_people_live']
senticnet['new_house'] = [-0.067, 0.121, 0, 0.098, '#interesting', '#admirable', 0.051, 'build_bridge', 'build_house', 'build_wall', 'build_home', 'construct']
senticnet['new_idea'] = [0.866, 0.821, 0, 0, '#joyful', '#interesting', 0.562, 'epiphany', 'new_insight', 'come_conclusion', 'revelation', 'brain_storm']
senticnet['new_information'] = [0.76, -0.608, 0, 0.881, '#joyful', '#admirable', 0.75, 'change_attitude', 'laugh', 'share_knowledge', 'need_information', 'maintain_relationship']
senticnet['new_insight'] = [0.76, -0.608, 0, 0.881, '#joyful', '#admirable', 0.75, 'know_fact', 'broaden_horizon', 'open_mind', 'new_idea', 'lifestyle_change']
senticnet['new_job'] = [0, 0.106, -0.091, 0.092, '#interesting', '#admirable', 0.036, 'question_ask', 'resume', 'job_offer', 'ask_nicely', 'obligation']
senticnet['new_knowledge'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'education', 'broaden_horizon', 'comprehend', 'expand_knowledge', 'accumulate_knowledge']
senticnet['new_law'] = [0, -0.831, 0, 0.768, '#surprising', '#admirable', 0.533, 'witness', 'appeal', 'make_judgment', 'court_action', 'contact_lawyer']
senticnet['new_life'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'holiday', 'discover_world', 'new_experience', 'foreign_country', 'travel']
senticnet['new_look'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'new_life', 'new_hairstyle', 'go_to_hairdresser', 'go_get_haircut', 'change_clothes']
senticnet['new_movie'] = [0.952, -0.883, 0, 0, '#joyful', '#surprising', 0.612, 'satire', 'game_toy', 'stage_curtain', 'thespian', 'open_night']
senticnet['new_person'] = [0, 0.989, 0, 0.84, '#interesting', '#admirable', 0.61, 'newbie', 'matrimony', 'contrary', 'inquisitive', 'likely_discover_truth']
senticnet['new_perspective'] = [-0.074, -0.028, 0.035, -0.197, '#sad', '#disgusting', -0.093, 'insight', 'new_insight', 'solution_to_problem', 'new_idea', 'open_mind']
senticnet['new_relationship'] = [0.77, 0.742, 0, 0, '#joyful', '#interesting', 0.504, 'happy_time', 'annual_celebration', 'love_each_other', 'retirement', 'party_time']
senticnet['new_stuff'] = [-0.058, 0.106, 0, 0.06, '#interesting', '#admirable', 0.036, 'buy_new', 'buy', 'buy_happiness', 'buy_new_car', 'buy_new_game']
senticnet['new_style'] = [0.034, 0, 0, 0.085, '#joyful', '#admirable', 0.04, 'fancy_car', 'hair_long', 'new_hair_style', 'haircut', 'change_hair_style']
senticnet['new_think'] = [-0.078, 0.199, -0.049, 0.109, '#interesting', '#admirable', 0.06, 'eureka', 'idea', 'brain_activity', 'brain_function', 'make_right_decision']
senticnet['new_world'] = [0.048, 0.181, -0.058, 0.175, '#interesting', '#admirable', 0.115, 'type_of_government', 'form_government', 'political_system', 'unite', 'united_country']
senticnet['new_york_city'] = [-0.024, -0.005, -0.049, 0, '#sad', '#scared', -0.023, 'medikit', 'manchester', 'ghetto', 'metropolitan_city', 'medical_build']
senticnet['newbie'] = [0, 0, 0.781, -0.891, '#angry', '#disgusting', -0.557, 'stupid', 'idiot', 'dummy', 'idiotic', 'dumb']
senticnet['newborn'] = [-0.973, 0, 0.977, -0.937, '#sad', '#angry', -0.962, 'stillborn_infant', 'premature_baby', 'preterm_baby', 'premature_infant', 'preterm_infant']
senticnet['newborn_baby'] = [-0.048, 0, 0.029, 0, '#sad', '#angry', -0.026, 'little_baby', 'nostalgic', 'baby', 'blind_person', 'youth']
senticnet['newlywed'] = [0.54, -0.569, 0, 0.981, '#surprising', '#admirable', 0.697, 'bride', 'groom', 'bridegroom', 'spouse', 'partner']
senticnet['news'] = [0.088, -0.003, 0, 0, '#joyful', '#surprising', 0.03, 'look_up_information', 'find_newspaper', 'headlines', 'enter_contest', 'latest_find_newspaper']
senticnet['news_paper'] = [0.074, 0.114, 0, 0.126, '#interesting', '#admirable', 0.105, 'paragraph', 'newspaper_write', 'index', 'newspaper_story', 'chapter']
senticnet['news_reporter'] = [-0.066, -0.016, -0.104, -0.16, '#scared', '#disgusting', -0.105, 'buy_weapon', 'buy_gun', 'explosive_device', 'join_military', 'aerial_bomb']
senticnet['news_story'] = [0, 0.81, 0, 0.746, '#interesting', '#admirable', 0.519, 'part_of_speech', 'word', 'ideograph', 'vowel', 'alphabet']
senticnet['newscaster'] = [0.101, 0.332, -0.187, 0.303, '#interesting', '#admirable', 0.183, 'tell_everyone', 'courtesy', 'request', 'identify', 'mutual_understand']
senticnet['newsfeed'] = [0, 0.772, 0, 0.906, '#interesting', '#admirable', 0.559, 'headline', 'bulletin', 'paper_write', 'world_event', 'current_event']
senticnet['newspaper'] = [-0.058, 0.106, 0, 0.06, '#interesting', '#admirable', 0.036, 'buy', 'buy_newspaper', 'read_buy_newspaper', 'buy_book', 'read_news']
senticnet['newspaper_article'] = [0.021, 0, 0, 0.076, '#joyful', '#admirable', 0.032, 'newspaper_story', 'newspaper_write', 'magazine_newspaper', 'article', 'editorial']
senticnet['newspaper_stand'] = [0.821, -0.817, 0, 0, '#joyful', '#surprising', 0.546, 'aircraft_roadway', 'taxiway', 'runway', 'flight_terminal', 'ticket_counter']
senticnet['newspaper_story'] = [0.074, 0.114, 0, 0.126, '#interesting', '#admirable', 0.105, 'paragraph', 'newspaper_write', 'news_paper', 'index', 'chapter']
senticnet['newspaper_write'] = [0, 0.077, 0, 0.068, '#interesting', '#admirable', 0.048, 'make_book', 'file', 'paper_write', 'readable', 'document']
senticnet['newsreel'] = [0.789, -0.518, 0, 0.947, '#joyful', '#admirable', 0.751, 'flick', 'cartoon', 'animated_cartoon', 'toon', 'short_subject']
senticnet['newsstand'] = [0, 0, 0, -0.069, '#disgusting', '#disgusting', -0.023, 'soda_machine', 'bookshop', 'walmart', 'shoe_store', 'hooker']
senticnet['newsworthiness'] = [0.509, -0.678, 0, 0.707, '#surprising', '#admirable', 0.631, 'color', 'interestingness', 'shrillness', 'vividness', 'charisma']
senticnet['newton'] = [-0.641, 0, 0.678, -0.705, '#angry', '#disgusting', -0.675, 'pound', 'dyne', 'force_unit', 'sthene', 'poundal']
senticnet['newyork'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'big_city', 'london', 'beijing', 'rome', 'tokyo']
senticnet['next'] = [0, 0, -0.739, -0.968, '#scared', '#disgusting', -0.569, 'side_by_side', 'succeeding', 'following', 'adjacent', 'future']
senticnet['next_door'] = [0, 0, 0, 0.074, '#admirable', '#admirable', 0.025, 'next_house', 'corridor', 'home_entrance', 'glass_front', 'use_farm']
senticnet['next_episode'] = [-0.063, 0.122, -0.046, 0.113, '#interesting', '#admirable', 0.042, 'encounter', 'portray', 'reveal', 'episode', 'sequel']
senticnet['next_house'] = [0, 0, 0, 0.086, '#admirable', '#admirable', 0.029, 'next_door', 'glass_front', 'corridor', 'door', 'home_entrance']
senticnet['next_level'] = [0.795, 0, 0, 0.927, '#joyful', '#admirable', 0.574, 'yardstick', 'level', 'scale', 'measure_tool', 'same_level']
senticnet['ngo'] = [-0.549, 0, 0.863, -0.76, '#angry', '#disgusting', -0.724, 'denomination', 'committee', 'citizens_committee', 'mission', 'missionary_post']
senticnet['nibble'] = [-0.091, -0.039, 0.066, -0.128, '#sad', '#disgusting', -0.082, 'bell_cat', 'order_pizza', 'eat_snack', 'digest', 'eat_pudding']
senticnet['nice'] = [0.147, 0.126, -0.096, 0.314, '#joyful', '#admirable', 0.164, 'lovely', 'niceness', 'good', 'pleasant', 'capitalize']
senticnet['nice_clothes'] = [0.928, 0.778, 0, 0, '#joyful', '#interesting', 0.569, 'change_clothes', 'put_clean_clothes', 'put_nice_clothes', 'take_shower_bath', 'take_shower']
senticnet['nice_day'] = [0.09, 0.129, -0.047, 0.102, '#interesting', '#admirable', 0.091, 'block_sun', 'no_sun', 'over_head', 'sun_cover', 'weather_forecast']
senticnet['nice_dog'] = [0.887, 0, 0, 0.941, '#joyful', '#admirable', 0.609, 'hold_puppy', 'dog', 'domesticate_dog', 'hold_dog', 'domesticate_animal']
senticnet['nice_eat'] = [0.06, 0, 0.038, 0.104, '#joyful', '#admirable', 0.042, 'eatable', 'yummy', 'bake_product', 'sweet_food', 'starchy_food']
senticnet['nice_ending'] = [0.801, 0.779, 0, 0, '#joyful', '#interesting', 0.527, 'child_book', 'interesting_story', 'something_to_tell', 'scholar', 'good_story']
senticnet['nice_environment'] = [0.561, 0.575, 0, 0.763, '#interesting', '#admirable', 0.633, 'go_green', 'better_world', 'live', 'religious_experience', 'good_health']
senticnet['nice_gesture'] = [0.948, 0, 0, 0.913, '#joyful', '#admirable', 0.62, 'celebrate_anniversary', 'show_affection', 'show_love', 'make_happy', 'jump_out']
senticnet['nice_house'] = [0.169, 0.114, 0, 0.168, '#joyful', '#admirable', 0.15, 'dwell_place', 'place_to_live', 'domestic_dwell', 'domicile', 'live_place']
senticnet['nice_look'] = [0.944, 0.792, 0, 0, '#joyful', '#interesting', 0.579, 'gorgeous', 'good_look', 'lovely', 'pretty', 'attractive']
senticnet['nice_meal'] = [0.796, 0.851, 0, 0, '#joyful', '#interesting', 0.549, 'hungry', 'delicious_food', 'fast_food', 'meal', 'snack']
senticnet['nice_person'] = [0.754, 0.899, 0, 0, '#joyful', '#interesting', 0.551, 'call_doctor', 'doctor_patient', 'medical_person', 'medical', 'trustworthy']
senticnet['nice_place_to_live'] = [0.361, 0.23, -0.05, 0.359, '#joyful', '#admirable', 0.3, 'live_long_healthy_life', 'complement', 'live_ripe_old_age', 'long_lifespan', 'live_well']
senticnet['nice_smell'] = [0.992, 0.78, 0, 0, '#joyful', '#interesting', 0.591, 'savor', 'make_toast', 'good_smell', 'snack', 'create_food']
senticnet['nice_smile'] = [0.106, 0.162, 0.037, 0.32, '#interesting', '#admirable', 0.184, 'clean_tooth', 'smile', 'healthy', 'good_looking', 'sexy']
senticnet['nice_view'] = [0.034, 0.13, -0.083, 0.258, '#interesting', '#admirable', 0.113, 'tourism', 'big_monument', 'tourist_attraction', 'temple', 'sightsee']
senticnet['nice_walk'] = [0.993, 0.727, 0, 0, '#joyful', '#interesting', 0.573, 'nature', 'enjoy_view', 'relax_moment', 'enjoy_nature', 'enjoy_life']
senticnet['nice_weather'] = [0.807, 0.773, 0, 0, '#joyful', '#interesting', 0.527, 'warm_weather', 'hot_weather', 'go_jogging', 'hot_day', 'good_exercise']
senticnet['niceness'] = [0.12, 0.254, -0.204, 0.354, '#interesting', '#admirable', 0.175, 'good', 'good_etiquette', 'similarity', 'nice', 'important']
senticnet['nickel'] = [0, 0.172, 0.034, 0.151, '#interesting', '#admirable', 0.096, 'dense_water', 'smooth_surface', 'head_tail', 'round_metal', 'shinny']
senticnet['nicknack'] = [0.833, -0.838, 0, 0.923, '#surprising', '#admirable', 0.865, 'curio', 'oddity', 'curiosity', 'peculiarity', 'oddment']
senticnet['nickname'] = [0.072, 0.244, -0.202, 0.252, '#interesting', '#admirable', 0.122, 'doe', 'live_object', 'live_organism', 'descriptive_term', 'alive']
senticnet['nicotine'] = [-0.897, 0, -0.831, 0, '#sad', '#scared', -0.576, 'tobacco', 'cigar', 'cigarette_smoke', 'tobacco_product', 'cigarette']
senticnet['nictitating_membrane'] = [-0.79, 0, 0.769, -0.798, '#sad', '#disgusting', -0.786, 'flap', 'eyelid', 'lid', 'palpebra', 'protective_fold']
senticnet['niece'] = [0, 0.887, 0, 0.906, '#interesting', '#admirable', 0.598, 'female_human', 'female_person', 'damsel', 'female', 'woman']
senticnet['niff'] = [-0.741, 0, 0.579, -0.977, '#sad', '#disgusting', -0.766, 'malodor', 'stench', 'stink', 'fetor', 'bad_smell']
senticnet['nifty'] = [0.876, 0.733, 0, 0, '#joyful', '#interesting', 0.536, 'bang-up', 'dandy', 'corking', 'cracking', 'bully']
senticnet['niggle'] = [-0.692, 0, 0.768, -0.671, '#sad', '#angry', -0.71, 'dither', 'pother', 'worry', 'flap', 'scruple']
senticnet['nigh'] = [0.653, 0.646, -0.242, 0.31, '#joyful', '#interesting', 0.456, 'comfortably', 'comfortableness', 'solace', 'belonging', 'elating']
senticnet['night'] = [-0.775, 0, -0.861, 0, '#sad', '#scared', -0.545, 'blackness', 'blackout', 'darkness', 'dark', 'obscure']
senticnet['night_blindness'] = [-0.821, 0, 0.996, -0.613, '#sad', '#angry', -0.81, 'visual_impairment', 'visual_defect', 'vision_defect', 'visual_disorder', 'avitaminosis']
senticnet['night_club'] = [-0.901, 0, 0.848, -0.944, '#sad', '#disgusting', -0.898, 'cabaret', 'nightclub', 'dive', 'club', 'nightspot']
senticnet['night_dress'] = [0.859, 0, 0, 0.91, '#joyful', '#admirable', 0.59, 'woman_dress', 'item_clothes', 'fancy_dress', 'piece_of_clothing', 'robe']
senticnet['night_shift'] = [-0.077, 0, -0.171, -0.059, '#sad', '#scared', -0.102, 'feel_sleepy', 'drowsiness', 'drink_coffee', 'need_rest', 'feel_little_tired']
senticnet['night_sun'] = [0.032, 0.134, 0, 0.105, '#interesting', '#admirable', 0.09, 'blackness', 'around_earth', 'star_planet', 'outer', 'void']
senticnet['night_time'] = [-0.083, 0, -0.045, 0, '#sad', '#scared', -0.043, 'get_dark', 'dark_outside', 'day_end', 'sundown', 'dusk']
senticnet['night_vision'] = [0, 0.214, -0.115, 0.137, '#interesting', '#admirable', 0.079, 'imaginative', 'hallucinate', 'lucid', 'fantasy', 'dream']
senticnet['nightclub'] = [0.84, -0.76, 0, 0, '#joyful', '#surprising', 0.533, 'pub', 'disco', 'dance_club', 'cafe', 'tavern']
senticnet['nightfall'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'dusk', 'day_end', 'sundown', 'sunset', 'twilight']
senticnet['nightgown'] = [0.032, 0.075, 0, 0, '#joyful', '#interesting', 0.036, 'apparel', 'garment', 'clothes', 'dress', 'shirt']
senticnet['nightingale'] = [0.039, 0.089, -0.081, 0.143, '#interesting', '#admirable', 0.063, 'hen', 'jay', 'stork', 'bird', 'rooster']
senticnet['nightly_ritual'] = [-0.032, 0, -0.056, 0, '#sad', '#scared', -0.029, 'rabbit', 'squirrel', 'mole', 'chipmunk', 'nymph']
senticnet['nightmare'] = [-0.088, 0, -0.049, -0.155, '#sad', '#disgusting', -0.097, 'unsettle', 'sleepwalk', 'hallucinate', 'get_rest', 'reflect']
senticnet['nightspot'] = [-0.901, 0, 0.848, -0.944, '#sad', '#disgusting', -0.898, 'cabaret', 'nightclub', 'night_club', 'club', 'dive']
senticnet['nihil'] = [-0.957, 0, 0.653, -0.834, '#sad', '#disgusting', -0.815, 'null', 'zero', 'naught', 'zip', 'nothing']
senticnet['nihilism'] = [-0.502, 0, 0.641, -0.899, '#angry', '#disgusting', -0.681, 'delusions_of_persecution', 'hallucination', 'delusions_of_grandeur', 'nihilistic_delusion', 'delusion']
senticnet['nihilistic_delusion'] = [-0.502, 0, 0.641, -0.899, '#angry', '#disgusting', -0.681, 'delusions_of_persecution', 'hallucination', 'delusions_of_grandeur', 'delusion', 'nihilism']
senticnet['nil'] = [0.027, 0.102, 0.081, 0.16, '#interesting', '#admirable', 0.069, 'zero', 'nothing', 'empty', 'void', 'null']
senticnet['nile'] = [0, 0.068, 0, 0.142, '#interesting', '#admirable', 0.07, 'water_stream', 'water_formation', 'small_stream', 'water_flow', 'flow_lake']
senticnet['nimble_finger'] = [-0.079, 0, 0.065, -0.052, '#sad', '#angry', -0.065, 'language_skill', 'learn_how', 'use_finger', 'debug', 'use_keyboard']
senticnet['nimby'] = [-0.931, 0, 0.688, -0.631, '#sad', '#angry', -0.75, 'dissident', 'dissenter', 'protester', 'objector', 'contestant']
senticnet['ninepenny'] = [0.753, -0.945, 0, 0.965, '#surprising', '#admirable', 0.888, 'threepenny', 'size', 'eightpenny', 'fourpenny', 'sized']
senticnet['ninety_degree'] = [0.07, 0.106, 0.026, 0.187, '#interesting', '#admirable', 0.112, 'left_right', 'rotate', 'sharpness', 'around_corner', 'go_around']
senticnet['ninja'] = [0.021, -0.067, 0, 0, '#joyful', '#surprising', 0.029, 'plastic_bottle', 'party', 'use_party', 'lighter_air', 'compress_air']
senticnet['nip'] = [-0.038, -0.084, 0.09, -0.136, '#angry', '#disgusting', -0.06, 'bite', 'sting', 'flea', 'muzzle', 'tidbit']
senticnet['nip_and_tuck'] = [-0.642, 0, 0.576, -0.83, '#sad', '#disgusting', -0.683, 'nisi', 'indeterminate', 'equivocal', 'neck_and_neck', 'inconclusive']
senticnet['nipple'] = [0.147, 0.126, -0.096, 0.314, '#joyful', '#admirable', 0.164, 'bone', 'backbone', 'leave_leg', 'thigh', 'scrotum']
senticnet['nipple_shield'] = [-0.666, 0, 0.947, -0.887, '#angry', '#disgusting', -0.833, 'protective_cover', 'protective_covering', 'scale', 'protection', 'shield']
senticnet['nirvana'] = [0.876, 0.984, 0, 0, '#joyful', '#interesting', 0.62, 'eden', 'peace', 'peacemaker', 'haze', 'fog']
senticnet['nisi'] = [-0.642, 0, 0.576, -0.83, '#sad', '#disgusting', -0.683, 'inconclusive', 'indeterminate', 'equivocal', 'neck_and_neck', 'nip_and_tuck']
senticnet['nit'] = [-0.034, -0.053, 0.098, -0.098, '#angry', '#disgusting', -0.059, 'gnat', 'ladybug', 'flea', 'mite', 'louse']
senticnet['nitrate'] = [-0.886, 0, 0.87, -0.761, '#sad', '#angry', -0.839, 'cellulose_ester', 'pyroxylin', 'pyroxyline', 'pyrocellulose', 'cellulose_nitrate']
senticnet['nitrocellulose'] = [-0.558, 0, 0.525, -0.725, '#sad', '#disgusting', -0.603, 'cellulose_ester', 'pyroxylin', 'pyroxyline', 'pyrocellulose', 'nitrate']
senticnet['nitrocotton'] = [-0.953, 0, 0.699, -0.597, '#sad', '#angry', -0.75, 'cellulose_ester', 'pyroxylin', 'pyroxyline', 'pyrocellulose', 'nitrate']
senticnet['nitrogen_triiodide'] = [-0.947, 0, 0.906, -0.998, '#sad', '#disgusting', -0.95, 'dangerous', 'danger', 'kill_person', 'poison', 'kill']
senticnet['no_choice'] = [-0.076, 0.075, -0.179, 0, '#sad', '#scared', -0.06, 'protect_family', 'flaw', 'protect_oneself', 'expire', 'kill_self']
senticnet['no_color'] = [0.833, 0.927, 0, 0, '#joyful', '#interesting', 0.587, 'clarity', 'transparency', 'sunny_weather', 'intelligent', 'water_color']
senticnet['no_corner'] = [0, 0.765, 0, 0.733, '#interesting', '#admirable', 0.499, 'round', 'circular_shape', 'circle_shape', 'circle', 'circular']
senticnet['no_doubt'] = [0, 0.105, 0, 0, '#interesting', '#interesting', 0.035, 'boss', 'visitor', 'business_man', 'defendant', 'dolt']
senticnet['no_edge'] = [0, 0.741, 0, 0.751, '#interesting', '#admirable', 0.497, 'no_corner', 'circle_shape', 'round_shape', 'circular', 'circular_shape']
senticnet['no_effort'] = [-0.057, -0.043, 0.054, -0.077, '#sad', '#disgusting', -0.048, 'turn_off_alarm_clock', 'take_sleep_pill', 'lie_down_close_eye', 'lie_down_bed', 'count_sheep']
senticnet['no_end'] = [-0.965, 0, -0.958, 0, '#sad', '#scared', -0.641, 'dead', 'sentence_end', 'reason_why', 'negative', 'dead_stay_dead']
senticnet['no_exercise'] = [-0.969, 0, 0.212, -0.926, '#sad', '#disgusting', -0.702, 'unhealthy_food', 'eat_too_much', 'greasy_food', 'fast_food', 'fat_person']
senticnet['no_fun'] = [0.029, 0, 0.011, 0.109, '#joyful', '#admirable', 0.042, 'talkative', 'japanese', 'verbal', 'discourse', 'orate']
senticnet['no_hair'] = [0, -0.011, 0.044, -0.069, '#angry', '#disgusting', -0.034, 'hair', 'two_eyes', 'fur_keep_warm', 'hold_hair', 'facial_hair']
senticnet['no_light'] = [0, 0, -0.922, -0.919, '#scared', '#disgusting', -0.614, 'block_sunlight', 'dark_area', 'cover_window', 'block_road', 'no_sun']
senticnet['no_long_hungry'] = [-0.159, -0.051, -0.083, -0.125, '#sad', '#disgusting', -0.105, 'tongue', 'choke', 'bite_tongue', 'spill', 'digest']
senticnet['no_man_land'] = [0.738, -0.855, 0, 0.89, '#surprising', '#admirable', 0.828, 'evasiveness', 'twilight_zone', 'prevarication', 'equivocalness', 'unclearness']
senticnet['no_mercy'] = [-0.103, 0, -0.065, 0, '#sad', '#scared', -0.056, 'violent', 'beat', 'beat_violently', 'thrash', 'thief']
senticnet['no_noise'] = [0.268, 0.199, -0.123, 0, '#joyful', '#interesting', 0.115, 'peace', 'no_war', 'truce', 'treaty', 'civil_war']
senticnet['no_other_choice'] = [0, 0, -0.725, -0.729, '#scared', '#disgusting', -0.485, 'polite', 'show_respect', 'stand_behind', 'say_thank_you', 'show_affection']
senticnet['no_place'] = [-0.947, 0, -0.966, 0, '#sad', '#scared', -0.638, 'residence', 'hearth', 'domicile', 'live_area', 'dwell_place']
senticnet['no_rain'] = [-0.985, 0, -0.796, 0, '#sad', '#scared', -0.594, 'drought', 'lose_team', 'leave_out', 'disrespect', 'cause_suffer']
senticnet['no_result'] = [-0.973, 0, 0.009, -0.929, '#sad', '#disgusting', -0.637, 'without_end_product', 'waste_of_time', 'failure', 'unsuccessful', 'come_to_nothing']
senticnet['no_show'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'escape', 'escape_situation', 'cancel_meeting', 'cancel_appointment', 'bail_out']
senticnet['no_sight'] = [-0.075, 0, 0.07, 0, '#sad', '#angry', -0.048, 'head_ball', 'part_of_face', 'face_feature', 'ball', 'facial_organ']
senticnet['no_stop'] = [-0.05, 0.182, -0.083, 0.185, '#interesting', '#admirable', 0.078, 'reject', 'go_back', 'come', 'commence', 'move_ahead']
senticnet['no_sun'] = [0, 0, -0.712, -0.905, '#scared', '#disgusting', -0.539, 'block_sunlight', 'dark_area', 'cover_window', 'no_light', 'block_road']
senticnet['no_war'] = [0.299, 0.299, -0.157, 0.233, '#joyful', '#interesting', 0.225, 'desirable', 'stay_calm', 'cease_fire', 'stillness', 'get_along']
senticnet['no_water'] = [0, -0.048, 0, 0.053, '#surprising', '#admirable', 0.034, 'coat_surface', 'dune', 'desert', 'dry', 'dry_paint']
senticnet['nobble'] = [-0.952, 0, 0.647, -0.523, '#sad', '#angry', -0.707, 'lay_up', 'modify', 'disable', 'alter', 'change']
senticnet['nobility'] = [0.068, 0.194, 0, 0.241, '#interesting', '#admirable', 0.168, 'almighty', 'baron', 'royalty', 'lord', 'kingly']
senticnet['noble'] = [0.055, 0.109, -0.077, 0.124, '#interesting', '#admirable', 0.07, 'king', 'duke', 'duchess', 'earl', 'royal_title']
senticnet['noble_gas'] = [-0.871, 0, 0.949, -0.809, '#sad', '#angry', -0.876, 'chemical_element', 'element', 'atomic_number_54', 'inert_gas', 'argonon']
senticnet['noble_metal'] = [-0.624, 0, 0.504, -0.798, '#sad', '#disgusting', -0.642, 'green_gold', 'pure_gold', 'gold_dust', 'guinea_gold', 'atomic_number_79']
senticnet['nobleman'] = [0.053, 0.169, 0.012, 0.244, '#interesting', '#admirable', 0.151, 'nobility', 'kingly', 'title', 'axiom', 'classification']
senticnet['noblesse'] = [0.976, -0.5, 0, 0.853, '#joyful', '#admirable', 0.776, 'knighthood', 'elite', 'elite_group', 'aristocracy', 'peerage']
senticnet['nobody'] = [-0.444, -0.154, 0, -0.364, '#sad', '#disgusting', -0.218, 'nothing', 'zero', 'nonsense', 'none', 'anybody']
senticnet['noctuid'] = [-0.534, 0, 0.8, -0.619, '#angry', '#disgusting', -0.651, 'armyworm', 'underwing', 'antler_moth', 'heliothis_moth', 'moth']
senticnet['noctuid_moth'] = [-0.608, 0, 0.636, -0.984, '#angry', '#disgusting', -0.743, 'armyworm', 'underwing', 'antler_moth', 'heliothis_moth', 'moth']
senticnet['nocturnal'] = [0.725, -0.893, 0, 0, '#joyful', '#surprising', 0.539, 'furry_creature', 'hairy', 'furry', 'woodland_creature', 'animal_furry']
senticnet['nod'] = [0.021, 0.179, -0.133, 0.164, '#interesting', '#admirable', 0.077, 'nod_head', 'point_finger', 'upgrade', 'ask', 'put_bid']
senticnet['nod_head'] = [0.042, 0.141, -0.094, 0.1, '#interesting', '#admirable', 0.063, 'make_eye_contact', 'discuss', 'move_head', 'share_idea', 'become_friend']
senticnet['noddle'] = [0.914, -0.56, 0, 0.869, '#joyful', '#admirable', 0.781, 'tabula_rasa', 'ego', 'subconscious', 'unconscious', 'psyche']
senticnet['node'] = [-0.671, 0, 0.97, -0.64, '#sad', '#angry', -0.76, 'joint', 'connexion', 'articulation', 'join', 'juncture']
senticnet['nodus'] = [-0.75, 0, 0.87, 0, '#sad', '#angry', -0.54, 'block', 'obstacle', 'hitch', 'impediment', 'obstruction']
senticnet['noise'] = [0.03, -0.019, 0.023, 0.053, '#joyful', '#admirable', 0.026, 'sound', 'animal_sound', 'loudness', 'decibel', 'loud_sound']
senticnet['noise_maker'] = [0, 0, 0.772, -0.852, '#angry', '#disgusting', -0.541, 'jingle', 'chime', 'school_end', 'bell_noise', 'loud_music']
senticnet['noise_pollution'] = [0, 0, 0.735, -0.708, '#angry', '#disgusting', -0.481, 'swing_set', 'roadway_square', 'fresh_air', 'dog_poop', 'wildflower']
senticnet['noisome'] = [-0.062, 0.128, 0.707, -0.677, '#angry', '#disgusting', -0.439, 'sickish', 'turn_stomach', 'vile', 'sickening', 'nauseous']
senticnet['noisomeness'] = [-0.721, 0, 0.71, -0.9, '#sad', '#disgusting', -0.777, 'perniciousness', 'harmfulness', 'toxicity', 'unwholesomeness', 'noxiousness']
senticnet['noisy'] = [-0.444, -0.154, 0, -0.364, '#sad', '#disgusting', -0.218, 'loud', 'uncontrollable', 'obsolete', 'light_colored', 'last_clue']
senticnet['noisy_place'] = [0.021, 0, 0, 0.113, '#joyful', '#admirable', 0.045, 'big_car', 'large_automobile', 'large_car', 'long_car', 'expensive_car']
senticnet['nomad'] = [0.141, 0, -0.063, 0.086, '#joyful', '#admirable', 0.055, 'dancer', 'stout', 'old_dance', 'climb_rock', 'jump_around']
senticnet['nominal_aphasia'] = [-0.82, 0, 0.953, -0.878, '#angry', '#disgusting', -0.884, 'auditory_aphasia', 'acoustic_aphasia', 'word_deafness', 'aphasia', 'anomic_aphasia']
senticnet['nominate'] = [0.027, 0.24, -0.072, 0.257, '#interesting', '#admirable', 0.151, 'march_rear', 'assign', 'edict', 'selection', 'presidential']
senticnet['nominative'] = [0.843, -0.602, 0, 0.97, '#joyful', '#admirable', 0.805, 'subject_case', 'oblique_case', 'grammatical_case', 'grammar', 'subject']
senticnet['nominative_case'] = [0.843, -0.602, 0, 0.97, '#joyful', '#admirable', 0.805, 'oblique', 'oblique_case', 'nominative', 'grammatical_case', 'subject_case']
senticnet['non-renewable_resource'] = [-0.09, -0.006, -0.164, -0.096, '#scared', '#disgusting', -0.115, 'dig_up', 'decay', 'fuel_source', 'radiation', 'mine_ore']
senticnet['non_fiction'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'literature', 'bed_time_story', 'biography', 'fiction', 'book_story']
senticnet['nonabsorbency'] = [-0.522, 0, 0.596, -0.76, '#angry', '#disgusting', -0.626, 'retention', 'retentiveness', 'retentivity', 'solidness', 'impermeability']
senticnet['nonadhesive'] = [-0.735, 0, 0.957, -0.609, '#sad', '#angry', -0.767, 'ungummed', 'nonglutinous', 'nonviscid', 'nonresinous', 'nonresiny']
senticnet['nonagenarian'] = [0.556, -0.641, 0, 0.64, '#surprising', '#admirable', 0.612, 'centenarian', 'golden_ager', 'octogenarian', 'septuagenarian', 'sexagenarian']
senticnet['nonchurchgoing'] = [-0.932, 0, 0.75, -0.645, '#sad', '#angry', -0.776, 'heathen', 'heathenish', 'pagan', 'lapsed', 'irreligious']
senticnet['noncivilized'] = [-0.52, 0, 0.896, -0.763, '#angry', '#disgusting', -0.726, 'barbarous', 'primitive', 'savage', 'wild', 'preliterate']
senticnet['nonconformance'] = [0.526, -0.633, 0, 0.59, '#surprising', '#admirable', 0.583, 'nonconformity', 'iconoclasm', 'nonconformism', 'heterodoxy', 'orientation']
senticnet['nonconformism'] = [0.526, -0.633, 0, 0.59, '#surprising', '#admirable', 0.583, 'nonconformity', 'iconoclasm', 'heterodoxy', 'nonconformance', 'orientation']
senticnet['nonconformity'] = [0.526, -0.633, 0, 0.59, '#surprising', '#admirable', 0.583, 'heterodoxy', 'iconoclasm', 'nonconformism', 'nonconformance', 'orientation']
senticnet['noncontroversial'] = [-0.957, 0, 0.783, -0.654, '#sad', '#angry', -0.798, 'unchallengeable', 'undisputed', 'unchallenged', 'unquestioned', 'agreed_upon']
senticnet['noncurrent'] = [-0.909, 0, 0.517, -0.92, '#sad', '#disgusting', -0.782, 'outdated', 'obsolescent', 'disused', 'obsolete', 'superannuated']
senticnet['nondescript'] = [0.514, -0.967, 0, 0.968, '#surprising', '#admirable', 0.816, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['nondigestible'] = [-0.774, 0, 0.671, -0.807, '#sad', '#disgusting', -0.751, 'flatulent', 'indigestible', 'undigested', 'stodgy', 'heavy']
senticnet['none'] = [-0.444, -0.154, 0, -0.364, '#sad', '#disgusting', -0.218, 'nothing', 'zero', 'nonsense', 'nobody', 'anybody']
senticnet['nonentity'] = [-0.631, 0, 0.591, -0.732, '#sad', '#disgusting', -0.651, 'irreality', 'void', 'impossibleness', 'unreality', 'impossibility']
senticnet['nonequivalent'] = [-0.868, 0, 0.63, -0.697, '#sad', '#disgusting', -0.732, 'unequalized', 'mismatched', 'unequal', 'uneven', 'unbalanced']
senticnet['nonessential'] = [-0.819, 0, 0.987, -0.641, '#sad', '#angry', -0.816, 'unessential', 'accidental', 'incidental', 'accessorial', 'adscititious']
senticnet['nonesuch'] = [0.805, -0.581, 0, 0.525, '#joyful', '#surprising', 0.637, 'jimdandy', 'jimhickey', 'crackerjack', 'class_act', 'humdinger']
senticnet['nonexistence'] = [-0.775, 0, 0.908, -0.611, '#sad', '#angry', -0.765, 'irreality', 'void', 'impossibleness', 'unreality', 'impossibility']
senticnet['nonexistent'] = [-0.988, 0, 0.801, -0.667, '#sad', '#angry', -0.819, 'lacking', 'wanting', 'nonextant', 'absent', 'missing']
senticnet['nonextant'] = [-0.988, 0, 0.801, -0.667, '#sad', '#angry', -0.819, 'lacking', 'wanting', 'nonexistent', 'absent', 'missing']
senticnet['nonglutinous'] = [-0.735, 0, 0.957, -0.609, '#sad', '#angry', -0.767, 'ungummed', 'nonadhesive', 'nonviscid', 'nonresinous', 'nonresiny']
senticnet['nongovernmental_organization'] = [-0.69, 0, 0.836, -0.733, '#angry', '#disgusting', -0.753, 'denomination', 'committee', 'citizens_committee', 'mission', 'missionary_post']
senticnet['nonhereditary'] = [-0.951, 0, 0.684, -0.762, '#sad', '#disgusting', -0.799, 'innate', 'nurtural', 'inborn', 'nontransmissible', 'nonheritable']
senticnet['nonheritable'] = [-0.951, 0, 0.684, -0.762, '#sad', '#disgusting', -0.799, 'innate', 'nurtural', 'inborn', 'nontransmissible', 'nonhereditary']
senticnet['nonhuman'] = [-0.939, 0, 0.508, -0.582, '#sad', '#disgusting', -0.676, 'inhuman', 'bloodless', 'apelike', 'anthropoid', 'anthropoidal']
senticnet['nonindulgent'] = [0.682, -0.559, 0, 0.985, '#joyful', '#admirable', 0.742, 'renunciant', 'renunciative', 'puritanic', 'puritanical', 'corrective']
senticnet['noninheritable'] = [-0.524, 0, 0.821, -0.588, '#angry', '#disgusting', -0.644, 'innate', 'nurtural', 'inborn', 'nontransmissible', 'nonhereditary']
senticnet['nonintellectual'] = [0.849, -0.897, 0, 0.924, '#surprising', '#admirable', 0.89, 'philistine', 'lowbrow', 'lowbrowed', 'mindless', 'uncultivated']
senticnet['nonmalignant_neoplasm'] = [-0.843, 0, 0.614, -0.891, '#sad', '#disgusting', -0.783, 'fibroma', 'adenoma', 'chondroma', 'enchondroma', 'myoma']
senticnet['nonmalignant_tumor'] = [-0.977, 0, 0.787, -0.503, '#sad', '#angry', -0.756, 'fibroma', 'adenoma', 'chondroma', 'enchondroma', 'myoma']
senticnet['nonmeaningful'] = [-0.523, 0, 0.663, -0.607, '#angry', '#disgusting', -0.598, 'insignificant', 'mindless', 'empty', 'nonsense', 'vacuous']
senticnet['nonmetal'] = [-0.575, 0, 0.954, -0.806, '#angry', '#disgusting', -0.778, 'chemical_element', 'transactinide', 'hydrogen', 'atomic_number_1', 'xenon']
senticnet['nonmotile'] = [-0.576, 0, 0.97, -0.761, '#angry', '#disgusting', -0.769, 'immovable', 'immoveable', 'unmovable', 'immobile', 'immotile']
senticnet['nonmoving'] = [-0.829, 0, 0.99, -0.872, '#angry', '#disgusting', -0.897, 'motionless', 'rigid', 'inactive', 'still', 'static']
senticnet['nonpareil'] = [0.78, -0.506, 0, 0.93, '#joyful', '#admirable', 0.739, 'jimdandy', 'jimhickey', 'crackerjack', 'class_act', 'humdinger']
senticnet['nonplus'] = [-0.444, -0.154, 0, -0.364, '#sad', '#disgusting', -0.218, 'baffle', 'stupefy', 'dumbfound', 'stupefaction', 'confuse']
senticnet['nonplused'] = [-0.833, 0, 0.925, -0.994, '#angry', '#disgusting', -0.917, 'at_loss', 'perplexed', 'confused', 'puzzled', 'bewildered']
senticnet['nonplussed'] = [0, 0, -0.755, -0.975, '#scared', '#disgusting', -0.577, 'vex', 'perplex', 'puzzle', 'get', 'stick']
senticnet['nonrational'] = [0.649, -0.74, 0, 0.749, '#surprising', '#admirable', 0.713, 'absurd', 'inconsequential', 'intuitive', 'visceral', 'illogical']
senticnet['nonreligious_person'] = [-0.542, 0, 0.606, -0.737, '#angry', '#disgusting', -0.628, 'heathen', 'pagan', 'gentile', 'infidel', 'mortal']
senticnet['nonresinous'] = [-0.735, 0, 0.957, -0.609, '#sad', '#angry', -0.767, 'ungummed', 'nonglutinous', 'nonviscid', 'nonadhesive', 'nonresiny']
senticnet['nonresiny'] = [-0.735, 0, 0.957, -0.609, '#sad', '#angry', -0.767, 'ungummed', 'nonglutinous', 'nonviscid', 'nonresinous', 'nonadhesive']
senticnet['nonsense'] = [-0.444, -0.154, 0, -0.364, '#sad', '#disgusting', -0.218, 'nothing', 'none', 'zero', 'nobody', 'anything']
senticnet['nonsensicality'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'nonsense', 'meaninglessness', 'bunk', 'absurdity', 'hokum']
senticnet['nonsexual'] = [-0.507, 0, 0.763, -0.833, '#angry', '#disgusting', -0.701, 'agamic', 'agamous', 'agamogenetic', 'parthenogenetic', 'apomictic']
senticnet['nonstarter'] = [-0.949, 0, 0.551, -0.984, '#sad', '#disgusting', -0.828, 'unfortunate', 'insolvent', 'underdog', 'bankrupt', 'dud']
senticnet['nonsuch'] = [0.582, -0.979, 0, 0.802, '#surprising', '#admirable', 0.788, 'jimdandy', 'jimhickey', 'crackerjack', 'class_act', 'humdinger']
senticnet['nontransferable'] = [-0.805, 0, 0.815, -0.984, '#angry', '#disgusting', -0.868, 'infrangible', 'inalienable', 'unassignable', 'untransferable', 'inviolable']
senticnet['nontransmissible'] = [-0.951, 0, 0.684, -0.762, '#sad', '#disgusting', -0.799, 'innate', 'nurtural', 'inborn', 'nonheritable', 'nonhereditary']
senticnet['nonuniform'] = [-0.826, 0, 0.756, -0.516, '#sad', '#angry', -0.699, 'inhomogeneous', 'heterogeneous', 'assorted', 'sundry', 'mixed']
senticnet['nonuniformity'] = [0.737, -0.837, 0, 0.641, '#joyful', '#surprising', 0.738, 'inconsistency', 'dissimilarity', 'unsimilarity', 'heterogeneity', 'heterogeneousness']
senticnet['nonviscid'] = [-0.735, 0, 0.957, -0.609, '#sad', '#angry', -0.767, 'ungummed', 'nonglutinous', 'nonadhesive', 'nonresinous', 'nonresiny']
senticnet['nonvisual'] = [-0.519, 0, 0.979, -0.89, '#angry', '#disgusting', -0.796, 'occult', 'concealed', 'invisible', 'hidden', 'out_of_sight']
senticnet['nonvoluntary'] = [-0.526, 0, 0.857, -0.754, '#angry', '#disgusting', -0.712, 'unwilling', 'unconscious', 'unwilled', 'driven', 'forced']
senticnet['noob'] = [-0.067, -0.055, 0.009, -0.18, '#sad', '#disgusting', -0.067, 'newbie', 'loser', 'computer_user', 'dummy', 'beginner']
senticnet['noodel'] = [0.03, 0, 0, 0.076, '#joyful', '#admirable', 0.035, 'food_ingredient', 'rice', 'granulate', 'white_grain', 'wheat_flour']
senticnet['noodle'] = [0.041, -0.071, 0.034, 0, '#joyful', '#surprising', 0.026, 'butter', 'mayonaise', 'pie', 'bagel', 'muffin']
senticnet['noodles'] = [0.711, 0, 0, 0, '#joyful', '#joyful', 0.237, 'chicken_rice', 'dumpling', 'chinese_food', 'porridge', 'rice']
senticnet['noose'] = [-0.063, -0.031, 0.015, -0.055, '#sad', '#disgusting', -0.034, 'suspend', 'long_arm', 'hang', 'antenna', 'long_neck']
senticnet['noreaster'] = [-0.782, 0, 0.906, -0.545, '#sad', '#angry', -0.744, 'rainstorm', 'atmospheric_phenomenon', 'northeaster', 'storm', 'hailstorm']
senticnet['normal'] = [0.029, 0.228, 0, 0.145, '#interesting', '#admirable', 0.134, 'usual_ordinary', 'typical', 'usual', 'frequent', 'sameness']
senticnet['normal_distribution'] = [0.948, -0.992, 0, 0.549, '#joyful', '#surprising', 0.83, 'sampling', 'equidistribution', 'frequency_distribution', 'distribution', 'sample_distribution']
senticnet['normal_human_body'] = [-0.042, 0.077, -0.092, -0.08, '#scared', '#disgusting', -0.046, 'body', 'inside_body', 'corpse', 'dead_person', 'nervous_system']
senticnet['normalcy'] = [0.798, -0.517, 0, 0.519, '#joyful', '#admirable', 0.611, 'averageness', 'commonness', 'expectedness', 'typicality', 'condition']
senticnet['north'] = [0, 0.157, 0, 0.094, '#interesting', '#admirable', 0.084, 'east', 'sunrise', 'sunset', 'limit', 'dawn']
senticnet['north_south'] = [0.046, -0.15, 0.016, 0.167, '#surprising', '#admirable', 0.116, 'dense_air', 'toxic_metal', 'heavy_metal', 'heavy_element', 'tin_foil']
senticnet['northeaster'] = [-0.782, 0, 0.906, -0.545, '#sad', '#angry', -0.744, 'rainstorm', 'atmospheric_phenomenon', 'storm', 'noreaster', 'hailstorm']
senticnet['northern_barramundi'] = [0.565, -0.697, 0, 0.787, '#surprising', '#admirable', 0.683, 'species', 'saratoga', 'spotted_barramundi', 'spotted_bonytongue', 'fish_species']
senticnet['northern_phalarope'] = [0.786, -0.82, 0, 0.776, '#joyful', '#surprising', 0.794, 'red_phalarope', 'phalarope', 'shorebird', 'shore_bird', 'limicoline_bird']
senticnet['northern_red_oak'] = [0.672, -0.696, 0, 0.831, '#surprising', '#admirable', 0.733, 'southern_red_oak', 'swamp_red_oak', 'turkey_oak', 'red_oak', 'oak']
senticnet['nose'] = [0.057, 0.111, 0, 0.143, '#interesting', '#admirable', 0.104, 'mouth', 'facial_organ', 'face_feature', 'facial', 'facial_part']
senticnet['nose_drops'] = [-0.7, 0, 0.698, -0.578, '#sad', '#angry', -0.659, 'smack', 'hell_dust', 'diacetylmorphine', 'thunder', 'skag']
senticnet['nose_flute'] = [0.821, -0.531, 0, 0.785, '#joyful', '#admirable', 0.712, 'fife', 'flute', 'piccolo', 'woodwind', 'woodwind_instrument']
senticnet['nose_mouth'] = [0, 0.076, 0, 0.052, '#interesting', '#admirable', 0.043, 'hold_brain', 'face', 'skull', 'top_face', 'eye_nose']
senticnet['nosh'] = [0.789, -0.68, 0, 0.729, '#joyful', '#admirable', 0.733, 'refreshment', 'collation', 'coffee_break', 'tea_break', 'meal']
senticnet['nosiness'] = [-0.909, 0, 0.865, -0.772, '#sad', '#angry', -0.849, 'curiousness', 'snoopiness', 'prying', 'curiosity', 'wonder']
senticnet['nostalgia'] = [-0.837, 0, -0.866, 0, '#sad', '#scared', -0.568, 'eat_meal', 'eat_chip', 'eat_much_food', 'feed_child', 'eat_much']
senticnet['nostalgic'] = [-0.051, -0.004, -0.074, -0.05, '#sad', '#scared', -0.057, 'vulnerable', 'many_children', 'bald', 'newborn', 'baby_dog']
senticnet['nostrum'] = [-0.889, 0, 0.907, -0.775, '#sad', '#angry', -0.857, 'remedy', 'cure', 'elixir', 'therapeutic', 'curative']
senticnet['note'] = [0.047, 0, 0, 0.132, '#joyful', '#admirable', 0.06, 'message', 'letter', 'chord', 'put_ink_paper', 'announcement']
senticnet['note_book'] = [0.8, -0.913, 0, 0, '#joyful', '#surprising', 0.571, 'photo_copy', 'writing_paper', 'printing_paper', 'color_paper', 'white_paper']
senticnet['note_down'] = [0, 0.077, 0, 0.154, '#interesting', '#admirable', 0.077, 'form_of_communication', 'communication_method', 'written_language', 'written_communication', 'written_note']
senticnet['note_pad'] = [0, 0, 0, -0.776, '#disgusting', '#disgusting', -0.259, 'icon', 'bullshit', 'scrap_paper', 'attendee', 'agenda']
senticnet['notebook'] = [-0.028, 0.094, 0, 0.097, '#interesting', '#admirable', 0.054, 'make_note', 'write', 'take_note', 'note', 'write_note']
senticnet['noted'] = [0, 0.977, 0, 0.799, '#interesting', '#admirable', 0.592, 'mention', 'observe', 'notice', 'mark', 'remark']
senticnet['notepad'] = [0.028, -0.039, 0.058, -0.099, '#angry', '#disgusting', -0.03, 'pocket_size_notebook', 'memo_pad', 'intern', 'self_adhesive_label', 'paper_clip']
senticnet['notes'] = [0.022, -0.057, 0.079, -0.116, '#angry', '#disgusting', -0.039, 'stationery', 'ink', 'paper', 'refill', 'ball_point_pen']
senticnet['nothing'] = [-0.554, 0, 0.882, -0.735, '#angry', '#disgusting', -0.724, 'null', 'zero', 'naught', 'zip', 'bugger_all']
senticnet['nothing_better'] = [0.937, 0.878, 0, 0.738, '#joyful', '#interesting', 0.851, 'spend_time_with_friend', 'enjoyment', 'entertain_oneself', 'pastime', 'get_out_of_house']
senticnet['nothing_special'] = [0, 0, 0, -0.873, '#disgusting', '#disgusting', -0.291, 'domestic_pet', 'popular_pet', 'similar', 'common_pet', 'common']
senticnet['nothingness'] = [-0.78, 0, 0.722, 0, '#sad', '#angry', -0.501, 'heavenly_body', 'star_planet', 'celestial_body', 'limitless', 'around_earth']
senticnet['notice'] = [0, 0.707, 0, 0, '#interesting', '#interesting', 0.236, 'announcement', 'observation', 'comment', 'placard', 'observe']
senticnet['notice_problem'] = [0, 0.951, 0, 0, '#interesting', '#interesting', 0.317, 'arm_weapon', 'smoke_joint', 'deal_card_player', 'bridge_difference', 'explain_everything']
senticnet['noticeable'] = [0.958, -0.838, 0, 0.81, '#joyful', '#surprising', 0.869, 'discernible', 'perceptible', 'evident', 'detectable', 'observable']
senticnet['notification'] = [-0.085, 0.146, 0, 0.116, '#interesting', '#admirable', 0.059, 'musical_notation', 'bill_pay', 'musical_note', 'written_note', 'reminder']
senticnet['notion'] = [0.92, 0, 0, 0.713, '#joyful', '#admirable', 0.544, 'idea', 'belief', 'concept', 'opinion', 'view']
senticnet['notional'] = [-0.677, 0, 0.716, -0.897, '#angry', '#disgusting', -0.763, 'imaginary', 'unreal', 'fabled', 'hallucinatory', 'illusional']
senticnet['notoriety'] = [-0.785, 0, 0.913, 0, '#sad', '#angry', -0.566, 'status', 'seeker', 'everyone_know', 'critical', 'caste']
senticnet['noun'] = [0.03, -0.009, 0, 0.089, '#joyful', '#admirable', 0.043, 'grammar', 'alphabet', 'letter', 'language', 'abc']
senticnet['noun_form'] = [0, 0.192, -0.091, 0.149, '#interesting', '#admirable', 0.083, 'mathematical', 'math_function', 'math_process', 'math_operation', 'math_action']
senticnet['nourish'] = [0, 0.155, -0.051, 0.11, '#interesting', '#admirable', 0.071, 'provide_food', 'ingest_food', 'make_eat', 'animal_eat', 'satiate_hunger']
senticnet['nourishment'] = [0.79, 0.9, 0, 0, '#joyful', '#interesting', 0.563, 'sustenance', 'eat', 'feed_oneself', 'transport_food', 'satisfy_hunger']
senticnet['nous'] = [0.911, -0.94, 0, 0.953, '#surprising', '#admirable', 0.935, 'common_sense', 'good_sense', 'horse_sense', 'mother_wit', 'gumption']
senticnet['novel'] = [0.036, 0.219, 0, 0.19, '#interesting', '#admirable', 0.148, 'long_story', 'text', 'fiction', 'book', 'classic']
senticnet['novelist'] = [0.163, 0.255, -0.2, 0.31, '#interesting', '#admirable', 0.176, 'actor', 'movie', 'cctv', 'cinema', 'writer']
senticnet['novelty'] = [0.876, 0.854, 0, 0.79, '#joyful', '#interesting', 0.84, 'new', 'timely', 'know_time', 'sec', 'never_end']
senticnet['novelty_item'] = [0.869, 0.887, 0, 0.708, '#joyful', '#interesting', 0.821, 'expensive_sport', 'toy', 'old_game', 'game', 'consider_good_luck']
senticnet['november'] = [0, 0, -0.116, 0, '#scared', '#scared', -0.039, 'year', 'week', 'century', 'month', 'reckon']
senticnet['novice'] = [-0.954, 0, 0.735, -0.842, '#sad', '#disgusting', -0.844, 'cub', 'beginner', 'tyro', 'tiro', 'initiate']
senticnet['novocaine'] = [-0.058, -0.019, -0.074, -0.239, '#scared', '#disgusting', -0.117, 'phenobarbital', 'ibuprofen', 'x-ray_machine', 'palliative', 'analgesic']
senticnet['now_time'] = [0, 0.902, 0, 0.973, '#interesting', '#admirable', 0.625, 'event', 'occasion', 'incident', 'present', 'accident']
senticnet['nowhere'] = [0.053, 0.163, -0.051, 0.102, '#interesting', '#admirable', 0.089, 'utopia', 'mount_ever', 'java', 'outhouse', 'international_space_station']
senticnet['nowhere_live'] = [0, 0.208, -0.142, 0.162, '#interesting', '#admirable', 0.076, 'much_child', 'grandchild', 'offspring', 'descendant', 'human_offspring']
senticnet['noxious'] = [-0.864, 0, 0.891, -0.821, '#sad', '#angry', -0.859, 'baneful', 'pernicious', 'vesicatory', 'vesicant', 'pestilent']
senticnet['noxious_gas'] = [-0.99, 0, 0.518, -0.994, '#sad', '#disgusting', -0.834, 'holocaust', 'kill_person', 'gas', 'poison_gas', 'noxious']
senticnet['noxiousness'] = [-0.721, 0, 0.71, -0.9, '#sad', '#disgusting', -0.777, 'perniciousness', 'harmfulness', 'toxicity', 'noisomeness', 'unwholesomeness']
senticnet['nubbiness'] = [-0.9, 0, 0.841, -0.731, '#sad', '#angry', -0.824, 'raggedness', 'tweediness', 'harshness', 'graininess', 'granularity']
senticnet['nuclear'] = [0, 0, 0, -0.081, '#disgusting', '#disgusting', -0.027, 'dynamite', 'gunshot', 'missile', 'nuclear_bomb', 'fall_sky']
senticnet['nuclear_bomb'] = [0, 0, 0.851, -0.916, '#angry', '#disgusting', -0.589, 'bomb', 'atomic_bomb', 'nuclear_weapon', 'explosive', 'grenade']
senticnet['nuclear_energy'] = [-0.909, 0, 0.748, -0.904, '#sad', '#disgusting', -0.854, 'alternative_energy', 'activation_energy', 'energy_of_activation', 'atomic_energy', 'energy']
senticnet['nuclear_power_plant'] = [-0.057, -0.032, 0.018, -0.083, '#sad', '#disgusting', -0.042, 'build', 'construction_site', 'skyscraper', 'tall_building', 'construct_building']
senticnet['nuclear_war'] = [-0.933, 0, -0.751, 0, '#sad', '#scared', -0.561, 'kill', 'bigot', 'murder', 'death_penalty', 'execute']
senticnet['nuclear_weapon'] = [-0.032, -0.031, -0.054, -0.201, '#scared', '#disgusting', -0.085, 'nuclear_bomb', 'bomb', 'explosive', 'atomic_bomb', 'grenade']
senticnet['nucleoplasm'] = [0, 0.095, 0.016, 0.106, '#interesting', '#admirable', 0.062, 'blood_plasma', 'cytoplasm', 'germplasm', 'plasma', 'protoplasm']
senticnet['nucleus'] = [0.071, 0.118, 0, 0.124, '#interesting', '#admirable', 0.104, 'atom', 'proton_neutron', 'neutron', 'proton', 'molecule']
senticnet['nude'] = [-0.947, 0, 0.991, -0.656, '#sad', '#angry', -0.865, 'birthday_suit', 'raw', 'altogether', 'nakedness', 'undress']
senticnet['nude_dancing'] = [0.993, -0.967, 0, 0.917, '#joyful', '#surprising', 0.959, 'strip', 'fan_dance', 'striptease', 'strip_show', 'bubble_dance']
senticnet['nude_mouse'] = [-0.55, 0, 0.955, -0.96, '#angry', '#disgusting', -0.822, 'house_mouse', 'harvest_mouse', 'field_mouse', 'fieldmouse', 'mouse']
senticnet['nudeness'] = [-0.806, 0, 0.602, -0.589, '#sad', '#angry', -0.666, 'birthday_suit', 'raw', 'altogether', 'nude', 'undress']
senticnet['nudity'] = [-0.611, 0, 0.86, -0.533, '#sad', '#angry', -0.668, 'birthday_suit', 'raw', 'altogether', 'nude', 'undress']
senticnet['nudnick'] = [-0.998, 0, 0.636, -0.808, '#sad', '#disgusting', -0.814, 'pest', 'dullard', 'bore', 'blighter', 'cuss']
senticnet['nudnik'] = [-0.537, 0, 0.973, -0.644, '#angry', '#disgusting', -0.718, 'pest', 'dullard', 'bore', 'blighter', 'cuss']
senticnet['nugget'] = [0.03, 0, 0, 0.091, '#joyful', '#admirable', 0.04, 'part_of_meal', 'make_egg', 'good_eat', 'produce_egg', 'yum']
senticnet['nuisance'] = [-0.747, 0, 0.704, -0.798, '#sad', '#disgusting', -0.75, 'pain_in_ass', 'pain', 'pain_in_neck', 'annoyance', 'bother']
senticnet['nuisance_insect'] = [-0.038, -0.017, 0.094, -0.051, '#angry', '#disgusting', -0.055, 'small_insect', 'annoy_bug', 'small_bug', 'parasite', 'tiny_insect']
senticnet['null'] = [-0.554, 0, 0.882, -0.735, '#angry', '#disgusting', -0.724, 'bugger_all', 'zero', 'naught', 'zip', 'nothing']
senticnet['nullify'] = [-0.929, 0, 0.762, -0.628, '#sad', '#angry', -0.773, 'stet', 'set_aside', 'break', 'cancel', 'strike_down']
senticnet['numb'] = [-0.818, 0, -0.923, 0, '#sad', '#scared', -0.58, 'spasm', 'cure', 'forceps', 'treatment', 'operation']
senticnet['number'] = [-0.852, 0, 0.605, -0.739, '#sad', '#disgusting', -0.732, 'fewness', 'numerousness', 'numerosity', 'innumerableness', 'countlessness']
senticnet['number_one'] = [0.043, 0.118, 0.085, 0.126, '#interesting', '#admirable', 0.067, 'ordinal', 'unit', 'military_group', 'prime', 'best']
senticnet['number_pad'] = [0, 0, 0.076, 0, '#angry', '#angry', -0.025, 'device', 'computer', 'browser', 'input_device', 'telephone_computer']
senticnet['number_person'] = [0.052, 0.16, 0.061, 0.161, '#interesting', '#admirable', 0.104, 'count_person', 'small_group', 'crowd', 'large_amount', 'elite']
senticnet['numbness'] = [-0.211, -0.161, -0.105, -0.267, '#sad', '#disgusting', -0.141, 'earache', 'physical_pain', 'car_wreck', 'punch_face', 'ice_cream_melt']
senticnet['numeracy'] = [0.817, -0.514, 0, 0.991, '#joyful', '#admirable', 0.774, 'acquirement', 'skill', 'accomplishment', 'acquisition', 'attainment']
senticnet['numeral'] = [0.049, 0.113, 0.107, 0.162, '#interesting', '#admirable', 0.072, 'list_number', 'ordinal', 'count', 'numerical', 'enumeration']
senticnet['numerate'] = [-0.933, 0, 0.8, -0.501, '#sad', '#angry', -0.745, 'miscount', 'tot', 'tally', 'find', 'add']
senticnet['numeration'] = [0.809, -0.719, 0, 0.708, '#joyful', '#surprising', 0.745, 'tally', 'investigating', 'tap', 'scrutiny', 'testing']
senticnet['numerical'] = [0.024, 0.172, 0.073, 0.245, '#interesting', '#admirable', 0.123, 'enumeration', 'ordinal', 'list_number', 'tally', 'twice']
senticnet['numerosity'] = [-0.852, 0, 0.605, -0.739, '#sad', '#disgusting', -0.732, 'fewness', 'numerousness', 'number', 'innumerableness', 'countlessness']
senticnet['numerousness'] = [-0.852, 0, 0.605, -0.739, '#sad', '#disgusting', -0.732, 'fewness', 'number', 'numerosity', 'innumerableness', 'countlessness']
senticnet['numismatics'] = [0, 0, 0, 0.101, '#admirable', '#admirable', 0.034, 'collector', 'collect_item', 'coin', 'collect', 'stamp']
senticnet['numskull'] = [-0.642, 0, 0.576, -0.87, '#sad', '#disgusting', -0.696, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['nun'] = [0.047, 0.204, -0.132, 0.171, '#interesting', '#admirable', 0.097, 'sister', 'cousin', 'wench', 'aunt', 'parent']
senticnet['nurse'] = [0.024, 0.172, 0.073, 0.245, '#interesting', '#admirable', 0.123, 'doctor', 'cure', 'medicine', 'clinic', 'doctor_surgery']
senticnet['nurse_home'] = [0.024, 0.172, 0.073, 0.245, '#interesting', '#admirable', 0.123, 'clinic', 'hospital', 'emergency_room', 'emergency_ward', 'medical_office']
senticnet['nursery'] = [0.054, 0.076, 0, 0.127, '#interesting', '#admirable', 0.086, 'take_care', 'old_folk_home', 'laboratory', 'nurse', 'compost_pile']
senticnet['nursery_school'] = [-0.048, 0.088, 0.013, 0.069, '#interesting', '#admirable', 0.032, 'kindergarden', 'daycare', 'nursery', 'child', 'asylum']
senticnet['nursing'] = [-0.802, 0, 0.724, -0.706, '#sad', '#angry', -0.744, 'infant_feeding', 'schedule_feeding', 'demand_feeding', 'breast_feeding', 'feeding']
senticnet['nurtural'] = [-0.951, 0, 0.684, -0.762, '#sad', '#disgusting', -0.799, 'innate', 'nonheritable', 'inborn', 'nontransmissible', 'nonhereditary']
senticnet['nurture'] = [0.928, 0, 0, 0.712, '#joyful', '#admirable', 0.547, 'look_after', 'serve', 'kindness', 'need_grocery', 'keep_alive']
senticnet['nurture_child'] = [0.255, 0.182, -0.06, 0.314, '#joyful', '#admirable', 0.23, 'quiet_child', 'care_child', 'name_baby', 'shoulder_responsibility', 'name_child']
senticnet['nut'] = [-0.594, 0, 0.945, -0.854, '#angry', '#disgusting', -0.798, 'palm_nut', 'palm_kernel', 'edible_nut', 'cembra_nut', 'cedar_nut']
senticnet['nut_bolt'] = [0, -0.018, 0.048, -0.046, '#angry', '#disgusting', -0.025, 'wrench', 'power_drill', 'tool', 'clamp', 'drill_bite']
senticnet['nut_bread'] = [0.644, -0.946, 0, 0.729, '#surprising', '#admirable', 0.773, 'gem', 'banana_bread', 'date_bread', 'quick_bread', 'oatcake']
senticnet['nut_house'] = [-0.817, 0, 0.6, -0.627, '#sad', '#disgusting', -0.681, 'asylum', 'mental_hospital', 'psychiatric_hospital', 'mental_institution', 'mental_home']
senticnet['nutcase'] = [-0.648, 0, 0.781, -0.743, '#angry', '#disgusting', -0.724, 'weirdo', 'crazy', 'loony', 'looney', 'lunatic']
senticnet['nuthouse'] = [-0.766, 0, 0.904, -0.802, '#angry', '#disgusting', -0.824, 'asylum', 'mental_hospital', 'psychiatric_hospital', 'mental_institution', 'mental_home']
senticnet['nutrient'] = [0.061, 0, 0, 0.052, '#joyful', '#admirable', 0.038, 'noodle', 'result_cook', 'biscuit', 'chow', 'cream']
senticnet['nutrition'] = [0.842, 0.896, 0, 0, '#joyful', '#interesting', 0.579, 'sustain_life', 'sustenance', 'survival', 'keep_alive', 'satisfy_hunger']
senticnet['nutritious'] = [0.063, 0.089, 0.036, 0.146, '#interesting', '#admirable', 0.087, 'edible', 'good_eat', 'crunchy', 'delicious', 'juicy']
senticnet['nutty'] = [0, -0.96, 0, 0.721, '#surprising', '#admirable', 0.56, 'nutlike', 'balmy', 'bats', 'barmy', 'batty']
senticnet['nuzzle'] = [0.879, -0.516, 0, 0.569, '#joyful', '#admirable', 0.655, 'pet', 'paw', 'fondle', 'pat', 'stroke']
senticnet['nyctalopia'] = [-0.575, 0, 0.629, -0.784, '#angry', '#disgusting', -0.663, 'visual_impairment', 'visual_defect', 'vision_defect', 'visual_disorder', 'avitaminosis']
senticnet['nylon'] = [0.04, 0.091, -0.065, 0.066, '#interesting', '#admirable', 0.044, 'velcro', 'velcro_product', 'clothes', 'shoe', 'pants']
senticnet['nylon_product'] = [0.04, 0.091, -0.065, 0.066, '#interesting', '#admirable', 0.044, 'nylon', 'velcro', 'clothes', 'shoe', 'pants']
senticnet['nymph'] = [0, 0, -0.973, -0.994, '#scared', '#disgusting', -0.656, 'annoy_bug', 'insect', 'bug', 'hare', 'cockroach']
senticnet['nympholepsy'] = [-0.875, 0, 0.599, -0.717, '#sad', '#disgusting', -0.73, 'hysteria', 'fury', 'delirium', 'frenzy', 'craze']
senticnet['oak'] = [0.043, -0.04, 0, 0, '#joyful', '#surprising', 0.028, 'willow', 'cedar', 'birch', 'elm', 'lumber']
senticnet['oarsmanship'] = [0.679, -0.956, 0, 0.504, '#joyful', '#surprising', 0.713, 'acquirement', 'skill', 'accomplishment', 'acquisition', 'attainment']
senticnet['oat'] = [0.804, 0.893, 0, 0, '#joyful', '#interesting', 0.566, 'wheat', 'grain', 'rye', 'white_rice', 'rice']
senticnet['oatcake'] = [0.644, -0.946, 0, 0.729, '#surprising', '#admirable', 0.773, 'gem', 'banana_bread', 'date_bread', 'nut_bread', 'quick_bread']
senticnet['oath'] = [0, 0.287, -0.236, 0.404, '#interesting', '#admirable', 0.152, 'promise', 'propose', 'suggest', 'affirmation', 'ask']
senticnet['oatmeal'] = [0.081, 0, 0, 0, '#joyful', '#joyful', 0.027, 'bottle_wine', 'table_chair', 'coconut', 'chef_special', 'human_intelligence']
senticnet['obduracy'] = [-0.972, 0, 0.99, -0.516, '#sad', '#angry', -0.826, 'firmness', 'resolve', 'resoluteness', 'firmness_of_purpose', 'resolution']
senticnet['obdurate'] = [0, 0, -0.909, -0.739, '#scared', '#disgusting', -0.549, 'unrepentant', 'obstinate', 'flint', 'flinty', 'cussed']
senticnet['obedience'] = [0.738, 0.722, 0, 0.735, '#joyful', '#admirable', 0.732, 'demand', 'elect_president', 'respect', 'must', 'requirement']
senticnet['obedient'] = [0.023, 0.275, -0.189, 0.298, '#interesting', '#admirable', 0.136, 'obey', 'honor', 'duty', 'mandatory', 'confirmation']
senticnet['obeisance'] = [-0.705, 0, 0.925, 0, '#sad', '#angry', -0.543, 'reverence', 'genuflection', 'genuflexion', 'kowtow', 'mafia']
senticnet['obese'] = [0, 0, -0.98, -0.978, '#scared', '#disgusting', -0.653, 'fat', 'fatty', 'worse', 'health_issue', 'clinical_problem']
senticnet['obesity'] = [-0.031, -0.023, -0.082, -0.133, '#scared', '#disgusting', -0.074, 'get_fat', 'decrease_hunger', 'feel_full', 'upset_stomach', 'no_long_hungry']
senticnet['obey'] = [0.094, 0.261, -0.24, 0.39, '#interesting', '#admirable', 0.168, 'good_behavior', 'honor', 'mandatory', 'politeness', 'obedience']
senticnet['obey_god'] = [0.076, 0.316, -0.182, 0.262, '#interesting', '#admirable', 0.157, 'islam', 'dogma', 'evangelist', 'faith', 'believe']
senticnet['obey_law'] = [0.905, 0.749, 0, 0.82, '#joyful', '#admirable', 0.825, 'bridge_difference', 'arm_oneself', 'stand_alone', 'see_sky', 'market_product']
senticnet['obey_parent'] = [0, 0.281, -0.201, 0.302, '#interesting', '#admirable', 0.127, 'thoughtful', 'helpful', 'certainty', 'attitude', 'abstract_concept']
senticnet['obey_rule'] = [-0.055, 0, 0.018, 0, '#sad', '#angry', -0.024, 'find_museum', 'leave_house', 'decide_to_go', 'look_map', 'book_ticket']
senticnet['obey_traffic_law'] = [0.062, 0.161, -0.076, 0.216, '#interesting', '#admirable', 0.121, 'dampness', 'wooden_spoon', 'smoothie', 'like_food', 'hold_inside']
senticnet['obfuscation'] = [-0.508, 0, 0.6, -0.885, '#angry', '#disgusting', -0.664, 'confusion', 'disarray', 'mental_confusion', 'confusedness', 'muddiness']
senticnet['obituary'] = [-0.787, 0, -0.913, 0, '#sad', '#scared', -0.567, 'editorial', 'news_story', 'article', 'headline', 'newspaper_write']
senticnet['object'] = [0, 0.982, 0, 0.844, '#interesting', '#admirable', 0.609, 'thing', 'build_block', 'solid', 'six_sides', 'item']
senticnet['object_lesson'] = [-0.662, 0, 0.809, -0.655, '#sad', '#angry', -0.709, 'example', 'deterrent_example', 'lesson', 'word_of_advice', 'advice']
senticnet['object_recognition'] = [-0.739, 0, 0.814, -0.887, '#angry', '#disgusting', -0.813, 'contrast', 'perception', 'face_recognition', 'seeing', 'visual_space']
senticnet['objective'] = [-0.037, 0.152, 0, 0.16, '#interesting', '#admirable', 0.092, 'make_happen', 'set_instruction', 'mission', 'attempt', 'police_work']
senticnet['objectiveness'] = [0.828, -0.904, 0, 0.874, '#surprising', '#admirable', 0.869, 'perspicacity', 'judgment', 'fair', 'sound_judgment', 'fair_judgment']
senticnet['objectivity'] = [0.998, -0.737, 0, 0.962, '#joyful', '#admirable', 0.899, 'perspicacity', 'judgment', 'fair', 'sound_judgment', 'fair_judgment']
senticnet['objector'] = [-0.931, 0, 0.688, -0.631, '#sad', '#angry', -0.75, 'dissident', 'dissenter', 'protester', 'nimby', 'contestant']
senticnet['objurgate'] = [-0.99, 0, 0.545, -0.555, '#sad', '#disgusting', -0.697, 'castigate', 'tell_off', 'brush_down', 'chasten', 'bawl_out']
senticnet['objurgation'] = [-0.989, 0, 0.537, -0.726, '#sad', '#disgusting', -0.751, 'reprimand', 'wigging', 'rebuke', 'reproof', 'reproval']
senticnet['obligate'] = [-0.886, 0, 0.977, -0.815, '#sad', '#angry', -0.893, 'execute', 'run', 'compel', 'oblige', 'enforce']
senticnet['obligation'] = [-0.066, 0.262, -0.207, 0.231, '#interesting', '#admirable', 0.073, 'make_happen', 'question_ask', 'task', 'ask_nicely', 'chore']
senticnet['obligatory'] = [0.924, -0.551, 0, 0.756, '#joyful', '#admirable', 0.744, 'bounden', 'incumbent_on', 'de_rigueur', 'compulsory', 'mandatory']
senticnet['oblige'] = [0.731, -0.592, 0, 0.634, '#joyful', '#admirable', 0.652, 'accommodate', 'obey', 'conform_to', 'toe_line', 'abide_by']
senticnet['oblique'] = [-0.827, 0, 0.81, -0.617, '#sad', '#angry', -0.751, 'accusative', 'genitive', 'genitive_case', 'possessive', 'possessive_case']
senticnet['oblique_case'] = [-0.844, 0, 0.509, -0.608, '#sad', '#disgusting', -0.654, 'accusative', 'genitive', 'genitive_case', 'possessive', 'possessive_case']
senticnet['oblique_triangle'] = [0.763, -0.612, 0, 0.777, '#joyful', '#admirable', 0.717, 'acute_triangle', 'wedge_shape', 'cuneus', 'wedge', 'triangle']
senticnet['obliterate'] = [0, 0, -0.756, -0.811, '#scared', '#disgusting', -0.522, 'ba_lot_of_out', 'kill', 'wipe_out', 'veil', 'obscure']
senticnet['oblivion'] = [0, 0.106, -0.052, 0.163, '#interesting', '#admirable', 0.072, 'band', 'kit', 'genesis', 'rock_band', 'high_school_band']
senticnet['oblong'] = [0.831, -0.847, 0, 0.586, '#joyful', '#surprising', 0.755, 'plane_figure', 'star', 'heart', 'polygon', 'polygonal_shape']
senticnet['obloquy'] = [-0.5, 0, 0.921, -0.878, '#angry', '#disgusting', -0.766, 'reproach', 'ignominy', 'odium', 'dishonor', 'humiliation']
senticnet['obovate_leaf'] = [-0.666, 0, 0.971, -0.753, '#angry', '#disgusting', -0.797, 'lyrate_leaf', 'needle', 'elliptic_leaf', 'hastate_leaf', 'simple_leaf']
senticnet['obscene'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repulsive', 'repugnant', 'detestably', 'abominably', 'odiously']
senticnet['obscenity'] = [-0.526, 0, 0.648, -0.967, '#angry', '#disgusting', -0.714, 'improperness', 'outrageousness', 'impropriety', 'immodesty', 'indecency']
senticnet['obscurantist'] = [0.765, -0.524, 0, 0.921, '#joyful', '#admirable', 0.737, 'slicker', 'beguiler', 'deceiver', 'cheat', 'cheater']
senticnet['obscure'] = [0, 0, -0.71, -0.934, '#scared', '#disgusting', -0.548, 'night', 'blackout', 'darkness', 'dark', 'blackness']
senticnet['obscured'] = [0, 0, -0.83, -0.919, '#scared', '#disgusting', -0.583, 'befog', 'fog', 'becloud', 'haze_over', 'obnubilate']
senticnet['obscureness'] = [-0.62, 0, 0.72, -0.515, '#sad', '#angry', -0.618, 'overcast', 'dark', 'semidarkness', 'darkness', 'dimness']
senticnet['obsequious'] = [0.981, -0.887, 0, 0.939, '#joyful', '#admirable', 0.936, 'slavelike', 'submissive', 'servile', 'subservient', 'slavish']
senticnet['observable'] = [0.958, -0.838, 0, 0.81, '#joyful', '#surprising', 0.869, 'discernible', 'perceptible', 'evident', 'detectable', 'noticeable']
senticnet['observance'] = [0.614, -0.953, 0, 0.768, '#surprising', '#admirable', 0.778, 'keeping', 'formality', 'honoring', 'line', 'abidance']
senticnet['observant'] = [-0.256, 0.128, -0.19, 0.055, '#sad', '#scared', -0.088, 'look_clue', 'say_eureka', 'rational', 'make_decision', 'ask_many_questions']
senticnet['observation'] = [0, 0.811, 0, 0, '#interesting', '#interesting', 0.27, 'observe', 'glimpse', 'look', 'stare', 'glance']
senticnet['observatory'] = [0.057, -0.038, 0, 0, '#joyful', '#surprising', 0.032, 'phone_booth', 'office_build', 'office', 'discount_store', 'internet_cafe']
senticnet['observe'] = [-0.055, 0.085, 0, 0.098, '#interesting', '#admirable', 0.043, 'observation', 'look', 'stare', 'glimpse', 'use_eye']
senticnet['observe_nature'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'read_science_book', 'study_language', 'write_on_notebook', 'buy_textbook', 'use_telescope']
senticnet['observer'] = [0.986, 0.99, 0, 0, '#joyful', '#interesting', 0.659, 'peer', 'familiar', 'well_known', 'association', 'human_group']
senticnet['obsessed'] = [0.858, -0.933, 0, 0.58, '#joyful', '#surprising', 0.79, 'regimented', 'controlled', 'possessed', 'disciplined', 'dominated']
senticnet['obsessed_love'] = [-0.752, 0.288, -0.434, -0.058, '#sad', '#scared', -0.319, 'addicted', 'obsession', 'addiction', 'stalker', 'weird']
senticnet['obsession'] = [-0.752, 0.288, -0.434, -0.058, '#sad', '#scared', -0.319, 'addicted', 'obsessed_love', 'addiction', 'stalker', 'weird']
senticnet['obsessive_compulsive_disorder'] = [-0.453, 0.186, -0.406, 0.065, '#sad', '#scared', -0.203, 'clean_often', 'mass_hysteria', 'organizational_skill', 'caution', 'maintenance']
senticnet['obsolescence'] = [0.671, -0.561, 0, 0.685, '#joyful', '#admirable', 0.639, 'macular_degeneration', 'attack', 'degeneration', 'process', 'physical_process']
senticnet['obsolescent'] = [-0.909, 0, 0.517, -0.92, '#sad', '#disgusting', -0.782, 'outdated', 'noncurrent', 'disused', 'obsolete', 'superannuated']
senticnet['obsolete'] = [-0.444, -0.154, 0, -0.364, '#sad', '#disgusting', -0.218, 'loud', 'uncontrollable', 'noisy', 'light_colored', 'last_clue']
senticnet['obstacle'] = [-0.048, 0, 0.023, 0, '#sad', '#angry', -0.024, 'golf_place', 'college_class', 'school_study', 'school_class', 'school_course']
senticnet['obstinacy'] = [-0.633, 0, 0.942, -0.528, '#sad', '#angry', -0.701, 'stubbornness', 'impenitence', 'obstinance', 'bullheadedness', 'pigheadedness']
senticnet['obstinance'] = [-0.633, 0, 0.942, -0.528, '#sad', '#angry', -0.701, 'stubbornness', 'obstinacy', 'impenitence', 'bullheadedness', 'pigheadedness']
senticnet['obstinate'] = [-0.513, 0, 0.559, -0.892, '#angry', '#disgusting', -0.655, 'persevere', 'hang_in', 'persist', 'hang_on', 'hold_on']
senticnet['obstreperous'] = [-0.698, 0, 0.516, -0.941, '#sad', '#disgusting', -0.718, 'insubordinate', 'recalcitrant', 'defiant', 'resistant', 'resistive']
senticnet['obstruct'] = [-0.571, 0, 0.814, -0.805, '#angry', '#disgusting', -0.73, 'block', 'jam', 'close_up', 'block_off', 'obturate']
senticnet['obstruct_justice'] = [-0.99, 0, 0.581, -0.97, '#sad', '#disgusting', -0.847, 'crime', 'obstruct', 'killer', 'murderer', 'thief']
senticnet['obstructer'] = [-0.929, 0, 0.576, -0.833, '#sad', '#disgusting', -0.779, 'naysayer', 'stonewaller', 'eristic', 'disputant', 'controversialist']
senticnet['obstruction'] = [-0.99, 0, 0.581, -0.97, '#sad', '#disgusting', -0.847, 'obstruct_justice', 'football_rule', 'block_road', 'hinder', 'interfere']
senticnet['obstructionist'] = [-0.973, 0, 0.62, -0.727, '#sad', '#disgusting', -0.773, 'obstructor', 'obstructer', 'technophobe', 'naysayer', 'resister']
senticnet['obstructor'] = [-0.988, 0, 0.811, -0.981, '#sad', '#disgusting', -0.927, 'naysayer', 'stonewaller', 'eristic', 'disputant', 'controversialist']
senticnet['obtain'] = [-0.058, 0.24, -0.137, 0.279, '#interesting', '#admirable', 0.108, 'acquire', 'business_transaction', 'get_gift', 'receive', 'hand_out']
senticnet['obtain_degree'] = [-0.058, 0.24, -0.137, 0.279, '#interesting', '#admirable', 0.108, 'get_degree', 'pass_exam', 'finish_college', 'prepare_exam', 'obtain']
senticnet['obtain_food'] = [0, -0.017, 0.065, -0.05, '#angry', '#disgusting', -0.033, 'decide_want_eat', 'find_restaurant', 'bite_food', 'make_sandwich', 'grow_organic_garden']
senticnet['obtain_information'] = [0.612, 0.99, 0, 0.713, '#interesting', '#admirable', 0.772, 'scan', 'comprehension', 'inform', 'learn_how_read', 'receive_information']
senticnet['obtain_knowledge'] = [0.731, 0, 0, 0.843, '#joyful', '#admirable', 0.525, 'increase_knowledge', 'become_knowledgeable', 'gain_knowledge', 'learn_much', 'better_understand']
senticnet['obtain_ticket'] = [-0.037, -0.051, 0.073, -0.086, '#angry', '#disgusting', -0.048, 'book_ticket', 'buy_concert_ticket', 'purchase_ticket', 'buy_ticket', 'pay_ticket']
senticnet['obtain_water'] = [-0.182, -0.078, 0, -0.203, '#sad', '#disgusting', -0.102, 'water_spill', 'water', 'atmosphere', 'cool_water', 'bad_drug']
senticnet['obtrude'] = [-0.536, 0, 0.662, -0.886, '#angry', '#disgusting', -0.695, 'intrude', 'inflict', 'clamp', 'give', 'communicate']
senticnet['obtrude_upon'] = [-0.954, 0, 0.703, -0.836, '#sad', '#disgusting', -0.831, 'raid', 'come_in', 'foray_into', 'enter', 'get_into']
senticnet['obturate'] = [-0.571, 0, 0.814, -0.805, '#angry', '#disgusting', -0.73, 'block', 'jam', 'close_up', 'obstruct', 'block_off']
senticnet['obtuse'] = [-0.949, 0, -0.808, 0, '#sad', '#scared', -0.586, 'dense', 'purblind', 'dull', 'dumb', 'dim']
senticnet['obtuseness'] = [-0.827, 0, 0.663, -0.508, '#sad', '#angry', -0.666, 'oscitance', 'dullness', 'sleepiness', 'drowsiness', 'somnolence']
senticnet['obviate'] = [-0.869, 0, -0.721, 0, '#sad', '#scared', -0.53, 'debar', 'rid_of', 'eliminate', 'forfend', 'forefend']
senticnet['obvious'] = [-0.954, 0, -0.799, 0, '#sad', '#scared', -0.584, 'sudden', 'suddenly', 'lovely', 'translucent', 'situation']
senticnet['obviousness'] = [-0.516, 0, 0.607, -0.769, '#angry', '#disgusting', -0.631, 'offensiveness', 'odiousness', 'distastefulness', 'patency', 'blatancy']
senticnet['occasion'] = [0.701, 0.867, 0, 0, '#joyful', '#interesting', 0.523, 'festivity', 'special_day', 'birthday', 'special_time', 'cake_candle']
senticnet['occasion_dress'] = [0, 0.093, 0, 0.07, '#interesting', '#admirable', 0.054, 'dress_up', 'dress', 'dress_appropriately', 'go_outdoors', 'doll_up']
senticnet['occasions'] = [0.057, -0.038, 0, 0, '#joyful', '#surprising', 0.032, 'cheap_stuff', 'save_money', 'less_quality', 'discount_store', 'poor_people']
senticnet['occluded'] = [-0.963, 0, 0.742, 0, '#sad', '#angry', -0.568, 'block', 'obstruct', 'close', 'clogged', 'shutter']
senticnet['occult'] = [-0.519, 0, 0.979, -0.89, '#angry', '#disgusting', -0.796, 'invisible', 'concealed', 'nonvisual', 'hidden', 'out_of_sight']
senticnet['occupation'] = [0, 0.112, -0.049, 0.099, '#interesting', '#admirable', 0.054, 'profession', 'career', 'vocation', 'important_job', 'laborer']
senticnet['occupational_hazard'] = [-0.523, 0, 0.577, -0.93, '#angry', '#disgusting', -0.677, 'peril', 'jeopardy', 'endangerment', 'hazard', 'risk']
senticnet['occupy'] = [-0.756, 0, 0, -0.871, '#sad', '#disgusting', -0.542, 'concerned', 'humility', 'desperate', 'compassionate', 'anxious']
senticnet['occupy_by_force'] = [-0.967, 0, 0.609, -0.993, '#sad', '#disgusting', -0.856, 'fight', 'battle', 'conflict', 'war', 'quarrel']
senticnet['occupy_mind'] = [0.912, 0, 0, 0.974, '#joyful', '#admirable', 0.629, 'become_famous', 'ego_boost', 'get_excited', 'spread_idea', 'show_off']
senticnet['occur'] = [0.879, -0.956, 0, 0.766, '#joyful', '#surprising', 0.867, 'happen', 'shine', 'come_up', 'chance', 'break']
senticnet['occurrence'] = [0.078, -0.034, -0.046, 0.105, '#joyful', '#admirable', 0.057, 'special_time', 'special_day', 'special_moment', 'special_occasion', 'yearly_celebration']
senticnet['occurrent'] = [-0.737, 0, 0.591, -0.681, '#sad', '#disgusting', -0.67, 'whammy', 'happening', 'occurrence', 'setback', 'natural_event']
senticnet['ocean'] = [0.078, -0.034, -0.046, 0.105, '#joyful', '#admirable', 0.057, 'aquarium', 'underwater', 'pacific_ocean', 'sea', 'ocean_wave']
senticnet['ocean_animal'] = [0.052, 0.066, 0, 0.106, '#interesting', '#admirable', 0.075, 'shell_fish', 'seafood', 'marine_animal', 'sometimes', 'crustacean']
senticnet['ocean_beach'] = [0.03, 0.117, 0, 0.084, '#interesting', '#admirable', 0.077, 'beach', 'waterfront', 'ocean', 'coast', 'sea']
senticnet['ocean_bottom'] = [0.979, -0.75, 0, 0.764, '#joyful', '#admirable', 0.831, 'ocean_floor', 'sea_floor', 'twilight_zone', 'seabed', 'sea_bottom']
senticnet['ocean_edge'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'bottom_ocean', 'ocean_floor', 'sea_floor', 'surface_earth', 'seabed']
senticnet['ocean_floor'] = [-0.024, -0.015, 0.03, -0.049, '#angry', '#disgusting', -0.029, 'ocean_beach', 'beach', 'water_sea', 'shore', 'ground_ocean']
senticnet['ocean_ground'] = [-0.044, -0.015, 0.103, 0, '#sad', '#angry', -0.044, 'near_beach', 'along_beach', 'full_water', 'sea_bed', 'salty']
senticnet['ocean_movement'] = [0.895, 0.709, 0, 0, '#joyful', '#interesting', 0.535, 'sea_movement', 'fast_water', 'water_movement', 'ebb', 'water_motion']
senticnet['ocean_shore'] = [0, 0.112, 0, 0.137, '#interesting', '#admirable', 0.083, 'island', 'popular_vacation_destination', 'land_feature', 'near_ocean', 'oceanside']
senticnet['ocean_tide'] = [0.889, -0.995, 0, 0, '#joyful', '#surprising', 0.628, 'sea_movement', 'ocean_movement', 'fast_water', 'water_motion', 'water_movement']
senticnet['ocean_water'] = [-0.024, -0.022, 0.064, -0.071, '#angry', '#disgusting', -0.046, 'fillet', 'fillet_fish', 'chowder', 'port', 'underwater']
senticnet['ocean_wave'] = [0, -0.078, 0, 0.116, '#surprising', '#admirable', 0.065, 'ocean_movement', 'sea_movement', 'fast_water', 'water_movement', 'tsunami']
senticnet['oceanside'] = [-0.03, 0.085, 0, 0.127, '#interesting', '#admirable', 0.061, 'ocean', 'under_water', 'underwater', 'beach', 'big_lake']
senticnet['octagon'] = [0.037, 0.082, 0.055, 0.183, '#interesting', '#admirable', 0.082, 'hexagon', 'geometric_figure', 'parallelogram', 'trapezoid', 'geometric_object']
senticnet['octogenarian'] = [0.556, -0.641, 0, 0.64, '#surprising', '#admirable', 0.612, 'centenarian', 'nonagenarian', 'golden_ager', 'septuagenarian', 'sexagenarian']
senticnet['octopod'] = [-0.523, 0, 0.728, -0.926, '#angry', '#disgusting', -0.726, 'nautilus', 'cephalopod', 'cephalopod_mollusk', 'paper_nautilus', 'octopus']
senticnet['octopus'] = [-0.523, 0, 0.728, -0.926, '#angry', '#disgusting', -0.726, 'nautilus', 'cephalopod', 'cephalopod_mollusk', 'paper_nautilus', 'octopod']
senticnet['oculus_dexter'] = [0.753, -0.647, 0, 0.556, '#joyful', '#surprising', 0.652, 'eye', 'stemma', 'naked_eye', 'peeper', 'oculus_sinister']
senticnet['oculus_sinister'] = [0.753, -0.647, 0, 0.556, '#joyful', '#surprising', 0.652, 'oculus_dexter', 'stemma', 'naked_eye', 'peeper', 'eye']
senticnet['odd'] = [0.036, 0.121, 0, 0.139, '#interesting', '#admirable', 0.099, 'high_level', 'number', 'sum_total', 'maximum', 'backside']
senticnet['oddity'] = [0.808, -0.981, 0, 0.628, '#joyful', '#surprising', 0.806, 'curio', 'collector_item', 'curiosity', 'peculiarity', 'oddment']
senticnet['oddment'] = [0.808, -0.981, 0, 0.628, '#joyful', '#surprising', 0.806, 'curio', 'oddity', 'curiosity', 'peculiarity', 'collector_item']
senticnet['odds'] = [0, 0, -0.942, -0.922, '#scared', '#disgusting', -0.621, 'difficulty', 'dilemma', 'bad_situation', 'misplace', 'sadness']
senticnet['ode'] = [0.237, 0.094, -0.077, 0.124, '#joyful', '#admirable', 0.126, 'verse', 'song_lyric', 'like_poetry', 'rhyme', 'song']
senticnet['odiously'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repulsive', 'repugnant', 'detestably', 'abominably', 'detestable']
senticnet['odiousness'] = [-0.97, 0, 0.536, -0.583, '#sad', '#disgusting', -0.696, 'lousiness', 'vileness', 'sliminess', 'unpleasantness', 'blatancy']
senticnet['odist'] = [0.836, -0.602, 0, 0.845, '#joyful', '#admirable', 0.761, 'poetess', 'bard', 'elegist', 'poet', 'poet_laureate']
senticnet['odium'] = [-0.063, 0.183, 0.651, -0.642, '#angry', '#disgusting', -0.391, 'abhorrence', 'abomination', 'detestation', 'execration', 'loathing']
senticnet['odontiasis'] = [-0.719, 0, 0.84, -0.891, '#angry', '#disgusting', -0.817, 'precocious_dentition', 'growth', 'growing', 'maturation', 'development']
senticnet['odor'] = [0, 0.069, 0, 0.103, '#interesting', '#admirable', 0.057, 'stick_out', 'nose', 'sniff', 'scent', 'smell']
senticnet['odorize'] = [-0.674, 0, 0.503, -0.67, '#sad', '#disgusting', -0.616, 'stink_up', 'smell_up', 'stink_out', 'incense', 'perfume']
senticnet['oedema'] = [-0.626, 0, 0.585, -0.569, '#sad', '#angry', -0.593, 'angioedema', 'atrophedema', 'giant_hives', 'periodic_edema', 'lymphedema']
senticnet['of_essence'] = [0.86, -0.857, 0, 0.864, '#joyful', '#admirable', 0.86, 'all_important', 'of_import', 'outstanding', 'master', 'chief']
senticnet['of_import'] = [0.86, -0.857, 0, 0.864, '#joyful', '#admirable', 0.86, 'all_important', 'of_essence', 'outstanding', 'master', 'chief']
senticnet['off'] = [-0.751, 0, 0.785, -0.7, '#sad', '#angry', -0.745, 'disappointing', 'dissatisfactory', 'unsatisfying', 'unsatisfactory', 'unacceptable']
senticnet['off_guard'] = [-0.926, 0, 0.659, -0.814, '#sad', '#disgusting', -0.8, 'unripe', 'napping', 'unready', 'off_one_guard', 'off_his_guard']
senticnet['off_his_guard'] = [-0.926, 0, 0.659, -0.814, '#sad', '#disgusting', -0.8, 'unripe', 'napping', 'off_guard', 'off_one_guard', 'unready']
senticnet['off_one_guard'] = [-0.926, 0, 0.659, -0.814, '#sad', '#disgusting', -0.8, 'unripe', 'napping', 'off_guard', 'unready', 'off_his_guard']
senticnet['offend'] = [-0.791, 0, 0.82, -0.986, '#angry', '#disgusting', -0.866, 'bothersome', 'disgust', 'pique', 'crucify', 'dun']
senticnet['offend_other_person'] = [-0.08, -0.047, 0.201, -0.419, '#angry', '#disgusting', -0.218, 'make_face', 'wave_hand', 'dance_around', 'get_angry', 'wet_pant']
senticnet['offender'] = [-0.902, 0, 0.896, -0.863, '#sad', '#angry', -0.887, 'break_law', 'projector', 'actor', 'give_performance', 'theater_box']
senticnet['offense'] = [-0.9, -0.783, 0.904, 0, '#sad', '#angry', -0.34, 'despise', 'scorn', 'offensive', 'dislike', 'isolation']
senticnet['offensive'] = [0, 0, 0.972, -0.906, '#angry', '#disgusting', -0.626, 'aggressiveness', 'despise', 'maleficence', 'malign', 'malefic']
senticnet['offensiveness'] = [-0.568, 0, 0.829, -0.617, '#angry', '#disgusting', -0.671, 'lousiness', 'vileness', 'sliminess', 'unpleasantness', 'blatancy']
senticnet['offer'] = [0, 0.326, -0.284, 0.369, '#interesting', '#admirable', 0.137, 'cope', 'contribution', 'receive', 'give', 'deal']
senticnet['offer_accommodation'] = [0, 0.084, 0, 0.083, '#interesting', '#admirable', 0.056, 'home_sweet_home', 'guest', 'take_care', 'host', 'show_around']
senticnet['offer_help'] = [0, 0, 0, 0.843, '#admirable', '#admirable', 0.281, 'captain_boat', 'welcome_friend', 'chair_meet', 'agree_disagree', 'age_gracefully']
senticnet['offer_money'] = [0, 0, 0, 0.819, '#admirable', '#admirable', 0.273, 'enter_store', 'complete_job', 'save_money', 'pay_fee', 'count_money']
senticnet['offer_opinion'] = [0.718, 0.642, 0, 0.603, '#joyful', '#interesting', 0.654, 'learn_new_subject', 'inform', 'teach', 'tell_information', 'tell_other_person']
senticnet['offer_solace'] = [0, 0, 0, 0.719, '#admirable', '#admirable', 0.24, 'hunt_duck', 'talk_telephone', 'part_of_way', 'shake_hand', 'call_mom']
senticnet['office'] = [0.026, 0.082, 0, 0, '#joyful', '#interesting', 0.036, 'account_department', 'accountant_office', 'stationery_store', 'shirt_pocket', 'desk_drawer']
senticnet['office_build'] = [0.057, -0.038, 0, 0, '#joyful', '#surprising', 0.032, 'phone_booth', 'internet_cafe', 'office', 'discount_store', 'observatory']
senticnet['office_job'] = [-0.034, 0.166, -0.115, 0.152, '#interesting', '#admirable', 0.056, 'hire_help', 'occupation', 'task', 'career', 'police_work']
senticnet['office_space'] = [0.03, 0, 0, 0.071, '#joyful', '#admirable', 0.034, 'office', 'workplace', 'work_area', 'other_work', 'place_work']
senticnet['office_stuff'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'smart_technology', 'pencil_sharpener', 'electric_pencil_sharpener', 'school_stuff', 'pencil']
senticnet['office_worker'] = [0, 0.764, 0, 0.968, '#interesting', '#admirable', 0.577, 'manager', 'colleague', 'public_servant', 'coworker', 'secretary']
senticnet['officer'] = [0, 0.802, 0, 0.843, '#interesting', '#admirable', 0.548, 'head_guy', 'leadership_position', 'navy_officer', 'leader', 'police_rank']
senticnet['official'] = [0.046, 0.137, 0.009, 0.141, '#interesting', '#admirable', 0.105, 'supreme_court', 'legal', 'judge_jury', 'arbiter', 'lawyer']
senticnet['officious'] = [-0.997, 0, 0.851, -0.896, '#sad', '#disgusting', -0.915, 'interfering', 'meddlesome', 'meddling', 'intrusive', 'busybodied']
senticnet['offset'] = [0.702, -0.543, 0, 0.614, '#joyful', '#admirable', 0.62, 'point_in_time', 'threshold', 'birth', 'incipiency', 'incipience']
senticnet['offspring'] = [-0.062, 0.2, -0.1, 0.168, '#interesting', '#admirable', 0.069, 'orphan', 'take_child', 'become_parent', 'progeny', 'much_child']
senticnet['often_red'] = [0, 0.114, 0, 0.122, '#interesting', '#admirable', 0.079, 'red', 'delicate', 'red_color', 'orifice', 'bright_red']
senticnet['ogee_arch'] = [0.641, -0.569, 0, 0.748, '#joyful', '#admirable', 0.653, 'trefoil_arch', 'pointed_arch', 'keel_arch', 'drop_arch', 'arch']
senticnet['ogre'] = [-0.823, 0, 0.635, -0.569, '#sad', '#angry', -0.676, 'fiend', 'demoniac', 'demon', 'devil', 'monster']
senticnet['ohm'] = [0, 0, 0.122, 0, '#angry', '#angry', -0.041, 'mile', 'inch', 'meter', 'ounce', 'length']
senticnet['oil'] = [0, 0, 0, 0.882, '#admirable', '#admirable', 0.294, 'lubricant', 'fuel', 'gas', 'inert_gas', 'diesel']
senticnet['oil_hinge'] = [-0.937, 0, 0, -0.902, '#sad', '#disgusting', -0.613, 'marry_man', 'service_car', 'date_woman', 'man_post', 'date_man']
senticnet['oil_paint'] = [0, 0.084, 0, 0.095, '#interesting', '#admirable', 0.06, 'oil_painting', 'wall_art', 'artist_tool', 'artist', 'painting']
senticnet['oil_painting'] = [0.041, 0.112, 0, 0.077, '#interesting', '#admirable', 0.077, 'oil_paint', 'artist_tool', 'painter', 'artist', 'painting']
senticnet['oil_palm'] = [0.635, -0.847, 0, 0.85, '#surprising', '#admirable', 0.777, 'feather_palm', 'babassu', 'babassu_palm', 'coco_de_macao', 'wax_palm']
senticnet['oil_stain'] = [-0.518, 0, 0.937, -0.926, '#angry', '#disgusting', -0.794, 'bloodstain', 'mud_stain', 'iron_mold', 'iron_mould', 'discoloration']
senticnet['oil_tanker'] = [0, 0, 0, -0.08, '#disgusting', '#disgusting', -0.027, 'submarine', 'titanic', 'vessel', 'lifeboat', 'battleship']
senticnet['oilcloth'] = [-0.903, 0, 0, -0.894, '#sad', '#disgusting', -0.599, 'needle', 'sew_needle', 'haircloth', 'needle_thread', 'sew_machine']
senticnet['oily'] = [0, 0, -0.903, -0.951, '#scared', '#disgusting', -0.618, 'sebaceous', 'greasy', 'fulsome', 'oleaginous', 'buttery']
senticnet['oily_road'] = [-0.988, 0, 0.674, -0.933, '#sad', '#disgusting', -0.865, 'wet_floor', 'black_liquid', 'slippery', 'slick', 'dangerous']
senticnet['ointment'] = [-0.892, 0, -0.98, 0, '#sad', '#scared', -0.624, 'peanut', 'leave_over', 'floppy', 'circular_motion', 'store_vegetable']
senticnet['okay'] = [0.075, 0.229, -0.176, 0.409, '#interesting', '#admirable', 0.179, 'reciprocal', 'all_right', 'good_etiquette', 'politeness', 'good_behavior']
senticnet['okeh'] = [0.751, -0.986, 0, 0.989, '#surprising', '#admirable', 0.909, 'okay', 'approval', 'commendation', 'okey', 'imprimatur']
senticnet['okey'] = [0.751, -0.986, 0, 0.989, '#surprising', '#admirable', 0.909, 'okay', 'approval', 'commendation', 'imprimatur', 'okeh']
senticnet['old'] = [-0.871, 0, -0.729, 0, '#sad', '#scared', -0.533, 'elderly', 'grumpy', 'age', 'ancient', 'get_old']
senticnet['old-fashioned'] = [0, 0, -0.841, -0.882, '#scared', '#disgusting', -0.574, 'old_hat', 'demode', 'old', 'outmoded', 'antique']
senticnet['old_age'] = [-0.09, 0, -0.19, -0.153, '#scared', '#disgusting', -0.144, 'drug_addiction', 'get_lung_cancer', 'suicide', 'die', 'execute']
senticnet['old_bag'] = [-0.598, 0, 0.573, -0.56, '#sad', '#angry', -0.577, 'termagant', 'disagreeable_woman', 'shrew', 'frump', 'hellcat']
senticnet['old_book'] = [0, 0.098, 0, 0, '#interesting', '#interesting', 0.033, 'gym_equipment', 'exercise_equipment', 'plumber', 'car_stereo', 'sunscreen']
senticnet['old_building'] = [-0.072, 0, 0, -0.032, '#sad', '#disgusting', -0.035, 'skyscraper', 'building', 'tall_building', 'nuclear_power_plant', 'government_office']
senticnet['old_car'] = [0, 0, 0, 0.103, '#admirable', '#admirable', 0.034, 'fancy_car', 'car_model', 'expensive_car', 'most_cars', 'car']
senticnet['old_child'] = [0, 0.079, 0, 0, '#interesting', '#interesting', 0.026, 'descendant', 'female_child', 'human_offspring', 'male_child', 'offspring']
senticnet['old_clothes'] = [0, -0.016, 0.026, -0.066, '#angry', '#disgusting', -0.025, 'junk', 'old_stuff', 'egg_shell', 'food_scrap', 'old_paper']
senticnet['old_coin'] = [0, 0.066, 0.041, 0.054, '#interesting', '#admirable', 0.026, 'metal_coin', 'coin', 'money', 'monetary_unit', 'down_payment']
senticnet['old_computer'] = [-0.035, -0.098, 0.164, -0.197, '#angry', '#disgusting', -0.099, 'old_technology', 'pair_of_scissors', 'power_drill', 'push_pin', 'thumb_tack']
senticnet['old_dance'] = [0.203, -0.102, 0.013, 0, '#joyful', '#surprising', 0.097, 'dance', 'slow_dance', 'enter_contest', 'stout', 'dancer']
senticnet['old_fashion'] = [0.025, -0.028, 0, 0.054, '#surprising', '#admirable', 0.036, 'rock_music', 'old', 'clock_face', 'elements', 'bright']
senticnet['old_fashioned'] = [-0.121, -0.06, -0.089, -0.036, '#sad', '#scared', -0.062, 'passe', 'unglamorous', 'special_person', 'bloke', 'male']
senticnet['old_folk'] = [0, 0, -0.054, -0.08, '#scared', '#disgusting', -0.045, 'grandma_house', 'chess_tournament', 'laboratory', 'computer_lab', 'old_folk_home']
senticnet['old_folk_home'] = [0, 0, -0.054, -0.08, '#scared', '#disgusting', -0.045, 'grandma_house', 'chess_tournament', 'laboratory', 'computer_lab', 'old_folk']
senticnet['old_food'] = [-0.908, 0, 0.282, -0.97, '#sad', '#disgusting', -0.72, 'trash', 'waste', 'garbage', 'rubbish', 'refuse']
senticnet['old_friend'] = [0.877, -0.738, 0, 0, '#joyful', '#surprising', 0.538, 'director_chair', 'alcohol', 'bride_groom', 'attendee', 'coworker']
senticnet['old_game'] = [0, -0.076, 0, 0.081, '#surprising', '#admirable', 0.052, 'consider_good_luck', 'game', 'form_of_gambling', 'popular_game', 'game_skill']
senticnet['old_gold'] = [-0.514, 0, 0.626, -0.544, '#angry', '#disgusting', -0.561, 'brownish_yellow', 'canary_yellow', 'yellowness', 'gold', 'canary']
senticnet['old_grandchild'] = [0.951, -0.774, 0, 0, '#joyful', '#surprising', 0.575, 'informal', 'family', 'lullaby', 'play_together', 'family_tree']
senticnet['old_house'] = [0.101, 0.099, 0, 0.169, '#joyful', '#admirable', 0.123, 'family_home', 'small_home', 'own_house', 'appliance_store', 'residence']
senticnet['old_lady'] = [0, 0, -0.064, -0.116, '#scared', '#disgusting', -0.06, 'elderly_person', 'hide-a-bed', 'homosexual', 'linen_chest', 'dust_mite']
senticnet['old_lady_house'] = [0.146, -0.217, -0.046, 0.139, '#joyful', '#surprising', 0.152, 'comic_book', 'cartoon', 'book', 'comic', 'comic_strip']
senticnet['old_man'] = [0.126, 0.187, -0.106, 0.155, '#interesting', '#admirable', 0.121, 'female', 'female_parent', 'care_giver', 'wisdom', 'happy_together']
senticnet['old_movie'] = [-0.042, -0.007, -0.051, 0, '#sad', '#scared', -0.029, 'music_school', 'civic_center', 'opus_house', 'choir', 'concert']
senticnet['old_newspaper'] = [-0.903, 0, 0, -0.747, '#sad', '#disgusting', -0.55, 'old_paper', 'food_scrap', 'mind_child', 'moldy_food', 'egg_shell']
senticnet['old_object'] = [0.02, 0, 0, 0.084, '#joyful', '#admirable', 0.035, 'small_shop', 'shop', 'sell_stuff', 'item_sell', 'vintage']
senticnet['old_paper'] = [0, -0.016, 0.026, -0.066, '#angry', '#disgusting', -0.025, 'junk', 'old_stuff', 'egg_shell', 'food_scrap', 'old_clothes']
senticnet['old_people'] = [-0.055, -0.029, -0.06, -0.126, '#scared', '#disgusting', -0.071, 'old_person', 'nurse', 'elderly_person', 'dislike_person', 'sick_person']
senticnet['old_person'] = [-0.055, -0.029, -0.06, -0.126, '#scared', '#disgusting', -0.071, 'old_people', 'nurse', 'elderly_person', 'dislike_person', 'sick_person']
senticnet['old_photograph'] = [-0.045, 0, -0.08, -0.078, '#scared', '#disgusting', -0.068, 'wheelchair', 'dirty_laundry', 'wife', 'hot_chick', 'mommy']
senticnet['old_salt'] = [0.587, -0.67, 0, 0.729, '#surprising', '#admirable', 0.662, 'mariner', 'seaman', 'tar', 'sea_lawyer', 'seafarer']
senticnet['old_sock'] = [0, -0.019, 0.075, -0.078, '#angry', '#disgusting', -0.045, 'dirty_magazine', 'cookie_crumb', 'smelly', 'dirty_sock', 'dust_mite']
senticnet['old_software'] = [0, 0, 0.894, -0.825, '#angry', '#disgusting', -0.573, 'get_old', 'become_obsolete', 'unglam', 'old_technology', 'overrated']
senticnet['old_stuff'] = [-0.912, 0, 0.618, -0.932, '#sad', '#disgusting', -0.821, 'get_stolen', 'second_hand', 'give_away', 'lose_wallet', 'away']
senticnet['old_technology'] = [0, 0, 0.721, -0.979, '#angry', '#disgusting', -0.567, 'software_crash', 'old_computer', 'seventy', 'music_storage', 'disk']
senticnet['old_testament'] = [0, 0.776, 0, 0.879, '#interesting', '#admirable', 0.552, 'cook_book', 'a_lot_of_books', 'bookmark', 'religious_tract', 'index_card_drawer']
senticnet['old_time'] = [0.021, 0.069, 0.067, 0.086, '#interesting', '#admirable', 0.036, 'wall_street', 'many_floors', 'old_object', 'item_sell', 'school_subject']
senticnet['old_west'] = [0.823, -0.992, 0, 0, '#joyful', '#surprising', 0.605, 'bar', 'tavern', 'pub', 'eat_establishment', 'internet_site']
senticnet['old_wives_tale'] = [0.95, -0.863, 0, 0.947, '#joyful', '#admirable', 0.92, 'content', 'lore', 'folklore', 'cognitive_content', 'mental_object']
senticnet['old_woman'] = [0.52, -0.773, 0, 0.921, '#surprising', '#admirable', 0.738, 'oldster', 'old_person', 'senior_citizen', 'golden_ager', 'beldam']
senticnet['older'] = [0.822, -0.863, 0, 0.818, '#joyful', '#surprising', 0.834, 'practiced', 'veteran', 'experienced', 'seasoned', 'knowledgeable']
senticnet['oldster'] = [0.795, -0.852, 0, 0.973, '#surprising', '#admirable', 0.873, 'centenarian', 'nonagenarian', 'octogenarian', 'septuagenarian', 'sexagenarian']
senticnet['olfactory_property'] = [-0.984, 0, 0.967, -0.606, '#sad', '#angry', -0.852, 'body_odor', 'aroma', 'scent', 'fetidness', 'smell']
senticnet['olfactory_sensation'] = [-0.512, 0, 0.986, -0.833, '#angry', '#disgusting', -0.777, 'niff', 'pong', 'smell', 'odor', 'fetor']
senticnet['oligarchy'] = [0.028, 0.12, 0.068, 0.176, '#interesting', '#admirable', 0.085, 'elite', 'number_person', 'count_person', 'small_group', 'enumeration']
senticnet['olympiads'] = [0, 0.069, 0, 0.111, '#interesting', '#admirable', 0.06, 'hold_every_four_years', 'event', 'important_event', 'important_game', 'important_occasion']
senticnet['olympic_event'] = [0.778, 0, 0, 0.935, '#joyful', '#admirable', 0.571, 'athletics', 'train_hard', 'shape', 'form_of_exercise', 'good_shape']
senticnet['olympic_game'] = [0.915, 0, 0.724, 0.952, '#joyful', '#admirable', 0.381, 'influence_worldwide', 'celebrate', 'world_event', 'international_affair', 'magnificent']
senticnet['olympic_medal'] = [-0.04, -0.021, 0.027, -0.031, '#sad', '#disgusting', -0.026, 'precious_metal', 'many_different_kinds', 'shiny_metal', 'bloodstone', 'valuable_metal']
senticnet['olympic_sport'] = [0, -0.046, 0.037, 0.093, '#surprising', '#admirable', 0.034, 'fun_sport', 'sport', 'pastime', 'dangerous_sport', 'outdoor_sport']
senticnet['omega'] = [0, 0.231, -0.111, 0.229, '#interesting', '#admirable', 0.116, 'finish_complete', 'end_point', 'end', 'finish', 'commence']
senticnet['omen'] = [0.851, -0.657, 0, 0.66, '#joyful', '#admirable', 0.723, 'auspice', 'portent', 'presage', 'prognostic', 'prognostication']
senticnet['ominous'] = [0, 0, 0.764, -0.856, '#angry', '#disgusting', -0.54, 'menacing', 'baleful', 'forbidding', 'minacious', 'minatory']
senticnet['omniscient'] = [0.071, 0.222, -0.107, 0.234, '#interesting', '#admirable', 0.14, 'baron', 'almighty', 'deity', 'nobility', 'jesus_christ']
senticnet['omnivore'] = [0.046, 0.085, 0, 0.061, '#interesting', '#admirable', 0.064, 'high_animal', 'furry_creature', 'small_furry', 'small_rodent', 'dog']
senticnet['on_alert'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'alert', 'watchful', 'guard', 'vigilant', 'wary']
senticnet['on_cloud_nine'] = [0.673, 0.631, -0.233, 0.309, '#joyful', '#interesting', 0.46, 'exultingly', 'exultation', 'jubilance', 'have_fun', 'walk_on_air']
senticnet['on_fence'] = [0.778, -0.502, 0, 0.517, '#joyful', '#admirable', 0.599, 'indecisive', 'suspensive', 'undecided', 'hesitant', 'hesitating']
senticnet['on_person'] = [0.064, 0.117, 0, 0.125, '#interesting', '#admirable', 0.102, 'head', 'hair', 'human_part', 'part_of_body', 'body_organ']
senticnet['on_sale'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'save_money', 'good_customer', 'better_price', 'sales', 'buy_cheaper']
senticnet['onanism'] = [0.569, -0.988, 0, 0.935, '#surprising', '#admirable', 0.831, 'wank', 'frottage', 'jacking_off', 'jerking_off', 'hand_job']
senticnet['one'] = [-0.61, 0, 0.856, -0.826, '#angry', '#disgusting', -0.764, 'unfixed', 'indefinite', 'nebulous', 'indecisive', 'coy']
senticnet['one_and_only'] = [0.816, -0.599, 0, 0.947, '#joyful', '#admirable', 0.787, 'matchless', 'nonpareil', 'incomparable', 'peerless', 'unmatchable']
senticnet['one_more'] = [0, 0.173, 0.021, 0.223, '#interesting', '#admirable', 0.125, 'plus', 'twice', 'sequence', 'redo', 'bis']
senticnet['one_night_stand'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'find_motel', 'find_bedroom', 'find_car', 'cover_pillow', 'bed']
senticnet['one_of_thing'] = [0.097, 0.076, 0, 0.108, '#joyful', '#admirable', 0.094, 'topic', 'subject', 'method', 'school_paper', 'scientific_method']
senticnet['one_way'] = [0, 0.071, 0, 0.143, '#interesting', '#admirable', 0.071, 'post_notice', 'gps', 'way', 'indicator', 'arrow']
senticnet['oneself'] = [-0.421, -0.187, 0.017, -0.535, '#sad', '#disgusting', -0.262, 'migraine', 'lay_off', 'forget_everything', 'call_name', 'bad_vision']
senticnet['onion'] = [0.754, -0.734, 0, 0, '#joyful', '#surprising', 0.496, 'prune', 'tomato', 'pea', 'berry', 'fig']
senticnet['onion_smut'] = [-0.935, 0, 0.699, -0.91, '#sad', '#disgusting', -0.848, 'smut_fungus', 'head_smut', 'stinking_smut', 'flag_smut_fungus', 'covered_smut']
senticnet['online'] = [0, 0.087, 0, 0, '#interesting', '#interesting', 0.029, 'find_address', 'find_computer', 'internet_connection', 'hard_drive', 'buy_computer']
senticnet['online_booking'] = [0, 0.084, 0, 0, '#interesting', '#interesting', 0.028, 'reservation', 'book_hotel', 'staycation', 'rate', 'currency']
senticnet['only'] = [0, 0, -0.78, -0.719, '#scared', '#disgusting', -0.5, 'sole', 'solitary', 'single', 'lonesome', 'alone']
senticnet['only_bird'] = [0.036, 0.127, 0.019, 0.225, '#interesting', '#admirable', 0.123, 'bird', 'sing_bird', 'hatch', 'vulture', 'batman']
senticnet['only_mammal'] = [0.039, 0.086, 0, 0, '#joyful', '#interesting', 0.042, 'leopard', 'most_cats', 'lynx', 'mane', 'hare']
senticnet['onrush'] = [-0.798, 0, 0.59, -0.567, '#sad', '#angry', -0.652, 'debris_surge', 'debris_storm', 'flowing', 'surge', 'flow']
senticnet['ontogeny'] = [-0.595, 0, 0.983, -0.675, '#angry', '#disgusting', -0.751, 'growth', 'growing', 'maturation', 'development', 'caenogenesis']
senticnet['onus'] = [-0.813, 0, 0.979, -0.882, '#angry', '#disgusting', -0.891, 'vexation', 'dead_weight', 'imposition', 'worry', 'concern']
senticnet['onward_motion'] = [0.903, -0.886, 0, 0.556, '#joyful', '#surprising', 0.782, 'plain_sailing', 'clear_sailing', 'easy_going', 'move', 'push']
senticnet['ooh'] = [-0.786, 0, 0.701, -0.782, '#sad', '#disgusting', -0.756, 'express', 'utter', 'gee', 'cry_out', 'aah']
senticnet['ooze'] = [-0.095, 0, -0.073, -0.06, '#sad', '#scared', -0.076, 'blown', 'gape', 'move_air', 'mud', 'gash']
senticnet['oozing'] = [-0.617, 0, 0.732, -0.591, '#sad', '#angry', -0.647, 'drafty', 'draughty', 'porous', 'drippy', 'leaky']
senticnet['opacity'] = [0.906, -0.601, 0, 0.653, '#joyful', '#admirable', 0.72, 'opaqueness', 'faintness', 'dimness', 'blurriness', 'vagueness']
senticnet['opaque'] = [0, 0.776, 0, 0.782, '#interesting', '#admirable', 0.519, 'solid', 'brown', 'red_stone', 'precious_jewel', 'generic']
senticnet['opaqueness'] = [0.906, -0.601, 0, 0.653, '#joyful', '#admirable', 0.72, 'blurriness', 'faintness', 'dimness', 'opacity', 'vagueness']
senticnet['open'] = [-0.045, 0.12, -0.047, 0.128, '#interesting', '#admirable', 0.052, 'aperture', 'build_open', 'control_access', 'keep_someone_out', 'use_farm']
senticnet['open_area'] = [0, 0.093, 0.023, 0.095, '#interesting', '#admirable', 0.055, 'wide_open', 'area', 'acreage', 'acre', 'grassy_area']
senticnet['open_book'] = [0, 0.093, 0.023, 0.095, '#interesting', '#admirable', 0.055, 'buy_book', 'go_to_library', 'read_book', 'visit_library', 'find_book']
senticnet['open_bottle'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'drink_a_lot_of_booze', 'drink_excess', 'consume_alcohol', 'drink_a_lot_of_alcohol', 'buy_alcohol']
senticnet['open_business'] = [0, 0, 0.937, -0.879, '#angry', '#disgusting', -0.605, 'make_porn', 'sell_new_book', 'go_off_strike', 'go_public', 'deal_drug']
senticnet['open_car_door'] = [0, 0.128, -0.049, 0.064, '#interesting', '#admirable', 0.048, 'open_door', 'put_key_ignition', 'find_car_key', 'stay_sober', 'start_car_engine']
senticnet['open_close'] = [-0.05, 0.07, 0, 0.142, '#interesting', '#admirable', 0.054, 'house_open', 'sill', 'see_out', 'look_out', 'look_outside']
senticnet['open_close_mouth'] = [-0.085, 0, 0.031, -0.089, '#sad', '#disgusting', -0.068, 'raise_voice', 'choke_food', 'voice_opinion', 'act_out', 'annoy_other_person']
senticnet['open_container'] = [0, 0, 0.066, -0.077, '#angry', '#disgusting', -0.048, 'container_cup', 'cup', 'grease_trap', 'dish', 'salad_bowl']
senticnet['open_door'] = [-0.094, -0.02, 0.019, -0.028, '#sad', '#disgusting', -0.04, 'close_door', 'find_location', 'drop_ball', 'try_best', 'blow_horn']
senticnet['open_envelope'] = [0.038, -0.174, 0.024, 0.141, '#surprising', '#admirable', 0.11, 'open_letter', 'receive_mail', 'check_mail', 'write_friend', 'phone_bill']
senticnet['open_eye'] = [0, 0, 0.922, -0.749, '#angry', '#disgusting', -0.557, 'wear_glass', 'near_tv', 'blur_vision', 'turn_on_tv', 'eyesight']
senticnet['open_front_door'] = [-0.072, -0.003, 0.009, 0, '#sad', '#angry', -0.026, 'leave_house', 'decide_to_go', 'take_train', 'know_go', 'find_museum']
senticnet['open_gift'] = [0.03, -0.163, 0, 0.069, '#surprising', '#admirable', 0.087, 'make_someone_laugh', 'laugh_joke', 'give_assistance', 'please_parent', 'comfort_friend']
senticnet['open_land'] = [0, 0.084, 0.021, 0.063, '#interesting', '#admirable', 0.042, 'open_space', 'crop_place', 'grassy', 'cow_home', 'grass_area']
senticnet['open_letter'] = [-0.109, 0, -0.055, 0, '#sad', '#scared', -0.055, 'check_mail', 'receive_mail', 'crowd_elevator', 'find_book_library', 'page_through_book']
senticnet['open_lock'] = [-0.156, 0.081, -0.084, 0, '#sad', '#scared', -0.053, 'turn_key', 'free_prisoner', 'turn_car_off', 'open_door', 'start_engine']
senticnet['open_lock_door'] = [-0.024, 0.122, 0, 0.137, '#interesting', '#admirable', 0.078, 'unlock', 'hang_door', 'enter_room', 'control_access', 'separate_room']
senticnet['open_mailbox'] = [-0.052, 0.072, 0.012, 0.066, '#interesting', '#admirable', 0.025, 'sink_water', 'eat_cheese', 'bell_cat', 'eat', 'shoulder_burden']
senticnet['open_marriage'] = [-0.595, 0, 0.84, -0.809, '#angry', '#disgusting', -0.748, 'marriage', 'matrimony', 'union', 'spousal_relationship', 'wedlock']
senticnet['open_mind'] = [0.731, 0.542, 0, 0.827, '#joyful', '#admirable', 0.7, 'persistence', 'absorb_information', 'ask_expert', 'study_history', 'discover_new']
senticnet['open_mouth'] = [-0.053, 0, 0.03, -0.029, '#sad', '#angry', -0.037, 'clear_throat', 'speak_up', 'move_tongue', 'think_first', 'open_close_mouth']
senticnet['open_night'] = [0.116, -0.037, 0, 0, '#joyful', '#surprising', 0.051, 'meet_place', 'sticky_floor', 'row_seat', 'theater_box', 'place_to_drink']
senticnet['open_package'] = [0.719, -0.785, 0, 0, '#joyful', '#surprising', 0.501, 'cut_food', 'chop_vegetable', 'cut_vegetable', 'stir_pot', 'pierce']
senticnet['open_refrigerator'] = [0.964, -0.909, 0, 0, '#joyful', '#surprising', 0.624, 'hungry', 'prepare_breakfast', 'set_table', 'season_food', 'prepare_dinner']
senticnet['open_space'] = [0.022, 0.069, 0.027, 0.059, '#interesting', '#admirable', 0.041, 'open_land', 'grassy', 'terrain', 'flat_land', 'land']
senticnet['open_up'] = [0, 0.087, 0, 0, '#interesting', '#interesting', 0.029, 'know_how_read', 'learn_how_read', 'learn_read', 'literate', 'literacy']
senticnet['open_wallet'] = [-0.05, 0.14, 0.015, 0.082, '#interesting', '#admirable', 0.052, 'debit_card', 'cash_pay', 'need_earn_money', 'cash', 'earn_wage']
senticnet['open_wind'] = [-0.17, -0.056, 0, -0.198, '#sad', '#disgusting', -0.104, 'cause_bleed', 'laceration', 'painful_injury', 'gash', 'cut_skin']
senticnet['open_window'] = [-0.111, 0, -0.046, -0.126, '#sad', '#disgusting', -0.094, 'stagger', 'box_ear', 'lower_standard', 'correct_mistake', 'smoke_cigar']
senticnet['opener'] = [0.034, -0.024, 0.054, -0.092, '#angry', '#disgusting', -0.029, 'compass', 'swiss_army_knife', 'bake_pan', 'coffee_mug', 'wine_opener']
senticnet['openhearted'] = [0.552, 0.681, -0.294, 0.297, '#joyful', '#interesting', 0.412, 'charitable', 'good-hearted', 'large-hearted', 'benevolent', 'kindly']
senticnet['opening'] = [-0.935, 0, 0.607, -0.67, '#sad', '#disgusting', -0.737, 'blowhole', 'stigma', 'orifice', 'spiracle', 'porta']
senticnet['openness'] = [0.066, 0.07, 0.012, 0.095, '#interesting', '#admirable', 0.073, 'charisma', 'unlimited', 'eye_contact', 'hump_leg', 'start_conversation']
senticnet['opera'] = [0.231, 0, 0, 0.109, '#joyful', '#admirable', 0.113, 'watch_comedy', 'dinner_party', 'big_home', 'family_activity', 'anarchy']
senticnet['operable'] = [0.986, -0.629, 0, 0.807, '#joyful', '#admirable', 0.807, 'serviceable', 'functional', 'user_friendly', 'usable', 'operational']
senticnet['operate'] = [0, -0.831, 0, 0.989, '#surprising', '#admirable', 0.607, 'use', 'make_use', 'handle', 'do_it_yourself', 'activate']
senticnet['operate_computer'] = [0, -0.965, 0, 0.993, '#surprising', '#admirable', 0.653, 'browse_web', 'entertainment', 'kill_time', 'research', 'surf_net']
senticnet['operating_room'] = [0.839, -0.89, 0, 0.687, '#joyful', '#surprising', 0.805, 'emergency_room', 'room', 'hospital_room', 'operating_theater', 'surgery']
senticnet['operating_theater'] = [0.839, -0.89, 0, 0.687, '#joyful', '#surprising', 0.805, 'emergency_room', 'room', 'operating_room', 'hospital_room', 'surgery']
senticnet['operation'] = [-0.07, 0.069, -0.187, 0, '#sad', '#scared', -0.063, 'medical_procedure', 'cure', 'doctor_surgery', 'treatment', 'doctor_work']
senticnet['operational'] = [0.986, -0.629, 0, 0.807, '#joyful', '#admirable', 0.807, 'operable', 'functional', 'user_friendly', 'usable', 'serviceable']
senticnet['operative_system'] = [-0.023, 0.084, 0.036, 0.118, '#interesting', '#admirable', 0.048, 'house_open', 'computer_operative_system', 'look_out', 'look_glass', 'see_out']
senticnet['operator'] = [0, 0.352, -0.234, 0.307, '#interesting', '#admirable', 0.142, 'driver', 'specialist', 'employee', 'agent', 'surgeon']
senticnet['operoseness'] = [-0.646, 0, 0.928, -0.703, '#angry', '#disgusting', -0.759, 'difficulty', 'arduousness', 'strenuousness', 'laboriousness', 'effortfulness']
senticnet['ophidian'] = [-0.575, 0, 0.571, -0.975, '#sad', '#disgusting', -0.707, 'viper', 'elapid', 'elapid_snake', 'worm_snake', 'blind_snake']
senticnet['ophthalmia'] = [-0.698, 0, 0.852, -0.697, '#sad', '#angry', -0.749, 'conjunctivitis', 'ophthalmitis', 'rubor', 'redness', 'inflammation']
senticnet['ophthalmitis'] = [-0.698, 0, 0.852, -0.697, '#sad', '#angry', -0.749, 'ophthalmia', 'conjunctivitis', 'rubor', 'redness', 'inflammation']
senticnet['opiate'] = [0, -0.021, -0.096, -0.146, '#scared', '#disgusting', -0.074, 'cough_syrup', 'yellow_flower', 'flower', 'poisonous_plant', 'rubber_duck']
senticnet['opinion'] = [0, 0.352, -0.234, 0.307, '#interesting', '#admirable', 0.142, 'reason', 'forethought', 'consider', 'strong_feeling', 'choice']
senticnet['opinioned'] = [0, 0, 0.933, -0.887, '#angry', '#disgusting', -0.607, 'debate_politics', 'let_heard', 'conquer_opponent', 'dicussion', 'debate']
senticnet['opium'] = [0, 0.073, -0.093, -0.087, '#scared', '#disgusting', -0.036, 'cotton_boll', 'asbestos', 'corn', 'cauliflower', 'rice']
senticnet['opponent'] = [0, 0, 0.8, -0.859, '#angry', '#disgusting', -0.553, 'beat_up', 'rival', 'opposition', 'duel', 'strategy']
senticnet['opportune'] = [0.915, -0.99, 0, 0.673, '#joyful', '#surprising', 0.859, 'ripe', 'good', 'right', 'timely', 'seasonable']
senticnet['opportunism'] = [-0.813, 0, 0.886, -0.656, '#sad', '#angry', -0.785, 'selfishness', 'greediness', 'rapaciousness', 'voraciousness', 'expedience']
senticnet['opportunity'] = [0.027, 0.254, -0.206, 0.294, '#interesting', '#admirable', 0.123, 'contribution', 'improvement', 'receive', 'give', 'bid']
senticnet['oppose'] = [-0.066, 0.068, -0.089, -0.074, '#scared', '#disgusting', -0.054, 'fist', 'whack', 'rudeness', 'make_fist', 'hand']
senticnet['opposite'] = [-0.946, 0, 0, -0.778, '#sad', '#disgusting', -0.575, 'contrary', 'contradiction', 'lie', 'liar', 'bad_person']
senticnet['opposite_cold'] = [0, -0.728, 0, 0.974, '#surprising', '#admirable', 0.567, 'hot', 'suppose_impartial', 'type_of_valley', 'heat', 'warm']
senticnet['opposites_attract_each_other'] = [0.538, -0.721, 0, 0.606, '#surprising', '#admirable', 0.622, 'attraction', 'magnetic_attraction', 'complementary', 'attract', 'magnetism']
senticnet['opposition'] = [0, 0, 0.912, -0.982, '#angry', '#disgusting', -0.631, 'uprise', 'disagreement', 'conflict', 'fight_against', 'big_fight']
senticnet['oppositive'] = [-0.668, 0, 0.502, -0.796, '#sad', '#disgusting', -0.655, 'adversative', 'disjunctive', 'contrastive', 'alternative', 'separative']
senticnet['oppress'] = [-0.501, 0, 0.936, -0.951, '#angry', '#disgusting', -0.796, 'quash', 'keep_down', 'reduce', 'repress', 'subdue']
senticnet['oppressed'] = [-0.834, 0.214, -0.391, -0.108, '#sad', '#scared', -0.373, 'oppressiveness', 'tyrannical', 'downtrodden', 'oppressive', 'tyrannous']
senticnet['oppression'] = [-0.973, 0, 0, -0.778, '#sad', '#disgusting', -0.584, 'laden', 'oppressively', 'oppressive', 'tyrannical', 'tyrannous']
senticnet['oppressive'] = [-0.834, 0.214, -0.391, -0.108, '#sad', '#scared', -0.373, 'oppressiveness', 'tyrannical', 'downtrodden', 'tyrannous', 'laden']
senticnet['oppressively'] = [-0.834, 0.214, -0.391, -0.108, '#sad', '#scared', -0.373, 'oppressiveness', 'tyrannical', 'downtrodden', 'oppressive', 'tyrannous']
senticnet['oppressiveness'] = [-0.834, 0.214, -0.391, -0.108, '#sad', '#scared', -0.373, 'tyrannical', 'downtrodden', 'oppressive', 'tyrannous', 'laden']
senticnet['opprobrious'] = [-0.799, 0, 0, -0.83, '#sad', '#disgusting', -0.543, 'disgraceful', 'shameful', 'dishonorably', 'inglorious', 'dishonored']
senticnet['optic_radiation'] = [-0.735, 0, 0.897, -0.774, '#angry', '#disgusting', -0.802, 'commissure', 'pathway', 'radiatio_optica', 'peduncle', 'cerebral_peduncle']
senticnet['optical_illusion'] = [-0.947, 0, 0.866, -0.912, '#sad', '#disgusting', -0.908, 'movement', 'apparent_motion', 'motion', 'apparent_movement', 'mirage']
senticnet['optical_instrument'] = [0.954, -0.668, 0, 0.958, '#joyful', '#admirable', 0.86, 'instrument', 'spectroscope', 'prism_spectroscope', 'binoculars', 'field_glasses']
senticnet['optimism'] = [1, 1, 0, 0, '#joyful', '#interesting', 0.667, 'anticipation', 'preference', 'devotion', 'adoration', 'positive']
senticnet['optimistic'] = [0.483, 0.675, -0.262, 0.256, '#joyful', '#interesting', 0.384, 'optimistically', 'encouraging', 'encouraged', 'bucked_up', 'encouragingly']
senticnet['optimistically'] = [0.483, 0.675, -0.262, 0.256, '#joyful', '#interesting', 0.384, 'optimistic', 'encouraging', 'encouraged', 'bucked_up', 'encouragingly']
senticnet['option'] = [0.096, 0.296, -0.159, 0.419, '#interesting', '#admirable', 0.217, 'conclude', 'explanation', 'possibility', 'chance', 'conclusion']
senticnet['optional'] = [0.769, -0.912, 0, 0, '#joyful', '#surprising', 0.56, 'seldom', 'change_someone_greatly', 'stifle', 'worst', 'toward']
senticnet['opulent'] = [0.92, 0.879, 0, 0, '#joyful', '#interesting', 0.6, 'luxurious', 'princely', 'gilded', 'grand', 'deluxe']
senticnet['opus'] = [0, 0.898, 0, 0, '#interesting', '#interesting', 0.299, 'opus_house', 'concert_hall', 'creative_work', 'studio', 'tv_studio']
senticnet['opus_house'] = [0, 0.898, 0, 0, '#interesting', '#interesting', 0.299, 'opus', 'concert_hall', 'studio', 'creative_work', 'tv_studio']
senticnet['opus_ticket'] = [0.203, 0.111, 0, 0.089, '#joyful', '#interesting', 0.134, 'ticket_taker', 'ticket_turnstile', 'go_friend', 'movie_star', 'other_person']
senticnet['oracle'] = [0.686, -0.514, 0, 0.829, '#joyful', '#admirable', 0.676, 'diviner', 'augur', 'auspex', 'prophetess', 'sibyl']
senticnet['oral_cleaning'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'wipe', 'wipe_mouth', 'napkin', 'clean_mouth', 'toothbrush']
senticnet['oral_exam'] = [0, 0.899, 0, 0.846, '#interesting', '#admirable', 0.582, 'organize_thought', 'scratch_head', 'know_answer', 'use_word', 'know_talk']
senticnet['oral_sex'] = [0.215, 0.194, -0.204, 0.279, '#joyful', '#admirable', 0.161, 'win_lottery', 'make_friend_happy', 'show_affection', 'make_happy', 'give_away']
senticnet['orange'] = [0.703, 0.75, 0, 0, '#joyful', '#interesting', 0.484, 'ball_shape', 'round_shape', 'circle_shape', 'cornerless', 'orb']
senticnet['orange_color'] = [0.935, 0.836, 0, 0, '#joyful', '#interesting', 0.59, 'citrus_fruit', 'orange_fruit', 'citrus', 'hair_color', 'fruits']
senticnet['orange_drink'] = [0.04, 0.095, -0.06, 0.132, '#interesting', '#admirable', 0.069, 'healthy_drink', 'liquid_beverage', 'popular_soda', 'liquid_drink', 'cola']
senticnet['orange_fruit'] = [0, -0.068, 0, 0, '#surprising', '#surprising', 0.023, 'ripe_apple', 'custard', 'cookie', 'candy', 'candy_cane']
senticnet['orange_juice'] = [0.721, -0.75, 0, 0, '#joyful', '#surprising', 0.49, 'lemon_juice', 'chocolate_pudding', 'grape_juice', 'carrot_juice', 'juice']
senticnet['orange_milkwort'] = [-0.706, 0, 0.769, -0.703, '#sad', '#angry', -0.726, 'subshrub', 'suffrutex', 'senega', 'milkwort', 'yellow_milkwort']
senticnet['orange_peel'] = [-0.952, 0, 0.845, -0.679, '#sad', '#angry', -0.825, 'grapefruit_peel', 'lemon_peel', 'candied_citrus_peel', 'candied_fruit', 'succade']
senticnet['orange_sneezeweed'] = [-0.767, 0, 0.76, -0.669, '#sad', '#angry', -0.732, 'herb', 'autumn_sneezeweed', 'sneezeweed', 'owlclaws', 'rosilla']
senticnet['orate'] = [0, 0, 0, 0.137, '#admirable', '#admirable', 0.046, 'discourse', 'verbalize', 'speech', 'verbal_communication', 'verbal']
senticnet['oration'] = [0, -0.007, 0, 0.085, '#surprising', '#admirable', 0.031, 'speech', 'spoken_language', 'talkative', 'orate', 'verbalize']
senticnet['orb'] = [0.97, 0.934, 0, 0, '#joyful', '#interesting', 0.635, 'round_object', 'sphere', 'spherical_shape', 'round_figure', 'three_dimensions']
senticnet['orbit'] = [0.989, -0.905, 0, 0.876, '#joyful', '#surprising', 0.923, 'reach', 'range', 'compass', 'scope', 'confines']
senticnet['orbit_around_earth'] = [0.054, 0.098, 0, 0.076, '#interesting', '#admirable', 0.076, 'sky', 'heaven', 'constellation', 'thunder_storm', 'paradise']
senticnet['orbit_around_sun'] = [0.052, 0, 0, 0.094, '#joyful', '#admirable', 0.049, 'god_creation', 'enormous', 'milky', 'milky_galaxy', 'nasa']
senticnet['orbit_earth'] = [-0.035, -0.046, 0.102, -0.113, '#angry', '#disgusting', -0.068, 'unlimited', 'limitless', 'star_planet', 'make_cheese', 'void']
senticnet['orbit_sun'] = [0, -0.947, 0, 0.948, '#surprising', '#admirable', 0.632, 'spherical', 'round_orb', 'three_dimensions', 'seen_night_sky', 'round']
senticnet['orchestra'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'play_music', 'opera', 'create_music', 'play_orchestra', 'play_tune']
senticnet['orchestra_pit'] = [0, 0.117, -0.077, 0.094, '#interesting', '#admirable', 0.045, 'concert_hall', 'usher', 'stage_border', 'civic_center', 'balcony_seat']
senticnet['orchestra_play'] = [0.871, 0.986, 0, 0, '#joyful', '#interesting', 0.619, 'style_music', 'music', 'sing', 'tune', 'good_music']
senticnet['orchestra_seat'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'orchestra_play', 'symphony_hall', 'music', 'orchestra_pit', 'concert_hall']
senticnet['orchitis'] = [-0.998, 0, 0.964, -0.704, '#sad', '#angry', -0.889, 'blepharitis', 'diverticulitis', 'epiglottitis', 'inflammation', 'prostatitis']
senticnet['order'] = [0.049, 0.212, 0, 0.195, '#interesting', '#admirable', 0.152, 'order_beer', 'order_dinner', 'order_drink', 'order_food', 'order_meal']
senticnet['order_beer'] = [-0.035, 0, 0.017, -0.058, '#sad', '#disgusting', -0.037, 'order_hamburger', 'show_id', 'money_credit', 'make_sure_enough_money', 'go_supermarket']
senticnet['order_dinner'] = [-0.056, -0.005, 0.014, -0.141, '#sad', '#disgusting', -0.069, 'pay_meal', 'take_number', 'use_restroom', 'place_order', 'order_french_fries']
senticnet['order_drink'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'read_menu', 'look_menu', 'order_beer', 'order_menu', 'buy_drink']
senticnet['order_food'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'order_drink', 'order_french_fries', 'order_meal', 'order_menu', 'order_pizza']
senticnet['order_french_fries'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'take_number', 'carve_niche', 'wait_patiently', 'wait_line', 'stand_queue']
senticnet['order_fry'] = [-0.026, 0, 0.046, -0.061, '#angry', '#disgusting', -0.044, 'place_order', 'order_dinner', 'decide_order', 'read_menu', 'order_hamburger']
senticnet['order_hamburger'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'place_order', 'order_beer', 'order_menu', 'decide_order', 'look_menu']
senticnet['order_lunch'] = [0.854, 0.659, 0, 0.545, '#joyful', '#interesting', 0.686, 'teeth', 'obtain_food', 'find_restaurant', 'bite_food', 'decide_eat']
senticnet['order_meal'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'place_order', 'order_hamburger', 'use_restroom', 'want_drink', 'order_menu']
senticnet['order_menu'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'order_hamburger', 'look_menu', 'order_beer', 'read_menu', 'order_drink']
senticnet['order_pizza'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'order_hamburger', 'order_meal', 'order_menu', 'eat_pizza', 'order_french_fries']
senticnet['ordered_series'] = [-0.585, 0, 0.658, -0.958, '#angry', '#disgusting', -0.734, 'measure', 'standard', 'wage_scale', 'wage_schedule', 'wind_scale']
senticnet['ordering'] = [0.888, -0.815, 0, 0.617, '#joyful', '#surprising', 0.773, 'bacteria_order', 'word_order', 'genetic_code', 'genome', 'series']
senticnet['orderly'] = [0.021, 0.219, -0.105, 0.199, '#interesting', '#admirable', 0.111, 'order', 'organize', 'arrange', 'precise', 'disciplined']
senticnet['ordinal'] = [0.049, 0.113, 0.107, 0.162, '#interesting', '#admirable', 0.072, 'list_number', 'numeral', 'count', 'numerical', 'enumeration']
senticnet['ordinariness'] = [0.793, -0.804, 0, 0.66, '#joyful', '#surprising', 0.752, 'quality', 'commonplaceness', 'everydayness', 'mediocrity', 'averageness']
senticnet['ordinary'] = [0, 0.183, 0, 0.105, '#interesting', '#admirable', 0.096, 'common', 'usual', 'typical', 'normal', 'usual_ordinary']
senticnet['ore'] = [0.024, 0.108, 0, 0.144, '#interesting', '#admirable', 0.092, 'make_out_metal', 'door_opener', 'both_functional_decorative', 'mix_metal', 'hardware']
senticnet['oregano'] = [0.1, 0, 0, 0, '#joyful', '#joyful', 0.033, 'burn_material', 'ash', 'stay_warm', 'bonfire', 'campfire']
senticnet['organ'] = [0, 0.073, 0, 0, '#interesting', '#interesting', 0.024, 'body_tissue', 'organ_body', 'internal_organ', 'vital_organ', 'part_of_human_body']
senticnet['organ_body'] = [0, 0, 0, 0.118, '#admirable', '#admirable', 0.039, 'vital_organ', 'hold_glass', 'sensory_organ', 'sense_organ', 'body_organ']
senticnet['organ_stop'] = [0.939, -0.717, 0, 0.775, '#joyful', '#admirable', 0.81, 'vox_angelica', 'voix_celeste', 'dulciana', 'pipe', 'diapason']
senticnet['organic'] = [0.035, 0.088, 0.031, 0.113, '#interesting', '#admirable', 0.068, 'cultivate_yard', 'same_answer', 'poisonous_human', 'juicy', 'natural_material']
senticnet['organic_material'] = [0, 0.761, 0, 0.975, '#interesting', '#admirable', 0.579, 'same_answer', 'come_off', 'natural', 'fluffy_white', 'come_out']
senticnet['organic_matter'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'compost_pile', 'decompose', 'recycle', 'soil', 'fertiliser']
senticnet['organic_substance'] = [0.031, -0.003, 0, 0.062, '#joyful', '#admirable', 0.032, 'solid_fuel', 'fire_starter', 'renewable_resource', 'use_fuel', 'go_green']
senticnet['organiser'] = [0, 0.877, 0, 0, '#interesting', '#interesting', 0.292, 'desk', 'office', 'folder', 'file_drawer', 'document']
senticnet['organism'] = [0, 0.071, 0, 0, '#interesting', '#interesting', 0.024, 'eukaryote', 'human_chest', 'live_entity', 'system', 'secret_agent']
senticnet['organization'] = [0.076, 0.167, -0.073, 0.116, '#interesting', '#admirable', 0.095, 'association', 'committee', 'egalitarian_society', 'assemble', 'majority']
senticnet['organizational_skill'] = [-0.036, 0.183, -0.083, 0.094, '#interesting', '#admirable', 0.053, 'organize', 'clean_often', 'orderly', 'clear_up', 'maintenance']
senticnet['organize'] = [0.021, 0.171, -0.084, 0.185, '#interesting', '#admirable', 0.098, 'neat_tidy', 'neatness', 'orderly', 'neat', 'tidy']
senticnet['organize_book'] = [-0.06, 0, -0.057, -0.055, '#sad', '#scared', -0.057, 'book', 'religious_book', 'court_system', 'book_genre', 'book_poetry']
senticnet['organize_clothes'] = [-0.066, -0.019, 0.037, 0, '#sad', '#angry', -0.028, 'store_dress', 'keep_clothes', 'hold_clothes', 'hang_hanger', 'hang_up_clothes']
senticnet['organize_data'] = [0, 0.833, 0, 0.767, '#interesting', '#admirable', 0.533, 'acknowledge', 'go_over', 'recognize_pattern', 'deduce', 'figure_out']
senticnet['organize_document'] = [0.026, 0.077, 0, 0.05, '#interesting', '#admirable', 0.051, 'keep_paper_together', 'store_document', 'bind_paper_together', 'carry_paper', 'fasten_paper_together']
senticnet['organize_group'] = [0.159, -0.071, 0.024, 0, '#joyful', '#surprising', 0.069, 'club', 'metal_stick', 'hangout', 'bart', 'staff']
senticnet['organize_information'] = [0.573, 0.87, 0, 0.56, '#joyful', '#interesting', 0.668, 'word_process', 'surf_internet', 'spread_information', 'process_data', 'predict_weather']
senticnet['organize_life'] = [0, 0, 0, 0.897, '#admirable', '#admirable', 0.299, 'clear_think', 'declutter', 'neatness', 'sort', 'organizational_skill']
senticnet['organize_paper'] = [0, 0.091, 0, 0.079, '#interesting', '#admirable', 0.057, 'hold_document', 'store_pen', 'hold_paper', 'write_paper', 'keep_paper']
senticnet['organize_thought'] = [0, 0.774, 0, 0.781, '#interesting', '#admirable', 0.518, 'convey_information', 'fact_right', 'ability_communicate', 'write_word', 'draw_picture']
senticnet['organized'] = [-0.906, 0, 0.533, -0.934, '#sad', '#disgusting', -0.791, 'incorporated', 'arranged', 'configured', 'corporate', 'reorganized']
senticnet['orgasm'] = [0.024, -0.031, -0.056, -0.216, '#scared', '#disgusting', -0.072, 'erection', 'wet_oneself', 'arousal', 'kill_brain_cell', 'feel_relieved']
senticnet['orgy'] = [0, 0, -0.864, -0.999, '#scared', '#disgusting', -0.621, 'center_attention', 'pia_lot_of_seat', 'seat_chair', 'loose_end', 'death_row']
senticnet['oriental_medicine'] = [0, -0.045, 0.098, -0.113, '#angry', '#disgusting', -0.055, 'grapefruit', 'plum', 'lemon_juice', 'green_apple', 'apricot']
senticnet['orientation'] = [-0.049, 0.132, -0.047, 0.108, '#interesting', '#admirable', 0.048, 'help_find', 'upgrade', 'seek_out', 'scan', 'help_understand']
senticnet['orifice'] = [0, 0.085, 0.02, 0.127, '#interesting', '#admirable', 0.064, 'facial_organ', 'near_mouth', 'part_of_face', 'facial_part', 'face_part']
senticnet['origanum'] = [0.632, -0.933, 0, 0.928, '#surprising', '#admirable', 0.831, 'herb', 'oregano', 'marjoram', 'pot_marjoram', 'wild_marjoram']
senticnet['origin'] = [0.102, 0.142, -0.081, 0.224, '#interesting', '#admirable', 0.129, 'come_from', 'from_here', 'join_together', 'source', 'enlarge']
senticnet['original'] = [0.039, 0.219, -0.097, 0.25, '#interesting', '#admirable', 0.137, 'abstract', 'from_here', 'source', 'good', 'same']
senticnet['originality'] = [0, 0.97, 0, 0.917, '#interesting', '#admirable', 0.629, 'novelty', 'innovativeness', 'freshness', 'ability', 'power']
senticnet['orison'] = [0.638, -0.838, 0, 0.852, '#surprising', '#admirable', 0.776, 'blessing', 'grace', 'commination', 'benediction', 'supplication']
senticnet['ornament'] = [0.088, -0.066, -0.081, 0.126, '#joyful', '#admirable', 0.066, 'pendant', 'ring', 'statue', 'card', 'yellow_ribbon']
senticnet['ornamentation'] = [0.032, 0, 0, 0.178, '#joyful', '#admirable', 0.07, 'window_treatment', 'picture', 'wall_decoration', 'wall_hang', 'painting']
senticnet['ornate'] = [0.162, -0.206, 0, 0.232, '#surprising', '#admirable', 0.2, 'adornment', 'frilly', 'jewelry', 'stylish', 'jewel']
senticnet['ornateness'] = [-0.544, 0, 0.7, -0.64, '#angry', '#disgusting', -0.628, 'flourish', 'rant', 'bombast', 'fustian', 'claptrap']
senticnet['orneriness'] = [-0.751, 0, 0.683, -0.992, '#sad', '#disgusting', -0.809, 'cussedness', 'contrariness', 'unruliness', 'fractiousness', 'willfulness']
senticnet['orphan'] = [-0.165, -0.054, -0.126, -0.134, '#sad', '#disgusting', -0.124, 'waif', 'orphanage', 'stray', 'ragamuffin', 'lonely']
senticnet['orphanage'] = [-0.165, -0.054, -0.126, -0.134, '#sad', '#disgusting', -0.124, 'waif', 'orphan', 'stray', 'ragamuffin', 'lonely']
senticnet['orpin'] = [-0.592, 0, 0.942, -0.758, '#angry', '#disgusting', -0.764, 'livelong', 'herb', 'stonecrop', 'sedume', 'sedum']
senticnet['orpine'] = [-0.592, 0, 0.942, -0.758, '#angry', '#disgusting', -0.764, 'livelong', 'herb', 'stonecrop', 'sedum', 'orpin']
senticnet['orthodox'] = [0.033, 0.278, 0, 0.275, '#interesting', '#admirable', 0.195, 'sect', 'protestant', 'religious_service', 'holy_man', 'jewish']
senticnet['orthodoxy'] = [-0.913, 0, 0.987, 0, '#sad', '#angry', -0.633, 'conventionality', 'traditionalism', 'conventionalism', 'traditionality', 'strict']
senticnet['orthogonal'] = [-0.868, 0, 0.894, -0.72, '#sad', '#angry', -0.827, 'inapplicable', 'unsuitable', 'immaterial', 'extraneous', 'irrelevant']
senticnet['oscine'] = [-0.845, 0, 0.655, -0.851, '#sad', '#disgusting', -0.784, 'piping_crow', 'butcherbird', 'currawong', 'bell_magpie', 'australian_magpie']
senticnet['oscitance'] = [-0.827, 0, 0.663, -0.508, '#sad', '#angry', -0.666, 'obtuseness', 'dullness', 'sleepiness', 'drowsiness', 'somnolence']
senticnet['oscitancy'] = [-0.925, 0, 0.549, -0.656, '#sad', '#disgusting', -0.71, 'obtuseness', 'dullness', 'sleepiness', 'drowsiness', 'somnolence']
senticnet['osmotic_pressure'] = [-0.623, 0, 0.901, -0.715, '#angry', '#disgusting', -0.746, 'pressure', 'hypertonicity', 'hypotonicity', 'pressure_level', 'force_per_unit_area']
senticnet['osteitis'] = [-0.607, 0, 0.949, -0.96, '#angry', '#disgusting', -0.839, 'osteomyelitis', 'rubor', 'redness', 'inflammation', 'osteitis_deformans']
senticnet['osteitis_deformans'] = [-0.607, 0, 0.949, -0.96, '#angry', '#disgusting', -0.839, 'osteomyelitis', 'rubor', 'redness', 'inflammation', 'osteitis']
senticnet['ostensible'] = [-0.631, 0, 0.857, -0.711, '#angry', '#disgusting', -0.733, 'shallow', 'facile', 'superficial', 'sounding', 'looking']
senticnet['ostentation'] = [-0.818, 0, 0.936, -0.579, '#sad', '#angry', -0.778, 'pedantry', 'bluster', 'splurge', 'ritz', 'display']
senticnet['osteomyelitis'] = [-0.607, 0, 0.949, -0.96, '#angry', '#disgusting', -0.839, 'osteitis', 'rubor', 'redness', 'inflammation', 'osteitis_deformans']
senticnet['osteopetrosis'] = [-0.599, 0, 0.606, -0.571, '#sad', '#angry', -0.592, 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect', 'congenital_disease']
senticnet['osteosclerosis'] = [-0.596, 0, 0.911, -0.877, '#angry', '#disgusting', -0.795, 'induration', 'sclerosis', 'disseminated_sclerosis', 'multiple_sclerosis', 'pathology']
senticnet['osteosclerosis_congenita'] = [-0.85, 0, 0.572, -0.753, '#sad', '#disgusting', -0.725, 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect', 'congenital_disease']
senticnet['osteostracan'] = [-0.542, 0, 0.992, -0.872, '#angry', '#disgusting', -0.802, 'hag', 'jawless_fish', 'cephalaspid', 'ostracoderm', 'heterostracan']
senticnet['ostracoderm'] = [-0.542, 0, 0.992, -0.872, '#angry', '#disgusting', -0.802, 'hag', 'osteostracan', 'cephalaspid', 'jawless_fish', 'heterostracan']
senticnet['other_half_marriage'] = [0.048, 0.19, -0.061, 0.077, '#interesting', '#admirable', 0.085, 'circular_route', 'city_hall', 'walking_stick', 'crutch', 'hardware_shop']
senticnet['other_people'] = [0.099, 0.248, -0.079, 0.282, '#interesting', '#admirable', 0.183, 'rest_of_group', 'others', 'precise', 'significant', 'description']
senticnet['other_person'] = [0.203, 0.111, 0, 0.089, '#joyful', '#interesting', 0.134, 'ticket_taker', 'ticket_turnstile', 'go_friend', 'movie_star', 'opus_ticket']
senticnet['other_side'] = [0.967, 0.982, 0, 0.777, '#joyful', '#interesting', 0.909, 'good_environment', 'make_strong', 'green', 'cultivate', 'usual_green']
senticnet['other_work'] = [0.03, 0, 0, 0.071, '#joyful', '#admirable', 0.034, 'office', 'workplace', 'work_area', 'place_work', 'office_space']
senticnet['others'] = [0.099, 0.248, -0.079, 0.282, '#interesting', '#admirable', 0.183, 'rest_of_group', 'other_people', 'precise', 'significant', 'description']
senticnet['others_understand'] = [0.255, 0.182, -0.06, 0.314, '#joyful', '#admirable', 0.23, 'much_need', 'good_sense_of_humor', 'complement', 'knowledgeable', 'taken_seriously']
senticnet['otherworldliness'] = [0.995, -0.731, 0, 0.83, '#joyful', '#admirable', 0.852, 'spiritism', 'internality', 'spirituality', 'spiritualism', 'introversion']
senticnet['otiose'] = [-0.784, 0, 0.651, -0.564, '#sad', '#angry', -0.666, 'rubbishy', 'sorry', 'trashy', 'worthless', 'superfluous']
senticnet['otitis'] = [-0.879, 0, 0.773, -0.907, '#sad', '#disgusting', -0.853, 'rubor', 'redness', 'inflammation', 'labyrinthitis', 'otitis_interna']
senticnet['otitis_interna'] = [-0.879, 0, 0.773, -0.907, '#sad', '#disgusting', -0.853, 'rubor', 'redness', 'inflammation', 'labyrinthitis', 'otitis']
senticnet['otosclerosis'] = [-0.565, 0, 0.577, -0.679, '#angry', '#disgusting', -0.607, 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect', 'congenital_disease']
senticnet['otoscope'] = [0.255, 0.182, -0.06, 0.314, '#joyful', '#admirable', 0.23, 'doctor_office', 'urethroscope', 'sigmoidoscope', 'hospital', 'check_health']
senticnet['otter'] = [0, 0, -0.071, 0, '#scared', '#scared', -0.024, 'seal', 'walrus', 'mussel', 'alligator', 'whale']
senticnet['ouch'] = [-0.165, -0.054, -0.126, -0.134, '#sad', '#disgusting', -0.124, 'ache', 'excruciate', 'hurt', 'pain', 'cut_skin']
senticnet['ought'] = [0, 0.979, 0, 0.81, '#interesting', '#admirable', 0.596, 'must', 'requirement', 'needful', 'necessary', 'need']
senticnet['ounce'] = [0.023, 0.096, 0.021, 0.175, '#interesting', '#admirable', 0.091, 'frequency', 'amplitude', 'echo', 'volume', 'loudness']
senticnet['oust'] = [0, 0, -0.799, -0.771, '#scared', '#disgusting', -0.523, 'throw_out', 'drum_out', 'kick_out', 'boot_out', 'expel']
senticnet['ouster'] = [-0.92, 0, 0.897, -0.511, '#sad', '#angry', -0.776, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['out'] = [-0.75, 0, 0.614, -0.743, '#sad', '#disgusting', -0.702, 'impermissible', 'unmentionable', 'untouchable', 'taboo', 'tabu']
senticnet['out_bed'] = [0.258, 0, 0, 0, '#joyful', '#joyful', 0.086, 'good_night_sleep', 'enough_sleep', 'read_good_book', 'good_day', 'get_up_morning']
senticnet['out_breath'] = [-0.92, 0, -0.978, 0, '#sad', '#scared', -0.633, 'blister_foot', 'breahard', 'sprain_ankle', 'trip_fall', 'twist_ankle']
senticnet['out_car'] = [-0.091, 0, 0, -0.063, '#sad', '#disgusting', -0.051, 'plan_day', 'get_stick_traffic', 'rush_work', 'adjust_clothes', 'meet_old_friend']
senticnet['out_chair'] = [-0.034, 0.066, 0, 0.067, '#interesting', '#admirable', 0.033, 'wear_good_shoes', 'use_leg', 'wear_running_shoes', 'find_ball', 'put_shoes']
senticnet['out_country'] = [0.801, -0.894, 0, 0, '#joyful', '#surprising', 0.565, 'sunset', 'wood_duck', 'pink_flower', 'beau', 'autumn_leaf']
senticnet['out_door'] = [-0.025, 0, 0, -0.054, '#sad', '#disgusting', -0.026, 'butt', 'foreign_country', 'menagerie', 'way', 'ass']
senticnet['out_focus'] = [0.038, 0, 0, 0.066, '#joyful', '#admirable', 0.035, 'cotton', 'herringbone', 'wool', 'cotton_boll', 'fleece']
senticnet['out_gay_man'] = [-0.119, 0, -0.115, 0, '#sad', '#scared', -0.078, 'speak_english', 'deal_card_player', 'bridge_difference', 'forward_email', 'shoulder_responsibility']
senticnet['out_money'] = [-0.088, 0, 0, -0.04, '#sad', '#disgusting', -0.043, 'spend_money', 'compare_price', 'buy_gift', 'spend_a_lot_of_money', 'spend_much_money']
senticnet['out_of_blue'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'without_warning', 'unexpected', 'unpredicted', 'unanticipated', 'without_notice']
senticnet['out_of_house'] = [0.038, 0, 0, 0.066, '#joyful', '#admirable', 0.035, 'get_out_of_house', 'see_countryside', 'show_off', 'see_new_place', 'go_outdoors']
senticnet['out_of_line'] = [-0.966, 0, 0.877, -0.977, '#sad', '#disgusting', -0.94, 'ruin', 'break_rule', 'destroy', 'damage', 'bad_person']
senticnet['out_of_sight'] = [-0.139, 0.07, -0.105, 0.104, '#sad', '#scared', -0.023, 'unseen', 'hide', 'conceal', 'hide_evidence', 'hidden']
senticnet['out_of_stock'] = [-0.777, 0, 0.644, -0.687, '#sad', '#disgusting', -0.703, 'unobtainable', 'unprocurable', 'unavailable', 'gone', 'untouchable']
senticnet['out_of_whack'] = [-0.732, 0, 0.787, -0.662, '#sad', '#angry', -0.727, 'wrong', 'haywire', 'bad', 'malfunctioning', 'amiss']
senticnet['out_place'] = [0.091, 0, 0.034, 0.049, '#joyful', '#admirable', 0.035, 'summer_vacation', 'outdoor_activity', 'hard_use', 'easy_use', 'hunt_fish']
senticnet['out_shape'] = [0.062, 0.097, -0.094, 0.11, '#interesting', '#admirable', 0.058, 'live_long', 'long_life', 'live_long_life', 'live_healthy_lifestyle', 'like_exercise']
senticnet['out_wallet'] = [0.728, 0.922, 0, 0.996, '#interesting', '#admirable', 0.882, 'use_money', 'enough_money', 'money_credit', 'good_credit', 'moolah']
senticnet['out_work'] = [-0.295, -0.099, 0, -0.358, '#sad', '#disgusting', -0.185, 'death_penalty', 'threaten', 'anthrax', 'capital_punishment', 'terrorize']
senticnet['outback'] = [0.88, -0.808, 0, 0.696, '#joyful', '#surprising', 0.795, 'inaccessible', 'trackless', 'pathless', 'roadless', 'untracked']
senticnet['outbreak'] = [-0.114, 0.078, -0.154, -0.125, '#scared', '#disgusting', -0.105, 'illiteracy', 'sexually_transmit_disease', 'disease', 'infectious_disease', 'contagious_disease']
senticnet['outburst'] = [0, 0, 0.982, -0.822, '#angry', '#disgusting', -0.601, 'cry', 'acting_out', 'explosion', 'halloo', 'yell']
senticnet['outcaste'] = [-0.828, 0, 0.85, -0.709, '#sad', '#angry', -0.796, 'unwanted', 'casteless', 'unclaimed', 'unwelcome', 'undesired']
senticnet['outcome'] = [-0.081, 0.175, -0.164, 0.232, '#interesting', '#admirable', 0.054, 'result', 'conclusion', 'consequence', 'effect', 'end_point']
senticnet['outcry'] = [-0.869, 0, 0.516, -0.769, '#sad', '#disgusting', -0.718, 'bronx_cheer', 'call', 'cry', 'yell', 'shout']
senticnet['outdated'] = [-0.909, 0, 0.517, -0.92, '#sad', '#disgusting', -0.782, 'noncurrent', 'obsolescent', 'disused', 'obsolete', 'superannuated']
senticnet['outdo'] = [0.974, 0, 0, 0.977, '#joyful', '#admirable', 0.65, 'top', 'cap', 'trump', 'beat', 'better']
senticnet['outdoor'] = [0.076, 0.079, 0.027, 0.118, '#interesting', '#admirable', 0.082, 'adam_and_eve', 'plant_place', 'plant_ground', 'grass_area', 'cultivate_yard']
senticnet['outdoor_activity'] = [0.064, 0, 0.013, 0.138, '#joyful', '#admirable', 0.063, 'kid_activity', 'game_action', 'activity', 'water_activity', 'fun_activity']
senticnet['outdoor_event'] = [0, 0.102, 0, 0, '#interesting', '#interesting', 0.034, 'frostbite', 'mountain_goat', 'eskimo', 'glacier', 'coldness']
senticnet['outdoor_sport'] = [0, -0.068, 0.014, 0.078, '#surprising', '#admirable', 0.044, 'pastime', 'popular_sport_america', 'ball_sport', 'popular_sport', 'type_of_sport']
senticnet['outer'] = [0, 0.072, 0, 0.087, '#interesting', '#admirable', 0.053, 'star_planet', 'emptiness', 'void', 'nothingness', 'around_earth']
senticnet['outer_space'] = [0, 0.09, 0, 0.066, '#interesting', '#admirable', 0.052, 'massive', 'universe', 'without_light', 'limitless', 'above_earth']
senticnet['outer_wear'] = [0.841, 0.852, 0, 0, '#joyful', '#interesting', 0.564, 'vest', 'suit', 'garment', 'cape', 'kimono']
senticnet['outerwear'] = [0.053, -0.013, -0.052, 0.121, '#joyful', '#admirable', 0.045, 'coat', 'winter_clothes', 'stylish', 'adorn', 'protective_cover']
senticnet['outfight'] = [0.586, -0.947, 0, 0.748, '#surprising', '#admirable', 0.76, 'vanquish', 'beat', 'beat_out', 'trounce', 'crush']
senticnet['outfit'] = [0.068, 0, 0.014, 0.055, '#joyful', '#admirable', 0.036, 'frill', 'blouse', 'frock', 'fashion', 'wear']
senticnet['outfitted'] = [0.84, -0.973, 0, 0.517, '#joyful', '#surprising', 0.777, 'prepared', 'visored', 'armored', 'equipped', 'helmeted']
senticnet['outflank'] = [0.699, -0.699, 0, 0.587, '#joyful', '#surprising', 0.662, 'best', 'outmaneuver', 'trump', 'scoop', 'outdo']
senticnet['outgo'] = [0.957, -0.936, 0, 0.795, '#joyful', '#surprising', 0.896, 'outdo', 'outstrip', 'outmatch', 'outrange', 'outperform']
senticnet['outgo_personality'] = [0.975, 0.823, 0, 0, '#joyful', '#interesting', 0.599, 'picture_taken', 'celebrate_special_occasion', 'good_mood', 'good_feeling', 'hospitable']
senticnet['outgoing'] = [0, 0, -0.763, -0.878, '#scared', '#disgusting', -0.547, 'surpass', 'outmatch', 'outdo', 'outstrip', 'exceed']
senticnet['outhouse'] = [0.048, 0.077, 0, -0.031, '#joyful', '#interesting', 0.031, 'soccer_field', 'baseball_diamond', 'memorial', 'baseball_field', 'city_park']
senticnet['outlandish'] = [0.722, 0, 0, 0.755, '#joyful', '#admirable', 0.492, 'freaky', 'flaky', 'eccentric', 'bizarre', 'gonzo']
senticnet['outlaw'] = [0, 0, -0.113, -0.123, '#scared', '#disgusting', -0.079, 'hunting_season', 'hound', 'cougar', 'hunter', 'dragon']
senticnet['outlet'] = [-0.903, 0, -0.824, 0, '#sad', '#scared', -0.576, 'shopping_area', 'sour_cream', 'leave_over', 'hand_print', 'taffy']
senticnet['outlier'] = [-0.045, 0.234, -0.101, 0.263, '#interesting', '#admirable', 0.117, 'different', 'alternative', 'unusual', 'rear_end', 'exception']
senticnet['outline'] = [0, 0.229, 0, 0.196, '#interesting', '#admirable', 0.142, 'blueprint', 'pencil_art', 'draw_blueprint', 'trace', 'diagram']
senticnet['outmaneuver'] = [0.699, -0.699, 0, 0.587, '#joyful', '#surprising', 0.662, 'best', 'outflank', 'trump', 'scoop', 'outdo']
senticnet['outmanoeuvre'] = [0.513, -0.504, 0, 0.986, '#joyful', '#admirable', 0.668, 'best', 'outflank', 'trump', 'scoop', 'outdo']
senticnet['outmatch'] = [-0.696, 0, 0.66, -0.72, '#sad', '#disgusting', -0.692, 'shame', 'outcry', 'crush', 'outsell', 'trounce']
senticnet['outperform'] = [0, 0.95, 0, 0.725, '#interesting', '#admirable', 0.558, 'exceed', 'outshout', 'outstrip', 'outshine', 'outsail']
senticnet['outpost'] = [0.04, 0.112, -0.053, 0.079, '#interesting', '#admirable', 0.059, 'location', 'large_area', 'vicinity', 'place', 'post']
senticnet['outpouring'] = [-0.592, 0, 0.753, -0.549, '#sad', '#angry', -0.631, 'discharge', 'spray', 'spritz', 'spirt', 'run']
senticnet['output'] = [0, 0.098, -0.065, 0.15, '#interesting', '#admirable', 0.061, 'make_book', 'use_ink', 'make_newspaper', 'pencil_mark', 'computer_command']
senticnet['outrage'] = [-0.138, 0.145, 0.625, -0.638, '#angry', '#disgusting', -0.419, 'indignation', 'indignantly', 'umbrageous', 'outraged', 'incensed']
senticnet['outraged'] = [-0.139, 0.146, 0.623, -0.637, '#angry', '#disgusting', -0.418, 'umbrageous', 'incensed', 'indignant', 'outrage', 'indignation']
senticnet['outrageous'] = [-0.231, 0.235, 0.456, -0.571, '#angry', '#disgusting', -0.341, 'horrid', 'queasy', 'misanthropical', 'misanthropic', 'sulky']
senticnet['outrageousness'] = [-0.526, 0, 0.648, -0.967, '#angry', '#disgusting', -0.714, 'improperness', 'indecency', 'impropriety', 'immodesty', 'obscenity']
senticnet['outrange'] = [0.957, -0.936, 0, 0.795, '#joyful', '#surprising', 0.896, 'outdo', 'outstrip', 'outmatch', 'outgo', 'outperform']
senticnet['outrank'] = [-0.53, 0, 0.977, -0.544, '#angry', '#disgusting', -0.684, 'rank', 'surpass', 'shine_at', 'excel_at', 'exceed']
senticnet['outrider'] = [-0.993, 0, 0.877, -0.777, '#sad', '#angry', -0.882, 'yeoman', 'bodyguard', 'yeoman_of_guard', 'beefeater', 'defender']
senticnet['outright'] = [-0.669, 0, 0.721, -0.539, '#sad', '#angry', -0.643, 'unlimited', 'unqualified', 'unconditional', 'categoric', 'categorical']
senticnet['outroar'] = [0.644, -0.613, 0, 0.648, '#joyful', '#admirable', 0.635, 'outdo', 'outstrip', 'outmatch', 'outgo', 'outperform']
senticnet['outsail'] = [0.859, -0.791, 0, 0.897, '#joyful', '#admirable', 0.849, 'outdo', 'outstrip', 'outmatch', 'outgo', 'outperform']
senticnet['outsell'] = [-0.594, 0, 0.973, -0.974, '#angry', '#disgusting', -0.847, 'surpass', 'outmatch', 'outgo', 'outperform', 'outstrip']
senticnet['outset'] = [0, 0.117, -0.066, 0.177, '#interesting', '#admirable', 0.076, 'start', 'thumb', 'knuckle', 'extend_arm', 'reach']
senticnet['outside'] = [-0.521, 0, 0.783, -0.975, '#angry', '#disgusting', -0.76, 'international', 'abroad', 'overseas', 'external', 'foreign']
senticnet['outside_area'] = [0, 0.099, 0.059, 0.121, '#interesting', '#admirable', 0.054, 'grass_area', 'plant_place', 'grassy_area', 'grow_place', 'plant_ground']
senticnet['outside_atmosphere'] = [-0.702, 0, 0, -0.943, '#sad', '#disgusting', -0.548, 'nothing', 'none', 'void', 'emptiness', 'suction']
senticnet['outside_house'] = [-0.027, -0.004, 0.022, -0.036, '#sad', '#disgusting', -0.027, 'fancy_house', 'atrium', 'front_house', 'abide', 'many_homes']
senticnet['outsider'] = [-0.231, 0.235, 0.456, -0.571, '#angry', '#disgusting', -0.341, 'stranger', 'alien', 'outlier', 'intruder', 'bug']
senticnet['outsmart'] = [0.866, -0.995, 0, 0.651, '#joyful', '#surprising', 0.837, 'outdo', 'outstrip', 'outmatch', 'outgo', 'outperform']
senticnet['outspoken'] = [0.05, 0.166, -0.071, 0.152, '#interesting', '#admirable', 0.099, 'direct', 'person', 'direct_person', 'frank', 'candid']
senticnet['outspokenness'] = [0.664, -0.941, 0, 0.613, '#joyful', '#surprising', 0.739, 'communicativeness', 'frankness', 'garrulity', 'garrulousness', 'loquaciousness']
senticnet['outstanding'] = [0.837, -0.898, 0, 0.869, '#surprising', '#admirable', 0.868, 'conspicuous', 'bold', 'marked', 'prominent', 'striking']
senticnet['outstrip'] = [0.995, 0, 0, 0.825, '#joyful', '#admirable', 0.607, 'outsell', 'trounce', 'outrun', 'outdistance', 'outpace']
senticnet['outwear'] = [0.654, -0.515, 0, 0.617, '#joyful', '#admirable', 0.595, 'outdo', 'outstrip', 'outmatch', 'outgo', 'outperform']
senticnet['outweigh'] = [0.904, -0.695, 0, 0.758, '#joyful', '#admirable', 0.786, 'override', 'overarch', 'preponderate', 'predominate', 'overbalance']
senticnet['oval'] = [0, 0.775, 0, 0.802, '#interesting', '#admirable', 0.526, 'round_white', 'oval_shape', 'frustrate_person', 'small_round', 'round_ball']
senticnet['oval_shape'] = [-0.902, 0, -0.851, 0, '#sad', '#scared', -0.584, 'round_white', 'oval', 'frustrate_person', 'small_round', 'round_ball']
senticnet['ovarian_pregnancy'] = [-0.752, 0, 0.715, -0.725, '#sad', '#disgusting', -0.731, 'abdominal_pregnancy', 'ectopic_gestation', 'tubal_pregnancy', 'pregnancy', 'gestation']
senticnet['ovary'] = [0.058, 0.094, 0, 0, '#joyful', '#interesting', 0.051, 'make_baby', 'find_mate', 'procreation', 'pregnancy', 'cum']
senticnet['oven'] = [0.042, -0.04, 0, 0, '#joyful', '#surprising', 0.027, 'grill', 'stove', 'pan', 'bake_oven', 'toaster']
senticnet['over_head'] = [-0.893, 0, -0.909, 0, '#sad', '#scared', -0.601, 'no_sun', 'out_of_blue', 'without_light', 'block_sun', 'nice_day']
senticnet['overage'] = [0.522, -0.88, 0, 0.965, '#surprising', '#admirable', 0.789, 'assets', 'crown_jewel', 'security', 'capital', 'hole_card']
senticnet['overall'] = [-0.675, 0, 0.688, -0.899, '#angry', '#disgusting', -0.754, 'protective_garment', 'boilersuit', 'boilers_suit', 'coverall', 'duster']
senticnet['overappraisal'] = [0.83, -0.835, 0, 0.872, '#surprising', '#admirable', 0.846, 'estimation', 'overvaluation', 'overestimate', 'overestimation', 'commercial_document']
senticnet['overarch'] = [0.904, -0.695, 0, 0.758, '#joyful', '#admirable', 0.786, 'override', 'predominate', 'preponderate', 'outweigh', 'overbalance']
senticnet['overbalance'] = [0, 0, 0.864, -0.951, '#angry', '#disgusting', -0.605, 'preponderate', 'outweigh', 'predominate', 'capsize', 'upset']
senticnet['overcast'] = [0, 0.071, 0, 0.078, '#interesting', '#admirable', 0.05, 'sun_cover', 'no_sun', 'cool_temperature', 'nice_day', 'block_sun']
senticnet['overclothe'] = [-0.635, 0, 0.694, -0.997, '#angry', '#disgusting', -0.775, 'raiment', 'garb', 'dress', 'clothe', 'enclothe']
senticnet['overcoat'] = [0.049, -0.071, 0.119, -0.091, '#angry', '#disgusting', -0.03, 'jacket', 'coat', 'vest', 'outerwear', 'slack']
senticnet['overcome'] = [0.828, 0, 0, 0.994, '#joyful', '#admirable', 0.607, 'overcome_problem', 'overcome_obstacle', 'win_battle', 'succeed', 'win_game']
senticnet['overcome_obstacle'] = [0.724, 0, 0, 0.816, '#joyful', '#admirable', 0.513, 'overcome_problem', 'overcome', 'win_battle', 'succeed', 'win_game']
senticnet['overcome_problem'] = [0.904, 0, 0, 0.83, '#joyful', '#admirable', 0.578, 'overcome', 'overcome_obstacle', 'win_battle', 'succeed', 'win_game']
senticnet['overcompensate'] = [0.846, -0.534, 0, 0.919, '#joyful', '#admirable', 0.766, 'correct', 'compensate', 'counterbalance', 'make_up', 'even_out']
senticnet['overdraw'] = [0.54, -0.976, 0, 0.569, '#surprising', '#admirable', 0.695, 'overstate', 'hyperbolize', 'glorify', 'exaggerate', 'aggrandize']
senticnet['overdress'] = [-0.852, 0, 0.853, -0.913, '#angry', '#disgusting', -0.873, 'raiment', 'garb', 'dress', 'clothe', 'enclothe']
senticnet['overeat'] = [0, 0, 0.814, -0.931, '#angry', '#disgusting', -0.582, 'eat_much', 'eat_dinner', 'eat_lunch', 'eat_excessively', 'eat_too_much']
senticnet['overemphasize'] = [-0.925, 0, 0, -0.833, '#sad', '#disgusting', -0.586, 'overstate', 'hyperbolize', 'exaggerate', 'overdraw', 'magnify']
senticnet['overestimate'] = [0.83, -0.835, 0, 0.872, '#surprising', '#admirable', 0.846, 'overappraisal', 'overvaluation', 'estimation', 'overestimation', 'commercial_document']
senticnet['overestimation'] = [0.83, -0.835, 0, 0.872, '#surprising', '#admirable', 0.846, 'overappraisal', 'overvaluation', 'overestimate', 'estimation', 'commercial_document']
senticnet['overexertion'] = [-0.508, 0, 0.681, -0.898, '#angry', '#disgusting', -0.696, 'sweat', 'effort', 'elbow_grease', 'exertion', 'travail']
senticnet['overfatigue'] = [-0.91, 0, 0.594, -0.531, '#sad', '#angry', -0.678, 'fatigue', 'wear', 'fag', 'tire', 'jade']
senticnet['overflow_incontinence'] = [-0.776, 0, 0.966, -0.518, '#sad', '#angry', -0.753, 'enuresis', 'incontinency', 'incontinence', 'stress_incontinence', 'urge_incontinence']
senticnet['overgrowth'] = [-0.762, 0, 0.571, -0.847, '#sad', '#disgusting', -0.727, 'bigger_than_usual', 'giantism', 'disease', 'hypertrophy', 'feel_pain']
senticnet['overhang'] = [0.753, -0.909, 0, 0.572, '#joyful', '#surprising', 0.745, 'bag', 'stick_out', 'thrust', 'push_up', 'spear']
senticnet['overhead'] = [-0.741, 0, 0, -0.858, '#sad', '#disgusting', -0.533, 'expense', 'excess', 'cost', 'fee', 'disadvantage']
senticnet['overjealous'] = [0.093, 0.086, 0.814, -0.682, '#angry', '#disgusting', -0.439, 'green-eyed_monster', 'green-eyed', 'covetous', 'grasp', 'covet']
senticnet['overlap'] = [-0.585, 0, 0.715, -0.597, '#angry', '#disgusting', -0.632, 'fly', 'flap', 'barndoor', 'coattail', 'codpiece']
senticnet['overlook'] = [-0.946, 0, -0.846, 0, '#sad', '#scared', -0.597, 'investigate_fact', 'investigation', 'think_logically', 'search', 'watch_carefully']
senticnet['overlooked'] = [-0.603, 0, 0.564, -0.85, '#sad', '#disgusting', -0.672, 'unmarked', 'ignored', 'unheeded', 'unnoticed', 'unnoted']
senticnet['overlord'] = [-0.808, 0, 0.826, -0.629, '#sad', '#angry', -0.754, 'liege', 'liege_lord', 'master', 'feudal_lord', 'lord']
senticnet['overmaster'] = [-0.542, 0, 0.945, -0.947, '#angry', '#disgusting', -0.811, 'crush', 'steamroller', 'steamroll', 'trounce', 'beat']
senticnet['overnight_guest'] = [0.097, -0.014, 0, 0, '#joyful', '#surprising', 0.037, 'sleep_upon', 'sit_upon', 'sleep', 'bed_time', 'good_sleep']
senticnet['overpay'] = [0, 0, 0.82, -0.741, '#angry', '#disgusting', -0.52, 'influenza', 'cripple', 'disability', 'chicken_pox', 'diabetes']
senticnet['overplus'] = [-0.775, 0, 0.9, -0.799, '#angry', '#disgusting', -0.825, 'embarrassment', 'fifth_wheel', 'deadwood', 'redundance', 'plethora']
senticnet['overpopulation'] = [-0.081, 0, 0.016, -0.104, '#sad', '#disgusting', -0.067, 'large_family', 'pass_gene', 'lower_standard_live', 'venereal_disease', 'make_person']
senticnet['overpower'] = [-0.791, 0, -0.808, 0, '#sad', '#scared', -0.533, 'keep_peace', 'defeat_enemy', 'conquer_enemy', 'gain_territory', 'kill_soldier']
senticnet['overprice'] = [-0.122, 0.193, 0.597, -0.627, '#angry', '#disgusting', -0.384, 'hire', 'job', 'ask_person', 'find_job', 'expensive']
senticnet['overprize'] = [-0.122, 0.193, 0.597, -0.627, '#angry', '#disgusting', -0.384, 'upvalue', 'overvalue', 'overrate', 'overstimate', 'overprice']
senticnet['overrate'] = [-0.122, 0.193, 0.597, -0.627, '#angry', '#disgusting', -0.384, 'upvalue', 'overvalue', 'overprize', 'overstimate', 'overprice']
senticnet['overrated'] = [0, 0, 0.894, -0.825, '#angry', '#disgusting', -0.573, 'get_old', 'old_software', 'unglam', 'old_technology', 'become_obsolete']
senticnet['override'] = [0.904, -0.695, 0, 0.758, '#joyful', '#admirable', 0.786, 'predominate', 'overarch', 'preponderate', 'outweigh', 'overbalance']
senticnet['overseas'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'abroad', 'another_country', 'study_abroad', 'elsewhere', 'live_abroad']
senticnet['oversee'] = [-0.029, 0.203, -0.093, 0.171, '#interesting', '#admirable', 0.084, 'take_charge', 'file_complaint', 'courageous', 'man_ship', 'obey_law']
senticnet['overshoe'] = [-0.881, 0, 0.75, -0.855, '#sad', '#disgusting', -0.829, 'rubber', 'galosh', 'golosh', 'arctic', 'gumshoe']
senticnet['oversleep'] = [-0.147, -0.057, 0, -0.166, '#sad', '#disgusting', -0.085, 'sleep_day', 'pull_up_cover', 'toss_turn', 'miss_work', 'look_out_window']
senticnet['overspend'] = [0, 0, 0.723, -0.747, '#angry', '#disgusting', -0.49, 'become_poor', 'little_money', 'lose_wallet', 'spend_much_money', 'pay_fine']
senticnet['overstate'] = [-0.743, 0, 0, -0.882, '#sad', '#disgusting', -0.542, 'brag', 'embellish', 'overemphasize', 'overstress', 'vaunt']
senticnet['overstimate'] = [-0.122, 0.193, 0.597, -0.627, '#angry', '#disgusting', -0.384, 'upvalue', 'overvalue', 'overprize', 'overrate', 'overprice']
senticnet['overstress'] = [0.796, -0.623, 0, 0.683, '#joyful', '#admirable', 0.701, 'overstate', 'hyperbolize', 'exaggerate', 'overdraw', 'magnify']
senticnet['overstrung'] = [-0.897, 0, -0.808, 0, '#sad', '#scared', -0.568, 'high-strung', 'uptight', 'restive', 'nervy', 'jumpy']
senticnet['overt'] = [-0.695, 0, 0.857, -0.921, '#angry', '#disgusting', -0.824, 'bald', 'raw', 'barefaced', 'visible', 'naked']
senticnet['overthrow'] = [-0.848, 0, 0.744, -0.581, '#sad', '#angry', -0.724, 'subversion', 'subversive_activity', 'termination', 'ending', 'conclusion']
senticnet['overtire'] = [-0.808, 0, 0.63, -0.914, '#sad', '#disgusting', -0.784, 'fatigue', 'wear', 'fag', 'tire', 'jade']
senticnet['overturn'] = [0.985, -0.761, 0, 0.96, '#joyful', '#admirable', 0.902, 'reverse', 'lift', 'go_back_on', 'vacate', 'annul']
senticnet['overturned'] = [-0.652, 0, 0.935, -0.846, '#angry', '#disgusting', -0.811, 'upset', 'inverted', 'turned', 'upturned', 'reversed']
senticnet['overvaluation'] = [0.83, -0.835, 0, 0.872, '#surprising', '#admirable', 0.846, 'overappraisal', 'estimation', 'overestimate', 'overestimation', 'commercial_document']
senticnet['overvalue'] = [-0.122, 0.193, 0.597, -0.627, '#angry', '#disgusting', -0.384, 'upvalue', 'overrate', 'overprize', 'overstimate', 'overprice']
senticnet['overweary'] = [-0.591, 0, 0.852, -0.718, '#angry', '#disgusting', -0.72, 'fatigue', 'wear', 'fag', 'tire', 'jade']
senticnet['overweight'] = [-0.031, 0.157, 0.698, -0.661, '#angry', '#disgusting', -0.411, 'fat', 'look_unattractive', 'fatty', 'unhealthy', 'eat_too_much']
senticnet['overwhelm'] = [-0.398, -0.049, 0, -0.418, '#sad', '#disgusting', -0.256, 'black_eye', 'censorship', 'call_name', 'schizophrenia', 'imprisonment']
senticnet['ovum'] = [0, 0.067, 0, 0.07, '#interesting', '#admirable', 0.046, 'peck', 'embryo', 'chicken_egg', 'bushel', 'egg']
senticnet['owe'] = [-0.055, 0.299, -0.117, 0.134, '#interesting', '#admirable', 0.087, 'payment', 'afford', 'bribe', 'debit', 'wage']
senticnet['owe_money'] = [-0.139, 0.251, -0.131, 0.146, '#interesting', '#admirable', 0.042, 'give_cash', 'bill_pay', 'send_money', 'money_exchange', 'money']
senticnet['owlclaws'] = [-0.767, 0, 0.76, -0.669, '#sad', '#angry', -0.732, 'herb', 'autumn_sneezeweed', 'orange_sneezeweed', 'sneezeweed', 'rosilla']
senticnet['owlet_moth'] = [-0.708, 0, 0.718, -0.559, '#sad', '#angry', -0.662, 'armyworm', 'underwing', 'antler_moth', 'heliothis_moth', 'moth']
senticnet['own'] = [0, 0.276, -0.213, 0.323, '#interesting', '#admirable', 0.129, 'have_something', 'ownership', 'possession', 'possess', 'owner']
senticnet['own_bathroom'] = [0, 0.092, 0.016, 0.074, '#interesting', '#admirable', 0.05, 'walmart', 'drugstore', 'beach_bag', 'pharmacy', 'car_trunk']
senticnet['own_benefit'] = [0, 0.844, 0, 0.928, '#interesting', '#admirable', 0.591, 'improve_self-image', 'keep_body_healthy', 'look_attractive', 'feel_better_oneself', 'make_healthy']
senticnet['own_car'] = [0, 0.95, 0, 0.784, '#interesting', '#admirable', 0.578, 'storm_out_room', 'captain_boat', 'mine_diamond', 'bicycle_across_town', 'sail_around_world']
senticnet['own_computer'] = [0.063, 0.099, 0, 0.119, '#interesting', '#admirable', 0.094, 'a_lot_of_time', 'buddha', 'learn_program_language', 'turn_computer_on', 'write_email']
senticnet['own_flag'] = [0.062, 0.078, 0, 0, '#joyful', '#interesting', 0.047, 'large_area_land', 'type_of_government', 'kingdom', 'flag', 'citizen']
senticnet['own_freezer'] = [0, 0.071, 0.009, 0.104, '#interesting', '#admirable', 0.055, 'retail_store', 'supermarket', 'grocery_store', 'farmer_market', 'market']
senticnet['own_house'] = [0.101, 0.099, 0, 0.169, '#joyful', '#admirable', 0.123, 'family_home', 'small_home', 'old_house', 'appliance_store', 'residence']
senticnet['own_kitchen'] = [0.038, 0, 0, 0.089, '#joyful', '#admirable', 0.042, 'kitchen_ware', 'container', 'storage', 'pantry', 'food_storage']
senticnet['own_land'] = [-0.049, 0.258, -0.13, 0.185, '#interesting', '#admirable', 0.088, 'good_investment', 'estate', 'personal_belong', 'property', 'ownership']
senticnet['own_lot'] = [0, 0.142, -0.061, 0.143, '#interesting', '#admirable', 0.075, 'populate', 'group_of_people', 'bird_group', 'asset', 'urban']
senticnet['own_person'] = [0.059, 0.16, -0.154, 0.24, '#interesting', '#admirable', 0.102, 'owner', 'ownership', 'possession', 'own', 'have_something']
senticnet['own_pet'] = [0, 0, 0.958, 0, '#angry', '#angry', -0.319, 'perform_magic', 'find_love', 'complain_state_world', 'jump_off_bridge', 'live_apartment']
senticnet['own_space'] = [0.247, 0.204, -0.064, 0.354, '#joyful', '#admirable', 0.247, 'family_live', 'nice_house', 'live_life', 'residence', 'live_space']
senticnet['owner'] = [0.035, 0.213, -0.169, 0.21, '#interesting', '#admirable', 0.096, 'own_person', 'property', 'have_something', 'ownership', 'own']
senticnet['owner_house'] = [0, -0.062, 0, 0.062, '#surprising', '#admirable', 0.041, 'box', 'small_box', 'small_apartment', 'veterinarian_office', 'pet_shop']
senticnet['ownership'] = [0, 0.259, -0.225, 0.338, '#interesting', '#admirable', 0.124, 'own', 'have_something', 'possess', 'possession', 'possessive']
senticnet['oxblood_red'] = [0.59, -0.866, 0, 0.561, '#joyful', '#surprising', 0.672, 'claret', 'wine', 'dark_red', 'red', 'redness']
senticnet['oxeye_daisy'] = [0.782, -0.695, 0, 0.684, '#joyful', '#surprising', 0.72, 'mayweed', 'stinking_mayweed', 'stinking_chamomile', 'dog_fennel', 'composite_plant']
senticnet['oxide'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'small_piece', 'spangle', 'stripe', 'particle', 'dust_particle']
senticnet['oxidizable'] = [0.766, -0.875, 0, 0.666, '#joyful', '#surprising', 0.769, 'reactive', 'unstable', 'labile', 'activated', 'excited']
senticnet['oxyacid'] = [-0.814, 0, 0.774, -0.776, '#sad', '#disgusting', -0.788, 'acid', 'hypophosphoric_acid', 'periodic_acid', 'hypophosphorous_acid', 'phosphorous_acid']
senticnet['oxycontin'] = [0.138, 0.103, 0, 0.095, '#joyful', '#interesting', 0.112, 'masturbation', 'sexual_intercourse', 'sex', 'warm_fuzzy_feeling', 'fuck']
senticnet['oxygen'] = [0.909, 0.983, 0, 0, '#joyful', '#interesting', 0.631, 'air', 'breathable', 'atmosphere', 'hydrogen', 'inhale_air']
senticnet['oxygen_acid'] = [-0.569, 0, 0.736, -0.528, '#sad', '#angry', -0.611, 'acid', 'hypophosphoric_acid', 'periodic_acid', 'hypophosphorous_acid', 'phosphorous_acid']
senticnet['oxyopia'] = [0.959, -0.976, 0, 0.633, '#joyful', '#surprising', 0.856, 'acuity', 'sight', 'top', 'vision', 'visual_sense']
senticnet['oyster_cracker'] = [-0.955, 0, 0.762, -0.648, '#sad', '#angry', -0.788, 'saltine', 'soda_cracker', 'cracker', 'water_biscuit', 'graham_cracker']
senticnet['ozone_hole'] = [-0.92, 0, 0.917, -0.956, '#sad', '#disgusting', -0.931, 'make_pollution', 'polluted_air', 'pollution', 'create_pollution', 'pollution_factory']
senticnet['pablum'] = [0.739, -0.899, 0, 0.702, '#joyful', '#surprising', 0.78, 'pap', 'content', 'drivel', 'folderol', 'codswallop']
senticnet['pace'] = [-0.04, 0.123, 0, 0.237, '#interesting', '#admirable', 0.107, 'foot_motion', 'foot_movement', 'foot_action', 'move_ahead', 'stride']
senticnet['pacesetter'] = [0.986, -0.609, 0, 0.568, '#joyful', '#surprising', 0.721, 'beaut', 'ideal', 'beauty', 'pattern', 'exemplar']
senticnet['pacific'] = [-0.606, 0, 0.694, -0.651, '#angry', '#disgusting', -0.65, 'appeasing', 'placating', 'placative', 'placatory', 'conciliative']
senticnet['pacific_northwest'] = [0.03, 0.068, -0.061, 0.062, '#interesting', '#admirable', 0.033, 'american_forest', 'thermal', 'treetop', 'animals', 'zoo']
senticnet['pacific_ocean'] = [0, 0.087, 0, 0.071, '#interesting', '#admirable', 0.053, 'pond', 'lake', 'atlantic_ocean', 'small_lake', 'mere']
senticnet['pacifically'] = [0.621, 0.648, -0.252, 0.296, '#joyful', '#interesting', 0.438, 'repose', 'peace-loving', 'peaceably', 'peaceable', 'peace_of_mind']
senticnet['pacificism'] = [-0.917, 0, 0.688, -0.574, '#sad', '#angry', -0.726, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['pacifism'] = [0.176, 0.317, -0.119, 0.458, '#interesting', '#admirable', 0.277, 'belief', 'forgiven', 'fallen_angel', 'dogma', 'religious_service']
senticnet['pacify'] = [0, 0.812, 0, 0.955, '#interesting', '#admirable', 0.589, 'tranquilize', 'tranquillize', 'calm_down', 'quieten', 'calm']
senticnet['pack'] = [0, 0.11, -0.057, 0.149, '#interesting', '#admirable', 0.067, 'pack_clothes', 'hold_stuff', 'carry_stuff', 'carry_book', 'carry_belongings']
senticnet['pack_animal'] = [0.024, 0.102, -0.068, 0.074, '#interesting', '#admirable', 0.044, 'dolphin', 'large_mammal', 'marine_mammal', 'mammal', 'smart_creature']
senticnet['pack_bag'] = [0.735, -0.785, 0, 0, '#joyful', '#surprising', 0.507, 'travel_work', 'sightsee', 'charge_battery', 'travel_to_another_place', 'create_pollution']
senticnet['pack_clothes'] = [0, 0.124, -0.057, 0.203, '#interesting', '#admirable', 0.09, 'carry_clothes', 'carry_belongings', 'carry_book', 'move_object', 'carry_stuff']
senticnet['pack_luggage'] = [0.986, -0.916, 0, 0, '#joyful', '#surprising', 0.634, 'pull_off_road', 'locate_place', 'discover_new_place', 'carry_luggage', 'drive_destination']
senticnet['pack_lunch'] = [0.044, -0.189, 0.03, 0.081, '#surprising', '#admirable', 0.095, 'go_mountain', 'step_forward', 'catch_bass', 'catch_catfish', 'tie_shoes']
senticnet['package'] = [0, -0.949, 0, 0.83, '#surprising', '#admirable', 0.593, 'parcel', 'mail', 'electric_bill', 'box', 'give_out']
senticnet['packman'] = [-0.774, 0, 0.874, -0.803, '#angry', '#disgusting', -0.817, 'peddler', 'pedlar', 'cheapjack', 'hawker', 'pitchman']
senticnet['pact'] = [0.397, 0.245, -0.135, 0.224, '#joyful', '#interesting', 0.244, 'agreement', 'provide', 'advice', 'contribution', 'offer']
senticnet['pad'] = [0.153, 0, 0, 0.149, '#joyful', '#admirable', 0.101, 'note_pad', 'stationery', 'post_note', 'intern', 'stamp_pad']
senticnet['paddle'] = [0.153, 0, 0, 0.149, '#joyful', '#admirable', 0.101, 'water_transportation', 'raft', 'canoe', 'water_vehicle', 'ship']
senticnet['paddle_boat'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'boat', 'big_boat', 'ship', 'large_boat', 'rowboat']
senticnet['paella'] = [0.039, 0.089, 0.023, 0, '#joyful', '#interesting', 0.035, 'steak_house', 'tapas', 'french_restaurant', 'spanish_restaurant', 'restaurant_diner']
senticnet['pag'] = [0.034, 0.074, 0, 0, '#joyful', '#interesting', 0.036, 'pet', 'retriever', 'most_cats', 'dog', 'poodle']
senticnet['pagan'] = [0, 0, 0, -0.776, '#disgusting', '#disgusting', -0.259, 'sophisticated', 'religion', 'worship', 'sing_microphone', 'guardian']
senticnet['page_doctor'] = [-0.132, 0.088, -0.12, 0, '#sad', '#scared', -0.055, 'needy', 'welcome_friend', 'offer_help', 'part_of_way', 'page_person']
senticnet['page_person'] = [-0.12, 0, -0.063, 0, '#sad', '#scared', -0.061, 'bridge_difference', 'stand_alone', 'deal_card_player', 'forward_email', 'explain_everything']
senticnet['page_through_book'] = [-0.128, 0, 0, -0.076, '#sad', '#disgusting', -0.068, 'check_mail', 'borrow_book_from_library', 'think_issue', 'report_crime', 'master_skill']
senticnet['paid'] = [0.521, -0.859, 0, 0.727, '#surprising', '#admirable', 0.702, 'compensated', 'remunerated', 'paying', 'stipendiary', 'remunerative']
senticnet['pain'] = [-0.993, 0, -0.734, 0, '#sad', '#scared', -0.576, 'hurt', 'ouch', 'ache', 'dislocation', 'excruciate']
senticnet['pain_in_ass'] = [-0.917, 0, 0.668, -0.997, '#sad', '#disgusting', -0.861, 'negative_stimulus', 'irritant', 'thorn', 'plague', 'nuisance']
senticnet['pain_in_neck'] = [-0.531, 0, 0.86, -0.657, '#angry', '#disgusting', -0.683, 'pain_in_ass', 'pain', 'irritant', 'annoyance', 'bother']
senticnet['pain_in_stomach'] = [-0.792, 0, -0.924, -0.708, '#sad', '#scared', -0.808, 'feel_weak', 'famine', 'need_snacks', 'order_food', 'feel_hunger']
senticnet['pain_person'] = [-0.097, -0.022, 0, -0.141, '#sad', '#disgusting', -0.072, 'close_eye', 'sleepwalk', 'wind_down', 'miss_appointment', 'quiet_mind']
senticnet['pain_pill'] = [-0.985, 0, 0.601, -0.695, '#sad', '#disgusting', -0.76, 'hydromorphone_hydrochloride', 'hydromorphone', 'acetaminophen', 'codeine', 'medicine']
senticnet['pain_reliever'] = [0.969, 0.817, 0, 0.828, '#joyful', '#admirable', 0.871, 'ibuprofen', 'painkiller', 'medicine', 'analgesic', 'phenobarbital']
senticnet['pain_sensation'] = [-0.928, 0, 0.782, -0.649, '#sad', '#angry', -0.786, 'pain', 'painful', 'inflict_pain', 'break_leg', 'cut_skin']
senticnet['pain_suffer'] = [-0.342, -0.024, -0.143, -0.232, '#sad', '#disgusting', -0.231, 'find_out_healthy', 'lose_mind', 'hurt_feeling', 'migraine', 'a_lot_of_stress']
senticnet['painful'] = [-0.768, 0, -0.911, 0, '#sad', '#scared', -0.56, 'fatal', 'hurtful', 'severe', 'bloody', 'unbearable']
senticnet['painful_injury'] = [-0.131, -0.016, -0.051, -0.097, '#sad', '#disgusting', -0.088, 'tear_apart', 'abrasion', 'wound', 'gash', 'laceration']
senticnet['painful_sensation'] = [-0.928, 0, 0.782, -0.649, '#sad', '#angry', -0.786, 'pain', 'painful', 'inflict_pain', 'break_leg', 'cut_skin']
senticnet['painfully'] = [-0.956, 0, -0.72, 0, '#sad', '#scared', -0.559, 'disquieted', 'distressing', 'disturbing', 'perturbing', 'troubling']
senticnet['painkiller'] = [0, 0, -0.058, -0.194, '#scared', '#disgusting', -0.084, 'phenobarbital', 'ibuprofen', 'analgesic', 'palliative', 'aspirin']
senticnet['painstakingness'] = [0.512, -0.945, 0, 0.5, '#joyful', '#surprising', 0.652, 'scrupulousness', 'carefulness', 'diligence', 'meticulousness', 'meticulosity']
senticnet['paint'] = [-0.073, 0, 0, -0.074, '#sad', '#disgusting', -0.049, 'cartoon_character', 'use_tool', 'mould', 'use_oil_cartoon_character', 'buy_cartoon_character']
senticnet['paint_brush'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'artist', 'oil_paint', 'painter', 'creative_person', 'make_paint']
senticnet['paint_canvas'] = [0.723, 0.816, 0, 0.922, '#interesting', '#admirable', 0.82, 'create_new_idea', 'letter_sign', 'create_music', 'make_paint', 'create']
senticnet['paint_ceiling'] = [-0.068, 0, 0, 0, '#sad', '#sad', -0.023, 'picture_scene', 'take_photograph', 'climb_ladder', 'frame_picture', 'staircase']
senticnet['paint_face'] = [0.051, 0.214, 0, 0.142, '#interesting', '#admirable', 0.136, 'soccer_game', 'have_fun', 'carnival', 'funny', 'joke']
senticnet['paint_fingernail'] = [0.721, 0, 0, 0.735, '#joyful', '#admirable', 0.485, 'deal_card_player', 'forward_email', 'explain_everything', 'mind_store', 'bridge_difference']
senticnet['paint_house'] = [0.936, 0.749, 0, 0.871, '#joyful', '#admirable', 0.852, 'paint_picture', 'tie-dye', 'create_art', 'make_patchwork_quilt', 'letter_sign']
senticnet['paint_lily'] = [0.532, -0.731, 0, 0.708, '#surprising', '#admirable', 0.657, 'beautify', 'embellish', 'decorate', 'adorn', 'grace']
senticnet['paint_line'] = [0, 0.119, 0, 0.123, '#interesting', '#admirable', 0.081, 'street_sign', 'road_sign', 'red_light', 'traffic_sign', 'halt']
senticnet['paint_nail'] = [0.736, 0.99, 0, 0, '#joyful', '#interesting', 0.575, 'clean_shoes', 'remove_paint', 'make_pretty', 'clean_floor', 'shine_shoes']
senticnet['paint_picture'] = [0.936, 0.749, 0, 0.871, '#joyful', '#admirable', 0.852, 'create_art', 'tie-dye', 'paint_house', 'make_patchwork_quilt', 'letter_sign']
senticnet['paintbrush'] = [0.719, 0.923, 0, 0, '#joyful', '#interesting', 0.547, 'use_brush', 'hair', 'brush_hair', 'brush_tooth', 'brush']
senticnet['painter'] = [0.041, 0.112, 0, 0.077, '#interesting', '#admirable', 0.077, 'oil_paint', 'artist_tool', 'artist', 'oil_painting', 'painting']
senticnet['painterly'] = [0.596, -0.64, 0, 0.945, '#surprising', '#admirable', 0.727, 'cosmetic', 'aesthetical', 'sensuous', 'artistic', 'enhancive']
senticnet['painting'] = [0, 0.09, 0, 0.111, '#interesting', '#admirable', 0.067, 'oil_paint', 'oil_painting', 'artwork', 'wall_art', 'mural']
senticnet['pair'] = [0.702, -0.65, 0, 0.788, '#joyful', '#admirable', 0.713, 'have', 'bonk', 'take', 'couple', 'fornicate']
senticnet['pair_of_pants'] = [0.845, -0.941, 0, 0, '#joyful', '#surprising', 0.595, 'jeans', 'panties', 'lingerie', 'clothes', 'underwear']
senticnet['pair_of_scissors'] = [0, -0.067, 0.092, -0.16, '#angry', '#disgusting', -0.062, 'thumb_tack', 'clipper', 'razor', 'scissor', 'haircut_scissor']
senticnet['pajama'] = [0, 0.081, 0.015, 0.052, '#interesting', '#admirable', 0.039, 'fabric', 'underwear', 'white_cotton', 'shirt', 'pants']
senticnet['pal'] = [0.153, 0, 0, 0.149, '#joyful', '#admirable', 0.101, 'buddy', 'comrade', 'companion', 'healthy_person', 'man_wife']
senticnet['palace'] = [0, 0.105, 0, 0.076, '#interesting', '#admirable', 0.06, 'big_house', 'mansion', 'castle', 'block_flat', 'medieval']
senticnet['pale'] = [-0.076, 0, -0.068, -0.043, '#sad', '#scared', -0.062, 'color_paint', 'no_color', 'dark_color', 'hue', 'after_sundown']
senticnet['palette'] = [0.041, 0.112, 0, 0.077, '#interesting', '#admirable', 0.077, 'oil_paint', 'artist', 'brush', 'artist_tool', 'canvas']
senticnet['pall'] = [0, 0, 0, -0.89, '#disgusting', '#disgusting', -0.297, 'scary', 'foreboding', 'boding', 'premonition', 'presentiment']
senticnet['pallbearer'] = [-0.989, 0, 0.664, -0.524, '#sad', '#angry', -0.726, 'unfortunate', 'unfortunate_person', 'weeper', 'griever', 'bearer']
senticnet['palliative'] = [-0.033, -0.02, -0.082, -0.187, '#scared', '#disgusting', -0.094, 'ibuprofen', 'phenobarbital', 'analgesic', 'sleep_drug', 'pill']
senticnet['pallidness'] = [-0.665, 0, 0.782, -0.529, '#sad', '#angry', -0.659, 'lividness', 'complexion', 'pallor', 'wanness', 'achromasia']
senticnet['pallor'] = [-0.665, 0, 0.782, -0.529, '#sad', '#angry', -0.659, 'lividness', 'pallidness', 'complexion', 'wanness', 'achromasia']
senticnet['palm'] = [0.586, -0.651, 0, 0.503, '#joyful', '#surprising', 0.58, 'decoration', 'laurel_wreath', 'medal', 'medallion', 'distinguished_service_cross']
senticnet['palm_kernel'] = [-0.594, 0, 0.945, -0.854, '#angry', '#disgusting', -0.798, 'palm_nut', 'nut', 'edible_nut', 'cembra_nut', 'cedar_nut']
senticnet['palm_nut'] = [-0.594, 0, 0.945, -0.854, '#angry', '#disgusting', -0.798, 'nut', 'palm_kernel', 'edible_nut', 'cembra_nut', 'cedar_nut']
senticnet['palm_tree'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'ocean_edge', 'water_beach', 'bottom_ocean', 'sea_shore', 'seashore']
senticnet['palmetto'] = [0.557, -0.534, 0, 0.704, '#joyful', '#admirable', 0.598, 'carnauba_palm', 'carnauba', 'wax_palm', 'fan_palm', 'palmyra']
senticnet['palmy'] = [0.98, -0.746, 0, 0.984, '#joyful', '#admirable', 0.903, 'prosperous', 'flourishing', 'successful', 'prospering', 'thriving']
senticnet['palmyra'] = [0.557, -0.534, 0, 0.704, '#joyful', '#admirable', 0.598, 'carnauba_palm', 'carnauba', 'wax_palm', 'palmetto', 'fan_palm']
senticnet['palpability'] = [-0.639, 0, 0.694, -0.667, '#angry', '#disgusting', -0.667, 'tangibility', 'tangibleness', 'corporality', 'reality', 'solidness']
senticnet['palpable'] = [0.985, -0.815, 0, 0.673, '#joyful', '#surprising', 0.824, 'discernible', 'noticeable', 'detectable', 'perceptible', 'perceivable']
senticnet['palpebra'] = [-0.79, 0, 0.769, -0.798, '#sad', '#disgusting', -0.786, 'flap', 'eyelid', 'lid', 'protective_fold', 'nictitating_membrane']
senticnet['pamper'] = [0.27, 0, 0, 0, '#joyful', '#joyful', 0.09, 'bourgeois', 'social_event', 'pleasant', 'just_fun', 'break_work']
senticnet['pamperer'] = [0.687, -0.762, 0, 0.905, '#surprising', '#admirable', 0.785, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['pamphlet'] = [0.058, -0.049, 0, 0, '#joyful', '#surprising', 0.036, 'letter_slot', 'envelope', 'address_label', 'mailman', 'postage_stamp']
senticnet['pan'] = [0.758, 0.836, 0, 0, '#joyful', '#interesting', 0.531, 'scrumble_egg', 'heat_meal', 'beat_egg', 'breakfast', 'food']
senticnet['pan_out'] = [0.596, -0.995, 0, 0.593, '#joyful', '#surprising', 0.728, 'deliver_goods', 'succeed', 'win', 'bring_home_bacon', 'come_through']
senticnet['panama'] = [0.057, 0.118, -0.049, 0.151, '#interesting', '#admirable', 0.092, 'small_river', 'fresh_water', 'water_feature', 'water_body', 'large_body']
senticnet['pancake'] = [0, -0.113, 0, 0, '#surprising', '#surprising', 0.038, 'cake', 'cookie', 'mousse', 'doughnut', 'brownie']
senticnet['pancreas'] = [0.079, -0.107, 0.046, 0, '#joyful', '#surprising', 0.047, 'nerve', 'liver', 'groin', 'scrotum', 'diaphragm']
senticnet['panda'] = [0.02, 0.071, 0, 0.069, '#interesting', '#admirable', 0.053, 'many_animals', 'donkey', 'chimpanzee', 'cute_animal', 'creature']
senticnet['pane'] = [0, 0.069, 0.025, 0.074, '#interesting', '#admirable', 0.039, 'glass', 'look_glass', 'glass_of_water', 'see_thru', 'clear']
senticnet['panegyric'] = [0, 0, -0.913, -0.727, '#scared', '#disgusting', -0.547, 'encomiastic', 'encomium', 'paean', 'eulogy', 'pean']
senticnet['panel'] = [0, 0, 0, 0.121, '#admirable', '#admirable', 0.04, 'wood_panel', 'house_front', 'wooden_structure', 'slam', 'home_entrance']
senticnet['panendoscope'] = [0.255, 0.182, -0.06, 0.314, '#joyful', '#admirable', 0.23, 'doctor_office', 'urethroscope', 'sigmoidoscope', 'hospital', 'check_health']
senticnet['panhandler'] = [-0.127, 0, -0.063, -0.046, '#sad', '#scared', -0.079, 'graffiti', 'homeless_people', 'homeless_person', 'bum', 'homeless']
senticnet['panic'] = [-0.482, 0.167, -0.309, -0.213, '#sad', '#scared', -0.279, 'anxiety', 'scare', 'confusion', 'worry', 'embarrassment']
senticnet['panic-stricken'] = [-0.756, 0, -0.843, 0, '#sad', '#scared', -0.533, 'panic-struck', 'panicked', 'panicky', 'terrified', 'frightened']
senticnet['panic-struck'] = [-0.724, 0, -0.986, 0, '#sad', '#scared', -0.57, 'panic-stricken', 'panicked', 'panicky', 'terrified', 'frightened']
senticnet['panic_attack'] = [-0.986, -0.935, -0.945, 0, '#sad', '#scared', -0.332, 'fright', 'uneasiness', 'hysteria', 'terrible', 'hopeless']
senticnet['panicked'] = [-0.711, 0, -0.96, 0, '#sad', '#scared', -0.557, 'panic-struck', 'panic-stricken', 'panicky', 'terrified', 'frightened']
senticnet['panicky'] = [-0.803, 0, -0.701, 0, '#sad', '#scared', -0.501, 'panic-struck', 'panic-stricken', 'panicked', 'terrified', 'frightened']
senticnet['panoply'] = [0.757, -0.635, 0, 0.501, '#joyful', '#surprising', 0.631, 'array', 'row', 'table', 'tabular_array', 'matrix']
senticnet['panoptic'] = [0.654, -0.715, 0, 0.624, '#joyful', '#surprising', 0.664, 'viewable', 'gross', 'telescopic', 'seeable', 'visual']
senticnet['panorama'] = [0.813, 0, 0, 0.826, '#joyful', '#admirable', 0.546, 'vista', 'spectacular', 'perspective', 'image', 'scenic']
senticnet['pant'] = [-0.027, -0.05, 0.092, -0.065, '#angry', '#disgusting', -0.045, 'gasp', 'puff', 'wheeze', 'blow', 'heave']
senticnet['pant_back_pocket'] = [0, 0.092, 0, 0, '#interesting', '#interesting', 0.031, 'man_back_pocket', 'pocket', 'back_pocket', 'purse', 'clothes_washer']
senticnet['pant_pocket'] = [0, 0.092, 0, 0, '#interesting', '#interesting', 0.031, 'man_pocket', 'back_pocket', 'pocket', 'purse', 'clothes_washer']
senticnet['pantie'] = [0.875, 0.712, 0, 0, '#joyful', '#interesting', 0.529, 'under_garment', 'undergarment', 'underwear', 'woman_clothes', 'lady_underwear']
senticnet['panties'] = [0.854, 0.9, 0, 0, '#joyful', '#interesting', 0.585, 'lingerie', 'underwear', 'pair_of_pants', 'robe', 'slack']
senticnet['pantry'] = [-0.044, -0.009, 0.049, 0, '#sad', '#angry', -0.028, 'buy_many', 'buy_gum', 'shop_grocery', 'buy_clothes', 'find_pantry']
senticnet['pants'] = [-0.047, 0.1, 0, 0.152, '#interesting', '#admirable', 0.068, 'shirt', 'jacket', 'clothes', 'robe', 'garment']
senticnet['pantyhose'] = [0, -0.078, 0.099, -0.106, '#angry', '#disgusting', -0.042, 'prescription_medication', 'lingerie', 'sachet', 'shave_kit', 'panties']
senticnet['pap'] = [0.739, -0.899, 0, 0.702, '#joyful', '#surprising', 0.78, 'drivel', 'content', 'pablum', 'folderol', 'codswallop']
senticnet['paper'] = [0.022, -0.057, 0.079, -0.116, '#angry', '#disgusting', -0.039, 'stationery', 'ink', 'ball_point_pen', 'refill', 'notes']
senticnet['paper_airplane'] = [0, 0.8, 0, 0.836, '#interesting', '#admirable', 0.545, 'make_paper_airplane', 'make_mark_paper', 'write_note', 'witting', 'make_note']
senticnet['paper_bill'] = [0, 0.964, 0, 0.823, '#interesting', '#admirable', 0.596, 'cash_bill', 'cash_coin', 'dollar_bill', 'debit_card', 'check']
senticnet['paper_book'] = [0.024, 0.121, -0.077, 0.164, '#interesting', '#admirable', 0.077, 'conceal', 'concealment', 'front_page', 'vocabulary', 'book_content']
senticnet['paper_chromatography'] = [0.838, -0.618, 0, 0.556, '#joyful', '#surprising', 0.671, 'activity', 'natural_process', 'natural_action', 'column_chromatography', 'chromatography']
senticnet['paper_clip'] = [0, 0.106, -0.084, 0.145, '#interesting', '#admirable', 0.056, 'paper_fastener', 'paper_punch', 'intern', 'office', 'highlighter']
senticnet['paper_crumple'] = [0.76, 0.762, 0, 0, '#joyful', '#interesting', 0.507, 'talk', 'party', 'say_word', 'communicate', 'speak']
senticnet['paper_currency'] = [0, 0.239, 0, 0.129, '#interesting', '#admirable', 0.123, 'euro', 'currency', 'money_unit', 'dollar_change', 'four_quarters']
senticnet['paper_cut'] = [-0.829, -0.721, -0.807, 0, '#sad', '#scared', -0.305, 'feel_hurt', 'embarrassment', 'gonorrhea', 'hurt_feeling', 'psychoneurosis']
senticnet['paper_fastener'] = [0, 0.239, 0, 0.129, '#interesting', '#admirable', 0.123, 'paper_clip', 'decorate_wall', 'intern', 'glue', 'wallpaper']
senticnet['paper_menu'] = [0.146, 0.095, -0.046, 0, '#joyful', '#interesting', 0.065, 'dine_room', 'diner', 'cafe', 'restaurant', 'menu']
senticnet['paper_money'] = [-0.024, 0.147, 0, 0.073, '#interesting', '#admirable', 0.065, 'money_unit', 'monetary_unit', 'note', 'paper_currency', 'money_earn']
senticnet['paper_nautilus'] = [-0.523, 0, 0.728, -0.926, '#angry', '#disgusting', -0.726, 'nautilus', 'cephalopod', 'cephalopod_mollusk', 'octopod', 'octopus']
senticnet['paper_page'] = [0, -0.788, 0, 0.814, '#surprising', '#admirable', 0.534, 'current_event', 'headline', 'paper_write', 'bulletin', 'many_pages']
senticnet['paper_piece'] = [0.044, -0.007, 0.009, 0.138, '#joyful', '#admirable', 0.06, 'flat_thin', 'white_paper', 'paper_square', 'single_paper', 'game_piece']
senticnet['paper_plane'] = [0.999, 0.882, 0, 0, '#joyful', '#interesting', 0.627, 'learn_write', 'think_write', 'find_pen_and_paper', 'find_paper', 'pen_and_paper']
senticnet['paper_product'] = [-0.05, -0.039, 0.023, -0.095, '#sad', '#disgusting', -0.043, 'moldy_food', 'celery', 'spam', 'orange_juice', 'after_lunch']
senticnet['paper_punch'] = [0, 0.987, 0, 0.855, '#interesting', '#admirable', 0.614, 'intern', 'paper_fastener', 'office', 'paper_clip', 'self_adhesive_label']
senticnet['paper_sign'] = [0.076, 0, 0, 0.104, '#joyful', '#admirable', 0.06, 'post', 'newspaper_article', 'rail', 'column', 'peg']
senticnet['paper_square'] = [0.044, -0.007, 0.009, 0.138, '#joyful', '#admirable', 0.06, 'flat_thin', 'white_paper', 'paper_piece', 'single_paper', 'game_piece']
senticnet['paper_towel'] = [-0.73, 0, 0, -0.942, '#sad', '#disgusting', -0.557, 'moistener', 'steel_wool', 'toilet_paper', 'toilet_brush', 'bath_shower']
senticnet['paper_write'] = [0, -0.874, 0, 0.715, '#surprising', '#admirable', 0.53, 'current_event', 'headline', 'bulletin', 'paper_page', 'many_pages']
senticnet['paperclip'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'clip', 'clasp', 'glue_stick', 'clothespin', 'clamp']
senticnet['paperwork'] = [0.044, -0.026, 0, 0, '#joyful', '#surprising', 0.023, 'sheet_paper', 'piece_of_paper', 'staple_remover', 'board', 'whiteboard']
senticnet['pappose'] = [-0.754, 0, 0.734, -0.825, '#sad', '#disgusting', -0.771, 'puberulent', 'sericeous', 'furlike', 'haired', 'pilous']
senticnet['parachute'] = [-0.738, 0, 0, -0.742, '#sad', '#disgusting', -0.493, 'undergarment', 'outerwear', 'lady_underwear', 'under_garment', 'slip']
senticnet['paradise'] = [0.054, 0.098, 0, 0.076, '#interesting', '#admirable', 0.076, 'sky', 'heaven', 'constellation', 'thunder_storm', 'orbit_around_earth']
senticnet['paradox'] = [-0.569, 0, 0.593, -0.595, '#angry', '#disgusting', -0.586, 'antinomy', 'contradiction_in_terms', 'falsehood', 'falsity', 'untruth']
senticnet['paraffin'] = [0.072, 0.065, -0.068, 0.144, '#joyful', '#admirable', 0.071, 'gooey', 'bee_product', 'slick', 'goo', 'fuel_source']
senticnet['paragon'] = [0.118, 0.181, -0.076, 0.374, '#interesting', '#admirable', 0.199, 'compare', 'confrontation', 'collation', 'comparative', 'comparison']
senticnet['paragraph'] = [-0.042, 0.131, -0.055, 0.186, '#interesting', '#admirable', 0.073, 'print_word', 'document_type', 'typeface', 'hold_information', 'print']
senticnet['parakeet'] = [0.971, -0.598, 0, 0.768, '#joyful', '#admirable', 0.779, 'lovebird', 'parrakeet', 'parroket', 'paraquet', 'paroquet']
senticnet['paralegal'] = [-0.697, 0, 0.659, -0.696, '#sad', '#disgusting', -0.684, 'help', 'paraprofessional', 'legal_assistant', 'paramedic', 'paramedical']
senticnet['parallel'] = [0, 0, -0.9, -0.871, '#scared', '#disgusting', -0.59, 'analogue', 'analog', 'line_of_latitude', 'latitude', 'collimate']
senticnet['parallelogram'] = [0, 0.821, 0, 0.843, '#interesting', '#admirable', 0.555, 'polygon', 'geometric_figure', 'hexagon', 'geometrical_shape', 'geometric_shape']
senticnet['paralogism'] = [-0.777, 0, 0.885, -0.738, '#sad', '#angry', -0.8, 'pathetic_fallacy', 'misconception', 'fallacy', 'logical_fallacy', 'pseudoscience']
senticnet['paralysis'] = [-0.291, 0.095, -0.11, -0.135, '#sad', '#disgusting', -0.147, 'say_aha', 'think_hard', 'think_past', 'scratch_head', 'head_hurt']
senticnet['paramedic'] = [-0.697, 0, 0.659, -0.696, '#sad', '#disgusting', -0.684, 'help', 'paralegal', 'legal_assistant', 'paraprofessional', 'paraprofessionalal']
senticnet['paramedical'] = [-0.697, 0, 0.659, -0.696, '#sad', '#disgusting', -0.684, 'help', 'paralegal', 'legal_assistant', 'paramedic', 'paraprofessional']
senticnet['paramount_issue'] = [0.648, -0.873, 0, 0.597, '#joyful', '#surprising', 0.706, 'gut_issue', 'content', 'issue', 'pocketbook_issue', 'quodlibet']
senticnet['paramountcy'] = [0.94, -0.636, 0, 0.772, '#joyful', '#admirable', 0.783, 'dominion', 'raj', 'reign', 'sovereignty', 'suzerainty']
senticnet['paranoiac'] = [-0.606, 0, 0.892, -0.921, '#angry', '#disgusting', -0.806, 'schizophrenic', 'cataleptic', 'paranoid', 'psycho', 'sick_person']
senticnet['paranoid'] = [-0.086, -0.017, 0.137, -0.206, '#angry', '#disgusting', -0.137, 'go_trial', 'find_guilty', 'complain', 'piss_pant', 'commit_crime']
senticnet['paraphilia'] = [-0.622, 0, 0.515, -0.638, '#sad', '#disgusting', -0.592, 'immodesty', 'perversion', 'exhibitionism', 'sexual_perversion', 'fetishism']
senticnet['paraphrastic'] = [-0.623, 0, 0.657, -0.955, '#angry', '#disgusting', -0.745, 'altered', 'adjusted', 'changed', 'emended', 'edited']
senticnet['paraphrenia'] = [-0.227, -0.011, -0.133, -0.075, '#sad', '#scared', -0.141, 'clinical_problem', 'disorder', 'mental_disorder', 'disease', 'schizophrenic_disorder']
senticnet['paraprofessional'] = [-0.697, 0, 0.659, -0.696, '#sad', '#disgusting', -0.684, 'help', 'paralegal', 'legal_assistant', 'paramedic', 'paramedical']
senticnet['parapsychology'] = [-0.8, 0, 0.62, -0.712, '#sad', '#disgusting', -0.711, 'telekinesis', 'psychokinesis', 'clairvoyance', 'second_sight', 'extrasensory_perception']
senticnet['paraquat_poisoning'] = [-0.72, 0, 0.884, -0.758, '#angry', '#disgusting', -0.787, 'ergotism', 'poisoning', 'alkali_poisoning', 'caffeinism', 'caffeine_intoxication']
senticnet['paraquet'] = [0.971, -0.598, 0, 0.768, '#joyful', '#admirable', 0.779, 'parakeet', 'parrakeet', 'parroket', 'lovebird', 'paroquet']
senticnet['parasite'] = [-0.067, -0.022, 0.063, -0.113, '#sad', '#disgusting', -0.074, 'annoy_bug', 'nuisance_insect', 'fly_away', 'tiny_insect', 'small_fly']
senticnet['parasol'] = [-0.967, 0, -0.932, 0, '#sad', '#scared', -0.633, 'block_light', 'block_sunlight', 'no_sun', 'without_light', 'dark_area']
senticnet['parathion_poisoning'] = [-0.98, 0, 0.717, -0.515, '#sad', '#angry', -0.737, 'pesticide_poisoning', 'malathion_poisoning', 'toxic_condition', 'poisoning', 'intoxication']
senticnet['parcel'] = [-0.538, 0, 0.771, -0.696, '#angry', '#disgusting', -0.668, 'tract', 'piece_of_land', 'piece_of_ground', 'clearing_of_land', 'clearing']
senticnet['parcel_of_land'] = [-0.538, 0, 0.771, -0.696, '#angry', '#disgusting', -0.668, 'tract', 'piece_of_land', 'piece_of_ground', 'clearing', 'parcel']
senticnet['parched'] = [0, 0, -0.923, -0.966, '#scared', '#disgusting', -0.63, 'adust', 'scorched', 'sear', 'sunbaked', 'baked']
senticnet['pardon'] = [0.084, 0.139, -0.106, 0.334, '#interesting', '#admirable', 0.15, 'bless', 'faith', 'dogma', 'spiritual', 'gospel']
senticnet['pardonable'] = [0.768, -0.868, 0, 0.67, '#joyful', '#surprising', 0.769, 'expiable', 'excusable', 'forgivable', 'venial', 'minor']
senticnet['pardoner'] = [-0.935, 0, 0.951, -0.87, '#sad', '#angry', -0.919, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['parent'] = [0, 0.843, 0, 0.911, '#interesting', '#admirable', 0.585, 'female_sibling', 'female_relative', 'father', 'mother', 'same_parent']
senticnet['parent_child'] = [0, 0.829, 0, 0.842, '#interesting', '#admirable', 0.557, 'mom_dad', 'relate_person', 'father_mother', 'mother_father', 'brother_sister']
senticnet['parental_quality'] = [0.585, -0.885, 0, 0.615, '#surprising', '#admirable', 0.695, 'motherliness', 'maternal_quality', 'quality', 'maternalism', 'fatherliness']
senticnet['pariah_dog'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'dog', 'feist', 'fice', 'cur', 'domestic_dog']
senticnet['parisology'] = [0.633, -0.67, 0, 0.776, '#surprising', '#admirable', 0.693, 'double_entendre', 'loophole', 'amphibology', 'amphiboly', 'ambiguity']
senticnet['parity_check'] = [0.84, -0.979, 0, 0.713, '#joyful', '#surprising', 0.844, 'proof', 'bed_check', 'crosscheck', 'substantiation', 'redundancy_check']
senticnet['park'] = [0.026, 0, 0, 0.073, '#joyful', '#admirable', 0.033, 'state_park', 'arboretum', 'meadow', 'grass', 'backyard']
senticnet['park_area'] = [0.043, 0.087, 0, 0, '#joyful', '#interesting', 0.043, 'car_park', 'park_structure', 'taxiway', 'row_house', 'park_zone']
senticnet['park_bench'] = [0.1, 0, 0, 0, '#joyful', '#joyful', 0.033, 'bench', 'jogger', 'stool', 'bar', 'oak']
senticnet['park_meter'] = [0.91, 0.874, 0, 0, '#joyful', '#interesting', 0.595, 'candy', 'candy_machine', 'coin_purse', 'pocket', 'purse']
senticnet['park_space'] = [0.039, 0.081, -0.05, 0.053, '#interesting', '#admirable', 0.041, 'suite', 'empty_space', 'soda_machine', 'washroom', 'place_to_sit']
senticnet['park_structure'] = [0.057, 0.066, 0, -0.033, '#joyful', '#interesting', 0.03, 'car_park', 'semi-truck', 'taxiway', 'parking_lot', 'flight_terminal']
senticnet['park_zone'] = [0.043, 0.087, 0, 0, '#joyful', '#interesting', 0.043, 'park_area', 'park_structure', 'taxiway', 'parking_lot', 'car_park']
senticnet['parking_lot'] = [0, 0, 0, -0.095, '#disgusting', '#disgusting', -0.032, 'subway', 'bus', 'train_station', 'railway_station', 'bus_stop']
senticnet['parking_ticket'] = [-0.122, 0.193, 0.597, -0.627, '#angry', '#disgusting', -0.384, 'fee', 'speeding_ticket', 'ridiculous', 'car_wreck', 'meanness']
senticnet['parkinson'] = [-0.953, 0, 0.621, -0.725, '#sad', '#disgusting', -0.766, 'disease', 'brain_disorder', 'brain_disease', 'ill', 'epilepsy']
senticnet['parliament'] = [0.024, 0.274, -0.047, 0.195, '#interesting', '#admirable', 0.149, 'pope', 'minister', 'socialism', 'evangelist', 'rector']
senticnet['parlormaid'] = [-0.626, 0, 0.649, -0.673, '#angry', '#disgusting', -0.649, 'handmaid', 'handmaiden', 'chambermaid', 'lady_maid', 'maid']
senticnet['paroquet'] = [0.971, -0.598, 0, 0.768, '#joyful', '#admirable', 0.779, 'parakeet', 'parrakeet', 'parroket', 'paraquet', 'lovebird']
senticnet['parrakeet'] = [0.971, -0.598, 0, 0.768, '#joyful', '#admirable', 0.779, 'parakeet', 'lovebird', 'parroket', 'paraquet', 'paroquet']
senticnet['parroket'] = [0.971, -0.598, 0, 0.768, '#joyful', '#admirable', 0.779, 'parakeet', 'parrakeet', 'lovebird', 'paraquet', 'paroquet']
senticnet['parrot'] = [-0.687, 0, 0.947, -0.839, '#angry', '#disgusting', -0.824, 'popinjay', 'poll', 'bird', 'lovebird', 'amazon']
senticnet['parrotlike'] = [-0.5, 0, 0.97, -0.521, '#angry', '#disgusting', -0.664, 'simulated', 'apish', 'imitative', 'apelike', 'mimic']
senticnet['parry'] = [0, 0, 0.89, -0.85, '#angry', '#disgusting', -0.58, 'cut_down_tree', 'destroy_live', 'kill_life', 'destroy_city', 'destroy_home']
senticnet['parsimonious'] = [-0.919, 0, 0.598, -0.522, '#sad', '#angry', -0.68, 'stingy', 'penurious', 'scrimy', 'beggarly', 'chintzy']
senticnet['parsimoniousness'] = [0.533, -0.558, 0, 0.912, '#surprising', '#admirable', 0.668, 'parsimony', 'frugality', 'thrift', 'economy', 'prudence']
senticnet['parsimony'] = [0.533, -0.558, 0, 0.912, '#surprising', '#admirable', 0.668, 'frugality', 'parsimoniousness', 'thrift', 'economy', 'prudence']
senticnet['part'] = [0, 0.772, 0, 0.743, '#interesting', '#admirable', 0.505, 'segment', 'component', 'small_part', 'portion', 'fraction']
senticnet['part_of_band'] = [0.867, 0.808, 0, 0, '#joyful', '#interesting', 0.558, 'play_stringed_instrument', 'make_beautiful_music', 'keep_beat', 'make_music', 'chamber_music']
senticnet['part_of_body'] = [0, 0.068, 0, 0.097, '#interesting', '#admirable', 0.055, 'human_part', 'body_area', 'body_organ', 'human_organ', 'sense_organ']
senticnet['part_of_book'] = [0.053, 0, 0.025, 0.118, '#joyful', '#admirable', 0.049, 'paper_square', 'book', 'book_part', 'book_end', 'flat_thin']
senticnet['part_of_building'] = [0.021, 0.106, 0.014, 0.172, '#interesting', '#admirable', 0.095, 'house_place', 'house', 'live_area', 'live_quarter', 'house_location']
senticnet['part_of_ceremony'] = [0.894, 0, 0, 0.756, '#joyful', '#admirable', 0.55, 'obedience', 'suggestion', 'vow', 'good_behavior', 'behave']
senticnet['part_of_company'] = [-0.036, 0.149, -0.063, 0.14, '#interesting', '#admirable', 0.063, 'live_house', 'sell_house', 'address', 'house_location', 'name_street']
senticnet['part_of_day'] = [0.02, 0.067, 0, 0, '#joyful', '#interesting', 0.029, 'sunrise', 'begin_day', 'bright_sky', 'sunny', 'afternoon']
senticnet['part_of_dinner'] = [0.883, -0.98, 0, 0, '#joyful', '#surprising', 0.621, 'grape_juice', 'juice', 'ethanol', 'tea', 'meal']
senticnet['part_of_face'] = [0, 0.08, 0.016, 0.103, '#interesting', '#admirable', 0.056, 'facial_part', 'facial_organ', 'face_feature', 'head_organ', 'nose']
senticnet['part_of_family'] = [0, 0.08, 0.016, 0.103, '#interesting', '#admirable', 0.056, 'father', 'mother', 'daughter', 'son', 'grandfather']
senticnet['part_of_foot'] = [0, 0.08, 0.016, 0.103, '#interesting', '#admirable', 0.056, 'toe', 'ankle', 'hold_canvas', 'foot', 'heel']
senticnet['part_of_group'] = [0.242, 0.211, -0.068, 0.352, '#joyful', '#admirable', 0.246, 'team_up', 'together', 'social_group', 'bring_together', 'membership']
senticnet['part_of_hair'] = [-0.137, 0, -0.052, -0.065, '#sad', '#disgusting', -0.085, 'chair_committee', 'lose_key', 'age_gracefully', 'steal_store', 'wave_flag']
senticnet['part_of_history'] = [0.046, 0, 0, 0.085, '#joyful', '#admirable', 0.044, 'action_movie', 'history', 'medieval_time', 'human_history', 'history_book']
senticnet['part_of_house'] = [0, 0.953, 0, 0.833, '#interesting', '#admirable', 0.595, 'house_part', 'house_front', 'house_open', 'house_area', 'inside_house']
senticnet['part_of_human_body'] = [0, 0.073, 0, 0, '#interesting', '#interesting', 0.024, 'organ', 'organ_body', 'internal_organ', 'vital_organ', 'body_tissue']
senticnet['part_of_meal'] = [0.933, -0.744, 0, 0, '#joyful', '#surprising', 0.559, 'reproduction', 'survival', 'host_party', 'breed', 'put_ice']
senticnet['part_of_movie'] = [-0.105, 0, -0.114, 0, '#sad', '#scared', -0.073, 'part_of_play', 'act_part', 'play_part', 'act', 'role_play']
senticnet['part_of_plant'] = [0.046, 0, 0, 0.085, '#joyful', '#admirable', 0.044, 'leafy', 'plant_part', 'small_tree', 'leaf', 'tree_item']
senticnet['part_of_play'] = [0, -0.713, 0, 0.78, '#surprising', '#admirable', 0.498, 'part_of_movie', 'act_part', 'play_part', 'role_play', 'act']
senticnet['part_of_room'] = [0, 0.918, 0, 0.766, '#interesting', '#admirable', 0.561, 'location', 'front_rear', 'front_back', 'square', 'front']
senticnet['part_of_speech'] = [0.021, 0, 0, 0.174, '#joyful', '#admirable', 0.065, 'grammar_part', 'grammatical_term', 'sentence', 'word', 'written_language']
senticnet['part_of_team'] = [0, 0.843, 0, 0.766, '#interesting', '#admirable', 0.536, 'fit_person', 'engage_sport', 'challenge_oneself', 'something_to_do', 'leader']
senticnet['part_of_tree'] = [0, 0.751, 0, 0.837, '#interesting', '#admirable', 0.529, 'tree_piece', 'tree_part', 'tree_limb', 'tree_arm', 'tree_branch']
senticnet['part_of_way'] = [0.873, 0.942, 0, 0.907, '#interesting', '#admirable', 0.907, 'better_person', 'demand', 'give_help', 'end_argument', 'feel_strongly']
senticnet['part_of_whole'] = [0, 0.939, 0, 0.937, '#interesting', '#admirable', 0.625, 'component', 'fraction', 'portion', 'segment', 'piece']
senticnet['parthenogenetic'] = [-0.686, 0, 0.779, -0.863, '#angry', '#disgusting', -0.776, 'agamic', 'agamous', 'agamogenetic', 'asexual', 'apomictic']
senticnet['partial'] = [-0.716, 0, 0.871, -0.75, '#angry', '#disgusting', -0.779, 'differential', 'curvature', 'differential_derivative', 'calculation', 'computation']
senticnet['partial_breach'] = [-0.106, 0, -0.053, -0.24, '#sad', '#disgusting', -0.133, 'breach_of_warranty', 'breach_of_trust', 'breach_of_contract', 'anticipatory_breach', 'constructive_breach']
senticnet['partial_denture'] = [-0.657, 0, 0.65, -0.981, '#sad', '#disgusting', -0.763, 'false_teeth', 'bridge', 'bridgework', 'dental_plate', 'dental_appliance']
senticnet['partial_derivative'] = [-0.716, 0, 0.871, -0.75, '#angry', '#disgusting', -0.779, 'partial', 'curvature', 'differential', 'calculation', 'computation']
senticnet['partiality'] = [0, 0, 0, -0.948, '#disgusting', '#disgusting', -0.316, 'liking', 'like', 'likeable', 'convinced', 'well-disposed']
senticnet['participant'] = [0.072, 0, 0, 0.078, '#joyful', '#admirable', 0.05, 'participate', 'examine', 'voyeur', 'influence_public_decision', 'question_everything']
senticnet['participate'] = [0.967, 0, 0, 0.971, '#joyful', '#admirable', 0.646, 'solve', 'see_oneself', 'find_direction', 'fantasize', 'enjoy_art']
senticnet['participate_sport'] = [0.737, 0.909, 0, 0, '#joyful', '#interesting', 0.549, 'exercise', 'healthy_exercise', 'aerobic_exercise', 'prepare_fight', 'want_exercise']
senticnet['particle'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'small_piece', 'spangle', 'stripe', 'dust_particle', 'oxide']
senticnet['particle_accelerator'] = [0.562, -0.777, 0, 0.962, '#surprising', '#admirable', 0.767, 'console', 'instrument', 'accelerator', 'scientific_instrument', 'atom_smasher']
senticnet['particle_board'] = [0.514, -0.979, 0, 0.899, '#surprising', '#admirable', 0.797, 'board', 'beaver_board', 'fiberboard', 'furniture', 'dry_wall']
senticnet['particolored_buckeye'] = [-0.579, 0, 0.582, -0.65, '#angry', '#disgusting', -0.604, 'sweet_buckeye', 'dwarf_buckeye', 'bottlebrush_buckeye', 'red_buckeye', 'horse_chestnut']
senticnet['particular'] = [0.062, 0.293, -0.182, 0.316, '#interesting', '#admirable', 0.163, 'different', 'likely', 'outlier', 'strange', 'exclusion']
senticnet['particularism'] = [0.53, -0.649, 0, 0.76, '#surprising', '#admirable', 0.646, 'focus', 'get_focused', 'focusing', 'centering', 'focal_point']
senticnet['particulate'] = [-0.955, 0, 0.738, -0.584, '#sad', '#angry', -0.759, 'fallout', 'chalk_dust', 'radioactive_dust', 'dust', 'dust_matter']
senticnet['particulate_matter'] = [-0.955, 0, 0.738, -0.584, '#sad', '#angry', -0.759, 'fallout', 'chalk_dust', 'radioactive_dust', 'particulate', 'dust']
senticnet['partisan'] = [0.633, -0.922, 0, 0.869, '#surprising', '#admirable', 0.808, 'advocate', 'bigot', 'advocator', 'blind', 'fanatic']
senticnet['partition'] = [-0.056, 0.14, 0, 0.061, '#interesting', '#admirable', 0.048, 'store_file', 'store_document', 'keep_paper', 'hold_paper', 'store_paper']
senticnet['partizan'] = [0.954, -0.908, 0, 0.867, '#joyful', '#surprising', 0.91, 'friend', 'sports_fan', 'rooter', 'fan', 'nut']
senticnet['partner'] = [0.841, 0.721, 0, 0.74, '#joyful', '#admirable', 0.767, 'good_manner', 'two_people', 'love', 'guardian', 'guy']
senticnet['partnership'] = [0.089, 0.185, 0, 0.197, '#interesting', '#admirable', 0.157, 'large_business', 'business_firm', 'business_organization', 'business_group', 'partner']
senticnet['partridge'] = [0.567, -0.935, 0, 0.659, '#surprising', '#admirable', 0.72, 'bird', 'grouse', 'quail', 'wildfowl', 'pheasant']
senticnet['party'] = [0.717, 0.966, 0, 0, '#joyful', '#interesting', 0.561, 'use_party', 'hold_beer', 'greet_guest', 'gift_box', 'nave']
senticnet['party_animal'] = [0.884, 0, 0, 0, '#joyful', '#joyful', 0.295, 'egalitarian', 'partygoer', 'drink', 'have_fun', 'meet_people']
senticnet['party_pooper'] = [-0.958, 0, 0.673, -0.958, '#sad', '#disgusting', -0.863, 'worrier', 'fusspot', 'worrywart', 'unwelcome_person', 'killjoy']
senticnet['party_time'] = [0.796, 0.843, 0, 0, '#joyful', '#interesting', 0.546, 'annual_celebration', 'special_day', 'yearly_celebration', 'new_baby', 'celebrate']
senticnet['partygoer'] = [0.884, 0, 0, 0, '#joyful', '#joyful', 0.295, 'egalitarian', 'like_women', 'drink', 'have_fun', 'senator']
senticnet['parvenu'] = [-0.918, 0, 0.662, -0.824, '#sad', '#disgusting', -0.801, 'junior', 'unpleasant_person', 'disagreeable_person', 'climber', 'social_climber']
senticnet['pasang'] = [-0.51, 0, 0.845, -0.993, '#angry', '#disgusting', -0.783, 'bezoar_goat', 'wild_goat', 'markhor', 'goat', 'ibex']
senticnet['pasque_flower'] = [-0.793, 0, 0.837, -0.886, '#angry', '#disgusting', -0.839, 'sunray', 'wilding', 'sagebrush_buttercup', 'pasqueflower', 'wildflower']
senticnet['pasqueflower'] = [-0.793, 0, 0.837, -0.886, '#angry', '#disgusting', -0.839, 'sunray', 'wilding', 'sagebrush_buttercup', 'wildflower', 'pasque_flower']
senticnet['pass'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'further_goal', 'pass_ball', 'pass_glass', 'help', 'pass_exam']
senticnet['pass_along'] = [0.743, -0.517, 0, 0.551, '#joyful', '#admirable', 0.604, 'communicate', 'pass_on', 'pass', 'get_across', 'put_across']
senticnet['pass_around'] = [0.517, -0.672, 0, 0.549, '#surprising', '#admirable', 0.579, 'circularize', 'circulate', 'send_around', 'pass_on', 'distribute']
senticnet['pass_away'] = [0.041, -0.041, 0, -0.153, '#joyful', '#surprising', -0.024, 'visit_relative', 'maintain_relationship', 'experience_emotion', 'understand_culture', 'even_out']
senticnet['pass_ball'] = [0.024, 0.073, 0, 0.192, '#interesting', '#admirable', 0.096, 'throw_football', 'practice', 'jump_around', 'dance_move', 'pretzel']
senticnet['pass_by'] = [-0.037, 0, 0.033, -0.065, '#sad', '#disgusting', -0.045, 'carry_luggage', 'walk_through_door', 'meet_friends', 'pay_dinner', 'increase_value']
senticnet['pass_card'] = [-0.073, 0.085, -0.053, 0.137, '#interesting', '#admirable', 0.032, 'shuffle_card', 'broker', 'go_casino', 'business_agreement', 'deal']
senticnet['pass_exam'] = [0.796, 0.843, 0, 0, '#joyful', '#interesting', 0.546, 'get_degree', 'learn_knowledge', 'finish_college', 'become_educated', 'pass_test']
senticnet['pass_examination'] = [0.764, 0, 0, 0.927, '#joyful', '#admirable', 0.564, 'get_qualification', 'prove_knowledge', 'prove_learn', 'complete_course', 'test_knowledge']
senticnet['pass_fail'] = [-0.147, 0, -0.101, 0, '#sad', '#scared', -0.083, 'exam', 'test_knowledge', 'want_pass_class', 'get_grade', 'complete_course']
senticnet['pass_gas'] = [-0.124, 0, 0, -0.09, '#sad', '#disgusting', -0.071, 'study_library', 'complete_sentence', 'guess_answer', 'master_new_skill', 'point_out']
senticnet['pass_gene'] = [0, 0.078, 0.014, 0.059, '#interesting', '#admirable', 0.041, 'child', 'overpopulation', 'smile_child', 'young_child', 'large_family']
senticnet['pass_grade'] = [0.108, 0, 0, 0.056, '#joyful', '#admirable', 0.055, 'graduate_school', 'make_parent_happy', 'show_know', 'good_grade', 'knowledge_power']
senticnet['pass_information'] = [0.108, 0, 0, 0.056, '#joyful', '#admirable', 0.055, 'tell_information', 'information', 'report_event', 'receive_information', 'report_news']
senticnet['pass_judgment'] = [-0.152, 0.088, -0.101, 0, '#sad', '#scared', -0.055, 'hire_lawyer', 'call_lawyer', 'contact_lawyer', 'question_witness', 'become_lawyer']
senticnet['pass_knowledge'] = [0.108, 0, 0, 0.056, '#joyful', '#admirable', 0.055, 'gain_information', 'get_information', 'pass_information', 'find_out_information', 'increase_vocabulary']
senticnet['pass_law'] = [0.108, 0, 0, 0.056, '#joyful', '#admirable', 0.055, 'law', 'edict', 'rule', 'supreme_court', 'legislation']
senticnet['pass_off'] = [-0.882, 0, 0.682, -0.603, '#sad', '#angry', -0.722, 'absent', 'fall_away', 'evanesce', 'blow_over', 'disappear']
senticnet['pass_on'] = [0.743, -0.517, 0, 0.551, '#joyful', '#admirable', 0.604, 'communicate', 'get_across', 'pass', 'pass_along', 'put_across']
senticnet['pass_out'] = [-0.827, 0, -0.72, 0, '#sad', '#scared', -0.516, 'bump_head', 'loss_ofawareness', 'collapse', 'fall_down', 'bang_head']
senticnet['pass_over'] = [-0.926, 0, 0.743, -0.563, '#sad', '#angry', -0.744, 'miss', 'neglect', 'overlook', 'drop', 'pretermit']
senticnet['pass_test'] = [0.035, 0.112, -0.076, 0.195, '#interesting', '#admirable', 0.089, 'get_degree', 'study', 'take_test', 'pass_exam', 'finish_college']
senticnet['pass_through'] = [0.839, 0.926, 0, 0, '#joyful', '#interesting', 0.588, 'walk', 'find_garden', 'enter_place', 'walk_down', 'walk_around']
senticnet['passable'] = [-0.996, 0, 0.641, -0.765, '#sad', '#disgusting', -0.801, 'navigable', 'negotiable', 'surmountable', 'climbable', 'traversable']
senticnet['passage'] = [0, 0.089, 0, 0.129, '#interesting', '#admirable', 0.073, 'passageway', 'connect_room', 'entrance_room', 'corridor', 'walk_through']
senticnet['passageway'] = [0.029, 0.087, 0.065, 0.137, '#interesting', '#admirable', 0.063, 'archway', 'arch', 'mat', 'aisle', 'walkway']
senticnet['passe'] = [-0.121, -0.06, -0.089, -0.036, '#sad', '#scared', -0.062, 'old_fashioned', 'unglamorous', 'special_person', 'bloke', 'male']
senticnet['passenger'] = [0.069, 0.07, 0, 0.116, '#interesting', '#admirable', 0.085, 'traveller', 'tourist', 'travel', 'explorer', 'adventurer']
senticnet['passenger_car'] = [0.035, 0.112, -0.076, 0.195, '#interesting', '#admirable', 0.089, 'car_action', 'car_travel', 'steer_car', 'make_go', 'transportation']
senticnet['passenger_terminal'] = [0.841, 0.799, 0, 0, '#joyful', '#interesting', 0.547, 'ticket_counter', 'ticket_booth', 'ticket_window', 'ticket_turnstile', 'aircraft_roadway']
senticnet['passenger_ticket'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'transit_ticket', 'ticket_counter', 'train_ticket', 'hand_luggage', 'baggage']
senticnet['passing'] = [-0.92, 0, 0.835, -0.682, '#sad', '#angry', -0.812, 'aerial', 'lateral', 'forward_pass', 'lateral_pass', 'spot_pass']
senticnet['passion'] = [0.505, -0.856, 0, 0.94, '#surprising', '#admirable', 0.767, 'infatuation', 'ardor', 'fervor', 'fervency', 'fervidness']
senticnet['passionate'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'emotional_response', 'emotional_reaction', 'sentimental', 'sensitive', 'emotional']
senticnet['passionateness'] = [0.571, -0.954, 0, 0.903, '#surprising', '#admirable', 0.809, 'infatuation', 'ardor', 'fervor', 'fervency', 'fervidness']
senticnet['passionless'] = [0, 0, 0.709, -0.923, '#angry', '#disgusting', -0.544, 'apathetic', 'unemotionality', 'indifference', 'stolidity', 'phlegm']
senticnet['passive'] = [-0.815, 0, 0.796, 0, '#sad', '#angry', -0.537, 'win_money', 'team_lose', 'winner_loser', 'fun', 'competitive']
senticnet['passive_resister'] = [0.842, -0.66, 0, 0.663, '#joyful', '#admirable', 0.722, 'reformer', 'crusader', 'reformist', 'social_reformer', 'meliorist']
senticnet['passiveness'] = [-0.705, 0, 0.569, -0.887, '#sad', '#disgusting', -0.72, 'languor', 'inertia', 'phlegm', 'passivity', 'indolence']
senticnet['passivism'] = [-0.582, 0, 0.804, -0.562, '#sad', '#angry', -0.649, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['passivity'] = [-0.778, 0, 0.5, -0.751, '#sad', '#disgusting', -0.676, 'apathy', 'indifference', 'spiritlessness', 'inertia', 'inactiveness']
senticnet['passkey'] = [0.943, -0.787, 0, 0.571, '#joyful', '#surprising', 0.767, 'master', 'ignition_key', 'latchkey', 'key', 'master_key']
senticnet['passport'] = [0.082, 0.184, -0.075, 0.208, '#interesting', '#admirable', 0.133, 'identify_person', 'profile_picture', 'capitalize', 'personal_identification', 'identification_picture']
senticnet['passport_case'] = [0.022, -0.01, 0.074, -0.116, '#angry', '#disgusting', -0.053, 'checkbook_holder', 'lip_balm', 'checkbook_cover', 'card_case', 'address_book']
senticnet['passport_picture'] = [0.082, 0.184, -0.075, 0.208, '#interesting', '#admirable', 0.133, 'identify_person', 'profile_picture', 'capitalize', 'passport', 'personal_identification']
senticnet['password'] = [0.038, 0.117, 0, 0.095, '#interesting', '#admirable', 0.083, 'browser', 'computer', 'efficient', 'telephone_computer', 'modem']
senticnet['past'] = [0, 0.078, 0, 0.096, '#interesting', '#admirable', 0.058, 'ancient_rome', 'ancient', 'age', 'ancient_artifact', 'century']
senticnet['past_event'] = [-0.03, 0.106, -0.056, 0.08, '#interesting', '#admirable', 0.033, 'long_ago', 'history', 'school_topic', 'school_subject', 'subject']
senticnet['past_present'] = [-0.036, 0.108, -0.082, 0.104, '#interesting', '#admirable', 0.031, 'time', 'general_time', 'time_runner', 'calendar_event', 'unending']
senticnet['past_time'] = [0.044, 0, -0.135, -0.068, '#scared', '#disgusting', -0.053, 'good_news', 'history', 'important_event', 'past_event', 'long_ago']
senticnet['pasta'] = [0.939, 0.983, 0, 0, '#joyful', '#interesting', 0.641, 'breakfast', 'box_cereal', 'calcium', 'drink', 'carton_milk']
senticnet['paste'] = [0, -0.127, 0, 0, '#surprising', '#surprising', 0.042, 'chop', 'glue', 'carve', 'bandage', 'split']
senticnet['pasted'] = [0.993, -0.893, 0, 0.891, '#joyful', '#surprising', 0.926, 'mounted', 'appendant', 'basifixed', 'glued', 'affixed']
senticnet['pastime'] = [0.891, 0.835, 0, 0.721, '#joyful', '#interesting', 0.816, 'hobby', 'diversion', 'challenge', 'enjoy_game', 'leisure']
senticnet['pastinaca_sativa'] = [0.861, -0.879, 0, 0.597, '#joyful', '#surprising', 0.779, 'herb', 'cultivated_parsnip', 'wild_parsnip', 'madnep', 'herbaceous_plant']
senticnet['pastis'] = [0.693, -0.945, 0, 0.713, '#surprising', '#admirable', 0.784, 'anisette', 'maraschino', 'ratafia', 'cordial', 'ratafee']
senticnet['pastor'] = [0, 0, 0, 0.736, '#admirable', '#admirable', 0.245, 'church_head', 'religion', 'prayer', 'gospel', 'monk']
senticnet['pastry'] = [0.059, -0.028, 0.025, 0.109, '#joyful', '#admirable', 0.057, 'bakery_item', 'bake_treat', 'bake_goods', 'bake_good', 'loaf']
senticnet['pasture'] = [-0.907, 0, 0.765, -0.98, '#sad', '#disgusting', -0.884, 'common_landland', 'grazing_land', 'ley', 'common_land', 'lea']
senticnet['pastureland'] = [-0.907, 0, 0.765, -0.98, '#sad', '#disgusting', -0.884, 'common_land', 'grazing_land', 'ley', 'pasture', 'lea']
senticnet['pat'] = [0.047, 0.133, -0.111, 0.22, '#interesting', '#admirable', 0.096, 'feel_action', 'sensual', 'hand_action', 'make_contact', 'extend_arm']
senticnet['patch'] = [-0.583, 0, 0.561, -0.622, '#sad', '#disgusting', -0.589, 'spot', 'speckle', 'dapple', 'worn_spot', 'fleck']
senticnet['patchiness'] = [-0.535, 0, 0.765, -0.942, '#angry', '#disgusting', -0.747, 'jaggedness', 'unregularity', 'ruggedness', 'irregularity', 'unevenness']
senticnet['patchwork'] = [0.548, -0.611, 0, 0.556, '#surprising', '#admirable', 0.572, 'stitchery', 'darn', 'mend', 'stitch', 'applique']
senticnet['patency'] = [-0.516, 0, 0.607, -0.769, '#angry', '#disgusting', -0.631, 'offensiveness', 'odiousness', 'distastefulness', 'blatancy', 'obviousness']
senticnet['patent'] = [0, 0.729, 0, 0.794, '#interesting', '#admirable', 0.508, 'hard_work', 'animal_person', 'accomplish', 'keep_job', 'reinforce']
senticnet['patent_medicine'] = [-0.682, 0, 0.916, -0.705, '#angry', '#disgusting', -0.768, 'nostrum', 'medicine', 'medication', 'medicament', 'medicinal_drug']
senticnet['path'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'car_path', 'roadside', 'trail', 'intersection', 'under_bridge']
senticnet['pathetic'] = [-0.729, 0.314, -0.494, -0.033, '#sad', '#scared', -0.314, 'hangdog', 'shamed', 'dolefulness', 'suffering', 'misfortunate']
senticnet['pathetic_fallacy'] = [-0.777, 0, 0.885, -0.738, '#sad', '#angry', -0.8, 'fallacy', 'misconception', 'paralogism', 'logical_fallacy', 'pseudoscience']
senticnet['pathless'] = [0.88, -0.808, 0, 0.696, '#joyful', '#surprising', 0.795, 'outback', 'trackless', 'inaccessible', 'roadless', 'untracked']
senticnet['pathological_state'] = [-0.831, 0, 0.995, -0.954, '#angry', '#disgusting', -0.927, 'ill_health', 'unhealthiness', 'health_problem', 'physical_condition', 'physiological_state']
senticnet['pathology'] = [-0.596, 0, 0.911, -0.877, '#angry', '#disgusting', -0.795, 'osteosclerosis', 'sclerosis', 'disseminated_sclerosis', 'multiple_sclerosis', 'induration']
senticnet['pathos'] = [0, 0, 0, 0.951, '#admirable', '#admirable', 0.317, 'sympathize', 'commiserate', 'commiseration', 'feel_sorry', 'ruth']
senticnet['pathway'] = [-0.735, 0, 0.897, -0.774, '#angry', '#disgusting', -0.802, 'commissure', 'optic_radiation', 'radiatio_optica', 'peduncle', 'cerebral_peduncle']
senticnet['patience'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'fishing_rod', 'fishing', 'catch_fish', 'fish_lake', 'bait']
senticnet['patient'] = [-0.048, 0.075, -0.12, -0.153, '#scared', '#disgusting', -0.082, 'examination_table', 'wait_room', 'nurse', 'sick_person', 'cure']
senticnet['patient_person'] = [-0.068, 0, -0.097, -0.045, '#sad', '#scared', -0.07, 'pay_grocery', 'get_turn', 'decide_want', 'take_turn', 'conformist_attitude']
senticnet['patina'] = [0, 0.19, -0.066, 0.093, '#interesting', '#admirable', 0.072, 'shine', 'alias', 'shiny', 'earl', 'girl_name']
senticnet['patriot'] = [0.829, 0.795, 0, 0, '#joyful', '#interesting', 0.541, 'life', 'human_life', 'experience', 'sometimes_bad', 'human_experience']
senticnet['patriotic'] = [0.585, -0.7, 0, 0.586, '#surprising', '#admirable', 0.624, 'jingoistic', 'ultranationalistic', 'superpatriotic', 'nationalistic', 'chauvinistic']
senticnet['patriotism'] = [0, 0.19, -0.066, 0.093, '#interesting', '#admirable', 0.072, 'pride', 'revolution', 'patriot', 'motherland', 'homeland']
senticnet['patron'] = [0.996, 0.76, 0, 0, '#joyful', '#interesting', 0.585, 'shopper', 'clerk', 'customer', 'vintner', 'hairdresser']
senticnet['patronize'] = [0, -0.751, 0, 0.847, '#surprising', '#admirable', 0.533, 'condescend', 'sponsor', 'buy_at', 'support', 'patronise']
senticnet['patter'] = [-0.837, 0, 0.87, -0.978, '#angry', '#disgusting', -0.895, 'precipitate', 'mizzle', 'shower_down', 'spit', 'rain_down']
senticnet['pattern'] = [0.087, 0.069, 0.013, 0.052, '#joyful', '#interesting', 0.065, 'style', 'design', 'curly', 'art_form', 'fashion']
senticnet['paucity'] = [-0.881, 0, 0.732, -0.61, '#sad', '#angry', -0.741, 'scarceness', 'insufficiency', 'rareness', 'infrequency', 'dearth']
senticnet['pauper'] = [0, 0.835, 0, 0.804, '#interesting', '#admirable', 0.546, 'workman', 'homeowner', 'polite_person', 'man', 'compatriot']
senticnet['pauperism'] = [-0.575, 0, 0.903, -0.807, '#angry', '#disgusting', -0.762, 'poverty', 'impoverishment', 'poorness', 'beggary', 'mendicancy']
senticnet['pauperization'] = [-0.636, 0, 0.562, -0.621, '#sad', '#disgusting', -0.606, 'poverty', 'impoverishment', 'poorness', 'beggary', 'mendicancy']
senticnet['pause'] = [0, 0.118, -0.096, 0.111, '#interesting', '#admirable', 0.044, 'stop', 'time_out', 'halt', 'hesitation', 'rest_time']
senticnet['pave'] = [0, 0, 0.078, 0, '#angry', '#angry', -0.026, 'street_city', 'small_street', 'walkway', 'black_pavement', 'dark_road']
senticnet['pavement'] = [0, -0.011, 0.046, -0.052, '#angry', '#disgusting', -0.029, 'cement', 'tar', 'concrete', 'big_city_life', 'popular_building_material']
senticnet['paw'] = [-0.038, 0.121, 0, 0.096, '#interesting', '#admirable', 0.06, 'claws', 'animal_part', 'long_tail', 'sharp_tooth', 'fang']
senticnet['pawn'] = [0, 0, 0, 0.115, '#admirable', '#admirable', 0.038, 'chess_knight', 'chess_pawn', 'chess_piece', 'chess_queen', 'chess_rook']
senticnet['pawn_shop'] = [-0.053, 0, 0.031, -0.028, '#sad', '#angry', -0.037, 'clothes_drawer', 'clothes_store', 'department_store', 'sex_shop', 'record_store']
senticnet['pay'] = [0.865, 0.794, 0, 0, '#joyful', '#interesting', 0.553, 'give_cash', 'salary', 'wage', 'remittance', 'money']
senticnet['pay_a_lot_of_money'] = [-0.952, 0, -0.999, 0, '#sad', '#scared', -0.65, 'go_debt', 'negotiate', 'borrow_money', 'transact_business', 'sell_stock']
senticnet['pay_admission'] = [-0.881, 0, -0.824, 0, '#sad', '#scared', -0.568, 'find_museum', 'go_airport', 'dress_nicely', 'find_out', 'obey_rule']
senticnet['pay_attention'] = [-0.038, 0.121, 0, 0.096, '#interesting', '#admirable', 0.06, 'listen_carefully', 'focus', 'use_dictionary', 'move_eye', 'ask_question']
senticnet['pay_back'] = [-0.1, 0.272, -0.147, 0.15, '#interesting', '#admirable', 0.058, 'give_change', 'settle_bill', 'collect_money', 'owe_money', 'make_change']
senticnet['pay_barber'] = [-0.103, 0, 0, -0.062, '#sad', '#disgusting', -0.055, 'short_hair', 'talk_hairdresser', 'hair_become_short', 'hair_wash', 'keep_hair_short']
senticnet['pay_bill'] = [0.339, 0.302, 0, 0.387, '#joyful', '#admirable', 0.343, 'good_citizen', 'use_cash', 'use_credit_card', 'purchase_gift', 'pay_off_debt']
senticnet['pay_cash'] = [-0.047, -0.029, 0.04, -0.035, '#sad', '#angry', -0.031, 'pay_credit_card', 'purchase_gift', 'spend_money', 'buy_product', 'holiday_shop']
senticnet['pay_cashier'] = [0.339, 0.302, 0, 0.387, '#joyful', '#admirable', 0.343, 'pay', 'pay_bill', 'make_offer', 'buy_product', 'use_cash']
senticnet['pay_check'] = [-0.053, -0.051, 0.063, -0.065, '#angry', '#disgusting', -0.043, 'pay_bill', 'purchase_cellular_phone', 'pay_credit_card', 'pay_cash', 'spend_money']
senticnet['pay_child_support'] = [-0.109, 0, -0.092, -0.078, '#sad', '#scared', -0.093, 'obligation', 'fine', 'pay_dear', 'expensive', 'stress']
senticnet['pay_close_attention'] = [0.912, -0.85, 0, 0, '#joyful', '#surprising', 0.587, 'use_thermometer', 'change_plan', 'form_opinion', 'new_insight', 'thirst_knowledge']
senticnet['pay_credit_card'] = [0, -0.976, 0, 0.709, '#surprising', '#admirable', 0.562, 'pay_cash', 'holiday_shop', 'spend_money', 'christmas_shop', 'buy_product']
senticnet['pay_dear'] = [-0.109, 0, -0.092, -0.078, '#sad', '#scared', -0.093, 'obligation', 'fine', 'pay_child_support', 'expensive', 'stress']
senticnet['pay_debt'] = [0, 0.893, 0, 0.868, '#interesting', '#admirable', 0.587, 'pay_goods', 'purchase', 'establish_credit', 'purchase_item', 'buy_goods_service']
senticnet['pay_dinner'] = [0.896, 0, 0, 0, '#joyful', '#joyful', 0.299, 'walk_exercise', 'buy_candy', 'subscribe_magazine', 'gain_interest', 'buy_soda']
senticnet['pay_employee'] = [-0.059, 0.182, -0.084, 0.114, '#interesting', '#admirable', 0.051, 'pay_service', 'collect_debt', 'buy_gas', 'get_money', 'make_profit']
senticnet['pay_fee'] = [0, 0, 0, 0.703, '#admirable', '#admirable', 0.234, 'choose_destination', 'book_hotel_room', 'talk_to_travel_agent', 'make_reservation', 'decide_to_go_first']
senticnet['pay_fine'] = [-0.21, 0, 0, -0.13, '#sad', '#disgusting', -0.113, 'buy_goods_service', 'cashless', 'incur_debt', 'pay_goods', 'buy']
senticnet['pay_food'] = [-0.049, 0, 0.011, -0.029, '#sad', '#disgusting', -0.03, 'look_price', 'decide_buy', 'compare_price', 'take_out_wallet', 'check_wallet']
senticnet['pay_for_meal'] = [0.976, 0, 0, 0.708, '#joyful', '#admirable', 0.561, 'treat', 'birthday_surprise', 'birthday_treat', 'dessert', 'chocolate_dessert']
senticnet['pay_goods'] = [-0.993, 0, -0.734, 0, '#sad', '#scared', -0.576, 'incur_debt', 'pay_item', 'buy_goods_service', 'cashless', 'postpone_payment']
senticnet['pay_grocery'] = [-0.042, 0, 0, -0.073, '#sad', '#disgusting', -0.038, 'get_turn', 'decide_want', 'pay_meal', 'take_number', 'order_french_fries']
senticnet['pay_item'] = [-0.981, 0, -0.788, 0, '#sad', '#scared', -0.59, 'pay_goods', 'incur_debt', 'go_cashless', 'buy_goods_service', 'cashless']
senticnet['pay_meal'] = [0.339, 0.302, 0, 0.387, '#joyful', '#admirable', 0.343, 'order_dinner', 'pay_grocery', 'pay_bill', 'order_french_fries', 'pay_cashier']
senticnet['pay_money'] = [-0.996, 0, -0.856, 0, '#sad', '#scared', -0.617, 'money_spend', 'bankruptcy', 'receive_change', 'cash_check', 'compare_price']
senticnet['pay_monthly'] = [0.046, 0.201, -0.053, 0.115, '#interesting', '#admirable', 0.103, 'money_term', 'serve_hot', 'after_dinner', 'must_pay', 'monetary_amount']
senticnet['pay_off'] = [-0.098, 0.164, -0.099, 0.127, '#interesting', '#admirable', 0.031, 'payoff', 'deserve', 'find_money', 'spend_little_money', 'high_salary']
senticnet['pay_off_debt'] = [0.339, 0.302, 0, 0.387, '#joyful', '#admirable', 0.343, 'good_citizen', 'complement', 'positive_reinforcement', 'feel_important', 'good_sense_of_humor']
senticnet['pay_phone'] = [0.054, 0, 0.035, 0.066, '#joyful', '#admirable', 0.028, 'phone', 'telephone', 'cellphone', 'telephone_room', 'mobile_phone']
senticnet['pay_purchase'] = [-0.726, 0, -0.778, 0, '#sad', '#scared', -0.501, 'pay_goods', 'incur_debt', 'buy_goods_service', 'pay_cash', 'pay_item']
senticnet['pay_rend'] = [0, 0.117, -0.077, 0.094, '#interesting', '#admirable', 0.045, 'provide_shelter', 'wait_person', 'live_city', 'throw_party', 'live']
senticnet['pay_service'] = [-0.076, 0.137, -0.069, 0.095, '#interesting', '#admirable', 0.029, 'exchange_money', 'settle_bill', 'sell', 'transact_business', 'bankruptcy']
senticnet['pay_tab'] = [0, 0.709, 0, 0, '#interesting', '#interesting', 0.236, 'serve_beer', 'drink_beer', 'invite_friend', 'buy_drink', 'order_beer']
senticnet['pay_ticket'] = [0.339, 0.302, 0, 0.387, '#joyful', '#admirable', 0.343, 'buy_ticket', 'go_to_theater', 'buy_popcorn', 'buy_happiness', 'go_to_cinema']
senticnet['pay_toll'] = [0, -0.009, 0, 0.065, '#surprising', '#admirable', 0.025, 'drive_quickly', 'drive', 'drive_upon', 'get_fast', 'drive_somewhere']
senticnet['pay_tuition'] = [0, 0.872, 0, 0, '#interesting', '#interesting', 0.291, 'enroll_school', 'go_college', 'matriculate', 'show_up_time', 'enroll']
senticnet['pay_tv'] = [-0.917, 0, -0.934, 0, '#sad', '#scared', -0.617, 'ceiling_fan', 'tv_set', 'pornography', 'red_light_district', 'sexual_activity']
senticnet['pay_well'] = [0.955, 0.945, 0, 0.835, '#joyful', '#interesting', 0.912, 'perform_service', 'provide_service', 'accomplish', 'find_job', 'responsible']
senticnet['pay_work'] = [0.279, 0.184, 0, 0.269, '#joyful', '#admirable', 0.244, 'financial_security', 'desirable', 'prosper', 'enough_eat', 'a_lot_of_sex']
senticnet['payable'] = [0.628, -0.607, 0, 0.532, '#joyful', '#surprising', 0.589, 'account_indebtedness', 'indebtedness', 'limited_liability', 'debt', 'arrears']
senticnet['payback'] = [-0.629, 0, 0.7, -0.838, '#angry', '#disgusting', -0.722, 'take', 'issue', 'return', 'taking', 'proceeds']
senticnet['paycheck'] = [0.832, 0, 0, 0, '#joyful', '#joyful', 0.277, 'earn_money', 'receive_earn_paycheck', 'earn', 'earn_paycheck', 'finish_work']
senticnet['paying'] = [0.521, -0.859, 0, 0.727, '#surprising', '#admirable', 0.702, 'compensated', 'remunerated', 'paid', 'stipendiary', 'remunerative']
senticnet['payment'] = [-0.044, 0.277, -0.108, 0.11, '#interesting', '#admirable', 0.078, 'owe', 'tax', 'debit', 'afford', 'wage']
senticnet['payment_amount'] = [0, 0.289, 0, 0.169, '#interesting', '#admirable', 0.153, 'amount_due', 'money_payment', 'money_term', 'item_value', 'monetary']
senticnet['payment_counter'] = [0, 0.207, 0, 0.071, '#interesting', '#admirable', 0.093, 'check', 'bill', 'afford', 'owe', 'severance']
senticnet['paynim'] = [-0.888, 0, 0.929, -0.843, '#sad', '#angry', -0.887, 'gentile', 'nonreligious_person', 'idolizer', 'idolater', 'idol_worshiper']
senticnet['payoff'] = [-0.045, 0.208, -0.117, 0.204, '#interesting', '#admirable', 0.083, 'pay_off', 'spend_little_money', 'quit', 'increase_money', 'money_earn']
senticnet['pda'] = [0.113, 0.073, 0.028, 0.107, '#joyful', '#admirable', 0.088, 'portable_computer', 'telephone_computer', 'browser', 'number_pad', 'modem']
senticnet['pea'] = [0, -0.006, 0.053, -0.037, '#angry', '#disgusting', -0.028, 'kale', 'cucumber', 'cabbage', 'lettuce', 'broccoli']
senticnet['pea_crab'] = [-0.698, 0, 0.766, -0.826, '#angry', '#disgusting', -0.763, 'stone_crab', 'swimming_crab', 'rock_crab', 'fiddler_crab', 'crab']
senticnet['peace'] = [0.497, 0.453, -0.235, 0.189, '#joyful', '#interesting', 0.301, 'calm', 'calmness', 'stillness', 'truce', 'no_war']
senticnet['peace-loving'] = [0.621, 0.648, -0.252, 0.296, '#joyful', '#interesting', 0.438, 'pacifically', 'repose', 'peaceably', 'peaceable', 'peace_of_mind']
senticnet['peace_agreement'] = [0.068, 0.139, -0.093, 0.191, '#interesting', '#admirable', 0.102, 'peace', 'peace_maker', 'peacekeeping', 'peace_mission', 'united_nations']
senticnet['peace_maker'] = [0.068, 0.139, -0.093, 0.191, '#interesting', '#admirable', 0.102, 'peace', 'peace_agreement', 'peacekeeping', 'peace_mission', 'united_nations']
senticnet['peace_mind'] = [0.738, 0, 0, 0, '#joyful', '#joyful', 0.246, 'feel_good', 'good_feeling', 'self_satisfaction', 'serenity', 'feel_good_oneself']
senticnet['peace_mission'] = [0.068, 0.139, -0.093, 0.191, '#interesting', '#admirable', 0.102, 'peace', 'peace_maker', 'peacekeeping', 'peace_agreement', 'united_nations']
senticnet['peace_of_mind'] = [0.621, 0.648, -0.252, 0.296, '#joyful', '#interesting', 0.438, 'pacifically', 'repose', 'peace-loving', 'peaceably', 'peaceable']
senticnet['peace_officer'] = [0.74, -0.539, 0, 0.641, '#joyful', '#admirable', 0.64, 'air_marshal', 'sky_marshal', 'lawman', 'law_officer', 'marshal']
senticnet['peace_quiet'] = [0.911, 0, 0, 0, '#joyful', '#joyful', 0.304, 'lose_item', 'lucid', 'reflection', 'cup_coffee', 'find_quiet_place']
senticnet['peace_sign'] = [0.091, 0.08, 0.03, 0.132, '#joyful', '#admirable', 0.091, 'letter', 'sign', 'announcement', 'placard', 'indication']
senticnet['peaceable'] = [0.621, 0.648, -0.252, 0.296, '#joyful', '#interesting', 0.438, 'pacifically', 'repose', 'peace-loving', 'peaceably', 'peace_of_mind']
senticnet['peaceably'] = [0.621, 0.648, -0.252, 0.296, '#joyful', '#interesting', 0.438, 'pacifically', 'repose', 'peace-loving', 'peaceable', 'peace_of_mind']
senticnet['peaceful'] = [0.383, 0.246, -0.108, 0.256, '#joyful', '#admirable', 0.259, 'beautiful', 'lovely', 'strange', 'nice', 'pleasant']
senticnet['peaceful_place'] = [0, 0.077, 0, 0.086, '#interesting', '#admirable', 0.054, 'restful', 'comfy', 'live_inside', 'place_sleep', 'reside']
senticnet['peaceful_relax'] = [0.103, 0, 0.026, 0.145, '#joyful', '#admirable', 0.074, 'make_wood', 'beautiful', 'big', 'sail_sea', 'huge']
senticnet['peacefulness'] = [0.733, 0, 0, 0.801, '#joyful', '#admirable', 0.511, 'serenity', 'recreate', 'peace_of_mind', 'ease', 'serene']
senticnet['peacekeeping'] = [0.068, 0.139, -0.093, 0.191, '#interesting', '#admirable', 0.102, 'peace', 'peace_maker', 'peace_agreement', 'peace_mission', 'united_nations']
senticnet['peacemaker'] = [0.763, 0, 0, 0.719, '#joyful', '#admirable', 0.494, 'mist', 'haze', 'fog', 'misty', 'drizzle']
senticnet['peach'] = [0.02, -0.056, 0, 0, '#joyful', '#surprising', 0.025, 'many_fruits', 'buy_fruit', 'cherry', 'pineapple', 'tomato']
senticnet['peak'] = [0.057, 0.075, 0.039, 0.059, '#interesting', '#admirable', 0.051, 'summit', 'cliff', 'high_land', 'big_rock', 'mountain_side']
senticnet['peal'] = [-0.891, 0, -0.98, 0, '#sad', '#scared', -0.624, 'thwart', 'remain', 'chime', 'propose', 'hesitation']
senticnet['peanut'] = [-0.943, 0, 0.891, -0.939, '#sad', '#disgusting', -0.924, 'cause_allergy', 'seafood', 'wrong_food', 'sick', 'allergy_symptom']
senticnet['peanut_butter'] = [0.056, 0, 0, 0.05, '#joyful', '#admirable', 0.035, 'leftover', 'dusty', 'mayonnaise', 'leave_over', 'savory']
senticnet['pear'] = [0, -0.015, 0.037, -0.046, '#angry', '#disgusting', -0.023, 'lime', 'green_apple', 'apricot', 'cherry', 'pumpkin']
senticnet['pearlweed'] = [-0.725, 0, 0.64, -0.585, '#sad', '#angry', -0.65, 'pearlwort', 'groundcover', 'flora', 'rupturewort', 'whitlowwort']
senticnet['pearlwort'] = [-0.725, 0, 0.64, -0.585, '#sad', '#angry', -0.65, 'groundcover', 'pearlweed', 'flora', 'rupturewort', 'whitlowwort']
senticnet['peasant'] = [0, 0.233, -0.079, 0.113, '#interesting', '#admirable', 0.089, 'structure', 'construction_worker', 'builder', 'functionary', 'maker']
senticnet['peat'] = [0.599, -0.879, 0, 0.673, '#surprising', '#admirable', 0.717, 'humic_shale', 'material', 'stuff', 'humate', 'lignite']
senticnet['peavey'] = [-0.993, 0, 0.66, -0.508, '#sad', '#angry', -0.72, 'bar', 'treadle', 'pry', 'key', 'lever']
senticnet['peck'] = [0, 0.067, 0, 0.07, '#interesting', '#admirable', 0.046, 'bushel', 'embryo', 'chicken_egg', 'ovum', 'egg']
senticnet['peckish'] = [-0.713, 0, 0.692, -0.818, '#sad', '#disgusting', -0.741, 'famished', 'starved', 'ravenous', 'esurient', 'hungry']
senticnet['peculation'] = [-0.909, 0, 0.904, -0.988, '#sad', '#disgusting', -0.934, 'raid', 'thieving', 'plunderage', 'larceny', 'theft']
senticnet['peculiar'] = [0.136, 0.293, -0.119, 0.371, '#interesting', '#admirable', 0.227, 'characteristic', 'character_trait', 'good_quality', 'description', 'good_character']
senticnet['peculiarity'] = [0.808, -0.981, 0, 0.628, '#joyful', '#surprising', 0.806, 'curio', 'oddity', 'curiosity', 'collector_item', 'oddment']
senticnet['pecuniary_resource'] = [0.534, -0.868, 0, 0.736, '#surprising', '#admirable', 0.713, 'funds', 'finances', 'monetary_resource', 'cash_in_hand', 'escrow_funds']
senticnet['pedagogy'] = [0.695, -0.654, 0, 0.926, '#joyful', '#admirable', 0.758, 'education', 'didactics', 'educational_activity', 'continuing_education', 'instruction']
senticnet['pedal'] = [0.118, -0.06, 0.075, 0.086, '#joyful', '#admirable', 0.063, 'soft_hard', 'dance_type', 'attract', 'adjust', 'malleable']
senticnet['pedantic'] = [0.71, -0.811, 0, 0.937, '#surprising', '#admirable', 0.819, 'erudite', 'donnish', 'scholarly', 'learned', 'bookish']
senticnet['pedantry'] = [-0.818, 0, 0.936, -0.579, '#sad', '#angry', -0.778, 'ostentation', 'bluster', 'splurge', 'ritz', 'display']
senticnet['peddle'] = [-0.083, -0.053, 0.037, -0.068, '#sad', '#disgusting', -0.045, 'trip_fall', 'fall_off', 'fall_down', 'lose_balance', 'breahard']
senticnet['peddler'] = [-0.774, 0, 0.874, -0.803, '#angry', '#disgusting', -0.817, 'cheapjack', 'pedlar', 'packman', 'hawker', 'pitchman']
senticnet['pedestrian_crossing'] = [0.508, -0.726, 0, 0.727, '#surprising', '#admirable', 0.654, 'crosswalk', 'pelican_crossing', 'school_crossing', 'crossing', 'crossover']
senticnet['pediculosis'] = [-0.906, 0, 0.96, -0.836, '#sad', '#angry', -0.901, 'pediculosis_capitis', 'head_lice', 'pediculosis_corporis', 'pediculosis_pubis', 'crabs']
senticnet['pediculosis_capitis'] = [-0.841, 0, 0.767, -0.996, '#sad', '#disgusting', -0.868, 'lousiness', 'head_lice', 'pediculosis_corporis', 'pediculosis_pubis', 'crabs']
senticnet['pediculosis_corporis'] = [-0.841, 0, 0.767, -0.996, '#sad', '#disgusting', -0.868, 'pediculosis_capitis', 'head_lice', 'lousiness', 'pediculosis_pubis', 'crabs']
senticnet['pediculosis_pubis'] = [-0.841, 0, 0.767, -0.996, '#sad', '#disgusting', -0.868, 'pediculosis_capitis', 'head_lice', 'pediculosis_corporis', 'lousiness', 'crabs']
senticnet['pedicure'] = [0.944, -0.603, 0, 0.756, '#joyful', '#admirable', 0.768, 'makeover', 'beautification', 'manicure', 'beauty_treatment', 'facial']
senticnet['pedlar'] = [-0.774, 0, 0.874, -0.803, '#angry', '#disgusting', -0.817, 'peddler', 'cheapjack', 'packman', 'hawker', 'pitchman']
senticnet['pedophile'] = [0, 0.942, 0, 0, '#interesting', '#interesting', 0.314, 'guy', 'special_person', 'guardian', 'boys', 'male']
senticnet['peduncle'] = [-0.735, 0, 0.897, -0.774, '#angry', '#disgusting', -0.802, 'commissure', 'optic_radiation', 'radiatio_optica', 'pathway', 'cerebral_pathway']
senticnet['pee'] = [-0.044, 0, 0, -0.099, '#sad', '#disgusting', -0.048, 'urinate', 'go_toilet', 'go_potty', 'go_pee', 'bladder_full']
senticnet['pee_pants'] = [0, 0, 0.897, -0.719, '#angry', '#disgusting', -0.539, 'start_laugh', 'wet_pant', 'cry', 'make_others_laugh', 'have_fun']
senticnet['peek'] = [0, 0.096, 0, 0.075, '#interesting', '#admirable', 0.057, 'stern', 'quick_look', 'glimpse', 'peep', 'stare']
senticnet['peel_orange'] = [0.059, 0, 0, 0.062, '#joyful', '#admirable', 0.04, 'round_fruit', 'green_fruit', 'small_fruit', 'redness', 'red_fruit']
senticnet['peel_potato'] = [0, -0.133, 0, 0, '#surprising', '#surprising', 0.044, 'stir_pot', 'burn_food', 'remove_skin', 'prepare_ingredient', 'chop_vegetable']
senticnet['peelable'] = [-0.026, 0.068, 0.04, 0.084, '#interesting', '#admirable', 0.029, 'bright_red', 'green_black', 'purple', 'red', 'edible_human']
senticnet['peep'] = [0, 0.07, 0, 0.063, '#interesting', '#admirable', 0.044, 'microscope', 'glimpse', 'see', 'stare', 'observation']
senticnet['peeper'] = [0.753, -0.647, 0, 0.556, '#joyful', '#surprising', 0.652, 'oculus_dexter', 'stemma', 'naked_eye', 'eye', 'oculus_sinister']
senticnet['peer'] = [0.849, 0.856, 0, 0, '#joyful', '#interesting', 0.568, 'observer', 'peek', 'appearance', 'seer', 'glimpse']
senticnet['peer_pressure'] = [-0.152, 0.128, -0.326, 0, '#sad', '#scared', -0.117, 'strong_emotion', 'ridicule', 'need_help', 'correct_behavior', 'uncertainty']
senticnet['peerage'] = [0.976, -0.5, 0, 0.853, '#joyful', '#admirable', 0.776, 'knighthood', 'elite', 'elite_group', 'noblesse', 'aristocracy']
senticnet['peerless'] = [0.816, -0.599, 0, 0.947, '#joyful', '#admirable', 0.787, 'matchless', 'nonpareil', 'one_and_only', 'incomparable', 'unmatchable']
senticnet['peeved'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['peevishness'] = [-0.992, 0, 0.528, -0.959, '#sad', '#disgusting', -0.826, 'ill_humor', 'distemper', 'pet', 'testiness', 'touchiness']
senticnet['peg'] = [0.076, 0, 0, 0.104, '#joyful', '#admirable', 0.06, 'post', 'newspaper_article', 'rail', 'paper_sign', 'column']
senticnet['peg_down'] = [0.519, -0.554, 0, 0.746, '#surprising', '#admirable', 0.606, 'narrow_down', 'concretize', 'nail_down', 'narrow', 'pin_down']
senticnet['pelican_crossing'] = [0.508, -0.726, 0, 0.727, '#surprising', '#admirable', 0.654, 'crosswalk', 'pedestrian_crossing', 'school_crossing', 'crossing', 'crossover']
senticnet['pellucid'] = [0, 0, -0.937, -0.991, '#scared', '#disgusting', -0.643, 'luculent', 'crystal_clear', 'limpid', 'transparent', 'crystalline']
senticnet['pellucidity'] = [0.557, -0.513, 0, 0.59, '#joyful', '#admirable', 0.553, 'clearcutness', 'explicitness', 'preciseness', 'perspicuity', 'perspicuousness']
senticnet['pelt'] = [-0.582, 0, 0.517, -0.593, '#sad', '#disgusting', -0.564, 'fox', 'mink', 'seal', 'astrakhan', 'bearskin']
senticnet['pelvic_inflammatory_disease'] = [-0.756, 0, 0.84, -0.633, '#sad', '#angry', -0.743, 'angina', 'gastroenteritis', 'stomach_flu', 'intestinal_flu', 'inflammatory_disease']
senticnet['pemphigus'] = [-0.976, 0, 0.995, -0.804, '#sad', '#angry', -0.925, 'skin_disease', 'disease_of_skin', 'skin_disorder', 'autoimmune_disease', 'autoimmune_disorder']
senticnet['pen'] = [0, 0.096, 0, 0.075, '#interesting', '#admirable', 0.057, 'write', 'marker', 'sign_document', 'pencil', 'pencil_sharpener']
senticnet['pen_and_paper'] = [0.067, 0.153, -0.054, 0.111, '#interesting', '#admirable', 0.092, 'many_pages', 'record_event', 'book_newspaper', 'world_event', 'current_event']
senticnet['pen_ink'] = [0, 0.067, 0, 0.077, '#interesting', '#admirable', 0.048, 'pencil_mark', 'use_ink', 'script', 'pencil_paper', 'written_text']
senticnet['penalty'] = [-0.978, 0, -0.959, 0, '#sad', '#scared', -0.646, 'wrongdoing', 'fee', 'bad_behavior', 'illegal_activity', 'wrong']
senticnet['penalty_shoot'] = [-0.983, 0, 0.334, -0.914, '#sad', '#disgusting', -0.744, 'punishment', 'fault', 'probabilty_of_losing', 'yellow_card', 'red_card']
senticnet['penance'] = [-0.909, 0.142, -0.637, 0.07, '#sad', '#scared', -0.445, 'penitently', 'penitentially', 'penitent', 'repentantly', 'penitence']
senticnet['penchant'] = [0.558, 0.661, -0.271, 0.302, '#joyful', '#interesting', 0.417, 'predilection', 'well-disposed', 'friendliness', 'likeable', 'liking']
senticnet['pencil'] = [0.031, 0.08, 0.023, 0.069, '#interesting', '#admirable', 0.052, 'marker', 'graphite_pencil', 'pen', 'mechanical_graphite_pencil', 'stamp_pad']
senticnet['pencil_art'] = [0, 0.11, 0, 0.14, '#interesting', '#admirable', 0.083, 'create_image', 'like_paint', 'sketch', 'use_crayon', 'artwork']
senticnet['pencil_box'] = [0.038, 0, 0.01, 0.059, '#joyful', '#admirable', 0.029, 'paper_clip', 'eraser_holder', 'computer_desk', 'electric_pencil_sharpener', 'folder']
senticnet['pencil_mark'] = [0, 0, 0, 0.122, '#admirable', '#admirable', 0.041, 'handmade', 'make_book', 'make_newspaper', 'script', 'written_text']
senticnet['pencil_paper'] = [0.023, 0, 0, 0.066, '#joyful', '#admirable', 0.03, 'ink_paper', 'ink_cartridge', 'use_ink', 'pencil_mark', 'type_of_document']
senticnet['pencil_pen'] = [0.055, -0.017, 0, 0.106, '#joyful', '#admirable', 0.059, 'attendee', 'agenda', 'learn_write', 'find_paper', 'paper_plane']
senticnet['pencil_sharpener'] = [0.031, 0.08, 0.023, 0.069, '#interesting', '#admirable', 0.052, 'pencil', 'pencil_art', 'markert', 'paper_clip', 'electric_pencil_sharpener']
senticnet['pendant'] = [0.088, -0.066, -0.081, 0.126, '#joyful', '#admirable', 0.066, 'ornament', 'ring', 'statue', 'card', 'yellow_ribbon']
senticnet['pendulum'] = [0.036, -0.04, 0, 0, '#joyful', '#surprising', 0.025, 'minute', 'minute_second', 'hour', 'stopwatch', 'second']
senticnet['penetrate'] = [0.968, -0.767, 0, 0.583, '#joyful', '#surprising', 0.773, 'riddle', 'diffuse', 'permeate', 'pervade', 'spiritize']
senticnet['penetration'] = [0.89, -0.621, 0, 0.548, '#joyful', '#surprising', 0.686, 'breakthrough', 'interpenetration', 'foray', 'maraud', 'raid']
senticnet['penicillin'] = [-0.024, -0.026, -0.104, -0.14, '#scared', '#disgusting', -0.081, 'palliative', 'antibiotic', 'ibuprofen', 'analgesic', 'phenobarbital']
senticnet['penitence'] = [-0.909, 0.142, -0.637, 0.07, '#sad', '#scared', -0.445, 'penitently', 'penitentially', 'penitent', 'repentantly', 'repentant']
senticnet['penitent'] = [0, 0, 0.842, -0.732, '#angry', '#disgusting', -0.525, 'repentant', 'contrite', 'regretful', 'remorseful', 'sorry']
senticnet['penitentially'] = [-0.909, 0.142, -0.637, 0.07, '#sad', '#scared', -0.445, 'penitently', 'penitent', 'repentantly', 'penitence', 'repentant']
senticnet['penitentiary'] = [-0.753, 0, 0.981, -0.588, '#sad', '#angry', -0.774, 'retaliatory', 'punitive', 'correctional', 'retributive', 'retributory']
senticnet['penitently'] = [-0.909, 0.142, -0.637, 0.07, '#sad', '#scared', -0.445, 'penitentially', 'penitent', 'repentantly', 'penitence', 'repentant']
senticnet['penknife'] = [0.818, -0.956, 0, 0.695, '#joyful', '#surprising', 0.823, 'jackknife', 'clasp_knife', 'pocket_knife', 'switchblade', 'switchblade_knife']
senticnet['penniless'] = [-0.978, 0, 0.3, -0.931, '#sad', '#disgusting', -0.736, 'poor', 'need_money', 'homeless', 'hungry', 'bankruptcy']
senticnet['penny'] = [0.02, 0.079, 0, 0.069, '#interesting', '#admirable', 0.056, 'paper_bill', 'metal_coin', 'cash_bill', 'cash_coin', 'token']
senticnet['penny_dime'] = [0, 0.094, 0.085, 0.091, '#interesting', '#admirable', 0.033, 'small_currency', 'metal_money', 'small_coin', 'money_coin', 'small_money']
senticnet['pension_off'] = [0.661, -0.821, 0, 0.952, '#surprising', '#admirable', 0.811, 'displace', 'fire', 'give_notice', 'can', 'dismiss']
senticnet['pensionary'] = [-0.653, 0, 0.808, -0.699, '#angry', '#disgusting', -0.72, 'beneficiary', 'pensioner', 'devisee', 'legatee', 'recipient']
senticnet['pensioner'] = [-0.653, 0, 0.808, -0.699, '#angry', '#disgusting', -0.72, 'pensionary', 'beneficiary', 'devisee', 'legatee', 'recipient']
senticnet['pensive'] = [-0.946, 0, -0.742, 0, '#sad', '#scared', -0.563, 'pondering', 'ruminative', 'broody', 'pensiveness', 'meditative']
senticnet['pensively'] = [-0.848, 0, -0.845, 0, '#sad', '#scared', -0.564, 'think', 'ruminative', 'broody', 'contemplative', 'meditative']
senticnet['pensiveness'] = [-0.3, 0, 0, 0, '#sad', '#sad', -0.1, 'worry', 'ruminative', 'worried', 'think_too_much', 'sadness']
senticnet['pentagon'] = [0.067, 0.155, 0, 0.121, '#interesting', '#admirable', 0.114, 'vicinity', 'parallelogram', 'hexagon', 'trapezoid', 'small_room']
senticnet['pentose'] = [-0.528, 0, 0.681, -0.768, '#angry', '#disgusting', -0.659, 'triose', 'tetrose', 'simple_sugar', 'hexose', 'aldose']
senticnet['penurious'] = [-0.919, 0, 0.598, -0.522, '#sad', '#angry', -0.68, 'parsimonious', 'stingy', 'scrimy', 'beggarly', 'chintzy']
senticnet['penury'] = [-0.985, 0, 0.802, -0.88, '#sad', '#disgusting', -0.889, 'poverty', 'impoverishment', 'poorness', 'beggary', 'mendicancy']
senticnet['peon'] = [-0.248, -0.038, -0.054, -0.132, '#sad', '#disgusting', -0.132, 'laborer', 'worker', 'work_much', 'drudgery', 'occupation']
senticnet['people'] = [0.092, 0.114, 0, 0.108, '#interesting', '#admirable', 0.105, 'team_up', 'group_of_people', 'crowd', 'mass_person', 'individual']
senticnet['pep_rally'] = [0.669, -0.583, 0, 0.803, '#joyful', '#admirable', 0.685, 'rally', 'revival', 'revival_meeting', 'gathering', 'assemblage']
senticnet['pep_up'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerfully', 'cheerful', 'jolly_up', 'hearten', 'chirk_up']
senticnet['peplum'] = [0.522, -0.824, 0, 0.568, '#surprising', '#admirable', 0.638, 'adornment', 'goffer', 'gauffer', 'jabot', 'ruffle']
senticnet['pepper_spray'] = [-0.829, 0, 0.642, -0.72, '#sad', '#disgusting', -0.73, 'substance', 'capsaicin', 'gingerol', 'piperine', 'chemical_irritant']
senticnet['peppy'] = [0.65, -0.614, 0, 0.711, '#joyful', '#admirable', 0.658, 'bouncing', 'scintillating', 'spirited', 'lively', 'zippy']
senticnet['perambulate'] = [-0.14, 0.216, -0.069, 0.162, '#interesting', '#admirable', 0.056, 'give_signal', 'change_position', 'walk_around', 'rub_eye', 'pull_out']
senticnet['perceivable'] = [0.744, -0.766, 0, 0.669, '#joyful', '#surprising', 0.726, 'accessible', 'fathomable', 'approachable', 'comprehendible', 'intelligible']
senticnet['perceive'] = [-0.058, 0.169, -0.121, 0.174, '#interesting', '#admirable', 0.055, 'feel', 'sense', 'perception', 'empathize', 'look']
senticnet['perceiver'] = [-0.832, 0, 0.665, -0.512, '#sad', '#angry', -0.67, 'percipient', 'eavesdropper', 'auditor', 'observer', 'beholder']
senticnet['percentage'] = [-0.042, 0.315, -0.059, 0.161, '#interesting', '#admirable', 0.125, 'payment_amount', 'money_relate', 'money_payment', 'monetary', 'money_charge']
senticnet['perceptibility'] = [0.685, -0.912, 0, 0.566, '#joyful', '#surprising', 0.721, 'audibility', 'audibleness', 'visibleness', 'visibility', 'physical_property']
senticnet['perceptible'] = [0.985, -0.815, 0, 0.673, '#joyful', '#surprising', 0.824, 'discernible', 'noticeable', 'detectable', 'palpable', 'perceivable']
senticnet['perception'] = [-0.044, 0.143, -0.064, 0.128, '#interesting', '#admirable', 0.054, 'perceive', 'see', 'look', 'feeling', 'ship_part']
senticnet['perchance'] = [-0.04, 0.268, -0.069, 0.227, '#interesting', '#admirable', 0.129, 'proposition', 'abstract', 'get_rid', 'item_sell', 'business_transaction']
senticnet['percher'] = [-0.927, 0, 0.64, -0.529, '#sad', '#angry', -0.699, 'perching_bird', 'animal_order', 'thyreophoran', 'marginocephalian', 'euronithopod']
senticnet['perching_bird'] = [-0.927, 0, 0.64, -0.529, '#sad', '#angry', -0.699, 'animal_order', 'percher', 'thyreophoran', 'marginocephalian', 'euronithopod']
senticnet['percipient'] = [-0.832, 0, 0.665, -0.512, '#sad', '#angry', -0.67, 'auditor', 'eavesdropper', 'perceiver', 'observer', 'beholder']
senticnet['percussion'] = [0, -0.027, 0.055, -0.057, '#angry', '#disgusting', -0.028, 'djembe', 'make_musicr', 'use_jazz_music', 'tune_instrument', 'drummer']
senticnet['perdition'] = [-0.709, 0, 0.566, -0.95, '#sad', '#disgusting', -0.742, 'hellfire', 'red_region', 'imaginary_place', 'mythical_place', 'fictitious_place']
senticnet['perdurable'] = [-0.957, 0, 0.799, -0.673, '#sad', '#angry', -0.81, 'imputrescible', 'undestroyable', 'indestructible', 'durable', 'imperishable']
senticnet['peremptory'] = [-0.91, 0, 0.521, -0.811, '#sad', '#disgusting', -0.747, 'bullying', 'domineering', 'blustery', 'roughshod', 'cavalier']
senticnet['perennial'] = [0, 0.07, 0, 0.071, '#interesting', '#admirable', 0.047, 'tree_flower', 'bloom', 'blossom', 'poppy', 'greenery']
senticnet['perfect'] = [0, 0.794, 0, 0.941, '#interesting', '#admirable', 0.578, 'best', 'excellent', 'goodness', 'greatness', 'great']
senticnet['perfect_pitch'] = [0.785, -0.995, 0, 0.981, '#surprising', '#admirable', 0.92, 'ear', 'absolute_pitch', 'audition', 'modality', 'sense_modality']
senticnet['perfect_skill'] = [0.979, 0.887, 0, 0.825, '#joyful', '#interesting', 0.897, 'play_tune', 'play_stringed_instrument', 'make_music', 'annoy_mom', 'produce_musical_sound']
senticnet['perfect_sphere'] = [0, 0.794, 0, 0.941, '#interesting', '#admirable', 0.578, 'round_shape', 'circle', 'perfect', 'perfection', 'sphere']
senticnet['perfect_surface'] = [0.022, 0.069, 0.027, 0.059, '#interesting', '#admirable', 0.041, 'flat_object', 'flat_land', 'flat_surface', 'crockery', 'plate']
senticnet['perfect_world'] = [0, 0.091, 0, 0.101, '#interesting', '#admirable', 0.064, 'mythical', 'tale', 'dictionary', 'magic', 'fairy_tale']
senticnet['perfectibility'] = [0.946, -0.641, 0, 0.602, '#joyful', '#surprising', 0.73, 'grasp', 'capableness', 'imcapableness', 'reach', 'aptitude']
senticnet['perfection'] = [0, 0.706, 0, 0.934, '#interesting', '#admirable', 0.547, 'value', 'good_value', 'like_price', 'item_value', 'sort_mail']
senticnet['perfidious'] = [-0.669, 0, 0.709, -0.881, '#angry', '#disgusting', -0.753, 'untrue', 'apostate', 'treacherous', 'unfaithful', 'punic']
senticnet['perfidiousness'] = [0.927, -0.564, 0, 0.8, '#joyful', '#admirable', 0.764, 'disloyalty', 'subversiveness', 'traitorousness', 'perfidy', 'treachery']
senticnet['perfidy'] = [0.927, -0.564, 0, 0.8, '#joyful', '#admirable', 0.764, 'perfidiousness', 'subversiveness', 'traitorousness', 'disloyalty', 'treachery']
senticnet['perform'] = [0.861, 0.928, 0, 0, '#joyful', '#interesting', 0.596, 'act_play', 'go_stage', 'pretend', 'play_violin', 'play_guitar']
senticnet['perform_action'] = [0.97, -0.783, 0, 0, '#joyful', '#surprising', 0.584, 'run_errand', 'pay_credit_card', 'pay_bill', 'go_market', 'go_store']
senticnet['perform_art'] = [0.12, -0.061, 0, 0, '#joyful', '#surprising', 0.06, 'ballroom', 'ballet', 'nightclub', 'ballerina', 'venue']
senticnet['perform_magic'] = [0, 0, 0.958, 0, '#angry', '#angry', -0.319, 'complain_state_world', 'find_love', 'own_pet', 'jump_off_bridge', 'live_apartment']
senticnet['perform_of_music'] = [0, 0.706, 0, 0.934, '#interesting', '#admirable', 0.547, 'play_tune', 'play_orchestra', 'create_music', 'play_music', 'music']
senticnet['perform_on_stage'] = [0, 0.706, 0, 0.934, '#interesting', '#admirable', 0.547, 'compose_music', 'sing_song', 'play_piano', 'use_microphone', 'entertain_other_person']
senticnet['perform_play'] = [0, -0.912, 0, 0.705, '#surprising', '#admirable', 0.539, 'show_play', 'present_play', 'stage_play', 'drama', 'performance']
senticnet['perform_service'] = [-0.026, 0.147, 0, 0.068, '#interesting', '#admirable', 0.063, 'go_work_to_earn_money', 'responsible', 'provide_service', 'dance_joy', 'need_earn_money']
senticnet['perform_surgery'] = [0, 0, 0, 0.857, '#admirable', '#admirable', 0.286, 'surgery', 'compose_music', 'beep', 'sound_alarm', 'lift_leg']
senticnet['perform_task'] = [-0.04, 0.068, 0, 0.078, '#interesting', '#admirable', 0.035, 'job_offer', 'make_life_easy', 'settle', 'ask_person', 'job']
senticnet['perform_well'] = [0.808, 0.939, 0, 0.933, '#interesting', '#admirable', 0.893, 'go_rock_concert', 'sit_stand', 'touch_other', 'make_difference', 'enjoy_challenge']
senticnet['performance'] = [0.558, -0.602, 0, 0.779, '#surprising', '#admirable', 0.646, 'benefit', 'pianism', 'song_and_dance', 'routine', 'histrionics']
senticnet['performant'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'lightweight', 'aluminium', 'light', 'thin', 'carbon_fiber']
senticnet['performer'] = [0.756, 0, 0, 0.792, '#joyful', '#admirable', 0.516, 'movie_star', 'actress', 'entertainer', 'actor', 'preview']
senticnet['performing_art'] = [0.584, -0.783, 0, 0.546, '#joyful', '#surprising', 0.638, 'acting', 'musical_performance', 'dancing', 'dance', 'terpsichore']
senticnet['perfume'] = [0.066, 0.083, -0.064, 0.09, '#interesting', '#admirable', 0.058, 'aroma', 'female_perfume', 'fragrance', 'bad_odor', 'saliva']
senticnet['perfumed'] = [0, -0.929, 0, 0.962, '#surprising', '#admirable', 0.63, 'aromatize', 'odoriferous', 'sweet', 'scent', 'odorous']
senticnet['peri'] = [0.992, -0.917, 0, 0.851, '#joyful', '#surprising', 0.92, 'girl', 'miss', 'missy', 'young_lady', 'young_woman']
senticnet['pericarditis'] = [-0.548, 0, 0.67, -0.926, '#angry', '#disgusting', -0.715, 'carditis', 'rubor', 'redness', 'endocarditis', 'inflammation']
senticnet['peril'] = [0.565, -0.766, 0, 0.982, '#surprising', '#admirable', 0.771, 'risk', 'hazard', 'jeopardy', 'endangerment', 'health_hazard']
senticnet['period'] = [0.906, -0.627, 0, 0.941, '#joyful', '#admirable', 0.825, 'honeymoon', 'heyday', 'time', 'efflorescence', 'millennium']
senticnet['period_of_time'] = [0.978, -0.601, 0, 0.895, '#joyful', '#admirable', 0.825, 'period', 'quattrocento', 'twentieth_century', 'time_period', 'century']
senticnet['periodic'] = [0.09, 0.07, 0, 0.246, '#joyful', '#admirable', 0.135, 'hand_motion', 'water_form', 'water_relate', 'hand_gesture', 'arm_movement']
senticnet['periodic_acid'] = [-0.814, 0, 0.774, -0.776, '#sad', '#disgusting', -0.788, 'acid', 'hypophosphoric_acid', 'oxyacid', 'hypophosphorous_acid', 'phosphorous_acid']
senticnet['periodic_edema'] = [-0.998, 0, 0.605, -0.764, '#sad', '#disgusting', -0.789, 'angioedema', 'atrophedema', 'giant_hives', 'dropsy', 'lymphedema']
senticnet['perishability'] = [0.774, -0.827, 0, 0.63, '#joyful', '#surprising', 0.744, 'quality', 'unsatisfactoriness', 'perishableness', 'inadequateness', 'inadequacy']
senticnet['perishableness'] = [0.774, -0.827, 0, 0.63, '#joyful', '#surprising', 0.744, 'quality', 'perishability', 'unsatisfactoriness', 'inadequateness', 'inadequacy']
senticnet['periwig'] = [-0.848, 0, 0.633, -0.539, '#sad', '#angry', -0.673, 'grizzle', 'postiche', 'horsehair_wig', 'wig', 'peruke']
senticnet['perjurer'] = [-0.633, 0, 0.88, -0.941, '#angry', '#disgusting', -0.818, 'beguiler', 'slicker', 'prevaricator', 'false_witness', 'storyteller']
senticnet['perk'] = [0.844, -0.777, 0, 0.546, '#joyful', '#surprising', 0.722, 'benefit', 'appanage', 'provision', 'gratuity', 'tip']
senticnet['perk_up'] = [0.815, -0.757, 0, 0.744, '#joyful', '#surprising', 0.772, 'perk', 'convalesce', 'improve', 'look_better', 'meliorate']
senticnet['perkiness'] = [0.676, 0.63, -0.235, 0.31, '#joyful', '#interesting', 0.46, 'buoyancy', 'walk_on_air', 'exultingly', 'exultantly', 'jubilance']
senticnet['permanent'] = [-0.819, 0, 0.921, -0.803, '#sad', '#angry', -0.848, 'immovability', 'unchanging', 'lodgment', 'fixity', 'lodging']
senticnet['permeate'] = [0.968, -0.767, 0, 0.583, '#joyful', '#surprising', 0.773, 'riddle', 'diffuse', 'spiritize', 'pervade', 'penetrate']
senticnet['permeation'] = [0.789, -0.925, 0, 0.964, '#surprising', '#admirable', 0.893, 'ammonification', 'carbonation', 'impregnation', 'saturation', 'diffusion']
senticnet['permission'] = [-0.03, 0.308, -0.232, 0.406, '#interesting', '#admirable', 0.151, 'let', 'take', 'suggest', 'request', 'compel']
senticnet['permissiveness'] = [0.787, -0.885, 0, 0.858, '#surprising', '#admirable', 0.843, 'lenience', 'leniency', 'toleration', 'disposition', 'temperament']
senticnet['permit'] = [0, 0.243, -0.173, 0.292, '#interesting', '#admirable', 0.121, 'citation', 'concession', 'deliver', 'allow', 'permission']
senticnet['permutability'] = [0.912, -0.757, 0, 0.512, '#joyful', '#surprising', 0.727, 'transferability', 'convertibility', 'changeableness', 'changeability', 'exchangeability']
senticnet['permutable'] = [0.552, -0.585, 0, 0.762, '#surprising', '#admirable', 0.633, 'transposable', 'exchangeable', 'fungible', 'commutable', 'substitutable']
senticnet['permutation'] = [0.898, -0.874, 0, 0.929, '#joyful', '#admirable', 0.9, 'make', 'transposition', 'reversal', 'passing', 'reordering']
senticnet['pernicious'] = [-0.864, 0, 0.891, -0.821, '#sad', '#angry', -0.859, 'baneful', 'noxious', 'vesicatory', 'vesicant', 'pestilent']
senticnet['perniciousness'] = [-0.721, 0, 0.71, -0.9, '#sad', '#disgusting', -0.777, 'unwholesomeness', 'harmfulness', 'toxicity', 'noisomeness', 'noxiousness']
senticnet['pernickety'] = [0.682, -0.525, 0, 0.613, '#joyful', '#admirable', 0.607, 'nice', 'meticulous', 'dainty', 'prissy', 'fastidious']
senticnet['perorate'] = [0.584, -0.938, 0, 0.927, '#surprising', '#admirable', 0.816, 'elocute', 'scan', 'execute', 'declaim', 'perform']
senticnet['perpendicular'] = [-0.973, 0, 0.865, -0.543, '#sad', '#angry', -0.794, 'piping', 'lace', 'lacing', 'cord', 'slack']
senticnet['perpendicular_style'] = [0.578, -0.957, 0, 0.979, '#surprising', '#admirable', 0.838, 'perpendicular', 'gothic_architecture', 'architectural_style', 'style_of_architecture', 'type_of_architecture']
senticnet['perpetrator'] = [-0.064, 0, -0.153, 0, '#sad', '#scared', -0.072, 'heroism', 'role_play', 'repeat', 'act', 'part_of_movie']
senticnet['perpetual'] = [-0.605, 0, 0.509, -0.674, '#sad', '#disgusting', -0.596, 'dogging', 'persisting', 'sustained', 'consecutive', 'continuous']
senticnet['perplex'] = [0, -0.85, 0, 0, '#surprising', '#surprising', 0.283, 'awestricken', 'awestruck', 'awed', 'astonish', 'astonished']
senticnet['perplexed'] = [-0.833, 0, 0.925, -0.994, '#angry', '#disgusting', -0.917, 'at_loss', 'nonplused', 'confused', 'puzzled', 'bewildered']
senticnet['perplexity'] = [-0.605, 0, 0.631, -0.681, '#angry', '#disgusting', -0.639, 'quandary', 'snarl', 'dilemma', 'confusion', 'secret']
senticnet['perquisite'] = [0.83, -0.867, 0, 0.862, '#surprising', '#admirable', 0.853, 'benefit', 'appanage', 'provision', 'gratuity', 'tip']
senticnet['perseverant'] = [0.667, -0.97, 0, 0.608, '#joyful', '#surprising', 0.748, 'unruliness', 'fractiousness', 'willfulness', 'perverseness', 'cussedness']
senticnet['persevere'] = [0.997, 0.98, 0, 0, '#joyful', '#interesting', 0.659, 'obstinate', 'ask_for_it', 'uphold', 'plug', 'bear']
senticnet['persist'] = [-0.979, 0, 0.988, -0.504, '#sad', '#angry', -0.824, 'persevere', 'hang_in', 'ask_for_it', 'hang_on', 'hold_on']
senticnet['persistence'] = [-0.067, 0.203, -0.104, 0.147, '#interesting', '#admirable', 0.06, 'dedication', 'effort', 'eat_properly', 'physical_effort', 'study_language']
senticnet['persistent'] = [0, 0, -0.901, 0, '#scared', '#scared', -0.3, 'obstinate', 'stubborn', 'pigheaded', 'mulish', 'headstrong']
senticnet['persisting'] = [-0.605, 0, 0.509, -0.674, '#sad', '#disgusting', -0.596, 'dogging', 'continuous', 'sustained', 'consecutive', 'perpetual']
senticnet['persnickety'] = [0, 0, -0.764, -0.877, '#scared', '#disgusting', -0.547, 'snooty', 'uppish', 'too_big_for_ones_breeches', 'bigheaded', 'stuck-up']
senticnet['person'] = [0.756, 0.735, 0, 0, '#joyful', '#interesting', 0.497, 'mortal', 'soul', 'individual', 'someone', 'somebody']
senticnet['persona'] = [-0.829, 0, 0.958, -0.557, '#sad', '#angry', -0.781, 'character', 'role', 'theatrical_role', 'part', 'baddie']
senticnet['personage'] = [0.979, -0.692, 0, 0.576, '#joyful', '#surprising', 0.749, 'knocker', 'supremo', 'important_person', 'influential_person', 'big_cheese']
senticnet['personal'] = [0, 0.946, 0, 0.965, '#interesting', '#admirable', 0.637, 'owner', 'belong', 'own', 'no_place', 'asset']
senticnet['personal_belong'] = [0, 0.211, -0.172, 0.218, '#interesting', '#admirable', 0.086, 'ownership', 'own', 'possession', 'house_land', 'have_something']
senticnet['personal_career'] = [0.961, 0.937, 0, 0, '#joyful', '#interesting', 0.633, 'personal_gain', 'earn_money', 'become_rich', 'finish_work', 'go_work_to_earn_money']
senticnet['personal_cleanliness'] = [0.024, -0.003, 0.009, 0.071, '#joyful', '#admirable', 0.03, 'clean', 'cleanness', 'cleanliness', 'wash_away_dirt', 'run_out_soap']
senticnet['personal_computer'] = [0, 0, 0.128, 0, '#angry', '#angry', -0.043, 'grid', 'efficient', 'typewriter', 'computer', 'calculator']
senticnet['personal_enjoyment'] = [0, 0.8, 0, 0.791, '#interesting', '#admirable', 0.53, 'develop_skill', 'entertainment', 'kill_time', 'pastime', 'entertain_oneself']
senticnet['personal_equation'] = [-0.9, 0, 0.747, -0.63, '#sad', '#angry', -0.759, 'variedness', 'variability', 'variegation', 'changeableness', 'changeability']
senticnet['personal_fulfillment'] = [0.961, 0.937, 0, 0, '#joyful', '#interesting', 0.633, 'create_new_life', 'make_beautiful', 'stimulation', 'lower_stress', 'leisure_time']
senticnet['personal_gain'] = [0.961, 0.937, 0, 0, '#joyful', '#interesting', 0.633, 'personal_career', 'earn_money', 'become_rich', 'finish_work', 'go_work_to_earn_money']
senticnet['personal_groom'] = [0, 0.897, 0, 0.779, '#interesting', '#admirable', 0.559, 'new_hair_style', 'style_hair', 'fix_hair', 'change_hair_style', 'groom']
senticnet['personal_growth'] = [0.836, 0.836, 0, 0.72, '#joyful', '#interesting', 0.797, 'make_world_better_place', 'help_others', 'fame', 'improve_world', 'personal_improvement']
senticnet['personal_hygiene'] = [0.076, -0.008, 0, 0, '#joyful', '#surprising', 0.028, 'clean_body', 'clean_oneself', 'remove_dirt_body', 'shower', 'feel_refreshed']
senticnet['personal_identification'] = [0.082, 0.184, -0.075, 0.208, '#interesting', '#admirable', 0.133, 'identify_person', 'profile_picture', 'capitalize', 'passport', 'passport_picture']
senticnet['personal_improvement'] = [0.957, 0, 0, 0, '#joyful', '#joyful', 0.319, 'earn_degree', 'graduate_school', 'get_better_job', 'good_job', 'better_job']
senticnet['personal_item'] = [0.057, 0.141, -0.064, 0.162, '#interesting', '#admirable', 0.099, 'belongings', 'singer', 'madonna', 'guarantee', 'stuff']
senticnet['personal_manner'] = [0.646, -0.698, 0, 0.609, '#joyful', '#surprising', 0.651, 'good_manners', 'mildness', 'courtesy', 'comportment', 'mien']
senticnet['personal_preference'] = [0.054, 0.221, -0.12, 0.236, '#interesting', '#admirable', 0.13, 'abstract', 'exclamation', 'versatile', 'nice', 'subjective']
senticnet['personal_relation'] = [0.988, -0.609, 0, 0.7, '#joyful', '#admirable', 0.766, 'indebtedness', 'bonding', 'obligation', 'relationship', 'human_relationship']
senticnet['personal_relationship'] = [0.526, -0.869, 0, 0.954, '#surprising', '#admirable', 0.783, 'indebtedness', 'bonding', 'obligation', 'relationship', 'human_relationship']
senticnet['personal_satisfaction'] = [0.801, 0.779, 0, 0, '#joyful', '#interesting', 0.527, 'demonstrate_skill', 'learn_new_skill', 'educate', 'further_career', 'improve_skill']
senticnet['personal_trainer'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'coach', 'instructor', 'trainer', 'fit_person', 'train']
senticnet['personal_transport'] = [0, 0, 0, 0.154, '#admirable', '#admirable', 0.051, 'get_somewhere_fast', 'locomotion', 'get_place', 'go_some_place', 'go_fast']
senticnet['personality'] = [0, 0.964, 0, 0.932, '#interesting', '#admirable', 0.632, 'character', 'strong_personality', 'computer_type', 'riddle', 'mystery']
senticnet['personality_disorder'] = [0, 0, 0.896, -0.962, '#angry', '#disgusting', -0.619, 'antisocial', 'sociopathic', 'psychopathic_personality', 'disturbance', 'schizoid']
senticnet['personality_trait'] = [-0.041, 0.226, -0.143, 0.255, '#interesting', '#admirable', 0.099, 'like_read', 'plot', 'always_read', 'animate', 'play_role']
senticnet['personnel'] = [0, 0.942, 0, 0.72, '#interesting', '#admirable', 0.554, 'construction_worker', 'duty', 'policeman', 'vocation', 'laborer']
senticnet['perspective'] = [0, 0.139, 0, 0.18, '#interesting', '#admirable', 0.106, 'aspect', 'vista', 'scenic', 'spectacular', 'view']
senticnet['perspicaciousness'] = [0.555, -0.976, 0, 0.974, '#surprising', '#admirable', 0.835, 'foxiness', 'slyness', 'wiliness', 'craftiness', 'cunning']
senticnet['perspicacity'] = [0.626, -0.968, 0, 0.788, '#surprising', '#admirable', 0.794, 'foxiness', 'slyness', 'wiliness', 'craftiness', 'cunning']
senticnet['perspicuity'] = [0.743, -0.948, 0, 0.674, '#joyful', '#surprising', 0.788, 'lucidness', 'clarity', 'clearness', 'lucidity', 'pellucidity']
senticnet['perspicuousness'] = [0.634, -0.618, 0, 0.873, '#joyful', '#admirable', 0.708, 'lucidness', 'clarity', 'clearness', 'lucidity', 'pellucidity']
senticnet['perspiration'] = [-0.07, -0.023, 0, -0.083, '#sad', '#disgusting', -0.043, 'sweat', 'breathlessness', 'get_sweaty', 'pull_muscle', 'tired_leg']
senticnet['perspire'] = [-0.055, -0.056, 0.057, -0.089, '#angry', '#disgusting', -0.048, 'pull_muscle', 'sweat', 'breahard', 'get_tired', 'heavy_breathe']
senticnet['persuade'] = [-0.092, -0.039, 0, -0.111, '#sad', '#disgusting', -0.055, 'exchange_idea', 'share_idea', 'misunderstanding', 'transfer_knowledge', 'exchange_information']
senticnet['persuasion'] = [0, 0.325, -0.18, 0.335, '#interesting', '#admirable', 0.16, 'get_rid', 'cause_change', 'interaction', 'suggest', 'movement_towards']
senticnet['pertain'] = [0, 0, 0.845, -0.895, '#angry', '#disgusting', -0.58, 'relate', 'bear_on', 'come_to', 'concern', 'refer']
senticnet['pertinacious'] = [-0.964, 0, 0.858, -0.876, '#sad', '#disgusting', -0.899, 'contrarious', 'dogged', 'unregenerate', 'cantankerous', 'bolshy']
senticnet['perturb'] = [-0.831, 0, 0.564, -0.795, '#sad', '#disgusting', -0.73, 'upset', 'trouble', 'worry', 'disturb', 'vex']
senticnet['perturbing'] = [-0.759, 0, -0.875, 0, '#sad', '#scared', -0.545, 'disquieted', 'distressing', 'disturbing', 'troubling', 'worrisome']
senticnet['peruke'] = [-0.848, 0, 0.633, -0.539, '#sad', '#angry', -0.673, 'grizzle', 'postiche', 'horsehair_wig', 'periwig', 'wig']
senticnet['perusal'] = [0.572, -0.724, 0, 0.521, '#joyful', '#surprising', 0.606, 'browse', 'reading', 'perusing', 'poring_over', 'studying']
senticnet['peruse'] = [0.969, -0.575, 0, 0.851, '#joyful', '#admirable', 0.798, 'thumb', 'flick', 'flip', 'riffle', 'leaf']
senticnet['perusing'] = [0.572, -0.724, 0, 0.521, '#joyful', '#surprising', 0.606, 'browse', 'perusal', 'reading', 'poring_over', 'studying']
senticnet['pervade'] = [0.968, -0.767, 0, 0.583, '#joyful', '#surprising', 0.773, 'riddle', 'diffuse', 'permeate', 'spiritize', 'penetrate']
senticnet['perverseness'] = [0.667, -0.97, 0, 0.608, '#joyful', '#surprising', 0.748, 'unruliness', 'fractiousness', 'willfulness', 'perseverant', 'cussedness']
senticnet['perversion'] = [-0.622, 0, 0.515, -0.638, '#sad', '#disgusting', -0.592, 'immodesty', 'paraphilia', 'exhibitionism', 'sexual_paraphilia', 'fetishism']
senticnet['perversity'] = [0.885, -0.657, 0, 0.674, '#joyful', '#admirable', 0.739, 'unruliness', 'fractiousness', 'willfulness', 'perseverant', 'cussedness']
senticnet['pervert'] = [0, 0, 0, 0.075, '#admirable', '#admirable', 0.025, 'healthy_person', 'philanthropist', 'nazi', 'housekeeper', 'programmer']
senticnet['pesky'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'miffed', 'galling', 'annoying', 'vexatious', 'teasing']
senticnet['peso'] = [-0.026, 0.264, 0, 0.095, '#interesting', '#admirable', 0.111, 'finance', 'franc', 'cent', 'banknote', 'mastercard']
senticnet['pessimism'] = [-0.815, 0, -0.805, 0, '#sad', '#scared', -0.54, 'pessimistically', 'pessimistic', 'dispiritedly', 'hopelessness', 'hopelessly']
senticnet['pessimist'] = [-0.527, 0, 0.95, -0.788, '#angry', '#disgusting', -0.755, 'skeptic', 'sceptic', 'doubter', 'defeatist', 'negativist']
senticnet['pessimistic'] = [-0.731, 0, -0.988, 0, '#sad', '#scared', -0.573, 'pessimism', 'pessimistically', 'dispiritedly', 'hopelessness', 'hopelessly']
senticnet['pessimistically'] = [-0.884, 0, -0.767, 0, '#sad', '#scared', -0.55, 'pessimism', 'pessimistic', 'dispiritedly', 'hopelessness', 'hopelessly']
senticnet['pest'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'nuisance', 'annoyance', 'irritant', 'pain_in_ass', 'troublesome']
senticnet['pester'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'annoy', 'irritate', 'trouble', 'nag', 'bother']
senticnet['pestered'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['pestering'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['pesthole'] = [-0.55, 0, 0.996, -0.506, '#sad', '#angry', -0.684, 'breeding_ground', 'rookery', 'tract', 'piece_of_land', 'piece_of_ground']
senticnet['pesthouse'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'lazaret', 'lazarette', 'lazar_house', 'infirmary', 'lazaretto']
senticnet['pesticide_poisoning'] = [-0.98, 0, 0.717, -0.515, '#sad', '#angry', -0.737, 'parathion_poisoning', 'malathion_poisoning', 'toxic_condition', 'poisoning', 'intoxication']
senticnet['pestiferous'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['pestilence'] = [-0.955, 0, 0.876, -0.895, '#sad', '#disgusting', -0.909, 'bubonic_plague', 'pestis_bubonica', 'glandular_plague', 'septicemic_plague', 'pneumonic_plague']
senticnet['pestilent'] = [-0.864, 0, 0.891, -0.821, '#sad', '#angry', -0.859, 'baneful', 'pernicious', 'vesicatory', 'vesicant', 'noxious']
senticnet['pestis'] = [-0.714, 0, 0.604, -0.778, '#sad', '#disgusting', -0.699, 'bubonic_plague', 'pestis_bubonica', 'glandular_plague', 'septicemic_plague', 'pneumonic_plague']
senticnet['pestis_bubonica'] = [-0.683, 0, 0.755, -0.68, '#sad', '#angry', -0.706, 'pestis', 'plague', 'pestilence', 'pest', 'ambulant_plague']
senticnet['pet'] = [-0.514, 0, 0.723, -0.572, '#angry', '#disgusting', -0.603, 'animal', 'animate_being', 'beast', 'creature', 'brute']
senticnet['pet_cat'] = [0, 0, 0, -0.97, '#disgusting', '#disgusting', -0.323, 'sit_on_beach', 'clean_sink', 'absorb_moisture', 'mow_grass', 'wash_window']
senticnet['pet_die'] = [-0.706, 0, 0.946, 0, '#sad', '#angry', -0.551, 'complication', 'gonorrhea', 'toothache', 'brain_tumor', 'hear_bad_news']
senticnet['pet_dog'] = [0.065, 0.215, 0.011, 0.199, '#interesting', '#admirable', 0.156, 'domesticate_dog', 'domesticate_animal', 'gog', 'cat', 'pet']
senticnet['pet_food'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'attract_dog', 'food', 'dog', 'cat_food', 'dog_food']
senticnet['pet_shop'] = [0, -0.062, 0, 0.062, '#surprising', '#admirable', 0.041, 'box', 'small_box', 'small_apartment', 'veterinarian_office', 'owner_house']
senticnet['pet_store'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'windsor', 'lair', 'habitat', 'grassy_field', 'bee_hive']
senticnet['petallike'] = [-0.508, 0, 0.573, -0.893, '#angry', '#disgusting', -0.658, 'leafy', 'bowery', 'foliolate', 'unifoliate', 'bifoliate']
senticnet['peter'] = [0, -0.24, -0.046, 0.193, '#surprising', '#admirable', 0.129, 'omnivore', 'nocturnal', 'furry_creature', 'hairy', 'small_furry']
senticnet['petitio'] = [0.623, -0.532, 0, 0.873, '#joyful', '#admirable', 0.676, 'logical_fallacy_principii', 'logical_fallacy', 'hysteron_proteron', 'fallacy', 'false_belief']
senticnet['petitio_principii'] = [0.623, -0.532, 0, 0.873, '#joyful', '#admirable', 0.676, 'logical_fallacy', 'petitio', 'hysteron_proteron', 'fallacy', 'false_belief']
senticnet['petition'] = [-0.033, 0.22, -0.099, 0.21, '#interesting', '#admirable', 0.099, 'class_action', 'political_statement', 'require', 'go_against', 'posture']
senticnet['petri_dish'] = [-0.82, 0, 0, -0.789, '#sad', '#disgusting', -0.536, 'riverbed', 'bottom_ocean', 'waterfall', 'down_drain', 'septic_tank']
senticnet['petrol'] = [0, 0, -0.08, 0, '#scared', '#scared', -0.027, 'butane', 'diesel', 'kerosene', 'fuel', 'gasoline']
senticnet['petrol_kiosk'] = [0, 0.088, 0, 0, '#interesting', '#interesting', 0.029, 'buy_food', 'convenience', 'grocery_store', 'corner_shop', 'convenience_store']
senticnet['petroleum'] = [0, -0.24, -0.046, 0.193, '#surprising', '#admirable', 0.129, 'fuel_source', 'fossil_fuel', 'fuel', 'energy_source', 'natural_resource']
senticnet['petticoated'] = [-0.533, 0, 0.937, -0.802, '#angry', '#disgusting', -0.757, 'gowned', 'clad', 'surpliced', 'arrayed', 'caparisoned']
senticnet['pettifoggery'] = [-0.998, 0, 0.966, -0.827, '#sad', '#angry', -0.93, 'wrangle', 'dustup', 'quarrel', 'row', 'word']
senticnet['pettishness'] = [-0.598, 0, 0.911, -0.831, '#angry', '#disgusting', -0.78, 'biliousness', 'peevishness', 'querulousness', 'snappishness', 'surliness']
senticnet['petty'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'minor', 'unimportant', 'inessential', 'negligible', 'trivial']
senticnet['petulance'] = [-0.534, 0, 0.512, -0.821, '#sad', '#disgusting', -0.622, 'ill_humor', 'distemper', 'pet', 'testiness', 'touchiness']
senticnet['petulant'] = [0, 0, -0.897, -0.952, '#scared', '#disgusting', -0.616, 'nettlesome', 'fractious', 'peevish', 'irritable', 'cranky']
senticnet['pew'] = [0.065, 0.215, 0.011, 0.199, '#interesting', '#admirable', 0.156, 'fundamentalist', 'altar', 'confessional', 'chapel', 'pulpit']
senticnet['peyote'] = [-0.735, 0, 0.944, -0.942, '#angry', '#disgusting', -0.874, 'lysergic_acid_diethylamide', 'mescaline', 'psychedelic_drug', 'phencyclidine', 'drug']
senticnet['ph_level'] = [0.045, 0, 0, 0.051, '#joyful', '#admirable', 0.032, 'science', 'battery', 'chemistry', 'alkaline', 'chemical']
senticnet['phagocyte'] = [0.702, -0.524, 0, 0.958, '#joyful', '#admirable', 0.728, 'somatic_cell', 'vegetative_cell', 'fixed_phagocyte', 'macrophage', 'free_phagocyte']
senticnet['phalarope'] = [0.786, -0.82, 0, 0.776, '#joyful', '#surprising', 0.794, 'red_phalarope', 'northern_phalarope', 'shorebird', 'shore_bird', 'limicoline_bird']
senticnet['phalloplasty'] = [0.96, -0.839, 0, 0.566, '#joyful', '#surprising', 0.788, 'lift', 'plastic_surgery', 'abdominoplasty', 'tummy_tuck', 'autoplasty']
senticnet['phantasmagoric'] = [-0.93, 0, 0.94, -0.772, '#sad', '#angry', -0.881, 'delusive', 'unrealistic', 'unrealistical', 'surrealistic', 'wild']
senticnet['phantasmagorical'] = [-0.93, 0, 0.94, -0.772, '#sad', '#angry', -0.881, 'delusive', 'phantasmagoric', 'unrealistic', 'surrealistic', 'wild']
senticnet['phantom'] = [-0.888, 0, 0.589, -0.856, '#sad', '#disgusting', -0.778, 'illusion', 'shadow', 'disbelief', 'dark_magic', 'fool']
senticnet['pharisaic'] = [0.889, -0.694, 0, 0.908, '#joyful', '#admirable', 0.83, 'pious', 'piousal', 'sanctimonious', 'reverent', 'worshipful']
senticnet['pharisaical'] = [0.889, -0.694, 0, 0.908, '#joyful', '#admirable', 0.83, 'pharisaic', 'pious', 'sanctimonious', 'reverent', 'worshipful']
senticnet['pharmaceutical_chemist'] = [0.654, -0.579, 0, 0.685, '#joyful', '#admirable', 0.639, 'pharmacologist', 'druggist', 'health_professional', 'primary_care_provider', 'health_care_provider']
senticnet['pharmacist'] = [0.546, -0.832, 0, 0.973, '#surprising', '#admirable', 0.784, 'pharmacologist', 'pharmaceutical_chemist', 'health_professional', 'primary_care_provider', 'health_care_provider']
senticnet['pharmacologist'] = [0.654, -0.579, 0, 0.685, '#joyful', '#admirable', 0.639, 'druggist', 'pharmaceutical_chemist', 'health_professional', 'primary_care_provider', 'health_care_provider']
senticnet['pharmacy'] = [-0.026, -0.005, -0.077, -0.11, '#scared', '#disgusting', -0.069, 'bathroom_cabinet', 'medicine_cabinet', 'medicine', 'drugstore', 'medicine_chest']
senticnet['pharyngitis'] = [-0.821, 0, 0.609, -0.89, '#sad', '#disgusting', -0.773, 'inflammatory_disease', 'streptococcal_sore_throat', 'strep_throat', 'streptococcus_tonsilitis', 'septic_sore_throat']
senticnet['pharynx'] = [0.718, -0.882, 0, 0.83, '#surprising', '#admirable', 0.81, 'throat', 'tubular_cavity', 'cavity', 'bodily_cavity', 'cavum']
senticnet['pheasant'] = [0.567, -0.935, 0, 0.659, '#surprising', '#admirable', 0.72, 'bird', 'grouse', 'quail', 'partridge', 'wildfowl']
senticnet['phencyclidine'] = [-0.735, 0, 0.944, -0.942, '#angry', '#disgusting', -0.874, 'lysergic_acid_diethylamide', 'mescaline', 'peyote', 'psychedelic_drug', 'drug']
senticnet['phenobarbital'] = [0, -0.02, -0.064, -0.199, '#scared', '#disgusting', -0.081, 'palliative', 'ibuprofen', 'analgesic', 'painkiller', 'novocaine']
senticnet['phenolphthalein'] = [-0.501, 0, 0.582, -0.573, '#angry', '#disgusting', -0.552, 'purgative', 'cathartic', 'physic', 'aperient', 'laxative']
senticnet['phenomenology'] = [0.51, -0.876, 0, 0.775, '#surprising', '#admirable', 0.72, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['phenomenon'] = [0, 0.137, -0.107, 0.197, '#interesting', '#admirable', 0.076, 'boom', 'circumstance', 'loud', 'stormy', 'weather_element']
senticnet['phentolamine'] = [-0.595, 0, 0.537, -0.577, '#sad', '#disgusting', -0.57, 'virility_drug', 'sildenafil', 'sildenafil_citrate', 'tadalafil', 'vardenafil']
senticnet['phenylephrine'] = [0.887, -0.9, 0, 0.852, '#joyful', '#surprising', 0.88, 'pressor', 'adrenergic', 'phenylpropanolamine', 'vasoconstrictor', 'vasoconstrictive']
senticnet['phenylpropanolamine'] = [0.887, -0.9, 0, 0.852, '#joyful', '#surprising', 0.88, 'pressor', 'phenylephrine', 'adrenergic', 'vasoconstrictor', 'vasoconstrictive']
senticnet['philadelphia'] = [0, 0.081, 0.03, 0.126, '#interesting', '#admirable', 0.059, 'apple_tree', 'bald_eagle', 'roadway_square', 'rosebush', 'mammoth']
senticnet['philanthropist'] = [0.052, 0, 0, 0.069, '#joyful', '#admirable', 0.04, 'healthy_person', 'nazi', 'man', 'pervert', 'compatriot']
senticnet['philanthropy'] = [0.547, -0.982, 0, 0.977, '#surprising', '#admirable', 0.835, 'grant', 'gift', 'social_welfare', 'public_assistance', 'economic_aid']
senticnet['philia'] = [0.923, -0.689, 0, 0.85, '#joyful', '#admirable', 0.821, 'protectiveness', 'regard', 'respect', 'soft_spot', 'attachment']
senticnet['philistine'] = [0.849, -0.897, 0, 0.924, '#surprising', '#admirable', 0.89, 'nonintellectual', 'lowbrow', 'lowbrowed', 'mindless', 'uncultivated']
senticnet['philosopher'] = [0.922, -0.949, 0, 0.965, '#surprising', '#admirable', 0.945, 'utilitarian', 'egalitarian', 'equalitarian', 'elitist', 'moralist']
senticnet['philosophical_system'] = [0.95, -0.772, 0, 0.578, '#joyful', '#surprising', 0.767, 'philosophy', 'doctrine', 'amoralism', 'school_of_thought', 'ism']
senticnet['philosophy'] = [-0.051, 0.126, -0.054, 0.147, '#interesting', '#admirable', 0.056, 'read', 'read_book', 'piece_of_information', 'study', 'go_university']
senticnet['phlegm'] = [0, 0, 0, -0.964, '#disgusting', '#disgusting', -0.321, 'thick_substance', 'viscous_substance', 'mucous_substance', 'disgusting', 'disgust']
senticnet['phlegmatic'] = [-0.893, 0, 0.797, -0.958, '#sad', '#disgusting', -0.883, 'unemotional', 'unemotionalal', 'unblinking', 'stoic', 'chilly']
senticnet['phlegmatical'] = [-0.893, 0, 0.797, -0.958, '#sad', '#disgusting', -0.883, 'phlegmatic', 'unemotional', 'unblinking', 'stoic', 'chilly']
senticnet['phobia'] = [-0.791, -0.711, -0.96, -0.958, '#scared', '#disgusting', -0.666, 'fear', 'caution', 'deep_sadness', 'bad_feeling', 'psychoneurosis']
senticnet['phonate'] = [-0.602, 0, 0.603, -0.72, '#angry', '#disgusting', -0.642, 'talk', 'utter', 'speak', 'mouth', 'verbalize']
senticnet['phone'] = [0.035, -0.01, 0.027, 0.085, '#joyful', '#admirable', 0.034, 'telephone', 'cellphone', 'telephone_room', 'find_phone_number', 'use_telephone']
senticnet['phone_bill'] = [-0.071, -0.037, -0.112, 0, '#sad', '#scared', -0.049, 'sign_agreement', 'forget_name', 'receive_email', 'trade_stock', 'electric_bill']
senticnet['phone_book'] = [0, -0.083, -0.054, 0.099, '#surprising', '#admirable', 0.043, 'classify_ad', 'side_build', 'city_center', 'letter_alphabet', 'ads']
senticnet['phone_booth'] = [0.057, -0.038, 0, 0, '#joyful', '#surprising', 0.032, 'internet_cafe', 'office_build', 'office', 'discount_store', 'observatory']
senticnet['phone_call'] = [-0.096, -0.036, 0.061, 0, '#sad', '#angry', -0.04, 'bad_reception', 'wifi', 'internet', 'bad_connection', 'underground']
senticnet['phone_conversation'] = [0.896, 0, 0, 0.919, '#joyful', '#admirable', 0.605, 'call', 'use_phone', 'orate', 'use_telephone', 'speech']
senticnet['phone_line_busy'] = [-0.962, 0, 0.91, 0, '#sad', '#angry', -0.624, 'check_email', 'search_information', 'see_picture', 'conduct_research', 'better_oneself']
senticnet['phone_ring'] = [0.933, -0.984, 0, 0, '#joyful', '#surprising', 0.639, 'busy_signal', 'telephone_ring', 'dial_phone', 'converse', 'speak_loudly']
senticnet['phony'] = [-0.21, 0.174, -0.261, 0.206, '#sad', '#scared', -0.03, 'against_law', 'hide_truth', 'sneaky', 'immoral', 'fake']
senticnet['phosphorous_acid'] = [-0.814, 0, 0.774, -0.776, '#sad', '#disgusting', -0.788, 'acid', 'hypophosphoric_acid', 'periodic_acid', 'hypooxyacid', 'oxyacid']
senticnet['photo'] = [0.031, 0.103, 0, 0.06, '#interesting', '#admirable', 0.065, 'graphical_representation', 'crayon', 'artwork', 'photograph', 'varnish']
senticnet['photo_album'] = [0.066, 0.071, 0, 0, '#joyful', '#interesting', 0.046, 'old_photograph', 'picture_of_family', 'glass_front_display_cabinet', 'family_picture', 'video_tape']
senticnet['photo_copy'] = [0.922, -0.843, 0, 0, '#joyful', '#surprising', 0.588, 'color_paper', 'writing_paper', 'printing_paper', 'note_book', 'white_paper']
senticnet['photograph'] = [0, 0.074, -0.047, 0.127, '#interesting', '#admirable', 0.051, 'picture', 'drawing', 'art', 'painting', 'artwork']
senticnet['photographer'] = [0.095, 0, -0.045, 0.062, '#joyful', '#admirable', 0.037, 'liquid_water', 'water_spray', 'moisture', 'rise_water', 'droplet']
senticnet['phototherapy'] = [0.789, -0.817, 0, 0.591, '#joyful', '#surprising', 0.732, 'radiotherapy', 'radiation_therapy', 'radiation', 'actinotherapy', 'irradiation']
senticnet['phrasal_idiom'] = [0.563, -0.728, 0, 0.644, '#surprising', '#admirable', 0.645, 'idiom', 'idiomatic_expression', 'ruralism', 'set_phrase', 'phrase']
senticnet['phrase'] = [0, 0.115, -0.102, 0.249, '#interesting', '#admirable', 0.087, 'word', 'remark', 'grammar_part', 'speech_part', 'sentence']
senticnet['phraseology'] = [-0.611, 0, 0.73, -0.858, '#angry', '#disgusting', -0.733, 'diction', 'phrasing', 'verbiage', 'wording', 'verbalization']
senticnet['phrasing'] = [-0.611, 0, 0.73, -0.858, '#angry', '#disgusting', -0.733, 'diction', 'verbalization', 'verbiage', 'wording', 'phraseology']
senticnet['phrenitis'] = [-0.732, 0, 0.775, -0.923, '#angry', '#disgusting', -0.81, 'rubor', 'redness', 'sleeping_sickness', 'sleepy_sickness', 'epidemic_encephalitis']
senticnet['phto_copy'] = [0.73, -0.934, 0, 0, '#joyful', '#surprising', 0.555, 'white_paper', 'writing_paper', 'printing_paper', 'note_book', 'color_paper']
senticnet['physic'] = [0, 0.084, 0, 0.065, '#interesting', '#admirable', 0.05, 'college_major', 'chemistry', 'science', 'geology', 'subject_school']
senticnet['physic_term'] = [0, 0.228, -0.067, 0.29, '#interesting', '#admirable', 0.15, 'grow_long', 'plus', 'scientific_term', 'extent', 'commence']
senticnet['physical'] = [-0.064, 0.145, -0.061, 0.115, '#interesting', '#admirable', 0.045, 'good_shape', 'physical_condition', 'healthy_activity', 'touch_toe', 'elongation']
senticnet['physical_action'] = [-0.934, 0, 0.949, -0.986, '#angry', '#disgusting', -0.956, 'fight', 'kick', 'punch', 'slap', 'beat']
senticnet['physical_activity'] = [0, 0.348, -0.322, 0.382, '#interesting', '#admirable', 0.136, 'go_to_gym', 'maintain_muscle_strength', 'release_energy', 'prove_physical_endurance', 'physical_endurance']
senticnet['physical_aggression'] = [-0.917, 0, 0.451, -0.987, '#sad', '#disgusting', -0.785, 'slave', 'psychological_aggression', 'female_slave', 'aggression', 'verbal_aggression']
senticnet['physical_attraction'] = [0.638, -0.515, 0, 0.656, '#joyful', '#admirable', 0.603, 'love', 'aphrodisia', 'lecherousness', 'lustfulness', 'amorousness']
senticnet['physical_condition'] = [0, 0.077, 0, 0.077, '#interesting', '#admirable', 0.051, 'good_shape', 'fitness', 'physical', 'help_someone_live_long', 'cause_dehydration']
senticnet['physical_contact'] = [0.807, 0, 0, 0.76, '#joyful', '#admirable', 0.522, 'grab', 'reach_out', 'grasp', 'reach', 'extend_arm']
senticnet['physical_effort'] = [0, 0, 0, 0.946, '#admirable', '#admirable', 0.315, 'persistence', 'effort', 'eat_properly', 'healthy_environment', 'dedication']
senticnet['physical_endurance'] = [0, 0.348, -0.322, 0.382, '#interesting', '#admirable', 0.136, 'go_to_gym', 'maintain_muscle_strength', 'release_energy', 'physical_activity', 'prove_physical_endurance']
senticnet['physical_exam'] = [-0.075, 0, -0.133, 0, '#sad', '#scared', -0.069, 'know_healthy', 'nervous_breakdown', 'check_vital_sign', 'examination', 'epileptic_fit']
senticnet['physical_exercise'] = [-0.028, 0, 0.052, 0, '#sad', '#angry', -0.027, 'exercise', 'exercise_regularly', 'antioxidant', 'moderation', 'drink_plenty_water']
senticnet['physical_exertion'] = [-0.059, -0.033, 0.061, 0, '#sad', '#angry', -0.029, 'lose_energy', 'expend_energy', 'strain_muscle', 'sweaty', 'expend']
senticnet['physical_fitness'] = [0.051, -0.036, 0.014, 0, '#joyful', '#surprising', 0.024, 'exercise', 'keep_shape', 'strengthen_heart', 'keep_fit', 'exercise_dog']
senticnet['physical_injury'] = [-0.129, -0.058, 0, -0.134, '#sad', '#disgusting', -0.068, 'contusion', 'muscle_cramp', 'become_exhausted', 'pull_muscle', 'leg_hurt']
senticnet['physical_interaction'] = [-0.968, 0, 0.924, 0, '#sad', '#angry', -0.631, 'uprise', 'anti', 'go_against', 'fight_against', 'disagreement']
senticnet['physical_object'] = [0.03, 0.117, 0, 0.084, '#interesting', '#admirable', 0.077, 'object', 'insect_repellant', 'thin_wood', 'tree_product', 'book_page']
senticnet['physical_pain'] = [-0.718, 0, -0.95, 0, '#sad', '#scared', -0.556, 'broken_finger', 'bad_knee', 'car_wreck', 'ill_health', 'suffer']
senticnet['physical_phenomenon'] = [0.054, -0.057, 0, 0.098, '#surprising', '#admirable', 0.07, 'magnetism', 'boom', 'boil', 'spray', 'vapor']
senticnet['physical_process'] = [0.671, -0.561, 0, 0.685, '#joyful', '#admirable', 0.639, 'macular_degeneration', 'attack', 'obsolescence', 'process', 'degeneration']
senticnet['physical_property'] = [-0.812, 0, 0.83, -0.978, '#angry', '#disgusting', -0.873, 'deadness', 'rigidity', 'rigidness', 'stiffness', 'inelasticity']
senticnet['physical_quantity'] = [-0.066, 0.255, -0.155, 0.202, '#interesting', '#admirable', 0.079, 'human_trait', 'quantity', 'movement_towards', 'physics', 'velocity']
senticnet['physical_reaction'] = [-0.981, 0, -0.806, 0, '#sad', '#scared', -0.596, 'sometimes_painful', 'body_reaction', 'bad_feeling', 'fall_sick', 'stomach_pain']
senticnet['physical_rehabilitation'] = [0.641, -0.784, 0, 0.721, '#surprising', '#admirable', 0.715, 'correctional_rehabilitation', 'rehabilitation', 'physical_restoration', 'therapeutic_rehabilitation', 'vocational_rehabilitation']
senticnet['physical_restoration'] = [0.641, -0.784, 0, 0.721, '#surprising', '#admirable', 0.715, 'correctional_rehabilitation', 'physical_rehabilitation', 'rehabilitation', 'therapeutic_rehabilitation', 'vocational_rehabilitation']
senticnet['physical_strength'] = [0, 0.707, 0, 0.858, '#interesting', '#admirable', 0.522, 'strength', 'strong', 'manly', 'athlete', 'muscle']
senticnet['physicalness'] = [-0.597, 0, 0.747, -0.891, '#angry', '#disgusting', -0.745, 'tangibility', 'tangibleness', 'palpability', 'reality', 'solidness']
senticnet['physician'] = [0, 0, -0.166, -0.124, '#scared', '#disgusting', -0.097, 'nurse', 'surgeon', 'doctor', 'medical_doctor', 'cure']
senticnet['physiological_condition'] = [0.633, -0.634, 0, 0.507, '#joyful', '#surprising', 0.591, 'drug_addiction', 'white_plague', 'physical_condition', 'physiological_state', 'dependance']
senticnet['physiological_state'] = [0.633, -0.634, 0, 0.507, '#joyful', '#surprising', 0.591, 'drug_addiction', 'white_plague', 'physical_condition', 'dependance', 'physiological_condition']
senticnet['physique'] = [0, 0.115, 0, 0.115, '#interesting', '#admirable', 0.077, 'human_shape', 'below_neck', 'shape', 'human_part', 'hand_foot']
senticnet['pia_lot_of_airplane'] = [0, 0.727, 0, 0, '#interesting', '#interesting', 0.242, 'stand_alone', 'deal_card_player', 'forward_email', 'bridge_difference', 'rush_job']
senticnet['pia_lot_of_seat'] = [0.89, 0.944, 0, 0, '#joyful', '#interesting', 0.611, 'airplane_seat', 'small_seat', 'seat_chair', 'airplane', 'pilot']
senticnet['piano'] = [-0.988, 0, 0.614, -0.905, '#sad', '#disgusting', -0.836, 'grand', 'upright', 'grand_piano', 'mechanical_piano', 'player_piano']
senticnet['picaninny'] = [-0.83, 0, 0.987, -0.535, '#sad', '#angry', -0.784, 'fry', 'kid', 'minor', 'tike', 'small_fry']
senticnet['picayune'] = [0, 0, -0.868, -0.863, '#scared', '#disgusting', -0.577, 'footling', 'lilliputian', 'little', 'fiddling', 'niggling']
senticnet['piccaninny'] = [-0.953, 0, 0.624, -0.578, '#sad', '#angry', -0.718, 'fry', 'kid', 'minor', 'tike', 'small_fry']
senticnet['pick'] = [0, 0.26, -0.139, 0.236, '#interesting', '#admirable', 0.119, 'select', 'selection', 'choose', 'decide', 'compel']
senticnet['pick_apart'] = [-0.706, 0, 0.769, -0.625, '#sad', '#angry', -0.7, 'call_on_carpet', 'take_to_task', 'chide', 'berate', 'bawl_out']
senticnet['pick_at'] = [-0.822, 0, 0.835, -0.675, '#sad', '#angry', -0.777, 'disparage', 'belittle', 'deflate', 'puncture', 'depreciate']
senticnet['pick_berry'] = [-0.088, -0.013, 0.017, -0.064, '#sad', '#disgusting', -0.052, 'jump_air', 'run_far', 'meet_girl_of_your_dreams', 'monitor_heart_rate', 'pick_flower']
senticnet['pick_flower'] = [-0.081, 0, 0, -0.071, '#sad', '#disgusting', -0.051, 'find_flower', 'smoke_cigar', 'cross_bridge', 'blow_horn', 'plant_tree']
senticnet['pick_lock'] = [0, 0.129, -0.049, 0.07, '#interesting', '#admirable', 0.05, 'nose', 'lock', 'vision', 'pick', 'stick_out']
senticnet['pick_nose'] = [-0.062, 0.128, 0.707, -0.677, '#angry', '#disgusting', -0.439, 'disgust', 'impolite', 'bad_manner', 'laugh_oneself', 'uneducated']
senticnet['pick_out'] = [0.837, -0.894, 0, 0.544, '#joyful', '#surprising', 0.758, 'choose', 'define', 'screen', 'nominate', 'think_of']
senticnet['pick_team'] = [0.911, 0.772, 0, 0, '#joyful', '#interesting', 0.561, 'sell_car', 'throw_frisbee', 'market_product', 'price_goods', 'deal_card_player']
senticnet['pick_tooth'] = [0, 0.847, 0, 0.776, '#interesting', '#admirable', 0.541, 'read_human', 'read', 'find_library', 'borrow_book', 'use_internet']
senticnet['pick_up'] = [0.573, 0.616, -0.246, 0.389, '#joyful', '#interesting', 0.444, 'lift_up', 'uplift', 'togetherness', 'exhilarate', 'urge']
senticnet['pick_up_brush'] = [0.165, 0.069, 0.028, 0.057, '#joyful', '#interesting', 0.088, 'make_paint', 'stir_paint_brush', 'wall_art', 'stir_paint', 'buy_paint']
senticnet['pick_up_pen'] = [0, 0.715, 0, 0.724, '#interesting', '#admirable', 0.48, 'proofread', 'think_write', 'use_word', 'learn_write', 'run_out_ink']
senticnet['pick_up_telephone_receiver'] = [0.913, 0.864, 0, 0, '#joyful', '#interesting', 0.592, 'find_phone_number', 'dial_phone_number', 'dial', 'keypad', 'dial_telephone']
senticnet['pick_up_trash'] = [-0.775, 0, 0, -0.805, '#sad', '#disgusting', -0.527, 'chore', 'make_happen', 'elbow_grease', 'intuition', 'stop_procrastinate']
senticnet['pick_up_woman'] = [0.896, 0.849, 0, 0, '#joyful', '#interesting', 0.582, 'meet_new_person', 'looser', 'get_wasted', 'drink_beer', 'get_drink']
senticnet['pickaninny'] = [-0.974, 0, 0.58, -0.668, '#sad', '#disgusting', -0.741, 'fry', 'kid', 'minor', 'tike', 'small_fry']
senticnet['picket'] = [0, 0, 0.781, -0.929, '#angry', '#disgusting', -0.57, 'go_against', 'anti', 'political_statement', 'rally', 'angry_mob']
senticnet['picket_sign'] = [0.021, 0.108, 0, 0, '#joyful', '#interesting', 0.043, 'angry_mob', 'public_gathering', 'several_people', 'picket', 'protest']
senticnet['pickle'] = [-0.818, 0, 0.543, -0.63, '#sad', '#disgusting', -0.664, 'caper', 'gherkin', 'relish', 'dill_pickle', 'sweet_pickle']
senticnet['picklepuss'] = [-0.874, 0, 0.693, -0.645, '#sad', '#angry', -0.737, 'sourpuss', 'unwelcome_person', 'troublemaker', 'trouble_maker', 'troubler']
senticnet['pickpocket'] = [0, -0.035, 0.107, -0.148, '#angry', '#disgusting', -0.073, 'acquire_goods', 'buy_meat', 'thief', 'get_need', 'buy_goods']
senticnet['pickup'] = [-0.621, 0, 0.996, -0.683, '#angry', '#disgusting', -0.767, 'pack', 'face_pack', 'corrective', 'prosthesis', 'prosthetic_device']
senticnet['picnic'] = [0.074, 0, 0, 0, '#joyful', '#joyful', 0.025, 'hike_trail', 'ant_hill', 'compost', 'picnic_table', 'soccer_field']
senticnet['picnic_table'] = [0.074, 0, 0, 0, '#joyful', '#joyful', 0.025, 'hike_trail', 'ant_hill', 'compost', 'picnic', 'soccer_field']
senticnet['picture'] = [0.034, 0.075, 0, 0.143, '#interesting', '#admirable', 0.084, 'photograph', 'art', 'painting', 'artwork', 'mural']
senticnet['picture_frame'] = [0.059, -0.047, 0.014, 0, '#joyful', '#surprising', 0.031, 'frame', 'artwork', 'mural', 'tile', 'smoke_alarm']
senticnet['picture_of_family'] = [0.901, 0.961, 0, 0, '#joyful', '#interesting', 0.621, 'wife', 'old_photograph', 'family_picture', 'mum', 'photo_album']
senticnet['picture_person'] = [0, 0.164, 0, 0, '#interesting', '#interesting', 0.055, 'equity', 'buy_paint_brush', 'buy_paint', 'pick_up_brush', 'use_oil_paint']
senticnet['picture_scene'] = [0.903, 0.932, 0, 0, '#joyful', '#interesting', 0.612, 'take_photograph', 'climb_ladder', 'photo', 'frame_picture', 'knock_door']
senticnet['picture_taken'] = [0.268, 0, 0, 0, '#joyful', '#joyful', 0.089, 'outgo_personality', 'get_laid', 'pump_air', 'joke_around', 'become_intoxicated']
senticnet['pie'] = [0.039, -0.097, 0, 0, '#joyful', '#surprising', 0.045, 'cookie', 'muffin', 'bagel', 'pudding', 'brownie']
senticnet['piece_de_resistance'] = [0.61, -0.79, 0, 0.797, '#surprising', '#admirable', 0.732, 'curio', 'oddity', 'curiosity', 'peculiarity', 'oddment']
senticnet['piece_of_art'] = [0, 0.829, 0, 0.774, '#interesting', '#admirable', 0.534, 'current_event', 'cnn', 'piece_of_paper', 'paper_piece', 'paper']
senticnet['piece_of_cake'] = [0.795, -0.791, 0, 0.79, '#joyful', '#surprising', 0.792, 'labor', 'doddle', 'undertaking', 'project', 'task']
senticnet['piece_of_change'] = [0.801, 0.772, 0, 0, '#joyful', '#interesting', 0.524, 'cash_bill', 'paper_bill', 'debit_card', 'dollar_bill', 'cash_coin']
senticnet['piece_of_clothing'] = [0.842, 0.939, 0, 0, '#joyful', '#interesting', 0.594, 'clothes', 'fashion', 'robe', 'dress', 'shirt']
senticnet['piece_of_ground'] = [-0.55, 0, 0.996, -0.506, '#sad', '#angry', -0.684, 'pesthole', 'rookery', 'tract', 'piece_of_land', 'breeding_ground']
senticnet['piece_of_information'] = [0, 0.111, 0, 0.07, '#interesting', '#admirable', 0.06, 'grid_object', 'system_abstract_think', 'eiffel_tower', 'landmark', 'monument']
senticnet['piece_of_jewelry'] = [0.039, -0.004, 0.031, 0.154, '#joyful', '#admirable', 0.055, 'precious', 'bell_sound', 'wedding_band', 'jewelry', 'jewel']
senticnet['piece_of_land'] = [-0.55, 0, 0.996, -0.506, '#sad', '#angry', -0.684, 'pesthole', 'rookery', 'tract', 'breeding_ground', 'piece_of_ground']
senticnet['piece_of_material'] = [-0.033, 0, 0.077, 0, '#sad', '#angry', -0.037, 'measure_inch', 'scale', 'measure_tool', 'ruler', 'measurement_tool']
senticnet['piece_of_meat'] = [-0.03, 0, -0.056, 0, '#sad', '#scared', -0.029, 'keep_fresh', 'appetizer', 'archeology', 'porridge', 'food']
senticnet['piece_of_metal'] = [-0.094, -0.006, -0.05, -0.086, '#sad', '#disgusting', -0.075, 'gunpowder', 'projectile', 'ammunition', 'lethal', 'automatic']
senticnet['piece_of_music'] = [0.54, -0.575, 0, 0.678, '#surprising', '#admirable', 0.598, 'musical_composition', 'opus', 'composition', 'piece', 'adagio']
senticnet['piece_of_paper'] = [0.047, -0.107, 0.026, -0.046, '#joyful', '#surprising', 0.027, 'paper', 'fasten_paper_together', 'bind_paper_together', 'narrowness', 'keep_paper_together']
senticnet['piece_of_story'] = [0, 0.111, 0, 0.07, '#interesting', '#admirable', 0.06, 'beautiful_view', 'tourist_attraction', 'iconic_place', 'eiffel_tower', 'monument']
senticnet['piece_of_wood'] = [0, -0.069, 0.046, 0.09, '#surprising', '#admirable', 0.038, 'dog_fetch', 'wood', 'adhere', 'long_wood', 'branch']
senticnet['piece_together'] = [0, 0.203, 0.036, 0.204, '#interesting', '#admirable', 0.124, 'assemble', 'feel_heat', 'see_sky', 'close_together', 'fly_around']
senticnet['pied'] = [0.767, 0, 0, 0.844, '#joyful', '#admirable', 0.537, 'calico', 'multi-color', 'varicolored', 'motley', 'painted']
senticnet['pierce'] = [-0.093, -0.013, 0, -0.12, '#sad', '#disgusting', -0.067, 'cut_food', 'spread_butter', 'open_package', 'pick_out', 'lacerate']
senticnet['piercing'] = [0, 0, 0.889, -0.883, '#angry', '#disgusting', -0.591, 'incisive', 'thrust', 'pierce', 'acute', 'discriminating']
senticnet['piety'] = [0.681, -0.686, 0, 0.938, '#surprising', '#admirable', 0.768, 'righteousness', 'godliness', 'dutifulness', 'devoutness', 'religiousness']
senticnet['piffle'] = [0.714, -0.633, 0, 0.692, '#joyful', '#admirable', 0.68, 'nonsense', 'meaninglessness', 'bunk', 'nonsensicality', 'hokum']
senticnet['pig_meat'] = [0.039, -0.009, 0.018, 0.075, '#joyful', '#admirable', 0.035, 'high_protein', 'red_meat', 'meat_cut', 'food_item', 'dairy_product']
senticnet['pigeon'] = [0.114, 0, 0, 0, '#joyful', '#joyful', 0.038, 'mallard', 'vulture', 'most_birds', 'bird', 'can_fly']
senticnet['pigeon_breast'] = [-0.854, 0, 0.695, -0.658, '#sad', '#angry', -0.736, 'affliction', 'deformity', 'chicken_breast', 'clubfoot', 'talipes']
senticnet['piggy_bank'] = [0, 0.187, 0, 0, '#interesting', '#interesting', 0.062, 'billfold', 'wallet', 'bank', 'coffer', 'bank_vault']
senticnet['pigheaded'] = [0, 0, -0.901, 0, '#scared', '#scared', -0.3, 'obstinate', 'persistent', 'stubborn', 'mulish', 'headstrong']
senticnet['pigheadedness'] = [-0.633, 0, 0.942, -0.528, '#sad', '#angry', -0.701, 'stubbornness', 'obstinacy', 'obstinance', 'bullheadedness', 'impenitence']
senticnet['pigment'] = [0, 0, 0, 0.098, '#admirable', '#admirable', 0.033, 'cobalt', 'many_shades', 'cyan', 'green_yellow', 'tint']
senticnet['pike'] = [0.911, -0.825, 0, 0.844, '#joyful', '#admirable', 0.86, 'autobahn', 'autostrada', 'turnpike', 'toll_road', 'highway']
senticnet['pile_up'] = [-0.593, 0, 0.604, -0.951, '#angry', '#disgusting', -0.716, 'run_up', 'roll_up', 'collect', 'accumulate', 'amass']
senticnet['piles'] = [-0.64, 0, 0.87, -0.745, '#angry', '#disgusting', -0.752, 'disease', 'sick', 'discomfort', 'pain_in_ass', 'pain']
senticnet['pilferage'] = [-0.552, 0, 0.843, -0.585, '#angry', '#disgusting', -0.66, 'thieving', 'larceny', 'theft', 'thievery', 'stealing']
senticnet['pill'] = [-0.053, -0.019, -0.089, -0.198, '#scared', '#disgusting', -0.107, 'sleep_drug', 'analgesic', 'ibuprofen', 'palliative', 'medicine']
senticnet['pill_bottle'] = [0.033, -0.008, 0.065, -0.143, '#angry', '#disgusting', -0.056, 'vanity_case', 'inbox', 'coffee_cup', 'folder', 'cardboard_box']
senticnet['pill_pusher'] = [0.638, -0.881, 0, 0.843, '#surprising', '#admirable', 0.787, 'pharmacologist', 'pharmaceutical_chemist', 'health_professional', 'primary_care_provider', 'health_care_provider']
senticnet['pill_roller'] = [0.584, -0.622, 0, 0.989, '#surprising', '#admirable', 0.732, 'pharmacologist', 'pharmaceutical_chemist', 'health_professional', 'primary_care_provider', 'health_care_provider']
senticnet['pillage'] = [0, 0, -0.749, -0.89, '#scared', '#disgusting', -0.546, 'booty', 'loot', 'plunder', 'swag', 'prize']
senticnet['pillar'] = [0, 0.082, 0.009, 0.135, '#interesting', '#admirable', 0.069, 'vertical', 'support_structure', 'column', 'temple', 'backside']
senticnet['pillock'] = [-0.737, 0, 0.836, -0.699, '#sad', '#angry', -0.757, 'dunce', 'dunderhead', 'numskull', 'blockhead', 'bonehead']
senticnet['pillow_case'] = [0.931, -0.756, 0, 0, '#joyful', '#surprising', 0.562, 'contraceptive_device', 'condom', 'clothes_shelf', 'sex_toy', 'birth_control_pill']
senticnet['pillow_fight'] = [0, -0.082, 0, 0, '#surprising', '#surprising', 0.027, 'yo-yo', 'playroom', 'backgammon', 'action_figure', 'board_game']
senticnet['pillowcase'] = [0, 0.082, 0.009, 0.135, '#interesting', '#admirable', 0.069, 'duvet_cover', 'pillow', 'mattress', 'bed_sheet', 'duvet']
senticnet['pilomotor_reflex'] = [-0.849, 0, 0.804, -0.849, '#sad', '#disgusting', -0.834, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['pilous'] = [-0.754, 0, 0.734, -0.825, '#sad', '#disgusting', -0.771, 'puberulent', 'sericeous', 'furlike', 'pappose', 'haired']
senticnet['pimple'] = [-0.103, 0, -0.053, -0.112, '#sad', '#disgusting', -0.089, 'jaw', 'cheek', 'dimple', 'forehead', 'beard']
senticnet['pimpled'] = [-0.85, 0, 0.804, -0.855, '#sad', '#disgusting', -0.836, 'scarred', 'flyblown', 'marred', 'acned', 'blemished']
senticnet['pin'] = [-0.754, 0, 0.886, -0.726, '#sad', '#angry', -0.789, 'harass', 'move', 'check', 'fork', 'aggress']
senticnet['pin_down'] = [0.519, -0.554, 0, 0.746, '#surprising', '#admirable', 0.606, 'narrow_down', 'peg_down', 'nail_down', 'narrow', 'concretize']
senticnet['pin_needle'] = [0, 0.836, 0, 0.784, '#interesting', '#admirable', 0.54, 'pointy_object', 'without_space', 'pin', 'dart', 'blade']
senticnet['pin_up_girl'] = [0, 0, -0.946, -0.973, '#scared', '#disgusting', -0.64, 'thumb_tack', 'push_pin', 'glue_stick', 'letter_opener', 'pair_of_scissors']
senticnet['pinafore'] = [-0.531, 0, 0.569, -0.776, '#angry', '#disgusting', -0.625, 'dress', 'pinny', 'dirndl', 'gown', 'muumuu']
senticnet['pincer'] = [0, 0, -0.863, -0.993, '#scared', '#disgusting', -0.619, 'claw', 'muzzle', 'tic', 'whisker', 'bed_bug']
senticnet['pinch'] = [-0.147, 0, -0.146, -0.04, '#sad', '#scared', -0.111, 'break_apart', 'pulse', 'learn_lesson', 'fall_down_flight_stair', 'break_glass']
senticnet['pincushion_flower'] = [-0.827, 0, 0.619, -0.941, '#sad', '#disgusting', -0.796, 'sweet_scabious', 'scabiosa', 'mournful_widow', 'field_scabious', 'flower']
senticnet['pine_cone'] = [0, 0, -0.148, -0.036, '#scared', '#disgusting', -0.061, 'creeper', 'fallen_leaf', 'poison_ivy', 'detritus', 'tress']
senticnet['ping_pong'] = [0.037, 0.148, 0, 0.212, '#interesting', '#admirable', 0.132, 'horseshoe', 'four_leaf_clover', 'rotary_phone', 'horse_shoes', 'billiards']
senticnet['ping_pong_ball'] = [0, -0.037, 0.042, -0.074, '#angry', '#disgusting', -0.026, 'ball', 'ping_pong_show', 'dandruff', 'solid_water', 'empty_bottle']
senticnet['ping_pong_paddle'] = [0.796, -0.789, 0, 0, '#joyful', '#surprising', 0.528, 'yo-yo', 'ball', 'tennis_ball', 'sport_ball', 'basketball']
senticnet['ping_pong_show'] = [0, -0.037, 0.042, -0.074, '#angry', '#disgusting', -0.026, 'ball', 'ping_pong_ball', 'dandruff', 'solid_water', 'empty_bottle']
senticnet['pinhead'] = [-0.036, -0.032, 0.081, -0.059, '#angry', '#disgusting', -0.048, 'ladybug', 'mote', 'grain_sand', 'mite', 'sand']
senticnet['pink'] = [0, 0.069, 0, 0.094, '#interesting', '#admirable', 0.054, 'purple', 'colorful', 'green_black', 'red_green', 'red']
senticnet['pink_flower'] = [-0.899, 0, 0, -0.985, '#sad', '#disgusting', -0.628, 'tropical_fish', 'wood_duck', 'disney', 'autumn_leaf', 'beau']
senticnet['pink_paper_daisy'] = [-0.934, 0, 0.691, -0.971, '#sad', '#disgusting', -0.865, 'cudweed', 'strawflower', 'composite', 'composite_plant', 'everlasting_flower']
senticnet['pinkeye'] = [-0.601, 0, 0.8, -0.605, '#angry', '#disgusting', -0.669, 'ophthalmia', 'ophthalmitis', 'rubor', 'redness', 'inflammation']
senticnet['pinky'] = [0, 0, 0.068, 0, '#angry', '#angry', -0.023, 'extremity', 'human_appendage', 'body_appendage', 'appendage', 'body_member']
senticnet['pinnacle'] = [0.031, 0.126, 0.03, 0.111, '#interesting', '#admirable', 0.079, 'top', 'peak', 'mountain_top', 'summit', 'height']
senticnet['pinny'] = [-0.531, 0, 0.569, -0.776, '#angry', '#disgusting', -0.625, 'pinafore', 'dress', 'dirndl', 'gown', 'muumuu']
senticnet['pinprick'] = [-0.85, 0, 0.564, -0.924, '#sad', '#disgusting', -0.779, 'miff', 'impatience', 'snit', 'bummer', 'botheration']
senticnet['pint'] = [0.092, 0.07, 0.036, 0.068, '#joyful', '#interesting', 0.065, 'gallon', 'quart', 'lite', 'ounce', 'liquid_measurement']
senticnet['pioneer'] = [0, 0, 0, 0.972, '#admirable', '#admirable', 0.324, 'egalitarian', 'discovery', 'connoisseur', 'inventor', 'scientist']
senticnet['pious'] = [0.889, -0.694, 0, 0.908, '#joyful', '#admirable', 0.83, 'pharisaic', 'pharisaical', 'sanctimonious', 'reverent', 'worshipful']
senticnet['pious_platitude'] = [-0.611, 0, 0.981, -0.983, '#angry', '#disgusting', -0.858, 'talk', 'nothingness', 'jazz', 'malarkey', 'malarky']
senticnet['piousness'] = [0.838, -0.55, 0, 0.622, '#joyful', '#admirable', 0.67, 'righteousness', 'godliness', 'dutifulness', 'devoutness', 'religiousness']
senticnet['piperine'] = [-0.829, 0, 0.642, -0.72, '#sad', '#disgusting', -0.73, 'substance', 'capsaicin', 'gingerol', 'chemical_irritant', 'pepper_spray']
senticnet['piping'] = [-0.973, 0, 0.865, -0.543, '#sad', '#angry', -0.794, 'cord', 'lace', 'lacing', 'perpendicular', 'slack']
senticnet['piping_crow'] = [-0.845, 0, 0.655, -0.851, '#sad', '#disgusting', -0.784, 'australian_magpie', 'butcherbird', 'currawong', 'bell_magpie', 'oscine']
senticnet['pique'] = [-0.133, 0.083, 0.682, -0.668, '#angry', '#disgusting', -0.467, 'frustrating', 'dun', 'crucify', 'bedevil', 'displeasingly']
senticnet['pirate'] = [0, 0, 0.034, -0.089, '#angry', '#disgusting', -0.041, 'lifeboat', 'mast', 'bad_man', 'keel', 'yacht']
senticnet['pirate_ship'] = [-0.065, -0.022, -0.054, -0.118, '#sad', '#disgusting', -0.072, 'radio_station', 'old_movie', 'movie', 'chinatown', 'military_base']
senticnet['pis_aller'] = [-0.973, 0, 0.84, -0.528, '#sad', '#angry', -0.78, 'expedient', 'last_resort', 'temporary_expedient', 'makeshift', 'stopgap']
senticnet['piss'] = [-0.063, 0, 0, -0.069, '#sad', '#disgusting', -0.044, 'relieve_oneself', 'make_coffee', 'go_toilet', 'go_pee', 'defecate']
senticnet['piss_off'] = [0, 0, 0.86, 0, '#angry', '#angry', -0.287, 'overwhelm', 'black_eye', 'die_painfully', 'feel_anger', 'punch_face']
senticnet['piss_pant'] = [-0.136, 0.133, -0.166, 0, '#sad', '#scared', -0.056, 'testify', 'give_testimony', 'disagree', 'give_verdict', 'give_word']
senticnet['pissed'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['pissed_off'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['pisser'] = [-0.531, 0, 0.508, -0.748, '#sad', '#disgusting', -0.596, 'bedwetter', 'bed_wetter', 'mortal', 'wetter', 'person']
senticnet['pistol'] = [0, 0, 0.731, -0.873, '#angry', '#disgusting', -0.535, 'rifle', 'gun', 'revolver', 'hydrogen_bomb', 'firearm']
senticnet['piston'] = [-0.758, 0, -0.751, -0.998, '#sad', '#disgusting', -0.836, 'tease', 'upset', 'lubricant', 'vaseline', 'upset_person']
senticnet['pitch'] = [0, 0, 0, 0.107, '#admirable', '#admirable', 0.036, 'detect', 'squeak', 'hear_noise', 'rattle', 'loud_soft']
senticnet['pitch_black'] = [-0.604, 0, 0.895, -0.541, '#sad', '#angry', -0.68, 'coal_black', 'jet_black', 'black', 'soot_black', 'achromatic_color']
senticnet['pitch_tent'] = [0, 0.075, 0, 0, '#interesting', '#interesting', 0.025, 'sleep_tent', 'hot_summer', 'close_together', 'group_object', 'blow_away']
senticnet['pitcher'] = [0, 0.075, 0, 0, '#interesting', '#interesting', 0.025, 'cup', 'carafe', 'container_cup', 'mug', 'glasses']
senticnet['pitchman'] = [-0.774, 0, 0.874, -0.803, '#angry', '#disgusting', -0.817, 'peddler', 'pedlar', 'packman', 'hawker', 'cheapjack']
senticnet['pitchy'] = [-0.7, 0, 0.617, -0.523, '#sad', '#angry', -0.613, 'silvery', 'blackish', 'bluish_black', 'hueless', 'achromatic']
senticnet['piteous'] = [-0.799, 0, 0, -0.722, '#sad', '#disgusting', -0.507, 'suffering', 'miserably', 'pitiable', 'hapless', 'pitiful']
senticnet['pith'] = [0, 0, 0.861, -0.816, '#angry', '#disgusting', -0.559, 'marrow', 'kernel', 'centre', 'core', 'substance']
senticnet['pithiness'] = [-0.666, 0, 0.812, -0.881, '#angry', '#disgusting', -0.786, 'laconism', 'laconicism', 'conciseness', 'concision', 'terseness']
senticnet['pitiable'] = [-0.866, 0, 0, -0.881, '#sad', '#disgusting', -0.582, 'suffering', 'miserably', 'piteous', 'hapless', 'pitiful']
senticnet['pitiful'] = [-0.866, 0, 0, -0.881, '#sad', '#disgusting', -0.582, 'suffering', 'miserably', 'pitiable', 'piteous', 'pitilessness']
senticnet['pitiless'] = [-0.795, 0, 0.691, -0.886, '#sad', '#disgusting', -0.791, 'cold', 'inhumane', 'cruel', 'fell', 'vicious']
senticnet['pitilessness'] = [0, 0, 0.809, -0.77, '#angry', '#disgusting', -0.526, 'mercilessness', 'unkind', 'ruthlessness', 'cruelly', 'unassertively']
senticnet['pittsburgh'] = [0, 0, 0.04, -0.042, '#angry', '#disgusting', -0.027, 'ore', 'alloy', 'titanium', 'iron', 'strong_material']
senticnet['pity'] = [-0.805, 0, 0.736, 0, '#sad', '#angry', -0.514, 'shame', 'compassion', 'commiseration', 'remorse', 'mercy']
senticnet['pixie'] = [-0.73, 0, 0.72, -0.936, '#sad', '#disgusting', -0.795, 'imp', 'elf', 'hob', 'gremlin', 'leprechaun']
senticnet['pizza_parlor'] = [0.06, -0.012, 0, 0, '#joyful', '#surprising', 0.024, 'eat_food', 'fast_food', 'restaurant', 'pizza_store', 'kitchen_cupboard']
senticnet['pizza_store'] = [0.06, -0.012, 0, 0, '#joyful', '#surprising', 0.024, 'eat_food', 'fast_food', 'pizza_parlor', 'restaurant', 'kitchen_cupboard']
senticnet['pizzeria'] = [0.068, 0.066, 0.011, -0.034, '#joyful', '#interesting', 0.03, 'trattoria', 'eat_pizza', 'italian_restaurant', 'restaurant_diner', 'eatery']
senticnet['placard'] = [0, 0.137, 0, 0.133, '#interesting', '#admirable', 0.09, 'sign', 'indication', 'post_notice', 'notice', 'red_octagon']
senticnet['placate'] = [0.649, -0.705, 0, 0.657, '#surprising', '#admirable', 0.67, 'tranquilize', 'tranquillize', 'calm_down', 'quieten', 'calm']
senticnet['placating'] = [-0.606, 0, 0.694, -0.651, '#angry', '#disgusting', -0.65, 'appeasing', 'conciliative', 'placative', 'placatory', 'pacific']
senticnet['placative'] = [-0.606, 0, 0.694, -0.651, '#angry', '#disgusting', -0.65, 'appeasing', 'placating', 'conciliative', 'placatory', 'pacific']
senticnet['placatory'] = [-0.606, 0, 0.694, -0.651, '#angry', '#disgusting', -0.65, 'appeasing', 'placating', 'placative', 'conciliative', 'pacific']
senticnet['place'] = [0.051, 0.092, 0.014, 0.148, '#interesting', '#admirable', 0.092, 'home', 'location', 'find_floor', 'area', 'big_place']
senticnet['place_bet'] = [0.047, 0.138, 0, 0.075, '#interesting', '#admirable', 0.087, 'competitive_spirit', 'down_payment', 'money', 'take_out_loan', 'bring_wallet']
senticnet['place_buy'] = [0, 0.14, 0.028, 0.157, '#interesting', '#admirable', 0.09, 'type_of_store', 'item_sell', 'many_shops', 'sell_stuff', 'math_answer']
senticnet['place_camp'] = [0, 0.069, 0, 0.122, '#interesting', '#admirable', 0.064, 'sand_rock', 'sandy', 'sea_shell', 'sand', 'seashell']
senticnet['place_chess_piece'] = [0.878, 0.707, 0, 0, '#joyful', '#interesting', 0.528, 'play_checker', 'cut_cheese', 'play_game_chess', 'play_chess', 'play_game']
senticnet['place_eat'] = [0.094, 0.084, 0.024, 0.062, '#joyful', '#interesting', 0.072, 'good_reastaurant', 'cafe', 'good_place_eat', 'eatery', 'pub']
senticnet['place_house'] = [0, 0.096, 0, 0.115, '#interesting', '#admirable', 0.07, 'part_of_building', 'architectural_structure', 'inside', 'live_quarter', 'small_building']
senticnet['place_learn'] = [0, 0, 0.04, -0.029, '#angry', '#disgusting', -0.023, 'educational_facility', 'educational_institution', 'bachelor_degree', 'educational_place', 'student_study']
senticnet['place_of_origin'] = [0.102, 0.142, -0.081, 0.224, '#interesting', '#admirable', 0.129, 'origin', 'from_here', 'travel', 'source', 'come_from']
senticnet['place_of_study'] = [-0.04, -0.013, 0.031, -0.054, '#sad', '#disgusting', -0.037, 'learning_place', 'student_place', 'educational_place', 'student_study', 'school_class']
senticnet['place_of_work'] = [0.87, 0.892, 0, 0, '#joyful', '#interesting', 0.587, 'get_around_town', 'get_place', 'sightsee', 'get_school', 'commute_work']
senticnet['place_of_worship'] = [0, 0, 0, 0.863, '#admirable', '#admirable', 0.288, 'worship_house', 'religious_build', 'worship_place', 'holy_place', 'church_part']
senticnet['place_order'] = [-0.039, 0, 0.018, -0.085, '#sad', '#disgusting', -0.047, 'decide_order', 'order_hamburger', 'order_fry', 'order_dinner', 'read_menu']
senticnet['place_sleep'] = [0.165, 0, 0.032, 0.114, '#joyful', '#admirable', 0.082, 'good_sleep', 'shut_eye', 'comfortable_place_sleep', 'use_bed', 'lie_down_bed']
senticnet['place_somewhere'] = [-0.029, 0.19, 0, 0.167, '#interesting', '#admirable', 0.109, 'gas_stove', 'beautiful_sunset', 'suspect', 'position', 'same']
senticnet['place_to_drink'] = [0.208, 0, 0.031, 0.063, '#joyful', '#admirable', 0.08, 'metal_stick', 'drinking_place', 'water_hole', 'hangout', 'open_night']
senticnet['place_to_live'] = [0.028, 0.083, 0, 0.123, '#interesting', '#admirable', 0.078, 'dwell_place', 'domestic_dwell', 'live_place', 'live_quarter', 'live_space']
senticnet['place_to_sit'] = [0.988, -0.795, 0, 0.65, '#joyful', '#surprising', 0.811, 'sit_place', 'sit_furniture', 'find_chair', 'bend_knee', 'chair']
senticnet['place_where_people_live'] = [0, 0.089, 0, 0.138, '#interesting', '#admirable', 0.076, 'domestic_dwell', 'small_building', 'live_place', 'live_quarter', 'dwell_place']
senticnet['place_work'] = [0.03, 0, 0, 0.071, '#joyful', '#admirable', 0.034, 'office', 'workplace', 'work_area', 'other_work', 'office_space']
senticnet['placement'] = [0, 0.098, 0.012, 0.276, '#interesting', '#admirable', 0.121, 'position', 'job', 'find_own_place_in_world', 'character_trait', 'place']
senticnet['placid'] = [0.553, 0.658, -0.251, 0.271, '#joyful', '#interesting', 0.41, 'placidly', 'unruffled', 'placidity', 'placidness', 'tranquil']
senticnet['placidity'] = [0.553, 0.658, -0.251, 0.271, '#joyful', '#interesting', 0.41, 'placid', 'placidly', 'unruffled', 'placidness', 'tranquil']
senticnet['placidly'] = [0.553, 0.658, -0.251, 0.271, '#joyful', '#interesting', 0.41, 'placid', 'unruffled', 'placidity', 'placidness', 'tranquil']
senticnet['placidness'] = [0.553, 0.658, -0.251, 0.271, '#joyful', '#interesting', 0.41, 'placid', 'placidly', 'unruffled', 'placidity', 'tranquil']
senticnet['plagiarism'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'unfaithful', 'cheat_partner', 'cheat_on', 'deceive', 'trick']
senticnet['plague'] = [0, 0, -0.813, -0.726, '#scared', '#disgusting', -0.513, 'chivvy', 'harass', 'provoke', 'molest', 'beset']
senticnet['plague_spot'] = [-0.662, 0, 0.911, -0.993, '#angry', '#disgusting', -0.855, 'liver_spot', 'spot', 'freckle', 'lentigo', 'macule']
senticnet['plaguy'] = [-0.211, 0.069, 0.654, -0.671, '#angry', '#disgusting', -0.489, 'torment', 'harassment', 'pissed', 'irritated', 'miffed']
senticnet['plain'] = [0, 0.264, -0.09, 0.135, '#interesting', '#admirable', 0.103, 'plain_bread', 'plain_rice', 'field', 'open_space', 'pasture']
senticnet['plain_bread'] = [0, 0.264, -0.09, 0.135, '#interesting', '#admirable', 0.103, 'plain', 'plain_rice', 'field', 'open_space', 'pasture']
senticnet['plain_rice'] = [0, 0.264, -0.09, 0.135, '#interesting', '#admirable', 0.103, 'plain_bread', 'plain', 'field', 'open_space', 'pasture']
senticnet['plain_sailing'] = [0.559, -0.758, 0, 0.52, '#joyful', '#surprising', 0.612, 'forward_motion', 'onward_motion', 'progression', 'procession', 'progress']
senticnet['plaint'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'grievance', 'accusation', 'allegation', 'lodgment', 'accuse']
senticnet['plaintive'] = [-0.9, 0.15, -0.621, 0.063, '#sad', '#scared', -0.436, 'dolor', 'pain', 'plaintively', 'plaintiveness', 'mournfully']
senticnet['plaintively'] = [-0.905, 0.141, -0.628, 0.07, '#sad', '#scared', -0.441, 'plaintiveness', 'woeful', 'woefulness', 'woebegone', 'deplorable']
senticnet['plaintiveness'] = [-0.905, 0.141, -0.628, 0.07, '#sad', '#scared', -0.441, 'plaintively', 'woeful', 'woefulness', 'woebegone', 'deplorable']
senticnet['plan'] = [-0.052, 0.29, -0.064, 0.158, '#interesting', '#admirable', 0.111, 'blueprint', 'forethought', 'decision', 'choice', 'idea']
senticnet['plan_advance'] = [-0.825, 0, 0, 0, '#sad', '#sad', -0.275, 'moolah', 'ask_money', 'bind_agreement', 'money_credit', 'bring_wallet']
senticnet['plan_ahead'] = [0, 0.812, 0, 0.802, '#interesting', '#admirable', 0.538, 'face_music', 'take_ticket', 'look_clock', 'complete_task', 'look_clue']
senticnet['plan_attack'] = [-0.129, -0.013, -0.045, -0.265, '#sad', '#disgusting', -0.142, 'buy_gun', 'find_enemy', 'fire_weapon', 'buy_weapon', 'alibi']
senticnet['plan_carefully'] = [0, 0.76, 0, 0.788, '#interesting', '#admirable', 0.516, 'suffocate', 'protect_oneself', 'kill_another_person', 'start_war', 'good_plan']
senticnet['plan_day'] = [-0.13, 0, 0, -0.05, '#sad', '#disgusting', -0.06, 'adjust_clothes', 'get_stick_traffic', 'rush_work', 'fly_plane', 'push_limit']
senticnet['plan_meal'] = [-0.052, 0.29, -0.064, 0.158, '#interesting', '#admirable', 0.111, 'plan', 'prepare_meal', 'prepare_food', 'meal', 'prepare_dinner']
senticnet['plan_meet'] = [0, 0.718, 0, 0.871, '#interesting', '#admirable', 0.53, 'hobby', 'intellectual_stimulation', 'exercise_mind', 'get_know', 'share_time']
senticnet['plan_of_attack'] = [0.878, -0.587, 0, 0.624, '#joyful', '#admirable', 0.696, 'framing', 'approach', 'attack', 'conceptualization', 'creating_by_mental_acts']
senticnet['plan_party'] = [0.814, 0, 0, 0, '#joyful', '#joyful', 0.271, 'experience_joy', 'lift_spirit', 'act_silly', 'think_funny', 'sense_joy']
senticnet['plan_retirement'] = [0, 0.718, 0, 0.871, '#interesting', '#admirable', 0.53, 'retirement', 'plan', 'happy_life', 'free_time', 'hobby']
senticnet['plan_route'] = [-0.084, 0, 0, 0, '#sad', '#sad', -0.028, 'turn_key', 'fasten_seat_belt', 'open_car_door', 'book_flight', 'turn_car_off']
senticnet['plan_terrorist_attack'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'make_terrorist_attack', 'terrorist', 'bomb', 'attack', 'terrorist_attack']
senticnet['plan_time'] = [-0.08, 0, 0.01, -0.062, '#sad', '#disgusting', -0.051, 'book_ticket', 'buy_airplane_ticket', 'purchase_ticket', 'talk_to_travel_agent', 'buy_plane_ticket']
senticnet['plan_trip'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'buy_airline_ticket', 'desire_social_interaction', 'see_different', 'proselytize', 'improve_knowledge']
senticnet['plan_vacation'] = [0.787, 0.833, 0, 0, '#joyful', '#interesting', 0.54, 'go_vacation', 'leave_country', 'go_somewhere', 'visit_other_country', 'go_pub']
senticnet['plan_wed'] = [0.7, 0.845, 0, 0, '#joyful', '#interesting', 0.515, 'trust_god', 'believe_god', 'kneel', 'belief_god', 'bicycle_across_town']
senticnet['plan_wedding'] = [-0.036, 0.284, -0.112, 0.211, '#interesting', '#admirable', 0.116, 'believe_god', 'trust_god', 'kneel', 'belief_god', 'wish']
senticnet['plane'] = [0.061, 0, 0.039, 0.097, '#joyful', '#admirable', 0.04, 'airplane', 'paper_plane', 'back_airplane', 'aircraft', 'bus']
senticnet['plane_figure'] = [0.831, -0.847, 0, 0.586, '#joyful', '#surprising', 0.755, 'oblong', 'star', 'heart', 'polygon', 'polygonal_shape']
senticnet['plane_land'] = [0, 0, 0, 0.095, '#admirable', '#admirable', 0.032, 'floss', 'station_wagon', 'land', 'empty_land', 'national']
senticnet['plane_ticket'] = [0, 0, 0, 0.095, '#admirable', '#admirable', 0.032, 'air_ticket', 'passenger_ticket', 'train_ticket', 'plane', 'travel']
senticnet['planet_earth'] = [0.045, 0, 0, 0.051, '#joyful', '#admirable', 0.032, 'perfect_sphere', 'pour_hot_coffee_mug', 'name_planet', 'alkaline', 'wrest']
senticnet['planet_solar_system'] = [0, 0, 0, 0.119, '#admirable', '#admirable', 0.04, 'planet', 'earth', 'spherical', 'hemisphere', 'terrain']
senticnet['plank'] = [0, -0.12, 0.057, 0.06, '#surprising', '#admirable', 0.041, 'hardwood', 'board', 'lumber', 'wood_plank', 'mahogany']
senticnet['plankton'] = [0, 0, -0.076, 0, '#scared', '#scared', -0.025, 'many_fishes', 'seahorse', 'starfish', 'porpoise', 'sea_wee']
senticnet['planless'] = [-0.997, 0, 0.658, -0.736, '#sad', '#disgusting', -0.797, 'adrift', 'afloat', 'aimless', 'directionless', 'purposeless']
senticnet['plant'] = [-0.96, 0, 0.651, -0.655, '#sad', '#disgusting', -0.755, 'still', 'wine_maker', 'winery', 'mint', 'bottling_plant']
senticnet['plant_animal'] = [0.054, 0, 0, 0.056, '#joyful', '#admirable', 0.037, 'animal_plant', 'fauna', 'live_organism', 'flora', 'grow_place']
senticnet['plant_big'] = [0, 0.1, -0.061, 0.126, '#interesting', '#admirable', 0.055, 'foliage', 'green_leave', 'green_growth', 'large_plant', 'plant_part']
senticnet['plant_crop'] = [0, 0.07, 0, 0.062, '#interesting', '#admirable', 0.044, 'grow_crop', 'raise_animal', 'crop_field', 'food_production', 'agriculture']
senticnet['plant_die'] = [-0.075, 0, -0.131, 0, '#sad', '#scared', -0.069, 'die', 'life_end', 'chest_pain', 'religious_fundamentalist', 'stop_breathe']
senticnet['plant_disease'] = [0.606, -0.504, 0, 0.795, '#joyful', '#admirable', 0.635, 'cotton_ball', 'pinkroot', 'disease', 'rust', 'scorch']
senticnet['plant_field'] = [0.026, 0.104, 0.013, 0.103, '#interesting', '#admirable', 0.073, 'vegetable_field', 'edible_plant', 'plant_ground', 'plant_food', 'agricultural']
senticnet['plant_flower'] = [0.067, 0.153, -0.054, 0.111, '#interesting', '#admirable', 0.092, 'small_flower', 'plant_yard', 'water_flower', 'plant_tree', 'garden_plant']
senticnet['plant_food'] = [0, 0.09, 0.033, 0.078, '#interesting', '#admirable', 0.045, 'farm_plant', 'grown_food', 'farm_vegetable', 'wheat_corn', 'agricultural']
senticnet['plant_garden'] = [0, -0.097, 0.035, 0.1, '#surprising', '#admirable', 0.054, 'dig_dirt', 'plant_flower', 'decorate_yard', 'cut_grass', 'grow_flower']
senticnet['plant_ground'] = [0, 0.108, 0.01, 0.112, '#interesting', '#admirable', 0.07, 'grow_place', 'vegetable_grow', 'plant_field', 'plant_place', 'vegetable_field']
senticnet['plant_grow'] = [0, 0.072, 0, 0, '#interesting', '#interesting', 0.024, 'tree_flower', 'vegetation', 'greenery', 'wee', 'many_plants']
senticnet['plant_life'] = [-0.835, 0, 0.531, -0.727, '#sad', '#disgusting', -0.698, 'poisonous_plant', 'escape', 'wilding', 'perennial', 'rock_plant']
senticnet['plant_material'] = [0.069, 0.112, 0, 0.167, '#interesting', '#admirable', 0.116, 'boll', 'clothes_material', 'natural_fiber', 'natural_fabric', 'fabric_type']
senticnet['plant_matter'] = [0.102, 0, 0, 0, '#joyful', '#joyful', 0.034, 'fresh_vegetable', 'cabbage', 'fruit_vegetable', 'cut_flower', 'fruit']
senticnet['plant_part'] = [0.02, 0, 0, 0.057, '#joyful', '#admirable', 0.026, 'large_plant', 'small_tree', 'tall_person', 'green_leave', 'leafy']
senticnet['plant_place'] = [0.027, 0.094, 0.017, 0.107, '#interesting', '#admirable', 0.07, 'plant_ground', 'grow_place', 'grass_area', 'vegetable_grow', 'vegetable_field']
senticnet['plant_product'] = [0, 0, 0.064, -0.04, '#angry', '#disgusting', -0.035, 'calyx', 'funiculus', 'bird_food', 'fuzz', 'agricultural_product']
senticnet['plant_seed'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'seed_plant', 'grow_flower', 'plant_garden', 'plant_flower', 'many_plants']
senticnet['plant_tree'] = [0.737, 0.787, 0, 0.915, '#interesting', '#admirable', 0.813, 'find_flower', 'shoe_horse', 'seed_lawn', 'blue_steel', 'dig_grave']
senticnet['plant_yard'] = [-0.025, 0.099, 0, 0.081, '#interesting', '#admirable', 0.052, 'grow_plant', 'plant_flower', 'like_flower', 'plant_ground', 'plant_place']
senticnet['plantation'] = [0, 0.095, 0.016, 0.106, '#interesting', '#admirable', 0.062, 'field_crop', 'vegetable_grow', 'grow_place', 'crop_place', 'grow_stuff']
senticnet['plaque'] = [-0.81, 0, 0.741, -0.763, '#sad', '#disgusting', -0.771, 'spot', 'amyloid_plaque', 'dentist', 'arterial_plaque', 'dental_plaque']
senticnet['plash'] = [-0.879, 0, 0.682, -0.533, '#sad', '#angry', -0.698, 'swash', 'spatter', 'splatter', 'slosh_around', 'sslosh_around']
senticnet['plasma'] = [0, 0.095, 0.016, 0.106, '#interesting', '#admirable', 0.062, 'blood_plasma', 'cytoplasm', 'germplasm', 'nucleoplasm', 'protoplasm']
senticnet['plastic'] = [0, 0, -0.811, -1.0, '#scared', '#disgusting', -0.604, 'charge_plate', 'fictile', 'charge_card', 'credit_card', 'moldable']
senticnet['plastic_bag'] = [0.095, 0, 0, 0, '#joyful', '#joyful', 0.032, 'shop_bag', 'coffee_cup', 'bag', 'plastic', 'store_shelf']
senticnet['plastic_bottle'] = [0.021, -0.067, 0, 0, '#joyful', '#surprising', 0.029, 'compress_air', 'party', 'use_party', 'lighter_air', 'ninja']
senticnet['plastic_container'] = [0.725, 0.901, 0, 0, '#joyful', '#interesting', 0.542, 'water', 'sweet_drink', 'beer', 'bottle_water', 'convenience_store']
senticnet['plastic_explosive'] = [-0.585, 0, 0.661, -0.954, '#angry', '#disgusting', -0.733, 'explosive', 'cordite', 'dynamite', 'explosive_compound', 'plastique']
senticnet['plastic_surgery'] = [0.96, -0.839, 0, 0.566, '#joyful', '#surprising', 0.788, 'lift', 'phalloplasty', 'abdominoplasty', 'tummy_tuck', 'autoplasty']
senticnet['plastique'] = [-0.585, 0, 0.661, -0.954, '#angry', '#disgusting', -0.733, 'explosive', 'cordite', 'dynamite', 'plastic_explosive', 'explosive_compound']
senticnet['plate_silverware'] = [0.855, 0, 0, 0.971, '#joyful', '#admirable', 0.609, 'good_meal', 'hot_table', 'special', 'chef_special', 'chopstick']
senticnet['platform_rail'] = [0.096, -0.017, 0, 0, '#joyful', '#surprising', 0.038, 'chain', 'rail', 'catwalk', 'column', 'token_turnstile']
senticnet['platonic_body'] = [0.829, -0.536, 0, 0.953, '#joyful', '#admirable', 0.773, 'regular_tetrahedron', 'cube', 'regular_hexahedron', 'regular_dodecahedron', 'regular_octahedron']
senticnet['platonic_solid'] = [0.82, -0.652, 0, 0.826, '#joyful', '#admirable', 0.766, 'regular_tetrahedron', 'cube', 'regular_hexahedron', 'regular_dodecahedron', 'regular_octahedron']
senticnet['plausibility'] = [0.943, -0.751, 0, 0.515, '#joyful', '#surprising', 0.736, 'reasonableness', 'tenability', 'tenableness', 'credibility', 'credibleness']
senticnet['plausibleness'] = [0.782, -0.575, 0, 0.648, '#joyful', '#admirable', 0.668, 'reasonableness', 'tenability', 'tenableness', 'credibility', 'credibleness']
senticnet['play'] = [0.942, -0.582, 0, 0.54, '#joyful', '#surprising', 0.688, 'theater_of_absurd', 'playlet', 'miracle_play', 'morality_play', 'mystery_play']
senticnet['play_area'] = [-0.038, 0.095, 0, 0.103, '#interesting', '#admirable', 0.053, 'play_surface', 'play_place', 'location', 'terrain', 'area']
senticnet['play_around'] = [-0.753, 0, 0.547, -0.787, '#sad', '#disgusting', -0.696, 'cheat_on', 'cuckold', 'wander', 'betray', 'cheat']
senticnet['play_baseball'] = [0.064, 0.203, 0.014, 0.202, '#interesting', '#admirable', 0.152, 'compete', 'compete_against', 'score_home_run', 'blue_ribbon', 'play_hockey']
senticnet['play_baseball_game'] = [0.958, 0, 0, 0.868, '#joyful', '#admirable', 0.609, 'play_team_sport', 'run_basis', 'step_up_plate', 'win_competition', 'play_dog']
senticnet['play_basketball'] = [0, -0.758, 0, 0.766, '#surprising', '#admirable', 0.508, 'play_rugby', 'hit_ball_hard', 'play_volleyball', 'run_basis', 'break_record']
senticnet['play_blackjack'] = [0.818, 0.913, 0, 0.825, '#interesting', '#admirable', 0.852, 'greeting', 'blackjack', 'pass_card', 'credit', 'magic_trick']
senticnet['play_board_game'] = [0.084, 0.075, 0, 0.107, '#joyful', '#admirable', 0.089, 'play_on_grass', 'spend_time_together', 'talk_oneself', 'become_adult', 'play_hide_seek']
senticnet['play_bowling'] = [0.054, 0.081, 0, 0.113, '#interesting', '#admirable', 0.083, 'throw_ball', 'play_game', 'catch_ball', 'play_baseball', 'play_basketball']
senticnet['play_by_ear'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'impromptu', 'improvise', 'natural', 'easy_going', 'spontaneous']
senticnet['play_card'] = [-0.034, 0.068, 0, 0.062, '#interesting', '#admirable', 0.032, 'play_game', 'play_poker', 'play_chess', 'play_game_chess', 'compete']
senticnet['play_card_game'] = [0.881, 0, 0, 0.741, '#joyful', '#admirable', 0.541, 'serve_dinner', 'sit_around', 'eat_cereal', 'eat_lot', 'eat_food']
senticnet['play_cards'] = [0.028, 0.171, -0.134, 0.321, '#interesting', '#admirable', 0.129, 'niceness', 'poker', 'poker_hand', 'win_bet', 'with_person']
senticnet['play_cat'] = [0.986, 0.924, 0, 0, '#joyful', '#interesting', 0.637, 'add_two_numbers', 'play', 'win_sport_event', 'delight_audience', 'find_hardware_store']
senticnet['play_catch'] = [0.987, 0, 0, 0.868, '#joyful', '#admirable', 0.618, 'bounce_up_down', 'entertain_child', 'amuse_child', 'add_two_numbers', 'play_fun']
senticnet['play_cd'] = [0.726, 0, 0, 0.933, '#joyful', '#admirable', 0.553, 'listen_cd', 'turn_on_radio', 'play_music', 'play_tune', 'music_album']
senticnet['play_checker'] = [0.993, 0.913, 0, 0, '#joyful', '#interesting', 0.635, 'cut_cheese', 'place_chess_piece', 'play_game_chess', 'play_chess', 'play_game']
senticnet['play_chess'] = [-0.049, 0.107, 0.017, 0.055, '#interesting', '#admirable', 0.032, 'play_game_chess', 'play_card', 'play_game', 'play_poker', 'compete']
senticnet['play_computer'] = [0.931, 0.938, 0, 0, '#joyful', '#interesting', 0.623, 'quiet_mind', 'experience_pleasure', 'miss_appointment', 'correct_mistake', 'sleep_bed']
senticnet['play_computer_game'] = [-0.148, 0, 0, -0.07, '#sad', '#disgusting', -0.073, 'train_open_mind', 'write_computer_program', 'erase_blackboard', 'lower_expectation', 'solve_equation']
senticnet['play_dead'] = [-0.038, 0.082, 0, 0.062, '#interesting', '#admirable', 0.035, 'pull_cart', 'group_animal', 'fun_around', 'jump_over_fence', 'max']
senticnet['play_device'] = [0.044, -0.059, 0.034, 0.079, '#surprising', '#admirable', 0.049, 'play_object', 'plaything', 'child_plaything', 'kid_game', 'kid_play']
senticnet['play_dog'] = [0.051, -0.077, 0.043, 0.055, '#surprising', '#admirable', 0.047, 'bounce', 'throw', 'play_catch', 'bounce_up_down', 'inflate']
senticnet['play_doll'] = [0.811, 0.758, 0, 0, '#joyful', '#interesting', 0.523, 'talk_oneself', 'go_moon', 'sleep_late', 'gain_respect', 'stay_touch_friend']
senticnet['play_down'] = [0.739, -0.764, 0, 0.977, '#surprising', '#admirable', 0.827, 'accent', 'stress', 'wave_off', 'emphasize', 'punctuate']
senticnet['play_fetch'] = [-0.026, 0, -0.064, 0, '#sad', '#scared', -0.03, 'run_lot', 'ride_car', 'chew_bone', 'play_human', 'stability']
senticnet['play_fiddle'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'play_instrument', 'fiddler', 'rock_out', 'pluck', 'read_music']
senticnet['play_fire'] = [0, 0, -0.849, -0.858, '#scared', '#disgusting', -0.569, 'start_flame_fire', 'make_campfire', 'light_fire', 'start_fire', 'strike_match']
senticnet['play_football'] = [0, 0.093, 0, 0.07, '#interesting', '#admirable', 0.054, 'dribble', 'football', 'play_team', 'play_game', 'play']
senticnet['play_friend'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'competition', 'recreation', 'play_game_together', 'fun_with_friend', 'friend']
senticnet['play_frisbee'] = [0.925, 0.993, 0, 0.832, '#joyful', '#interesting', 0.917, 'karaoke', 'dance', 'skate', 'jump_rope', 'dance_samba']
senticnet['play_fun'] = [0.987, 0, 0, 0.868, '#joyful', '#admirable', 0.618, 'bounce_up_down', 'entertain_child', 'play_catch', 'add_two_numbers', 'amuse_child']
senticnet['play_game'] = [0, -0.07, -0.047, 0.063, '#surprising', '#admirable', 0.029, 'yo-yo', 'playroom', 'game', 'backgammon', 'board_game']
senticnet['play_game_basketball'] = [0, 0, 0.079, 0, '#angry', '#angry', -0.026, 'dunk', 'judo', 'athletics', 'football', 'hockey']
senticnet['play_game_chess'] = [-0.045, 0.115, 0.012, 0.06, '#interesting', '#admirable', 0.039, 'play_chess', 'play_card', 'play_game', 'play_poker', 'compete']
senticnet['play_game_together'] = [0.068, 0, 0, 0.089, '#joyful', '#admirable', 0.052, 'hump_leg', 'tell_name', 'charisma', 'talkative', 'chat']
senticnet['play_golf'] = [0.989, 0.871, 0, 0.842, '#joyful', '#interesting', 0.901, 'plan_party', 'dance_music', 'become_adult', 'like_boy', 'drive_crazy']
senticnet['play_guitar'] = [-0.078, 0.271, -0.145, 0.343, '#interesting', '#admirable', 0.13, 'play_violin', 'play_piano', 'play_harp', 'fiddle', 'perform']
senticnet['play_hard'] = [-0.196, -0.004, -0.14, -0.099, '#sad', '#scared', -0.144, 'make_cry', 'wear_silly_hat', 'bring_joy', 'roll_ball', 'trade_baseball_card']
senticnet['play_harp'] = [-0.078, 0.271, -0.145, 0.343, '#interesting', '#admirable', 0.13, 'play_violin', 'play_piano', 'play_guitar', 'fiddle', 'perform']
senticnet['play_hide_seek'] = [0.927, 0.988, 0, 0, '#joyful', '#interesting', 0.638, 'play_on_grass', 'smoke_marijuana', 'rake_leave', 'juggle', 'play_board_game']
senticnet['play_hockey'] = [0.064, 0.203, 0.014, 0.202, '#interesting', '#admirable', 0.152, 'compete', 'compete_against', 'score_home_run', 'play_baseball', 'blue_ribbon']
senticnet['play_human'] = [0.11, 0, 0, 0.095, '#joyful', '#admirable', 0.068, 'play_fetch', 'ride_car', 'dog', 'chew_bone', 'run']
senticnet['play_in_band'] = [-0.038, 0.095, 0, 0.103, '#interesting', '#admirable', 0.053, 'music_band', 'play_music', 'play_tune', 'make_music', 'play_orchestra']
senticnet['play_in_theater'] = [-0.056, -0.013, -0.134, 0, '#sad', '#scared', -0.059, 'play_part', 'role_play', 'act_part', 'stage_play', 'play_role']
senticnet['play_indoors'] = [0, -0.09, 0.053, 0.075, '#surprising', '#admirable', 0.037, 'popular_sport_america', 'team_sport', 'ball_sport', 'popular_sport', 'popular_game']
senticnet['play_instrument'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'record_music', 'sound_beautiful', 'record_song', 'play_stringed_instrument', 'play_in_band']
senticnet['play_jack'] = [-0.039, -0.003, 0, -0.05, '#sad', '#disgusting', -0.029, 'salt_food', 'bone_chicken', 'brown_hamburger', 'heat_meal', 'gamblin']
senticnet['play_jazz'] = [0.812, 0, 0, 0.788, '#joyful', '#admirable', 0.533, 'blow_note', 'play_in_band', 'produce_musical_sound', 'play_tune', 'play_music']
senticnet['play_marble'] = [0, 0.119, 0.015, 0.165, '#interesting', '#admirable', 0.09, 'game_chess', 'many_games', 'billiards', 'chess', 'chess_game']
senticnet['play_match'] = [0.941, 0, 0, 0.865, '#joyful', '#admirable', 0.602, 'fire_light', 'match', 'explosion', 'firebomb', 'make_fire']
senticnet['play_music'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'play_orchestra', 'make_music', 'create_music', 'play_instrument', 'produce_musical_sound']
senticnet['play_musical_instrument'] = [0, -0.016, 0.038, -0.079, '#angry', '#disgusting', -0.034, 'give_performance', 'play_instrument', 'annoy_person', 'like_music', 'computer_software']
senticnet['play_object'] = [0.942, 0, 0, 0.994, '#joyful', '#admirable', 0.645, 'plaything', 'child_plaything', 'play_device', 'kid_play', 'kid_game']
senticnet['play_on_grass'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'play_game_together', 'play_football', 'play_game', 'play', 'enjoy_nature']
senticnet['play_orchestra'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'play_music', 'opera', 'create_music', 'orchestra', 'play_tune']
senticnet['play_outside'] = [-0.037, 0, -0.05, 0, '#sad', '#scared', -0.029, 'think_food', 'sense_fear', 'trust_friend', 'guide_blind_person', 'cause_accident']
senticnet['play_paint'] = [-0.098, 0, 0, -0.042, '#sad', '#disgusting', -0.047, 'play_on_grass', 'become_adult', 'play_hide_seek', 'finger_paint', 'like_boy']
senticnet['play_part'] = [0.76, 0, 0, 0.826, '#joyful', '#admirable', 0.529, 'act_part', 'part_of_play', 'role_play', 'part_of_movie', 'stage_play']
senticnet['play_person'] = [0, 0, 0, 0.068, '#admirable', '#admirable', 0.023, 'dark_corner', 'child_game', 'cast', 'role_play', 'part_of_play']
senticnet['play_piano'] = [0.773, 0.797, 0, 0.731, '#joyful', '#interesting', 0.767, 'perform_on_stage', 'play_violin', 'play_guitar', 'compose_music', 'listen_orchestra']
senticnet['play_ping_pong'] = [0.854, 0.773, 0, 0, '#joyful', '#interesting', 0.542, 'delight_audience', 'add_two_numbers', 'play_marble', 'stunt', 'like_boy']
senticnet['play_place'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'play_area', 'military_installation', 'kid_activity', 'location', 'playground']
senticnet['play_poker'] = [-0.034, 0.068, 0, 0.062, '#interesting', '#admirable', 0.032, 'play_game', 'play_card', 'play_chess', 'play_game_chess', 'compete']
senticnet['play_polo'] = [0.041, 0, 0, 0.084, '#joyful', '#admirable', 0.042, 'travel_place', 'busy', 'make_effort', 'carry_person', 'ride']
senticnet['play_pool'] = [0.844, 0.99, 0, 0, '#joyful', '#interesting', 0.611, 'play_board_game', 'amuse_child', 'drive_crazy', 'play_tag', 'lift_spirit']
senticnet['play_risiko'] = [-0.122, 0, 0, -0.059, '#sad', '#disgusting', -0.06, 'battle_illness', 'throw_fit', 'watch_d', 'sun_oneself', 'honor_parent']
senticnet['play_role'] = [0.863, 0, 0, 0.831, '#joyful', '#admirable', 0.565, 'play_part', 'act_part', 'act', 'role_play', 'part_of_play']
senticnet['play_rugby'] = [0, -0.758, 0, 0.766, '#surprising', '#admirable', 0.508, 'break_record', 'hit_ball_hard', 'play_volleyball', 'run_basis', 'play_basketball']
senticnet['play_rule'] = [0.038, -0.033, 0.089, -0.056, '#angry', '#disgusting', -0.025, 'win_money', 'gamble_money', 'winner_loser', 'win', 'win_game']
senticnet['play_saxophone'] = [0.744, 0.81, 0, 0, '#joyful', '#interesting', 0.518, 'change_tire', 'fix_flat_tire', 'lie_floor', 'desire_eat', 'eat_animal']
senticnet['play_snow'] = [0.988, 0.802, 0, 0, '#joyful', '#interesting', 0.597, 'make_gift', 'think_funny', 'make_someone_happy', 'enjoy_challenge', 'amuse_oneself']
senticnet['play_song'] = [0.988, 0.802, 0, 0, '#joyful', '#interesting', 0.597, 'create_music', 'perform_of_music', 'play_tune', 'play_music', 'produce_musical_sound']
senticnet['play_sport'] = [0.041, 0.086, 0.016, 0, '#joyful', '#interesting', 0.037, 'team', 'basketball_court', 'game', 'exercise', 'match']
senticnet['play_stringed_instrument'] = [0, -0.071, 0.094, -0.093, '#angry', '#disgusting', -0.039, 'make_music', 'create_music', 'play_music', 'annoy_neighbor', 'keep_beat']
senticnet['play_surface'] = [0, 0.123, 0.035, 0.121, '#interesting', '#admirable', 0.07, 'play_area', 'acreage', 'grassy_area', 'grassy', 'crop_place']
senticnet['play_tag'] = [-0.046, 0, 0, -0.099, '#sad', '#disgusting', -0.048, 'drive_crazy', 'become_adult', 'add_two_numbers', 'wear_silly_hat', 'roll_ball']
senticnet['play_tape'] = [0.96, -0.917, 0, 0, '#joyful', '#surprising', 0.626, 'pop_popcorn', 'turn_off', 'drink_soda', 'scrub_floor', 'pop_up']
senticnet['play_team'] = [0.896, 0.887, 0, 0.719, '#joyful', '#interesting', 0.834, 'win_sport_event', 'win_game', 'go_game', 'dribble', 'play_catch']
senticnet['play_team_sport'] = [0.877, 0.832, 0, 0.791, '#joyful', '#interesting', 0.833, 'enjoy_challenge', 'engage_sport', 'win_competition', 'game', 'enjoy_game']
senticnet['play_together'] = [0.047, 0, 0.025, 0.066, '#joyful', '#admirable', 0.029, 'musical_term', 'music_note', 'musical_note', 'guitar_string', 'musical_sound']
senticnet['play_trick'] = [-0.824, 0, 0.53, -0.889, '#sad', '#disgusting', -0.748, 'delude', 'deceive', 'cozen', 'snooker', 'lead_on']
senticnet['play_trick_on'] = [-0.66, 0, 0.771, -0.954, '#angry', '#disgusting', -0.795, 'delude', 'deceive', 'cozen', 'snooker', 'lead_on']
senticnet['play_tune'] = [0.047, 0, 0.025, 0.066, '#joyful', '#admirable', 0.029, 'perform_of_music', 'play_orchestra', 'create_music', 'produce_musical_sound', 'music']
senticnet['play_up'] = [0.985, -0.759, 0, 0.894, '#joyful', '#admirable', 0.879, 'cozy_up', 'cotton_up', 'shine_up', 'sidle_up', 'ingratiate']
senticnet['play_video_game'] = [0.896, 0.887, 0, 0.719, '#joyful', '#interesting', 0.834, 'play', 'video_game', 'turn_on_tv', 'buy_video_game', 'play_game']
senticnet['play_violin'] = [0.726, 0.785, 0, 0, '#joyful', '#interesting', 0.504, 'play_harp', 'play_piano', 'play_guitar', 'fiddle', 'perform']
senticnet['play_volleyball'] = [0.892, 0.761, 0, 0.7, '#joyful', '#interesting', 0.784, 'spring_action', 'learn_love_another', 'throw_fit', 'watch_d', 'sun_oneself']
senticnet['play_water'] = [0.063, -0.011, 0, 0, '#joyful', '#surprising', 0.025, 'play_marble', 'play_catch', 'bounce_up_down', 'add_two_numbers', 'amuse_child']
senticnet['player_piano'] = [-0.988, 0, 0.614, -0.905, '#sad', '#disgusting', -0.836, 'grand', 'upright', 'grand_piano', 'mechanical_piano', 'piano']
senticnet['playful'] = [0.582, -0.783, 0, 0.795, '#surprising', '#admirable', 0.72, 'elfish', 'elvish', 'kittenish', 'frisky', 'sportive']
senticnet['playful_mood'] = [-0.055, -0.009, 0.086, -0.184, '#angry', '#disgusting', -0.105, 'bad_mood', 'rain_forest', 'sadness', 'hole_ground', 'feel_down']
senticnet['playfulness'] = [0.918, 0.476, -0.197, 0.417, '#joyful', '#interesting', 0.538, 'merriment', 'cheery', 'gaiety', 'festal', 'plume']
senticnet['playground_equipment'] = [0.024, 0.152, -0.065, 0.236, '#interesting', '#admirable', 0.116, 'basketball_court', 'play_sport', 'tennis_game', 'squash_court', 'gymnasium']
senticnet['playroom'] = [0, -0.079, 0, 0, '#surprising', '#surprising', 0.026, 'yo-yo', 'pillow_fight', 'board_game', 'beanie_baby', 'action_figure']
senticnet['plea'] = [0.032, 0.276, -0.199, 0.427, '#interesting', '#admirable', 0.179, 'suggest', 'request', 'all_right', 'demand', 'politeness']
senticnet['plead'] = [0, 0, 0.829, -0.917, '#angry', '#disgusting', -0.582, 'conjure', 'appeal', 'beg', 'implore', 'pray']
senticnet['pleasant'] = [0.765, 0.804, 0, 0, '#joyful', '#interesting', 0.523, 'good', 'universal', 'nice', 'pleasurable', 'niceness']
senticnet['pleasant_emotion'] = [0.864, 0, 0, 0.739, '#joyful', '#admirable', 0.534, 'happy_emotion', 'happy_feeling', 'good_feeling', 'good_emotion', 'human_emotion']
senticnet['pleasant_experience'] = [0.825, 0.923, 0, 0.934, '#interesting', '#admirable', 0.894, 'happy', 'mentally_challenged', 'sit_sun', 'time_think', 'enjoy_beauty']
senticnet['pleasant_thought'] = [0.884, 0.888, 0, 0, '#joyful', '#interesting', 0.591, 'see_funny', 'unsettle', 'fall_asleep', 'laziness', 'happiness']
senticnet['pleasantness'] = [1, 0, 0, 0, '#joyful', '#joyful', 0.333, 'ecstasy', 'joy', 'mood', 'serenity', 'good_emotion']
senticnet['please'] = [0, 0.794, 0, 0.941, '#interesting', '#admirable', 0.578, 'need', 'similarity', 'kindness', 'demand', 'show_affection']
senticnet['please_eye'] = [0.133, 0.114, 0, 0.189, '#joyful', '#admirable', 0.145, 'home_improvement', 'pretty', 'decorative', 'decorate', 'visual']
senticnet['please_mother'] = [-0.152, 0, 0.079, -0.166, '#sad', '#disgusting', -0.132, 'cowardly', 'venomous', 'household_animal', 'immoral', 'home_animal']
senticnet['please_parent'] = [0, 0, 0, 0.895, '#admirable', '#admirable', 0.298, 'give_assistance', 'make_better_world', 'forgive', 'propose_woman', 'thank']
senticnet['please_person'] = [0.198, -0.228, -0.051, 0.262, '#surprising', '#admirable', 0.212, 'important_man', 'good_soul', 'sung', 'aphrodisiac', 'pleasant']
senticnet['please_teacher'] = [0.198, -0.228, -0.051, 0.262, '#surprising', '#admirable', 0.212, 'get_degree', 'pass_exam', 'learn_knowledge', 'become_educated', 'get_smart']
senticnet['pleased'] = [0.653, 0.635, -0.244, 0.294, '#joyful', '#interesting', 0.446, 'merrily', 'jubilantly', 'happily', 'mirthfully', 'gayly']
senticnet['pleasing'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'gratifyingly', 'satiable', 'satisfactorily', 'comforting', 'satisfyingly']
senticnet['pleasurable'] = [0.854, 0.81, 0, 0, '#joyful', '#interesting', 0.555, 'just_fun', 'universal', 'bourgeois', 'enjoyable', 'make_feel_happy']
senticnet['pleasure'] = [0.818, 0.76, 0, 0, '#joyful', '#interesting', 0.526, 'have_fun', 'enjoyment', 'enjoy_oneself', 'entertainment', 'social_bond']
senticnet['pleasure_garden'] = [0.962, 0, 0, 0, '#joyful', '#joyful', 0.321, 'marijuana', 'cannabis', 'trellis', 'mushroom', 'cabbage']
senticnet['pleasure_ground'] = [-0.726, 0, 0.978, -0.861, '#angry', '#disgusting', -0.855, 'amusement_park', 'funfair', 'commons', 'village_green', 'tract']
senticnet['plectognath'] = [-0.545, 0, 0.829, -0.725, '#angry', '#disgusting', -0.7, 'puffer', 'pufferfish', 'blowfish', 'triggerfish', 'filefish']
senticnet['plectognath_fish'] = [-0.753, 0, 0.838, -0.963, '#angry', '#disgusting', -0.851, 'puffer', 'pufferfish', 'blowfish', 'triggerfish', 'filefish']
senticnet['pledge'] = [0.066, 0.217, -0.197, 0.218, '#interesting', '#admirable', 0.101, 'form_government', 'united_country', 'type_of_government', 'political', 'unite']
senticnet['pledge_allegiance'] = [0.039, 0, 0, 0.053, '#joyful', '#admirable', 0.031, 'census', 'democratic_country', 'free_country', 'unite', 'big_country']
senticnet['plentiful'] = [-0.083, 0.168, -0.069, 0.189, '#interesting', '#admirable', 0.068, 'abundance', 'a_lot', 'fat', 'plenty', 'abundant']
senticnet['plenty'] = [0.073, 0.238, 0, 0.255, '#interesting', '#admirable', 0.189, 'a_lot', 'sufficient', 'abundant', 'large_amount', 'plentiful']
senticnet['plenty_rest'] = [0.093, 0, 0.015, 0.064, '#joyful', '#admirable', 0.047, 'practice_yoga', 'rest_tire', 'eat_well', 'sleep_sometimes', 'sleep']
senticnet['plenty_sleep'] = [0.13, 0.108, 0.034, 0.081, '#joyful', '#interesting', 0.095, 'knowledge_subject', 'review_material', 'know_truth', 'study_for_exam', 'choose_subject']
senticnet['plethora'] = [-0.775, 0, 0.9, -0.799, '#angry', '#disgusting', -0.825, 'embarrassment', 'fifth_wheel', 'deadwood', 'overplus', 'redundance']
senticnet['pleuropneumonia'] = [-0.926, 0, 0.824, -0.522, '#sad', '#angry', -0.757, 'bronchopneumonia', 'bronchial_pneumonia', 'viral_pneumonia', 'pneumonia', 'pneumococcal_pneumonia']
senticnet['pliability'] = [0.798, -0.612, 0, 0.899, '#joyful', '#admirable', 0.77, 'pliancy', 'pliantness', 'flexibility', 'flexibleness', 'suppleness']
senticnet['pliable'] = [0, 0, -0.806, -0.896, '#scared', '#disgusting', -0.567, 'fictile', 'malleable', 'tensile', 'ductile', 'pliant']
senticnet['plication'] = [0.767, -0.793, 0, 0.553, '#joyful', '#surprising', 0.704, 'angular_shape', 'angularity', 'ruck', 'pucker', 'pleat']
senticnet['pliers'] = [0.053, -0.067, 0, 0, '#joyful', '#surprising', 0.04, 'pair_of_scissors', 'c_clamp', 'tool_box', 'salad_shaker', 'ladle']
senticnet['plight'] = [-0.873, 0, 0.673, -0.553, '#sad', '#angry', -0.7, 'hot_water', 'difficulty', 'care', 'corner', 'box']
senticnet['plodding'] = [0, 0, -0.98, -0.801, '#scared', '#disgusting', -0.594, 'grind', 'footslog', 'donkeywork', 'slog', 'drudgery']
senticnet['plot'] = [-0.055, 0.163, -0.122, 0.136, '#interesting', '#admirable', 0.041, 'always_read', 'personality_trait', 'narrative', 'riddle', 'computer_type']
senticnet['ploughland'] = [-0.769, 0, 0.695, -0.785, '#sad', '#disgusting', -0.75, 'cultivated_land', 'farmland', 'plowland', 'fallow', 'tilled_land']
senticnet['plow'] = [-0.991, 0, 0.827, -0.541, '#sad', '#angry', -0.786, 'treat', 'cover', 'handle', 'theologize', 'deal']
senticnet['plow_field'] = [0, 0.076, 0, 0.107, '#interesting', '#admirable', 0.061, 'raise_animal', 'crop_field', 'plant_crop', 'grow_crop', 'raise_crop']
senticnet['plowland'] = [-0.769, 0, 0.695, -0.785, '#sad', '#disgusting', -0.75, 'cultivated_land', 'farmland', 'fallow', 'ploughland', 'tilled_land']
senticnet['pluck'] = [-0.834, 0, 0, -0.869, '#sad', '#disgusting', -0.568, 'remove', 'pull', 'pain', 'remove_hair', 'pluck_hair']
senticnet['pluck_hair'] = [-0.892, 0, 0, -0.737, '#sad', '#disgusting', -0.543, 'remove', 'pull', 'pain', 'remove_hair', 'pluck']
senticnet['pluck_string'] = [0, 0.076, 0, 0.107, '#interesting', '#admirable', 0.061, 'play_guitar', 'play_violin', 'play_harp', 'play_music', 'make_music']
senticnet['plug'] = [0, 0.922, 0, 0.863, '#interesting', '#admirable', 0.595, 'read_instruction_manual', 'find_tv', 'turn_television_set', 'find_tape', 'buy_tv']
senticnet['plum'] = [0, 0.076, 0, 0.107, '#interesting', '#admirable', 0.061, 'apricot', 'cranberry', 'prune', 'grapefruit', 'cherry']
senticnet['plume'] = [0.929, 0.507, -0.172, 0.396, '#joyful', '#interesting', 0.553, 'pridefulness', 'congratulate', 'smugness', 'smug', 'proudly']
senticnet['plump'] = [0, 0, -0.953, -0.711, '#scared', '#disgusting', -0.555, 'plank', 'plonk', 'flump', 'plop', 'plummet']
senticnet['plump_for'] = [0.793, -0.949, 0, 0.953, '#surprising', '#admirable', 0.898, 'okay', 'warrant', 'sanction', 'approve', 'champion']
senticnet['plunderage'] = [-0.518, 0, 0.717, -0.758, '#angry', '#disgusting', -0.664, 'raid', 'thieving', 'embezzlement', 'larceny', 'theft']
senticnet['plunge'] = [0.062, 0, 0.019, 0.073, '#joyful', '#admirable', 0.039, 'go_underwater', 'dive', 'save_someone_from_drowning', 'swim', 'get_boat']
senticnet['plunger'] = [0.883, 0.894, 0, 0, '#joyful', '#interesting', 0.592, 'separate_shower', 'electric_razor', 'shampoo_conditioner', 'bath_shower', 'tub']
senticnet['plunk_for'] = [0.566, -0.622, 0, 0.551, '#joyful', '#surprising', 0.58, 'okay', 'warrant', 'sanction', 'approve', 'champion']
senticnet['plural'] = [0.032, 0.109, -0.079, 0.085, '#interesting', '#admirable', 0.049, 'calve', 'kin', 'relate_person', 'younger', 'young_people']
senticnet['plus'] = [0, 0.273, -0.057, 0.388, '#interesting', '#admirable', 0.201, 'good', 'add', 'comparison', 'one_more', 'extra']
senticnet['pneumococcal_pneumonia'] = [-0.926, 0, 0.824, -0.522, '#sad', '#angry', -0.757, 'bronchopneumonia', 'bronchial_pneumonia', 'viral_pneumonia', 'pleuropneumonia', 'pneumonia']
senticnet['pneumonia'] = [-0.926, 0, 0.824, -0.522, '#sad', '#angry', -0.757, 'bronchopneumonia', 'bronchial_pneumonia', 'viral_pneumonia', 'pleuropneumonia', 'pneumococcal_pneumonia']
senticnet['pneumonic_plague'] = [-0.955, 0, 0.876, -0.895, '#sad', '#disgusting', -0.909, 'bubonic_plague', 'pestis_bubonica', 'glandular_plague', 'septicemic_plague', 'pestilence']
senticnet['pocket'] = [0, 0.092, 0, 0, '#interesting', '#interesting', 0.031, 'man_back_pocket', 'pant_back_pocket', 'back_pocket', 'purse', 'clothes_washer']
senticnet['pocket_flask'] = [0.619, -0.834, 0, 0.912, '#surprising', '#admirable', 0.788, 'hipflask', 'flask', 'ampulla', 'canteen', 'vacuum_flask']
senticnet['pocket_knife'] = [0.818, -0.956, 0, 0.695, '#joyful', '#surprising', 0.823, 'jackknife', 'clasp_knife', 'penknife', 'switchblade', 'switchblade_knife']
senticnet['pocket_money'] = [0.057, 0.181, -0.049, 0.18, '#interesting', '#admirable', 0.123, 'small_money', 'alter', 'money_change', 'money_coin', 'small_coin']
senticnet['pocket_notebook'] = [0, -0.041, 0.061, -0.092, '#angry', '#disgusting', -0.037, 'index_card', 'ring_binder', 'highlighter_pen', 'memo_pad', 'notepad']
senticnet['pocket_size_notebook'] = [0, -0.047, 0.072, -0.102, '#angry', '#disgusting', -0.042, 'notepad', 'memo_pad', 'self_adhesive_label', 'intern', 'paper_clip']
senticnet['pocket_veto'] = [-0.811, 0, 0.513, -0.715, '#sad', '#disgusting', -0.68, 'ballot', 'vote', 'voting', 'balloting', 'veto']
senticnet['pocket_watch'] = [0, 0.946, 0, 0.711, '#interesting', '#admirable', 0.552, 'watch', 'find_pawnshop', 'wristwatch', 'stopwatch', 'clock']
senticnet['pocketbook_issue'] = [0.648, -0.873, 0, 0.597, '#joyful', '#surprising', 0.706, 'gut_issue', 'content', 'paramount_issue', 'issue', 'quodlibet']
senticnet['pocketknife'] = [0.759, -0.654, 0, 0.716, '#joyful', '#admirable', 0.71, 'jackknife', 'clasp_knife', 'penknife', 'switchblade', 'switchblade_knife']
senticnet['podium'] = [-0.711, 0, -0.794, 0, '#sad', '#scared', -0.502, 'pulpit', 'stump', 'dais', 'ambo', 'rostrum']
senticnet['poem'] = [0.071, 0, -0.059, 0.108, '#joyful', '#admirable', 0.04, 'poetry', 'prose', 'verse', 'rhyme', 'poet']
senticnet['poet'] = [0.836, -0.602, 0, 0.845, '#joyful', '#admirable', 0.761, 'poetess', 'bard', 'elegist', 'odist', 'poet_laureate']
senticnet['poet_laureate'] = [0.836, -0.602, 0, 0.845, '#joyful', '#admirable', 0.761, 'poetess', 'bard', 'elegist', 'odist', 'poet']
senticnet['poetry'] = [0.088, 0, -0.047, 0.082, '#joyful', '#admirable', 0.041, 'prose', 'poem', 'scripture', 'verse', 'rhyme']
senticnet['point'] = [0.04, 0.074, 0.059, 0.092, '#interesting', '#admirable', 0.049, 'sharpness', 'sharp_end', 'edge', 'sharp_corner', 'sharp_edge']
senticnet['point_finger'] = [0.021, 0.179, -0.133, 0.164, '#interesting', '#admirable', 0.077, 'nod_head', 'nod', 'upgrade', 'ask', 'put_bid']
senticnet['point_in_time'] = [0.916, -0.785, 0, 0.829, '#joyful', '#admirable', 0.843, 'second', 'then', 'outset', 'starting_time', 'showtime']
senticnet['point_out'] = [-0.097, 0, 0, -0.102, '#sad', '#disgusting', -0.066, 'complete_sentence', 'help_another_person', 'report_crime', 'study_library', 'state_fact']
senticnet['point_time'] = [0, 0, -0.056, -0.067, '#scared', '#disgusting', -0.041, 'second_base', 'death_row', 'another_planet', 'loose_end', 'car_race']
senticnet['pointed'] = [0.766, 0, 0, 0.727, '#joyful', '#admirable', 0.498, 'charge', 'orient', 'indicate', 'designate', 'show']
senticnet['pointed_arch'] = [0.641, -0.569, 0, 0.748, '#joyful', '#admirable', 0.653, 'trefoil_arch', 'ogee_arch', 'keel_arch', 'drop_arch', 'arch']
senticnet['pointer'] = [0, 0.915, 0, 0.718, '#interesting', '#admirable', 0.544, 'secret_agent', 'like_mouse', 'indicator', 'underground_animal', 'critter']
senticnet['pointless'] = [0, -0.869, 0.992, -0.92, '#angry', '#disgusting', -0.348, 'futile', 'useless', 'small', 'embarrassment', 'insignificant']
senticnet['pointy'] = [0, 0.961, 0, 0.835, '#interesting', '#admirable', 0.599, 'sharp_nail', 'sharp', 'sharp_end', 'sharp_point', 'jag']
senticnet['pointy_ear'] = [0.028, 0, 0.013, 0.061, '#joyful', '#admirable', 0.025, 'paw', 'tail', 'fur_keep_warm', 'mane', 'claw']
senticnet['pointy_object'] = [0, -0.962, 0, 0.891, '#surprising', '#admirable', 0.618, 'pin_needle', 'without_space', 'pin', 'dart', 'blade']
senticnet['poised'] = [0, 0, -0.821, -0.729, '#scared', '#disgusting', -0.517, 'balance', 'equanimous', 'brace', 'collected', 'self-collected']
senticnet['poison'] = [0, 0, -0.798, 0, '#scared', '#scared', -0.266, 'strong_smell', 'shoot', 'nuclear_weapon', 'murder_weapon', 'lethal']
senticnet['poison_gas'] = [-0.903, 0, 0.529, -0.842, '#sad', '#disgusting', -0.758, 'nerve_gas', 'nerve_agent', 'mustard_gas', 'mustard_agent', 'blistering_agent']
senticnet['poison_ivy'] = [0, 0, -0.148, -0.036, '#scared', '#disgusting', -0.061, 'pine_cone', 'fallen_leaf', 'creeper', 'detritus', 'tress']
senticnet['poison_sumac'] = [-0.799, 0, 0.906, -0.671, '#sad', '#angry', -0.792, 'water_dropwort', 'hemlock_water_dropwort', 'water_hemlock', 'plant_life', 'poisonous_plant']
senticnet['poisoner'] = [-0.628, 0, 0.94, -0.998, '#angry', '#disgusting', -0.855, 'slayer', 'choker', 'mortal', 'executioner', 'public_executioner']
senticnet['poisoning'] = [-0.72, 0, 0.884, -0.758, '#angry', '#disgusting', -0.787, 'ergotism', 'paraquat_poisoning', 'alkali_poisoning', 'caffeinism', 'caffeine_intoxication']
senticnet['poisonous'] = [0, 0, -0.798, 0, '#scared', '#scared', -0.266, 'poison', 'poisonous_fly', 'dangerous', 'deadly', 'lethal']
senticnet['poisonous_fly'] = [-0.968, 0, 0.108, -0.908, '#sad', '#disgusting', -0.661, 'itchy_skin', 'dangerous_insect', 'dangerous_fly', 'dangerous_animal', 'poisonous']
senticnet['poisonous_human'] = [0.024, 0.088, 0, 0.123, '#interesting', '#admirable', 0.078, 'fauna', 'cultivate_yard', 'poisonous', 'organic', 'generic_name']
senticnet['poisonous_plant'] = [-0.799, 0, 0.906, -0.671, '#sad', '#angry', -0.792, 'water_dropwort', 'hemlock_water_dropwort', 'water_hemlock', 'plant_life', 'poison_sumac']
senticnet['poisonous_snake'] = [-0.028, -0.008, -0.052, -0.08, '#scared', '#disgusting', -0.051, 'red-bellied_black_snake', 'eastern_brown_snake', 'lizard', 'snake', 'shark']
senticnet['poke'] = [0, 0, 0.734, -0.995, '#angry', '#disgusting', -0.576, 'extension', 'reach_out', 'break_half', 'attach', 'grab']
senticnet['poke_pin'] = [0, 0, -0.979, -0.864, '#scared', '#disgusting', -0.614, 'bad_knee', 'physical_pain', 'broken_finger', 'earache', 'pain']
senticnet['poker_chip'] = [0, -0.887, 0, 0.751, '#surprising', '#admirable', 0.546, 'habit_form', 'card', 'bet', 'chance', 'letter']
senticnet['poker_face'] = [0.719, -0.58, 0, 0.739, '#joyful', '#admirable', 0.679, 'countenance', 'look', 'face', 'expression', 'aspect']
senticnet['poker_game'] = [0, 0.089, 0.01, 0.118, '#interesting', '#admirable', 0.066, 'crate', 'mom_house', 'sack', 'carrier', 'safekeep']
senticnet['poker_hand'] = [0.028, 0.171, -0.134, 0.321, '#interesting', '#admirable', 0.129, 'niceness', 'poker', 'play_cards', 'win_bet', 'with_person']
senticnet['pokey'] = [0.613, -0.874, 0, 0.789, '#surprising', '#admirable', 0.759, 'lockup', 'holding_cell', 'workhouse', 'bastille', 'hoosegow']
senticnet['poky'] = [0.521, -0.564, 0, 0.592, '#surprising', '#admirable', 0.559, 'lockup', 'holding_cell', 'workhouse', 'bastille', 'hoosegow']
senticnet['polar_bear'] = [0, 0, -0.828, -0.98, '#scared', '#disgusting', -0.603, 'animal', 'grizzly_bear', 'forest', 'creatures', 'brown_bear']
senticnet['polarize'] = [-0.083, 0.28, -0.084, 0.157, '#interesting', '#admirable', 0.09, 'brain_function', 'brain_activity', 'thoughtfulness', 'new_think', 'idea']
senticnet['pole'] = [0.912, 0.98, 0, 0, '#joyful', '#interesting', 0.631, 'metal_stick', 'wand', 'bart', 'big_stick', 'north']
senticnet['polecat'] = [-0.547, 0, 0.768, -0.503, '#sad', '#angry', -0.606, 'striped_skunk', 'hooded_skunk', 'hognosed_skunk', 'badger_skunk', 'rooter_skunk']
senticnet['police'] = [-0.829, 0, -0.916, 0, '#sad', '#scared', -0.582, 'policeman', 'type_of_criminal', 'authority', 'officer', 'rogue']
senticnet['police_car'] = [-0.027, 0, 0, -0.112, '#sad', '#disgusting', -0.046, 'car', 'ride_bicycle', 'traffic_cop', 'bomber', 'lorry']
senticnet['police_force'] = [0.632, -0.965, 0, 0.632, '#joyful', '#surprising', 0.743, 'police', 'law_enforcement_agency', 'constabulary', 'law', 'agency']
senticnet['police_man'] = [0, 0, -0.049, -0.074, '#scared', '#disgusting', -0.041, 'army_person', 'army_man', 'sergent', 'warrior', 'soldier']
senticnet['police_rank'] = [0.031, 0.079, 0, 0, '#joyful', '#interesting', 0.037, 'army_title', 'military_rank', 'head_guy', 'army_boss', 'high_rank']
senticnet['police_station'] = [0, 0, -0.059, -0.117, '#scared', '#disgusting', -0.059, 'military_base', 'wrong_place', 'battlefield', 'prisoner_war_camp', 'war_museum']
senticnet['police_work'] = [0, 0.164, -0.091, 0.129, '#interesting', '#admirable', 0.067, 'career', 'vocation', 'task', 'occupation', 'employ']
senticnet['policy'] = [0.028, 0.153, -0.055, 0.18, '#interesting', '#admirable', 0.102, 'nominate', 'administration', 'reign', 'order', 'regulation']
senticnet['polio'] = [-0.732, 0, 0.865, -0.878, '#angry', '#disgusting', -0.825, 'ill', 'sickness', 'illness', 'malady', 'ail']
senticnet['polish'] = [0, 0, 0, 0.1, '#admirable', '#admirable', 0.033, 'find_earth', 'wax', 'plutonium', 'worn_person', 'melt']
senticnet['polished'] = [0.577, -0.696, 0, 0.645, '#surprising', '#admirable', 0.639, 'shining', 'lustrous', 'shiny', 'bright', 'burnished']
senticnet['polite'] = [0.051, 0.109, -0.103, 0.107, '#interesting', '#admirable', 0.055, 'exchange_gift', 'courteous', 'courtesy', 'end_argument', 'amiable']
senticnet['polite_person'] = [0.051, -0.042, 0.016, 0, '#joyful', '#surprising', 0.026, 'man', 'workman', 'hippie', 'compatriot', 'long_haired_man']
senticnet['politeness'] = [0.102, 0.262, -0.247, 0.412, '#interesting', '#admirable', 0.176, 'good_behavior', 'courtesy', 'good_etiquette', 'courteous', 'please']
senticnet['political'] = [0, 0.802, 0, 0.874, '#interesting', '#admirable', 0.559, 'kingdom', 'aboriginal', 'socialism', 'feudalism', 'type_of_government']
senticnet['political_action'] = [0.793, 0.82, 0, 0, '#joyful', '#interesting', 0.538, 'presidential', 'go_against', 'anti', 'petition', 'campaign']
senticnet['political_body'] = [0.048, 0.28, -0.159, 0.254, '#interesting', '#admirable', 0.141, 'president', 'type_of_government', 'government_person', 'political_leader', 'govern']
senticnet['political_campaign'] = [-0.797, 0, 0.525, -0.635, '#sad', '#disgusting', -0.652, 'campaigning', 'candidacy', 'candidature', 'electioneering', 'whispering_campaign']
senticnet['political_debate'] = [0, 0.962, 0, 0.891, '#interesting', '#admirable', 0.618, 'berth', 'sleep_under', 'use_bed', 'slumber', 'bed']
senticnet['political_division'] = [0.05, 0.067, 0, 0.073, '#interesting', '#admirable', 0.063, 'political_unit', 'large_state', 'political_state', 'political_entity', 'united_country']
senticnet['political_entity'] = [0.044, 0.084, 0, 0.074, '#interesting', '#admirable', 0.067, 'political_unit', 'united_country', 'political_state', 'pledge_allegiance', 'democratic_country']
senticnet['political_figure'] = [0.038, 0.228, 0, 0.196, '#interesting', '#admirable', 0.154, 'government_official', 'religious_official', 'country_leader', 'pope', 'minister']
senticnet['political_leader'] = [0.034, 0.156, -0.059, 0.099, '#interesting', '#admirable', 0.077, 'state_head', 'politician', 'legislature', 'governor', 'country_leader']
senticnet['political_orientation'] = [0.729, -0.561, 0, 0.785, '#joyful', '#admirable', 0.692, 'ideology', 'militarism', 'warmongering', 'war_advocacy', 'hawkishness']
senticnet['political_party'] = [0.894, 0.993, 0, 0, '#joyful', '#interesting', 0.629, 'government_system', 'political_system', 'free_country', 'political_entity', 'democratic_country']
senticnet['political_rally'] = [0, 0.904, 0, 0.812, '#interesting', '#admirable', 0.572, 'hell', 'underworld', 'funeral', 'short_circuit', 'box_match']
senticnet['political_state'] = [0.053, 0.08, 0, 0.07, '#interesting', '#admirable', 0.068, 'political_unit', 'political_entity', 'united_country', 'large_state', 'political_division']
senticnet['political_statement'] = [0, 0.813, 0, 0.726, '#interesting', '#admirable', 0.513, 'go_against', 'anti', 'petition', 'picket', 'uprise']
senticnet['political_system'] = [0.045, 0.183, -0.075, 0.165, '#interesting', '#admirable', 0.106, 'government_system', 'form_government', 'united_country', 'political_entity', 'political_party']
senticnet['political_unit'] = [0.041, 0.067, 0, 0.065, '#interesting', '#admirable', 0.058, 'political_state', 'political_entity', 'political_division', 'united_country', 'large_state']
senticnet['politician'] = [0, 0.804, 0, 0.817, '#interesting', '#admirable', 0.54, 'country_leader', 'prime_minister', 'president', 'elect_official', 'leader']
senticnet['politics'] = [0.075, 0.216, -0.07, 0.11, '#interesting', '#admirable', 0.11, 'government', 'form_government', 'government_person', 'type_of_government', 'parliament']
senticnet['polka'] = [0.055, 0, 0.028, 0.101, '#joyful', '#admirable', 0.043, 'salsa', 'jitterbug', 'twist', 'dot', 'point']
senticnet['poll'] = [0, 0.178, -0.101, 0.193, '#interesting', '#admirable', 0.09, 'practical', 'survey', 'ballot', 'index_card_drawer', 'issue']
senticnet['pollinosis'] = [-0.606, 0, 0.931, -0.922, '#angry', '#disgusting', -0.82, 'rhinitis', 'coryza', 'hay_fever', 'allergic_rhinitis', 'hypersensitivity_reaction']
senticnet['pollute_air'] = [0, 0, 0.748, -0.758, '#angry', '#disgusting', -0.502, 'leave_out', 'feel_sick', 'screw_up', 'terminal_illness', 'cause_suffer']
senticnet['pollute_environment'] = [-0.174, -0.076, 0.023, -0.16, '#sad', '#disgusting', -0.094, 'run_out_gas', 'stop_red_light', 'stand_around', 'accident', 'shift_gear']
senticnet['polluted'] = [0, 0, -0.78, -0.988, '#scared', '#disgusting', -0.589, 'tired_leg', 'traveling_destination', 'get_sweaty', 'sweat_lot', 'little_pollution']
senticnet['polluted_air'] = [-0.92, 0, 0.917, -0.956, '#sad', '#disgusting', -0.931, 'ozone_hole', 'make_pollution', 'pollution', 'create_pollution', 'pollution_factory']
senticnet['pollution'] = [0, 0, 0, -0.087, '#disgusting', '#disgusting', -0.029, 'greenhouse_gas', 'smog', 'unhealthy', 'bad_habit', 'fog']
senticnet['pollution_factory'] = [-0.92, 0, 0.917, -0.956, '#sad', '#disgusting', -0.931, 'ozone_hole', 'polluted_air', 'pollution', 'create_pollution', 'make_pollution']
senticnet['polyarteritis'] = [-0.853, 0, 0.657, -0.868, '#sad', '#disgusting', -0.793, 'pulseless_disease', 'temporal_arteritis', 'rubor', 'redness', 'arteritis']
senticnet['polycystic_kidney_disease'] = [0.576, -0.572, 0, 0.768, '#joyful', '#admirable', 0.639, 'uropathy', 'polyuria', 'kidney_disease', 'renal_failure', 'kidney_failure']
senticnet['polydactyly'] = [-0.61, 0, 0.981, -0.523, '#sad', '#angry', -0.705, 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder', 'congenital_abnormality']
senticnet['polygamy'] = [-0.952, 0, 0, -0.73, '#sad', '#disgusting', -0.561, 'waste_time', 'fool_around', 'one_night_stand', 'make_fun', 'cheat']
senticnet['polygenic_disease'] = [0.504, -0.939, 0, 0.797, '#surprising', '#admirable', 0.747, 'diabetes', 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect']
senticnet['polygenic_disorder'] = [0.8, -0.685, 0, 0.921, '#joyful', '#admirable', 0.802, 'diabetes', 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect']
senticnet['polygon'] = [0, 0.722, 0, 0.942, '#interesting', '#admirable', 0.555, 'geometric_figure', 'parallelogram', 'geometrical_shape', 'geometric_shape', 'geometry_shape']
senticnet['polygonal_shape'] = [0.831, -0.847, 0, 0.586, '#joyful', '#surprising', 0.755, 'oblong', 'star', 'heart', 'polygon', 'plane_figure']
senticnet['polyhidrosis'] = [-0.584, 0, 0.773, -0.797, '#angry', '#disgusting', -0.718, 'perspiration', 'sweating', 'diaphoresis', 'sudation', 'hidrosis']
senticnet['polyneuritis'] = [-0.652, 0, 0.873, -0.637, '#sad', '#angry', -0.721, 'neuritis', 'multiple_neuritis', 'rubor', 'redness', 'inflammation']
senticnet['polysomy'] = [0.636, -0.922, 0, 0.636, '#joyful', '#surprising', 0.731, 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder', 'congenital_abnormality']
senticnet['ponder'] = [0, 0.107, 0.22, -0.196, '#angry', '#disgusting', -0.103, 'deceitful', 'crazy', 'tension', 'feel_small', 'make_decision']
senticnet['pondering'] = [0, 0.726, 0, 0.97, '#interesting', '#admirable', 0.565, 'ruminative', 'broody', 'contemplative', 'meditative', 'think']
senticnet['ponderosa'] = [-0.698, 0, 0.725, -0.89, '#angry', '#disgusting', -0.771, 'yellow_pine', 'plant', 'western_yellow_pine', 'bull_pine', 'longleaf_pine']
senticnet['ponderosa_pine'] = [-0.698, 0, 0.725, -0.89, '#angry', '#disgusting', -0.771, 'ponderosa', 'yellow_pine', 'western_yellow_pine', 'bull_pine', 'longleaf_pine']
senticnet['ponderousness'] = [-0.685, 0, 0.93, -0.852, '#angry', '#disgusting', -0.822, 'powerlessness', 'uninterestingness', 'impotence', 'impotency', 'dullness']
senticnet['pong'] = [-0.898, 0, 0.897, -0.676, '#sad', '#angry', -0.824, 'malodor', 'stench', 'stink', 'fetor', 'bad_smell']
senticnet['poo'] = [0.067, 0.068, 0, 0.09, '#interesting', '#admirable', 0.075, 'talk_oneself', 'learn_dance', 'avoid_pain', 'eat_spaghetti', 'eat_potato']
senticnet['poodle'] = [0.034, 0.074, 0, 0, '#joyful', '#interesting', 0.036, 'pet', 'retriever', 'most_cats', 'dog', 'pag']
senticnet['pool'] = [0, 0, 0, 0.964, '#admirable', '#admirable', 0.321, 'swimming_pool', 'swim', 'swimsuit', 'lake', 'have_fun']
senticnet['pool_hall'] = [0.103, 0, 0, 0, '#joyful', '#joyful', 0.034, 'restaurant', 'brewery', 'club', 'men_club', 'strip_club']
senticnet['pool_party'] = [0.755, 0.702, 0, 0, '#joyful', '#interesting', 0.486, 'take_leak', 'family_fun', 'pool', 'swim', 'go_underwater']
senticnet['poop'] = [-0.03, -0.017, -0.054, -0.121, '#scared', '#disgusting', -0.063, 'shit', 'wildflower', 'skink', 'wild_flower', 'dog_poop']
senticnet['poop_out'] = [0.891, -0.554, 0, 0.996, '#joyful', '#admirable', 0.814, 'weary', 'tire', 'jade', 'pall', 'fatigue']
senticnet['poor'] = [-0.561, 0, -0.493, -0.093, '#sad', '#scared', -0.382, 'lack', 'absence', 'poverty', 'emptiness', 'hunger']
senticnet['poor_as_church_mouse'] = [-0.962, 0, 0.705, -0.934, '#sad', '#disgusting', -0.867, 'poor', 'rare', 'mouse', 'poor_person', 'homeless']
senticnet['poor_english'] = [-0.958, 0, 0, -0.957, '#sad', '#disgusting', -0.638, 'mistake', 'error', 'grammar_mistake', 'misspell', 'bad_writing']
senticnet['poor_eyesight'] = [-0.246, -0.081, 0.03, -0.361, '#sad', '#disgusting', -0.185, 'criticize', 'time_waste', 'move_eye', 'learn', 'bad_vision']
senticnet['poor_fish'] = [-0.882, 0, 0.613, -0.617, '#sad', '#disgusting', -0.704, 'dunce', 'dunderhead', 'numskull', 'blockhead', 'bonehead']
senticnet['poor_health'] = [-0.3, -0.071, -0.222, -0.217, '#sad', '#scared', -0.223, 'feel_pain', 'experience_pain', 'schizophrenia', 'take_aspirin', 'ill_health']
senticnet['poor_people'] = [0.057, -0.038, 0, 0, '#joyful', '#surprising', 0.032, 'cheap_stuff', 'save_money', 'less_quality', 'occasions', 'discount_store']
senticnet['poor_person'] = [-0.05, 0, -0.11, -0.045, '#sad', '#scared', -0.068, 'doctor', 'doctor_surgery', 'inventor', 'sick_person', 'nurse']
senticnet['poor_quality'] = [-0.923, 0, 0.256, -0.986, '#sad', '#disgusting', -0.722, 'lousy', 'bad_quality', 'failure', 'low_quality', 'defective']
senticnet['poor_strategy'] = [-0.081, -0.031, 0.043, -0.124, '#sad', '#disgusting', -0.072, 'lose_game', 'bad_luck', 'lose', 'lose_focus', 'miss_point']
senticnet['poor_vision'] = [-0.746, 0, -0.95, 0, '#sad', '#scared', -0.565, 'two_arms', 'two_ears', 'hormone', 'adam_apple', 'nerve']
senticnet['poor_visual_perception'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'walking_stick', 'sunglasses', 'disabled', 'blind_person', 'vision_loss']
senticnet['poorly'] = [-0.229, 0.115, -0.201, 0.12, '#sad', '#scared', -0.065, 'get_back', 'concede', 'bad_grade', 'payoff', 'loss']
senticnet['poorness'] = [-0.617, 0, 0.694, -0.815, '#angry', '#disgusting', -0.709, 'destitution', 'deprivation', 'indigence', 'penury', 'pauperism']
senticnet['pop'] = [0.098, 0.103, -0.062, 0.134, '#interesting', '#admirable', 0.091, 'like_food', 'ethanol', 'foodstuff', 'bake_bean', 'mountain_dew']
senticnet['pop_balloon'] = [-0.102, -0.054, -0.119, 0, '#sad', '#scared', -0.056, 'scratch_back', 'knock_door', 'make_face', 'wave_hand', 'call_out']
senticnet['pop_group'] = [-0.507, 0, 0.902, -0.548, '#angry', '#disgusting', -0.652, 'gamelan', 'jug_band', 'ensemble', 'mariachi', 'skiffle_group']
senticnet['pop_music'] = [0.136, -0.092, 0.087, -0.033, '#joyful', '#surprising', 0.036, 'style_music', 'form_of_music', 'tune', 'rhythm', 'music']
senticnet['pop_popcorn'] = [-0.123, 0, 0, -0.08, '#sad', '#disgusting', -0.068, 'play_tape', 'scrub_floor', 'fill_bottle', 'arrive_work', 'train_open_mind']
senticnet['pop_quiz'] = [0, 0.761, 0, 0.711, '#interesting', '#admirable', 0.491, 'multiple_choices', 'final_exam', 'pass_fail', 'stressful', 'exam']
senticnet['pop_up'] = [-0.09, -0.049, 0.039, -0.24, '#sad', '#disgusting', -0.107, 'learn_new_idea', 'learn_quickly', 'point_out', 'look_picture', 'jot_down_note']
senticnet['popcorn'] = [0, -0.048, -0.052, -0.106, '#scared', '#disgusting', -0.037, 'projector', 'sticky_floor', 'usher', 'theater_ticket', 'movie_ticket']
senticnet['pope'] = [0.036, 0.219, 0, 0.19, '#interesting', '#admirable', 0.148, 'minister', 'evangelist', 'rector', 'parliament', 'goddess']
senticnet['popinjay'] = [-0.687, 0, 0.947, -0.839, '#angry', '#disgusting', -0.824, 'parrot', 'poll', 'bird', 'lovebird', 'amazon']
senticnet['poppy_seed'] = [0, -0.06, 0, 0.065, '#surprising', '#admirable', 0.042, 'doughnut', 'roll', 'custard', 'bread', 'biscuit']
senticnet['poppycock'] = [-0.785, 0, 0.92, -0.696, '#sad', '#angry', -0.8, 'meaninglessness', 'nonsense', 'bunk', 'nonsensicality', 'hokum']
senticnet['popular'] = [0, 0, 0, 0.882, '#admirable', '#admirable', 0.294, 'important', 'universal', 'vip', 'prestige', 'status']
senticnet['popular_building_material'] = [0, -0.011, 0.046, -0.052, '#angry', '#disgusting', -0.029, 'cement', 'tar', 'pavement', 'big_city_life', 'concrete']
senticnet['popular_food'] = [0.053, 0, 0.036, 0.069, '#joyful', '#admirable', 0.029, 'cereal_grain', 'japanese_food', 'tree_fruit', 'form_of_food', 'food_item']
senticnet['popular_game'] = [0, -0.072, 0, 0.092, '#surprising', '#admirable', 0.055, 'game_skill', 'popular_sport_america', 'rough_sport', 'team_sport', 'violent_sport']
senticnet['popular_hobby'] = [0.722, 0.961, 0, 0, '#joyful', '#interesting', 0.561, 'bible', 'bible_story', 'big_boat', 'song_lyric', 'walk_beach']
senticnet['popular_japan'] = [0.025, -0.189, 0.045, 0.251, '#surprising', '#admirable', 0.14, 'easy_tear', 'spherical', 'seen_night_sky', 'fill_with_sand', 'light_colored']
senticnet['popular_music'] = [0.133, -0.106, 0.06, 0, '#joyful', '#surprising', 0.06, 'classical', 'rap', 'form_of_music', 'rock_roll', 'style_music']
senticnet['popular_pet'] = [0, 0, 0, -0.873, '#disgusting', '#disgusting', -0.291, 'domestic_pet', 'common_pet', 'similar', 'nothing_special', 'common']
senticnet['popular_recreation'] = [0.701, -0.73, 0, 0, '#joyful', '#surprising', 0.477, 'trekking', 'exercise', 'exercise_regularly', 'moderation', 'nice_weather']
senticnet['popular_soda'] = [0.045, 0, -0.052, -0.08, '#scared', '#disgusting', -0.029, 'healthy_drink', 'cola', 'diuretic', 'beverage', 'soft_drink']
senticnet['popular_sport'] = [0, -0.071, 0.029, 0.09, '#surprising', '#admirable', 0.044, 'popular_sport_america', 'ball_sport', 'type_of_sport', 'team_sport', 'play_indoors']
senticnet['popular_sport_america'] = [0, -0.078, 0.017, 0.082, '#surprising', '#admirable', 0.048, 'ball_sport', 'team_sport', 'rough_sport', 'type_of_sport', 'rough_game']
senticnet['popular_unite_state'] = [0, 0, 0, 0.966, '#admirable', '#admirable', 0.322, 'full_air', 'spherical', 'use_sport', 'fill_with_sand', 'seen_night_sky']
senticnet['popular_vacation_destination'] = [0, 0.112, 0, 0.137, '#interesting', '#admirable', 0.083, 'maldives', 'near_ocean', 'land_feature', 'ocean_shore', 'oceanside']
senticnet['popularity'] = [0.882, 0, 0, 0.863, '#joyful', '#admirable', 0.582, 'have_fun', 'humor', 'attract_opposite_sex', 'happiness', 'feel_pleasure']
senticnet['populate'] = [0, 0.142, -0.061, 0.143, '#interesting', '#admirable', 0.075, 'own_lot', 'group_of_people', 'bird_group', 'asset', 'urban']
senticnet['populate_area'] = [0.089, 0, 0, 0.13, '#joyful', '#admirable', 0.073, 'metropolis', 'county', 'good_view', 'complex_structure', 'beautiful_place']
senticnet['population'] = [0.038, 0.073, 0, 0, '#joyful', '#interesting', 0.037, 'majority', 'bunch', 'multitude', 'colony', 'big_group']
senticnet['porcupine'] = [0, 0, -0.924, -0.909, '#scared', '#disgusting', -0.611, 'most_plants', 'plant', 'poisonous_plant', 'yellow_flower', 'lichen']
senticnet['pore'] = [0, 0, 0.019, -0.085, '#angry', '#disgusting', -0.035, 'worm_intestine', 'no_hair', 'fur_keep_warm', 'animal', 'whisker']
senticnet['poring_over'] = [0.572, -0.724, 0, 0.521, '#joyful', '#surprising', 0.606, 'browse', 'perusal', 'perusing', 'reading', 'studying']
senticnet['pork_butcher'] = [0.053, 0.085, 0.019, 0, '#joyful', '#interesting', 0.04, 'mexican_restaurant', 'spanish_restaurant', 'potato', 'french_restaurant', 'toxic_waste']
senticnet['porno'] = [0, -0.952, 0, 0.875, '#surprising', '#admirable', 0.609, 'vegetate', 'learn_entertainment', 'see_happen', 'find_out_information', 'keep_up_current_event']
senticnet['pornography'] = [0.971, 0.946, 0, 0, '#joyful', '#interesting', 0.639, 'ceiling_fan', 'tv_set', 'pay_tv', 'red_light_district', 'sexual_activity']
senticnet['porous'] = [0.703, 0, 0, 0.989, '#joyful', '#admirable', 0.564, 'tree_product', 'rectangular', 'wood_product', 'make_wood', 'flat_thin']
senticnet['porphyria'] = [-0.577, 0, 0.973, -0.843, '#angry', '#disgusting', -0.798, 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect', 'congenital_disease']
senticnet['porpoise'] = [0, 0, -0.076, 0, '#scared', '#scared', -0.025, 'many_fishes', 'seahorse', 'starfish', 'plankton', 'sea_wee']
senticnet['port'] = [-0.024, -0.022, 0.064, -0.071, '#angry', '#disgusting', -0.046, 'ocean_water', 'fillet_fish', 'chowder', 'fillet', 'underwater']
senticnet['porta'] = [-0.935, 0, 0.607, -0.67, '#sad', '#disgusting', -0.737, 'blowhole', 'stigma', 'orifice', 'opening', 'spiracle']
senticnet['portable'] = [0.194, 0.307, -0.109, 0.338, '#interesting', '#admirable', 0.243, 'hold_stuff', 'carry_around', 'tote', 'hold_up', 'take']
senticnet['portable_computer'] = [0.113, 0.073, 0.028, 0.107, '#joyful', '#admirable', 0.088, 'pda', 'telephone_computer', 'browser', 'number_pad', 'modem']
senticnet['portal'] = [0.02, 0, 0, 0.148, '#joyful', '#admirable', 0.056, 'build_open', 'home_entrance', 'house_open', 'house_front', 'aperture']
senticnet['portend'] = [-0.997, 0, -0.904, 0, '#sad', '#scared', -0.634, 'prognosticate', 'omen', 'bode', 'auspicate', 'presage']
senticnet['portent'] = [-0.75, 0, -0.718, 0, '#sad', '#scared', -0.489, 'prognostication', 'prognostic', 'presage', 'omen', 'prodigy']
senticnet['porticoed'] = [-0.659, 0, 0.878, -0.868, '#angry', '#disgusting', -0.802, 'amphistylar', 'amphiprostylar', 'amphiprostyle', 'apteral', 'prostyle']
senticnet['portrait'] = [0.036, 0.099, -0.055, 0.118, '#interesting', '#admirable', 0.066, 'wall_hang', 'like_paint', 'artwork', 'easel', 'painting']
senticnet['portray'] = [0.889, 0, 0, 0.742, '#joyful', '#admirable', 0.544, 'act', 'act_part', 'part_of_play', 'imitate', 'play_part']
senticnet['pose'] = [0.044, -0.644, 0, 0.38, '#surprising', '#admirable', 0.356, 'dumfounded', 'dumbstricken', 'mystify', 'baffle', 'dumbstruck']
senticnet['posh'] = [0.125, -0.147, 0, 0.286, '#surprising', '#admirable', 0.186, 'comfy', 'line_place', 'beautiful', 'delicate', 'big']
senticnet['position'] = [0.058, 0.184, 0, 0.21, '#interesting', '#admirable', 0.151, 'placement', 'administration', 'command', 'status', 'confirmation']
senticnet['position_furniture'] = [0.859, 0.906, 0, 0, '#joyful', '#interesting', 0.588, 'forward_email', 'stand_alone', 'deal_card_player', 'explain_everything', 'bridge_difference']
senticnet['positive'] = [0.572, 0.668, -0.341, 0.485, '#joyful', '#interesting', 0.461, 'adoration', 'esteem', 'encouragement', 'optimism', 'confidence']
senticnet['positive_attitude'] = [0.701, 0.874, 0, 0.752, '#interesting', '#admirable', 0.776, 'self_satisfaction', 'enjoy_life', 'good_feeling', 'good_attitude', 'enjoy']
senticnet['positive_fraud'] = [-0.914, 0, 0.85, -0.766, '#sad', '#angry', -0.843, 'fraud_in_fact', 'fraud', 'mail_fraud', 'swindle', 'rig']
senticnet['positive_reinforcement'] = [0.347, 0.348, -0.133, 0.394, '#interesting', '#admirable', 0.319, 'good_deed', 'benefit', 'gratification', 'self_respect', 'bonus']
senticnet['positive_reinforcer'] = [0.583, -0.826, 0, 0.574, '#joyful', '#surprising', 0.661, 'stimulant', 'positive_reinforcing_stimulus', 'reinforcer', 'negative_reinforcing_stimulus', 'negative_reinforcer']
senticnet['positive_reinforcing_stimulus'] = [0.583, -0.826, 0, 0.574, '#joyful', '#surprising', 0.661, 'stimulant', 'reinforcer', 'positive_reinforcer', 'negative_reinforcing_stimulus', 'negative_reinforcer']
senticnet['positive_stimulus'] = [0.588, -0.914, 0, 0.717, '#surprising', '#admirable', 0.74, 'fillip', 'joy', 'bonus', 'stimulant', 'delight']
senticnet['positively_charged'] = [0.626, -0.603, 0, 0.769, '#joyful', '#admirable', 0.666, 'positive', 'electropositive', 'charged', 'live', 'polar']
senticnet['possess'] = [0, 0.877, 0, 0.789, '#interesting', '#admirable', 0.555, 'have_something', 'own', 'owner', 'ownership', 'have']
senticnet['possession'] = [0.034, 0.229, -0.202, 0.316, '#interesting', '#admirable', 0.126, 'own', 'have_something', 'ownership', 'owner', 'possess']
senticnet['possessive'] = [-0.847, -0.894, -0.91, -0.911, '#scared', '#disgusting', -0.591, 'jealous', 'possessive_case', 'oppressive', 'stingy', 'selfish']
senticnet['possessive_case'] = [-0.967, 0, 0.845, -0.994, '#sad', '#disgusting', -0.935, 'judge', 'mental_problem', 'jealous', 'court', 'trial']
senticnet['possessiveness'] = [-0.5, 0, 0.939, -0.835, '#angry', '#disgusting', -0.758, 'avarice', 'covetousness', 'greed', 'desire', 'acquisitiveness']
senticnet['possibility'] = [0, 0.163, -0.099, 0.232, '#interesting', '#admirable', 0.099, 'random', 'unpredictable', 'unsure', 'possible', 'question_starter']
senticnet['possibility_to_die'] = [-0.969, 0, 0.172, -0.997, '#sad', '#disgusting', -0.713, 'severe_cold', 'cold', 'hypothermia', 'cold_winter', 'freeze']
senticnet['possible'] = [0, 0.163, -0.099, 0.232, '#interesting', '#admirable', 0.099, 'random', 'unpredictable', 'unsure', 'possibility', 'question_starter']
senticnet['possibleness'] = [-0.968, 0, 0.603, -0.915, '#sad', '#disgusting', -0.829, 'potential', 'potency', 'conceivableness', 'conceivability', 'achievability']
senticnet['post'] = [0, 0.885, 0, 0.931, '#interesting', '#admirable', 0.605, 'letter', 'message', 'parcel', 'snail_mail', 'announcement']
senticnet['post-it_note'] = [0.038, 0, 0, 0.097, '#joyful', '#admirable', 0.045, 'blank_check', 'glue_stick', 'address_book', 'ball_point_pen', 'paper_clip']
senticnet['post_doc'] = [0.846, -0.755, 0, 0.69, '#joyful', '#surprising', 0.764, 'experimenter', 'boffin', 'fieldworker', 'postdoc', 'investigator']
senticnet['post_letter'] = [0, 0.163, -0.099, 0.232, '#interesting', '#admirable', 0.099, 'receive_letter', 'receive_email', 'letter', 'post', 'postcard']
senticnet['post_message'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'send_email', 'display_image', 'access_internet', 'prepare_report', 'enter_data']
senticnet['post_note'] = [0, -0.046, 0.081, -0.078, '#angry', '#disgusting', -0.038, 'intern', 'white-out', 'post-it_note', 'letter_scale', 'paper_punch']
senticnet['post_notice'] = [0, 0, 0, 0.074, '#admirable', '#admirable', 0.025, 'placard', 'sign', 'banner', 'post', 'notice']
senticnet['postage'] = [0, 0, 0, 0.098, '#admirable', '#admirable', 0.033, 'send_mail', 'snail_mail', 'stamp', 'buy_stamp', 'put_envelope']
senticnet['postage_stamp'] = [0.058, -0.049, 0, 0, '#joyful', '#surprising', 0.036, 'letter_slot', 'envelope', 'pamphlet', 'mailman', 'address_label']
senticnet['postal_counter'] = [0.035, 0.076, 0, 0.067, '#interesting', '#admirable', 0.059, 'clutter', 'paperwork', 'coworker', 'white-out', 'stapler']
senticnet['postal_service'] = [0, 0.754, 0, 0.711, '#interesting', '#admirable', 0.488, 'send', 'mail_delivery', 'mail', 'delivery', 'package']
senticnet['postcard'] = [0.051, 0, 0, 0.072, '#joyful', '#admirable', 0.041, 'letter_slot', 'birthday_card', 'postage_stamp', 'icon', 'graphical_representation']
senticnet['poster_child'] = [0.994, -0.976, 0, 0.936, '#joyful', '#surprising', 0.969, 'child', 'small_fry', 'tyke', 'tike', 'kid']
senticnet['postiche'] = [-0.813, 0, 0.599, -0.677, '#sad', '#disgusting', -0.696, 'attire', 'garb', 'wig', 'dress', 'switch']
senticnet['postman'] = [0, 0, 0, 0.101, '#admirable', '#admirable', 0.034, 'mailman', 'package', 'mail', 'parcel', 'letter_slot']
senticnet['postmortem'] = [-0.643, 0, 0.684, -0.717, '#angry', '#disgusting', -0.681, 'consecutive', 'succeeding', 'ensuing', 'following', 'undermentioned']
senticnet['postpone'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'put_off', 'delay', 'retard', 'procrastination', 'lag']
senticnet['postpone_payment'] = [-0.05, 0.165, -0.054, 0.103, '#interesting', '#admirable', 0.055, 'cashless', 'buy_goods_service', 'debit', 'pay_goods', 'incur_debt']
senticnet['posttraumatic_stress_disorder'] = [-0.754, 0, 0.87, -0.514, '#sad', '#angry', -0.713, 'battle_fatigue', 'combat_fatigue', 'combat_neurosis', 'shell_shock', 'anxiety_disorder']
senticnet['postulate'] = [-0.662, 0, 0.813, -0.946, '#angry', '#disgusting', -0.807, 'demand', 'need', 'require', 'take', 'cry_for']
senticnet['posture'] = [0, 0.199, -0.114, 0.317, '#interesting', '#admirable', 0.134, 'body_language', 'gentleman', 'gesture', 'petition', 'take']
senticnet['posturing'] = [-0.845, 0, 0.969, -0.685, '#sad', '#angry', -0.833, 'conceitedness', 'swelled_head', 'egotism', 'boastfulness', 'vainglory']
senticnet['pot_marjoram'] = [0.632, -0.933, 0, 0.928, '#surprising', '#admirable', 0.831, 'herb', 'oregano', 'marjoram', 'origanum', 'wild_marjoram']
senticnet['pot_metal'] = [0.706, -0.941, 0, 0.622, '#joyful', '#surprising', 0.756, 'alloy_iron', 'alloy_cast_iron', 'cast_iron', 'iron', 'atomic_number_26']
senticnet['pot_roast'] = [0.797, -0.842, 0, 0, '#joyful', '#surprising', 0.546, 'make_flour', 'bake_bread', 'bake_food', 'bake', 'bake_cookie']
senticnet['potable'] = [0.795, -0.839, 0, 0.503, '#joyful', '#surprising', 0.712, 'smoothie', 'drinking_water', 'nutrient', 'milk', 'refresher']
senticnet['potable_liquid'] = [0.121, 0.113, -0.046, 0.114, '#joyful', '#admirable', 0.101, 'gulp', 'better_cold', 'sip', 'liquid_beverage', 'ingest']
senticnet['potato_fungus'] = [-0.872, 0, 0.723, -0.946, '#sad', '#disgusting', -0.847, 'potato_wart_fungus', 'bottom_rot_fungus', 'fungus', 'black_root_rot_fungus', 'sclerotinia']
senticnet['potato_wart_fungus'] = [-0.872, 0, 0.723, -0.946, '#sad', '#disgusting', -0.847, 'fungus', 'bottom_rot_fungus', 'potato_fungus', 'black_root_rot_fungus', 'sclerotinia']
senticnet['potency'] = [0.742, -0.927, 0, 0.564, '#joyful', '#surprising', 0.744, 'imperium', 'lordship', 'power_of_appointment', 'carte_blanche', 'command']
senticnet['potential_danger'] = [-0.873, -0.794, 0.729, -0.976, '#sad', '#disgusting', -0.595, 'radiation', 'cancer', 'sickness', 'electromagnetic_radiation', 'x_ray']
senticnet['potential_energy'] = [0, -0.809, 0, 0.822, '#surprising', '#admirable', 0.544, 'potential', 'radiation', 'electromagnetic_radiation', 'petroleum', 'kinetic_energy']
senticnet['potentiality'] = [0.554, -0.78, 0, 0.792, '#surprising', '#admirable', 0.709, 'prospect', 'chance', 'possibility', 'possibleness', 'latency']
senticnet['pother'] = [-0.692, 0, 0.768, -0.671, '#sad', '#angry', -0.71, 'dither', 'niggle', 'worry', 'flap', 'scruple']
senticnet['pothole'] = [0, -0.723, 0, 0.976, '#surprising', '#admirable', 0.566, 'american_flag', 'asphalt', 'rubble', 'pavement', 'pave']
senticnet['pothouse'] = [-0.769, 0, 0.75, -0.563, '#sad', '#angry', -0.694, 'public_house', 'pub', 'saloon', 'free_house', 'gin_mill']
senticnet['potter_field'] = [-0.501, 0, 0.762, -0.895, '#angry', '#disgusting', -0.719, 'cemetery', 'graveyard', 'burial_site', 'burial_ground', 'burying_ground']
senticnet['pottery'] = [0, 0, 0.07, 0, '#angry', '#angry', -0.023, 'price_product', 'demo', 'create_sound', 'music', 'create_new_idea']
senticnet['potty_chair'] = [0.778, -0.932, 0, 0.578, '#joyful', '#surprising', 0.763, 'flushless_toilet', 'flush_toilet', 'lavatory', 'potty_seat', 'commode']
senticnet['potty_seat'] = [0.778, -0.932, 0, 0.578, '#joyful', '#surprising', 0.763, 'flushless_toilet', 'flush_toilet', 'lavatory', 'commode', 'potty_chair']
senticnet['pouch'] = [0, 0, 0.036, -0.11, '#angry', '#disgusting', -0.049, 'credit_card_wallet', 'clutch_bag', 'checkbook_holder', 'checkbook_cover', 'coin_purse']
senticnet['poundal'] = [-0.641, 0, 0.678, -0.705, '#angry', '#disgusting', -0.675, 'pound', 'dyne', 'newton', 'sthene', 'force_unit']
senticnet['pour'] = [0, 0.084, -0.068, 0.156, '#interesting', '#admirable', 0.057, 'stream_ocean', 'reflect_image', 'pour_liquid', 'stream', 'evaporate']
senticnet['pour_hot_coffee_mug'] = [0, 0.953, 0, 0.998, '#interesting', '#admirable', 0.65, 'stuff_use_calculation', 'complete_thesis', 'written_programmer', 'speedo', 'voltage']
senticnet['pour_liquid'] = [0, 0.734, 0, 0.904, '#interesting', '#admirable', 0.546, 'move_liquid', 'hand_hold', 'fill_in_glass', 'pour', 'push']
senticnet['pour_water'] = [-0.057, 0, -0.07, 0, '#sad', '#scared', -0.042, 'wear_bath_suit', 'water_spill', 'malfunction', 'put_swimsuit', 'go_pool']
senticnet['pout'] = [-0.847, -0.894, -0.91, -0.911, '#scared', '#disgusting', -0.591, 'jealous', 'envious', 'enviously', 'covetously', 'jealously']
senticnet['poverty'] = [0, 0, 0, -0.979, '#disgusting', '#disgusting', -0.326, 'emotional_pain', 'get_fired', 'paper_cut', 'feel_bad', 'anguish']
senticnet['powderiness'] = [-0.643, 0, 0.835, -0.509, '#sad', '#angry', -0.662, 'sleekness', 'slickness', 'silkiness', 'smoothness', 'burnish']
senticnet['power'] = [0, 0.956, 0, 0.924, '#interesting', '#admirable', 0.627, 'force', 'like_electricity', 'increase_tax', 'form_of_energy', 'watt']
senticnet['power_drill'] = [0, 0.933, 0, 0.884, '#interesting', '#admirable', 0.606, 'air_pump', 'chisel', 'drill_bite', 'knife', 'screwdriver']
senticnet['power_electricity'] = [0.17, -0.01, 0, 0.184, '#joyful', '#admirable', 0.121, 'easy_use', 'hard_use', 'obsolete', 'expensive', 'just_fun']
senticnet['power_engine'] = [0.276, 0.207, -0.141, 0.123, '#joyful', '#interesting', 0.155, 'generate_heat', 'last_long_time', 'cool_room', 'warm_house', 'cool_house']
senticnet['power_gasoline'] = [0, 0.897, 0, 0.964, '#interesting', '#admirable', 0.62, 'sail_sea', 'stalin', 'power_engine', 'boat_part', 'expensive']
senticnet['power_of_appointment'] = [0.742, -0.927, 0, 0.564, '#joyful', '#surprising', 0.744, 'imperium', 'lordship', 'potency', 'carte_blanche', 'command']
senticnet['power_outage'] = [-0.309, -0.144, 0, -0.376, '#sad', '#disgusting', -0.18, 'stop_move', 'insomnia', 'become_unconscious', 'unconsciousness', 'slow_heart_beat']
senticnet['power_plant'] = [0, 0.714, 0, 0.821, '#interesting', '#admirable', 0.512, 'electrical', 'electric', 'static_electricity', 'electric_current', 'electrical_unit']
senticnet['power_screwdriver'] = [0, -0.978, 0, 0.847, '#surprising', '#admirable', 0.608, 'screwdriver', 'glass_front_display_cabinet', 'tool', 'paint', 'ratchet_screwdriver']
senticnet['power_source'] = [0, 0.889, 0, 0.849, '#interesting', '#admirable', 0.579, 'potential', 'generate_energy', 'electrical', 'power', 'potential_energy']
senticnet['power_supply'] = [0, -0.033, 0, 0.093, '#surprising', '#admirable', 0.042, 'work_well', 'internal_combustion_engine', 'broken_car', 'mode_transportation', 'machine']
senticnet['power_switch'] = [0, -0.026, 0, 0.061, '#surprising', '#admirable', 0.029, 'channel_selector', 'female_television_connector', 'speaker', 'tuner', 'handset']
senticnet['powerful'] = [0.862, 0, 0, 0.906, '#joyful', '#admirable', 0.589, 'good_quality', 'important', 'vitality', 'essential', 'capitalize']
senticnet['powerful_man'] = [0.099, 0, 0.019, 0.081, '#joyful', '#admirable', 0.054, 'boss', 'regal', 'royalty', 'elect_official', 'country_leader']
senticnet['powerless'] = [-0.95, 0, 0.708, -0.649, '#sad', '#angry', -0.769, 'helpless', 'incapacitated', 'feeble', 'weak', 'nerveless']
senticnet['powerlessness'] = [-0.652, 0, 0.64, -0.691, '#sad', '#disgusting', -0.661, 'impuissance', 'weakness', 'unpersuasiveness', 'uninterestingness', 'helplessness']
senticnet['practical'] = [0, 0.299, -0.163, 0.28, '#interesting', '#admirable', 0.139, 'thoughtful', 'identify', 'exclamation', 'tell_everyone', 'strong_feeling']
senticnet['practicality'] = [0.99, -0.88, 0, 0.831, '#joyful', '#surprising', 0.9, 'functionality', 'sensibleness', 'viability', 'usefulness', 'realism']
senticnet['practice'] = [-0.032, 0.114, 0, 0.111, '#interesting', '#admirable', 0.064, 'pass_ball', 'rehearse', 'know_rule', 'skill', 'determination']
senticnet['practice_bundling'] = [-0.621, 0, 0.944, -0.729, '#angry', '#disgusting', -0.765, 'catnap', 'sleep_late', 'sleep_in', 'rest', 'catch_some_z']
senticnet['practice_lot'] = [0.706, 0.809, 0, 0.632, '#joyful', '#interesting', 0.716, 'know_subject_well', 'read_book_subject', 'use_telescope', 'review_note', 'seek_info']
senticnet['practice_of_law'] = [0.54, -0.712, 0, 0.573, '#surprising', '#admirable', 0.608, 'learned_profession', 'medicine', 'theology', 'profession', 'law']
senticnet['practice_skill'] = [0.706, 0.809, 0, 0.632, '#joyful', '#interesting', 0.716, 'personal_enjoyment', 'develop_skill', 'waste_time', 'organize_information', 'surf_internet']
senticnet['practice_yoga'] = [0.738, 0, 0, 0, '#joyful', '#joyful', 0.246, 'eat_healthy_diet', 'live_good_life', 'accomplish_goal', 'eat_fruit', 'eat_banana']
senticnet['practise'] = [-0.138, -0.076, 0.05, -0.13, '#sad', '#disgusting', -0.081, 'try_best', 'loose', 'try_hard', 'strategize', 'sore_knee']
senticnet['prairie_fox'] = [-0.662, 0, 0.992, -0.726, '#angry', '#disgusting', -0.793, 'vixen', 'red_fox', 'kit_fox', 'fox', 'white_fox']
senticnet['praise'] = [0.765, 0, 0, 0.716, '#joyful', '#admirable', 0.494, 'compliment', 'trust', 'dogma', 'belief', 'freedom']
senticnet['praiseworthily'] = [0.575, 0.636, -0.268, 0.318, '#joyful', '#interesting', 0.42, 'laudably', 'admirably', 'commendable', 'look_up_to', 'admirable']
senticnet['prank'] = [0.584, -0.728, 0, 0.639, '#surprising', '#admirable', 0.65, 'folly', 'lunacy', 'craziness', 'indulgence', 'shtik']
senticnet['prate'] = [-0.875, 0, 0.838, -0.695, '#sad', '#angry', -0.803, 'blither', 'prattle', 'gibber', 'blabber', 'gabble']
senticnet['prattle'] = [-0.875, 0, 0.838, -0.695, '#sad', '#angry', -0.803, 'prate', 'blither', 'gibber', 'blabber', 'gabble']
senticnet['pray'] = [0, 0.194, -0.081, 0.239, '#interesting', '#admirable', 0.117, 'pray_god', 'belief_god', 'listen_sermon', 'religious_purpose', 'prayer']
senticnet['pray_god'] = [0, 0, 0, 0.817, '#admirable', '#admirable', 0.272, 'pray', 'belief_god', 'religious_purpose', 'faith', 'religious']
senticnet['prayer'] = [0.023, 0.295, -0.058, 0.283, '#interesting', '#admirable', 0.181, 'religion', 'religious_purpose', 'world_religion', 'gospel', 'judaism']
senticnet['preach'] = [0, 0, 0, 0.914, '#admirable', '#admirable', 0.305, 'superstition', 'religious_action', 'belief_god', 'believe_god', 'offer_solace']
senticnet['preacher'] = [0, 0, 0, 0.835, '#admirable', '#admirable', 0.278, 'church_head', 'priest', 'christian', 'protestant', 'pastor']
senticnet['precarious'] = [0, 0, -0.842, -0.92, '#scared', '#disgusting', -0.587, 'unstable', 'parlous', 'perilous', 'touch-and-go', 'shaky']
senticnet['precaution'] = [-0.795, 0, -0.835, 0, '#sad', '#scared', -0.543, 'care', 'look_after', 'demand', 'take_care', 'watch_over']
senticnet['preceding'] = [-0.569, 0, 0.954, -0.804, '#angry', '#disgusting', -0.776, 'previous', 'above', 'old', 'foregoing', 'introductory']
senticnet['precept'] = [0.841, -0.657, 0, 0.645, '#joyful', '#surprising', 0.714, 'moral_principle', 'rule', 'caveat_emptor', 'higher_law', 'hypothetical_imperative']
senticnet['precious'] = [0, 0.761, 0, 0.834, '#interesting', '#admirable', 0.532, 'valuable', 'costly', 'expensive', 'valued', 'special']
senticnet['precious_floor'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'floor', 'wood', 'hardwood', 'hardwood_floor', 'fancy_house']
senticnet['precious_gem'] = [0, -0.835, 0, 0.864, '#surprising', '#admirable', 0.566, 'expensive_stone', 'gem_stone', 'precious_stone', 'jewel', 'gem']
senticnet['precious_jewel'] = [0, -0.954, 0, 0.856, '#surprising', '#admirable', 0.603, 'solid', 'brown', 'red_stone', 'opaque', 'generic']
senticnet['precious_metal'] = [-0.04, -0.021, 0.027, -0.031, '#sad', '#disgusting', -0.026, 'many_different_kinds', 'olympic_medal', 'shiny_metal', 'bloodstone', 'valuable_metal']
senticnet['precious_stone'] = [0.037, 0.073, 0.027, 0.072, '#interesting', '#admirable', 0.052, 'sapphire', 'birth_stone', 'turquoise', 'gemstone', 'amethyst']
senticnet['precipitance'] = [-0.566, 0, 0.828, -0.689, '#angry', '#disgusting', -0.694, 'abruptness', 'precipitateness', 'precipitousness', 'hastiness', 'precipitancy']
senticnet['precipitancy'] = [-0.566, 0, 0.828, -0.689, '#angry', '#disgusting', -0.694, 'abruptness', 'precipitateness', 'precipitousness', 'precipitance', 'hastiness']
senticnet['precipitate'] = [-0.848, 0, 0.908, 0, '#sad', '#angry', -0.585, 'hasty', 'come_down', 'fall', 'overhasty', 'precipitant']
senticnet['precipitateness'] = [-0.566, 0, 0.828, -0.689, '#angry', '#disgusting', -0.694, 'abruptness', 'hastiness', 'precipitousness', 'precipitance', 'precipitancy']
senticnet['precipitous'] = [0, 0, 0, -0.783, '#disgusting', '#disgusting', -0.261, 'suddenly', 'sudden', 'immediate', 'unexpected', 'sudden_asthma_attack']
senticnet['precipitousness'] = [-0.566, 0, 0.828, -0.689, '#angry', '#disgusting', -0.694, 'abruptness', 'precipitateness', 'hastiness', 'precipitance', 'precipitancy']
senticnet['precise'] = [0, 0.203, -0.072, 0.198, '#interesting', '#admirable', 0.11, 'sharp', 'educated', 'swiss_watch', 'guilty_crime', 'capitalize']
senticnet['preciseness'] = [0.794, -0.523, 0, 0.794, '#joyful', '#admirable', 0.704, 'lucidness', 'clarity', 'clearness', 'lucidity', 'pellucidity']
senticnet['precision'] = [0, -0.821, 0, 0.844, '#surprising', '#admirable', 0.555, 'precise', 'accuracy', 'correct', 'performance', 'measure']
senticnet['preclude'] = [0.931, -0.637, 0, 0.989, '#joyful', '#admirable', 0.852, 'save', 'foil', 'spoil', 'frustrate', 'stymie']
senticnet['precocious_dentition'] = [-0.883, 0, 0.876, -0.844, '#sad', '#angry', -0.868, 'dentition', 'growth', 'growing', 'maturation', 'development']
senticnet['precognition'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'predict_future', 'psychic_phenomenon', 'parapsychology', 'clairvoyance', 'foreknowledge']
senticnet['preconception'] = [-0.531, 0, 0.967, -0.857, '#angry', '#disgusting', -0.785, 'opinion', 'sentiment', 'persuasion', 'thought', 'view']
senticnet['precondition'] = [-0.922, 0, 0.547, -0.984, '#sad', '#disgusting', -0.818, 'assumption', 'boundary_condition', 'provision', 'proviso', 'premiss']
senticnet['precursory'] = [-0.955, 0, 0.739, -0.599, '#sad', '#angry', -0.764, 'foreboding', 'prophetic', 'premonitory', 'apocalyptic', 'apocalyptical']
senticnet['predator'] = [0, 0, -0.071, 0, '#scared', '#scared', -0.024, 'reptile', 'animal', 'alligator', 'meat_eater', 'river']
senticnet['predestinarian'] = [-0.55, 0, 0.58, -0.982, '#angry', '#disgusting', -0.704, 'fatalist', 'determinist', 'necessitarian', 'predestinationist', 'philosopher']
senticnet['predestinationist'] = [-0.55, 0, 0.58, -0.982, '#angry', '#disgusting', -0.704, 'fatalist', 'determinist', 'predestinarian', 'necessitarian', 'philosopher']
senticnet['predetermine'] = [0.716, -0.718, 0, 0.736, '#surprising', '#admirable', 0.723, 'predestinate', 'foreordain', 'predestine', 'influence', 'preordain']
senticnet['predicament'] = [0, 0, -0.934, -0.97, '#scared', '#disgusting', -0.635, 'bad_situation', 'political_rally', 'tourist_site', 'dilemma', 'situation']
senticnet['predict'] = [0.048, 0.074, 0, 0, '#joyful', '#interesting', 0.041, 'prediction', 'rain_wind', 'stormy', 'climate', 'rainy']
senticnet['predict_weather'] = [-0.082, -0.019, 0.036, -0.108, '#sad', '#disgusting', -0.069, 'surf_internet', 'teach_computer', 'play_computer_game', 'write_computer_program', 'point_out']
senticnet['predictability'] = [-0.571, 0, 0.713, -0.649, '#angry', '#disgusting', -0.644, 'sure_thing', 'foregone_conclusion', 'certainty', 'determinateness', 'definiteness']
senticnet['prediction'] = [0.039, 0.298, -0.108, 0.233, '#interesting', '#admirable', 0.154, 'imaginary', 'predict', 'circumstance', 'weather_prediction', 'phenomenon']
senticnet['predilection'] = [0.558, 0.661, -0.271, 0.302, '#joyful', '#interesting', 0.417, 'penchant', 'well-disposed', 'friendliness', 'likeable', 'liking']
senticnet['predisposition'] = [0.98, -0.614, 0, 0.598, '#joyful', '#surprising', 0.731, 'diathesis', 'hypersensitivity', 'susceptibility', 'susceptibleness', 'habitus']
senticnet['predominate'] = [0.904, -0.695, 0, 0.758, '#joyful', '#admirable', 0.786, 'override', 'overarch', 'preponderate', 'outweigh', 'overbalance']
senticnet['preen'] = [0.789, 0.592, -0.209, 0.345, '#joyful', '#interesting', 0.506, 'complacent', 'self-satisfaction', 'self-complacency', 'complacence', 'self-complacent']
senticnet['prefer'] = [0.195, 0.409, -0.273, 0.448, '#interesting', '#admirable', 0.26, 'certainty', 'yearn', 'thoughtful', 'want_badly', 'similarity']
senticnet['preference'] = [0.57, 0.754, -0.325, 0.464, '#joyful', '#interesting', 0.488, 'esteem', 'optimism', 'anticipation', 'adoration', 'confidence']
senticnet['preform'] = [0.938, -0.874, 0, 0.992, '#joyful', '#admirable', 0.935, 'shape', 'form', 'work', 'mold', 'mould']
senticnet['pregnancy'] = [-0.752, 0, 0.715, -0.725, '#sad', '#disgusting', -0.731, 'abdominal_ectopic_gestation', 'ovarian_ectopic_gestation', 'tubal_ectopic_gestation', 'ectopic_gestation', 'gestation']
senticnet['pregnant'] = [0.746, 0.721, 0, 0, '#joyful', '#interesting', 0.489, 'make_love', 'find_woman', 'love_oneself', 'care_deeply', 'change_diaper']
senticnet['prehensile'] = [0.098, 0.084, 0.819, -0.682, '#angry', '#disgusting', -0.44, 'grasp', 'covet', 'covetousness', 'avaricious', 'grabby']
senticnet['prehistoric'] = [-0.874, 0, 0.83, -0.611, '#sad', '#angry', -0.772, 'out', 'dated', 'stodgy', 'unfashionable', 'antique']
senticnet['preist'] = [-0.078, 0.226, -0.137, 0.239, '#interesting', '#admirable', 0.083, 'evangelist', 'minister', 'rector', 'christian', 'church_head']
senticnet['prejudice'] = [-0.997, 0, 0, -0.949, '#sad', '#disgusting', -0.649, 'insanity', 'angry_emotion', 'dislike', 'psychosis', 'fight']
senticnet['prejure_oneself'] = [-0.723, 0, -0.731, 0, '#sad', '#scared', -0.485, 'forswear_oneself', 'fabricate', 'commit_perjury', 'misrepresent', 'prevaricate']
senticnet['preliminary_agreement'] = [0.026, 0.212, -0.105, 0.188, '#interesting', '#admirable', 0.107, 'compromise', 'accord', 'arrangement', 'deal', 'pact']
senticnet['preliterate'] = [-0.52, 0, 0.896, -0.763, '#angry', '#disgusting', -0.726, 'barbarous', 'primitive', 'savage', 'wild', 'noncivilized']
senticnet['premature_baby'] = [-0.514, 0, 0.747, -0.944, '#angry', '#disgusting', -0.735, 'stillborn_infant', 'neonate', 'preterm_baby', 'premature_infant', 'preterm_infant']
senticnet['premature_infant'] = [-0.514, 0, 0.747, -0.944, '#angry', '#disgusting', -0.735, 'stillborn_infant', 'premature_baby', 'preterm_baby', 'neonate', 'preterm_infant']
senticnet['premiss'] = [-0.922, 0, 0.547, -0.984, '#sad', '#disgusting', -0.818, 'assumption', 'boundary_condition', 'provision', 'proviso', 'precondition']
senticnet['premonition'] = [-0.768, 0, -0.739, 0, '#sad', '#scared', -0.502, 'boding', 'foreboding', 'presentiment', 'presage', 'timorous']
senticnet['premonitory'] = [-0.955, 0, 0.739, -0.599, '#sad', '#angry', -0.764, 'foreboding', 'precursory', 'prophetic', 'apocalyptic', 'apocalyptical']
senticnet['preparation'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'choose_subject', 'persistence', 'knowledge_subject', 'sign_up', 'review_material']
senticnet['prepare'] = [0, 0.973, 0, 0.907, '#interesting', '#admirable', 0.627, 'upgrade', 'effort', 'preparation', 'investigation', 'look_behind']
senticnet['prepare_army'] = [-0.901, 0, 0.092, -0.947, '#sad', '#disgusting', -0.647, 'war', 'fight_war', 'battle', 'wage_war', 'kill_person']
senticnet['prepare_breakfast'] = [-0.022, 0, 0.011, -0.036, '#sad', '#disgusting', -0.023, 'set_table', 'fix_breakfast', 'brown_hamburger', 'chop_vegetable', 'heat_meal']
senticnet['prepare_dinner'] = [0.937, 0, 0, 0.828, '#joyful', '#admirable', 0.588, 'create_meal', 'measure_ingredient', 'prepare_soup', 'prepare_table', 'make_toast']
senticnet['prepare_event'] = [-0.053, 0.141, 0.031, 0.079, '#interesting', '#admirable', 0.045, 'hard_work', 'produce_value', 'a_lot_of_work', 'accomplish', 'finish_work']
senticnet['prepare_exam'] = [0, -0.859, 0, 0.792, '#surprising', '#admirable', 0.55, 'get_degree', 'educate', 'get_education', 'get_smart', 'become_smart']
senticnet['prepare_fight'] = [-0.086, -0.078, 0.01, -0.201, '#sad', '#disgusting', -0.073, 'participate_sport', 'test_mettle', 'buy_gun', 'endurance', 'plan_attack']
senticnet['prepare_food'] = [0.032, -0.068, 0, 0, '#joyful', '#surprising', 0.033, 'bake_bread', 'food', 'make_flour', 'bake', 'bread']
senticnet['prepare_go_jail'] = [-0.138, 0.09, -0.079, -0.12, '#sad', '#disgusting', -0.082, 'seek_psychiatric_help', 'buy_weapon', 'consider_consequence', 'buy_gun', 'find_victim']
senticnet['prepare_ingredient'] = [0, -0.01, 0.014, -0.102, '#angry', '#disgusting', -0.035, 'burp', 'add_spice', 'say_grace', 'measure_ingredient', 'swallow_food']
senticnet['prepare_lesson'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'teach_student', 'make_presentation', 'presentation', 'explain_subject', 'use_computer']
senticnet['prepare_luggage'] = [-0.061, 0, 0.025, 0, '#sad', '#angry', -0.029, 'cook_dinner', 'make_bread', 'cook_meal', 'press_shirt', 'separate_egg']
senticnet['prepare_meal'] = [0.769, 0, 0, 0, '#joyful', '#joyful', 0.256, 'make_breakfast', 'enjoy_meal', 'put_food_into_mouth', 'appetite', 'prepare_breakfast']
senticnet['prepare_report'] = [-0.072, -0.04, 0.094, -0.073, '#angry', '#disgusting', -0.066, 'move_mouse', 'surf_internet', 'increase_efficiency', 'type_of_keyboard', 'train_open_mind']
senticnet['prepare_snack'] = [-0.05, -0.025, 0.013, -0.049, '#sad', '#disgusting', -0.029, 'make_pot_coffee', 'play_pool', 'make_mess', 'meet_another_person', 'drink_tea']
senticnet['prepare_soup'] = [0.937, 0, 0, 0.828, '#joyful', '#admirable', 0.588, 'prepare_dinner', 'measure_ingredient', 'create_meal', 'prepare_table', 'make_toast']
senticnet['prepare_supper'] = [-0.08, 0, 0, 0, '#sad', '#sad', -0.027, 'needy', 'come_house', 'quiet_child', 'soup', 'salt_food']
senticnet['prepare_table'] = [0.937, 0, 0, 0.828, '#joyful', '#admirable', 0.588, 'prepare_dinner', 'measure_ingredient', 'prepare_soup', 'create_meal', 'make_toast']
senticnet['prepare_test'] = [-0.14, -0.023, 0, -0.131, '#sad', '#disgusting', -0.083, 'pass_exam', 'please_teacher', 'study_test', 'pass_test', 'learn_fact']
senticnet['prepared'] = [0.801, -0.575, 0, 0.947, '#joyful', '#admirable', 0.774, 'precooked', 'equipped', 'fitted_out', 'embattled', 'spread']
senticnet['preparedness'] = [0.025, 0.237, -0.073, 0.297, '#interesting', '#admirable', 0.162, 'ready', 'inclusion', 'get_ready', 'born_ready', 'never_fail']
senticnet['prerequisite'] = [0.695, -0.856, 0, 0.501, '#joyful', '#surprising', 0.684, 'essential_condition', 'sine_qua_non', 'responsibility', 'precondition', 'academic_requirement']
senticnet['presage'] = [-0.968, 0, 0, -0.931, '#sad', '#disgusting', -0.633, 'boding', 'premonition', 'presentiment', 'foreboding', 'trepidly']
senticnet['presbyopia'] = [-0.85, 0, 0.781, -0.956, '#sad', '#disgusting', -0.862, 'farsightedness', 'hyperopia', 'hypermetropia', 'hypermetropy', 'longsightedness']
senticnet['prescription'] = [0.039, 0, -0.07, -0.113, '#scared', '#disgusting', -0.048, 'narcotic', 'sleep_drug', 'analgesic', 'medicine', 'palliative']
senticnet['prescription_medication'] = [0, -0.076, 0.11, -0.1, '#angry', '#disgusting', -0.045, 'sachet', 'lingerie', 'pantyhose', 'underwear', 'panties']
senticnet['presence'] = [0, 0.928, 0, 0.831, '#interesting', '#admirable', 0.586, 'feel_presence', 'instant', 'person', 'make_effort', 'currently']
senticnet['presence_of_mind'] = [0.937, -0.799, 0, 0.634, '#joyful', '#surprising', 0.79, 'resoluteness', 'firmness_of_purpose', 'firmness', 'resolve', 'will_power']
senticnet['presenile_dementia'] = [-0.947, 0, 0.821, -0.756, '#sad', '#angry', -0.841, 'dementedness', 'insanity', 'senile_dementia', 'senile_psychosis', 'alcoholic_dementia']
senticnet['present'] = [0, 0.857, 0, 0.716, '#interesting', '#admirable', 0.524, 'birthday_gift', 'surprise', 'gift', 'birthday', 'holiday']
senticnet['present_award'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'star_movie', 'win_award', 'star_film', 'recite_poem', 'knock_door']
senticnet['present_bill'] = [-0.705, 0, 0.925, 0, '#sad', '#angry', -0.543, 'receive_paycheck', 'car_break_down', 'car_crash', 'dig_ground', 'work']
senticnet['present_play'] = [0, -0.896, 0, 0.874, '#surprising', '#admirable', 0.59, 'show_play', 'perform_play', 'stage_play', 'drama', 'performance']
senticnet['present_times'] = [0.86, -0.794, 0, 0.93, '#joyful', '#admirable', 0.861, 'modern_times', 'time', 'modern_world', 'contemporary_world', 'period']
senticnet['presentation'] = [0, -0.74, 0, 0.821, '#surprising', '#admirable', 0.52, 'show_how', 'lecture', 'impression', 'show', 'projector']
senticnet['presentiment'] = [-0.827, 0, 0, -0.938, '#sad', '#disgusting', -0.588, 'boding', 'foreboding', 'premonition', 'presage', 'timorous']
senticnet['preservation'] = [-0.973, 0, 0.885, -0.976, '#sad', '#disgusting', -0.945, 'protection', 'conservation', 'environmentalism', 'reservation', 'immobilization']
senticnet['preservative'] = [0.03, 0, 0, 0.076, '#joyful', '#admirable', 0.035, 'food_ingredient', 'white_grain', 'granulate', 'white_powder', 'flavor']
senticnet['preserve'] = [0, 0.243, -0.119, 0.201, '#interesting', '#admirable', 0.108, 'upkeep', 'contain', 'keep_safe', 'keep', 'prevent']
senticnet['preserve_food'] = [0.04, 0, 0, 0.067, '#joyful', '#admirable', 0.036, 'find_plant', 'court_action', 'add_flavor', 'ingredient', 'sell_grocery_store']
senticnet['preserved'] = [0.789, -0.58, 0, 0.715, '#joyful', '#admirable', 0.695, 'desiccated', 'aged', 'lyophilized', 'cured', 'candied']
senticnet['president'] = [0.917, 0.812, 0, 0, '#joyful', '#interesting', 0.576, 'supervisor', 'chief', 'leader', 'ambassador', 'commander']
senticnet['president_united_states'] = [0.025, 0.127, -0.054, 0.076, '#interesting', '#admirable', 0.058, 'prime_minister', 'country_leader', 'elect_official', 'ceo', 'officer']
senticnet['presidential'] = [0, 0.251, -0.157, 0.296, '#interesting', '#admirable', 0.13, 'democratic_process', 'elect_president', 'elect', 'nominate', 'selection']
senticnet['presidential_election'] = [0, 0.88, 0, 0.876, '#interesting', '#admirable', 0.585, 'good_man', 'soldier', 'war', 'civil_war', 'find_enemy']
senticnet['press'] = [0, 0.726, 0, 0.898, '#interesting', '#admirable', 0.541, 'compression', 'push_hard', 'print_newspaper', 'journalist', 'make_newspaper']
senticnet['press_accelerator'] = [-0.081, -0.026, 0, -0.092, '#sad', '#disgusting', -0.049, 'travel_quickly', 'arrive_late', 'traffic_accident', 'get_lose', 'get_plane']
senticnet['press_brake'] = [-0.08, -0.075, 0.054, -0.171, '#sad', '#disgusting', -0.077, 'use_brake', 'stop_stop_sign', 'shift_gear', 'stop_red_light', 'turn_steer_wheel']
senticnet['press_button'] = [-0.091, 0, 0.064, -0.061, '#sad', '#angry', -0.072, 'deduce', 'revelation', 'look_clue', 'look_behind', 'get_answer']
senticnet['press_enter'] = [0, 0.101, 0.039, 0.054, '#interesting', '#admirable', 0.039, 'wipe_tear', 'smear', 'smudge', 'push_button', 'scratch_back']
senticnet['press_key'] = [-0.042, 0, 0.098, -0.072, '#angry', '#disgusting', -0.071, 'move_finger', 'sit_bench', 'loose_track_time', 'tune_instrument', 'pluck_string']
senticnet['press_play'] = [-0.094, 0, 0, -0.136, '#sad', '#disgusting', -0.077, 'insert_dvd_in_player', 'view_film', 'turn_on_dvd_player', 'use_remote_control', 'rewind']
senticnet['press_shirt'] = [-0.061, 0, 0.025, 0, '#sad', '#angry', -0.029, 'cook_dinner', 'make_bread', 'cook_meal', 'prepare_luggage', 'separate_egg']
senticnet['pressure'] = [-0.124, 0, -0.113, -0.032, '#sad', '#scared', -0.09, 'breeze', 'move_air', 'air_movement', 'gape', 'blown']
senticnet['pressure_go_away'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'relaxation', 'feel_relieved', 'feel_released', 'feel_relief', 'more_easy_life']
senticnet['pressure_level'] = [-0.623, 0, 0.901, -0.715, '#angry', '#disgusting', -0.746, 'pressure', 'hypertonicity', 'hypotonicity', 'osmotic_pressure', 'force_per_unit_area']
senticnet['prestidigitator'] = [0.605, -0.65, 0, 0.961, '#surprising', '#admirable', 0.739, 'escapologist', 'escape_expert', 'mind_reader', 'telepathist', 'performer']
senticnet['prestige'] = [0.254, 0.188, -0.082, 0.203, '#joyful', '#admirable', 0.188, 'honor', 'popular', 'designation', 'high_class', 'champion']
senticnet['presumption'] = [-0.694, 0, 0.806, -0.742, '#angry', '#disgusting', -0.747, 'hypothesis', 'theory', 'base', 'possibility', 'supposal']
senticnet['presuppose'] = [0.863, -0.947, 0, 0.986, '#surprising', '#admirable', 0.932, 'postulate', 'posit', 'assume', 'presume', 'take_for_granted']
senticnet['pretence'] = [-0.562, 0, 0.505, -0.953, '#sad', '#disgusting', -0.673, 'unnaturalness', 'artificiality', 'pretension', 'staginess', 'theatricality']
senticnet['pretend'] = [-0.95, 0, 0.557, -0.668, '#sad', '#disgusting', -0.725, 'pretence', 'feigning', 'pretense', 'pretending', 'simulation']
senticnet['pretending'] = [-0.617, 0, 0.9, -0.56, '#sad', '#angry', -0.692, 'deceit', 'deception', 'dissembling', 'affectedness', 'pose']
senticnet['pretense'] = [-0.988, 0, 0.537, -0.721, '#sad', '#disgusting', -0.749, 'deceit', 'deception', 'dissembling', 'affectedness', 'pose']
senticnet['pretension'] = [-0.562, 0, 0.505, -0.953, '#sad', '#disgusting', -0.673, 'unnaturalness', 'pretence', 'artificiality', 'staginess', 'theatricality']
senticnet['pretentious'] = [0.596, -0.815, 0, 0.767, '#surprising', '#admirable', 0.726, 'inflated', 'hifalutin', 'snooty', 'highfalutin', 'portentous']
senticnet['preterm_baby'] = [-0.514, 0, 0.747, -0.944, '#angry', '#disgusting', -0.735, 'stillborn_infant', 'premature_baby', 'neonate', 'premature_infant', 'preterm_infant']
senticnet['preterm_infant'] = [-0.514, 0, 0.747, -0.944, '#angry', '#disgusting', -0.735, 'stillborn_infant', 'premature_baby', 'preterm_baby', 'premature_infant', 'neonate']
senticnet['pretermit'] = [-0.926, 0, 0.743, -0.563, '#sad', '#angry', -0.744, 'miss', 'neglect', 'overlook', 'drop', 'pass_over']
senticnet['pretext'] = [-0.618, 0, 0.817, -0.78, '#angry', '#disgusting', -0.738, 'pretence', 'feigning', 'dissembling', 'pretense', 'putoff']
senticnet['prettify'] = [0.928, -0.516, 0, 0.924, '#joyful', '#admirable', 0.789, 'suit', 'better', 'improve', 'look_better', 'meliorate']
senticnet['pretty'] = [0.812, 0.984, 0, 0.838, '#interesting', '#admirable', 0.878, 'beautiful', 'elegant', 'nice_look', 'beauty', 'please_eye']
senticnet['pretty_flower'] = [0.105, 0.214, -0.169, 0.178, '#interesting', '#admirable', 0.109, 'blossom', 'bloom', 'sign_love', 'flower_type', 'symbol_love']
senticnet['pretty_girl'] = [0, 0.098, 0, 0.107, '#interesting', '#admirable', 0.068, 'interjection', 'beautiful_woman', 'policy', 'traffic_cop', 'adjust_seat']
senticnet['pretty_woman'] = [0.789, 0.979, 0, 0, '#joyful', '#interesting', 0.589, 'gorgeous', 'nice_look', 'good_look', 'belle', 'sophisticated']
senticnet['pretzel'] = [0.274, -0.015, 0.012, 0.132, '#joyful', '#admirable', 0.136, 'dance_type', 'swirl', 'throw_football', 'jump_around', 'dance_move']
senticnet['prevail'] = [0.564, -0.547, 0, 0.663, '#joyful', '#admirable', 0.591, 'override', 'overarch', 'preponderate', 'outweigh', 'overbalance']
senticnet['prevaricate'] = [-0.811, 0, -0.797, 0, '#sad', '#scared', -0.536, 'forswear_oneself', 'fabricate', 'prejure_oneself', 'misrepresent', 'commit_perjury']
senticnet['prevarication'] = [0.68, -0.861, 0, 0.72, '#surprising', '#admirable', 0.754, 'whopper', 'white_lie', 'jactitation', 'walloper', 'fib']
senticnet['prevaricator'] = [-0.633, 0, 0.88, -0.941, '#angry', '#disgusting', -0.818, 'beguiler', 'slicker', 'perjurer', 'false_witness', 'storyteller']
senticnet['prevent'] = [0, 0.266, -0.124, 0.303, '#interesting', '#admirable', 0.148, 'keep', 'upkeep', 'bring', 'hold_onto', 'hold']
senticnet['prevent_accident'] = [0.822, 0.86, 0, 0.751, '#joyful', '#interesting', 0.811, 'drive_safe', 'take_nap', 'go_slow', 'feel_little_tired', 'rest_dream']
senticnet['prevent_cavity'] = [-0.159, -0.06, 0, -0.081, '#sad', '#disgusting', -0.06, 'go_dentist', 'miss_appointment', 'snore', 'jump_off_bridge', 'unplug']
senticnet['prevent_conception'] = [0.11, 0.209, 0, 0.238, '#interesting', '#admirable', 0.186, 'use_condom', 'abstinence', 'never_go_out', 'gnaw', 'choke']
senticnet['prevent_dandruff'] = [0.702, 0, 0, 0.703, '#joyful', '#admirable', 0.468, 'sculpt_gel', 'dandruff_shampoo', 'hair_care_article', 'get_clean', 'hair_conditioner']
senticnet['prevent_disease'] = [0.078, 0, 0, 0.074, '#joyful', '#admirable', 0.051, 'remove_dirt_body', 'smell_better', 'feel_clean', 'smell_nice', 'ensure_proper_hygiene']
senticnet['prevent_pregnancy'] = [0, 0, 0, 0.752, '#admirable', '#admirable', 0.251, 'avoid_pregnancy', 'contraception', 'safe_sex', 'sex', 'sexual_excitement']
senticnet['prevent_stress'] = [0.036, 0.232, -0.057, 0.192, '#interesting', '#admirable', 0.134, 'well_deigned', 'comfortable', 'useful', 'ergonomic_chair', 'ergonomic_pillow']
senticnet['prevent_sunburn'] = [0, 0, -0.701, -0.895, '#scared', '#disgusting', -0.532, 'protect_head', 'wave_wind', 'keep_hair_place', 'brightness', 'cover_head']
senticnet['previous'] = [0, 0.084, 0, 0.094, '#interesting', '#admirable', 0.059, 'calendar_event', 'never_end', 'time_period', 'time_length', 'time_frame']
senticnet['prevision'] = [-0.5, 0, 0.775, -0.873, '#angry', '#disgusting', -0.716, 'farsightedness', 'knowing', 'apprehension', 'savvy', 'discernment']
senticnet['prey'] = [0, 0.749, 0, 0.807, '#interesting', '#admirable', 0.519, 'insect', 'fly_away', 'small_insect', 'maggot', 'chihuahua']
senticnet['price'] = [0, 0.219, -0.05, 0.144, '#interesting', '#admirable', 0.104, 'value_for_money', 'value', 'amount_charge', 'amount', 'item_worth']
senticnet['price_bracket'] = [0.763, -0.677, 0, 0.945, '#joyful', '#admirable', 0.795, 'set', 'income_bracket', 'tax_bracket', 'income_tax_bracket', 'bracket']
senticnet['price_goods'] = [0.935, 0.815, 0, 0, '#joyful', '#interesting', 0.583, 'gain_interest', 'carry_home', 'sign_agreement', 'make_offer', 'count_change']
senticnet['price_high'] = [-0.04, 0.278, -0.048, 0.116, '#interesting', '#admirable', 0.102, 'money_involve', 'money_pay', 'revenue', 'money_owe', 'money_payment']
senticnet['price_index'] = [0.538, -0.802, 0, 0.517, '#joyful', '#surprising', 0.619, 'indicator', 'retail_price_index', 'producer_price_index', 'wholesale_price_index', 'consumer_price_index']
senticnet['price_item'] = [-0.064, 0.271, 0, 0.155, '#interesting', '#admirable', 0.121, 'value_amount', 'item_value', 'amount_due', 'amount_pay', 'item_worth']
senticnet['price_level'] = [0.995, -0.539, 0, 0.842, '#joyful', '#admirable', 0.792, 'indicator', 'retail_price_index', 'producer_price_index', 'wholesale_price_index', 'consumer_price_index']
senticnet['price_merchandise'] = [0, 0, -0.068, -0.043, '#scared', '#disgusting', -0.037, 'fire', 'huge_fire', 'rapid_oxidation', 'create_flame', 'cinder']
senticnet['price_product'] = [0.047, 0, 0, 0.067, '#joyful', '#admirable', 0.038, 'fillet_fish', 'clon', 'photography', 'sculpt', 'demo']
senticnet['priceless'] = [0.093, 0.136, 0, 0.197, '#interesting', '#admirable', 0.142, 'important_human', 'universal', 'decorative', 'please_eye', 'subjective']
senticnet['prick'] = [0, -0.109, 0.19, -0.183, '#angry', '#disgusting', -0.088, 'make_goal', 'victorious', 'lift_car', 'silly', 'win']
senticnet['pricker'] = [-0.849, 0, 0.987, -0.777, '#sad', '#angry', -0.871, 'thorn', 'sticker', 'glochid', 'prickle', 'spikelet']
senticnet['prickle'] = [-0.849, 0, 0.987, -0.777, '#sad', '#angry', -0.871, 'thorn', 'sticker', 'pricker', 'glochid', 'spikelet']
senticnet['prickling'] = [-0.78, 0, 0.669, -0.894, '#sad', '#disgusting', -0.781, 'pain_sensation', 'painful_sensation', 'somatic_sensation', 'tingling', 'pain']
senticnet['prickly'] = [0, 0, -0.858, -0.728, '#scared', '#disgusting', -0.529, 'barbed', 'splenetic', 'bristly', 'barbellate', 'waspish']
senticnet['pride'] = [0.912, 0.732, 0, 0.763, '#joyful', '#admirable', 0.802, 'contentment', 'satisfy', 'gratify', 'euphoria', 'gloat']
senticnet['prideful'] = [0.732, 0.614, -0.224, 0.329, '#joyful', '#interesting', 0.484, 'exulting', 'triumphal', 'exultant', 'triumphant', 'rejoicing']
senticnet['pridefulness'] = [0.929, 0.507, -0.172, 0.396, '#joyful', '#interesting', 0.553, 'plume', 'congratulate', 'smugness', 'smug', 'proudly']
senticnet['priest'] = [0, 0, 0, 0.829, '#admirable', '#admirable', 0.276, 'clergy', 'church_head', 'preacher', 'monk', 'friar']
senticnet['prim_out'] = [0.645, -0.697, 0, 0.566, '#joyful', '#surprising', 0.636, 'dress', 'garb', 'raiment', 'clothe', 'enclothe']
senticnet['prim_up'] = [0.968, -0.852, 0, 0.734, '#joyful', '#surprising', 0.851, 'dress', 'garb', 'raiment', 'clothe', 'enclothe']
senticnet['primary'] = [0.716, 0, 0, 0.74, '#joyful', '#admirable', 0.485, 'principal', 'elementary', 'main', 'master', 'chief']
senticnet['primary_care_provider'] = [0.654, -0.579, 0, 0.685, '#joyful', '#admirable', 0.639, 'pharmacologist', 'pharmaceutical_chemist', 'health_professional', 'druggist', 'health_care_provider']
senticnet['primary_color'] = [0.723, 0, 0, 0.762, '#joyful', '#admirable', 0.495, 'color_rainbow', 'secondary_color', 'color', 'happiness', 'bright_color']
senticnet['prime'] = [0.043, 0.118, 0.085, 0.126, '#interesting', '#admirable', 0.067, 'ordinal', 'unit', 'military_group', 'number_one', 'best']
senticnet['prime_minister'] = [0.039, 0.113, 0, 0.069, '#interesting', '#admirable', 0.074, 'country_leader', 'elect_official', 'officer', 'ceo', 'emperor']
senticnet['primitive'] = [-0.73, 0, 0.734, -0.786, '#angry', '#disgusting', -0.75, 'barbarian', 'headhunter', 'cannibal', 'anthropophagus', 'anthropophagite']
senticnet['primitiveness'] = [-0.905, 0, 0.667, -0.994, '#sad', '#disgusting', -0.855, 'natural_state', 'crudeness', 'crudity', 'primitivism', 'rudeness']
senticnet['primitivism'] = [-0.905, 0, 0.667, -0.994, '#sad', '#disgusting', -0.855, 'primitiveness', 'crudeness', 'crudity', 'natural_state', 'rudeness']
senticnet['prince'] = [0.051, 0.097, 0, 0.065, '#interesting', '#admirable', 0.071, 'king', 'queen', 'duchess', 'throne', 'lord']
senticnet['princess'] = [0.951, 0.955, 0, 0, '#joyful', '#interesting', 0.635, 'king', 'queen', 'lady', 'wench', 'baron']
senticnet['principal'] = [-0.066, 0, 0, -0.032, '#sad', '#disgusting', -0.033, 'direct_person', 'teacher', 'hard_worker', 'leadership', 'lead_team']
senticnet['principle'] = [0, 0.272, -0.077, 0.232, '#interesting', '#admirable', 0.142, 'axiom', 'hypothetical', 'govern', 'tenet', 'government_person']
senticnet['prink'] = [-0.888, 0, 0.896, -0.796, '#sad', '#angry', -0.86, 'overdress', 'attire', 'dress_up', 'dizen', 'fig_out']
senticnet['print_material'] = [0.036, 0.219, 0, 0.19, '#interesting', '#admirable', 0.148, 'novel', 'fiction', 'classic', 'long_story', 'literature']
senticnet['print_medium'] = [0, 0, 0, 0.078, '#admirable', '#admirable', 0.026, 'written', 'book_write', 'readable', 'book_page', 'book_content']
senticnet['print_newspaper'] = [0, 0.867, 0, 0.981, '#interesting', '#admirable', 0.616, 'press', 'make_newspaper', 'push_hard', 'print', 'journalist']
senticnet['print_paper'] = [-0.121, 0, 0, 0, '#sad', '#sad', -0.04, 'written_paper', 'make_out_paper', 'purchase_book', 'explain_problem', 'sell_book']
senticnet['print_printer'] = [0, 0.807, 0, 0.735, '#interesting', '#admirable', 0.514, 'post_message', 'send_mail', 'enter_data', 'use_computer', 'send_email']
senticnet['print_word'] = [-0.049, -0.017, -0.046, 0, '#sad', '#scared', -0.026, 'document_type', 'paragraph', 'typeface', 'hold_information', 'print']
senticnet['printing_paper'] = [0, 0.786, 0, 0.8, '#interesting', '#admirable', 0.529, 'photo_copy', 'writing_paper', 'color_paper', 'note_book', 'white_paper']
senticnet['prioritize'] = [0, 0.798, 0, 0.787, '#interesting', '#admirable', 0.528, 'ponder', 'priority', 'put_two_together', 'think_creatively', 'make_right_decision']
senticnet['prism_spectroscope'] = [0.954, -0.668, 0, 0.958, '#joyful', '#admirable', 0.86, 'instrument', 'spectroscope', 'optical_instrument', 'binoculars', 'field_glasses']
senticnet['prison'] = [-0.029, 0, -0.092, -0.069, '#scared', '#disgusting', -0.063, 'crack_house', 'jail', 'memorial', 'bowl_alley', 'homeless_shelter']
senticnet['prison_breaker'] = [-0.931, 0, 0.945, -0.932, '#angry', '#disgusting', -0.936, 'break_rule', 'escape_prison', 'illegal', 'escape_justice', 'stole_goods']
senticnet['prison_cell'] = [0, 0, 0.905, -0.89, '#angry', '#disgusting', -0.598, 'shoe_store', 'chess_tournament', 'dress_room', 'front_desk', 'locker_room']
senticnet['prison_sentence'] = [-0.315, 0, -0.407, 0.169, '#sad', '#scared', -0.184, 'wrong', 'wrongdoing', 'vengeance', 'mock', 'bad_behavior']
senticnet['prisoner'] = [-0.862, 0, -0.978, 0, '#sad', '#scared', -0.613, 'jailbird', 'captive', 'imprisoned', 'convict', 'inmate']
senticnet['prisoner_war_camp'] = [-0.039, 0, -0.083, -0.155, '#scared', '#disgusting', -0.092, 'dark_alley', 'war_museum', 'funeral_home', 'battlefield', 'shoot_range']
senticnet['privacy'] = [0, 0.825, 0, 0.717, '#interesting', '#admirable', 0.514, 'keep_bathroom_dry', 'sexual_activity', 'store_belonging', 'red_light_district', 'sexual_pleasure']
senticnet['private'] = [0, 0.725, 0, 0.813, '#interesting', '#admirable', 0.513, 'general', 'military_rank', 'army_boss', 'high_rank', 'police_rank']
senticnet['private_place'] = [0, 0.08, 0, 0.091, '#interesting', '#admirable', 0.057, 'privacy', 'part_of_building', 'house_area', 'house_place', 'place_house']
senticnet['private_tuition'] = [-0.077, 0, 0.073, -0.262, '#sad', '#disgusting', -0.137, 'college_tuition', 'tuition', 'pay_tuition', 'enroll_class', 'enroll_school']
senticnet['privateness'] = [0.779, -0.756, 0, 0.526, '#joyful', '#surprising', 0.687, 'hiddenness', 'covertness', 'bosom', 'isolation', 'confidentiality']
senticnet['prize'] = [0.894, 0.881, 0, 0.803, '#joyful', '#interesting', 0.859, 'remittance', 'afford', 'account_term', 'money_due', 'amount_owe']
senticnet['pro'] = [0.036, 0.243, -0.095, 0.274, '#interesting', '#admirable', 0.153, 'objective', 'confirmation', 'honor', 'etiquette', 'bottom_line']
senticnet['probability'] = [0, 0.736, 0, 0.726, '#interesting', '#admirable', 0.487, 'gamble_game', 'chance', 'dare', 'jeopardy', 'announcement']
senticnet['probabilty_of_losing'] = [-0.983, 0, 0.334, -0.914, '#sad', '#disgusting', -0.744, 'punishment', 'fault', 'penalty_shoot', 'yellow_card', 'red_card']
senticnet['probe'] = [0, 0.825, 0, 0, '#interesting', '#interesting', 0.275, 'query', 'interrogation', 'inquire', 'response', 'solution']
senticnet['probiotic'] = [-0.998, 0, 0.987, -0.965, '#sad', '#angry', -0.983, 'lactobacillus', 'acidophilus', 'acidophilus_bacterium', 'acidophilus_microflora', 'acidophilus_flora']
senticnet['probiotic_bacterium'] = [-0.998, 0, 0.987, -0.965, '#sad', '#angry', -0.983, 'lactobacillus', 'probiotic', 'acidophilus', 'probiotic_microflora', 'probiotic_flora']
senticnet['probiotic_flora'] = [-0.998, 0, 0.987, -0.965, '#sad', '#angry', -0.983, 'lactobacillus', 'probiotic', 'probiotic_bacterium', 'probiotic_microflora', 'acidophilus']
senticnet['probiotic_microflora'] = [-0.998, 0, 0.987, -0.965, '#sad', '#angry', -0.983, 'lactobacillus', 'probiotic', 'probiotic_bacterium', 'acidophilus', 'probiotic_flora']
senticnet['problem'] = [0, 0, 0.897, -0.86, '#angry', '#disgusting', -0.586, 'result', 'difficulty', 'consequence', 'wrong_answer', 'effect']
senticnet['problem_solve'] = [-0.066, 0.101, 0, 0.157, '#interesting', '#admirable', 0.064, 'use_memory', 'commemorate_event', 'contemplation', 'provide_answer', 'recite']
senticnet['problem_solved'] = [0.083, 0.129, -0.097, 0.155, '#interesting', '#admirable', 0.09, 'relax', 'relieved', 'breath_sigh_relief', 'emotion', 'body_language']
senticnet['problematic'] = [0, 0, 0.837, -0.87, '#angry', '#disgusting', -0.569, 'difficult', 'difficult_concept', 'hard_to_understand', 'tough', 'hard']
senticnet['procedure'] = [-0.067, 0.247, -0.109, 0.239, '#interesting', '#admirable', 0.103, 'conjecture', 'scientific_method', 'scientific', 'hypothetical', 'hypothesis']
senticnet['proceed'] = [0, 0.29, -0.149, 0.418, '#interesting', '#admirable', 0.186, 'go_on', 'take', 'bring_up', 'go_onwards', 'permission']
senticnet['proceeding'] = [-0.751, 0, 0.735, -0.872, '#sad', '#disgusting', -0.786, 'eviction', 'defense', 'plea', 'dispossession', 'due_process']
senticnet['proceeds'] = [-0.629, 0, 0.7, -0.838, '#angry', '#disgusting', -0.722, 'take', 'issue', 'return', 'taking', 'payback']
senticnet['process'] = [-0.032, 0.2, -0.107, 0.298, '#interesting', '#admirable', 0.12, 'procedure', 'action', 'create_form', 'transform', 'posture']
senticnet['process_data'] = [0, 0.994, 0, 0, '#interesting', '#interesting', 0.331, 'word_process', 'help_solve_problem', 'learn_skill', 'access_internet', 'process_information']
senticnet['process_information'] = [0, 0.994, 0, 0, '#interesting', '#interesting', 0.331, 'process_data', 'surf_internet', 'access_internet', 'word_process', 'information']
senticnet['processing'] = [0.783, -0.606, 0, 0.512, '#joyful', '#surprising', 0.634, 'refinement', 'blowing', 'data_processing', 'development', 'developing']
senticnet['procession'] = [0, 0, -0.048, -0.075, '#scared', '#disgusting', -0.041, 'good_band', 'band', 'kit', 'motorcade', 'oblivion']
senticnet['proclamation'] = [0, 0.281, -0.165, 0.377, '#interesting', '#admirable', 0.164, 'request', 'suggest', 'yes_no', 'consent', 'mutual_understand']
senticnet['procrastinate'] = [0, 0.082, 0, 0.077, '#interesting', '#admirable', 0.053, 'drink_tea', 'absorb_moisture', 'sit_on_beach', 'procrastination', 'wave_goodbye']
senticnet['procrastination'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'put_off', 'delay', 'retard', 'postpone', 'lag']
senticnet['procreate'] = [0.039, 0.092, -0.085, 0.125, '#interesting', '#admirable', 0.057, 'copulate', 'reproduce', 'start_family', 'cause_cold', 'give_birth_child']
senticnet['procreation'] = [0.77, 0.867, 0, 0.766, '#joyful', '#interesting', 0.801, 'make_baby', 'create_new_life', 'find_mate', 'survival_species', 'get_date']
senticnet['procure'] = [0.832, -0.92, 0, 0.783, '#joyful', '#surprising', 0.845, 'patent', 'engage', 'suborn', 'copyright', 'enlist']
senticnet['prodigal'] = [0.87, -0.937, 0, 0.831, '#joyful', '#surprising', 0.879, 'spendthrift', 'waster', 'wastrel', 'spender', 'scattergood']
senticnet['prodigious'] = [0.873, 0.793, 0, 0, '#joyful', '#interesting', 0.555, 'exceptional', 'colossal', 'portentous', 'exceeding', 'stupendous']
senticnet['produce'] = [0, 0.17, 0, 0.201, '#interesting', '#admirable', 0.124, 'vegetable_fruit', 'manufacture', 'product', 'store_vegetable', 'groceries']
senticnet['produce_child'] = [0, 0, -0.098, -0.105, '#scared', '#disgusting', -0.068, 'get_trouble', 'marry_kid', 'arousal', 'get_married', 'become_pregnant']
senticnet['produce_egg'] = [0.03, 0, 0, 0.091, '#joyful', '#admirable', 0.04, 'part_of_meal', 'make_egg', 'good_eat', 'nugget', 'yum']
senticnet['produce_food'] = [0, 0.079, 0.036, 0.082, '#interesting', '#admirable', 0.042, 'agriculture', 'cow_home', 'raise_crop', 'grow_food', 'raise_animal']
senticnet['produce_goods'] = [-0.031, 0.128, 0.012, 0.108, '#interesting', '#admirable', 0.064, 'make_product', 'make_goods', 'make_stuff', 'make_happen', 'produce_product']
senticnet['produce_heat'] = [0.608, 0.647, -0.266, 0.325, '#joyful', '#interesting', 0.438, 'warm_house', 'heat_home', 'heat_house', 'warm_room', 'warm_place']
senticnet['produce_milk'] = [0, 0.749, 0, 0.847, '#interesting', '#admirable', 0.532, 'bovine', 'good_friend', 'like_girl', 'barn_animal', 'make_milk']
senticnet['produce_music'] = [0.91, 0.838, 0, 0.741, '#joyful', '#interesting', 0.83, 'create_music', 'play_tune', 'play_music', 'play_orchestra', 'perform_of_music']
senticnet['produce_musical_sound'] = [0.91, 0.838, 0, 0.741, '#joyful', '#interesting', 0.83, 'make_music', 'create_music', 'play_tune', 'play_music', 'play_in_band']
senticnet['produce_product'] = [-0.115, 0, 0.022, -0.091, '#sad', '#disgusting', -0.076, 'pick_out', 'hard_work', 'cut_food', 'make_model', 'circulate_blood']
senticnet['produce_section'] = [0.937, 0, 0, 0.828, '#joyful', '#admirable', 0.588, 'bakery', 'thanksgiving_dinner', 'fruit_bowl', 'dinner_meal', 'fast_food']
senticnet['produce_sound'] = [0, 0, 0.732, -0.881, '#angry', '#disgusting', -0.538, 'make_music', 'wake_morning', 'communicator', 'clear_throat', 'mouth_noise']
senticnet['produce_store'] = [0, 0.074, 0, 0.071, '#interesting', '#admirable', 0.048, 'grocery_cart', 'salad_bar', 'fruit_stand', 'candy_store', 'super_market']
senticnet['produce_value'] = [0.91, 0.838, 0, 0.741, '#joyful', '#interesting', 0.83, 'hard_work', 'produce', 'value', 'earn_money', 'finish_work']
senticnet['producer_price_index'] = [0.538, -0.802, 0, 0.517, '#joyful', '#surprising', 0.619, 'indicator', 'retail_price_index', 'price_index', 'wholesale_price_index', 'consumer_price_index']
senticnet['product'] = [0, 0.243, 0, 0.218, '#interesting', '#admirable', 0.154, 'ware', 'goods', 'item_sell', 'good_price', 'bargain']
senticnet['production'] = [0, 0.164, -0.086, 0.215, '#interesting', '#admirable', 0.098, 'manufacture', 'factory_output', 'creation', 'assembly_line', 'make']
senticnet['productive'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'need_money', 'arrive_mail', 'earn_wage', 'earn_money', 'need_earn_money']
senticnet['profane'] = [-0.518, 0, 0.515, -0.926, '#sad', '#disgusting', -0.653, 'suborn', 'modify', 'poison', 'lead_astray', 'alter']
senticnet['profanity'] = [-0.806, 0, 0.899, -0.524, '#sad', '#angry', -0.743, 'filth', 'smut', 'expletive', 'curse_word', 'swearword']
senticnet['profession'] = [0, 0.097, 0, 0.058, '#interesting', '#admirable', 0.052, 'occupation', 'career', 'tradesman', 'vocation', 'important_job']
senticnet['professional_athlete'] = [0, 0, 0, 0.97, '#admirable', '#admirable', 0.323, 'increase_strength', 'keep_fit', 'fit_person', 'exercise', 'strengthen_heart']
senticnet['professor'] = [0, 0, 0, 0.97, '#admirable', '#admirable', 0.323, 'lecturer', 'teacher', 'instructor', 'college_teacher', 'teach_lesson']
senticnet['professor_office'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'laboratory', 'student_place', 'science_class', 'educational_institution', 'elementary_school']
senticnet['profile'] = [0, 0.189, 0.04, 0.091, '#interesting', '#admirable', 0.08, 'combination', 'margin', 'teller', 'merge', 'finite']
senticnet['profile_picture'] = [0.122, 0.159, -0.054, 0.217, '#interesting', '#admirable', 0.148, 'identity', 'unity', 'country_person', 'unite', 'name_state']
senticnet['profit'] = [0, 0.323, -0.134, 0.169, '#interesting', '#admirable', 0.119, 'bribe', 'owe', 'tax', 'wage', 'reward']
senticnet['profitable'] = [0.998, -0.54, 0, 0.856, '#joyful', '#admirable', 0.798, 'lucrative', 'moneymaking', 'gainful', 'paying', 'paid']
senticnet['profound'] = [0.715, 0.617, -0.23, 0.329, '#joyful', '#interesting', 0.477, 'deep', 'thoughtful', 'intelligent', 'respectful', 'profound_thought']
senticnet['profound_thought'] = [0.715, 0.617, -0.23, 0.329, '#joyful', '#interesting', 0.477, 'deep', 'thoughtful', 'intelligent', 'respectful', 'profound']
senticnet['profundity'] = [0, 0, -0.722, -0.93, '#scared', '#disgusting', -0.551, 'abstrusity', 'reconditeness', 'astuteness', 'abstruseness', 'profoundness']
senticnet['profuseness'] = [0.581, -0.656, 0, 0.959, '#surprising', '#admirable', 0.732, 'wilderness', 'overgrowth', 'greenness', 'verdancy', 'verdure']
senticnet['profusion'] = [0.689, -0.518, 0, 0.632, '#joyful', '#admirable', 0.613, 'wilderness', 'overgrowth', 'greenness', 'verdancy', 'verdure']
senticnet['prognosis'] = [0.993, -0.654, 0, 0.743, '#joyful', '#admirable', 0.797, 'weather_forecast', 'weather_outlook', 'financial_forecast', 'prediction', 'foretelling']
senticnet['program'] = [0.715, 0.617, -0.23, 0.329, '#joyful', '#interesting', 0.477, 'program_computer', 'write_program', 'use_computer', 'write_code', 'source_code']
senticnet['program_computer'] = [0.829, 0, 0, 0.973, '#joyful', '#admirable', 0.601, 'write_program', 'add_up_column_number', 'compute_sum', 'use_calculator', 'calculate_quickly']
senticnet['program_language'] = [0, 0, 0, 0.074, '#admirable', '#admirable', 0.025, 'write_message', 'grammar', 'run_out_paper', 'english', 'computer_language']
senticnet['programme'] = [0, 0.863, 0, 0.91, '#interesting', '#admirable', 0.591, 'episode', 'jeopardy', 'sitcom', 'replay', 'describe']
senticnet['programming_bug'] = [-0.046, 0.121, 0, 0.178, '#interesting', '#admirable', 0.084, 'uppercase_bug', 'bug', 'code', 'developer', 'bad']
senticnet['programming_error'] = [-0.985, 0, 0.869, -0.803, '#sad', '#angry', -0.886, 'error', 'syntax_error', 'semantic_error', 'runtime_error', 'computer_error']
senticnet['progress'] = [-0.06, 0.191, -0.095, 0.223, '#interesting', '#admirable', 0.086, 'advance', 'enter_place', 'meander', 'go_ahead', 'lunge']
senticnet['progymnosperm'] = [-0.772, 0, 0.585, -0.835, '#sad', '#disgusting', -0.731, 'gymnosperm', 'welwitschia', 'cycad', 'seed_fern', 'pteridosperm']
senticnet['prohibit'] = [-0.279, -0.18, 0.02, -0.361, '#sad', '#disgusting', -0.16, 'interruption', 'criticism', 'anthrax', 'deny', 'lay_off']
senticnet['prohibitionist_society'] = [-0.038, 0.14, -0.08, 0.111, '#interesting', '#admirable', 0.044, 'use_game_chess', 'make_up_person', 'blade_weapon', 'find_airplane', 'overrate']
senticnet['project'] = [0, 0.097, 0, 0.092, '#interesting', '#admirable', 0.063, 'urgent', 'classify_ad', 'like_write', 'review', 'repetition']
senticnet['projectile'] = [0, 0.726, 0, 0.866, '#interesting', '#admirable', 0.531, 'ammunition', 'bullet', 'pistol', 'shotgun', 'rifle']
senticnet['projectile_weapon'] = [-0.988, 0, 0.338, -0.971, '#sad', '#disgusting', -0.766, 'gun', 'bullet', 'rifle', 'shoot', 'pistol']
senticnet['projection'] = [-0.034, 0.133, -0.071, 0.214, '#interesting', '#admirable', 0.081, 'arm_movement', 'hand_gesture', 'water_motion', 'hand_signal', 'sea_movement']
senticnet['projector'] = [-0.034, 0.133, -0.071, 0.214, '#interesting', '#admirable', 0.081, 'floodlight', 'spotlight', 'headlight', 'light', 'teach_lesson']
senticnet['prolixity'] = [-0.575, 0, 0.767, -0.617, '#angry', '#disgusting', -0.653, 'verboseness', 'verbosity', 'turgidity', 'turgidness', 'flatulence']
senticnet['prolixness'] = [-0.622, 0, 0.955, -0.983, '#angry', '#disgusting', -0.853, 'verboseness', 'verbosity', 'turgidity', 'turgidness', 'flatulence']
senticnet['prolong_life'] = [0.133, 0.1, -0.121, 0.144, '#joyful', '#admirable', 0.085, 'improve_self-image', 'keep_body_healthy', 'much_energy', 'healthy', 'long_life']
senticnet['prom'] = [0.088, -0.004, 0, 0.077, '#joyful', '#admirable', 0.056, 'ballerina', 'ballroom', 'ballet', 'party', 'nightclub']
senticnet['prominence'] = [0.55, -0.742, 0, 0.81, '#surprising', '#admirable', 0.701, 'strikingness', 'glare', 'salience', 'saliency', 'standing']
senticnet['prominent'] = [0.998, 0, 0, 0.848, '#joyful', '#admirable', 0.615, 'outstanding', 'salient', 'big', 'spectacular', 'striking']
senticnet['promise'] = [0, 0.286, -0.228, 0.383, '#interesting', '#admirable', 0.147, 'oath', 'propose', 'suggest', 'ask', 'give_word']
senticnet['promise_good'] = [-0.187, 0, -0.066, -0.065, '#sad', '#scared', -0.106, 'roll_ball', 'wear_silly_hat', 'bicycle_school', 'trade_baseball_card', 'ring_doorbell']
senticnet['promote'] = [0.092, 0.123, -0.064, 0.187, '#interesting', '#admirable', 0.113, 'spread_idea', 'fame', 'make_money', 'ego_boost', 'make_world_better_place']
senticnet['promote_business'] = [0.84, 0.813, 0, 0.915, '#joyful', '#admirable', 0.856, 'increase_income', 'transact_business', 'resolve_dispute', 'time_consume', 'able_use']
senticnet['promotion'] = [0.032, 0.312, -0.12, 0.185, '#interesting', '#admirable', 0.136, 'obligation', 'tedious', 'reinforce', 'incentive', 'task']
senticnet['prompt'] = [0.032, 0.312, -0.12, 0.185, '#interesting', '#admirable', 0.136, 'ready', 'prepared', 'set', 'quick', 'precise']
senticnet['promptness'] = [-0.582, 0, 0.52, -0.996, '#sad', '#disgusting', -0.699, 'quickness', 'celerity', 'rapidity', 'rapidness', 'speediness']
senticnet['prone'] = [-0.783, 0, 0.95, -0.731, '#sad', '#angry', -0.821, 'drooping', 'crooked', 'weeping', 'unerect', 'supine']
senticnet['pronounce'] = [-0.023, 0.186, 0, 0.213, '#interesting', '#admirable', 0.125, 'description', 'mumble', 'bummer', 'numerical', 'proverb']
senticnet['pronunciation'] = [0.524, -0.751, 0, 0.932, '#surprising', '#admirable', 0.736, 'accent', 'assibilation', 'sibilation', 'mispronunciation', 'homophony']
senticnet['proof'] = [0.029, 0.226, -0.092, 0.174, '#interesting', '#admirable', 0.112, 'evidence', 'judgment', 'regulation', 'serve_jury', 'law']
senticnet['proof_of_purchase'] = [0.029, 0.226, -0.092, 0.174, '#interesting', '#admirable', 0.112, 'proof', 'movie_ticket', 'purchase', 'receipt', 'buy_item']
senticnet['proofed'] = [-0.739, 0, 0.641, -0.748, '#sad', '#disgusting', -0.709, 'burnt', 'burned', 'treated', 'doped', 'activated']
senticnet['proofread'] = [0.642, -0.532, 0, 0.575, '#joyful', '#admirable', 0.583, 'check', 'assure', 'see', 'insure', 'see_to_it']
senticnet['prop_up'] = [0.169, 0.223, -0.106, 0.219, '#interesting', '#admirable', 0.168, 'ferment', 'vibrate', 'blend', 'fill_glass', 'jiggle']
senticnet['proper'] = [0.163, 0.255, -0.2, 0.31, '#interesting', '#admirable', 0.176, 'honest', 'virtue', 'compliment', 'obedience', 'personal']
senticnet['proper_equipment'] = [0, 0.086, 0.04, 0.106, '#interesting', '#admirable', 0.051, 'tumble', 'up_hill', 'go_mountain', 'move_up', 'equipment']
senticnet['proper_name'] = [0.145, 0.173, 0, 0.212, '#interesting', '#admirable', 0.177, 'christmas_song', 'chant', 'hymn', 'common_language', 'universal_language']
senticnet['properness'] = [0.837, -0.903, 0, 0.822, '#joyful', '#surprising', 0.854, 'decency', 'decorum', 'decorousness', 'correctness', 'seemliness']
senticnet['property'] = [0.024, 0.199, -0.118, 0.168, '#interesting', '#admirable', 0.091, 'estate', 'own_land', 'real_estate', 'good_investment', 'owner']
senticnet['prophecy'] = [0.958, -0.508, 0, 0.527, '#joyful', '#admirable', 0.664, 'divination', 'anticipation', 'prevision', 'crystal_gazing', 'foretelling']
senticnet['prophesy'] = [0.927, -0.896, 0, 0.604, '#joyful', '#surprising', 0.809, 'vaticinate', 'call', 'enlighten', 'irradiate', 'predict']
senticnet['prophet'] = [0, 0.264, -0.075, 0.219, '#interesting', '#admirable', 0.136, 'bless', 'pastor', 'gospel', 'saint', 'church_head']
senticnet['prophetic'] = [-0.955, 0, 0.739, -0.599, '#sad', '#angry', -0.764, 'foreboding', 'precursory', 'premonitory', 'apocalyptic', 'apocalyptical']
senticnet['prophetical'] = [-0.814, 0, 0.871, -0.946, '#angry', '#disgusting', -0.877, 'foreboding', 'precursory', 'premonitory', 'apocalyptic', 'apocalyptical']
senticnet['propitiation'] = [-0.97, 0, 0.772, -0.673, '#sad', '#angry', -0.805, 'expiation', 'atonement', 'deliverance', 'redemption', 'rescue']
senticnet['propitious'] = [0.736, -0.663, 0, 0.777, '#joyful', '#admirable', 0.725, 'lucky', 'gracious', 'prosperous', 'favorable', 'favourable']
senticnet['propitiousness'] = [0.905, -0.595, 0, 0.648, '#joyful', '#admirable', 0.716, 'profitableness', 'favorableness', 'favourableness', 'advantageousness', 'positivity']
senticnet['proposal'] = [-0.028, 0.168, -0.146, 0.329, '#interesting', '#admirable', 0.108, 'engage', 'suggest', 'interaction', 'promise', 'engagement']
senticnet['propose'] = [0, 0.951, 0, 0.814, '#interesting', '#admirable', 0.588, 'cope', 'promise', 'oath', 'ask', 'affirmation']
senticnet['propose_marriage'] = [0, 0.99, 0, 0.93, '#interesting', '#admirable', 0.64, 'decorate_oneself', 'display_wealth', 'engagement', 'symbolism', 'marriage_ceremony']
senticnet['propose_woman'] = [0.702, 0, 0, 0.928, '#joyful', '#admirable', 0.543, 'commit', 'kiss', 'commit_to_memory', 'love', 'marriage']
senticnet['proposition'] = [0.021, 0.286, -0.218, 0.387, '#interesting', '#admirable', 0.159, 'tell_everyone', 'make_better', 'make_right', 'again_and_again', 'suggest']
senticnet['propriety'] = [0.509, -0.637, 0, 0.77, '#surprising', '#admirable', 0.639, 'decency', 'decorum', 'decorousness', 'correctness', 'seemliness']
senticnet['propulsion'] = [0, 0, 0, 0.135, '#admirable', '#admirable', 0.045, 'water_activity', 'boat_type', 'athletic_activity', 'outdoor_activity', 'backstroke']
senticnet['prorogue'] = [-0.575, 0, 0.576, -0.785, '#angry', '#disgusting', -0.645, 'reprieve', 'respite', 'suspend', 'call', 'delay']
senticnet['prosaic'] = [0, 0, -0.916, -0.763, '#scared', '#disgusting', -0.56, 'matter-of-fact', 'commonplace', 'pedestrian', 'prosy', 'earthbound']
senticnet['proscribe'] = [0, 0, -0.917, -0.908, '#scared', '#disgusting', -0.608, 'forbid', 'prohibit', 'veto', 'disallow', 'interdict']
senticnet['prose'] = [0.048, 0, 0, 0.058, '#joyful', '#admirable', 0.035, 'poetry', 'scripture', 'chapter', 'rhyme', 'print_material']
senticnet['prosecutor'] = [0.024, 0.141, 0, 0.082, '#interesting', '#admirable', 0.082, 'arbiter', 'jury', 'gavel', 'judge_jury', 'lawyer']
senticnet['prosper'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'a_lot_of_sex', 'desirable', 'give_birth_child', 'sexual_intercourse', 'diversity']
senticnet['prosperity'] = [0.989, 0, 0, 0, '#joyful', '#joyful', 0.33, 'look_beautiful', 'luck', 'good_luck', 'consistency', 'fame']
senticnet['prostatitis'] = [-0.998, 0, 0.964, -0.704, '#sad', '#angry', -0.889, 'blepharitis', 'diverticulitis', 'epiglottitis', 'orchitis', 'inflammation']
senticnet['prosthesis'] = [-0.03, 0, -0.094, -0.145, '#scared', '#disgusting', -0.09, 'x-ray_machine', 'artificial_arm', 'ambulance', 'syringe', 'latex_glove']
senticnet['prosthetic_device'] = [-0.621, 0, 0.996, -0.683, '#angry', '#disgusting', -0.767, 'pack', 'face_pack', 'pickup', 'prosthesis', 'corrective']
senticnet['prostitute'] = [-0.88, 0, 0.606, -0.731, '#sad', '#disgusting', -0.739, 'slattern', 'camp_follower', 'call_girl', 'comfort_woman', 'ianfu']
senticnet['prostration'] = [-0.936, 0, 0.807, -0.954, '#sad', '#disgusting', -0.899, 'heatstroke', 'heat_hyperpyrexia', 'malady', 'breakdown', 'shock']
senticnet['prostyle'] = [-0.659, 0, 0.878, -0.868, '#angry', '#disgusting', -0.802, 'amphistylar', 'amphiprostylar', 'amphiapteral', 'porticoed', 'apteral']
senticnet['protagonist'] = [0, 0, -0.737, -0.922, '#scared', '#disgusting', -0.553, 'champion', 'admirer', 'booster', 'friend', 'supporter']
senticnet['protease_inhibitor'] = [-0.818, 0, 0.767, -0.936, '#sad', '#disgusting', -0.84, 'antiviral', 'indinavir', 'nelfinavir', 'ritonavir', 'saquinavir']
senticnet['protect'] = [0, 0.94, 0, 0.728, '#interesting', '#admirable', 0.556, 'secure', 'defend', 'watch_over', 'guard', 'stronghold']
senticnet['protect_body'] = [0.151, 0, 0, 0.055, '#joyful', '#admirable', 0.069, 'dry_off_towel', 'lock_front_door', 'try_clothes_before_buy', 'dry_towel', 'put_clothes']
senticnet['protect_child'] = [-0.074, 0, 0, -0.061, '#sad', '#disgusting', -0.045, 'raise_child', 'teach_child', 'help_another_person', 'understand_idea', 'look_closely']
senticnet['protect_country'] = [-0.064, -0.025, -0.083, -0.163, '#scared', '#disgusting', -0.095, 'kill_enemy', 'make_war', 'conquer_enemy', 'self_defense', 'enslave_person']
senticnet['protect_environment'] = [0, 0.77, 0, 0.809, '#interesting', '#admirable', 0.526, 'agree_disagree', 'offer_help', 'part_of_way', 'receive_email', 'welcome_friend']
senticnet['protect_eye_sun'] = [0.051, 0.099, -0.078, 0.117, '#interesting', '#admirable', 0.063, 'shade_eye', 'cover_window', 'obey_traffic_law', 'block_light', 'do_anything']
senticnet['protect_family'] = [0.852, 0, 0, 0, '#joyful', '#joyful', 0.284, 'transmit_disease', 'sometimes_bad', 'gain_power', 'end_war', 'rape']
senticnet['protect_foot'] = [-0.063, -0.048, 0.094, 0, '#sad', '#angry', -0.036, 'keep_foot_warm', 'look_stylish', 'high_heel', 'walk_upon', 'stand_upon']
senticnet['protect_from_sun'] = [0, 0.128, 0, 0.058, '#interesting', '#admirable', 0.062, 'no_light', 'shade', 'without_light', 'sun_block', 'dark_area']
senticnet['protect_head'] = [0, 0.808, 0, 0.899, '#interesting', '#admirable', 0.569, 'prevent_sunburn', 'cover_head', 'keep_hair_place', 'shade_eye', 'cover_body']
senticnet['protect_home'] = [0.11, 0.188, 0, 0, '#joyful', '#interesting', 0.099, 'purpose_container', 'home_improvement', 'protection', 'please_eye', 'protect']
senticnet['protect_house'] = [0.036, 0.088, 0.059, 0.14, '#interesting', '#admirable', 0.068, 'record', 'wall_decoration', 'form_of_art', 'creative_activity', 'ideal']
senticnet['protect_king'] = [0, 0, 0, 0.802, '#admirable', '#admirable', 0.267, 'play_game', 'play_card', 'play_chess', 'play_game_chess', 'play_blackjack']
senticnet['protect_oneself'] = [-0.145, 0, -0.11, -0.204, '#sad', '#disgusting', -0.153, 'defend_oneself', 'kill', 'death_destruction', 'murder', 'get_rid_of_enemy']
senticnet['protect_rain'] = [0.027, 0, 0.102, -0.044, '#angry', '#disgusting', -0.04, 'modesty', 'make_dress', 'cover_table', 'keep_someone_warm', 'protect_body']
senticnet['protect_surface'] = [0, 0.908, 0, 0.757, '#interesting', '#admirable', 0.555, 'make_pretty', 'cover_table', 'cover', 'protection', 'paint_nail']
senticnet['protect_wood'] = [0.035, -0.053, 0, 0.101, '#surprising', '#admirable', 0.063, 'dry', 'coat_wall', 'artist_tool', 'palette', 'coat_surface']
senticnet['protected'] = [-0.898, 0, 0.627, -0.547, '#sad', '#angry', -0.691, 'shielded', 'weatherproof', 'covert', 'stormproof', 'fortified']
senticnet['protection'] = [0, 0.805, 0, 0.926, '#interesting', '#admirable', 0.577, 'defend', 'shield', 'arm_man', 'watch_over', 'protect']
senticnet['protection_element'] = [0, 0.779, 0, 0.794, '#interesting', '#admirable', 0.524, 'protection_weather', 'reside', 'raise_family', 'save_space', 'live_inside']
senticnet['protection_sun'] = [0, 0.764, 0, 0.889, '#interesting', '#admirable', 0.551, 'keep_someone_warm', 'keep_body_warm', 'outerwear', 'make_fashion_statement', 'winter_clothes']
senticnet['protection_weather'] = [0.091, 0.102, -0.101, 0.153, '#interesting', '#admirable', 0.082, 'protection_element', 'reside', 'raise_family', 'live_life', 'live_inside']
senticnet['protective'] = [0.488, 0.689, -0.27, 0.311, '#joyful', '#interesting', 0.406, 'protectiveness', 'protectively', 'fond_regard', 'fondness', 'soft_spot']
senticnet['protective_coloration'] = [0.62, -0.598, 0, 0.967, '#joyful', '#admirable', 0.728, 'aposematic_coloration', 'warning_coloration', 'apatetic_coloration', 'cryptic_coloration', 'coloration']
senticnet['protective_cover'] = [-0.587, 0, 0.992, -0.874, '#angry', '#disgusting', -0.818, 'mask', 'blind', 'watch_crystal', 'cladding', 'thumbstall']
senticnet['protective_covering'] = [-0.586, 0, 0.989, -0.644, '#angry', '#disgusting', -0.74, 'mask', 'blind', 'watch_crystal', 'cladding', 'thumbstall']
senticnet['protective_fold'] = [-0.79, 0, 0.769, -0.798, '#sad', '#disgusting', -0.786, 'flap', 'eyelid', 'lid', 'palpebra', 'nictitating_membrane']
senticnet['protective_garment'] = [-0.99, 0, 0.806, -0.677, '#sad', '#angry', -0.824, 'wear', 'biohazard_suit', 'coverall', 'shoulder_pad', 'wearable']
senticnet['protective_gear'] = [0, 0.078, 0, 0, '#interesting', '#interesting', 0.026, 'knight_protection', 'gold', 'chrome', 'foil', 'rusty_metal']
senticnet['protectively'] = [0.487, 0.675, -0.267, 0.266, '#joyful', '#interesting', 0.387, 'protectiveness', 'soft_spot', 'fond_regard', 'affectionateness', 'warmness']
senticnet['protectiveness'] = [0.487, 0.675, -0.267, 0.266, '#joyful', '#interesting', 0.387, 'protectively', 'soft_spot', 'fond_regard', 'affectionateness', 'warmness']
senticnet['protest'] = [0, 0, 0.971, 0, '#angry', '#angry', -0.324, 'angry_mob', 'against', 'gang', 'riot', 'picket_sign']
senticnet['protestant'] = [0, 0.306, -0.053, 0.287, '#interesting', '#admirable', 0.18, 'church_head', 'pastor', 'prayer', 'religion', 'religious_official']
senticnet['protester'] = [-0.931, 0, 0.688, -0.631, '#sad', '#angry', -0.75, 'dissident', 'dissenter', 'nimby', 'objector', 'contestant']
senticnet['proton_neutron'] = [0, 0, 0, 0.101, '#admirable', '#admirable', 0.034, 'elementary_particle', 'neutron', 'electron', 'subatomic_particle', 'proton']
senticnet['prototype'] = [0.397, 0.245, -0.135, 0.224, '#joyful', '#interesting', 0.244, 'self_respect', 'animal_person', 'help_person', 'better_person', 'receive_reward']
senticnet['protractor'] = [0, -0.005, 0.034, -0.068, '#angry', '#disgusting', -0.032, 'celsius', 'grade', 'certificate', 'learn_tool', 'temperature_measure']
senticnet['protrusion'] = [0, 0.079, 0, 0.112, '#interesting', '#admirable', 0.064, 'speak_organ', 'face_part', 'near_mouth', 'facial_feature', 'facial_part']
senticnet['proud'] = [0.71, 0.49, -0.24, 0.373, '#joyful', '#interesting', 0.444, 'joy', 'satisfaction', 'pride', 'elation', 'gratitude']
senticnet['proudly'] = [0.8, 0.588, -0.207, 0.349, '#joyful', '#interesting', 0.51, 'self-satisfied', 'smug', 'smugness', 'preen', 'self-complacent']
senticnet['prove'] = [-0.03, 0.17, -0.128, 0.157, '#interesting', '#admirable', 0.056, 'find', 'describe', 'help_find', 'review', 'help_understand']
senticnet['prove_fitness'] = [0.112, 0.178, -0.055, 0.143, '#interesting', '#admirable', 0.126, 'win_marathon', 'support_cause', 'challenge_oneself', 'enjoy_competition', 'earn_a_lot_of_money']
senticnet['prove_knowledge'] = [-0.06, 0, -0.061, 0, '#sad', '#scared', -0.04, 'prove_learn', 'get_qualification', 'want_pass_class', 'want_degree', 'complete_course']
senticnet['prove_learn'] = [-0.053, 0, -0.062, 0, '#sad', '#scared', -0.038, 'get_qualification', 'prove_knowledge', 'want_pass_class', 'get_grade', 'complete_course']
senticnet['prove_oneself'] = [0.052, 0.071, 0, 0, '#joyful', '#interesting', 0.041, 'support_cause', 'big_money', 'win_marathon', 'healthy', 'prove_fitness']
senticnet['prove_physical_endurance'] = [0, 0.348, -0.322, 0.382, '#interesting', '#admirable', 0.136, 'go_to_gym', 'maintain_muscle_strength', 'release_energy', 'physical_activity', 'physical_endurance']
senticnet['prove_point'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'keep_word', 'form_opinion', 'point_out', 'share_opinion', 'help_another_person']
senticnet['prove_theory'] = [0.763, 0, 0, 0.719, '#joyful', '#admirable', 0.494, 'hypothesis', 'test_hypothesis', 'theory', 'big_bang', 'experiment']
senticnet['proverb'] = [0, 0.137, 0, 0.24, '#interesting', '#admirable', 0.126, 'elaborate', 'question_answer', 'interrogation', 'feedback', 'request']
senticnet['provide'] = [0, 0.348, -0.322, 0.382, '#interesting', '#admirable', 0.136, 'give', 'receive', 'accept', 'cope', 'given']
senticnet['provide_answer'] = [-0.066, 0.101, 0, 0.157, '#interesting', '#admirable', 0.064, 'use_memory', 'commemorate_event', 'contemplation', 'problem_solve', 'recite']
senticnet['provide_electricity'] = [0, 0.973, 0, 0.878, '#interesting', '#admirable', 0.617, 'power', 'form_of_energy', 'power_source', 'potential', 'energy']
senticnet['provide_employment'] = [-0.066, 0.166, 0, 0.095, '#interesting', '#admirable', 0.065, 'transact_business', 'exchange_money', 'make_profit', 'pay_service', 'make_rich']
senticnet['provide_family'] = [-0.081, 0.179, -0.06, 0.096, '#interesting', '#admirable', 0.045, 'purchase_food', 'buy_food', 'buy_lunch', 'get_food', 'buy_grocery']
senticnet['provide_food'] = [0.02, 0.162, 0, 0.062, '#interesting', '#admirable', 0.081, 'make_eat', 'satiate_hunger', 'animal_eat', 'nourish', 'bait_trap']
senticnet['provide_heat'] = [0.101, 0, 0, 0, '#joyful', '#joyful', 0.034, 'keep_warm', 'keep_warm_winter', 'provide_warmth', 'keep_someone_warm', 'stay_warm']
senticnet['provide_information'] = [0.595, 0.893, 0, 0.993, '#interesting', '#admirable', 0.827, 'express_opinion', 'give_information', 'transfer_knowledge', 'tell_information', 'share_idea']
senticnet['provide_light'] = [0.096, -0.017, 0, 0, '#joyful', '#surprising', 0.038, 'light', 'illuminate_room', 'hot_sun', 'ultraviolet', 'illumination']
senticnet['provide_service'] = [-0.055, 0.104, 0, 0.056, '#interesting', '#admirable', 0.035, 'perform_service', 'go_work_to_earn_money', 'support_family', 'responsible', 'receive_paycheck']
senticnet['provide_shelter'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'inhabit', 'raise_family', 'rent', 'live_life', 'house_person']
senticnet['provide_warmth'] = [0, 0.951, 0, 0.702, '#interesting', '#admirable', 0.551, 'stay_warm', 'keep_warm_winter', 'keep_someone_warm', 'keep_warm', 'warmth']
senticnet['provident'] = [0.527, -0.807, 0, 0.705, '#surprising', '#admirable', 0.68, 'careful', 'thrifty', 'farseeing', 'longsighted', 'foresighted']
senticnet['province'] = [0.8, -0.843, 0, 0.868, '#surprising', '#admirable', 0.837, 'commonwealth', 'eparchy', 'administrative_district', 'administrative_division', 'territorial_division']
senticnet['provision'] = [0, 0.221, -0.174, 0.257, '#interesting', '#admirable', 0.101, 'store_vegetable', 'supply', 'food', 'keep_fresh', 'japanese_food']
senticnet['proviso'] = [-0.922, 0, 0.547, -0.984, '#sad', '#disgusting', -0.818, 'assumption', 'boundary_condition', 'provision', 'precondition', 'premiss']
senticnet['provocateur'] = [0, 0, 0.997, 0, '#angry', '#angry', -0.332, 'stand_out', 'express_oneself', 'tell_many_person', 'egalitarian', 'pioneer']
senticnet['provocative'] = [-0.096, -0.157, 0.52, -0.633, '#angry', '#disgusting', -0.364, 'anger', 'injury', 'sore', 'strengthful', 'bruise']
senticnet['provocative_discussion'] = [-0.964, 0, 0, -0.715, '#sad', '#disgusting', -0.56, 'embarrass_oneself', 'uncomfortable_situation', 'bad_experience', 'shy', 'become_red']
senticnet['provoke'] = [-0.593, 0.162, 0.221, -0.503, '#sad', '#disgusting', -0.385, 'chivvy', 'harass', 'beset', 'annoy', 'poke']
senticnet['provoked'] = [-0.121, 0.069, 0.703, -0.673, '#angry', '#disgusting', -0.476, 'aggravate', 'exacerbate', 'aggravated', 'exasperation', 'displeased']
senticnet['provoker'] = [-0.712, 0, 0.512, -0.827, '#sad', '#disgusting', -0.684, 'troublemaker', 'trouble_maker', 'troubler', 'bad_hat', 'ringleader']
senticnet['prowess'] = [0.858, -0.953, 0, 0.599, '#joyful', '#surprising', 0.803, 'eristic', 'puppetry', 'homiletics', 'aviation', 'airmanship']
senticnet['proximity'] = [0.158, 0.22, 0, 0.298, '#interesting', '#admirable', 0.225, 'long_distance', 'compass_direction', 'afar', 'direction', 'neighbor']
senticnet['proxy'] = [0, 0.285, -0.079, 0.281, '#interesting', '#admirable', 0.162, 'restraint', 'restriction', 'confirmation', 'axiom', 'standard']
senticnet['prudence'] = [0, 0.91, 0, 0.874, '#interesting', '#admirable', 0.595, 'discretion', 'frugality', 'frugalness', 'providence', 'judgement']
senticnet['prudent'] = [0.625, -0.88, 0, 0.782, '#surprising', '#admirable', 0.762, 'judicious', 'discreet', 'prudential', 'heady', 'circumspect']
senticnet['prudish'] = [0, 0, 0.929, -0.876, '#angry', '#disgusting', -0.602, 'prissy', 'puritanical', 'priggish', 'prim', 'square-toed']
senticnet['prune'] = [0.912, -0.834, 0, 0, '#joyful', '#surprising', 0.582, 'onion', 'tomato', 'pea', 'berry', 'fig']
senticnet['prune_tree'] = [-0.889, 0, 0.778, -0.794, '#sad', '#disgusting', -0.82, 'climb_mountain', 'skate', 'chop_down_tree', 'ski', 'jump_out_of_window']
senticnet['pruno'] = [-0.831, 0, 0.647, -0.946, '#sad', '#disgusting', -0.808, 'intoxicant', 'hootch', 'alcohol', 'alcoholic_drink', 'alcoholic_beverage']
senticnet['prurience'] = [0.996, -0.869, 0, 0.673, '#joyful', '#surprising', 0.846, 'amorousness', 'sexiness', 'amativeness', 'eroticism', 'erotism']
senticnet['pruriency'] = [0.811, -0.894, 0, 0.858, '#surprising', '#admirable', 0.854, 'amorousness', 'sexiness', 'amativeness', 'eroticism', 'erotism']
senticnet['pruritus'] = [-0.506, 0, 0.868, -0.798, '#angry', '#disgusting', -0.724, 'itch', 'itchiness', 'itching', 'pruritus_ani', 'pruritus_vulvae']
senticnet['pruritus_ani'] = [-0.506, 0, 0.868, -0.798, '#angry', '#disgusting', -0.724, 'itch', 'itchiness', 'itching', 'pruritus', 'pruritus_vulvae']
senticnet['pruritus_vulvae'] = [-0.506, 0, 0.868, -0.798, '#angry', '#disgusting', -0.724, 'itch', 'itchiness', 'itching', 'pruritus_ani', 'pruritus']
senticnet['pry'] = [-0.993, 0, 0.66, -0.508, '#sad', '#angry', -0.72, 'bar', 'treadle', 'lever', 'key', 'peavey']
senticnet['pry_open'] = [0.752, -0.901, 0, 0, '#joyful', '#surprising', 0.551, 'cut_food', 'drink_beer', 'serve_drink', 'drink_much', 'drink_beverage']
senticnet['prying'] = [-0.909, 0, 0.865, -0.772, '#sad', '#angry', -0.849, 'nosiness', 'snoopiness', 'curiousness', 'curiosity', 'wonder']
senticnet['psalm'] = [0.034, 0.161, -0.05, 0.172, '#interesting', '#admirable', 0.106, 'font', 'dissertation', 'report', 'print', 'print_word']
senticnet['pseud'] = [-0.618, 0, 0.764, -0.728, '#angry', '#disgusting', -0.703, 'beguiler', 'slicker', 'name_dropper', 'ringer', 'deceiver']
senticnet['pseudo'] = [-0.663, 0, 0.918, -0.624, '#sad', '#angry', -0.735, 'beguiler', 'slicker', 'name_dropper', 'ringer', 'deceiver']
senticnet['pseudoscience'] = [-0.777, 0, 0.885, -0.738, '#sad', '#angry', -0.8, 'pathetic_fallacy', 'misconception', 'paralogism', 'logical_fallacy', 'fallacy']
senticnet['psoriatic_arthritis'] = [-0.899, 0, 0.989, -0.59, '#sad', '#angry', -0.826, 'arthritis', 'rheumatoid_arthritis', 'juvenile_rheumatoid_arthritis', 'autoimmune_disease', 'autoimmune_disorder']
senticnet['psych_up'] = [-0.799, 0, 0.605, -0.759, '#sad', '#disgusting', -0.721, 'charge_up', 'commove', 'agitate', 'excite', 'charge']
senticnet['psyche'] = [0.914, -0.56, 0, 0.869, '#joyful', '#admirable', 0.781, 'tabula_rasa', 'ego', 'subconscious', 'unconscious', 'noddle']
senticnet['psychedelic_drug'] = [-0.735, 0, 0.944, -0.942, '#angry', '#disgusting', -0.874, 'lysergic_acid_diethylamide', 'mescaline', 'peyote', 'phencyclidine', 'drug']
senticnet['psychiatric_hospital'] = [-0.655, 0, 0.931, -0.654, '#sad', '#angry', -0.747, 'snake_pit', 'booby_hatch', 'crazy_house', 'cuckoo_nest', 'funny_farm']
senticnet['psychic'] = [0.034, 0.161, -0.05, 0.172, '#interesting', '#admirable', 0.106, 'mental', 'psychical', 'psychologist', 'mind_power', 'mind']
senticnet['psychic_phenomenon'] = [-0.883, 0, 0.794, -0.651, '#sad', '#angry', -0.776, 'telekinesis', 'psychokinesis', 'clairvoyance', 'second_sight', 'extrasensory_perception']
senticnet['psychic_trauma'] = [0.775, -0.636, 0, 0.68, '#joyful', '#admirable', 0.697, 'birth_trauma', 'psychological_state', 'psychological_condition', 'mental_state', 'mental_condition']
senticnet['psycho'] = [-0.606, 0, 0.892, -0.921, '#angry', '#disgusting', -0.806, 'schizophrenic', 'cataleptic', 'paranoid', 'paranoiac', 'sick_person']
senticnet['psychogenesis'] = [0.96, -0.638, 0, 0.663, '#joyful', '#admirable', 0.754, 'growth', 'growing', 'maturation', 'development', 'ontogeny']
senticnet['psychokinesis'] = [-0.8, 0, 0.62, -0.712, '#sad', '#disgusting', -0.711, 'telekinesis', 'parapsychology', 'clairvoyance', 'second_sight', 'extrasensory_perception']
senticnet['psychological_aggression'] = [-0.917, 0, 0.451, -0.987, '#sad', '#disgusting', -0.785, 'slave', 'female_slave', 'physical_aggression', 'aggression', 'verbal_aggression']
senticnet['psychological_condition'] = [0.964, -0.592, 0, 0.982, '#joyful', '#admirable', 0.846, 'case', 'thinking_cap', 'temporary_state', 'psychological_state', 'frame_of_mind']
senticnet['psychological_disorder'] = [-0.511, 0, 0.927, -0.913, '#angry', '#disgusting', -0.784, 'encopresis', 'upset', 'psychosomatic_disorder', 'conversion_disorder', 'conversion_reaction']
senticnet['psychological_pressure'] = [-0.089, 0, -0.153, -0.206, '#scared', '#disgusting', -0.149, 'ask_money', 'exaction', 'wringing', 'intimidate', 'extortion']
senticnet['psychological_state'] = [0.964, -0.592, 0, 0.982, '#joyful', '#admirable', 0.846, 'case', 'thinking_cap', 'temporary_state', 'frame_of_mind', 'psychological_condition']
senticnet['psychological_terror'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'mobbing', 'violence', 'physical_pain', 'boss_around', 'bully']
senticnet['psychologist'] = [0.031, 0, -0.064, -0.055, '#scared', '#disgusting', -0.029, 'specialist', 'detective', 'connoisseur', 'truck_driver', 'medical_professional']
senticnet['psychomotor_development'] = [0.874, -0.739, 0, 0.608, '#joyful', '#surprising', 0.74, 'growth', 'growing', 'maturation', 'development', 'ontogeny']
senticnet['psychoneurosis'] = [-0.37, -0.033, -0.39, -0.151, '#sad', '#scared', -0.293, 'gonorrhea', 'feel_bad', 'severe_pain', 'anguish', 'learn_disease']
senticnet['psychoneurotic'] = [-0.749, 0, 0.839, -0.907, '#angry', '#disgusting', -0.832, 'sick_person', 'diseased_person', 'sufferer', 'claustrophobe', 'hysteric']
senticnet['psychopath'] = [0, 0, -0.96, -0.804, '#scared', '#disgusting', -0.588, 'get_rid_of_enemy', 'kill_another_person', 'hurt_others', 'harden_criminal', 'end_live']
senticnet['psychopathic_personality'] = [0, 0, 0.896, -0.962, '#angry', '#disgusting', -0.619, 'antisocial', 'sociopathic', 'personality_disorder', 'disturbance', 'schizoid']
senticnet['psychopathy'] = [0.618, -0.594, 0, 0.773, '#joyful', '#admirable', 0.662, 'insanity', 'psychosis', 'megalomania', 'psychological_state', 'psychological_condition']
senticnet['psychosis'] = [0, 0, -0.973, 0, '#scared', '#scared', -0.324, 'angry_emotion', 'dislike', 'hurt_feeling', 'feel_hurt', 'mental_disorder']
senticnet['psychosomatic_disorder'] = [-0.68, 0, 0.969, -0.94, '#angry', '#disgusting', -0.863, 'mental_disorder', 'mental_disturbance', 'psychological_disorder', 'folie', 'disturbance']
senticnet['psychotic'] = [-0.678, 0, 0.963, -0.957, '#angry', '#disgusting', -0.866, 'schizophrenic', 'cataleptic', 'paranoid', 'paranoiac', 'sick_person']
senticnet['psychotic_person'] = [-0.8, 0, 0.788, -0.956, '#sad', '#disgusting', -0.848, 'schizophrenic', 'cataleptic', 'paranoid', 'paranoiac', 'sick_person']
senticnet['pteridosperm'] = [-0.772, 0, 0.585, -0.835, '#sad', '#disgusting', -0.731, 'progymnosperm', 'welwitschia', 'cycad', 'seed_fern', 'gymnosperm']
senticnet['pterygoid_muscle'] = [0.934, -0.62, 0, 0.79, '#joyful', '#admirable', 0.781, 'voluntary_muscle', 'deltoid', 'skeletal_muscle', 'abductor', 'abductor_muscle']
senticnet['ptomaine'] = [-0.534, 0, 0.678, -0.73, '#angry', '#disgusting', -0.647, 'malady', 'mushroom_poisoning', 'botulism', 'food_poisoning', 'poison']
senticnet['ptomaine_poisoning'] = [-0.534, 0, 0.678, -0.73, '#angry', '#disgusting', -0.647, 'malady', 'mushroom_poisoning', 'botulism', 'ptomaine', 'food_poisoning']
senticnet['pub'] = [0.743, -0.745, 0, 0, '#joyful', '#surprising', 0.496, 'tavern', 'cafe', 'nightclub', 'bar', 'liquor_store']
senticnet['puberty'] = [0.859, 0.91, 0, 0, '#joyful', '#interesting', 0.59, 'tell_everyone', 'reason', 'clarify', 'forethought', 'opinion']
senticnet['puberulent'] = [-0.754, 0, 0.734, -0.825, '#sad', '#disgusting', -0.771, 'haired', 'sericeous', 'furlike', 'pappose', 'pilous']
senticnet['public'] = [0, 0.743, 0, 0.902, '#interesting', '#admirable', 0.548, 'available', 'freely_available', 'population', 'crowd', 'majority']
senticnet['public_assistance'] = [0.753, -0.621, 0, 0.959, '#joyful', '#admirable', 0.778, 'assistance', 'relief', 'economic_aid', 'financial_aid', 'social_insurance']
senticnet['public_easement'] = [0.621, -0.603, 0, 0.545, '#joyful', '#surprising', 0.59, 'privilege', 'perquisite', 'easement', 'right_of_way', 'prerogative']
senticnet['public_embarrassment'] = [-0.062, 0.128, 0.707, -0.677, '#angry', '#disgusting', -0.439, 'embarrassment', 'peer_pressure', 'sudden', 'bad_feeling', 'scandal']
senticnet['public_executioner'] = [-0.628, 0, 0.94, -0.998, '#angry', '#disgusting', -0.855, 'poisoner', 'choker', 'mortal', 'executioner', 'slayer']
senticnet['public_gathering'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'gathering', 'group_gathering', 'mob', 'gather_person', 'several_people']
senticnet['public_house'] = [-0.769, 0, 0.75, -0.563, '#sad', '#angry', -0.694, 'free_house', 'pub', 'saloon', 'pothouse', 'gin_mill']
senticnet['public_knowledge'] = [0.986, -0.974, 0, 0.766, '#joyful', '#surprising', 0.909, 'light', 'open', 'common_knowledge', 'surface', 'cognition']
senticnet['public_place'] = [0, 0.118, 0.023, 0.053, '#interesting', '#admirable', 0.049, 'whorehouse', 'skyscraper', 'tall_building', 'city_hall', 'memorial']
senticnet['public_presentation'] = [0.925, -0.613, 0, 0.686, '#joyful', '#admirable', 0.741, 'benefit', 'pianism', 'song_and_dance', 'routine', 'histrionics']
senticnet['public_servant'] = [0, 0.767, 0, 0.875, '#interesting', '#admirable', 0.547, 'manager', 'colleague', 'office_worker', 'coworker', 'secretary']
senticnet['public_toilet'] = [0.026, 0.096, 0.02, 0, '#joyful', '#interesting', 0.034, 'accountant_office', 'account_department', 'toilet', 'office_build', 'office']
senticnet['public_transport'] = [-0.041, -0.016, 0, -0.092, '#sad', '#disgusting', -0.039, 'wait_train', 'board_subway_train', 'wait', 'find_end_line', 'travel']
senticnet['public_transportation'] = [0, 0, 0, 0.076, '#admirable', '#admirable', 0.025, 'work_oneself', 'work_car', 'stay_sober', 'find_job', 'settle']
senticnet['publish'] = [0, 0.949, 0, 0.897, '#interesting', '#admirable', 0.615, 'make_book', 'magazine', 'write_with_style', 'scribble', 'record_information']
senticnet['publish_book'] = [0, 0.886, 0, 0.767, '#interesting', '#admirable', 0.551, 'write_book', 'artist', 'write_with_style', 'life_style', 'fashion_style']
senticnet['puck'] = [0, 0.912, 0, 0.708, '#interesting', '#admirable', 0.54, 'hockey_puck', 'hockey_stick', 'disk', 'loop', 'bullseye']
senticnet['pucker'] = [-0.926, 0, 0.71, -0.821, '#sad', '#disgusting', -0.819, 'flexure', 'fold', 'crease', 'plication', 'crimp']
senticnet['pudding'] = [0.053, -0.092, 0, 0, '#joyful', '#surprising', 0.048, 'cookie', 'muffin', 'custard', 'biscuit', 'chocolate_dessert']
senticnet['pudding_berry'] = [0.773, -0.55, 0, 0.949, '#joyful', '#admirable', 0.757, 'bunchberry', 'dwarf_cornel', 'crackerberry', 'cornel', 'common_white_dogwood']
senticnet['pudding_head'] = [-0.663, 0, 0.748, -0.991, '#angry', '#disgusting', -0.801, 'dunce', 'dunderhead', 'numskull', 'blockhead', 'bonehead']
senticnet['puddle'] = [0, -0.048, 0.059, -0.086, '#angry', '#disgusting', -0.032, 'squirt', 'dirty_water', 'mud', 'slosh', 'sludge']
senticnet['puff_of_air'] = [0.957, -0.576, 0, 0.857, '#joyful', '#admirable', 0.797, 'bluster', 'puff', 'sandblast', 'gust', 'whiff']
senticnet['puffed_rice'] = [-0.923, 0, 0.609, -0.745, '#sad', '#disgusting', -0.759, 'cold_cereal', 'granola', 'raisin_bran', 'corn_flake', 'bran_flake']
senticnet['puffer'] = [-0.545, 0, 0.829, -0.725, '#angry', '#disgusting', -0.7, 'plectognath', 'plectognathfish', 'blowfish', 'triggerfish', 'filefish']
senticnet['pufferfish'] = [-0.545, 0, 0.829, -0.725, '#angry', '#disgusting', -0.7, 'puffer', 'plectognath', 'blowfish', 'triggerfish', 'filefish']
senticnet['puffiness'] = [-0.735, 0, 0.94, -0.875, '#angry', '#disgusting', -0.85, 'edema', 'oedema', 'hydrops', 'dropsy', 'bloat']
senticnet['pugilist'] = [-0.081, 0, -0.114, 0, '#sad', '#scared', -0.065, 'mediocrity', 'effect', 'suspicion', 'exclusion', 'disconnection']
senticnet['pugnacity'] = [-0.507, 0, 0.817, -0.593, '#angry', '#disgusting', -0.639, 'disagreeableness', 'truculence', 'truculency', 'bellicosity', 'bellicoseness']
senticnet['puke'] = [0, 0, 0, -0.79, '#disgusting', '#disgusting', -0.263, 'vomit', 'blackout', 'get_sick', 'throw_up', 'hangover']
senticnet['pull'] = [0, 0.872, 0, 0.976, '#interesting', '#admirable', 0.616, 'tug', 'carry_object', 'tow', 'extend', 'drag']
senticnet['pull_ahead'] = [0.949, -0.854, 0, 0.926, '#joyful', '#admirable', 0.91, 'tally', 'steal', 'score', 'hit', 'rack_up']
senticnet['pull_apart'] = [-0.091, 0, 0, 0, '#sad', '#sad', -0.03, 'tear_apart', 'painful_injury', 'break_apart', 'pulverize', 'small_cut']
senticnet['pull_away'] = [-0.621, 0, 0.516, -0.998, '#sad', '#disgusting', -0.712, 'retreat', 'retrograde', 'back_up', 'move', 'give_up']
senticnet['pull_back'] = [-0.52, 0, 0.524, -0.693, '#angry', '#disgusting', -0.579, 'retreat', 'retrograde', 'back_up', 'move', 'give_up']
senticnet['pull_car'] = [-0.065, 0.164, -0.117, 0.238, '#interesting', '#admirable', 0.073, 'move_object', 'gain_speed', 'pull', 'movement', 'turn_around']
senticnet['pull_cart'] = [-0.056, 0.088, 0, 0.07, '#interesting', '#admirable', 0.034, 'play_dead', 'jump_over_fence', 'many_different_colors', 'jump_fence', 'group_animal']
senticnet['pull_down_pant'] = [-0.054, 0, -0.084, -0.081, '#scared', '#disgusting', -0.073, 'unzip_pant', 'find_restroom', 'find_toilet', 'serve_beer', 'full_bladder']
senticnet['pull_fast_one_on'] = [-0.691, 0, 0.893, -0.772, '#angry', '#disgusting', -0.785, 'delude', 'deceive', 'cozen', 'snooker', 'lead_on']
senticnet['pull_leg_of'] = [-0.62, 0, 0.9, -0.911, '#angry', '#disgusting', -0.81, 'dupe', 'slang', 'put_on', 'cod', 'take_in']
senticnet['pull_muscle'] = [-0.079, -0.078, 0.022, -0.135, '#sad', '#disgusting', -0.053, 'sore_muscle', 'increased_heart_rate', 'breahard', 'become_exhausted', 'sweat']
senticnet['pull_off_road'] = [0, 0.954, 0, 0.768, '#interesting', '#admirable', 0.574, 'carry_luggage', 'locate_place', 'get_plane', 'get_bus', 'arrive_late']
senticnet['pull_out'] = [-0.066, 0.109, -0.055, 0.158, '#interesting', '#admirable', 0.049, 'elasticity', 'stretch_out', 'grow_long', 'widen', 'advance_civilization']
senticnet['pull_string'] = [0.086, -0.148, 0.184, -0.156, '#angry', '#disgusting', -0.035, 'appreciate_music', 'string_break', 'sound_good', 'entertain_audience', 'entertain_others']
senticnet['pull_tooth'] = [-0.045, -0.009, 0, -0.083, '#sad', '#disgusting', -0.04, 'dentist_work', 'order_french_fries', 'take_number', 'wait_patiently', 'wait']
senticnet['pull_trigger'] = [-0.257, 0, -0.198, -0.161, '#sad', '#scared', -0.205, 'end_life', 'feel_anger', 'stab_knife', 'feel_remorse', 'arrest_police']
senticnet['pull_up'] = [0.023, 0.25, -0.105, 0.275, '#interesting', '#admirable', 0.148, 'rise_up', 'move_up', 'bring_up', 'raise_up', 'go_up']
senticnet['pull_up_cover'] = [-0.034, 0, 0, -0.045, '#sad', '#disgusting', -0.026, 'toss_turn', 'sleep_day', 'wear_pyjamas', 'oversleep', 'close_eye']
senticnet['pull_wagon'] = [-0.08, 0, -0.069, 0, '#sad', '#scared', -0.05, 'drive_around', 'near_destination', 'fly_around', 'notice_problem', 'shovel_snow']
senticnet['pull_weed'] = [-0.073, 0, 0, -0.057, '#sad', '#disgusting', -0.043, 'plant_garden', 'plant_flower', 'plant_seed', 'dig_dirt', 'water_flower']
senticnet['pulley'] = [0, 0.142, 0, 0.125, '#interesting', '#admirable', 0.089, 'weight_machine', 'power_drill', 'screw', 'screwdriver', 'air_pump']
senticnet['pullulation'] = [-0.778, 0, 0.764, -0.548, '#sad', '#angry', -0.697, 'asexual_reproduction', 'apomixis', 'blastogenesis', 'budding', 'fission']
senticnet['pulpit'] = [0.023, 0.218, 0.01, 0.235, '#interesting', '#admirable', 0.155, 'confessional', 'altar', 'chapel', 'temple', 'christianity']
senticnet['pulse'] = [-0.183, -0.007, -0.18, 0, '#sad', '#scared', -0.119, 'collide', 'amount_nothing', 'hold_two_together', 'feel_terrible', 'impulse']
senticnet['pulseless_disease'] = [-0.853, 0, 0.657, -0.868, '#sad', '#disgusting', -0.793, 'arteritis', 'temporal_arteritis', 'rubor', 'redness', 'polyarteritis']
senticnet['pulverise'] = [-0.183, -0.007, -0.18, 0, '#sad', '#scared', -0.119, 'pulverize', 'violent_action', 'smash', 'hit_hard', 'melt_away']
senticnet['pulverization'] = [-0.982, 0, 0.516, -0.908, '#sad', '#disgusting', -0.802, 'devastation', 'atomization', 'annihilation', 'vaporization', 'destruction']
senticnet['pulverize'] = [-0.183, -0.007, -0.18, 0, '#sad', '#scared', -0.119, 'pulverise', 'violent_action', 'smash', 'hit_hard', 'melt_away']
senticnet['puma'] = [-0.06, 0, -0.046, 0, '#sad', '#scared', -0.035, 'small_dog', 'red-bellied_black_snake', 'eastern_brown_snake', 'wiener_dog', 'many_humans']
senticnet['pump_air'] = [0.86, -0.718, 0, 0, '#joyful', '#surprising', 0.526, 'picture_taken', 'become_intoxicated', 'outgo_personality', 'joke_around', 'candle_light']
senticnet['pump_blood'] = [0.932, 0, 0, 0.859, '#joyful', '#admirable', 0.597, 'eat_live', 'live_apartment', 'involuntary', 'happiness', 'ease_pain']
senticnet['pumpkin'] = [0, -0.015, 0.037, -0.046, '#angry', '#disgusting', -0.023, 'pear', 'green_apple', 'apricot', 'cherry', 'lime']
senticnet['pumpkin_pie'] = [0.972, 0, 0, 0, '#joyful', '#joyful', 0.324, 'chocolate_dessert', 'unhealthy_food', 'food_bake', 'ice_cream', 'chewy']
senticnet['punch'] = [0, 0, 0.781, -0.898, '#angry', '#disgusting', -0.56, 'hurt_else', 'cut_oneself', 'advance_battle', 'jump_off_cliff', 'fight_enemy']
senticnet['punch_bag'] = [0, -0.066, 0.077, -0.109, '#angry', '#disgusting', -0.04, 'lose_ball', 'increase_price', 'ball_bounce', 'tired_iron', 'buy_ball']
senticnet['punch_face'] = [0, 0, 0.72, -0.792, '#angry', '#disgusting', -0.504, 'go_insane', 'feel_stupid', 'fall_down_flight_stair', 'lose_mind', 'feel_ashamed']
senticnet['punctual'] = [0, 0.951, 0, 0.974, '#interesting', '#admirable', 0.642, 'ethic', 'diversity', 'new_experience', 'self_esteem', 'involve']
senticnet['punctuation'] = [-0.03, 0.144, 0, 0.173, '#interesting', '#admirable', 0.096, 'reason_why', 'finger_action', 'indicate', 'sport_score', 'full_stop']
senticnet['puncture'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'boring', 'pierce', 'bore', 'uninteresting', 'dull']
senticnet['pungent'] = [0, 0, -0.915, -0.823, '#scared', '#disgusting', -0.579, 'barbed', 'biting', 'acrid', 'mordacious', 'nipping']
senticnet['punic'] = [-0.669, 0, 0.709, -0.881, '#angry', '#disgusting', -0.753, 'untrue', 'apostate', 'treacherous', 'perfidious', 'unfaithful']
senticnet['punish'] = [-0.146, -0.042, 0, -0.102, '#sad', '#disgusting', -0.069, 'form_of_punishment', 'inflict_pain', 'death_penalty', 'kill', 'form_of_punishmentment']
senticnet['punish_child'] = [0, -0.066, 0.077, -0.109, '#angry', '#disgusting', -0.04, 'punish', 'beat', 'slap', 'punishment', 'cry']
senticnet['punish_crime'] = [0, 0, 0, 0.867, '#admirable', '#admirable', 0.289, 'seek_justice', 'convict_criminal', 'find_guilty', 'punish_criminal', 'question_witness']
senticnet['punish_criminal'] = [0, 0.136, -0.071, 0.082, '#interesting', '#admirable', 0.049, 'justice', 'trial', 'see_justice_done', 'try_case', 'pass_judgment']
senticnet['punishment'] = [-0.141, 0.116, -0.203, -0.034, '#sad', '#scared', -0.087, 'put_in_jail', 'incarceration', 'jail_time', 'send_to_jail', 'felony']
senticnet['punitive'] = [-0.753, 0, 0.981, -0.588, '#sad', '#angry', -0.774, 'retaliatory', 'penitentiary', 'correctional', 'retributive', 'retributory']
senticnet['punitive_damage'] = [-0.657, 0, 0.776, -0.767, '#angry', '#disgusting', -0.733, 'amends', 'damages', 'indemnification', 'redress', 'restitution']
senticnet['punitory'] = [-0.604, 0, 0.87, -0.649, '#angry', '#disgusting', -0.708, 'retaliatory', 'penitentiary', 'correctional', 'retributive', 'retributory']
senticnet['punk'] = [-0.727, 0, 0.748, -0.824, '#angry', '#disgusting', -0.766, 'criminal', 'bully', 'outlaw', 'malefactor', 'felon']
senticnet['pup'] = [0.71, 0, 0, 0.957, '#joyful', '#admirable', 0.556, 'goof', 'magical', 'bloodhound', 'chance', 'karma']
senticnet['pupil'] = [-0.082, -0.028, 0, -0.051, '#sad', '#disgusting', -0.035, 'professor', 'group_student', 'school_division', 'good_student', 'college_student']
senticnet['pupillary_reflex'] = [-0.929, 0, 0.923, -0.596, '#sad', '#angry', -0.816, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['puppy_love'] = [0.522, 0.674, -0.277, 0.27, '#joyful', '#interesting', 0.396, 'calf_love', 'infatuation', 'amatory', 'amorousness', 'amorous']
senticnet['purchase'] = [-0.057, 0.175, 0, 0.117, '#interesting', '#admirable', 0.078, 'establish_credit', 'cash_check', 'pay_goods', 'pay_debt', 'buy_goods_service']
senticnet['purchase_book'] = [-0.062, -0.019, 0, -0.044, '#sad', '#disgusting', -0.029, 'choose_book', 'bad_read', 'store_book', 'sell_book', 'hold_book']
senticnet['purchase_car'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'car', 'buy_motorbike', 'buy', 'buy_car', 'buy_object']
senticnet['purchase_cellular_phone'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'pay_bill', 'pay_check', 'pay_credit_card', 'pay_cash', 'spend_money']
senticnet['purchase_food'] = [-0.036, -0.004, 0.036, 0, '#sad', '#angry', -0.023, 'buy_bread', 'buy_grocery', 'get_grocery', 'buy_food', 'shop_grocery']
senticnet['purchase_gift'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'buy_gift', 'gift', 'christmas_gift', 'birthday_gift', 'buy_happiness']
senticnet['purchase_goods'] = [0, 0.095, -0.054, 0.132, '#interesting', '#admirable', 0.058, 'buy_gum', 'buy', 'buy_cheap_item', 'fresh_breathe', 'spread_love']
senticnet['purchase_grocery'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'buy_milk', 'buy_vegetable', 'purchase_item', 'shop_grocery', 'buy_grocery']
senticnet['purchase_house'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'family_nest', 'love_back', 'protection', 'shelter', 'buy_home']
senticnet['purchase_item'] = [-0.058, 0.106, 0, 0.06, '#interesting', '#admirable', 0.036, 'buy_item', 'get_goods', 'buy_stuff', 'buy_cheap_item', 'buy_goods']
senticnet['purchase_pharmacy'] = [-0.039, -0.04, 0.074, -0.054, '#angry', '#disgusting', -0.042, 'find_ranch', 'require_good_health', 'eaten', 'find_animal', 'ranch']
senticnet['purchase_ticket'] = [-0.062, 0, 0, -0.034, '#sad', '#disgusting', -0.032, 'buy_ticket', 'book_ticket', 'find_out_play', 'money_ticket', 'buy_ticket_theater']
senticnet['pure'] = [0.053, 0.162, -0.098, 0.297, '#interesting', '#admirable', 0.138, 'godliness', 'soft', 'white', 'capitalize', 'general_term']
senticnet['pure_gold'] = [-0.624, 0, 0.504, -0.798, '#sad', '#disgusting', -0.642, 'green_gold', 'atomic_number_79', 'gold_dust', 'guinea_gold', 'noble_metal']
senticnet['purgative'] = [0.945, -0.998, 0, 0.873, '#joyful', '#surprising', 0.939, 'medicament', 'medicinal_drug', 'medication', 'aloe', 'bitter_aloe']
senticnet['purify'] = [0.581, -0.885, 0, 0.534, '#joyful', '#surprising', 0.667, 'better', 'improve', 'pure', 'meliorate', 'amend']
senticnet['purity'] = [0, 0.08, 0, 0.144, '#interesting', '#admirable', 0.075, 'cloud', 'mist', 'precipitate', 'fog', 'initiation']
senticnet['purloin'] = [0, 0, -0.811, -0.95, '#scared', '#disgusting', -0.587, 'cabbage', 'pinch', 'pilfer', 'abstract', 'snarf']
senticnet['purple'] = [0.591, -0.553, 0, 0.514, '#joyful', '#surprising', 0.553, 'violet', 'mauve', 'lavender', 'reddish_purple', 'royal_purple']
senticnet['purple_color'] = [-0.136, 0, 0, 0, '#sad', '#sad', -0.045, 'yellow_blue', 'blue_yellow', 'green', 'violet', 'purple']
senticnet['purple_milk_vetch'] = [-0.943, 0, 0.608, -0.954, '#sad', '#disgusting', -0.835, 'wild_licorice', 'wild_liquorice', 'alpine_milk_vetch', 'milk_vetch', 'woody_plant']
senticnet['purpose'] = [-0.057, 0.278, -0.176, 0.319, '#interesting', '#admirable', 0.121, 'motive', 'intend', 'conclude', 'reason', 'explanation']
senticnet['purpose_container'] = [0.088, 0.186, -0.086, 0.163, '#interesting', '#admirable', 0.117, 'design', 'artwork', 'floral', 'ornamentation', 'like_paint']
senticnet['purposeless'] = [-0.997, 0, 0.658, -0.736, '#sad', '#disgusting', -0.797, 'adrift', 'afloat', 'aimless', 'directionless', 'planless']
senticnet['purpura'] = [-0.866, 0, 0.668, -0.543, '#sad', '#angry', -0.692, 'blood_disease', 'blood_disorder', 'disease', 'blood_problem', 'cancer']
senticnet['purulence'] = [-0.525, 0, 0.538, -0.959, '#angry', '#disgusting', -0.674, 'sanies', 'pus', 'gleet', 'suppuration', 'ichor']
senticnet['purview'] = [0.517, -0.867, 0, 0.663, '#surprising', '#admirable', 0.682, 'reach', 'range', 'compass', 'scope', 'orbit']
senticnet['pus'] = [-0.525, 0, 0.538, -0.959, '#angry', '#disgusting', -0.674, 'sanies', 'gleet', 'purulence', 'suppuration', 'ichor']
senticnet['push'] = [0, 0.813, 0, 0.733, '#interesting', '#admirable', 0.515, 'motion', 'tow', 'revolve', 'haul', 'lunge']
senticnet['push_aside'] = [-0.863, 0, 0.897, -0.813, '#sad', '#angry', -0.858, 'disregard', 'ignore', 'brush_off', 'flout', 'dismiss']
senticnet['push_button'] = [-0.048, 0.124, 0, 0.165, '#interesting', '#admirable', 0.08, 'finger_action', 'sport_score', 'sharpness', 'sharp_corner', 'bend']
senticnet['push_cart'] = [-0.809, 0, 0.718, -0.797, '#sad', '#disgusting', -0.775, 'walk_exercise', 'lose_wallet', 'go_debt', 'pay_dinner', 'spend_much_money']
senticnet['push_forward'] = [-0.978, 0, 0.504, -0.52, '#sad', '#disgusting', -0.667, 'rush', 'race', 'hotfoot', 'hasten', 'hie']
senticnet['push_hard'] = [0, 0, -0.853, -0.716, '#scared', '#disgusting', -0.523, 'make_newspaper', 'press', 'hand_action', 'print_newspaper', 'hand_movement']
senticnet['push_limit'] = [-0.102, 0, -0.062, 0, '#sad', '#scared', -0.055, 'travel_work', 'fly_plane', 'hurry_work', 'bicycle_work', 'rush_work']
senticnet['push_out'] = [-0.965, 0, 0.814, -0.988, '#sad', '#disgusting', -0.922, 'bouncer', 'strike', 'kick_out', 'push', 'keep_distant']
senticnet['push_pin'] = [0, 0, -0.9, -0.771, '#scared', '#disgusting', -0.557, 'thumb_tack', 'pin_up_girl', 'glue_stick', 'letter_opener', 'pair_of_scissors']
senticnet['push_together'] = [0.052, 0.077, 0, 0.171, '#interesting', '#admirable', 0.1, 'large_number', 'group_of_people', 'bunch_person', 'large_group', 'mass_person']
senticnet['push_up'] = [0, 0.151, -0.088, 0.232, '#interesting', '#admirable', 0.098, 'good_human', 'active', 'healthy_activity', 'bra', 'result_injury']
senticnet['push_wind'] = [-0.034, 0.094, -0.047, 0.142, '#interesting', '#admirable', 0.052, 'exhalation', 'body_reaction', 'mouth_action', 'bad_odor', 'body_action']
senticnet['pushpin'] = [0, 0, -0.869, -0.844, '#scared', '#disgusting', -0.571, 'aspirin', 'scalpel', 'ibuprofen', 'capsule', 'palliative']
senticnet['puss'] = [-0.091, 0, -0.141, 0.086, '#sad', '#scared', -0.049, 'abrasion', 'painful_injury', 'body_reaction', 'infection', 'ouch']
senticnet['pussycat'] = [0.565, -0.507, 0, 0.865, '#joyful', '#admirable', 0.646, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['pustule'] = [-0.816, 0, 0.73, -0.99, '#sad', '#disgusting', -0.845, 'blister', 'pimple', 'zit', 'hickey', 'bleb']
senticnet['put_across'] = [0.743, -0.517, 0, 0.551, '#joyful', '#admirable', 0.604, 'communicate', 'pass_on', 'pass', 'pass_along', 'get_across']
senticnet['put_at_stake'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'danger', 'dangerous', 'trouble', 'double_trouble', 'problem']
senticnet['put_away'] = [-0.091, 0, -0.141, 0.086, '#sad', '#scared', -0.049, 'set_aside', 'stow_away', 'push_aside', 'preserve', 'leave']
senticnet['put_back'] = [0.635, 0.639, -0.243, 0.291, '#joyful', '#interesting', 0.441, 'heal', 'back_up', 'restore', 'restore_energy', 'fill_up']
senticnet['put_bag'] = [-0.217, 0.126, -0.149, 0, '#sad', '#scared', -0.08, 'price_goods', 'sign_agreement', 'mind_store', 'market_product', 'explain_everything']
senticnet['put_basis'] = [0.487, 0.675, -0.267, 0.266, '#joyful', '#interesting', 0.387, 'build_foundation', 'solid_basis', 'study_hard', 'intelligent', 'gather_intelligence']
senticnet['put_bath_suit'] = [-0.09, 0.067, -0.089, -0.047, '#sad', '#scared', -0.053, 'falling_water', 'go_colorado', 'water_fall', 'take_off_clothes', 'remove_clothes']
senticnet['put_bid'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'make_comparison', 'good_bet', 'ask_question', 'share_opinion', 'spread_out']
senticnet['put_box'] = [-0.37, 0, -0.308, -0.07, '#sad', '#scared', -0.249, 'say_prayer', 'end_relationship', 'see_light', 'keep_promise', 'become_depressed']
senticnet['put_clean_clothes'] = [0.928, 0.778, 0, 0, '#joyful', '#interesting', 0.569, 'nice_clothes', 'change_clothes', 'put_nice_clothes', 'take_bath', 'take_shower']
senticnet['put_clothes'] = [0, 0.076, -0.065, 0.205, '#interesting', '#admirable', 0.072, 'cover_body', 'bring_present', 'christmas', 'carry_book', 'move_away']
senticnet['put_clothes_back'] = [-0.046, 0, -0.071, -0.101, '#scared', '#disgusting', -0.073, 'clock_out', 'sit_back_relax', 'quit_work', 'make_sex', 'stop_work']
senticnet['put_coat'] = [0.337, 0, 0, 0.093, '#joyful', '#admirable', 0.143, 'feel_comfortable', 'feel_warm', 'spread_germ', 'wear_sweater', 'light_cigar']
senticnet['put_coin'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'buy_water', 'buy_drink', 'play_video_game', 'coin', 'buy_cheap_item']
senticnet['put_costume'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'star_movie', 'become_artist', 'recite_poem', 'become_actor', 'wit']
senticnet['put_down'] = [-0.135, 0, -0.069, 0, '#sad', '#scared', -0.068, 'reject', 'rest_time', 'inactivity', 'leave_behind', 'recline']
senticnet['put_effort'] = [-0.054, 0.08, -0.054, 0.158, '#interesting', '#admirable', 0.043, 'hold_out', 'resist', 'strike_against', 'hold_match', 'change_plan']
senticnet['put_envelope'] = [-0.127, 0, 0, -0.068, '#sad', '#disgusting', -0.065, 'address_envelope', 'make_note', 'store_pen', 'make_mark_paper', 'write_word']
senticnet['put_feet_up'] = [0.708, -0.728, 0, 0, '#joyful', '#surprising', 0.479, 'drink_coffee', 'drink_cup_coffee', 'cafe', 'drink_soda', 'fall_asleep']
senticnet['put_food'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'food', 'prepare_meal', 'cook', 'serve_food', 'prepare_food']
senticnet['put_food_into_mouth'] = [0.769, 0, 0, 0, '#joyful', '#joyful', 0.256, 'make_breakfast', 'enjoy_meal', 'appetite', 'prepare_meal', 'prepare_breakfast']
senticnet['put_food_mouth'] = [0.026, 0.069, 0, 0, '#joyful', '#interesting', 0.032, 'eat_food', 'eat_beef', 'eat_dinner', 'chew_food', 'eat_much']
senticnet['put_food_table'] = [0.078, 0, 0, 0, '#joyful', '#joyful', 0.026, 'tip_waiter', 'finish_job', 'eat_food', 'buy_food', 'buy_sandwich']
senticnet['put_foot'] = [0, -0.089, 0.127, -0.136, '#angry', '#disgusting', -0.058, 'dress_appropriately', 'put_shoes', 'dirty_magazine', 'velcro', 'shoe']
senticnet['put_garbage'] = [-0.05, -0.018, 0, -0.127, '#sad', '#disgusting', -0.053, 'hold_trash', 'store_trash', 'put_trash', 'rubbish', 'garbage']
senticnet['put_gear'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'use_car', 'start_engine', 'steer_car', 'turn_ignition', 'burn_gasoline']
senticnet['put_glass'] = [-0.079, 0, 0, -0.086, '#sad', '#disgusting', -0.055, 'learn_how_read', 'go_museum', 'open_up', 'unfold', 'learn_read']
senticnet['put_groceries'] = [0, 0.07, 0, 0.067, '#interesting', '#admirable', 0.046, 'boot', 'car_trunk', 'extra_tyre', 'store', 'storage_place']
senticnet['put_hand'] = [0, 0.133, -0.053, 0.149, '#interesting', '#admirable', 0.076, 'restrict_access', 'door_knob', 'keep_someone_out', 'handle', 'control_access']
senticnet['put_helmet'] = [-0.08, -0.005, 0.099, 0, '#sad', '#angry', -0.058, 'find_ball', 'good_balance', 'wear_good_shoes', 'use_leg', 'buy_shoes']
senticnet['put_ice'] = [0.097, -0.102, 0.054, 0, '#joyful', '#surprising', 0.048, 'bake_food', 'bake', 'make_grain', 'roast', 'birthday_treat']
senticnet['put_in'] = [-0.69, 0, 0.883, -0.912, '#angry', '#disgusting', -0.828, 'stick_in', 'enclose', 'insert', 'inclose', 'feed_in']
senticnet['put_in_evidence'] = [0.026, 0.227, 0, 0.233, '#interesting', '#admirable', 0.162, 'best_moment', 'sport_highlight', 'football_highlight', 'television_news', 'highlight']
senticnet['put_in_jail'] = [-0.359, 0, -0.243, -0.133, '#sad', '#scared', -0.245, 'criminal', 'arrest', 'injustice', 'send_to_jail', 'go_to_jail']
senticnet['put_ink_paper'] = [-0.025, 0.088, 0, 0.102, '#interesting', '#admirable', 0.055, 'note', 'unit_language', 'message', 'remark', 'form_of_communication']
senticnet['put_jogging_shoes'] = [-0.078, -0.06, 0.074, -0.051, '#sad', '#angry', -0.048, 'put_running_shoes', 'put_sneaker', 'wear_running_shoes', 'bring_dog', 'put_shoes']
senticnet['put_key_ignition'] = [0, 0.098, 0, 0.107, '#interesting', '#admirable', 0.068, 'check_mirror', 'fasten_seatbelt', 'turn_engine', 'change_gear', 'adjust_seat']
senticnet['put_liquid'] = [0, 0.091, -0.06, 0.114, '#interesting', '#admirable', 0.048, 'chill_drink', 'drink_liquid', 'hold_coffee', 'serve_beer', 'store_liquid']
senticnet['put_mask'] = [-0.052, 0, 0, -0.14, '#sad', '#disgusting', -0.064, 'buy_wood', 'seek_psychiatric_help', 'prepare_fight', 'use_knife', 'try_calm_down']
senticnet['put_money'] = [0, 0.177, 0, 0.085, '#interesting', '#admirable', 0.087, 'keep_money', 'money_holder', 'require_signature', 'hold_money', 'money_storage']
senticnet['put_mouth'] = [-0.063, 0.183, 0.651, -0.642, '#angry', '#disgusting', -0.391, 'runny_nose', 'chew', 'pierce', 'mastication', 'allergic_reaction']
senticnet['put_music'] = [0.966, 0.738, 0, 0, '#joyful', '#interesting', 0.568, 'sense_rhythm', 'free_ticket', 'turn_music', 'stressful_situation', 'type_of_music']
senticnet['put_napkin_lap'] = [-0.077, 0, 0, 0, '#sad', '#sad', -0.026, 'market', 'refrigerate', 'hammer_nail', 'buy_market', 'defrost']
senticnet['put_nice_clothes'] = [0.928, 0.778, 0, 0, '#joyful', '#interesting', 0.569, 'nice_clothes', 'put_clean_clothes', 'change_clothes', 'take_bath', 'take_shower']
senticnet['put_off'] = [-0.798, 0, 0.87, 0, '#sad', '#angry', -0.556, 'confusedly', 'disordered', 'discombobulation', 'confused', 'confusing']
senticnet['put_old_clothes'] = [-0.054, 0.107, 0.043, 0.058, '#interesting', '#admirable', 0.023, 'use_vacuum_cleaner', 'vacuum_floor', 'clean_often', 'vacuum_carpet', 'remove_paint']
senticnet['put_on'] = [-0.587, 0, 0.955, -0.698, '#angry', '#disgusting', -0.747, 'hat', 'scarf', 'try_on', 'try', 'dress']
senticnet['put_on_line'] = [-0.602, 0, 0.849, -0.861, '#angry', '#disgusting', -0.771, 'hazard', 'stake', 'jeopardize', 'essay', 'assay']
senticnet['put_one_across'] = [0.636, -0.692, 0, 0.527, '#joyful', '#surprising', 0.618, 'lead_astray', 'pull_leg_of', 'kid', 'betray', 'deceive']
senticnet['put_one_over'] = [0.653, -0.954, 0, 0.962, '#surprising', '#admirable', 0.856, 'lead_astray', 'pull_leg_of', 'kid', 'betray', 'deceive']
senticnet['put_order'] = [0, 0.076, 0, 0.099, '#interesting', '#admirable', 0.058, 'tidy_up', 'sort', 'clean_sink', 'neat', 'neatness']
senticnet['put_out'] = [-0.122, 0, -0.071, -0.133, '#sad', '#disgusting', -0.109, 'dress_doll', 'wear_dress', 'gather_flower', 'hold_breath', 'wear_skirt']
senticnet['put_out_fire'] = [0, -0.072, 0, 0, '#surprising', '#surprising', 0.024, 'extinguish_fire', 'make_ice', 'bake_bread', 'feed_baby', 'bake_cookie']
senticnet['put_paper'] = [-0.038, 0.121, 0, 0.096, '#interesting', '#admirable', 0.06, 'keep_paper', 'hold_pencil', 'store_document', 'organize_paper', 'use_paper']
senticnet['put_pocket'] = [-0.909, 0, -0.869, 0, '#sad', '#scared', -0.593, 'comparison_shop', 'gift_wrap', 'spend_much_money', 'run_out_money', 'receive_change']
senticnet['put_protective_gear'] = [-0.074, 0, 0.07, 0, '#sad', '#angry', -0.048, 'buy_shoes', 'put_helmet', 'gather_team', 'good_balance', 'buy_ball']
senticnet['put_pyjamas'] = [-0.983, 0, 0, 0, '#sad', '#sad', -0.328, 'call_sick', 'count_sheep', 'go_room', 'sleepwalk', 'turn_out_light']
senticnet['put_radio'] = [0, 0, 0, 0.882, '#admirable', '#admirable', 0.294, 'listen_cd', 'turn_on_radio', 'radio', 'listen_music', 'switch_on_radio']
senticnet['put_running_shoes'] = [-0.092, -0.017, 0.05, 0, '#sad', '#angry', -0.042, 'wear_running_shoes', 'wear_good_shoes', 'put_jogging_shoes', 'stretch', 'put_tennis_shoes']
senticnet['put_screw'] = [0, 0, 0, 0.882, '#admirable', '#admirable', 0.294, 'remove_screw', 'oil', 'screwdriver', 'lubricant', 'fuel']
senticnet['put_shoes'] = [0, 0.144, -0.079, 0.222, '#interesting', '#admirable', 0.096, 'shoe', 'wear_shoes', 'jogging', 'put_jogging_shoes', 'sport']
senticnet['put_sneaker'] = [0, 0.144, -0.079, 0.222, '#interesting', '#admirable', 0.096, 'bring_dog', 'put_jogging_shoes', 'move_leg', 'wear_proper_clothes', 'stretch_muscle']
senticnet['put_sock'] = [-0.057, -0.011, 0.014, -0.035, '#sad', '#disgusting', -0.032, 'step_aside', 'step_out', 'stay_still', 'meander', 'wilt']
senticnet['put_stuff'] = [0, 0.144, -0.079, 0.222, '#interesting', '#admirable', 0.096, 'carry_item', 'carry_stuff', 'hold_stuff', 'hold_small_item', 'carry_book']
senticnet['put_swimsuit'] = [-0.053, 0, 0.035, 0, '#sad', '#angry', -0.029, 'catch_fish', 'go_lake', 'go_pool', 'put_bath_suit', 'cool_water']
senticnet['put_tennis_shoes'] = [0, 0.144, -0.079, 0.222, '#interesting', '#admirable', 0.096, 'stretch_first', 'stretch_muscle', 'join_gym', 'run', 'run_long_distance']
senticnet['put_to_death'] = [0.733, -0.711, 0, 0.877, '#joyful', '#admirable', 0.774, 'crucify', 'kill', 'burn', 'hang', 'string_up']
senticnet['put_to_sleep'] = [-0.651, 0, 0.824, -0.869, '#angry', '#disgusting', -0.781, 'anesthesia', 'operation', 'general_anesthesia', 'surgery', 'local_anesthesia']
senticnet['put_together'] = [0, 0.211, -0.121, 0.286, '#interesting', '#admirable', 0.125, 'bring_together', 'fuse', 'redo', 'fuse_together', 'request']
senticnet['put_trash'] = [0, 0, 0.775, -0.865, '#angry', '#disgusting', -0.547, 'hold_trash', 'put_garbage', 'store_trash', 'rubbish', 'garbage']
senticnet['put_two_together'] = [-0.101, 0.14, 0, 0.105, '#interesting', '#admirable', 0.048, 'make_right_decision', 'reach_conclusion', 'think', 'analysis', 'brain_activity']
senticnet['put_uniform'] = [0.782, 0, 0, 0.706, '#joyful', '#admirable', 0.496, 'go_to_work', 'respect', 'gain_respect', 'respect_law', 'respect_authority']
senticnet['put_up'] = [-0.101, 0.14, 0, 0.105, '#interesting', '#admirable', 0.048, 'build_house', 'put_up_construction', 'set_up', 'construct_skyscraper', 'erect']
senticnet['put_up_construction'] = [-0.101, 0.14, 0, 0.105, '#interesting', '#admirable', 0.048, 'build_house', 'put_up', 'set_up', 'construct_skyscraper', 'erect']
senticnet['put_walking_shoes'] = [0, 0.144, -0.079, 0.222, '#interesting', '#admirable', 0.096, 'put_shoes', 'wear_shoes', 'leave_house_first', 'dress_appropriately', 'look_map']
senticnet['put_warm_clothes'] = [0, -0.037, 0.059, -0.053, '#angry', '#disgusting', -0.025, 'autumn', 'snow', 'sleigh', 'snow_fall', 'cold_weather']
senticnet['put_water'] = [-0.06, 0.103, 0, 0.073, '#interesting', '#admirable', 0.039, 'translucent', 'see_through', 'see_thru', 'transparent', 'clear_solid']
senticnet['putoff'] = [-0.618, 0, 0.817, -0.78, '#angry', '#disgusting', -0.738, 'pretence', 'feigning', 'dissembling', 'pretense', 'pretext']
senticnet['putout'] = [-0.83, 0, 0.965, -0.845, '#angry', '#disgusting', -0.88, 'out', 'sacrifice', 'force', 'force_out', 'force_play']
senticnet['putrefacient'] = [-0.657, 0, 0.995, -0.625, '#sad', '#angry', -0.759, 'dirty', 'putrefactive', 'infected', 'abscessed', 'contaminative']
senticnet['putrefaction'] = [-0.557, 0, 0.605, -0.551, '#sad', '#angry', -0.571, 'decay', 'putrescence', 'rottenness', 'corruption', 'putridness']
senticnet['putrefactive'] = [-0.657, 0, 0.995, -0.625, '#sad', '#angry', -0.759, 'dirty', 'infected', 'putrefacient', 'abscessed', 'contaminative']
senticnet['putrescence'] = [-0.557, 0, 0.605, -0.551, '#sad', '#angry', -0.571, 'decay', 'putrefaction', 'rottenness', 'corruption', 'putridness']
senticnet['putridness'] = [-0.557, 0, 0.605, -0.551, '#sad', '#angry', -0.571, 'decay', 'putrescence', 'rottenness', 'corruption', 'putrefaction']
senticnet['putz'] = [0.663, -0.687, 0, 0.892, '#surprising', '#admirable', 0.747, 'saphead', 'muggins', 'tomfool', 'fool', 'sap']
senticnet['puzzle'] = [0, 0, 0.705, -0.901, '#angry', '#disgusting', -0.535, 'pose', 'perplex', 'stupefy', 'flummox', 'mystify']
senticnet['puzzle_game'] = [0.04, 0.07, 0, 0, '#joyful', '#interesting', 0.037, 'breaking_news', 'grade_paper', 'crossword', 'crossword_puzzle', 'game']
senticnet['puzzled'] = [-0.833, 0, 0.925, -0.994, '#angry', '#disgusting', -0.917, 'at_loss', 'nonplused', 'confused', 'perplexed', 'bewildered']
senticnet['puzzlement'] = [-0.616, 0, 0.832, -0.559, '#sad', '#angry', -0.669, 'confusion', 'disarray', 'mental_confusion', 'confusedness', 'muddiness']
senticnet['puzzling'] = [0, 0, -0.721, -0.706, '#scared', '#disgusting', -0.476, 'perplex', 'stick', 'get', 'puzzle', 'vex']
senticnet['pycnodysostosis'] = [-0.871, 0, 0.873, -0.621, '#sad', '#angry', -0.788, 'dwarfism', 'genetic_disease', 'genetic_disorder', 'genetic_abnormality', 'genetic_defect']
senticnet['pyramid'] = [0, 0.11, 0, 0.077, '#interesting', '#admirable', 0.062, 'mountain', 'skier', 'mound', 'excavation', 'snake']
senticnet['pyre'] = [-0.817, 0, 0.758, -0.966, '#sad', '#disgusting', -0.847, 'heap', 'agglomerate', 'piles', 'mound', 'cumulation']
senticnet['pyrocellulose'] = [-0.886, 0, 0.87, -0.761, '#sad', '#angry', -0.839, 'cellulose_ester', 'pyroxylin', 'pyroxyline', 'cellulose_nitrate', 'nitrate']
senticnet['pyromania'] = [-0.898, 0, 0.987, -0.904, '#angry', '#disgusting', -0.93, 'logorrhea', 'logomania', 'agromania', 'cacoethes', 'necrophilia']
senticnet['pyroxylin'] = [-0.886, 0, 0.87, -0.761, '#sad', '#angry', -0.839, 'cellulose_ester', 'cellulose_nitrate', 'cellulose_nitratee', 'pyrocellulose', 'nitrate']
senticnet['pyroxyline'] = [-0.886, 0, 0.87, -0.761, '#sad', '#angry', -0.839, 'cellulose_ester', 'pyroxylin', 'cellulose_nitrate', 'pyrocellulose', 'nitrate']
senticnet['python'] = [0, 0.11, 0, 0.077, '#interesting', '#admirable', 0.062, 'snake', 'cobra', 'reptile', 'animal', 'rattlesnake']
senticnet['quack'] = [-0.502, 0, 0.764, -0.618, '#angry', '#disgusting', -0.628, 'doctor', 'mountebank', 'charlatan', 'duck', 'physician']
senticnet['quaintness'] = [-0.561, 0, 0.977, -0.869, '#angry', '#disgusting', -0.802, 'freakishness', 'strangeness', 'abnormality', 'queerness', 'crotchet']
senticnet['quake'] = [-0.93, 0, -0.723, 0, '#sad', '#scared', -0.551, 'avalanche', 'tremor', 'rumble', 'electric_shock', 'bump']
senticnet['qualification'] = [0.034, 0.119, 0, 0.075, '#interesting', '#admirable', 0.076, 'diploma', 'certificate', 'grade', 'graduate', 'celsius']
senticnet['qualified'] = [0, 0, -0.777, -0.877, '#scared', '#disgusting', -0.551, 'stipulate', 'qualify', 'measure_up', 'dispose', 'restrict']
senticnet['qualify'] = [0, 0, 0, 0.963, '#admirable', '#admirable', 0.321, 'strong_relationship', 'self_respect', 'pass_grade', 'knowledgeable', 'world_peace']
senticnet['quality'] = [0.844, 0.903, 0, 0.79, '#joyful', '#interesting', 0.846, 'assurance', 'rate', 'merit', 'amount', 'importance']
senticnet['qualm'] = [-0.749, 0, -0.912, 0, '#sad', '#scared', -0.554, 'misgiving', 'scruple', 'insecurely', 'insecurity', 'insecure']
senticnet['quandary'] = [-0.922, 0, 0.591, -0.572, '#sad', '#angry', -0.695, 'hot_water', 'difficulty', 'care', 'corner', 'box']
senticnet['quandry'] = [-0.023, 0, -0.085, 0, '#sad', '#scared', -0.036, 'symposium', 'middle_road', 'loose_end', 'death_row', 'another_planet']
senticnet['quantity'] = [0, 0.184, 0.048, 0.171, '#interesting', '#admirable', 0.102, 'amount', 'total_number', 'total', 'measure_unit', 'all_of_it']
senticnet['quarantine'] = [-0.914, 0, 0.931, -0.724, '#sad', '#angry', -0.856, 'get_arrested', 'custody', 'incarceration', 'detention', 'prisoner']
senticnet['quark'] = [0.068, 0, 0.034, 0.076, '#joyful', '#admirable', 0.037, 'neutron', 'lepton', 'proton', 'proton_neutron', 'subatomic_particle']
senticnet['quarrel'] = [-0.852, 0, 0.873, -0.968, '#angry', '#disgusting', -0.898, 'dispute', 'fight', 'disagreement', 'conflict', 'big_fight']
senticnet['quarry'] = [0, 0, -0.903, -0.934, '#scared', '#disgusting', -0.612, 'fair_game', 'pit', 'stone_pit', 'target', 'prey']
senticnet['quart'] = [0.068, 0, 0.034, 0.076, '#joyful', '#admirable', 0.037, 'gallon', 'liquid_measurement', 'ounce', 'measurement', 'litre']
senticnet['quarter'] = [0, 0.823, 0, 0.788, '#interesting', '#admirable', 0.537, 'dime', 'nickel', 'metal_money', 'coin', 'penny_dime']
senticnet['quartette'] = [0.552, -0.61, 0, 0.588, '#surprising', '#admirable', 0.583, 'barbershop_quartet', 'string_quartet', 'string_quartette', 'musical_organization', 'musical_group']
senticnet['quartz'] = [-0.027, -0.003, 0.045, -0.034, '#angry', '#disgusting', -0.034, 'sand', 'salt', 'grain_sand', 'sandy', 'silica']
senticnet['quartz_battery'] = [-0.98, 0, 0.521, -0.773, '#sad', '#disgusting', -0.758, 'battery', 'stamp_battery', 'stamp_mill', 'quartz_mill', 'factory']
senticnet['quartz_mill'] = [-0.98, 0, 0.521, -0.773, '#sad', '#disgusting', -0.758, 'battery', 'stamp_battery', 'quartz_battery', 'stamp_mill', 'factory']
senticnet['quash'] = [-0.501, 0, 0.936, -0.951, '#angry', '#disgusting', -0.796, 'oppress', 'keep_down', 'reduce', 'repress', 'subdue']
senticnet['queasy'] = [-0.208, 0.249, 0.467, -0.577, '#angry', '#disgusting', -0.334, 'outrageous', 'horrid', 'dislikeable', 'choler', 'angrily']
senticnet['queen'] = [0, -0.946, 0, 0.838, '#surprising', '#admirable', 0.595, 'king', 'royal', 'duchess', 'queen_of_england', 'monarch']
senticnet['queen_of_england'] = [0, 0, 0, 0.848, '#admirable', '#admirable', 0.283, 'king', 'noble', 'duchess', 'queen', 'monarch']
senticnet['queer'] = [-0.978, 0, 0.971, -0.849, '#sad', '#angry', -0.933, 'fail', 'betray', 'disappoint', 'cross', 'disillusion']
senticnet['queerness'] = [-0.561, 0, 0.977, -0.869, '#angry', '#disgusting', -0.802, 'freakishness', 'quaintness', 'abnormality', 'strangeness', 'crotchet']
senticnet['quell'] = [-0.691, 0, 0.89, -0.707, '#angry', '#disgusting', -0.763, 'still', 'burke', 'moderate', 'hush_up', 'suppress']
senticnet['quelled'] = [-0.725, 0, 0.728, -0.5, '#sad', '#angry', -0.651, 'suppressed', 'squelched', 'burked', 'quenched', 'unreleased']
senticnet['quench_thirst'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'drink_glass', 'appear_beautiful', 'forward_email', 'mind_store', 'speak_english']
senticnet['quenched'] = [-0.793, 0, 0.817, -0.538, '#sad', '#angry', -0.716, 'alleviated', 'eased', 'relieved', 'lessened', 'mitigated']
senticnet['quenchless'] = [-0.728, 0, 0.933, -0.505, '#sad', '#angry', -0.722, 'unsatisfied', 'insatiable', 'unquenchable', 'unsated', 'unsatiated']
senticnet['querier'] = [-0.623, 0, 0.632, -0.783, '#angry', '#disgusting', -0.679, 'inquirer', 'enquirer', 'questioner', 'inquisitor', 'asker']
senticnet['querulous'] = [-0.679, 0, 0.78, -0.816, '#angry', '#disgusting', -0.758, 'complaining', 'whiney', 'whiny', 'fretful', 'protestant']
senticnet['querulousness'] = [-0.598, 0, 0.911, -0.831, '#angry', '#disgusting', -0.78, 'biliousness', 'peevishness', 'pettishness', 'snappishness', 'surliness']
senticnet['query'] = [0, 0.735, 0, 0.785, '#interesting', '#admirable', 0.507, 'inquiry', 'inquire', 'answer', 'yes_no', 'question']
senticnet['quest'] = [0, -0.944, 0, 0.772, '#surprising', '#admirable', 0.572, 'journey', 'adventure', 'navigate', 'find', 'travel']
senticnet['quest_knowledge'] = [0.972, 0, 0, 0.894, '#joyful', '#admirable', 0.622, 'interest_art', 'make_beautiful', 'create_new_life', 'want_entertain', 'curiosity']
senticnet['question'] = [0, 0.999, 0, 0.97, '#interesting', '#admirable', 0.656, 'answer', 'inquiry', 'question_answering', 'query', 'reply']
senticnet['question_answer'] = [-0.061, 0.083, -0.049, 0.2, '#interesting', '#admirable', 0.058, 'retort', 'answer_back', 'interrogation', 'write_back', 'response']
senticnet['question_answering'] = [0, 0.746, 0, 0.796, '#interesting', '#admirable', 0.514, 'answer', 'question', 'inquiry', 'question_mark', 'query']
senticnet['question_ask'] = [0, 0.73, 0, 0, '#interesting', '#interesting', 0.243, 'ask_nicely', 'obligation', 'resume', 'make_effort', 'day_job']
senticnet['question_authority'] = [-0.14, 0, -0.138, -0.063, '#sad', '#scared', -0.114, 'battle_cancer', 'kill_oneself', 'lose_key', 'borrow_book_from_library', 'wave_flag']
senticnet['question_everything'] = [0, 0, 0.845, -0.866, '#angry', '#disgusting', -0.57, 'examine', 'look_detail', 'influence_public_decision', 'analyze', 'rob_bank']
senticnet['question_mark'] = [0, 0.835, 0, 0.991, '#interesting', '#admirable', 0.609, 'answer', 'question', 'inquiry', 'question_answering', 'query']
senticnet['question_start'] = [-0.091, 0.22, -0.185, 0.286, '#interesting', '#admirable', 0.077, 'inquiry', 'question_starter', 'query', 'solution', 'explanation']
senticnet['question_starter'] = [-0.063, 0.194, -0.16, 0.309, '#interesting', '#admirable', 0.093, 'question_start', 'inquiry', 'question', 'query', 'request']
senticnet['question_teacher'] = [-0.183, -0.027, 0, -0.124, '#sad', '#disgusting', -0.093, 'fail_exam', 'fail_test', 'fail_class', 'disrespect', 'irreverence']
senticnet['question_witness'] = [0, 0, 0.845, -0.848, '#angry', '#disgusting', -0.564, 'close_case', 'convict_criminal', 'find_guilty', 'seek_justice', 'call_police']
senticnet['questioner'] = [-0.623, 0, 0.632, -0.783, '#angry', '#disgusting', -0.679, 'inquirer', 'enquirer', 'inquisitor', 'querier', 'asker']
senticnet['questionnaire'] = [0, 0.112, 0, 0.156, '#interesting', '#admirable', 0.089, 'application', 'question_answer', 'interrogation', 'job_application', 'rebuttal']
senticnet['quetch'] = [-0.524, 0, 0.607, -0.549, '#angry', '#disgusting', -0.56, 'bewail', 'bemoan', 'mutter', 'scold', 'gripe']
senticnet['queue'] = [-0.154, 0, 0.029, -0.118, '#sad', '#disgusting', -0.1, 'start_over', 'front_line', 'find_line', 'take_turn', 'long_line']
senticnet['quibble'] = [0, 0, -0.794, -0.803, '#scared', '#disgusting', -0.532, 'niggle', 'quiddity', 'bicker', 'pettifog', 'cavil']
senticnet['quick'] = [0, 0.12, 0, 0.169, '#interesting', '#admirable', 0.096, 'fast', 'quickness', 'speedy', 'rapid', 'haste']
senticnet['quick_bread'] = [0.644, -0.946, 0, 0.729, '#surprising', '#admirable', 0.773, 'gem', 'banana_bread', 'date_bread', 'nut_bread', 'oatcake']
senticnet['quick_buck'] = [0.963, -0.907, 0, 0.952, '#joyful', '#admirable', 0.941, 'profit', 'net_income', 'net', 'net_profit', 'lucre']
senticnet['quick_change'] = [0, -0.289, -0.114, 0.258, '#surprising', '#admirable', 0.144, 'change', 'change_quickly', 'surprise', 'new_beginning', 'wow']
senticnet['quick_look'] = [-0.056, 0.127, -0.053, 0.166, '#interesting', '#admirable', 0.061, 'look', 'glimpse', 'ship_part', 'stare', 'use_eye']
senticnet['quick_motion'] = [0, 0.126, 0.037, 0.225, '#interesting', '#admirable', 0.105, 'pace', 'quick_movement', 'foot_action', 'walk_quickly', 'flee']
senticnet['quick_movement'] = [0, 0.155, 0, 0.237, '#interesting', '#admirable', 0.131, 'speedy', 'quick_motion', 'no_stop', 'flee', 'fast']
senticnet['quick_snack'] = [0.855, 1.0, 0, 0, '#joyful', '#interesting', 0.618, 'healthy_snack', 'healthy_food', 'eat_apple', 'sate_hunger', 'eat_quickly']
senticnet['quick_temper'] = [-0.124, 0.13, 0.646, -0.64, '#angry', '#disgusting', -0.427, 'irascibility', 'short_temper', 'irascible', 'choleric', 'ill_temper']
senticnet['quicken'] = [-0.032, 0.112, -0.086, 0.164, '#interesting', '#admirable', 0.053, 'run', 'jump_over', 'quick', 'sprint', 'flee']
senticnet['quickly'] = [0, 0.081, 0, 0.134, '#interesting', '#admirable', 0.072, 'get_ready', 'quick_movement', 'speedy', 'warm_food', 'fry_egg']
senticnet['quickness'] = [0, 0.127, -0.046, 0.194, '#interesting', '#admirable', 0.092, 'quick', 'fast', 'speedy', 'quick_movement', 'speed']
senticnet['quiescence'] = [-0.877, 0, 0.915, -0.951, '#angry', '#disgusting', -0.914, 'inactivity', 'inactiveness', 'slumber', 'inaction', 'hibernation']
senticnet['quiescency'] = [-0.969, 0, 0.552, -0.826, '#sad', '#disgusting', -0.782, 'inactivity', 'inactiveness', 'slumber', 'inaction', 'hibernation']
senticnet['quiet'] = [0.859, 0, 0, 0.978, '#joyful', '#admirable', 0.612, 'calm', 'calmness', 'serenity', 'soothe', 'peacefulness']
senticnet['quiet_baby'] = [0, 0, -0.068, -0.069, '#scared', '#disgusting', -0.046, 'baby', 'love_child', 'marry_kid', 'loss_offreedom', 'cum']
senticnet['quiet_child'] = [0.924, 0.905, 0, 0, '#joyful', '#interesting', 0.61, 'quiet_baby', 'care_child', 'name_baby', 'name_child', 'forward_email']
senticnet['quiet_cry_baby'] = [-0.097, 0.079, -0.113, -0.078, '#sad', '#scared', -0.07, 'name_child', 'care_child', 'name_baby', 'ease_pain', 'butter_toast']
senticnet['quiet_down'] = [0.711, -0.952, 0, 0, '#joyful', '#surprising', 0.554, 'channel_surf', 'feel_content', 'entertain_friend', 'stop_hunger', 'feel_satisfaction']
senticnet['quiet_mind'] = [0, 0, 0, -0.095, '#disgusting', '#disgusting', -0.032, 'think_future', 'lower_standard', 'miss_appointment', 'battle_cancer', 'sleep_bed']
senticnet['quiet_place'] = [0, 0.105, 0, 0.084, '#interesting', '#admirable', 0.063, 'annals', 'print_medium', 'archive', 'written', 'media']
senticnet['quieten'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'calmly', 'soothing', 'assuasive', 'tranquility', 'tranquilize']
senticnet['quietness'] = [0.579, 0.652, -0.249, 0.276, '#joyful', '#interesting', 0.419, 'tranquilly', 'tranquility', 'quietude', 'tranquil', 'unagitated']
senticnet['quietude'] = [0.579, 0.652, -0.249, 0.276, '#joyful', '#interesting', 0.419, 'tranquilly', 'tranquility', 'quietness', 'tranquil', 'unagitated']
senticnet['quill_brush'] = [0.031, 0.08, 0.023, 0.069, '#interesting', '#admirable', 0.052, 'pencil', 'marker', 'photo', 'icon', 'graphical_representation']
senticnet['quilted_bedspread'] = [0.883, -0.912, 0, 0.991, '#surprising', '#admirable', 0.929, 'spread', 'bedspread', 'bedcover', 'bed_cover', 'bed_covering']
senticnet['quit'] = [-0.035, 0.131, -0.047, 0.107, '#interesting', '#admirable', 0.052, 'payoff', 'pay_off', 'spend_little_money', 'get_back', 'poorly']
senticnet['quit_job'] = [-0.095, 0.072, -0.083, 0, '#sad', '#scared', -0.035, 'leave_work', 'floss_tooth', 'set_clock', 'out_bed', 'sell_vegetable']
senticnet['quit_work'] = [-0.988, 0, -0.828, -0.798, '#sad', '#scared', -0.871, 'finish_work', 'move_furniture', 'floss_tooth', 'work_home', 'work_team']
senticnet['quiver'] = [0, 0, -0.703, 0, '#scared', '#scared', -0.234, 'shudder', 'tingle', 'attachment', 'frisson', 'exuberance']
senticnet['quotidian'] = [0, 0, -0.85, -0.823, '#scared', '#disgusting', -0.558, 'workaday', 'unremarkable', 'routine', 'everyday', 'mundane']
senticnet['rabbi'] = [0, 0, 0, 0.882, '#admirable', '#admirable', 0.294, 'priest', 'clergy', 'jewish', 'preacher', 'goddess']
senticnet['rabbit'] = [0, 0, -0.073, 0, '#scared', '#scared', -0.024, 'nymph', 'mole', 'nightly_ritual', 'impairment_person', 'squirrel']
senticnet['rabbit_food'] = [0.175, 0.101, 0.035, 0.195, '#joyful', '#admirable', 0.145, 'leafy_green', 'lawn_green', 'fruit_plant', 'vegetarian_food', 'green_vegetable']
senticnet['rabbit_on'] = [0.984, -0.638, 0, 0.731, '#joyful', '#admirable', 0.784, 'utter', 'talk', 'speak', 'mouth', 'verbalize']
senticnet['rabies'] = [-0.721, 0, -0.825, -0.841, '#scared', '#disgusting', -0.796, 'helpless', 'unwanted', 'big_rat', 'small_cat', 'freckle']
senticnet['raccoon'] = [0, 0, -0.102, 0, '#scared', '#scared', -0.034, 'lonely_person', 'vegetarian', 'hermit', 'lab_rat', 'user']
senticnet['race'] = [0, 0, 0, 0.108, '#admirable', '#admirable', 0.036, 'fast', 'flee', 'sprint', 'marathon', 'good_form_exercise']
senticnet['race_hare'] = [-0.045, 0.118, -0.069, 0.102, '#interesting', '#admirable', 0.035, 'a_lot_of_practice', 'air_tank', 'live_old', 'hide_shell', 'grasp']
senticnet['race_other'] = [-0.958, 0, 0, -0.96, '#sad', '#disgusting', -0.639, 'miss_ball', 'monitor_heart_rate', 'strike_out', 'collapse', 'chase_ball']
senticnet['racetrack'] = [-0.058, 0, 0.023, -0.049, '#sad', '#disgusting', -0.043, 'track', 'run_event', 'run', 'course', 'run_place']
senticnet['raciness'] = [-0.698, 0, 0.597, -0.569, '#sad', '#angry', -0.621, 'improperness', 'impropriety', 'indelicacy', 'spiciness', 'gaminess']
senticnet['racism'] = [-0.721, 0, -0.825, -0.841, '#scared', '#disgusting', -0.796, 'racist', 'intolerant', 'xenophobic', 'antisemitism', 'nazism']
senticnet['racist'] = [-0.721, 0, -0.825, -0.841, '#scared', '#disgusting', -0.796, 'racism', 'intolerant', 'xenophobic', 'antisemitism', 'nazism']
senticnet['rack'] = [-0.67, 0, 0.85, -0.599, '#sad', '#angry', -0.706, 'instrument_of_torture', 'boot', 'whip', 'iron_boot', 'iron_heel']
senticnet['rack_of_lamb'] = [0.783, -0.635, 0, 0.829, '#joyful', '#admirable', 0.749, 'leg_of_lamb', 'gigot', 'joint', 'roast', 'lamb_roast']
senticnet['rack_up'] = [0.572, -0.603, 0, 0.892, '#surprising', '#admirable', 0.689, 'tally', 'steal', 'score', 'hit', 'get_ahead']
senticnet['racket'] = [0, 0, 0.725, -0.778, '#angry', '#disgusting', -0.501, 'umpire', 'referee', 'legal_proceed', 'clang', 'clamor']
senticnet['racoon'] = [0, 0, 0.08, 0, '#angry', '#angry', -0.027, 'tree_animal', 'small_furry', 'rodent', 'big_mouse', 'small_rodent']
senticnet['raddled'] = [-0.843, 0, 0.653, -0.885, '#sad', '#disgusting', -0.794, 'battered', 'woebegone', 'tattered', 'derelict', 'worn']
senticnet['radial_asymmetry'] = [-0.596, 0, 0.6, -0.519, '#sad', '#angry', -0.572, 'asymmetry', 'dissymmetry', 'imbalance', 'directivity', 'directionality']
senticnet['radiance'] = [0.931, -0.825, 0, 0.709, '#joyful', '#surprising', 0.822, 'light', 'aureole', 'corona', 'visible_light', 'visible_radiation']
senticnet['radiancy'] = [0.916, -0.991, 0, 0.984, '#surprising', '#admirable', 0.964, 'gleaming', 'luster', 'polish', 'glow', 'burnish']
senticnet['radiant'] = [0.04, 0.101, 0, 0.153, '#interesting', '#admirable', 0.098, 'source_light', 'celestial_body', 'far_away', 'heavenly_body', 'around_earth']
senticnet['radiatio_optica'] = [-0.735, 0, 0.897, -0.774, '#angry', '#disgusting', -0.802, 'commissure', 'optic_radiation', 'pathway', 'peduncle', 'cerebral_peduncle']
senticnet['radiation'] = [0, 0, -0.15, 0, '#scared', '#scared', -0.05, 'photon', 'potential_energy', 'electromagnetic_radiation', 'energy_source', 'petroleum']
senticnet['radiation_therapy'] = [0.789, -0.817, 0, 0.591, '#joyful', '#surprising', 0.732, 'radiotherapy', 'phototherapy', 'radiation', 'actinotherapy', 'irradiation']
senticnet['radical'] = [0.219, -0.143, 0.04, 0, '#joyful', '#surprising', 0.107, 'just_fun', 'enjoyable', 'taboo', 'creepy', 'fun']
senticnet['radical_cell'] = [0.942, -0.797, 0, 0.561, '#joyful', '#surprising', 0.767, 'sleeper_cell', 'terrorist_cell', 'cadre', 'political_unit', 'political_entity']
senticnet['radio'] = [0.064, -0.069, 0.054, 0, '#joyful', '#surprising', 0.026, 'stereo', 'tuner', 'speaker', 'record_library', 'amplifier']
senticnet['radio-control_helicopter'] = [0, 0.957, 0, 0.908, '#interesting', '#admirable', 0.622, 'manga', 'cartoon', 'anime', 'beat_off', 'see_someone_play_game']
senticnet['radio_station'] = [-0.065, -0.022, -0.054, -0.118, '#sad', '#disgusting', -0.072, 'pirate_ship', 'old_movie', 'movie', 'chinatown', 'military_base']
senticnet['radio_studio'] = [0.077, 0.073, 0.013, -0.028, '#joyful', '#interesting', 0.036, 'registry_office', 'book_office', 'music_studio', 'conference_auditorium', 'mezzanine']
senticnet['radio_wave'] = [0, 0, -0.074, -0.169, '#scared', '#disgusting', -0.081, 'cosmic_ray', 'sun', 'solar_cell', 'x-ray', 'gamma_ray']
senticnet['radioactive'] = [-0.027, 0, 0.047, -0.112, '#angry', '#disgusting', -0.062, 'hold_trash', 'put_garbage', 'rubbish', 'put_trash', 'store_trash']
senticnet['radioactive_dust'] = [-0.955, 0, 0.738, -0.584, '#sad', '#angry', -0.759, 'fallout', 'chalk_dust', 'dust', 'particulate', 'particulate_matter']
senticnet['rag'] = [-0.1, 0, 0.674, -0.662, '#angry', '#disgusting', -0.479, 'bedevil', 'dun', 'frustrating', 'crucify', 'bothersome']
senticnet['ragamuffin'] = [-0.165, -0.054, -0.126, -0.134, '#sad', '#disgusting', -0.124, 'waif', 'orphanage', 'stray', 'orphan', 'lonely']
senticnet['rage'] = [0, 0, 1, 0, '#angry', '#angry', -0.333, 'mad', 'malice', 'animosity', 'resentment', 'temper']
senticnet['ragged'] = [0, 0, -0.976, -0.705, '#scared', '#disgusting', -0.56, 'crucify', 'torment', 'bedevil', 'frustrate', 'dun']
senticnet['raggedness'] = [-0.9, 0, 0.841, -0.731, '#sad', '#angry', -0.824, 'nubbiness', 'tweediness', 'harshness', 'graininess', 'granularity']
senticnet['raid'] = [-0.881, 0, 0.548, -0.965, '#sad', '#disgusting', -0.798, 'penetration', 'air_raid', 'air_attack', 'swoop', 'incursion']
senticnet['rail'] = [0.096, -0.017, 0, 0, '#joyful', '#surprising', 0.038, 'chain', 'platform_rail', 'catwalk', 'column', 'token_turnstile']
senticnet['raillery'] = [-0.853, 0, 0.855, -0.878, '#angry', '#disgusting', -0.862, 'banter', 'repartee', 'backchat', 'wit', 'humor']
senticnet['railway_station'] = [0, 0.147, 0, 0.099, '#interesting', '#admirable', 0.082, 'train_station', 'airport', 'subway', 'airport_terminal', 'depot']
senticnet['raiment'] = [-0.979, 0, 0.51, -0.892, '#sad', '#disgusting', -0.794, 'wear', 'war_paint', 'wearable', 'clothing', 'article_of_clothing']
senticnet['rain'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'storm', 'heavy_bad_climate', 'bad_climate', 'snow', 'become_sick']
senticnet['rain_bucket'] = [-0.771, 0, 0.583, -0.609, '#sad', '#disgusting', -0.654, 'rain', 'rain_down', 'sheet', 'sluice', 'sluice_down']
senticnet['rain_cats_and_dogs'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'bad_climate', 'heavy_rain', 'get_wet', 'snow', 'get_sick']
senticnet['rain_check'] = [0.814, 0.773, 0, 0, '#joyful', '#interesting', 0.529, 'control_weather', 'check_weather', 'weather_forecast', 'forecast', 'weather']
senticnet['rain_down'] = [-0.837, 0, 0.87, -0.978, '#angry', '#disgusting', -0.895, 'precipitate', 'mizzle', 'shower_down', 'spit', 'patter']
senticnet['rain_equipment'] = [0.106, 0.162, 0.037, 0.32, '#interesting', '#admirable', 0.184, 'block_sun', 'waterproof_jacket', 'waterproof_boot', 'umbrella', 'block_rain']
senticnet['rain_fall'] = [0, 0, -0.739, -0.792, '#scared', '#disgusting', -0.51, 'hard_see', 'dizzy', 'dew', 'rain', 'mist']
senticnet['rain_forest'] = [-0.055, -0.009, 0.086, -0.184, '#angry', '#disgusting', -0.105, 'playful_mood', 'bad_mood', 'sadness', 'hole_ground', 'feel_down']
senticnet['rain_parade'] = [-0.081, 0, 0, -0.065, '#sad', '#disgusting', -0.049, 'journey_far', 'fly_helicopter', 'land_plane', 'drop_bomb', 'free_bird']
senticnet['rain_snow'] = [-0.176, -0.073, 0, -0.159, '#sad', '#disgusting', -0.087, 'snow_storm', 'cold_hot', 'rainy', 'natural_phenomenon', 'weather_type']
senticnet['rain_storm'] = [0.045, 0, 0, 0.088, '#joyful', '#admirable', 0.044, 'loud_sound', 'thunder', 'boom', 'sound_wave', 'rain_wind']
senticnet['rain_water'] = [0.942, -0.853, 0, 0, '#joyful', '#surprising', 0.598, 'fallen', 'water_drip', 'falling_water', 'feel_cold', 'drip']
senticnet['rain_wind'] = [0.045, 0, 0, 0.088, '#joyful', '#admirable', 0.044, 'loud_sound', 'thunder', 'rain_storm', 'sound_wave', 'boom']
senticnet['rainbow'] = [0.03, 0.085, 0, 0, '#joyful', '#interesting', 0.038, 'favorite_color', 'colourful', 'different_color', 'pink', 'happy']
senticnet['raincoat'] = [0, -0.083, 0.105, -0.102, '#angry', '#disgusting', -0.041, 'underwear', 'shirt', 'panties', 'robe', 'slack']
senticnet['rainfall'] = [0, 0, 0.073, 0, '#angry', '#angry', -0.024, 'condensation', 'water_fall', 'falling_water', 'frozen_water', 'water_drop']
senticnet['rainmaker'] = [0.703, -0.598, 0, 0.842, '#joyful', '#admirable', 0.714, 'executive', 'minister', 'administrator', 'corporate_executive', 'business_executive']
senticnet['rainstorm'] = [-0.872, 0, 0.91, -0.78, '#sad', '#angry', -0.854, 'storm', 'thundershower', 'rain', 'line_storm', 'equinoctial_storm']
senticnet['rainy'] = [-0.176, -0.073, 0, -0.159, '#sad', '#disgusting', -0.087, 'snow_storm', 'rain_snow', 'cold_hot', 'natural_phenomenon', 'weather_type']
senticnet['rainy_day'] = [-0.099, 0, -0.152, -0.161, '#scared', '#disgusting', -0.137, 'emotional_pain', 'desire_entertain', 'feel_depressed', 'desire_entertainment', 'embarrassment']
senticnet['raise'] = [0, 0.275, -0.153, 0.222, '#interesting', '#admirable', 0.115, 'lift', 'arise', 'rise', 'go_up', 'pull_up']
senticnet['raise_animal'] = [0, 0.084, 0, 0.083, '#interesting', '#admirable', 0.056, 'grow_crop', 'agriculture', 'plant_crop', 'crop_field', 'grow_food']
senticnet['raise_arm'] = [0.072, 0, 0, 0, '#joyful', '#joyful', 0.024, 'move_place_another', 'hold_hand', 'raise_money', 'try_forget', 'pull_out']
senticnet['raise_child'] = [-0.074, 0, 0, -0.061, '#sad', '#disgusting', -0.045, 'protect_child', 'teach_child', 'help_another_person', 'understand_idea', 'look_closely']
senticnet['raise_crop'] = [0, 0.071, 0.024, 0.065, '#interesting', '#admirable', 0.037, 'grow_food', 'raise_animal', 'agriculture', 'grow_stuff', 'grow_crop']
senticnet['raise_family'] = [0.098, 0.087, -0.079, 0.074, '#joyful', '#interesting', 0.06, 'live_life', 'protection_element', 'reside', 'house_person', 'family_live']
senticnet['raise_flag'] = [0, 0.886, 0, 0, '#interesting', '#interesting', 0.295, 'kill_oneself', 'arm_oneself', 'right_injustice', 'market_product', 'bridge_difference']
senticnet['raise_hand'] = [0.874, 0.77, 0, 0, '#joyful', '#interesting', 0.548, 'think_first', 'think_say', 'speak_mind', 'know_talk', 'speak_up']
senticnet['raise_hell'] = [-0.145, 0, -0.08, -0.04, '#sad', '#scared', -0.088, 'serve_beer', 'drink_juice', 'wear_hat', 'drink_much_beer', 'spill_food_clothes']
senticnet['raise_money'] = [-0.038, -0.013, 0.044, -0.049, '#angry', '#disgusting', -0.039, 'experience_joy', 'drive_around', 'join_club', 'talk_other', 'read_bedtime_story']
senticnet['raise_right_hand'] = [-0.129, 0.28, -0.112, 0.174, '#interesting', '#admirable', 0.071, 'stubborn', 'find_another_person', 'become_politician', 'make_decision', 'tell_why']
senticnet['raise_self_esteem'] = [0, 0, 0, 0.968, '#admirable', '#admirable', 0.323, 'demonstrate_skill', 'improve_skill', 'kill_time', 'compete_others', 'golfer']
senticnet['raise_up'] = [0.057, 0.248, -0.127, 0.288, '#interesting', '#admirable', 0.155, 'move_upward', 'go_up', 'upward_movement', 'rise_up', 'ascend']
senticnet['raise_voice'] = [-0.089, -0.031, 0.039, -0.12, '#sad', '#disgusting', -0.072, 'open_close_mouth', 'use_voice', 'annoy_other_person', 'dry_mouth', 'hunt_duck']
senticnet['raisin'] = [0, 0.066, -0.058, 0.089, '#interesting', '#admirable', 0.032, 'pineapple', 'kale', 'banana', 'pickle', 'tomato']
senticnet['raisin_bran'] = [-0.923, 0, 0.609, -0.745, '#sad', '#disgusting', -0.759, 'puffed_rice', 'granola', 'cold_cereal', 'corn_flake', 'bran_flake']
senticnet['raising'] = [0.858, -0.778, 0, 0.735, '#joyful', '#surprising', 0.79, 'breeding', 'training', 'education', 'upbringing', 'nurture']
senticnet['rake_leave'] = [-0.101, 0, -0.056, 0, '#sad', '#scared', -0.052, 'fancy_girl', 'kiss_girl', 'wedge_door', 'jump_off_bridge', 'date_girl']
senticnet['rally'] = [0.669, -0.583, 0, 0.803, '#joyful', '#admirable', 0.685, 'pep_rally', 'revival', 'revival_meeting', 'gathering', 'assemblage']
senticnet['ramble'] = [0, 0, -0.794, -0.752, '#scared', '#disgusting', -0.515, 'meander', 'jog', 'swan', 'roll', 'wander']
senticnet['rambunctious'] = [-0.642, 0, 0.941, -0.664, '#angry', '#disgusting', -0.749, 'rowdy', 'boisterous', 'unruly', 'disorderly', 'robustious']
senticnet['ramification'] = [0, 0, -0.983, -0.715, '#scared', '#disgusting', -0.566, 'fork', 'branching', 'branch', 'forking', 'leg']
senticnet['ramify'] = [-0.866, 0, 0.511, -0.764, '#sad', '#disgusting', -0.714, 'separate', 'move', 'branch', 'diverge', 'fork']
senticnet['rancher'] = [0, 0.067, 0, 0.058, '#interesting', '#admirable', 0.042, 'plant_crop', 'grow_crop', 'raise_animal', 'cultivation', 'grow_food']
senticnet['rancor'] = [0.034, 0.126, 0.758, -0.673, '#angry', '#disgusting', -0.424, 'resentfully', 'gall', 'seek_revenge', 'resentful', 'warpath']
senticnet['random'] = [0, 0.7, 0, 0.787, '#interesting', '#admirable', 0.496, 'right_now', 'unsure', 'now_time', 'unpredictable', 'contemporary']
senticnet['random_sampling'] = [0.956, -0.839, 0, 0.755, '#joyful', '#surprising', 0.85, 'choice', 'option', 'sampling', 'stratified_sampling', 'representative_sampling']
senticnet['range'] = [0.828, -0.898, 0, 0.693, '#joyful', '#surprising', 0.806, 'confines', 'expanse', 'view', 'internationality', 'purview']
senticnet['ranitidine'] = [-0.533, 0, 0.954, -0.541, '#angry', '#disgusting', -0.676, 'antacid', 'histamine_blocker', 'gastric_antacid', 'alkalizer', 'antiacid']
senticnet['rank'] = [0.034, 0.105, 0, 0, '#joyful', '#interesting', 0.046, 'military_order', 'army_position', 'army_boss', 'police_rank', 'hierarchy']
senticnet['rankle'] = [-0.731, 0, 0.585, -0.957, '#sad', '#disgusting', -0.758, 'nettle', 'bother', 'devil', 'chafe', 'rag']
senticnet['rant'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'angry', 'complain', 'lament', 'protest', 'bewail']
senticnet['ranting'] = [-0.912, 0, 0.704, -0.702, '#sad', '#angry', -0.773, 'rant', 'raving', 'harangue', 'declamation', 'tirade']
senticnet['rap'] = [0.155, -0.099, 0.028, 0, '#joyful', '#surprising', 0.075, 'classical', 'popular_music', 'rhapsody', 'rock_roll', 'jingle']
senticnet['rape'] = [-0.141, 0, -0.17, -0.087, '#sad', '#scared', -0.133, 'revenge', 'break_law', 'die', 'commit_crime', 'defend_oneself']
senticnet['rape_suspect'] = [0.964, -0.577, 0, 0.827, '#joyful', '#admirable', 0.789, 'mortal', 'murder_suspect', 'robbery_suspect', 'suspect', 'person']
senticnet['raper'] = [0.997, -0.846, 0, 0.927, '#joyful', '#admirable', 0.923, 'felon', 'crook', 'malefactor', 'outlaw', 'criminal']
senticnet['rapid'] = [0.03, 0.117, -0.045, 0.153, '#interesting', '#admirable', 0.085, 'quick', 'haste', 'fast', 'swift', 'quickness']
senticnet['rapid_oxidation'] = [0.021, 0, -0.105, -0.049, '#scared', '#disgusting', -0.044, 'huge_fire', 'heat_light', 'fire', 'flame', 'cinder']
senticnet['rapine'] = [0, 0, -0.843, -0.901, '#scared', '#disgusting', -0.581, 'steal_money', 'theft', 'burglary', 'robbery', 'thief']
senticnet['rapist'] = [0.864, -0.548, 0, 0.613, '#joyful', '#admirable', 0.675, 'felon', 'crook', 'malefactor', 'outlaw', 'criminal']
senticnet['rapper'] = [0, 0.756, 0, 0.853, '#interesting', '#admirable', 0.536, 'dollar_change', 'small_currency', 'currency_unit', 'metal_money', 'american_money']
senticnet['rapscallion'] = [-0.625, 0, 0.768, -0.588, '#sad', '#angry', -0.66, 'rascal', 'holy_terror', 'scalawag', 'scallywag', 'monkey']
senticnet['rapt'] = [0.79, 0, 0, 0.71, '#joyful', '#admirable', 0.5, 'joyful', 'ecstatic', 'enjoyousured', 'joyousurous', 'joyous']
senticnet['raptor'] = [-0.747, 0, 0.963, -0.763, '#angry', '#disgusting', -0.824, 'bird', 'hawk', 'eagle', 'vulture', 'secretary_bird']
senticnet['raptorial_bird'] = [-0.538, 0, 0.648, -0.705, '#angry', '#disgusting', -0.63, 'bird', 'hawk', 'eagle', 'vulture', 'secretary_bird']
senticnet['rapturous'] = [0.857, 0, 0, 0.93, '#joyful', '#admirable', 0.596, 'joyful', 'ecstatic', 'enraptured', 'joyous', 'rapt']
senticnet['raptus'] = [0, 0, -0.866, -0.949, '#scared', '#disgusting', -0.605, 'convulsion', 'raptus_hemorrhagicus', 'focal_seizure', 'absence', 'seizure']
senticnet['raptus_hemorrhagicus'] = [0.637, -0.568, 0, 0.761, '#joyful', '#admirable', 0.655, 'convulsion', 'raptus', 'focal_seizure', 'absence', 'absence_seizure']
senticnet['rara_avis'] = [0.808, -0.564, 0, 0.952, '#joyful', '#admirable', 0.775, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['rare_bird'] = [0.975, -0.818, 0, 0.88, '#joyful', '#admirable', 0.891, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['rare_piscator'] = [0.073, -0.022, 0, 0, '#joyful', '#surprising', 0.032, 'fisherman', 'informal_rod', 'archaic_fisher', 'angler', 'fishing_line']
senticnet['rarely'] = [0.03, 0, 0, 0.051, '#joyful', '#admirable', 0.027, 'ford', 'form_of_transportation', 'mode_transportation', 'machine_transportation', 'load']
senticnet['rareness'] = [-0.881, 0, 0.732, -0.61, '#sad', '#angry', -0.741, 'paucity', 'insufficiency', 'scarceness', 'infrequency', 'dearth']
senticnet['rarify'] = [-0.907, 0, 0.617, -0.776, '#sad', '#disgusting', -0.767, 'modify', 'alter', 'change', 'sophisticate', 'involve']
senticnet['raring'] = [0, 0.801, 0, 0.945, '#interesting', '#admirable', 0.582, 'impatiently', 'fretful', 'fidgetiness', 'antsy', 'fidgety']
senticnet['rascal'] = [-0.625, 0, 0.768, -0.588, '#sad', '#angry', -0.66, 'holy_terror', 'rapscallion', 'scalawag', 'scallywag', 'monkey']
senticnet['rase'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'raze', 'destroy', 'smash', 'kill', 'raze_to_ground']
senticnet['rash'] = [0, 0, 0.947, -0.827, '#angry', '#disgusting', -0.591, 'itch', 'measles', 'nip', 'skin_rash', 'scratch']
senticnet['rasp'] = [-0.992, 0, 0.869, -0.604, '#sad', '#angry', -0.822, 'excoriate', 'chafe', 'abrade', 'wear_away', 'wear_off']
senticnet['rasping'] = [-0.937, 0, 0.576, -0.545, '#sad', '#angry', -0.686, 'grating', 'cacophonic', 'raspy', 'jarring', 'gruff']
senticnet['raspy'] = [-0.937, 0, 0.576, -0.545, '#sad', '#angry', -0.686, 'grating', 'rasping', 'cacophonic', 'jarring', 'gruff']
senticnet['rat'] = [-0.139, 0, 0.013, -0.081, '#sad', '#disgusting', -0.078, 'mouse', 'dig_tunnel', 'underground_animal', 'big_mouse', 'small_rodent']
senticnet['rat_race'] = [0.544, -0.915, 0, 0.941, '#surprising', '#admirable', 0.8, 'rut', 'groove', 'modus_operandi', 'procedure', 'process']
senticnet['rat_typhus'] = [0.579, -0.81, 0, 0.833, '#surprising', '#admirable', 0.741, 'murine_typhus', 'typhus', 'urban_typhus', 'endemic_typhus', 'rickettsial_disease']
senticnet['ratchet_screwdriver'] = [0.986, 0.866, 0, 0, '#joyful', '#interesting', 0.617, 'screwdriver', 'glass_front_display_cabinet', 'tool', 'paint', 'power_screwdriver']
senticnet['rate'] = [0, 0.281, 0, 0.206, '#interesting', '#admirable', 0.162, 'amount', 'quantity', 'merit', 'value', 'all_of_it']
senticnet['ratifier'] = [0.667, -0.982, 0, 0.61, '#joyful', '#surprising', 0.753, 'friend', 'champion', 'supporter', 'protagonist', 'admirer']
senticnet['rating'] = [0.798, -0.527, 0, 0.693, '#joyful', '#admirable', 0.673, 'overvaluation', 'grade', 'undervaluation', 'pricing', 'reevaluation']
senticnet['ration'] = [0, 0, 0, -0.112, '#disgusting', '#disgusting', -0.037, 'chow', 'result_cook', 'oatmeal', 'soybean', 'eat_food']
senticnet['rational'] = [0, 0.981, 0, 0.989, '#interesting', '#admirable', 0.657, 'arrive_conclusion', 'figure_out', 'resolve_problem', 'make_decision', 'come_up_idea']
senticnet['rational_motive'] = [0.674, -0.787, 0, 0.793, '#surprising', '#admirable', 0.751, 'motivator', 'incentive', 'inducement', 'motivation', 'need']
senticnet['rational_think'] = [0.832, 0.861, 0, 0.848, '#interesting', '#admirable', 0.847, 'logic', 'psychology', 'think_idea', 'analysis', 'brain_function']
senticnet['ratite'] = [-0.681, 0, 0.956, -0.909, '#angry', '#disgusting', -0.849, 'giant_moa', 'anomalopteryx', 'moa', 'moa_bird', 'flightless_bird']
senticnet['ratite_bird'] = [-0.681, 0, 0.956, -0.909, '#angry', '#disgusting', -0.849, 'giant_moa', 'anomalopteryx', 'ratite', 'moa', 'flightless_bird']
senticnet['rattle'] = [0.098, 0, -0.048, 0.112, '#joyful', '#admirable', 0.054, 'squeak', 'clang', 'vibration', 'loud_yell', 'tremor']
senticnet['rattling'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'terrific', 'wondrously', 'tremendous', 'marvelous', 'wondrous']
senticnet['rave'] = [0.098, -0.06, 0, 0, '#joyful', '#surprising', 0.053, 'banquet', 'carnival', 'gift_box', 'fun_place', 'rave_party']
senticnet['rave_party'] = [0.098, -0.06, 0, 0, '#joyful', '#surprising', 0.053, 'banquet', 'carnival', 'gift_box', 'fun_place', 'rave']
senticnet['raven'] = [-0.03, -0.029, 0.027, -0.109, '#sad', '#disgusting', -0.046, 'crow', 'dove', 'water_bird', 'bird_prey', 'bird_type']
senticnet['ravenous'] = [-0.713, 0, 0.692, -0.818, '#sad', '#disgusting', -0.741, 'famished', 'starved', 'hungry', 'esurient', 'peckish']
senticnet['raving'] = [-0.912, 0, 0.704, -0.702, '#sad', '#angry', -0.773, 'rant', 'declamation', 'harangue', 'ranting', 'tirade']
senticnet['raw'] = [0, 0, 0.071, 0, '#angry', '#angry', -0.024, 'ripe_apple', 'corn', 'rice', 'sausage', 'maroon']
senticnet['raw_fish'] = [0.79, 0.736, 0, 0, '#joyful', '#interesting', 0.509, 'form_of_food', 'japanese_food', 'food_item', 'after_lunch', 'food']
senticnet['raw_talent'] = [0.608, -0.55, 0, 0.726, '#joyful', '#admirable', 0.628, 'genius', 'endowment', 'flair', 'bent', 'knack']
senticnet['raw_throat'] = [-0.599, 0, 0.883, -0.752, '#angry', '#disgusting', -0.745, 'inflammatory_disease', 'streptococcal_sore_throat', 'strep_throat', 'streptococcus_tonsilitis', 'septic_sore_throat']
senticnet['raw_weather'] = [-0.927, 0, 0.929, -0.566, '#sad', '#angry', -0.807, 'overcast', 'weather', 'inclemency', 'storminess', 'cloudiness']
senticnet['ray'] = [0.86, 0.735, 0, 0, '#joyful', '#interesting', 0.532, 'sunlight', 'bright', 'light', 'brightness', 'sunshine']
senticnet['ray_of_light'] = [-0.507, 0, 0.75, -0.951, '#angry', '#disgusting', -0.736, 'beam', 'beam_of_light', 'light_beam', 'ray', 'sunbeam']
senticnet['raze'] = [-0.079, -0.031, -0.067, -0.164, '#sad', '#disgusting', -0.093, 'destroy', 'smash', 'damage', 'destruction', 'cause_injury']
senticnet['raze_to_ground'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'raze', 'destroy', 'smash', 'kill', 'rase']
senticnet['razor'] = [0, -0.069, 0.071, -0.178, '#angry', '#disgusting', -0.06, 'double_edge_razor', 'clipper', 'pair_of_scissors', 'knife', 'razor_blade']
senticnet['razor_blade'] = [0.023, -0.013, 0.079, -0.116, '#angry', '#disgusting', -0.053, 'knife', 'thumb_tack', 'razor', 'knife_sharp', 'pin']
senticnet['razz'] = [-0.995, 0, 0.974, -0.8, '#sad', '#angry', -0.923, 'outcry', 'call', 'cry', 'yell', 'shout']
senticnet['razzing'] = [-0.727, 0, 0.542, -0.792, '#sad', '#disgusting', -0.687, 'outcry', 'call', 'cry', 'yell', 'shout']
senticnet['reach'] = [0, 0.134, -0.107, 0.224, '#interesting', '#admirable', 0.084, 'extend', 'grasp', 'grab', 'extend_arm', 'hold']
senticnet['reach_advantage'] = [-0.039, 0.085, 0, 0.078, '#interesting', '#admirable', 0.041, 'compete_against', 'score_homer', 'conquer_opponent', 'score_home_run', 'win_baseball_game']
senticnet['reach_conclusion'] = [-0.109, 0.242, -0.072, 0.165, '#interesting', '#admirable', 0.075, 'figure_out', 'polarize', 'acknowledge', 'think_process', 'arrive_conclusion']
senticnet['reach_destination'] = [0.753, 0, 0, 0.896, '#joyful', '#admirable', 0.55, 'mission_accomplished', 'get_somewhere', 'get_to_another_place', 'get_to_destination', 'get_place']
senticnet['reach_goal'] = [0.741, 0.912, 0, 0.944, '#interesting', '#admirable', 0.866, 'accomplish_goal', 'make_difference', 'improve', 'set_example', 'happiness']
senticnet['reach_high_place'] = [0.066, 0.172, -0.055, 0.191, '#interesting', '#admirable', 0.125, 'pull_up', 'move_up', 'increase_height', 'bring_up', 'rise_up']
senticnet['reach_high_shelf'] = [-0.068, -0.034, 0.034, -0.087, '#sad', '#disgusting', -0.052, 'fall_over', 'fall', 'fall_ground', 'almost_fall', 'take_photo']
senticnet['reach_home'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'destination', 'near_destination', 'goal', 'return_home', 'almost_there']
senticnet['reach_impasse'] = [0, 0, 0, 0.095, '#admirable', '#admirable', 0.032, 'divide_person', 'change_society', 'take_oath', 'divide', 'institute_civil_action']
senticnet['reach_out'] = [0, 0.162, -0.1, 0.28, '#interesting', '#admirable', 0.114, 'extend_arm', 'grab', 'grow_long', 'elasticity', 'grasp']
senticnet['reach_star'] = [0.994, 0.745, 0, 0.812, '#joyful', '#admirable', 0.85, 'shoulder_burden', 'gather_berry', 'hang_picture_on_wall', 'see_star_night', 'weather_storm']
senticnet['reach_tentative_agreement'] = [0, -0.033, 0.027, 0.071, '#surprising', '#admirable', 0.026, 'agree', 'express_oneself', 'take_oath', 'tell_many_person', 'comfort_friend']
senticnet['reach_top'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'climb_hill', 'gain_ground', 'win_battle', 'score_goal', 'accomplish_mission']
senticnet['reaction_turbine'] = [-0.976, 0, 0.658, -0.606, '#sad', '#angry', -0.747, 'gas_turbine', 'hydroelectric_turbine', 'impulse_turbine', 'turbine', 'steam_turbine']
senticnet['reactive'] = [0.766, -0.875, 0, 0.666, '#joyful', '#surprising', 0.769, 'oxidizable', 'unstable', 'labile', 'activated', 'excited']
senticnet['reactivity'] = [0.698, -0.614, 0, 0.619, '#joyful', '#admirable', 0.644, 'sensitivity', 'sensitiveness', 'irritability', 'sensibility', 'excitability']
senticnet['read'] = [-0.051, -0.034, -0.051, 0, '#sad', '#scared', -0.023, 'find_library_human', 'find_library', 'make_paper', 'pick_tooth', 'illuminate_area']
senticnet['read_aloud'] = [-0.148, 0, 0, -0.097, '#sad', '#disgusting', -0.082, 'forget_else', 'recognize_pattern', 'think_through', 'ask_many_questions', 'concentrate']
senticnet['read_article'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'borrow_book', 'use_search_engine', 'write_on_notebook', 'study_history', 'buy_textbook']
senticnet['read_bedtime_story'] = [0.965, 0.954, 0, 0.845, '#joyful', '#interesting', 0.921, 'explain_everything', 'deal_card_player', 'stand_alone', 'forward_email', 'bridge_difference']
senticnet['read_bible'] = [0, 0.843, 0, 0.867, '#interesting', '#admirable', 0.57, 'keep_word', 'complete_sentence', 'help_another_person', 'think_issue', 'state_fact']
senticnet['read_book'] = [0.911, 0, 0, 0, '#joyful', '#joyful', 0.304, 'read_magazine', 'stay_awake', 'read_news', 'peace_quiet', 'find_quiet_place']
senticnet['read_book_subject'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'use_telescope', 'use_search_engine', 'review_note', 'remember_information', 'buy_textbook']
senticnet['read_carefully'] = [-0.116, 0, -0.095, 0, '#sad', '#scared', -0.07, 'find_library', 'read', 'read_fine_print', 'read_human', 'write_on_notebook']
senticnet['read_comic'] = [0, 0.724, 0, 0.929, '#interesting', '#admirable', 0.551, 'spend_time_together', 'play_game', 'play_card', 'play_chess', 'beat_off']
senticnet['read_cover'] = [-0.115, 0, 0, 0, '#sad', '#sad', -0.038, 'deflate', 'spread_out', 'look_behind', 'upgrade', 'scan']
senticnet['read_credit'] = [0.897, -0.991, 0, 0, '#joyful', '#surprising', 0.629, 'laugh_out_loud', 'change_channel', 'drink_soda', 'sit_sofa', 'drink_coke']
senticnet['read_direction'] = [-0.09, -0.006, 0, -0.078, '#sad', '#disgusting', -0.054, 'deflate', 'read_cover', 'wear_apron', 'learn_read', 'spread_out']
senticnet['read_document'] = [0.899, 0.726, 0, 0, '#joyful', '#interesting', 0.542, 'read', 'read_newspaper', 'read_program', 'read_book', 'read_paper']
senticnet['read_email'] = [-0.058, -0.076, 0.088, -0.133, '#angry', '#disgusting', -0.068, 'phone_line_busy', 'find_porn', 'check_email', 'pass_information', 'search_information']
senticnet['read_english_book'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'study', 'language', 'study_language', 'wanderlust', 'discover_new_culture']
senticnet['read_fairy_tale'] = [0.073, 0, 0, 0.083, '#joyful', '#admirable', 0.052, 'entertainment', 'keep_child_occupy', 'pastime', 'enjoyment', 'watch_cartoon']
senticnet['read_fast'] = [0.77, 0.905, 0, 0, '#joyful', '#interesting', 0.558, 'skim_through', 'read_cover', 'take_look', 'read_through', 'look_over']
senticnet['read_fine_print'] = [-0.059, 0, -0.063, 0, '#sad', '#scared', -0.041, 'read_carefully', 'see_clearly', 'write_down_idea', 'write_on_notebook', 'find_library']
senticnet['read_glass'] = [0, -0.028, 0.048, -0.058, '#angry', '#disgusting', -0.026, 'telescope', 'binoculars', 'eyeglass', 'camera', 'monocle']
senticnet['read_good_book'] = [0, 0.846, 0, 0.82, '#interesting', '#admirable', 0.555, 'meditate', 'fall_asleep', 'clear_mind', 'turn_off_television', 'pull_up_cover']
senticnet['read_history_book'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'study', 'study_history', 'history', 'prepare_exam', 'pass_exam']
senticnet['read_human'] = [-0.068, -0.039, -0.045, 0, '#sad', '#scared', -0.025, 'find_library', 'read', 'pick_tooth', 'make_paper', 'illuminate_area']
senticnet['read_instruction_manual'] = [0, 0.788, 0, 0.86, '#interesting', '#admirable', 0.549, 'turn', 'plug', 'switch', 'find_tape', 'twist']
senticnet['read_label'] = [0.768, 0.917, 0, 0, '#joyful', '#interesting', 0.562, 'tip_waitress', 'bring_home', 'carry_home', 'salivation', 'buy_steak']
senticnet['read_letter'] = [0.771, -0.962, 0, 0, '#joyful', '#surprising', 0.578, 'use_internet', 'surf_web', 'read_magazine', 'surf_net', 'hack']
senticnet['read_lot'] = [-0.062, -0.017, 0.016, -0.058, '#sad', '#disgusting', -0.04, 'bribe_teacher', 'study_hard', 'study_course_material', 'stay_school', 'graduate_college']
senticnet['read_magazine'] = [0, 0.073, -0.059, 0.067, '#interesting', '#admirable', 0.027, 'forum', 'blog', 'read_news', 'attend_meeting', 'read_book']
senticnet['read_manual'] = [-0.055, 0, 0.044, 0, '#sad', '#angry', -0.033, 'turn_computer_on', 'write_code', 'write_email', 'own_computer', 'learn_program_language']
senticnet['read_map'] = [-0.041, 0, 0.035, -0.115, '#sad', '#disgusting', -0.064, 'decide_to_go', 'buy_plane_ticket', 'buy_airplane_ticket', 'go_airport', 'know_go']
senticnet['read_material'] = [0.94, 0.736, 0, 0, '#joyful', '#interesting', 0.559, 'vocabulary', 'book_library', 'book_genre', 'many_words', 'definition']
senticnet['read_menu'] = [0, 0, 0.031, -0.1, '#angry', '#disgusting', -0.044, 'look_menu', 'fee_child', 'order_drink', 'use_restroom', 'place_order']
senticnet['read_message'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'leave_message', 'message', 'recall_message', 'send_message', 'take_message']
senticnet['read_much'] = [-0.048, 0.104, 0, 0.064, '#interesting', '#admirable', 0.04, 'intelligence', 'go_some_place_quiet', 'book_subject', 'study', 'focus_concentration']
senticnet['read_music'] = [0.899, 0.726, 0, 0, '#joyful', '#interesting', 0.542, 'part_of_band', 'sound_beautiful', 'beautiful_music', 'chamber_music', 'strum']
senticnet['read_new_book'] = [0.331, 0.119, 0.022, 0.229, '#joyful', '#admirable', 0.219, 'finish', 'book', 'finish_book', 'writer', 'finish_work']
senticnet['read_news'] = [0.494, 0.673, -0.269, 0.25, '#joyful', '#interesting', 0.383, 'information', 'report_event', 'source_information', 'review_book', 'report_news']
senticnet['read_newspaper'] = [-0.058, 0.106, 0, 0.06, '#interesting', '#admirable', 0.036, 'buy', 'newspaper', 'buy_newspaper', 'buy_book', 'read_news']
senticnet['read_out_loud'] = [-0.071, -0.069, 0.06, -0.24, '#sad', '#disgusting', -0.101, 'increase_knowledge', 'learn_much', 'gain_knowledge', 'gather_information', 'educate_oneself']
senticnet['read_paper'] = [0.899, 0.726, 0, 0, '#joyful', '#interesting', 0.542, 'read', 'read_newspaper', 'read_program', 'read_book', 'read_document']
senticnet['read_program'] = [0, 0.873, 0, 0, '#interesting', '#interesting', 0.291, 'applaud', 'listen_classical_music', 'enjoy_show', 'find_seat', 'see_performance']
senticnet['read_science_book'] = [0, 0.873, 0, 0, '#interesting', '#interesting', 0.291, 'look_up_dictionary_word', 'borrow_book_from_library', 'read_book', 'study_science', 'prepare_exam']
senticnet['read_story'] = [0, 0.898, 0, 0, '#interesting', '#interesting', 0.299, 'turn_page', 'improve_performance', 'discover_new', 'learn_book', 'take_book']
senticnet['read_textbook'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'read_book_subject', 'ask_expert', 'buy_textbook', 'use_search_engine', 'remember_information']
senticnet['read_through'] = [0.762, 0.823, 0, 0, '#joyful', '#interesting', 0.528, 'skim_through', 'read_cover', 'take_look', 'look_over', 'read_fast']
senticnet['readable'] = [0.026, 0, 0, 0.084, '#joyful', '#admirable', 0.037, 'book_write', 'make_book', 'written_text', 'written', 'book_paper']
senticnet['readiness'] = [-0.568, 0, 0.507, -0.891, '#sad', '#disgusting', -0.655, 'smoothness', 'ease', 'easiness', 'effortlessness', 'facility']
senticnet['reading'] = [0.572, -0.724, 0, 0.521, '#joyful', '#surprising', 0.606, 'browse', 'perusal', 'perusing', 'poring_over', 'studying']
senticnet['reading_program'] = [0.731, -0.97, 0, 0.957, '#surprising', '#admirable', 0.886, 'course_of_study', 'program', 'programme', 'curriculum', 'syllabus']
senticnet['ready'] = [0, 0.124, -0.072, 0.207, '#interesting', '#admirable', 0.086, 'start', 'motivation', 'likely', 'trust', 'available']
senticnet['ready_to_hand'] = [0.859, -0.81, 0, 0.615, '#joyful', '#surprising', 0.761, 'get_table', 'approachable', 'reachable', 'handy', 'accessible']
senticnet['ready_troop'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'kill_enemy', 'win_war', 'good_strategy', 'gain_territory', 'conquer_enemy']
senticnet['ready_work'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'write_resume', 'look_job', 'fill_out_application', 'go_interview', 'go_job']
senticnet['real'] = [0.092, 0.205, -0.084, 0.249, '#interesting', '#admirable', 0.154, 'good_investment', 'actual', 'estate', 'genuine', 'house_place']
senticnet['real_duck'] = [0, 0.07, 0, 0, '#interesting', '#interesting', 0.023, 'sunken_treasure', 'scuba_diver', 'urchin', 'mussel', 'gold_fish']
senticnet['real_estate'] = [0, 0.163, -0.049, 0.13, '#interesting', '#admirable', 0.081, 'house_land', 'estate', 'place_to_live', 'dwell_place', 'live_place']
senticnet['real_fact'] = [0, -0.039, 0, 0.097, '#surprising', '#admirable', 0.045, 'analyze', 'examine', 'find_truth', 'determine_truth', 'discover_truth']
senticnet['real_stuff'] = [0.726, -0.824, 0, 0.966, '#surprising', '#admirable', 0.839, 'real_thing', 'authenticity', 'credibility', 'credibleness', 'believability']
senticnet['real_thing'] = [0.726, -0.824, 0, 0.966, '#surprising', '#admirable', 0.839, 'authenticity', 'real_stuff', 'credibility', 'credibleness', 'believability']
senticnet['realign'] = [-0.756, 0, 0.514, -0.672, '#sad', '#disgusting', -0.647, 'align', 'realine', 'focus', 'true', 'address']
senticnet['realine'] = [-0.756, 0, 0.514, -0.672, '#sad', '#disgusting', -0.647, 'realign', 'align', 'focus', 'true', 'address']
senticnet['realistic'] = [0.858, 0, 0, 0.938, '#joyful', '#admirable', 0.599, 'earthy', 'real', 'practical', 'true', 'truthful']
senticnet['reality'] = [-0.639, 0, 0.694, -0.667, '#angry', '#disgusting', -0.667, 'tangibility', 'tangibleness', 'palpability', 'corporality', 'solidness']
senticnet['realization'] = [0, 0.893, 0, 0.72, '#interesting', '#admirable', 0.538, 'innovation', 'figure_out', 'come_conclusion', 'arrive_conclusion', 'resolve_problem']
senticnet['realize'] = [-0.058, 0.178, -0.129, 0.142, '#interesting', '#admirable', 0.044, 'recognize', 'investigation', 'deduce', 'aware', 'cognition']
senticnet['really_big'] = [0.033, 0.08, 0.044, 0.241, '#interesting', '#admirable', 0.103, 'large', 'big', 'huge', 'tall', 'wide']
senticnet['really_good'] = [0.886, 0.98, 0, 0.767, '#joyful', '#interesting', 0.878, 'high_quality', 'most_good', 'better_good', 'well_done', 'high_standard']
senticnet['really_hot'] = [0.247, 0.204, -0.064, 0.354, '#joyful', '#admirable', 0.247, 'burn_heat', 'hot', 'fire_burn', 'burn_hot', 'chemical_reaction']
senticnet['really_small'] = [-0.982, 0, -0.931, 0, '#sad', '#scared', -0.638, 'small', 'make_up_water', 'proton', 'spherical', 'small_object']
senticnet['really_want'] = [0.038, 0.306, -0.226, 0.313, '#interesting', '#admirable', 0.144, 'want_badly', 'yearn', 'help_out', 'generous', 'strong_desire']
senticnet['reanimate'] = [0.8, -0.977, 0, 0.512, '#joyful', '#surprising', 0.763, 'energize', 'perk_up', 'brace', 'stimulate', 'arouse']
senticnet['reap'] = [0.869, 0, 0, 0.908, '#joyful', '#admirable', 0.592, 'harvest', 'crop', 'grow_crop', 'plant_crop', 'graze_cattle']
senticnet['reaper'] = [-0.968, 0, -0.725, 0, '#sad', '#scared', -0.564, 'casualty', 'extermination', 'cause_death', 'abduction', 'die']
senticnet['rear'] = [-0.1, 0.184, -0.148, 0.179, '#interesting', '#admirable', 0.038, 'rear_end', 'flipside', 'backside', 'go_backwards', 'exception']
senticnet['rear_admiral'] = [0.688, -0.908, 0, 0.877, '#surprising', '#admirable', 0.824, 'fleet_admiral', 'flag_officer', 'admiral', 'full_admiral', 'vice_admiral']
senticnet['rear_end'] = [-0.046, 0.182, -0.104, 0.203, '#interesting', '#admirable', 0.078, 'exception', 'go_backwards', 'rear', 'backside', 'flipside']
senticnet['reason'] = [-0.097, 0.286, -0.182, 0.227, '#interesting', '#admirable', 0.078, 'consider', 'choice', 'explanation', 'rational', 'decide']
senticnet['reason_why'] = [0, 0.256, -0.052, 0.228, '#interesting', '#admirable', 0.144, 'end_point', 'end', 'conclusion', 'punctuation', 'bottom_line']
senticnet['reasonable'] = [-0.087, 0, -0.135, 0.085, '#sad', '#scared', -0.046, 'job_offer', 'rejection', 'lucky', 'borrow_money', 'quit_work']
senticnet['reasoning'] = [0.807, -0.711, 0, 0.877, '#joyful', '#admirable', 0.798, 'ratiocination', 'logical_argument', 'line_of_reasoning', 'thinking', 'thought']
senticnet['reasonless'] = [-0.982, 0, 0.646, -0.982, '#sad', '#disgusting', -0.87, 'indefensible', 'unreasonable', 'untenable', 'senseless', 'unwarranted']
senticnet['reassurance'] = [0.376, 0.271, -0.195, 0.258, '#joyful', '#interesting', 0.237, 'pleasant_emotion', 'bliss', 'good_feeling', 'like_taste', 'healthful']
senticnet['reassure'] = [0.52, 0.666, -0.261, 0.269, '#joyful', '#interesting', 0.398, 'reassuring', 'reassured', 'reassuringly', 'assure', 'likeable']
senticnet['reassured'] = [0.52, 0.666, -0.261, 0.269, '#joyful', '#interesting', 0.398, 'reassuring', 'reassuringly', 'reassure', 'assure', 'likeable']
senticnet['reassuring'] = [0.52, 0.666, -0.261, 0.269, '#joyful', '#interesting', 0.398, 'reassured', 'reassuringly', 'reassure', 'assure', 'likeable']
senticnet['reassuringly'] = [0.52, 0.666, -0.261, 0.269, '#joyful', '#interesting', 0.398, 'reassuring', 'reassured', 'reassure', 'assure', 'likeable']
senticnet['rebel'] = [0, 0, 0.732, -0.755, '#angry', '#disgusting', -0.496, 'decree', 'impose', 'raid', 'get_revenge', 'tyranny']
senticnet['rebellion'] = [0, 0, 0.859, -0.808, '#angry', '#disgusting', -0.556, 'uprise', 'opposition', 'against', 'disagreement', 'riot']
senticnet['rebellious'] = [-0.652, 0, 0.795, -0.96, '#angry', '#disgusting', -0.802, 'contumacious', 'disobedient', 'unruly', 'insubordinate', 'mutinous']
senticnet['reboot'] = [-0.05, 0.168, -0.045, 0.263, '#interesting', '#admirable', 0.112, 'move_mouse', 'keep_track_appointment', 'type_of_keyboard', 'train_open_mind', 'enter_address']
senticnet['rebuff'] = [-0.755, 0, 0.666, -0.518, '#sad', '#angry', -0.646, 'discourtesy', 'snub', 'cold_shoulder', 'offense', 'cut']
senticnet['rebuke'] = [-0.507, 0, 0.543, -0.628, '#angry', '#disgusting', -0.559, 'bawling_out', 'chewing_out', 'upbraiding', 'dressing_down', 'berating']
senticnet['rebut'] = [-0.962, 0, 0.885, -0.75, '#sad', '#angry', -0.866, 'controvert', 'answer', 'disown', 'renounce', 'repudiate']
senticnet['rebuttal'] = [-0.086, 0.101, -0.073, 0.169, '#interesting', '#admirable', 0.037, 'send_back', 'question_answer', 'retort', 'write_back', 'elaborate']
senticnet['recalcitrant'] = [-0.698, 0, 0.516, -0.941, '#sad', '#disgusting', -0.718, 'insubordinate', 'defiant', 'obstreperous', 'resistant', 'resistive']
senticnet['recalcitrate'] = [-0.68, 0, 0.765, -0.547, '#sad', '#angry', -0.664, 'fight', 'oppose', 'fight_back', 'fight_down', 'defend']
senticnet['recall'] = [0.946, 0.875, 0, 0, '#joyful', '#interesting', 0.607, 'recollection', 'brain_activity', 'memorization', 'memory', 'call_center']
senticnet['recall_message'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'leave_message', 'message', 'take_message', 'send_message', 'read_message']
senticnet['recant'] = [-0.97, 0, 0.616, -0.589, '#sad', '#angry', -0.725, 'abjure', 'repudiate', 'forswear', 'deny', 'reject']
senticnet['recede'] = [-0.548, 0, 0.644, -0.902, '#angry', '#disgusting', -0.698, 'retreat', 'retrograde', 'back_up', 'move', 'give_up']
senticnet['receipt'] = [0, 0.799, 0, 0.94, '#interesting', '#admirable', 0.58, 'invoice', 'bill', 'check', 'mastercard', 'payment_counter']
senticnet['receive'] = [0.773, 0, 0, 0.922, '#joyful', '#admirable', 0.565, 'give', 'cope', 'offer', 'accept', 'return']
senticnet['receive_applause'] = [0.795, -0.719, 0, 0, '#joyful', '#surprising', 0.505, 'exaggerate', 'wave_arm', 'show_off', 'laugh', 'applause']
senticnet['receive_change'] = [-0.795, 0, -0.956, 0, '#sad', '#scared', -0.584, 'go_broke', 'bankruptcy', 'run_out_money', 'compare_price', 'incur_debt']
senticnet['receive_email'] = [-0.05, 0.168, -0.045, 0.263, '#interesting', '#admirable', 0.112, 'email', 'receive', 'use_internet', 'use_computer', 'receive_information']
senticnet['receive_gift'] = [0.769, -0.713, 0, 0, '#joyful', '#surprising', 0.494, 'surprise_friend', 'act_foolish', 'blow_out_candle', 'tear_paper', 'say_love']
senticnet['receive_grade'] = [-0.096, -0.037, 0, -0.144, '#sad', '#disgusting', -0.068, 'show_know', 'get_grade', 'complete_course', 'test_knowledge', 'graduate']
senticnet['receive_help'] = [0.214, 0.258, -0.09, 0.2, '#joyful', '#interesting', 0.194, 'gather_evidence', 'testify', 'crime_scene', 'give_testimony', 'contact_police']
senticnet['receive_information'] = [0.75, 0.973, 0, 0.901, '#interesting', '#admirable', 0.875, 'learn_oneself', 'share_knowledge', 'increase_understand', 'know_story', 'gain_information']
senticnet['receive_letter'] = [0, 0.771, 0, 0, '#interesting', '#interesting', 0.257, 'post_letter', 'receive_email', 'hunt_duck', 'answer_telephone', 'needy']
senticnet['receive_mail'] = [0, 0.982, 0, 0, '#interesting', '#interesting', 0.327, 'open_letter', 'write_friend', 'receive_email', 'post_letter', 'open_envelope']
senticnet['receive_money'] = [0.025, 0.228, -0.079, 0.117, '#interesting', '#admirable', 0.097, 'work_for_money', 'give_money', 'earn_income', 'paycheck', 'compensation']
senticnet['receive_paycheck'] = [0, 0.982, 0, 0, '#interesting', '#interesting', 0.327, 'earn_paycheck', 'paycheck', 'earn_money', 'receive_money', 'compensation']
senticnet['receive_punishment'] = [-0.314, 0.095, -0.233, -0.033, '#sad', '#scared', -0.162, 'tell_lie', 'end_life', 'right_wrong', 'conceal_evidence', 'commit_crime']
senticnet['receive_reward'] = [0.559, 0.313, -0.212, 0.261, '#joyful', '#interesting', 0.307, 'good_emotion', 'satisfaction', 'joy', 'elation', 'happy']
senticnet['receive_service'] = [0.033, 0.179, -0.12, 0.251, '#interesting', '#admirable', 0.114, 'cash', 'cash_check', 'receive_change', 'incur_debt', 'bankruptcy']
senticnet['receive_signal'] = [0.107, 0.098, 0, 0.135, '#joyful', '#admirable', 0.113, 'listen_news', 'perform_on_stage', 'send_signal', 'play_cd', 'send_message']
senticnet['receive_thank'] = [0.917, 0, 0, 0.954, '#joyful', '#admirable', 0.624, 'feel_happy', 'good_karma', 'good_feeling', 'warm_feeling', 'say_thank_you']
senticnet['receiver'] = [0, 0, 0, 0.168, '#admirable', '#admirable', 0.056, 'handset', 'tuner', 'speaker', 'channel_selector', 'power_switch']
senticnet['recent'] = [0.842, 0.898, 0, 0, '#joyful', '#interesting', 0.58, 'holocene', 'recent_epoch', 'holocene_epoch', 'late', 'new']
senticnet['receptacle'] = [-0.047, 0.082, 0, 0.077, '#interesting', '#admirable', 0.037, 'achene', 'sepal', 'funiculus', 'calyx', 'rind']
senticnet['reception'] = [0.141, -0.125, -0.063, -0.06, '#joyful', '#surprising', 0.048, 'case_beer', 'confetti', 'cake_candle', 'festivity', 'keg']
senticnet['reception_area'] = [0.053, 0.1, 0, 0, '#joyful', '#interesting', 0.051, 'registry_office', 'lodgings', 'telephone_booth', 'cubicle', 'board_room']
senticnet['reception_desk'] = [0, 0.728, 0, 0.879, '#interesting', '#admirable', 0.536, 'fire_hydrant', 'stair_rail', 'christian_fundamentalist', 'extinguisher', 'fire_extinguisher']
senticnet['receptionist'] = [0.141, -0.125, -0.063, -0.06, '#joyful', '#surprising', 0.048, 'emergency_ward', 'dentist', 'hotel_receptionist', 'reception', 'receptionist_call']
senticnet['receptionist_call'] = [0.141, -0.125, -0.063, -0.06, '#joyful', '#surprising', 0.048, 'emergency_ward', 'dentist', 'hotel_receptionist', 'reception', 'receptionist']
senticnet['recidivate'] = [-0.9, 0, 0.837, -0.809, '#sad', '#angry', -0.849, 'revert', 'return', 'retrovert', 'regress', 'turn_back']
senticnet['recidivist'] = [0.806, -0.609, 0, 0.877, '#joyful', '#admirable', 0.764, 'felon', 'crook', 'malefactor', 'outlaw', 'criminal']
senticnet['recipient'] = [0.141, -0.125, -0.063, -0.06, '#joyful', '#surprising', 0.048, 'container', 'vessel', 'liquid_container', 'receptacle', 'bowl']
senticnet['reciprocal'] = [0.073, 0.256, -0.191, 0.371, '#interesting', '#admirable', 0.17, 'good_etiquette', 'okay', 'niceness', 'needful', 'want_badly']
senticnet['reciprocal_inhibition'] = [0.542, -0.63, 0, 0.912, '#surprising', '#admirable', 0.695, 'implosion_therapy', 'flooding', 'behavior_modification', 'aversion_therapy', 'desensitization_technique']
senticnet['reciprocate'] = [0.96, 0.951, 0, 0, '#joyful', '#interesting', 0.637, 'leave_table', 'seat_chair', 'crowd_room', 'learn_love_another', 'swim_lake']
senticnet['reciprocity'] = [-0.819, 0, 0.931, -0.777, '#sad', '#angry', -0.842, 'mutualness', 'mutuality', 'complementarity', 'correlation', 'correlativity']
senticnet['recite_poem'] = [0.047, -0.063, 0, -0.032, '#joyful', '#surprising', 0.026, 'convey_information', 'tell_story', 'express_idea', 'evoke_emotion', 'share_thought']
senticnet['reckless'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'lack_of_judgment', 'lack_of_discreetness', 'lack_of_discernment', 'injudiciousness', 'rentless']
senticnet['recklessness'] = [0, 0, 0.809, -0.914, '#angry', '#disgusting', -0.574, 'brashness', 'thoughtlessness', 'desperation', 'unthoughtfulness', 'rash']
senticnet['reckon'] = [0, 0, -0.116, 0, '#scared', '#scared', -0.039, 'year', 'week', 'century', 'month', 'november']
senticnet['recline'] = [0, 0, 0.808, -0.973, '#angry', '#disgusting', -0.594, 'inaction', 'lazy', 'stay', 'inactive', 'idle']
senticnet['recluse'] = [0, 0, -0.728, -0.763, '#scared', '#disgusting', -0.497, 'solitary', 'troglodyte', 'hermit', 'reclusive', 'solitudinarian']
senticnet['reclusiveness'] = [0.929, -0.797, 0, 0.915, '#joyful', '#admirable', 0.88, 'privacy', 'seclusion', 'privateness', 'solitariness', 'loneliness']
senticnet['recognition'] = [0.258, 0.35, -0.235, 0.318, '#interesting', '#admirable', 0.23, 'brownie_point', 'honor', 'reinforcement', 'positive_reinforcement', 'fame']
senticnet['recognize'] = [-0.047, 0.189, -0.067, 0.09, '#interesting', '#admirable', 0.055, 'cognition', 'become_aware', 'aware', 'gather_fact', 'figure_out']
senticnet['recognize_pattern'] = [0.919, 0.791, 0, 0, '#joyful', '#interesting', 0.57, 'ask_question', 'investigate_fact', 'think_through', 'ask_many_questions', 'form_opinion']
senticnet['recollection'] = [0, 0.935, 0, 0.804, '#interesting', '#admirable', 0.58, 'recall', 'think', 'brain_function', 'brain_activity', 'memory']
senticnet['recommend'] = [0.719, 0.902, 0, 0.701, '#joyful', '#interesting', 0.774, 'expand_horizon', 'escape_reality', 'stimulate_mind', 'acculturation', 'support']
senticnet['reconcile'] = [-0.752, 0, 0, -0.769, '#sad', '#disgusting', -0.507, 'pacify', 'appease', 'placate', 'propitiate', 'resignedly']
senticnet['reconsider'] = [0.91, 0.793, 0, 0, '#joyful', '#interesting', 0.568, 'weigh_consequence', 'consider_consequence', 'strategy', 'plan_attack', 'good_plan']
senticnet['reconstruct'] = [0.622, -0.827, 0, 0.776, '#surprising', '#admirable', 0.742, 'hypothesize', 'theorize', 'suppose', 'conjecture', 'speculate']
senticnet['reconstructive_surgery'] = [0.745, -0.556, 0, 0.597, '#joyful', '#admirable', 0.633, 'lift', 'phalloplasty', 'abdominoplasty', 'tummy_tuck', 'autoplasty']
senticnet['record_album'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'decorate_home', 'chamber_music', 'sound_beautiful', 'store_photo', 'produce_music']
senticnet['record_audio'] = [0.028, -0.602, 0, 0.354, '#surprising', '#admirable', 0.328, 'record', 'information', 'record_data', 'use_computer', 'record_information']
senticnet['record_data'] = [0.028, -0.602, 0, 0.354, '#surprising', '#admirable', 0.328, 'send_message', 'save_data', 'play_song', 'make_easy', 'perfect_skill']
senticnet['record_event'] = [0.028, -0.602, 0, 0.354, '#surprising', '#admirable', 0.328, 'event', 'record', 'record_data', 'record_movie', 'record_music']
senticnet['record_film'] = [0.779, 0.81, 0, 0, '#joyful', '#interesting', 0.53, 'store_film', 'proof_of_purchase', 'watch_television', 'use_television', 'view_video']
senticnet['record_history'] = [0.028, -0.602, 0, 0.354, '#surprising', '#admirable', 0.328, 'history', 'record_event', 'record_data', 'record_information', 'record']
senticnet['record_information'] = [0.028, -0.602, 0, 0.354, '#surprising', '#admirable', 0.328, 'record', 'information', 'record_data', 'use_computer', 'record_audio']
senticnet['record_keep'] = [-0.028, 0.204, 0, 0.106, '#interesting', '#admirable', 0.094, 'scribble', 'jot', 'keep_note', 'keep_track_expense', 'calligraphy']
senticnet['record_library'] = [0.064, -0.069, 0.054, 0, '#joyful', '#surprising', 0.026, 'stereo', 'tuner', 'speaker', 'radio', 'amplifier']
senticnet['record_movie'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'watch_news', 'watch_movie', 'watch_show', 'like_movie', 'enjoy_movie']
senticnet['record_music'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'record', 'music', 'record_song', 'record_sound', 'record_music_album']
senticnet['record_music_album'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'record', 'music', 'record_song', 'record_sound', 'record_music']
senticnet['record_song'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'record_music', 'play_instrument', 'play_musical_instrument', 'sound_beautiful', 'part_of_band']
senticnet['record_sound'] = [0.066, 0, 0, 0.141, '#joyful', '#admirable', 0.069, 'crochet', 'hold_two_together', 'shut_down', 'hear_noise', 'skip']
senticnet['record_store'] = [-0.053, 0, 0.031, -0.028, '#sad', '#angry', -0.037, 'clothes_drawer', 'clothes_store', 'department_store', 'sex_shop', 'pawn_shop']
senticnet['record_story'] = [0.742, 0, 0, 0.815, '#joyful', '#admirable', 0.519, 'write_down_idea', 'write_down', 'take_note', 'write_word', 'use_pen']
senticnet['record_studio'] = [0.723, -0.746, 0, 0, '#joyful', '#surprising', 0.49, 'studio', 'opus', 'concert_hall', 'tv_studio', 'opus_house']
senticnet['record_television_show'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'tape_television_show', 'view_film_home', 'watch_movie', 'rewind', 'record_movie']
senticnet['recover_illness'] = [0, 0, 0, 0.795, '#admirable', '#admirable', 0.265, 'clear_head', 'read_good_book', 'relax_mind', 'clear_mind', 'reduce_stress']
senticnet['recoverer'] = [-0.736, 0, 0.822, -0.732, '#sad', '#angry', -0.763, 'succorer', 'succourer', 'salvager', 'salvor', 'mortal']
senticnet['recreant'] = [-0.956, 0, 0.825, -0.806, '#sad', '#angry', -0.862, 'cur', 'dastard', 'craven', 'coward', 'mortal']
senticnet['recreate'] = [0, 0.828, 0, 0.822, '#interesting', '#admirable', 0.55, 'closeness', 'cheer_up', 'jubilation', 'glee', 'cheer']
senticnet['recreation'] = [0, 0.962, 0, 0.911, '#interesting', '#admirable', 0.624, 'play_friend', 'competition', 'break', 'watch_baseball', 'fun_exercise']
senticnet['recreational'] = [0, -0.897, 0, 0.92, '#surprising', '#admirable', 0.606, 'winter_sport', 'good_sport', 'enjoyable_activity', 'fun_exercise', 'competitive']
senticnet['recreational_activity'] = [0, -0.807, 0, 0.993, '#surprising', '#admirable', 0.6, 'winter_sport', 'fun_sport', 'olympic_sport', 'recreational', 'good_sport']
senticnet['recrudesce'] = [0.552, -0.641, 0, 0.955, '#surprising', '#admirable', 0.716, 'occur', 'fall_out', 'pass_off', 'happen', 'hap']
senticnet['rectangle'] = [0, 0.917, 0, 0.901, '#interesting', '#admirable', 0.606, 'square', 'four_sides', 'rhombus', 'four_corners', 'cube']
senticnet['rectangular'] = [0.037, 0.068, 0.051, 0.171, '#interesting', '#admirable', 0.075, 'four_corners', 'wooden', 'square', 'rectangle', 'rectangular_shape']
senticnet['rectangular_shape'] = [0.034, 0.141, 0.024, 0.239, '#interesting', '#admirable', 0.13, 'house_open', 'portal', 'square', 'entrance_room', 'home_entrance']
senticnet['rector'] = [0.031, 0.272, 0, 0.231, '#interesting', '#admirable', 0.178, 'minister', 'church_head', 'pastor', 'protestant', 'evangelist']
senticnet['recuperate'] = [0, 0.877, 0, 0, '#interesting', '#interesting', 0.292, 'get_rest', 'rejuvenation', 'feel_refreshed', 'take_nap', 'get_sleep']
senticnet['recur'] = [0, 0.128, -0.067, 0.172, '#interesting', '#admirable', 0.078, 'never_end', 'no_end', 'frequent', 'usual_ordinary', 'again_and_again']
senticnet['recusant'] = [0.742, -0.965, 0, 0.58, '#joyful', '#surprising', 0.762, 'dissident', 'beat', 'bohemian', 'maverick', 'enfant_terrible']
senticnet['recyclable'] = [0, 0.065, 0, 0.146, '#interesting', '#admirable', 0.07, 'drink_container', 'storage_container', 'opaque', 'drink_holder', 'food_container']
senticnet['recycle_bin'] = [0, 0.07, 0, 0.067, '#interesting', '#admirable', 0.046, 'car_trunk', 'walmart', 'warehouse', 'store', 'storage_place']
senticnet['recycle_paper'] = [0, 0, 0, 0.739, '#admirable', '#admirable', 0.246, 'spring_action', 'see_star_night', 'state_opinion', 'visit_grandmother', 'forward_email']
senticnet['red'] = [-0.076, 0.101, 0, 0.105, '#interesting', '#admirable', 0.043, 'green_black', 'bright_red', 'purple', 'red_green', 'precious_jewel']
senticnet['red-bellied_black_snake'] = [-0.028, -0.008, -0.052, -0.08, '#scared', '#disgusting', -0.051, 'eastern_brown_snake', 'poisonous_snake', 'lizard', 'snake', 'shark']
senticnet['red_apple'] = [-0.051, 0, 0.037, 0, '#sad', '#angry', -0.029, 'color', 'bright_color', 'secondary_color', 'light_red', 'primary_color']
senticnet['red_blue'] = [-0.047, 0.079, 0, 0.073, '#interesting', '#admirable', 0.035, 'red_green', 'red_orange', 'spectrum', 'yellow_green', 'black_green']
senticnet['red_bone_marrow'] = [0.73, -0.726, 0, 0.653, '#joyful', '#surprising', 0.703, 'red_marrow', 'bone_marrow', 'yellow_marrow', 'yellow_bone_marrow', 'connective_tissue']
senticnet['red_buckeye'] = [-0.579, 0, 0.582, -0.65, '#angry', '#disgusting', -0.604, 'sweet_buckeye', 'dwarf_buckeye', 'bottlebrush_buckeye', 'horse_chestnut', 'particolohorse_chestnut']
senticnet['red_card'] = [-0.983, 0, 0.334, -0.914, '#sad', '#disgusting', -0.744, 'punishment', 'fault', 'probabilty_of_losing', 'yellow_card', 'penalty_shoot']
senticnet['red_carpet'] = [0.796, 0.851, 0, 0, '#joyful', '#interesting', 0.549, 'expensive_dress', 'dress', 'fashion', 'gala', 'fancy_dress']
senticnet['red_color'] = [0, 0.114, 0, 0.122, '#interesting', '#admirable', 0.079, 'red', 'delicate', 'often_red', 'orifice', 'bright_red']
senticnet['red_cross'] = [0, 0.066, -0.058, 0.095, '#interesting', '#admirable', 0.034, 'interjection', 'like_car', 'another_name', 'traffic_cop', 'gas_electric']
senticnet['red_eye'] = [-0.191, -0.012, -0.093, -0.037, '#sad', '#scared', -0.103, 'easter_bunny', 'cute_animal', 'domestic_pet', 'household_pet', 'large_mouse']
senticnet['red_fox'] = [-0.662, 0, 0.992, -0.726, '#angry', '#disgusting', -0.793, 'vixen', 'fox', 'kit_fox', 'prairie_fox', 'white_fox']
senticnet['red_fruit'] = [0.049, 0.078, 0.05, 0.121, '#interesting', '#admirable', 0.066, 'green_fruit', 'tree_fruit', 'round_fruit', 'crunchy', 'redness']
senticnet['red_green'] = [-0.045, 0.076, 0.009, 0.087, '#interesting', '#admirable', 0.036, 'black_green', 'yellow_green', 'blue_green', 'purple', 'red_orange']
senticnet['red_indian'] = [0, -0.984, 0, 0.931, '#surprising', '#admirable', 0.638, 'from_here', 'far_west', 'live_place', 'family_live', 'original']
senticnet['red_light'] = [-0.078, 0, 0.115, -0.158, '#angry', '#disgusting', -0.117, 'stop', 'halt', 'alarm', 'alert', 'danger']
senticnet['red_light_district'] = [0.167, 0.092, -0.045, 0.13, '#joyful', '#admirable', 0.115, 'homosexual', 'pornography', 'ceiling_fan', 'pillow_case', 'storage_box']
senticnet['red_lip'] = [0.081, 0, 0, 0.086, '#joyful', '#admirable', 0.056, 'white_tooth', 'feel_clean', 'sexy', 'smell_better', 'look_good']
senticnet['red_marrow'] = [0.73, -0.726, 0, 0.653, '#joyful', '#surprising', 0.703, 'bone_marrow', 'red_bone_marrow', 'yellow_marrow', 'yellow_bone_marrow', 'connective_tissue']
senticnet['red_meat'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'grill', 'cook_grill', 'barbecue', 'cook', 'grilled_vegetables']
senticnet['red_oak'] = [0.672, -0.696, 0, 0.831, '#surprising', '#admirable', 0.733, 'southern_red_oak', 'swamp_red_oak', 'turkey_oak', 'northern_red_oak', 'oak']
senticnet['red_octagon'] = [0.021, 0.093, 0, 0.185, '#interesting', '#admirable', 0.1, 'octagon', 'indication', 'eight_sides', 'red_light', 'placard']
senticnet['red_orange'] = [-0.058, 0.082, 0, 0.073, '#interesting', '#admirable', 0.032, 'spectrum', 'green_yellow', 'red_blue', 'yellow_green', 'hue_tint']
senticnet['red_phalarope'] = [0.786, -0.82, 0, 0.776, '#joyful', '#surprising', 0.794, 'phalarope', 'northern_phalarope', 'shorebird', 'shore_bird', 'limicoline_bird']
senticnet['red_region'] = [-0.924, 0, 0.687, -0.75, '#sad', '#disgusting', -0.787, 'hellfire', 'infernal_region', 'imaginary_place', 'mythical_place', 'fictitious_place']
senticnet['red_rise'] = [0, 0.83, 0, 0.945, '#interesting', '#admirable', 0.592, 'hug', 'go_kiss', 'kiss', 'kiss_other', 'ferment']
senticnet['red_rose'] = [0.733, 0, 0, 0.854, '#joyful', '#admirable', 0.529, 'kiss', 'rise_plant', 'flower', 'sexuality', 'see_beautiful_girl']
senticnet['red_skin'] = [-0.078, 0, 0.115, -0.158, '#angry', '#disgusting', -0.117, 'crispy', 'skin_injury', 'make_hot', 'burn_skin', 'make_drunk']
senticnet['red_spot'] = [-0.963, 0, 0.064, -0.96, '#sad', '#disgusting', -0.662, 'disease', 'illness', 'sickness', 'itchy_skin', 'sick']
senticnet['red_stone'] = [0.826, 0, 0, 0.857, '#joyful', '#admirable', 0.561, 'solid', 'brown', 'opaque', 'precious_jewel', 'generic']
senticnet['red_white_blue'] = [0, 0.883, 0, 0.987, '#interesting', '#admirable', 0.623, 'blue_green', 'star_stripe', 'hue', 'hue_tint', 'purple']
senticnet['red_wine'] = [0.122, -0.155, 0.071, -0.069, '#joyful', '#surprising', 0.046, 'bar', 'tavern', 'brandy', 'rum', 'liquor_store']
senticnet['reddish_purple'] = [0.591, -0.553, 0, 0.514, '#joyful', '#surprising', 0.553, 'violet', 'mauve', 'lavender', 'purple', 'royal_purple']
senticnet['redemption'] = [0.786, 0, 0, 0.821, '#joyful', '#admirable', 0.536, 'expiation', 'atonement', 'propitiation', 'rescue', 'achievment']
senticnet['redneck'] = [-0.967, 0, 0.924, -0.865, '#sad', '#angry', -0.919, 'rustic', 'yokel', 'rube', 'hick', 'hayseed']
senticnet['redness'] = [0, 0.879, 0, 0.996, '#interesting', '#admirable', 0.625, 'red_fruit', 'crunchy', 'green_fruit', 'vegetarian_food', 'small_fruit']
senticnet['redo'] = [-0.031, 0.213, 0, 0.268, '#interesting', '#admirable', 0.15, 'again_and_again', 'one_more', 'do_again', 'done', 'inclusion']
senticnet['redolence'] = [0.61, -0.781, 0, 0.851, '#surprising', '#admirable', 0.747, 'scent', 'aroma', 'olfactory_property', 'smell', 'odor']
senticnet['redolent'] = [0, 0, -0.707, -0.801, '#scared', '#disgusting', -0.503, 'resonant', 'remindful', 'smelling', 'reminiscent', 'evocative']
senticnet['redress'] = [-0.881, 0, 0.811, -0.514, '#sad', '#angry', -0.735, 'atonement', 'expiation', 'punitive_damage', 'exemplary_damages', 'compensation']
senticnet['reduce'] = [-0.129, -0.058, 0, -0.134, '#sad', '#disgusting', -0.068, 'diminish', 'decrease', 'lower', 'lower_music', 'low_level']
senticnet['reduce_hunger'] = [0.885, 0, 0, 0.871, '#joyful', '#admirable', 0.585, 'fill_stomach', 'satisfy_hunger', 'sustenance', 'relieve_hunger', 'enjoy_eat']
senticnet['reduce_pollution'] = [0.107, 0.098, 0, 0.135, '#joyful', '#admirable', 0.113, 'go_green', 'respect_nature', 'save_water', 'go_on_foot', 'spread_seed']
senticnet['reduce_stress'] = [0.939, 0.865, 0, 0, '#joyful', '#interesting', 0.601, 'stress_reduction', 'relaxation', 'relax', 'stress_relief', 'lower_stress']
senticnet['reduce_temperature'] = [0.413, 0.239, -0.091, 0.137, '#joyful', '#interesting', 0.233, 'lower_temperature', 'remove_heat', 'cool_room', 'rich_house', 'nice_house']
senticnet['reduced'] = [-0.543, 0, 0.661, -0.711, '#angry', '#disgusting', -0.638, 'remittent', 'diminished', 'weakened', 'faded', 'small']
senticnet['reduction'] = [-0.129, -0.058, 0, -0.134, '#sad', '#disgusting', -0.068, 'decrement', 'diminution', 'decrease', 'inferior', 'reduce']
senticnet['redundance'] = [-0.775, 0, 0.9, -0.799, '#angry', '#disgusting', -0.825, 'embarrassment', 'fifth_wheel', 'deadwood', 'overplus', 'plethora']
senticnet['redundancy_check'] = [0.84, -0.979, 0, 0.713, '#joyful', '#surprising', 0.844, 'proof', 'bed_check', 'crosscheck', 'parity_check', 'substantiation']
senticnet['redundant'] = [0, 0, -0.956, -0.817, '#scared', '#disgusting', -0.591, 'spare', 'supererogatory', 'extra', 'superfluous', 'excess']
senticnet['reduviid'] = [-0.773, 0, 0.576, -0.922, '#sad', '#disgusting', -0.757, 'insect', 'firebug', 'water_bug', 'assassin_bug', 'heteropterous_insect']
senticnet['reed_instrument'] = [-0.036, -0.009, 0.018, -0.082, '#sad', '#disgusting', -0.042, 'use_jazz_music', 'stringed_musical_instrument', 'instrument_music', 'musical_instrument', 'listen_music']
senticnet['reed_mace'] = [0.656, -0.632, 0, 0.844, '#joyful', '#admirable', 0.711, 'bullrush', 'bulrush', 'nailrod', 'cattail', 'reedmace']
senticnet['reef'] = [0, 0, -0.065, -0.036, '#scared', '#disgusting', -0.034, 'tidal_pool', 'saltwater', 'fish_market', 'sea', 'coral_reef']
senticnet['reek'] = [-0.609, 0, 0.985, -0.524, '#sad', '#angry', -0.706, 'niff', 'pong', 'smell', 'odor', 'olfactory_sensation']
senticnet['reel'] = [0, -0.042, 0.113, -0.047, '#angry', '#disgusting', -0.039, 'net', 'fish_rod', 'swimsuit', 'volleyball', 'fish_pole']
senticnet['reenforce'] = [0.846, -0.941, 0, 0.797, '#joyful', '#surprising', 0.861, 'strengthen', 'buttress', 'mine', 'line', 'bolster']
senticnet['refer'] = [0.083, 0.179, -0.132, 0.256, '#interesting', '#admirable', 0.129, 'vocabulary', 'translation', 'sentence', 'narrative', 'reference']
senticnet['refill'] = [0.022, -0.057, 0.079, -0.116, '#angry', '#disgusting', -0.039, 'stationery', 'ink', 'paper', 'ball_point_pen', 'notes']
senticnet['refine'] = [0.992, -0.723, 0, 0.604, '#joyful', '#surprising', 0.773, 'better', 'improve', 'chisel', 'meliorate', 'cultivate']
senticnet['refined'] = [0.614, -0.959, 0, 0.537, '#joyful', '#surprising', 0.703, 'mincing', 'twee', 'gentlemanlike', 'gentlemanly', 'ladylike']
senticnet['refined_sugar'] = [0.53, -0.64, 0, 0.934, '#surprising', '#admirable', 0.701, 'aspartame', 'honey', 'saccharin', 'sugar', 'sweetener']
senticnet['reflect'] = [0.083, 0.179, -0.132, 0.256, '#interesting', '#admirable', 0.129, 'think', 'consider', 'ponder', 'deliberate', 'cogitate']
senticnet['reflect_image'] = [0, 0, 0, 0.08, '#admirable', '#admirable', 0.027, 'stream_ocean', 'mirror', 'cool_car_engine', 'flow_lake', 'liquid_drink']
senticnet['reflect_light'] = [-0.034, 0.087, 0, 0.061, '#interesting', '#admirable', 0.038, 'red_orange', 'hue_tint', 'yellow_orange', 'spectrum', 'red_blue']
senticnet['reflect_water'] = [0, 0.135, -0.087, 0.123, '#interesting', '#admirable', 0.057, 'rise', 'lift', 'store_garage', 'go_upstairs', 'arise']
senticnet['reflecting'] = [0, 0, -0.895, -0.944, '#scared', '#disgusting', -0.613, 'meditate', 'excogitate', 'ponder', 'think_over', 'chew_over']
senticnet['reflection'] = [0, 0.992, 0, 0.873, '#interesting', '#admirable', 0.622, 'thinker', 'viewpoint', 'recognize', 'know_first', 'observe']
senticnet['reflective'] = [0, 0.772, 0, 0.974, '#interesting', '#admirable', 0.582, 'chill', 'tender', 'stimulate', 'sensationally', 'sensational']
senticnet['reflex'] = [0, -0.89, 0, 0.891, '#surprising', '#admirable', 0.594, 'effect', 'push', 'smash', 'puss', 'heap']
senticnet['reflex_action'] = [0.89, -0.821, 0, 0.776, '#joyful', '#surprising', 0.829, 'reflex', 'reflex_response', 'babinski', 'instinctive_reflex', 'innate_reflex']
senticnet['reflex_response'] = [0.89, -0.821, 0, 0.776, '#joyful', '#surprising', 0.829, 'reflex', 'babinski', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['reformer'] = [-0.673, 0, 0.993, -0.85, '#angry', '#disgusting', -0.839, 'dry', 'insurgent', 'militant', 'passive_resister', 'demonstrator']
senticnet['reformist'] = [-0.829, 0, 0.901, -0.671, '#sad', '#angry', -0.8, 'dry', 'insurgent', 'militant', 'passive_resister', 'demonstrator']
senticnet['refractory'] = [-0.778, 0, 0.886, -0.584, '#sad', '#angry', -0.749, 'disobedient', 'obstinate', 'recalcitrant', 'froward', 'headstrong']
senticnet['refrain_from'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'avoid_conversation', 'avoid_person', 'prevent', 'avoid_fight', 'avoid']
senticnet['refresh'] = [0.867, 0.871, 0, 0, '#joyful', '#interesting', 0.579, 'work_break', 'recover', 'feel_fresh', 'middle_day', 'regain_energy']
senticnet['refresh_memory'] = [0.107, 0.098, 0, 0.135, '#joyful', '#admirable', 0.113, 'relax_mind', 'pleasant_thought', 'use_mind', 'reduce_stress', 'good_memory']
senticnet['refrigerate'] = [-0.063, 0, 0.013, 0, '#sad', '#angry', -0.025, 'dry_hair', 'bind_book', 'scrub_floor', 'remove_paint', 'mow_grass']
senticnet['refuge'] = [0, 0.091, 0, 0.101, '#interesting', '#admirable', 0.064, 'habitat', 'mom_house', 'windsor', 'pacific_northwest', 'wilderness']
senticnet['refulgence'] = [0.54, -0.645, 0, 0.728, '#surprising', '#admirable', 0.638, 'gleaming', 'luster', 'polish', 'glow', 'burnish']
senticnet['refulgency'] = [0.828, -0.527, 0, 0.815, '#joyful', '#admirable', 0.723, 'gleaming', 'luster', 'polish', 'glow', 'burnish']
senticnet['refuse'] = [0, 0, 0, -0.101, '#disgusting', '#disgusting', -0.034, 'rubbish', 'store_trash', 'hold_trash', 'put_trash', 'garbage']
senticnet['refuse_bin'] = [-0.91, 0, 0.38, -0.91, '#sad', '#disgusting', -0.733, 'trash', 'waste', 'garbage', 'rubbish', 'refuse']
senticnet['refuse_dogma'] = [-0.854, 0, 0.954, -0.863, '#angry', '#disgusting', -0.89, 'refuse_value', 'refuse_religion', 'disbelieve', 'discredit', 'distrust']
senticnet['refuse_heap'] = [-0.594, 0, 0.506, -0.521, '#sad', '#disgusting', -0.54, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'wasteyard']
senticnet['refuse_religion'] = [-0.854, 0, 0.954, -0.863, '#angry', '#disgusting', -0.89, 'refuse_value', 'refuse_dogma', 'disbelieve', 'discredit', 'distrust']
senticnet['refuse_value'] = [-0.854, 0, 0.954, -0.863, '#angry', '#disgusting', -0.89, 'refuse_religion', 'refuse_dogma', 'disbelieve', 'discredit', 'distrust']
senticnet['refute'] = [-0.686, 0, 0.733, -0.828, '#angry', '#disgusting', -0.749, 'controvert', 'answer', 'disown', 'renounce', 'repudiate']
senticnet['regain_energy'] = [0, -0.052, 0.027, 0.05, '#surprising', '#admirable', 0.025, 'exercise', 'heavy_breathing', 'need_break', 'rest_up', 'catch_breath']
senticnet['regal'] = [0.091, 0, -0.073, 0.176, '#joyful', '#admirable', 0.065, 'royalty', 'royal_person', 'royal_title', 'monarch', 'blue_blood']
senticnet['regard'] = [0.405, 0.638, -0.369, 0.484, '#interesting', '#admirable', 0.386, 'admire', 'preference', 'optimism', 'confidence', 'bravery']
senticnet['regenerate'] = [-0.819, 0, 0.504, -0.966, '#sad', '#disgusting', -0.763, 'freshen', 'air_out', 'air', 'renew', 'vent']
senticnet['regimentation'] = [-0.706, 0, 0.552, -0.681, '#sad', '#disgusting', -0.646, 'protection', 'imposition', 'taxation', 'trade_protection', 'reimposition']
senticnet['region'] = [0.034, 0.07, 0.01, 0.076, '#interesting', '#admirable', 0.057, 'territory', 'political_division', 'area', 'large_area', 'state']
senticnet['regional_enteritis'] = [-0.755, 0, 0.868, -0.992, '#angry', '#disgusting', -0.872, 'colitis', 'regional_ileitis', 'ulcerative_colitis', 'rubor', 'redness']
senticnet['regional_ileitis'] = [-0.755, 0, 0.868, -0.992, '#angry', '#disgusting', -0.872, 'regional_enteritis', 'colitis', 'ulcerative_colitis', 'rubor', 'redness']
senticnet['register_vote'] = [0, 0.923, 0, 0, '#interesting', '#interesting', 0.308, 'resolve_conflict', 'serve_jury', 'bang_gavel', 'examine_evidence', 'become_lawyer']
senticnet['registry_office'] = [0.053, 0.1, 0, 0, '#joyful', '#interesting', 0.051, 'board_room', 'lodgings', 'telephone_booth', 'cubicle', 'reception_area']
senticnet['regress'] = [-0.9, 0, 0.837, -0.809, '#sad', '#angry', -0.849, 'revert', 'return', 'retrovert', 'recidivate', 'turn_back']
senticnet['regression'] = [-0.946, 0, 0.678, -0.83, '#sad', '#disgusting', -0.818, 'reversion', 'change_of_state', 'reversal', 'regress', 'retrogression']
senticnet['regret'] = [-0.917, 0.096, -0.724, 0.098, '#sad', '#scared', -0.482, 'guilt', 'grief', 'sorrow', 'woe', 'remorse']
senticnet['regretful'] = [-0.869, 0.195, -0.58, 0, '#sad', '#scared', -0.418, 'sorrowful', 'ruefulness', 'sadly', 'mournful', 'self-pity']
senticnet['regrow'] = [-0.606, 0, 0.752, -0.987, '#angry', '#disgusting', -0.782, 'get', 'acquire', 'grow', 'develop', 'produce']
senticnet['regular'] = [0, 0.098, -0.073, 0.136, '#interesting', '#admirable', 0.054, 'normal', 'usual_ordinary', 'frequent', 'usual', 'typical']
senticnet['regular_convex_polyhedron'] = [0.805, -0.629, 0, 0.602, '#joyful', '#surprising', 0.679, 'regular_tetrahedron', 'cube', 'regular_hexahedron', 'regular_dodecahedron', 'regular_octahedron']
senticnet['regular_convex_solid'] = [0.829, -0.981, 0, 0.882, '#surprising', '#admirable', 0.897, 'regular_tetrahedron', 'cube', 'regular_hexahedron', 'regular_dodecahedron', 'regular_octahedron']
senticnet['regular_dodecahedron'] = [0.641, -0.6, 0, 0.957, '#joyful', '#admirable', 0.733, 'regular_tetrahedron', 'cube', 'regular_hexahedron', 'ideal_solid', 'regular_octahedron']
senticnet['regular_exercise'] = [-0.065, -0.027, 0.021, -0.06, '#sad', '#disgusting', -0.04, 'clean_window', 'vacuum_carpet', 'repetitive_task', 'run_long_time', 'exercise_daily']
senticnet['regular_hexahedron'] = [0.641, -0.6, 0, 0.957, '#joyful', '#admirable', 0.733, 'regular_tetrahedron', 'cube', 'ideal_solid', 'regular_dodecahedron', 'regular_octahedron']
senticnet['regular_octahedron'] = [0.641, -0.6, 0, 0.957, '#joyful', '#admirable', 0.733, 'regular_tetrahedron', 'cube', 'regular_hexahedron', 'regular_dodecahedron', 'ideal_solid']
senticnet['regular_payment'] = [0.529, -0.844, 0, 0.559, '#surprising', '#admirable', 0.644, 'pay', 'disability_check', 'disability_payment', 'wage', 'earnings']
senticnet['regular_polyhedron'] = [0.695, -0.778, 0, 0.802, '#surprising', '#admirable', 0.758, 'regular_tetrahedron', 'cube', 'regular_hexahedron', 'regular_dodecahedron', 'regular_octahedron']
senticnet['regular_tetrahedron'] = [0.641, -0.6, 0, 0.957, '#joyful', '#admirable', 0.733, 'ideal_solid', 'cube', 'regular_hexahedron', 'regular_dodecahedron', 'regular_octahedron']
senticnet['regularize'] = [-0.91, 0, 0.637, -0.598, '#sad', '#angry', -0.715, 'gauge', 'govern', 'regulate', 'standardize', 'order']
senticnet['regularly'] = [0, 0.152, 0, 0.119, '#interesting', '#admirable', 0.09, 'never_end', 'start_end', 'everyday', 'description', 'precise']
senticnet['regulation'] = [0, 0.178, 0, 0.182, '#interesting', '#admirable', 0.12, 'edict', 'law', 'legislation', 'rule', 'march_rear']
senticnet['regulatory_offence'] = [-0.648, 0, 0.854, -0.83, '#angry', '#disgusting', -0.777, 'crime', 'bigamy', 'sexual_assault', 'sexual_abuse', 'sex_crime']
senticnet['regulatory_offense'] = [-0.68, 0, 0.522, -0.543, '#sad', '#disgusting', -0.582, 'crime', 'bigamy', 'sexual_assault', 'sexual_abuse', 'sex_crime']
senticnet['rehabilitation'] = [0.641, -0.784, 0, 0.721, '#surprising', '#admirable', 0.715, 'correctional_rehabilitation', 'physical_rehabilitation', 'physical_restoration', 'therapeutic_rehabilitation', 'vocational_rehabilitation']
senticnet['rehearse'] = [-0.032, 0.114, 0, 0.111, '#interesting', '#admirable', 0.064, 'practice', 'warm_up', 'know_rule', 'skill', 'determination']
senticnet['rehearse_room'] = [0.136, -0.056, -0.046, -0.03, '#joyful', '#surprising', 0.039, 'theater_hall', 'amphitheater', 'theater_box', 'sound_control_room', 'soundstage']
senticnet['reign'] = [0.022, 0.138, 0, 0.128, '#interesting', '#admirable', 0.096, 'rule_government', 'rule', 'kingdom', 'regulation', 'legislature']
senticnet['reimposition'] = [-0.706, 0, 0.552, -0.681, '#sad', '#disgusting', -0.646, 'protection', 'regimentation', 'taxation', 'trade_protection', 'imposition']
senticnet['reinforce'] = [0.165, 0.297, -0.147, 0.26, '#interesting', '#admirable', 0.192, 'accomplish', 'incentive', 'get_job_done', 'promotion', 'ask_nicely']
senticnet['reinforce_concrete'] = [0, 0.762, 0, 0.716, '#interesting', '#admirable', 0.493, 'investment_return', 'entice', 'fish_lake', 'land_fish', 'catch_fish']
senticnet['reinforcement'] = [0.244, 0.445, -0.325, 0.454, '#interesting', '#admirable', 0.273, 'given', 'give_help', 'kindness', 'reinforce', 'fashionable']
senticnet['reinforcer'] = [0.583, -0.826, 0, 0.574, '#joyful', '#surprising', 0.661, 'stimulant', 'positive_reinforcing_stimulus', 'positive_reinforcer', 'negative_reinforcing_stimulus', 'negative_reinforcer']
senticnet['reinforcing_stimulus'] = [0.847, -0.994, 0, 0.512, '#joyful', '#surprising', 0.784, 'stimulant', 'positive_reinforcing_stimulus', 'positive_reinforcer', 'negative_reinforcing_stimulus', 'negative_reinforcer']
senticnet['reinvigorate'] = [0.845, -0.596, 0, 0.926, '#joyful', '#admirable', 0.789, 'energize', 'perk_up', 'brace', 'stimulate', 'arouse']
senticnet['reject'] = [-0.732, 0, 0.897, 0, '#sad', '#angry', -0.543, 'isolation', 'dislike', 'huffy', 'huffily', 'huffiness']
senticnet['reject_involvement'] = [-0.773, 0, 0.877, -0.947, '#angry', '#disgusting', -0.866, 'avoid_work', 'lazy', 'avoid_responsibility', 'skip_class', 'skip_assignment']
senticnet['rejection'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'forget_name', 'say_no', 'sexual_attraction', 'turn_down', 'tell_others']
senticnet['rejoice'] = [0.815, 0.745, 0, 0.893, '#joyful', '#admirable', 0.818, 'contented', 'rejoicing', 'jocularity', 'jocundity', 'jubilant']
senticnet['rejoicing'] = [0.723, 0.617, -0.225, 0.325, '#joyful', '#interesting', 0.48, 'triumphantly', 'triumphant', 'prideful', 'triumphal', 'exultant']
senticnet['rejoinder'] = [-0.842, 0, 0.572, -0.681, '#sad', '#disgusting', -0.698, 'reply', 'response', 'sass', 'sassing', 'backtalk']
senticnet['rejuvenation'] = [0.809, 0.702, 0, 0, '#joyful', '#interesting', 0.504, 'feel_refreshed', 'heal_injury', 'get_rest', 'recuperate', 'feel_little_tired']
senticnet['relate'] = [0.032, 0.261, -0.157, 0.198, '#interesting', '#admirable', 0.111, 'similar', 'contrary', 'good_etiquette', 'niceness', 'compliment']
senticnet['relate_music'] = [0.244, -0.085, 0.058, -0.029, '#joyful', '#surprising', 0.081, 'done_person', 'move_rhythm_music', 'ballroom_dance', 'waltz', 'jump_around']
senticnet['relate_person'] = [0, 0.935, 0, 0.753, '#interesting', '#admirable', 0.563, 'parent_child', 'kin', 'mom_dad', 'brother_sister', 'father_son']
senticnet['relation'] = [0, 0.847, 0, 0.713, '#interesting', '#admirable', 0.52, 'dad', 'brother_sister', 'cousin', 'female_sibling', 'relative']
senticnet['relationship'] = [0.767, 0.985, 0, 0.918, '#interesting', '#admirable', 0.89, 'kinship', 'care_giver', 'relative', 'relate_person', 'kin']
senticnet['relative'] = [0.771, 0.878, 0, 0, '#joyful', '#interesting', 0.55, 'family_member', 'female_sibling', 'kin', 'female_relative', 'relation']
senticnet['relative_house'] = [0, -0.069, 0, 0, '#surprising', '#surprising', 0.023, 'appliance_store', 'apartment', 'every_home', 'kitchen', 'coffee_shop']
senticnet['relative_quantity'] = [-0.56, 0, 0.711, -0.977, '#angry', '#disgusting', -0.749, 'null', 'zero', 'quantity', 'sufficiency', 'measure']
senticnet['relativity'] = [-0.69, 0, 0.83, -0.997, '#angry', '#disgusting', -0.839, 'general_relativity', 'general_theory_of_relativity', 'general_relativity_theory', 'special_relativity', 'special_theory_of_relativity']
senticnet['relax'] = [0.838, 0.744, 0, 0.874, '#joyful', '#admirable', 0.819, 'reduce_stress', 'take_easy', 'take_rest', 'stress_reduction', 'relaxation']
senticnet['relax_friend'] = [0.041, 0, 0, 0.109, '#joyful', '#admirable', 0.05, 'understand_world', 'party', 'use_party', 'hold_beer', 'good_idea']
senticnet['relax_mind'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'relaxation', 'stress_reduction', 'time_think', 'get_excited', 'make_out']
senticnet['relax_moment'] = [0.993, 0.727, 0, 0, '#joyful', '#interesting', 0.573, 'nature', 'enjoy_view', 'enjoy_nature', 'nice_walk', 'enjoy_life']
senticnet['relax_muscle'] = [0.997, 0.805, 0, 0.803, '#joyful', '#interesting', 0.868, 'relax', 'rejuvenate', 'feel_relaxed', 'become_relaxed', 'relieve_tension']
senticnet['relax_time'] = [0, 0.877, 0, 0, '#interesting', '#interesting', 0.292, 'cleaned', 'reinvigorated', 'shower', 'feel_refreshed', 'after_shower']
senticnet['relaxation'] = [0.978, -0.758, 0, 0, '#joyful', '#surprising', 0.579, 'set_mood', 'unwind', 'stress_reduction', 'distraction', 'enjoy_down_time']
senticnet['relay_information'] = [0.954, -0.767, 0, 0, '#joyful', '#surprising', 0.574, 'social_life', 'spread_knowledge', 'exchange_information', 'share_information', 'maintain_relationship']
senticnet['release'] = [0.896, 0.771, 0, 0, '#joyful', '#interesting', 0.556, 'release_energy', 'release_stress', 'release_tension', 'liberation', 'relief']
senticnet['release_energy'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'physical_activity', 'maintain_muscle_strength', 'get_fit', 'get_physical_activity', 'prove_physical_endurance']
senticnet['release_stress'] = [0.224, -0.188, 0.137, -0.133, '#joyful', '#surprising', 0.047, 'socialize_with_friend', 'get_hammered', 'funny_friend', 'meet_member_opposite_sex', 'meet_girl']
senticnet['release_tension'] = [0.194, -0.015, 0, 0, '#joyful', '#surprising', 0.07, 'make_baby', 'procreation', 'find_mate', 'feel_happy', 'get_laid']
senticnet['relegate'] = [0, 0, 0.767, -0.91, '#angry', '#disgusting', -0.559, 'submit', 'bump', 'break', 'pass_on', 'demote']
senticnet['relevance'] = [0, 0.813, 0, 0.805, '#interesting', '#admirable', 0.539, 'ocean_movement', 'ampere', 'fast_water', 'sea_movement', 'contemporary']
senticnet['relevant'] = [0, 0.798, 0, 0.772, '#interesting', '#admirable', 0.523, 'happen_now', 'electrical_unit', 'contemporary', 'up_date', 'latest']
senticnet['reliability'] = [0.948, 0.824, 0, 0.941, '#joyful', '#admirable', 0.904, 'complement', 'best_life', 'remission', 'much_need', 'run_business']
senticnet['reliable'] = [0.874, 0.914, 0, 0.838, '#joyful', '#interesting', 0.875, 'character_trait', 'good_etiquette', 'good_quality', 'well_done', 'characteristic']
senticnet['reliableness'] = [0.736, -0.616, 0, 0.926, '#joyful', '#admirable', 0.759, 'responsibleness', 'reproducibility', 'duplicability', 'solidness', 'responsibility']
senticnet['relief'] = [0.711, 0.772, 0, 0, '#joyful', '#interesting', 0.494, 'feel_relief', 'good_feeling', 'feel_ok', 'feel_relieved', 'feel_better']
senticnet['relief_pitcher'] = [-0.922, 0, 0.767, -0.85, '#sad', '#disgusting', -0.846, 'closer', 'finisher', 'pitcher', 'hurler', 'twirler']
senticnet['relieve'] = [0.615, 0.643, -0.247, 0.29, '#joyful', '#interesting', 0.434, 'allay', 'easiness', 'pacifically', 'peaceable', 'repose']
senticnet['relieve_boredom'] = [0.78, 0, 0, 0.851, '#joyful', '#admirable', 0.544, 'get_entertain', 'mindless_entertainment', 'appreciate_music', 'zone_out', 'entertainment']
senticnet['relieve_hunger'] = [0.705, 0, 0, 0.787, '#joyful', '#admirable', 0.497, 'fill_stomach', 'satisfy_hunger', 'sustenance', 'enjoy_eat', 'reduce_hunger']
senticnet['relieve_oneself'] = [0.029, 0, 0.042, -0.072, '#angry', '#disgusting', -0.028, 'fry_fish', 'make_coffee', 'make_ice', 'piss', 'clean_fish']
senticnet['relieve_pain'] = [-0.09, -0.038, 0.03, -0.289, '#sad', '#disgusting', -0.124, 'headache', 'tired_eye', 'lifestyle_change', 'eye_strain', 'move_eye']
senticnet['relieve_stress'] = [0.953, 0.989, 0, 0.955, '#interesting', '#admirable', 0.966, 'use_energy', 'social_bond', 'enjoy_outdoors', 'lower_stress', 'stress_reduction']
senticnet['relieve_tension'] = [0.773, 0, 0, 0.733, '#joyful', '#admirable', 0.502, 'relax', 'feel_relaxed', 'relax_muscle', 'sigh_relief', 'become_relaxed']
senticnet['relieved'] = [0, -0.816, 0, 0.902, '#surprising', '#admirable', 0.573, 'alleviate', 'assuage', 'palliate', 'take_over', 'exempt']
senticnet['reliever'] = [0.963, -0.847, 0, 0.947, '#joyful', '#admirable', 0.919, 'match', 'double', 'equal', 'alternate', 'stunt_man']
senticnet['religion'] = [0.979, 0.747, 0, 0.886, '#joyful', '#admirable', 0.871, 'world_religion', 'prayer', 'religious_purpose', 'gospel', 'philosophy']
senticnet['religious'] = [0.783, 0.804, 0, 0.826, '#interesting', '#admirable', 0.804, 'religious_purpose', 'spiritual', 'faith', 'religion', 'judaism']
senticnet['religious_action'] = [0.034, 0.411, -0.12, 0.399, '#interesting', '#admirable', 0.241, 'faith', 'believe', 'belief_god', 'religious', 'belief']
senticnet['religious_belief'] = [0.776, 0.796, 0, 0.942, '#interesting', '#admirable', 0.838, 'spiritual', 'faith', 'dogma', 'religious', 'christ']
senticnet['religious_book'] = [-0.06, 0, -0.057, -0.055, '#sad', '#scared', -0.057, 'book', 'court_system', 'organize_book', 'book_genre', 'book_poetry']
senticnet['religious_build'] = [0.772, 0.732, 0, 0.705, '#joyful', '#interesting', 0.736, 'holy_place', 'worship_place', 'worship_house', 'church_part', 'place_of_worship']
senticnet['religious_ceremony'] = [0.819, 0, 0, 0.918, '#joyful', '#admirable', 0.579, 'religious_service', 'church_service', 'sect', 'religious', 'catholic']
senticnet['religious_event'] = [0.75, 0.742, 0, 0.957, '#joyful', '#admirable', 0.816, 'sunday', 'happy_event', 'ceremony', 'tradition', 'rite']
senticnet['religious_experience'] = [0.571, 0.573, 0, 0.774, '#interesting', '#admirable', 0.639, 'better_world', 'make_enemy', 'find_enemy', 'disagreement', 'run_office']
senticnet['religious_fanatic'] = [0.056, 0.107, 0, 0.09, '#interesting', '#admirable', 0.084, 'mallet', 'fool', 'door_knob', 'mailman', 'court_trial']
senticnet['religious_figure'] = [0.836, 0.913, 0, 0.946, '#interesting', '#admirable', 0.898, 'religious_man', 'religious_leader', 'cleric', 'holy_man', 'religious_official']
senticnet['religious_fundamentalist'] = [-0.301, 0.083, -0.21, -0.178, '#sad', '#scared', -0.202, 'end_life', 'death', 'seek_revenge', 'kill_self', 'kill']
senticnet['religious_icon'] = [0, 0.273, 0, 0.204, '#interesting', '#admirable', 0.159, 'jesus_crucify', 'crucifix', 'religious', 'christian', 'religion']
senticnet['religious_leader'] = [0.031, 0.232, 0, 0.209, '#interesting', '#admirable', 0.157, 'cleric', 'religious_man', 'religious_official', 'church_official', 'religious_figure']
senticnet['religious_man'] = [0.036, 0.195, 0, 0.177, '#interesting', '#admirable', 0.136, 'clergyman', 'religious_leader', 'church_official', 'cleric', 'religious_figure']
senticnet['religious_official'] = [0.035, 0.257, 0, 0.234, '#interesting', '#admirable', 0.175, 'religious_leader', 'church_head', 'protestant', 'cleric', 'government_official']
senticnet['religious_person'] = [0.904, 0.761, 0, 0.762, '#joyful', '#admirable', 0.809, 'believer', 'true_believer', 'monk', 'religious_official', 'protestant']
senticnet['religious_place'] = [0.709, 0.812, 0, 0.816, '#interesting', '#admirable', 0.779, 'holy_place', 'religious_build', 'worship_place', 'place_of_worship', 'worship_house']
senticnet['religious_purpose'] = [0.08, 0.325, -0.057, 0.307, '#interesting', '#admirable', 0.218, 'religious', 'prayer', 'religion', 'judaism', 'spirituality']
senticnet['religious_ritual'] = [0.807, -0.92, 0, 0.796, '#joyful', '#surprising', 0.841, 'agape', 'confirmation', 'libation', 'rite', 'service']
senticnet['religious_service'] = [0.051, 0.291, 0, 0.322, '#interesting', '#admirable', 0.221, 'church_service', 'catholic', 'religious', 'religious_ceremony', 'holy_place']
senticnet['religious_sign'] = [0.341, 0, 0, 0.088, '#joyful', '#admirable', 0.143, 'sign', 'mark', 'symbol', 'emblem', 'stigma']
senticnet['religious_significance'] = [0.055, 0.219, -0.06, 0.15, '#interesting', '#admirable', 0.121, 'wood_structure', 'religious_icon', 'two_lines', 'counselor', 'stand']
senticnet['religious_tract'] = [0, 0.076, 0, 0.066, '#interesting', '#admirable', 0.047, 'old_testament', 'telephone_directory', 'cook_book', 'magazine', 'a_lot_of_books']
senticnet['religiousism'] = [-0.82, 0, 0.564, -0.529, '#sad', '#angry', -0.638, 'religiosity', 'religionism', 'religiousness', 'pietism', 'piety']
senticnet['religiousness'] = [-0.82, 0, 0.564, -0.529, '#sad', '#angry', -0.638, 'religiosity', 'religionism', 'religiousism', 'pietism', 'piety']
senticnet['relinquish'] = [-0.855, 0, 0.834, -0.861, '#sad', '#disgusting', -0.85, 'sacrifice', 'give', 'reach', 'hand', 'derequisition']
senticnet['relish'] = [0.969, 0.9, 0, 0.967, '#joyful', '#admirable', 0.945, 'kindly', 'large-hearted', 'openhearted', 'charitable', 'good-hearted']
senticnet['relocation'] = [-0.023, 0.119, -0.065, 0.216, '#interesting', '#admirable', 0.082, 'go_forward', 'locomotion', 'movement', 'move', 'move_ahead']
senticnet['reluctance'] = [-0.828, 0, 0.948, -0.855, '#angry', '#disgusting', -0.877, 'resistance', 'potential', 'electrical_phenomenon', 'distortion', 'capacity']
senticnet['rely'] = [-0.232, 0.325, -0.297, 0.392, '#interesting', '#admirable', 0.063, 'suggest', 'again_and_again', 'request', 'make_right', 'say_yes']
senticnet['rely_on_other_person'] = [0.72, 0, 0, 0.879, '#joyful', '#admirable', 0.533, 'friendship', 'friend', 'companion', 'adult', 'fully_developed']
senticnet['remain'] = [-0.766, 0, -0.837, 0, '#sad', '#scared', -0.534, 'hesitation', 'stay', 'rest_foot', 'pause', 'rest_leg']
senticnet['remainder'] = [0.04, 0.084, 0, 0.093, '#interesting', '#admirable', 0.072, 'inactivity', 'left_over', 'work_break', 'count_sheep', 'middle_day']
senticnet['remains'] = [-0.927, 0, 0.718, -0.984, '#sad', '#disgusting', -0.876, 'collectible', 'fossil', 'object', 'archeological_remains', 'physical_object']
senticnet['remark'] = [-0.034, 0.114, -0.098, 0.234, '#interesting', '#admirable', 0.072, 'reply', 'mention', 'comment', 'retort', 'announcement']
senticnet['remarry'] = [-0.64, 0, 0.517, -0.981, '#sad', '#disgusting', -0.713, 'marry', 'get_married', 'wed', 'conjoin', 'hook_up_with']
senticnet['remedy'] = [0.831, 0.86, 0, 0, '#joyful', '#interesting', 0.564, 'antidote', 'cure', 'therapeutic', 'curative', 'repair']
senticnet['remember'] = [0.998, 0.901, 0, 0, '#joyful', '#interesting', 0.633, 'cogitate', 'recollection', 'remember_phone_number', 'contemplate', 'mathematical_skill']
senticnet['remember_childhood'] = [0, -0.098, 0.105, -0.144, '#angry', '#disgusting', -0.05, 'make_music', 'play_song', 'create_music', 'perform_of_music', 'play_orchestra']
senticnet['remember_date'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'anniversary', 'special_occasion', 'good_memory', 'caring', 'love']
senticnet['remember_event'] = [0.706, 0.738, 0, 0, '#joyful', '#interesting', 0.481, 'think_creatively', 'brain_function', 'scratch_head', 'give_signal', 'brainstorm']
senticnet['remember_fact'] = [0.689, 0.893, 0, 0.787, '#interesting', '#admirable', 0.79, 'remember_information', 'absorb_information', 'gain_understand', 'read_out_loud', 'use_dictionary']
senticnet['remember_information'] = [0.69, -0.89, 0, 0.88, '#surprising', '#admirable', 0.82, 'remember_fact', 'review_note', 'read_book_subject', 'ask_expert', 'use_telescope']
senticnet['remember_late'] = [-0.127, -0.004, 0.052, -0.123, '#sad', '#disgusting', -0.099, 'recite', 'learn_fact', 'remember', 'become_expert', 'forget_else']
senticnet['remember_name'] = [0, 0.098, 0, 0.08, '#interesting', '#admirable', 0.059, 'talk_person', 'get_word_out', 'talk_another_person', 'diplomacy', 'greet_person']
senticnet['remember_oneself'] = [0.759, -0.767, 0, 0.878, '#surprising', '#admirable', 0.801, 'comport', 'move', 'walk', 'assert_oneself', 'act']
senticnet['remember_past'] = [0.717, 0.939, 0, 0, '#joyful', '#interesting', 0.552, 'remember', 'contemplation', 'commemorate_event', 'use_memory', 'honor_person']
senticnet['remember_phone_number'] = [-0.061, 0.145, 0.03, 0.062, '#interesting', '#admirable', 0.039, 'cogitate', 'remember', 'contemplate', 'use_memory', 'system_abstract_think']
senticnet['remind'] = [0.111, 0.187, -0.099, 0.161, '#interesting', '#admirable', 0.12, 'express_opinion', 'nod_head', 'new_information', 'provide_information', 'sincere']
senticnet['remind_of'] = [0, 0.136, 0, 0.199, '#interesting', '#admirable', 0.112, 'recall', 'remember', 'game_part', 'sound_like', 'push_together']
senticnet['reminder'] = [-0.028, 0.096, 0, 0.114, '#interesting', '#admirable', 0.061, 'musical_symbol', 'music_part', 'musical_notation', 'written_message', 'rhyme']
senticnet['remission'] = [0.392, 0.196, 0, 0.345, '#joyful', '#admirable', 0.311, 'complement', 'much_need', 'taken_seriously', 'good_sense_of_humor', 'knowledgeable']
senticnet['remissness'] = [-0.936, 0, 0.624, -0.599, '#sad', '#angry', -0.72, 'carelessness', 'willful_neglect', 'laxness', 'laxity', 'neglectfulness']
senticnet['remittal'] = [-0.883, 0, 0.727, -0.821, '#sad', '#disgusting', -0.81, 'defervescence', 'subsidence', 'break', 'remission', 'abatement']
senticnet['remittance'] = [-0.054, 0.267, -0.123, 0.154, '#interesting', '#admirable', 0.081, 'wage', 'money_due', 'owe', 'payment', 'account_term']
senticnet['remittent'] = [-0.978, 0, 0.584, -0.789, '#sad', '#disgusting', -0.784, 'decreased', 'diminished', 'weakened', 'faded', 'small']
senticnet['remorse'] = [-1, 0, 0, -1, '#sad', '#disgusting', -0.667, 'sorrow', 'guilt', 'guilty_conscience', 'grief', 'heartache']
senticnet['remorseful'] = [-0.884, 0.178, -0.6, 0, '#sad', '#scared', -0.435, 'contrite', 'rueful', 'ruthful', 'bereaved', 'sorrowing']
senticnet['remorsefully'] = [-0.891, 0.168, -0.609, 0.05, '#sad', '#scared', -0.427, 'contritely', 'contrition', 'contriteness', 'ruefully', 'attrition']
senticnet['remote'] = [-0.051, 0.169, -0.119, 0.157, '#interesting', '#admirable', 0.052, 'control', 'take_charge', 'strict', 'power', 'command']
senticnet['remote_control'] = [0.97, 0.797, 0, 0, '#joyful', '#interesting', 0.589, 'chatter_tooth', 'air_pump', 'safety_pin', 'slinky', 'typewriter_ribbon']
senticnet['removal'] = [0, 0, 0.776, -0.716, '#angry', '#disgusting', -0.497, 'dismissal', 'discharge', 'elimination', 'destitution', 'forced_removal']
senticnet['remove'] = [-0.77, 0.277, -0.449, -0.051, '#sad', '#scared', -0.331, 'delete', 'abolish', 'discharge', 'clear_away', 'cut_out']
senticnet['remove_cloth'] = [0.714, -0.583, 0, 0.667, '#joyful', '#admirable', 0.655, 'take_clothes_off', 'fill_bathtub_water', 'turn_water', 'take_off_clotheses', 'take_off_clothes']
senticnet['remove_clothes'] = [-0.076, 0, -0.047, -0.03, '#sad', '#scared', -0.051, 'take_off_clothes', 'take_clothes_off', 'undress', 'use_shower', 'naked']
senticnet['remove_control'] = [0, 0, -0.049, -0.066, '#scared', '#disgusting', -0.038, 'soud_system', 'television_set', 'tv_set', 'christian_fundamentalist', 'stair_down']
senticnet['remove_dirt'] = [0.024, 0, 0, 0.068, '#joyful', '#admirable', 0.031, 'clean_skin', 'clothes_clean', 'keep_clean', 'run_out_soap', 'cleanse_body']
senticnet['remove_dirt_body'] = [0.075, 0, 0, 0, '#joyful', '#joyful', 0.025, 'personal_hygiene', 'ensure_proper_hygiene', 'smell_clean', 'feel_clean', 'clean_body']
senticnet['remove_hair'] = [0, 0.999, 0, 0.745, '#interesting', '#admirable', 0.581, 'bee_product', 'flammable', 'gooey', 'slick', 'really_hot']
senticnet['remove_heat'] = [0.196, 0.077, 0, 0.064, '#joyful', '#interesting', 0.112, 'lower_temperature', 'reduce_temperature', 'temporary_shelter', 'entertain_company', 'get_meal']
senticnet['remove_paint'] = [-0.045, -0.03, 0.069, 0, '#sad', '#angry', -0.028, 'make_pretty', 'paint_nail', 'steal_paint', 'dust_furniture', 'vacuum_floor']
senticnet['remove_plaque'] = [-0.051, -0.017, 0.012, -0.04, '#sad', '#disgusting', -0.029, 'clean_between_tooth', 'keep_tooth_clean', 'close_mouth', 'chew', 'suck']
senticnet['remove_screw'] = [0, 0, 0, 0.882, '#admirable', '#admirable', 0.294, 'put_screw', 'oil', 'screwdriver', 'lubricant', 'fuel']
senticnet['remove_shoes'] = [0.725, 0.964, 0, 0, '#joyful', '#interesting', 0.563, 'disrobe', 'fill_bathtub', 'take_off_shoes', 'run_bath', 'take_off_clothes']
senticnet['remove_skin'] = [0, -0.133, 0, 0, '#surprising', '#surprising', 0.044, 'stir_pot', 'burn_food', 'peel_potato', 'prepare_ingredient', 'chop_vegetable']
senticnet['remove_splinter'] = [-0.088, 0, -0.084, 0, '#sad', '#scared', -0.057, 'age_well', 'feel_heat', 'crowd_elevator', 'close_together', 'smell_odor']
senticnet['remove_spot'] = [0.73, 0, 0, 0, '#joyful', '#joyful', 0.243, 'kill_spider', 'tidiness', 'house_look_better', 'house', 'free_sex']
senticnet['remove_stain'] = [0, 0.076, -0.059, 0.082, '#interesting', '#admirable', 0.033, 'smell_better', 'feel_fresh', 'clothes_clean', 'smell_nice', 'remove_dirt']
senticnet['remove_tooth'] = [0, 0, -0.08, -0.154, '#scared', '#disgusting', -0.078, 'dental_office', 'dentist', 'fear', 'dentist_office', 'pain']
senticnet['remuneration'] = [-0.683, 0, 0.688, -0.877, '#angry', '#disgusting', -0.749, 'pay', 'wage', 'earnings', 'living_wage', 'salary']
senticnet['renal_disorder'] = [0.804, -0.544, 0, 0.674, '#joyful', '#admirable', 0.674, 'uropathy', 'polyuria', 'polycystic_kidney_disease', 'renal_failure', 'kidney_failure']
senticnet['renal_failure'] = [-0.524, 0, 0.729, -0.895, '#angry', '#disgusting', -0.716, 'acute_renal_failure', 'acute_kidney_failure', 'chronic_renal_failure', 'chronic_kidney_failure', 'nephrosis']
senticnet['rend'] = [-0.285, 0, -0.238, -0.126, '#sad', '#scared', -0.216, 'tax', 'payment', 'owe', 'bribe', 'divorce_money']
senticnet['rend_movie'] = [0.071, 0.111, 0, 0.078, '#interesting', '#admirable', 0.087, 'make_popcorn', 'rend_video', 'wear_glass', 'watch_good_movie', 'able_see']
senticnet['rend_video'] = [0.071, 0.111, 0, 0.078, '#interesting', '#admirable', 0.087, 'make_popcorn', 'able_see', 'wear_glass', 'watch_good_movie', 'rend_movie']
senticnet['rendezvous'] = [0.049, 0.078, 0, 0.051, '#interesting', '#admirable', 0.059, 'work_in_garden', 'sweatshop', 'workplace', 'courier', 'hold_up_office']
senticnet['renege_on'] = [0.885, -0.661, 0, 0.879, '#joyful', '#admirable', 0.808, 'reverse', 'lift', 'overturn', 'vacate', 'annul']
senticnet['renegue_on'] = [0.81, -0.662, 0, 0.657, '#joyful', '#surprising', 0.71, 'reverse', 'lift', 'overturn', 'vacate', 'annul']
senticnet['renew'] = [0.857, -0.688, 0, 0.971, '#joyful', '#admirable', 0.839, 'revitalize', 'refurbish', 'reconstruct', 'renovate', 'freshen_up']
senticnet['renew_energy'] = [0.884, 0, 0, 0, '#joyful', '#joyful', 0.295, 'feel_better', 'lower_blood_pressure', 'feel_energized', 'feel_refreshed', 'feel_energetic']
senticnet['renewable_resource'] = [0.032, 0, 0, 0.078, '#joyful', '#admirable', 0.037, 'large_plant', 'tall_person', 'tree_piece', 'small_tree', 'part_of_tree']
senticnet['renounce'] = [-0.962, 0, 0.885, -0.75, '#sad', '#angry', -0.866, 'controvert', 'answer', 'disown', 'rebut', 'repudiate']
senticnet['rent'] = [0, 0, -0.78, -0.876, '#scared', '#disgusting', -0.552, 'split', 'rip', 'lease', 'snag', 'tear']
senticnet['rent_apartment'] = [0.913, 0.984, 0, 0, '#joyful', '#interesting', 0.632, 'brownstone', 'condominium', 'high_rise', 'condo', 'row_house']
senticnet['rent_house'] = [0.036, 0.138, 0.058, 0.223, '#interesting', '#admirable', 0.113, 'home_sweet_home', 'house', 'rent_room', 'live_apartment', 'need_companionship']
senticnet['rent_out'] = [-0.059, 0.116, -0.044, 0.102, '#interesting', '#admirable', 0.038, 'house', 'dwelling', 'multi-story_build', 'lease', 'large_house']
senticnet['rent_room'] = [0.036, 0.138, 0.058, 0.223, '#interesting', '#admirable', 0.113, 'home_sweet_home', 'house', 'live_apartment', 'rent_house', 'need_companionship']
senticnet['rentless'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'lack_of_judgment', 'lack_of_discreetness', 'lack_of_discernment', 'reckless', 'injudiciousness']
senticnet['reordering'] = [0.898, -0.874, 0, 0.929, '#joyful', '#admirable', 0.9, 'make', 'transposition', 'reversal', 'passing', 'permutation']
senticnet['reorganized'] = [-0.906, 0, 0.533, -0.934, '#sad', '#disgusting', -0.791, 'incorporated', 'arranged', 'configured', 'corporate', 'organized']
senticnet['repair_car'] = [0, 0.71, 0, 0.799, '#interesting', '#admirable', 0.503, 'car_workshop', 'repair_shop', 'workshop', 'repair_motorcycle', 'check_up_car']
senticnet['repair_motorcycle'] = [0, 0.71, 0, 0.799, '#interesting', '#admirable', 0.503, 'repair_car', 'repair_shop', 'workshop', 'car_workshop', 'check_up_car']
senticnet['repair_shop'] = [0.916, 0.736, 0, 0, '#joyful', '#interesting', 0.551, 'garage', 'garbage_dump', 'bicycle_shop', 'tool', 'fix_panel']
senticnet['repair_umbrella'] = [0, -0.011, 0.078, -0.039, '#angry', '#disgusting', -0.035, 'fix_computer', 'write_program', 'program_computer', 'design_software', 'compute_sum']
senticnet['repartee'] = [-0.853, 0, 0.855, -0.878, '#angry', '#disgusting', -0.862, 'banter', 'raillery', 'backchat', 'wit', 'humor']
senticnet['repay'] = [0, 0.972, 0, 0.836, '#interesting', '#admirable', 0.603, 'payback', 'money', 'money_owe', 'money_pay', 'money_due']
senticnet['repeat'] = [-0.1, 0.242, -0.13, 0.196, '#interesting', '#admirable', 0.069, 'go_over', 'realize', 'deduce', 'become_aware', 'cognition']
senticnet['repeat_action'] = [0, 0.918, 0, 0.798, '#interesting', '#admirable', 0.572, 'turn_away', 'shine_light', 'spring_up', 'repeat', 'like_boy']
senticnet['repeater'] = [0.756, -0.832, 0, 0.995, '#surprising', '#admirable', 0.861, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['repel'] = [-0.07, 0.133, 0.697, -0.672, '#angry', '#disgusting', -0.435, 'sicken', 'nauseate', 'gross_out', 'churn_up', 'loathsome']
senticnet['repellant'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['repellent'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['repelling'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['repent'] = [-0.848, 0, 0, -0.78, '#sad', '#disgusting', -0.543, 'penitence', 'penitent', 'penitently', 'repentantly', 'penitentially']
senticnet['repentance'] = [-0.995, 0, 0, -0.959, '#sad', '#disgusting', -0.651, 'repent', 'penitentially', 'repentant', 'penitent', 'sorrow']
senticnet['repentant'] = [-0.909, 0.142, -0.637, 0.07, '#sad', '#scared', -0.445, 'penitently', 'penitentially', 'penitent', 'repentantly', 'penitence']
senticnet['repentantly'] = [-0.909, 0.142, -0.637, 0.07, '#sad', '#scared', -0.445, 'penitently', 'penitentially', 'penitent', 'penitence', 'repentant']
senticnet['repetition'] = [-0.909, 0.142, -0.637, 0.07, '#sad', '#scared', -0.445, 'repetitive', 'repetitive_action', 'repetitive_task', 'repeat', 'monotony']
senticnet['repetitiousness'] = [-0.565, 0, 0.617, -0.804, '#angry', '#disgusting', -0.662, 'prolixity', 'prolixness', 'wordiness', 'repetitiveness', 'verboseness']
senticnet['repetitive'] = [-0.909, 0.142, -0.637, 0.07, '#sad', '#scared', -0.445, 'do_again', 'repetitive_action', 'repetitive_task', 'repeat', 'repetition']
senticnet['repetitive_action'] = [-0.909, 0.142, -0.637, 0.07, '#sad', '#scared', -0.445, 'repetition', 'repetitive', 'repetitive_task', 'repeat', 'monotony']
senticnet['repetitive_task'] = [-0.281, 0, -0.112, -0.153, '#sad', '#disgusting', -0.182, 'monotony', 'run_long_time', 'unpleasantness', 'repetition', 'hardship']
senticnet['repetitiveness'] = [-0.565, 0, 0.617, -0.804, '#angry', '#disgusting', -0.662, 'prolixity', 'prolixness', 'wordiness', 'verboseness', 'repetitiousness']
senticnet['replace'] = [0, 0.786, 0, 0.719, '#interesting', '#admirable', 0.502, 'line_place', 'placement', 'stance', 'place', 'position']
senticnet['replacement'] = [0, 0.124, 0, 0.055, '#interesting', '#admirable', 0.06, 'part', 'replace', 'put_back', 'extent', 'order']
senticnet['replay'] = [-0.094, 0.147, -0.112, 0.205, '#interesting', '#admirable', 0.049, 'question_starter', 'resolution', 'available', 'explanation', 'request']
senticnet['replenish_energy'] = [0.81, 0.959, 0, 0, '#joyful', '#interesting', 0.59, 'munch', 'satisfy_appetite', 'nourishment', 'able_eat', 'sustenance']
senticnet['replete'] = [-0.803, 0, 0.542, -0.941, '#sad', '#disgusting', -0.762, 'pall', 'take_in', 'take', 'ingest', 'have']
senticnet['replicate'] = [-0.024, 0.167, -0.061, 0.217, '#interesting', '#admirable', 0.1, 'clone', 'imitation', 'make_copy', 'source', 'duplicate']
senticnet['reply'] = [0.764, 0.714, 0, 0, '#joyful', '#interesting', 0.493, 'remark', 'answer', 'question', 'question_answering', 'get_response']
senticnet['reply_question'] = [-0.119, 0.075, -0.085, 0, '#sad', '#scared', -0.043, 'desire_help', 'forget_name', 'voice_opinion', 'lower_expectation', 'receive_email']
senticnet['report'] = [0, 0, 0.704, -0.77, '#angry', '#disgusting', -0.491, 'explanation', 'check', 'record', 'recital', 'disquisition']
senticnet['report_crime'] = [-0.135, -0.013, 0, -0.08, '#sad', '#disgusting', -0.067, 'complete_sentence', 'point_out', 'state_fact', 'borrow_book_from_library', 'page_through_book']
senticnet['report_event'] = [0, 0.796, 0, 0.75, '#interesting', '#admirable', 0.515, 'review_book', 'spread_news', 'pass_information', 'report_news', 'pass_knowledge']
senticnet['report_news'] = [0, -0.837, 0, 0.768, '#surprising', '#admirable', 0.535, 'seek_answer', 'analyze', 'know_world', 'educate_oneself', 'read_out_loud']
senticnet['reporter'] = [0.904, 0.941, 0, 0, '#joyful', '#interesting', 0.615, 'architect', 'public_servant', 'manager', 'hero', 'construction_worker']
senticnet['repose'] = [0.621, 0.648, -0.252, 0.296, '#joyful', '#interesting', 0.438, 'pacifically', 'peace-loving', 'peaceably', 'peaceable', 'peace_of_mind']
senticnet['repose_on'] = [-0.955, 0, 0.51, -0.962, '#sad', '#disgusting', -0.809, 'ride', 'owe', 'depend_on', 'depend_upon', 'turn_on']
senticnet['reprehension'] = [-0.66, 0, 0.722, -0.546, '#sad', '#angry', -0.643, 'bawling_out', 'chewing_out', 'upbraiding', 'dressing_down', 'berating']
senticnet['represent'] = [0, 0.128, -0.117, 0.228, '#interesting', '#admirable', 0.08, 'portray', 'heap', 'appear', 'juggler', 'charade']
senticnet['represent_idea'] = [0.827, 0, 0, 0, '#joyful', '#joyful', 0.276, 'convey_message', 'communicate_thought', 'like_write', 'record_history', 'store_knowledge']
senticnet['representation'] = [0, 0.157, 0, 0.147, '#interesting', '#admirable', 0.101, 'wall_hang', 'like_paint', 'illustration', 'artwork', 'wall_decoration']
senticnet['representative'] = [0.845, 0.91, 0, 0, '#joyful', '#interesting', 0.585, 'government', 'president', 'rogue', 'politician', 'ambassador']
senticnet['representative_sampling'] = [0.956, -0.839, 0, 0.755, '#joyful', '#surprising', 0.85, 'choice', 'option', 'random_sampling', 'stratified_sampling', 'sampling']
senticnet['represented'] = [0.824, -0.885, 0, 0.622, '#joyful', '#surprising', 0.777, 'depicted', 'pictured', 'portrayed', 'described', 'diagrammatic']
senticnet['repress'] = [-0.501, 0, 0.936, -0.951, '#angry', '#disgusting', -0.796, 'quash', 'keep_down', 'reduce', 'oppress', 'subdue']
senticnet['reprieve'] = [-0.539, 0, 0.608, -0.935, '#angry', '#disgusting', -0.694, 'defervescence', 'respite', 'hiatus', 'abatement', 'suspension']
senticnet['reprimand'] = [-0.504, -0.029, -0.289, -0.104, '#sad', '#scared', -0.289, 'unsafe', 'feel_stressed', 'stress', 'wrongdoing', 'screw_up']
senticnet['reprisal'] = [-0.888, 0, 0.733, -0.605, '#sad', '#angry', -0.742, 'vengeance', 'payback', 'retribution', 'retaliation', 'return']
senticnet['reproach'] = [-0.69, 0, 0.585, -0.812, '#sad', '#disgusting', -0.696, 'blame', 'rap', 'reprimand', 'rebuke', 'reproof']
senticnet['reproachful'] = [-0.74, 0, 0.982, -0.819, '#angry', '#disgusting', -0.847, 'inauspicious', 'admonishing', 'unfavorable', 'reproving', 'untoward']
senticnet['reprobate'] = [-0.759, 0, 0.985, -0.751, '#sad', '#angry', -0.832, 'scapegrace', 'black_sheep', 'degenerate', 'wretch', 'pervert']
senticnet['reproduce'] = [0.039, 0.109, -0.074, 0.147, '#interesting', '#admirable', 0.074, 'procreate', 'cause_cold', 'copulate', 'start_family', 'give_birth_child']
senticnet['reproof'] = [-0.886, 0, 0.822, -0.522, '#sad', '#angry', -0.743, 'bawling_out', 'chewing_out', 'upbraiding', 'dressing_down', 'berating']
senticnet['reproval'] = [-0.599, 0, 0.741, -0.589, '#sad', '#angry', -0.643, 'bawling_out', 'chewing_out', 'upbraiding', 'dressing_down', 'berating']
senticnet['reproving'] = [-0.74, 0, 0.982, -0.819, '#angry', '#disgusting', -0.847, 'inauspicious', 'admonishing', 'reproachful', 'unfavorable', 'untoward']
senticnet['reptile'] = [0, 0, -0.071, 0, '#scared', '#scared', -0.024, 'alligator', 'animal', 'predator', 'meat_eater', 'river']
senticnet['republican'] = [0, 0.988, 0, 0.938, '#interesting', '#admirable', 0.642, 'settle_disagreement', 'hitler', 'communist', 'conservative', 'kill_another_person']
senticnet['repudiate'] = [-0.97, 0, 0.616, -0.589, '#sad', '#angry', -0.725, 'abjure', 'recant', 'forswear', 'deny', 'reject']
senticnet['repugnance'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repulsive', 'repugnant', 'detestably', 'abominably', 'odiously']
senticnet['repugnant'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repulsive', 'detestably', 'abominably', 'odiously', 'detestable']
senticnet['repulse'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repulsive', 'repugnant', 'detestably', 'abominably', 'odiously']
senticnet['repulsion'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repulsive', 'repugnant', 'detestably', 'abominably', 'odiously']
senticnet['repulsive'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repugnant', 'detestably', 'abominably', 'odiously', 'detestable']
senticnet['repulsively'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repulsive', 'repugnant', 'detestably', 'abominably', 'odiously']
senticnet['reputable'] = [0.991, -0.989, 0, 0.588, '#joyful', '#surprising', 0.856, 'estimable', 'respected', 'esteemed', 'honored', 'prestigious']
senticnet['reputation'] = [0.728, 0.977, 0, 0.939, '#interesting', '#admirable', 0.881, 'toxic_metal', 'metallic_element', 'dense_air', 'heavy_metal', 'soft_metal']
senticnet['repute'] = [0.852, -0.753, 0, 0.763, '#joyful', '#admirable', 0.789, 'honor', 'laurels', 'fame', 'stock', 'character']
senticnet['request'] = [0, 0.734, 0, 0, '#interesting', '#interesting', 0.245, 'ask', 'suggest', 'proclamation', 'question_starter', 'tell_why']
senticnet['require'] = [0, 0.966, 0, 0.742, '#interesting', '#admirable', 0.569, 'needful', 'necessary', 'compel', 'requirement', 'strong_desire']
senticnet['require_electricity'] = [0.066, 0, 0.049, 0.086, '#joyful', '#admirable', 0.034, 'go_stage', 'perform', 'eye_up_down', 'act_play', 'hear_crowd_go_mad']
senticnet['require_good_health'] = [0.91, 0.973, 0, 0, '#joyful', '#interesting', 0.628, 'harvest_fall', 'mall', 'find_mall', 'eaten', 'grown_soil']
senticnet['require_signature'] = [0, 0.181, 0, 0.055, '#interesting', '#admirable', 0.079, 'keep_money', 'put_money', 'money_holder', 'store_money', 'sign_contract']
senticnet['required'] = [0, 0, 0.813, -0.789, '#angry', '#disgusting', -0.534, 'postulate', 'necessitate', 'take', 'ask', 'need']
senticnet['requirement'] = [0.756, 0.787, 0, 0, '#joyful', '#interesting', 0.514, 'must', 'necessary', 'needful', 'need', 'demand']
senticnet['requisite'] = [-0.995, 0, 0.712, -0.853, '#sad', '#disgusting', -0.853, 'need', 'want', 'must', 'desideratum', 'thing']
senticnet['rescind'] = [0, 0, -0.734, -0.887, '#scared', '#disgusting', -0.54, 'lift', 'countermand', 'revoke', 'reverse', 'annul']
senticnet['rescue'] = [0, 0, 0, 0.912, '#admirable', '#admirable', 0.304, 'defend', 'steal', 'steal_money', 'protect', 'fight_disease']
senticnet['research'] = [0.887, 0.877, 0, 0, '#joyful', '#interesting', 0.588, 'ask_expert', 'absorb_information', 'analyze', 'learn_computer', 'search_information']
senticnet['research_subject'] = [-0.158, -0.081, -0.065, -0.087, '#sad', '#disgusting', -0.076, 'ask_question', 'think_logically', 'investigate_fact', 'become_enlighten', 'ask_many_questions']
senticnet['research_topic'] = [0, 0.944, 0, 0.976, '#interesting', '#admirable', 0.64, 'research', 'topic', 'select_topic', 'research_subject', 'researcher']
senticnet['research_worker'] = [0.719, -0.723, 0, 0.738, '#surprising', '#admirable', 0.727, 'experimenter', 'boffin', 'fieldworker', 'postdoc', 'post_doc']
senticnet['researcher'] = [0, 0.886, 0, 0.944, '#interesting', '#admirable', 0.61, 'research', 'research_topic', 'research_subject', 'search', 'student']
senticnet['resemblance'] = [-0.886, 0, 0.813, -0.578, '#sad', '#angry', -0.759, 'affinity', 'mutual_resemblance', 'alikeness', 'likeness', 'similitude']
senticnet['resentful'] = [0.034, 0.126, 0.758, -0.673, '#angry', '#disgusting', -0.424, 'resentfully', 'gall', 'rancor', 'take_revenge', 'warpath']
senticnet['resentfully'] = [0.034, 0.126, 0.758, -0.673, '#angry', '#disgusting', -0.424, 'gall', 'seek_revenge', 'rancor', 'resentful', 'warpath']
senticnet['resentment'] = [0, 0.128, 0.658, -0.681, '#angry', '#disgusting', -0.404, 'jealousy', 'grudge', 'animosity', 'envy', 'mad']
senticnet['reservation'] = [0, 0.084, 0, 0, '#interesting', '#interesting', 0.028, 'book_hotel', 'call_restaurant', 'reserve', 'reserve_table', 'reserved']
senticnet['reserve'] = [0.049, 0.277, -0.152, 0.168, '#interesting', '#admirable', 0.114, 'protect', 'robbery', 'keep', 'steal_money', 'prevent']
senticnet['reserve_table'] = [0.519, -0.991, 0, 0.741, '#surprising', '#admirable', 0.75, 'earmark', 'appropriate', 'set_aside', 'reserve', 'allot']
senticnet['reserves'] = [-0.993, 0, 0.949, -0.89, '#sad', '#angry', -0.944, 'force', 'trainband', 'military_unit', 'military_force', 'military_group']
senticnet['reshape'] = [0.7, -0.796, 0, 0.66, '#joyful', '#surprising', 0.719, 'influence', 'determine', 'shape', 'mold', 'regulate']
senticnet['reside'] = [0.071, 0.115, -0.088, 0.167, '#interesting', '#admirable', 0.088, 'live_inside', 'protection_element', 'live_life', 'protection_weather', 'raise_family']
senticnet['residence'] = [0.038, 0.098, 0, 0.154, '#interesting', '#admirable', 0.097, 'live_place', 'live_area', 'domicile', 'dwell_place', 'domestic_dwell']
senticnet['resident'] = [0, 0.973, 0, 0.945, '#interesting', '#admirable', 0.639, 'tenant', 'ceiling_fan', 'citizien', 'stair_rail', 'roommate']
senticnet['residue'] = [0.059, -0.022, 0, 0, '#joyful', '#surprising', 0.027, 'rest', 'want_sleep', 'sleep_night', 'take_break', 'use_chair']
senticnet['resign'] = [-0.995, 0, 0.834, 0, '#sad', '#angry', -0.61, 'resignedly', 'abject', 'unhopeful', 'abjectly', 'resignation']
senticnet['resignation'] = [-0.79, 0, 0.849, 0, '#sad', '#angry', -0.546, 'resignedly', 'abject', 'unhopeful', 'abjectly', 'reconcile']
senticnet['resignedly'] = [-0.874, 0, 0.863, 0, '#sad', '#angry', -0.579, 'abject', 'unhopeful', 'abjectly', 'resignation', 'reconcile']
senticnet['resilience'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'elasticity', 'flexibility', 'elastic', 'suppleness', 'spring']
senticnet['resistance'] = [-0.973, 0, -0.787, 0, '#sad', '#scared', -0.587, 'quarrel', 'dispute', 'fight', 'siege', 'violence']
senticnet['resistant'] = [-0.698, 0, 0.516, -0.941, '#sad', '#disgusting', -0.718, 'insubordinate', 'recalcitrant', 'obstreperous', 'defiant', 'resistive']
senticnet['resister'] = [-0.973, 0, 0.62, -0.727, '#sad', '#disgusting', -0.773, 'obstructor', 'obstructer', 'technophobe', 'obstructionist', 'naysayer']
senticnet['resistive'] = [-0.698, 0, 0.516, -0.941, '#sad', '#disgusting', -0.718, 'insubordinate', 'recalcitrant', 'obstreperous', 'resistant', 'defiant']
senticnet['resole'] = [0.739, -0.538, 0, 0.716, '#joyful', '#admirable', 0.664, 'repair', 'mend', 'bushel', 'doctor', 'furbish_up']
senticnet['resolute'] = [0.518, -0.863, 0, 0.501, '#joyful', '#surprising', 0.627, 'undismayed', 'unshaken', 'undaunted', 'firm', 'stout']
senticnet['resoluteness'] = [0.906, -0.958, 0, 0.969, '#surprising', '#admirable', 0.944, 'willpower', 'will_power', 'decisiveness', 'trait', 'steadiness']
senticnet['resolution'] = [-0.032, 0.247, -0.193, 0.238, '#interesting', '#admirable', 0.087, 'make_up_mind', 'question_starter', 'decision', 'replay', 'suggestion']
senticnet['resolve'] = [-0.032, 0.247, -0.193, 0.238, '#interesting', '#admirable', 0.087, 'resolution', 'resolve_conflict', 'resolve_dispute', 'decide_case', 'examine_evidence']
senticnet['resolve_case'] = [0, 0.923, 0, 0, '#interesting', '#interesting', 0.308, 'resolve_conflict', 'consider_evidence', 'decide_guilt', 'examine_evidence', 'judgment']
senticnet['resolve_conflict'] = [0, 0.144, 0, 0, '#interesting', '#interesting', 0.048, 'serve_jury', 'consider_evidence', 'examine_evidence', 'decide_case', 'decide_guilt']
senticnet['resolve_dispute'] = [0.533, 0.818, 0, 0.683, '#interesting', '#admirable', 0.678, 'gain_information', 'report_news', 'educate_oneself', 'seek_answer', 'gather_information']
senticnet['resolve_problem'] = [0.761, 0.728, 0, 0, '#joyful', '#interesting', 0.496, 'arrive_conclusion', 'figure_out', 'come_conclusion', 'study_fact', 'come_up_idea']
senticnet['resolvent'] = [0.57, -0.84, 0, 0.721, '#surprising', '#admirable', 0.71, 'medium', 'acetone', 'propanone', 'dimethyl_ketone', 'chlorobenzene']
senticnet['resonant'] = [-0.726, 0, -0.897, 0, '#sad', '#scared', -0.541, 'reverberative', 'reverberating', 'resounding', 'resonating', 'evocative']
senticnet['respect'] = [0.324, 0.461, -0.347, 0.442, '#interesting', '#admirable', 0.293, 'obedience', 'regard', 'valor', 'affection', 'honor']
senticnet['respect_authority'] = [0.909, 0.974, 0, 0, '#joyful', '#interesting', 0.628, 'go_to_work', 'respect', 'gain_respect', 'respect_law', 'put_uniform']
senticnet['respect_law'] = [0.741, 0.928, 0, 0, '#joyful', '#interesting', 0.556, 'go_to_work', 'respect', 'gain_respect', 'put_uniform', 'respect_authority']
senticnet['respect_nature'] = [0.107, 0.098, 0, 0.135, '#joyful', '#admirable', 0.113, 'go_green', 'reduce_pollution', 'save_water', 'go_on_foot', 'spread_seed']
senticnet['respectable'] = [0.666, -0.831, 0, 0.896, '#surprising', '#admirable', 0.798, 'nice', 'decent', 'solid', 'presentable', 'upstanding']
senticnet['respiration'] = [0, 0.939, 0, 0.755, '#interesting', '#admirable', 0.565, 'exhale', 'cough', 'breathe', 'involuntary', 'smell_odor']
senticnet['respiratory_disease'] = [-0.788, 0, 0.993, -0.654, '#sad', '#angry', -0.812, 'bronchiolitis', 'chronic_bronchitis', 'bronchitis', 'respiratory_illness', 'respiratory_disorder']
senticnet['respiratory_disorder'] = [-0.788, 0, 0.993, -0.654, '#sad', '#angry', -0.812, 'bronchiolitis', 'chronic_bronchitis', 'respiratory_disease', 'respiratory_illness', 'bronchitis']
senticnet['respiratory_illness'] = [-0.788, 0, 0.993, -0.654, '#sad', '#angry', -0.812, 'bronchiolitis', 'chronic_bronchitis', 'respiratory_disease', 'bronchitis', 'respiratory_disorder']
senticnet['respond'] = [0.997, 0.77, 0, 0, '#joyful', '#interesting', 0.589, 'response', 'interrogation', 'yes_no', 'answer_back', 'inquire']
senticnet['response'] = [0, 0.708, 0, 0.89, '#interesting', '#admirable', 0.533, 'answer_back', 'interrogation', 'respond', 'write_back', 'retort']
senticnet['responsibility'] = [0, 0.772, 0, 0.883, '#interesting', '#admirable', 0.552, 'animal_person', 'mandatory', 'must', 'obligation', 'requirement']
senticnet['responsible'] = [0.955, 0.945, 0, 0.835, '#joyful', '#interesting', 0.912, 'support_family', 'provide_service', 'accomplish', 'find_job', 'pay_well']
senticnet['responsibleness'] = [0.881, -0.51, 0, 0.76, '#joyful', '#admirable', 0.717, 'trustworthiness', 'trustiness', 'dependability', 'dependableness', 'reliability']
senticnet['responsiveness'] = [0.92, -0.701, 0, 0.674, '#joyful', '#surprising', 0.765, 'sensitivity', 'sensitiveness', 'irritability', 'sensibility', 'excitability']
senticnet['rest'] = [0.064, -0.058, 0.02, 0, '#joyful', '#surprising', 0.034, 'sleep_night', 'want_sleep', 'go_sleep', 'use_chair', 'take_break']
senticnet['rest_area'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'sport_stadium', 'hotel', 'service_station', 'chill_out', 'motel_room']
senticnet['rest_dream'] = [0.1, 0.104, 0, 0, '#joyful', '#interesting', 0.068, 'sleep_time', 'rest_night', 'closing_time', 'shut_eye', 'inactivity']
senticnet['rest_foot'] = [0.064, -0.058, 0.02, 0, '#joyful', '#surprising', 0.034, 'rest_leg', 'rest_area', 'take_break', 'rest_place', 'rest']
senticnet['rest_leg'] = [0.064, -0.058, 0.02, 0, '#joyful', '#surprising', 0.034, 'rest_foot', 'rest_area', 'take_break', 'rest_place', 'rest']
senticnet['rest_night'] = [0.051, 0.072, 0, 0.062, '#interesting', '#admirable', 0.062, 'count_sheep', 'shut_eye', 'doze', 'inactivity', 'lay_down']
senticnet['rest_of_group'] = [0.099, 0.248, -0.079, 0.282, '#interesting', '#admirable', 0.183, 'others', 'other_people', 'precise', 'significant', 'description']
senticnet['rest_period'] = [0.961, -0.849, 0, 0.958, '#joyful', '#admirable', 0.923, 'pause', 'break', 'intermission', 'suspension', 'breathing_space']
senticnet['rest_place'] = [0, 0.074, 0, 0.107, '#interesting', '#admirable', 0.06, 'sleep_area', 'sleep_place', 'comfy', 'horizontal_surface', 'restful']
senticnet['rest_relaxation'] = [0.135, 0.073, 0, 0, '#joyful', '#interesting', 0.069, 'warm_down', 'sex_with_stranger', 'go_bed', 'go_sleep', 'stay_overnight']
senticnet['rest_room'] = [0.977, 0.987, 0, 0, '#joyful', '#interesting', 0.655, 'cocktail_cabinet', 'stool', 'chair', 'coffee_table', 'bar_stool']
senticnet['rest_time'] = [-0.182, 0, -0.104, 0, '#sad', '#scared', -0.095, 'tear_apart', 'time_out', 'painful_injury', 'break_apart', 'apart']
senticnet['rest_tire'] = [0.125, 0.097, 0, 0.152, '#joyful', '#admirable', 0.125, 'good_shape', 'after_exercise', 'elongate', 'plenty_rest', 'physical_condition']
senticnet['rest_up'] = [0, -0.052, 0.027, 0.05, '#surprising', '#admirable', 0.025, 'exercise', 'heavy_breathing', 'need_break', 'catch_breath', 'regain_energy']
senticnet['restaurant'] = [0.06, -0.012, 0, 0, '#joyful', '#surprising', 0.024, 'eat_food', 'fast_food', 'pizza_parlor', 'pizza_store', 'kitchen_cupboard']
senticnet['restaurant_bill'] = [0.044, 0.08, 0, -0.03, '#joyful', '#interesting', 0.031, 'birthday_card', 'labeler', 'bake_pan', 'account_book', 'computer_monitor']
senticnet['restaurant_diner'] = [0.076, 0.083, 0, -0.064, '#joyful', '#interesting', 0.032, 'trattoria', 'pizzeria', 'place_eat', 'romantic_date', 'eatery']
senticnet['restaurant_entrance'] = [0.087, 0.08, 0.013, 0, '#joyful', '#interesting', 0.051, 'advertise_company', 'billboard', 'underground_map', 'neighborhood_map', 'advertise_panel']
senticnet['restaurant_storage_area'] = [0.045, -0.053, 0, -0.029, '#joyful', '#surprising', 0.023, 'refrigerator', 'store_refrigerator', 'icebox', 'cold_storage', 'icy']
senticnet['rested'] = [0.516, -0.936, 0, 0.802, '#surprising', '#admirable', 0.751, 'invigorated', 'refreshed', 'reinvigorated', 'untired', 'unwearied']
senticnet['restful'] = [0.159, 0.16, 0, 0.218, '#interesting', '#admirable', 0.179, 'comfy', 'occur', 'sleep_area', 'sleep_place', 'rest_place']
senticnet['restitution'] = [-0.675, 0, 0.539, -0.995, '#sad', '#disgusting', -0.736, 'atonement', 'expiation', 'punitive_damage', 'exemplary_damages', 'compensation']
senticnet['restive'] = [-0.864, 0, -0.731, 0, '#sad', '#scared', -0.532, 'high-strung', 'uptight', 'overstrung', 'nervy', 'jumpy']
senticnet['restiveness'] = [-0.719, 0, -0.778, 0, '#sad', '#scared', -0.499, 'jumpiness', 'jitteriness', 'restive', 'nervy', 'jumpy']
senticnet['restless'] = [0, 0, 0.033, -0.096, '#angry', '#disgusting', -0.043, 'need_exercise', 'train_dog', 'tired', 'feel_energetic', 'need_fresh_air']
senticnet['restlessness'] = [-0.803, 0, -0.72, 0, '#sad', '#scared', -0.508, 'impatiently', 'raring', 'anxious', 'fidgetiness', 'fretful']
senticnet['restorative'] = [-0.507, 0, 0.937, -0.591, '#angry', '#disgusting', -0.678, 'bracer', 'medicine', 'medication', 'medicament', 'medicinal_drug']
senticnet['restore'] = [0.635, 0.639, -0.243, 0.291, '#joyful', '#interesting', 0.441, 'heal', 'put_back', 'back_up', 'restore_energy', 'fill_up']
senticnet['restore_energy'] = [0.635, 0.639, -0.243, 0.291, '#joyful', '#interesting', 0.441, 'heal', 'put_back', 'restore', 'back_up', 'fill_up']
senticnet['restrain'] = [-0.231, -0.018, -0.137, -0.07, '#sad', '#scared', -0.14, 'scold', 'diseased', 'go_hell', 'tragedy', 'put_in_jail']
senticnet['restraint'] = [-0.027, 0.201, -0.061, 0.246, '#interesting', '#admirable', 0.12, 'end_point', 'commence', 'restriction', 'direction', 'omega']
senticnet['restrict'] = [-0.337, -0.086, 0.011, -0.239, '#sad', '#disgusting', -0.167, 'leave_out', 'cause_suffer', 'disrespect', 'loathing', 'lose_team']
senticnet['restrict_access'] = [0.051, 0.165, -0.069, 0.174, '#interesting', '#admirable', 0.107, 'control_access', 'keep_someone_out', 'latch', 'lock', 'gate']
senticnet['restrict_freedom'] = [-0.205, -0.005, -0.057, -0.072, '#sad', '#disgusting', -0.11, 'suffocate', 'death_penalty', 'send_to_prison', 'terminate', 'even_odds']
senticnet['restriction'] = [0, 0, 0.764, -0.777, '#angry', '#disgusting', -0.514, 'dominate', 'tragedy', 'perpetrator', 'heroism', 'control']
senticnet['result'] = [-0.094, 0.205, -0.163, 0.183, '#interesting', '#admirable', 0.044, 'outcome', 'conclusion', 'problem', 'question_starter', 'effect']
senticnet['result_cook'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'french_toast', 'gnocchi', 'soybean', 'fondue', 'lasagna']
senticnet['result_death'] = [0, 0, -0.89, -0.781, '#scared', '#disgusting', -0.557, 'kill', 'make_someone_sick', 'destroy_target', 'socialist', 'murder_another_person']
senticnet['result_injury'] = [-0.027, 0.113, -0.088, 0.221, '#interesting', '#admirable', 0.073, 'movement', 'give_up', 'push_up', 'change_location', 'pull_car']
senticnet['resume'] = [-0.06, 0.149, -0.093, 0.181, '#interesting', '#admirable', 0.059, 'ask_nicely', 'job_offer', 'question_ask', 'make_happen', 'make_effort']
senticnet['retail_price_index'] = [0.538, -0.802, 0, 0.517, '#joyful', '#surprising', 0.619, 'indicator', 'price_index', 'producer_price_index', 'wholesale_price_index', 'consumer_price_index']
senticnet['retail_store'] = [0.02, 0, 0, 0.081, '#joyful', '#admirable', 0.034, 'grocery_store', 'supermarket', 'fast_food', 'restaurant', 'city_country']
senticnet['retain'] = [0.028, 0.239, -0.166, 0.295, '#interesting', '#admirable', 0.132, 'hold', 'hold_onto', 'keep', 'grasp', 'grab']
senticnet['retaliation'] = [-0.888, 0, 0.733, -0.605, '#sad', '#angry', -0.742, 'vengeance', 'payback', 'retribution', 'reprisal', 'return']
senticnet['retaliatory'] = [-0.753, 0, 0.981, -0.588, '#sad', '#angry', -0.774, 'punitive', 'penitentiary', 'correctional', 'retributive', 'retributory']
senticnet['retaliatory_eviction'] = [-0.873, 0, 0.765, -0.828, '#sad', '#disgusting', -0.822, 'due_process', 'due_process_of_law', 'ouster', 'dispossession', 'actual_eviction']
senticnet['retard'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'put_off', 'delay', 'procrastination', 'postpone', 'lag']
senticnet['retardation'] = [-0.602, 0, 0.827, -0.762, '#angry', '#disgusting', -0.73, 'slowness', 'mental_amentia', 'backwardness', 'subnormality', 'amentia']
senticnet['retarded'] = [-0.988, 0, 0.674, -0.933, '#sad', '#disgusting', -0.865, 'slow', 'slow_pace', 'stupid', 'slow_car', 'slow_vehicle']
senticnet['retention'] = [0.105, 0.226, -0.083, 0.176, '#interesting', '#admirable', 0.141, 'keep_someone_out', 'hold_onto', 'glass', 'drink_cup', 'make_apple']
senticnet['retentiveness'] = [0.685, -0.896, 0, 0.609, '#joyful', '#surprising', 0.73, 'mental_faculty', 'faculty', 'module', 'remembrance', 'anamnesis']
senticnet['retentivity'] = [0.965, -0.841, 0, 0.599, '#joyful', '#surprising', 0.802, 'mental_faculty', 'faculty', 'module', 'remembrance', 'anamnesis']
senticnet['reticent'] = [-0.896, 0, -0.864, 0, '#sad', '#scared', -0.587, 'retiring', 'restrained', 'unemotional', 'untalkative', 'self-effacing']
senticnet['retire'] = [0.078, 0.088, -0.071, 0, '#joyful', '#interesting', 0.032, 'inactivity', 'recover', 'avoid_accident', 'middle_day', 'need_food']
senticnet['retirement'] = [0.976, 0.847, 0, 0, '#joyful', '#interesting', 0.608, 'make_gift', 'new_relationship', 'amuse_oneself', 'celebrate_holiday', 'win_lottery']
senticnet['retort'] = [-0.066, 0.089, -0.082, 0.236, '#interesting', '#admirable', 0.059, 'answer_back', 'write_back', 'question_answer', 'response', 'send_back']
senticnet['retreat'] = [-0.375, 0.11, -0.218, -0.068, '#sad', '#scared', -0.184, 'military_retreat', 'downgrade', 'lose_battle', 'lose_war', 'retrocede']
senticnet['retribution'] = [-0.375, 0.11, -0.218, -0.068, '#sad', '#scared', -0.184, 'bad_behavior', 'correct_behavior', 'vengeance', 'judge_decision', 'put_in_jail']
senticnet['retributive'] = [-0.753, 0, 0.981, -0.588, '#sad', '#angry', -0.774, 'retaliatory', 'penitentiary', 'correctional', 'punitive', 'retributory']
senticnet['retributory'] = [-0.753, 0, 0.981, -0.588, '#sad', '#angry', -0.774, 'retaliatory', 'penitentiary', 'correctional', 'retributive', 'punitive']
senticnet['retrieve'] = [0.026, 0.165, -0.121, 0.292, '#interesting', '#admirable', 0.121, 'fetch', 'find', 'desire_win', 'take', 'obtain']
senticnet['retrocede'] = [-0.375, 0.11, -0.218, -0.068, '#sad', '#scared', -0.184, 'military_retreat', 'downgrade', 'lose_battle', 'lose_war', 'retreat']
senticnet['retrogress'] = [-0.771, 0, 0.785, -0.727, '#sad', '#angry', -0.761, 'recede', 'worsen', 'decline', 'drop_off', 'fall_back']
senticnet['retrogression'] = [-0.946, 0, 0.678, -0.83, '#sad', '#disgusting', -0.818, 'reversion', 'change_of_state', 'regression', 'regress', 'reversal']
senticnet['retrovert'] = [-0.9, 0, 0.837, -0.809, '#sad', '#angry', -0.849, 'revert', 'return', 'recidivate', 'regress', 'turn_back']
senticnet['return'] = [-0.077, 0.354, -0.214, 0.366, '#interesting', '#admirable', 0.143, 'receive', 'offer', 'gain', 'excise', 'transfer']
senticnet['return_goods'] = [-0.065, 0.097, 0, 0.076, '#interesting', '#admirable', 0.036, 'buy_stuff', 'refund', 'buy_goods', 'buy_item', 'buy_cheap_item']
senticnet['return_home'] = [0.719, 0.789, 0, 0, '#joyful', '#interesting', 0.503, 'drink_espresso', 'think_future', 'hang_picture_on_wall', 'gather_berry', 'mine_diamond']
senticnet['return_ticket'] = [0, 0, 0.014, -0.115, '#angry', '#disgusting', -0.043, 'bus_pass', 'transit_card', 'passenger_ticket', 'train_ticket', 'move_sidewalk']
senticnet['return_work'] = [0.229, 0.127, 0, 0, '#joyful', '#interesting', 0.119, 'begin_work', 'start_project', 'work_box_office', 'write_program', 'go_work']
senticnet['reunion'] = [0.119, -0.132, -0.062, 0, '#joyful', '#surprising', 0.063, 'gala', 'celebration', 'special_event', 'special_happen', 'special_moment']
senticnet['reuse_oil'] = [-0.98, 0, 0.594, -0.988, '#sad', '#disgusting', -0.854, 'fast_food', 'deep_fried', 'unhealthy_food', 'junk_food', 'fattening_food']
senticnet['reveal'] = [0.782, 0, 0, 0.992, '#joyful', '#admirable', 0.591, 'locate', 'encounter', 'concede', 'seek', 'search']
senticnet['reveal_truth'] = [0.698, -0.547, 0, 0.995, '#joyful', '#admirable', 0.747, 'learn_oneself', 'clarification', 'tell_information', 'understand', 'expose']
senticnet['revel'] = [-0.702, 0, 0.704, -0.552, '#sad', '#angry', -0.653, 'whoopee', 'merrymaking', 'jollification', 'binge', 'riot']
senticnet['revelry'] = [-0.612, 0, 0.972, -0.584, '#sad', '#angry', -0.723, 'whoopee', 'merrymaking', 'jollification', 'binge', 'riot']
senticnet['revenge'] = [0, 0, -0.965, -0.935, '#scared', '#disgusting', -0.633, 'vengeance', 'break_law', 'send_to_jail', 'get_revenge', 'arrest']
senticnet['revengefully'] = [-0.031, 0.157, 0.698, -0.661, '#angry', '#disgusting', -0.411, 'vengefulness', 'vindictively', 'vengefully', 'vindictive', 'spiteful']
senticnet['revenue'] = [-0.058, 0.307, -0.123, 0.148, '#interesting', '#admirable', 0.091, 'income', 'money_pay', 'earnings', 'stock_market', 'repay']
senticnet['revere'] = [0.962, 0.9, 0, 0, '#joyful', '#interesting', 0.621, 'reverently', 'hero-worship', 'venerate', 'idolize', 'veneration']
senticnet['reverence'] = [0, 0.776, 0, 0.953, '#interesting', '#admirable', 0.576, 'reverently', 'hero-worship', 'venerate', 'idolize', 'veneration']
senticnet['reverend'] = [0.796, -0.705, 0, 0.829, '#joyful', '#admirable', 0.777, 'divine', 'minister', 'deacon', 'acolyte', 'anagnost']
senticnet['reverent'] = [0, 0.883, 0, 0.853, '#interesting', '#admirable', 0.579, 'reverently', 'hero-worship', 'venerate', 'idolize', 'veneration']
senticnet['reverentially'] = [0, 0.769, 0, 0.769, '#interesting', '#admirable', 0.513, 'reverently', 'hero-worship', 'venerate', 'idolize', 'veneration']
senticnet['reverently'] = [0, 0.846, 0, 0.901, '#interesting', '#admirable', 0.582, 'hero-worship', 'venerate', 'idolize', 'veneration', 'reverentially']
senticnet['reversal'] = [-0.946, 0, 0.678, -0.83, '#sad', '#disgusting', -0.818, 'reversion', 'change_of_state', 'regression', 'regress', 'retrogression']
senticnet['reversed'] = [-0.652, 0, 0.935, -0.846, '#angry', '#disgusting', -0.811, 'upset', 'inverted', 'overturned', 'upturned', 'turned']
senticnet['reversion'] = [-0.946, 0, 0.678, -0.83, '#sad', '#disgusting', -0.818, 'reversal', 'change_of_state', 'regression', 'regress', 'retrogression']
senticnet['revert'] = [-0.9, 0, 0.837, -0.809, '#sad', '#angry', -0.849, 'recidivate', 'return', 'retrovert', 'regress', 'turn_back']
senticnet['review_book'] = [0, 0.87, 0, 0.713, '#interesting', '#admirable', 0.528, 'review', 'book', 'read_book', 'write_review', 'analyze_book']
senticnet['review_material'] = [-0.097, -0.011, 0.051, -0.177, '#sad', '#disgusting', -0.105, 'knowledge_subject', 'choose_subject', 'want_learn', 'better_grade', 'review_note']
senticnet['review_note'] = [0, 0.974, 0, 0.703, '#interesting', '#admirable', 0.559, 'review', 'note', 'review_book', 'write_review', 'write_note']
senticnet['revilement'] = [-0.765, 0, 0.519, -0.564, '#sad', '#disgusting', -0.616, 'scurrility', 'billingsgate', 'disrespect', 'discourtesy', 'vituperation']
senticnet['revise'] = [-0.175, 0, 0, -0.128, '#sad', '#disgusting', -0.101, 'study_material', 'study_lot', 'a_lot_of_study', 'go_college', 'study_hard']
senticnet['revitalize'] = [0.696, -0.957, 0, 0.851, '#surprising', '#admirable', 0.835, 'better', 'improve', 'look_better', 'meliorate', 'amend']
senticnet['revitalize_oneself'] = [0, 0, 0.037, -0.045, '#angry', '#disgusting', -0.027, 'set_alarm', 'feel_refreshed', 'rejuvenation', 'rest_dream', 'productive']
senticnet['revival_meeting'] = [0.669, -0.583, 0, 0.803, '#joyful', '#admirable', 0.685, 'pep_rally', 'revival', 'rally', 'gathering', 'assemblage']
senticnet['revive'] = [0.658, -0.605, 0, 0.691, '#joyful', '#admirable', 0.651, 'bring_up', 'bring_around', 'resurrect', 'boot', 'reboot']
senticnet['revived'] = [0.673, -0.95, 0, 0.914, '#surprising', '#admirable', 0.846, 'renewed', 'revitalized', 'resurgent', 'renascent', 'resuscitated']
senticnet['revivify'] = [0.734, -0.646, 0, 0.933, '#joyful', '#admirable', 0.771, 'energize', 'perk_up', 'brace', 'stimulate', 'arouse']
senticnet['revolt'] = [0, 0, 0.729, -0.788, '#angry', '#disgusting', -0.506, 'hostility', 'aggression', 'malice', 'animosity', 'despise']
senticnet['revolting'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'disgusting', 'fed_up', 'sick_of', 'disgustful']
senticnet['revoltingly'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['revolution'] = [0.866, 0.817, 0, 0, '#joyful', '#interesting', 0.561, 'patriotism', 'uprise', 'revolutionary', 'renovation', 'regeneration']
senticnet['revolutionary'] = [0, 0, 0, -0.122, '#disgusting', '#disgusting', -0.041, 'native_person', 'futurism', 'republic', 'revolution', 'look_ahead']
senticnet['revolve'] = [0, 0.134, -0.088, 0.225, '#interesting', '#admirable', 0.09, 'rotate', 'rotate_movement', 'wrap_around', 'change_direction', 'turn_around']
senticnet['revolver'] = [0, -0.745, 0, 0.731, '#surprising', '#admirable', 0.492, 'pistol', 'gun', 'hydrogen_bomb', 'rifle', 'shotgun']
senticnet['revolving'] = [0, 0, -0.918, -0.753, '#scared', '#disgusting', -0.557, 'orbit', 'orb', 'roll', 'go_around', 'rotate']
senticnet['revulsion'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'repulsive', 'repugnant', 'detestably', 'abominably', 'odiously']
senticnet['reward'] = [0.728, 0.949, 0, 0, '#joyful', '#interesting', 0.559, 'tax', 'payment', 'bribe', 'owe', 'divorce_money']
senticnet['rewarding'] = [0.866, 0.806, 0, 0, '#joyful', '#interesting', 0.557, 'reinforce', 'repay', 'honor', 'pay_back', 'award']
senticnet['rewind'] = [-0.135, 0, -0.084, -0.088, '#sad', '#disgusting', -0.102, 'jitters', 'see_film', 'press_play', 'use_remote_control', 'view_movie']
senticnet['rhapsody'] = [0.101, -0.049, 0.036, 0, '#joyful', '#surprising', 0.038, 'song', 'rap', 'jingle', 'chord', 'lyric']
senticnet['rhetoric'] = [0, 0.075, 0, 0.152, '#interesting', '#admirable', 0.076, 'idiom', 'utterance', 'spanish', 'whisper', 'voice']
senticnet['rheumatic_heart_disease'] = [0.852, -0.988, 0, 0.67, '#joyful', '#surprising', 0.837, 'cardiac_arrhythmia', 'arrhythmia', 'cardiomyopathy', 'heart_disease', 'cardiopathy']
senticnet['rheumatoid_arthritis'] = [-0.899, 0, 0.989, -0.59, '#sad', '#angry', -0.826, 'arthritis', 'psoriatic_arthritis', 'juvenile_rheumatoid_arthritis', 'autoimmune_disease', 'autoimmune_disorder']
senticnet['rhinitis'] = [-0.606, 0, 0.931, -0.922, '#angry', '#disgusting', -0.82, 'allergic_rhinitis', 'coryza', 'hay_fever', 'pollinosis', 'hypersensitivity_reaction']
senticnet['rhinostenosis'] = [-0.815, 0, 0.684, -0.813, '#sad', '#disgusting', -0.771, 'stenosis', 'enterostenosis', 'laryngostenosis', 'aortic_stenosis', 'mitral_stenosis']
senticnet['rhizoctinia_disease'] = [-0.699, 0, 0.776, -0.788, '#angry', '#disgusting', -0.754, 'little_potato', 'russet_scab', 'stem_canker', 'rosette', 'plant_disease']
senticnet['rhizotomy'] = [-0.847, 0, 0.567, -0.915, '#sad', '#disgusting', -0.776, 'operation', 'surgery', 'surgical_operation', 'surgical_procedure', 'surgical_process']
senticnet['rhyme'] = [0.956, 0.807, 0, 0.929, '#joyful', '#admirable', 0.897, 'like_poetry', 'refrain', 'song_lyric', 'verse', 'lyrics']
senticnet['rhythm'] = [0.711, 0.858, 0, 0, '#joyful', '#interesting', 0.523, 'lyric', 'tune', 'melody', 'lyrics', 'song']
senticnet['rhythmic'] = [0.109, 0, 0.04, 0.176, '#joyful', '#admirable', 0.082, 'vigorous_activity', 'body_movement', 'human_action', 'fast_movement', 'form_of_exercise']
senticnet['rhythmical'] = [-0.841, 0, 0.574, -0.668, '#sad', '#disgusting', -0.694, 'cadenced', 'cadent', 'metrical', 'metric', 'lilting']
senticnet['ribbon'] = [0, 0.834, 0, 0.941, '#interesting', '#admirable', 0.592, 'keepsake', 'neckwear', 'round_brush', 'jeans', 'panties']
senticnet['rich'] = [0.711, 0.914, 0, 0, '#joyful', '#interesting', 0.542, 'business', 'finance', 'revenue', 'wealth', 'income']
senticnet['rich_house'] = [0.216, 0.154, -0.055, 0.342, '#joyful', '#admirable', 0.219, 'own_space', 'nice_house', 'decorate_house', 'another_house', 'place_to_live']
senticnet['rich_person'] = [0.883, 0.759, 0, 0.718, '#joyful', '#interesting', 0.787, 'management', 'ambassador', 'supervisor', 'servant', 'master']
senticnet['riches'] = [0.068, 0.171, 0, 0.117, '#interesting', '#admirable', 0.119, 'wealthy', 'richness', 'much_money', 'slogan', 'immoral']
senticnet['richness'] = [0.144, 0.266, -0.051, 0.269, '#interesting', '#admirable', 0.209, 'riches', 'slogan', 'valuable', 'immoral', 'extra_money']
senticnet['rick'] = [0.037, 0.144, -0.059, 0.199, '#interesting', '#admirable', 0.107, 'small_circle', 'round_bread', 'circular_motion', 'bun', 'roll']
senticnet['rickettsial_disease'] = [-0.738, 0, 0.599, -0.96, '#sad', '#disgusting', -0.766, 'spotted_fever', 'trench_fever', 'rickettsialpox', 'typhus', 'typhus_fever']
senticnet['rickettsialpox'] = [-0.738, 0, 0.599, -0.96, '#sad', '#disgusting', -0.766, 'spotted_fever', 'trench_fever', 'rickettsial_disease', 'typhus', 'typhus_fever']
senticnet['rickettsiosis'] = [-0.589, 0, 0.797, -0.931, '#angry', '#disgusting', -0.772, 'spotted_fever', 'trench_fever', 'rickettsialpox', 'typhus', 'typhus_fever']
senticnet['rid'] = [0.712, -0.853, 0, 0.67, '#joyful', '#surprising', 0.745, 'smooth_out', 'clear', 'relieve', 'smooth', 'disembody']
senticnet['rid_of'] = [-0.989, 0, 0.383, -0.938, '#sad', '#disgusting', -0.77, 'lose', 'destroy', 'rid', 'defeat', 'kill']
senticnet['ridden'] = [-0.034, 0.131, -0.072, 0.121, '#interesting', '#admirable', 0.049, 'alike', 'true', 'invent_20th_century', 'group_animal', 'find_ranch']
senticnet['riddled'] = [-0.796, 0, -0.761, 0, '#sad', '#scared', -0.519, 'pervade', 'diffuse', 'penetrate', 'permeate', 'screen']
senticnet['ride'] = [0.887, 0.76, 0, 0, '#joyful', '#interesting', 0.549, 'transport', 'trucking', 'connect_city', 'transportation', 'car_travel']
senticnet['ride_airplane'] = [0.937, 0.82, 0, 0, '#joyful', '#interesting', 0.586, 'sit_airplane', 'work_pile_up', 'traveling_long_distance', 'come_back_home', 'fall_asleep']
senticnet['ride_bicycle'] = [-0.027, 0, 0, -0.112, '#sad', '#disgusting', -0.046, 'car', 'police_car', 'traffic_cop', 'bomber', 'lorry']
senticnet['ride_bicycle_work'] = [-0.083, 0.089, 0, 0.097, '#interesting', '#admirable', 0.034, 'shout_loudly', 'take_hike', 'stop_smoke', 'scream_real_loud', 'break_record']
senticnet['ride_bus'] = [0.995, 0.898, 0, 0, '#joyful', '#interesting', 0.631, 'bus', 'board_bus', 'ride', 'catch_bus', 'ride_airplane']
senticnet['ride_car'] = [0.11, 0, 0, 0.095, '#joyful', '#admirable', 0.068, 'play_fetch', 'chew_bone', 'dog', 'play_human', 'run']
senticnet['ride_horse'] = [0, 0, 0, 0.071, '#admirable', '#admirable', 0.024, 'two_horses', 'horse', 'mule', 'buddhist', 'barb']
senticnet['ride_motorbike'] = [-0.043, 0, -0.087, 0, '#sad', '#scared', -0.043, 'five_fingers', 'palm', 'arm_part', 'five_digits', 'wear_glove']
senticnet['ride_roller_coaster'] = [-0.183, 0, -0.142, -0.111, '#sad', '#scared', -0.145, 'fly_kite', 'walk_dog', 'skateboard', 'rake_leave', 'jump_up_down']
senticnet['ride_subway'] = [-0.059, 0.176, -0.066, 0.125, '#interesting', '#admirable', 0.059, 'bus_ride', 'buy_vending_machine', 'take_trip', 'ride_train', 'acquire']
senticnet['ride_train'] = [-0.059, 0.176, -0.066, 0.125, '#interesting', '#admirable', 0.059, 'bus_ride', 'buy_vending_machine', 'take_trip', 'ride_subway', 'acquire']
senticnet['ride_work'] = [0.045, 0.102, 0, 0, '#joyful', '#interesting', 0.049, 'save_time', 'enjoy_food', 'enjoy_view', 'meet_new_friend', 'speed_up']
senticnet['ridge'] = [0.029, 0.096, 0.013, 0, '#joyful', '#interesting', 0.037, 'knoll', 'steep', 'hill', 'land_form', 'mountain']
senticnet['ridgeback'] = [-0.915, 0, -0.995, 0, '#sad', '#scared', -0.637, 'minor_planet', 'dwarf_planet', 'insure', 'human_memory', 'competitive_activity']
senticnet['ridicule'] = [0, 0, 0.808, 0, '#angry', '#angry', -0.269, 'feel_hurt', 'hurt_feeling', 'get_hurt', 'feel_bad', 'feel_guilty']
senticnet['ridiculed'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'mocked', 'tormented', 'bothered', 'annoyed', 'teased']
senticnet['ridiculous'] = [-0.386, -0.086, 0, -0.34, '#sad', '#disgusting', -0.213, 'terminal_illness', 'ill_health', 'car_wreck', 'meanness', 'bad_hair_day']
senticnet['rife'] = [0, 0, -0.928, -0.774, '#scared', '#disgusting', -0.567, 'overabundant', 'prevailing', 'plethoric', 'predominant', 'dominant']
senticnet['rifle'] = [0, 0, 0.749, -0.733, '#angry', '#disgusting', -0.494, 'gun', 'pistol', 'revolver', 'firearm', 'handgun']
senticnet['rig'] = [-0.914, 0, 0.85, -0.766, '#sad', '#angry', -0.843, 'fraud_in_fact', 'positive_fraud', 'mail_fraud', 'swindle', 'fraud']
senticnet['rigamarole'] = [-0.924, 0, 0.648, -0.831, '#sad', '#disgusting', -0.801, 'meaninglessness', 'nonsense', 'bunk', 'nonsensicality', 'hokum']
senticnet['right'] = [0.961, 0.916, 0, 0.901, '#joyful', '#interesting', 0.926, 'good', 'again_and_again', 'band_together', 'song_title', 'plus']
senticnet['right_angle'] = [0.049, 0.088, 0.071, 0.078, '#interesting', '#admirable', 0.048, 'part_of_room', 'corner', 'sharpness', 'side', 'ninety_degree']
senticnet['right_injustice'] = [-0.88, 0, 0, -0.842, '#sad', '#disgusting', -0.574, 'raise_flag', 'bridge_difference', 'arm_oneself', 'market_product', 'deal_card_player']
senticnet['right_now'] = [0, 0.884, 0, 0.978, '#interesting', '#admirable', 0.621, 'now_time', 'immediately', 'contemporary', 'timely', 'time']
senticnet['right_of_way'] = [0.621, -0.603, 0, 0.545, '#joyful', '#surprising', 0.59, 'privilege', 'perquisite', 'public_easement', 'easement', 'prerogative']
senticnet['right_wrong'] = [0.937, 0.898, 0, 0, '#joyful', '#interesting', 0.612, 'weigh_consequence', 'make_plan', 'good_plan', 'vengeance', 'plan_carefully']
senticnet['righteousness'] = [0.998, -0.893, 0, 0.667, '#joyful', '#surprising', 0.853, 'honorableness', 'honourableness', 'morality', 'rectitude', 'honor']
senticnet['rigid'] = [0, 0.066, 0.056, 0.111, '#interesting', '#admirable', 0.04, 'durable', 'hard', 'hard_material', 'solid', 'inflexible']
senticnet['rigidification'] = [-0.84, 0, 0.8, -0.542, '#sad', '#angry', -0.727, 'rigor_mortis', 'natural_process', 'natural_action', 'activity', 'action']
senticnet['rigidifying'] = [-0.96, 0, 0.897, -0.728, '#sad', '#angry', -0.862, 'rigor_mortis', 'natural_process', 'natural_action', 'activity', 'action']
senticnet['rigidity'] = [-0.812, 0, 0.83, -0.978, '#angry', '#disgusting', -0.873, 'deadness', 'inelasticity', 'rigidness', 'stiffness', 'physical_property']
senticnet['rigidness'] = [-0.812, 0, 0.83, -0.978, '#angry', '#disgusting', -0.873, 'deadness', 'rigidity', 'inelasticity', 'stiffness', 'physical_property']
senticnet['rigmarole'] = [-0.801, 0, 0.54, -0.632, '#sad', '#disgusting', -0.658, 'meaninglessness', 'nonsense', 'bunk', 'nonsensicality', 'hokum']
senticnet['rigor_mortis'] = [-0.84, 0, 0.8, -0.542, '#sad', '#angry', -0.727, 'rigidification', 'natural_process', 'natural_action', 'activity', 'action']
senticnet['rile'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['riled'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['rim'] = [0, 0, 0.919, -0.746, '#angry', '#disgusting', -0.555, 'knife_sharp', 'decline', 'dart', 'unpleasantness', 'dullness']
senticnet['rind'] = [0, 0.141, 0.01, 0.115, '#interesting', '#admirable', 0.082, 'sepal', 'achene', 'funiculus', 'seed', 'pip']
senticnet['ring'] = [0.052, 0, 0, 0.118, '#joyful', '#admirable', 0.057, 'diamond_ring', 'piece_of_jewelry', 'bell_sound', 'wedding_band', 'engagement']
senticnet['ring_binder'] = [0, 0.923, 0, 0.977, '#interesting', '#admirable', 0.633, 'paper_clip', 'paper_punch', 'highlighter', 'office', 'pencil_sharpener']
senticnet['ring_disease'] = [-0.833, 0, 0.754, -0.979, '#sad', '#disgusting', -0.855, 'brown_rot_gummosis', 'ring_rot', 'brown_rot', 'tobacco_wilt', 'gummosis']
senticnet['ring_doorbell'] = [-0.155, 0, -0.059, -0.032, '#sad', '#scared', -0.082, 'roll_ball', 'laugh_clown', 'trade_baseball_card', 'throw_fit', 'watch_d']
senticnet['ring_loudly'] = [0.033, 0.095, 0.062, 0.167, '#interesting', '#admirable', 0.078, 'chime', 'school_end', 'ring', 'wedding_ring', 'bell_sound']
senticnet['ring_road'] = [0.032, 0.116, 0.016, 0, '#joyful', '#interesting', 0.044, 'curb', 'crossroad', 'intersection', 'lane', 'interstate']
senticnet['ring_rot'] = [-0.833, 0, 0.754, -0.979, '#sad', '#disgusting', -0.855, 'brown_rot_gummosis', 'brown_rot', 'ring_disease', 'tobacco_wilt', 'gummosis']
senticnet['ring_snake'] = [-0.514, 0, 0.625, -0.984, '#angry', '#disgusting', -0.708, 'common_water_snake', 'banded_water_snake', 'water_moccasin', 'grass_snake', 'water_snake']
senticnet['ringed'] = [-0.957, 0, -0.9, 0, '#sad', '#scared', -0.619, 'knell', 'reverberate', 'resound', 'peal', 'echo']
senticnet['ringer'] = [-0.97, 0, 0.728, -0.785, '#sad', '#disgusting', -0.828, 'beguiler', 'slicker', 'name_dropper', 'faker', 'deceiver']
senticnet['ringleader'] = [-0.599, 0, 0.79, -0.552, '#sad', '#angry', -0.647, 'troublemaker', 'trouble_maker', 'troubler', 'bad_hat', 'inciter']
senticnet['ringworm'] = [-0.964, 0, 0.694, -0.623, '#sad', '#angry', -0.76, 'fungal_infection', 'mycosis', 'kerion', 'tinea_pedis', 'athlete_foot']
senticnet['rinse_dish'] = [0, 0.091, -0.053, 0.073, '#interesting', '#admirable', 0.037, 'privately', 'hold_liquid', 'brew', 'make_wish', 'find_toilet']
senticnet['riot'] = [-0.895, 0, 0.829, -0.926, '#sad', '#disgusting', -0.883, 'against', 'uprise', 'dispute', 'quarrel', 'opposition']
senticnet['riot_act'] = [0.662, -0.849, 0, 0.709, '#surprising', '#admirable', 0.74, 'rebuke', 'reproof', 'reproval', 'reprehension', 'reprimand']
senticnet['riotously'] = [0.512, 0.658, -0.254, 0.256, '#joyful', '#interesting', 0.391, 'exuberantly', 'expansively', 'ebulliently', 'zestfulness', 'gusto']
senticnet['rip'] = [-0.113, -0.003, 0, -0.165, '#sad', '#disgusting', -0.092, 'pierce', 'spread_butter', 'cut_food', 'lacerate', 'bleed']
senticnet['rip_off'] = [-0.897, 0, 0.826, -0.501, '#sad', '#angry', -0.741, 'wrong', 'delude', 'deceive', 'cozen', 'victimize']
senticnet['rip_out'] = [-0.919, 0, 0.656, -0.813, '#sad', '#disgusting', -0.796, 'withdraw', 'squeeze_out', 'take', 'wring_out', 'demodulate']
senticnet['rip_up'] = [-0.576, 0, 0.852, -0.745, '#angry', '#disgusting', -0.724, 'tease', 'bust', 'tear', 'rupture', 'snap']
senticnet['ripe'] = [0, 0.138, -0.065, 0.221, '#interesting', '#admirable', 0.098, 'neat', 'neat_tidy', 'sort', 'tidy_up', 'tidy']
senticnet['ripe_apple'] = [0, -0.068, 0, 0, '#surprising', '#surprising', 0.023, 'candy_cane', 'custard', 'cookie', 'candy', 'orange_fruit']
senticnet['riposte'] = [-0.879, 0, 0.872, -0.831, '#sad', '#angry', -0.861, 'reply', 'response', 'comeback', 'sassing', 'backtalk']
senticnet['rise'] = [0, 0.124, -0.075, 0.115, '#interesting', '#admirable', 0.055, 'arise', 'lift', 'store_garage', 'go_upstairs', 'climb']
senticnet['rise_plant'] = [0.042, 0.166, -0.12, 0.178, '#interesting', '#admirable', 0.089, 'flower_type', 'rose', 'rise', 'symbol_love', 'rosebud']
senticnet['rise_up'] = [0, 0.229, -0.115, 0.243, '#interesting', '#admirable', 0.119, 'raise_up', 'pull_up', 'go_up', 'move_upward', 'move_up']
senticnet['rise_water'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'water_spray', 'liquid_water', 'water_inside', 'humid', 'water_relate']
senticnet['risen'] = [0, 0.338, -0.109, 0.24, '#interesting', '#admirable', 0.156, 'bonus', 'give_money', 'money_due', 'compensation', 'repay']
senticnet['risk'] = [-0.916, 0, -0.759, -0.87, '#sad', '#disgusting', -0.848, 'jeopardy', 'bad_situation', 'adversity', 'dare', 'deception']
senticnet['risk_to_lose'] = [-0.929, 0, 0.44, -0.943, '#sad', '#disgusting', -0.771, 'chance', 'risk', 'last_chance', 'dangerous', 'danger']
senticnet['risky'] = [-0.155, -0.064, -0.211, -0.054, '#sad', '#scared', -0.119, 'feel_scared', 'concussion', 'loss_ofbreath', 'unsafe', 'hardship']
senticnet['rite'] = [0, 0, 0, 0.86, '#admirable', '#admirable', 0.287, 'religious_event', 'ceremony', 'happy_event', 'occasion', 'christmas']
senticnet['ritonavir'] = [-0.818, 0, 0.767, -0.936, '#sad', '#disgusting', -0.84, 'antiviral', 'indinavir', 'nelfinavir', 'protease_inhibitor', 'saquinavir']
senticnet['ritual'] = [0, 0, 0, 0.813, '#admirable', '#admirable', 0.271, 'church_service', 'prayer', 'religious', 'faith', 'pardon']
senticnet['ritz'] = [-0.818, 0, 0.936, -0.579, '#sad', '#angry', -0.778, 'pedantry', 'bluster', 'splurge', 'ostentation', 'display']
senticnet['rival'] = [-0.126, 0.115, -0.064, -0.119, '#sad', '#disgusting', -0.065, 'opposition', 'fight_against', 'funny_look', 'uprise', 'anti']
senticnet['river'] = [0, 0, -0.071, 0, '#scared', '#scared', -0.024, 'reptile', 'animal', 'predator', 'meat_eater', 'alligator']
senticnet['river_bank'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'river', 'fresh_water', 'small_stream', 'small_river', 'water']
senticnet['river_bed'] = [-0.023, -0.035, 0.047, -0.081, '#angry', '#disgusting', -0.039, 'waterfall', 'riverbed', 'surface_earth', 'septic_tank', 'bottom_ocean']
senticnet['river_lake'] = [0, -0.025, 0.064, -0.085, '#angry', '#disgusting', -0.041, 'land_earth', 'spurt', 'brine', 'crush_ice', 'puddle']
senticnet['river_stream'] = [-0.061, -0.003, -0.092, 0, '#sad', '#scared', -0.05, 'capoeira', 'trouble', 'agony', 'cause_problem', 'madman']
senticnet['riverbed'] = [-0.023, -0.035, 0.047, -0.081, '#angry', '#disgusting', -0.039, 'waterfall', 'river_bed', 'surface_earth', 'septic_tank', 'bottom_ocean']
senticnet['riveting'] = [0.851, 0.815, 0, 0, '#joyful', '#interesting', 0.555, 'concentrate', 'focus', 'pore', 'centre', 'engrossing']
senticnet['roach'] = [0.021, -0.104, 0.248, -0.299, '#angry', '#disgusting', -0.141, 'dust', 'spider', 'dust_mite', 'cookie_crumb', 'dirty_sock']
senticnet['road_block'] = [0, 0, 0.727, -0.984, '#angry', '#disgusting', -0.57, 'traffic', 'congestion', 'block_road', 'traffic_congestion', 'stop']
senticnet['road_map'] = [0.525, -0.766, 0, 0.783, '#surprising', '#admirable', 0.691, 'guidance', 'plan', 'program', 'programme', 'counsel']
senticnet['road_rage'] = [-0.103, -0.049, 0, -0.147, '#sad', '#disgusting', -0.067, 'adjust_seat', 'angry_behavior', 'fasten_seatbelt', 'traffic_jam', 'skid_mark']
senticnet['road_sense'] = [0.588, -0.734, 0, 0.788, '#surprising', '#admirable', 0.703, 'common_sense', 'good_sense', 'horse_sense', 'mother_wit', 'gumption']
senticnet['road_sign'] = [0.038, 0.145, 0, 0.113, '#interesting', '#admirable', 0.099, 'street_sign', 'traffic_sign', 'sign', 'red_light', 'intersection']
senticnet['road_test'] = [0.928, -0.879, 0, 0.679, '#joyful', '#surprising', 0.829, 'field_trial', 'field_test', 'alpha_test', 'beta_test', 'test']
senticnet['roadblock'] = [0, 0, 0, -0.125, '#disgusting', '#disgusting', -0.042, 'corner_two_streets', 'street_corner', 'roadside', 'city_street', 'schoolyard']
senticnet['roadway_square'] = [0.093, 0, 0.011, 0.106, '#joyful', '#admirable', 0.063, 'many_different_types', 'many_types', 'type', 'many_kinds', 'bee']
senticnet['roam'] = [-0.665, 0, 0.949, -0.754, '#angry', '#disgusting', -0.789, 'gad', 'move', 'gallivant', 'jazz_around', 'travel']
senticnet['roar'] = [0, 0, -0.87, 0, '#scared', '#scared', -0.29, 'noise', 'clamor', 'clang', 'sound', 'squeak']
senticnet['roaring'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'deafening', 'hear_loud_sound', 'ear_splitting', 'rowdy', 'noisy']
senticnet['roast'] = [0.032, -0.068, 0, 0, '#joyful', '#surprising', 0.033, 'bake_bread', 'bake_cookie', 'grill_food', 'bake', 'roasted_chicken']
senticnet['roast_lamb'] = [0.619, -0.562, 0, 0.875, '#joyful', '#admirable', 0.685, 'leg_of_lamb', 'gigot', 'joint', 'roast', 'rack_of_lamb']
senticnet['roast_meat'] = [0, -0.139, 0.058, 0.059, '#surprising', '#admirable', 0.047, 'cook_meat', 'cook_hamburger', 'cook_food', 'cook_rice', 'brown_meat']
senticnet['roasted'] = [0, 0, -0.705, -0.871, '#scared', '#disgusting', -0.525, 'guy', 'blackguard', 'laugh_at', 'ridicule', 'jest_at']
senticnet['roasted_chicken'] = [0.032, -0.068, 0, 0, '#joyful', '#surprising', 0.033, 'bake_bread', 'bake_cookie', 'grill_food', 'bake', 'roast']
senticnet['rob'] = [-0.75, 0, 0.847, -0.783, '#angry', '#disgusting', -0.793, 'steal', 'theft', 'steal_money', 'burglary', 'stick_up']
senticnet['rob_bank'] = [-0.733, 0, 0.862, 0, '#sad', '#angry', -0.532, 'enter_store', 'play_video_game', 'go_town', 'climb_to_top', 'live_simply']
senticnet['robbery'] = [0, 0, -0.843, -0.901, '#scared', '#disgusting', -0.581, 'steal_money', 'theft', 'burglary', 'rapine', 'thief']
senticnet['robbery_suspect'] = [0.964, -0.577, 0, 0.827, '#joyful', '#admirable', 0.789, 'mortal', 'murder_suspect', 'suspect', 'rape_suspect', 'person']
senticnet['robe'] = [0.912, 0, 0, 0.979, '#joyful', '#admirable', 0.63, 'garment', 'slack', 'piece_of_clothing', 'underwear', 'clothes']
senticnet['robust'] = [0, 0.739, 0, 0.775, '#interesting', '#admirable', 0.505, 'hardy', 'sturdy', 'stalwart', 'durable', 'resilient']
senticnet['robustious'] = [-0.642, 0, 0.941, -0.664, '#angry', '#disgusting', -0.749, 'rowdy', 'boisterous', 'unruly', 'rambunctious', 'disorderly']
senticnet['roc'] = [-0.651, 0, 0.505, -0.919, '#sad', '#disgusting', -0.692, 'hellhound', 'mythical_being', 'dragon', 'mythical_monster', 'amphisbaena']
senticnet['rock_band'] = [0.937, 0, 0, 0, '#joyful', '#joyful', 0.312, 'music', 'classical', 'composer', 'songwriter', 'band_play']
senticnet['rock_chair'] = [-0.916, 0, -0.916, 0, '#sad', '#scared', -0.611, 'sofa_bed', 'armchair', 'sofa_hide_bed', 'chair', 'club_chair']
senticnet['rock_climb'] = [0.989, 0, 0, 0.837, '#joyful', '#admirable', 0.609, 'sport', 'exercise', 'enjoy_nature', 'extreme_sport', 'mountain_climb']
senticnet['rock_concert'] = [0.838, 0.75, 0, 0.708, '#joyful', '#interesting', 0.765, 'festival', 'party', 'banquet', 'marketplace', 'big_event']
senticnet['rock_crab'] = [-0.698, 0, 0.766, -0.826, '#angry', '#disgusting', -0.763, 'stone_crab', 'swimming_crab', 'crab', 'fiddler_crab', 'pea_crab']
senticnet['rock_cress'] = [0.598, -0.721, 0, 0.941, '#surprising', '#admirable', 0.753, 'sicklepod', 'tower_cress', 'tower_mustard', 'cress', 'cress_plant']
senticnet['rock_formation'] = [0.039, 0.073, 0.038, 0.107, '#interesting', '#admirable', 0.06, 'large_rock', 'big_rock', 'geographic_feature', 'land_formation', 'geographical_feature']
senticnet['rock_group'] = [0.032, 0.092, 0, 0.075, '#interesting', '#admirable', 0.066, 'eclectic', 'music_player', 'make_musicr', 'musical_group', 'guitar_player']
senticnet['rock_music'] = [0.061, 0, 0.017, 0.098, '#joyful', '#admirable', 0.047, 'form_expression', 'music_type', 'valuable_gem', 'small_boulder', 'music_genre']
senticnet['rock_out'] = [0, 0.776, 0, 0.758, '#interesting', '#admirable', 0.511, 'play_song', 'singer', 'perfect_skill', 'remember_childhood', 'play_tune']
senticnet['rock_plant'] = [0.704, -0.925, 0, 0.517, '#joyful', '#surprising', 0.715, 'plant', 'flora', 'plant_life', 'lithophyte', 'lithophytic_plant']
senticnet['rock_roll'] = [0.753, 0, 0, 0.869, '#joyful', '#admirable', 0.541, 'rhythm', 'hip_hop', 'lyric', 'type_of_music', 'tune']
senticnet['rock_star'] = [0.979, 0.982, 0, 0.752, '#joyful', '#interesting', 0.904, 'hippy', 'philanthropist', 'male_human', 'singer', 'nazi']
senticnet['rocker'] = [0.107, -0.046, 0, 0, '#joyful', '#surprising', 0.051, 'eclectic', 'gig', 'jazz', 'rock_group', 'folk_music']
senticnet['rocket'] = [-0.026, -0.02, 0, -0.122, '#sad', '#disgusting', -0.043, 'launch', 'sink_ship', 'missile', 'drop_airplane', 'assault']
senticnet['rockfoil'] = [-0.855, 0, 0.795, -0.74, '#sad', '#angry', -0.797, 'herb', 'yellow_mountain_saxifrage', 'meadow_saxifrage', 'mossy_saxifrage', 'western_saxifrage']
senticnet['rockweed'] = [-0.896, 0, 0.556, -0.726, '#sad', '#disgusting', -0.726, 'fucus', 'bladderwrack', 'black_rockweed', 'bladder_fucus', 'tang']
senticnet['rocky_area'] = [0, 0.069, 0, 0.065, '#interesting', '#admirable', 0.045, 'canyon', 'high_mountain', 'alp', 'ski_resort', 'high_place']
senticnet['rod'] = [0.166, -0.112, 0.025, 0, '#joyful', '#surprising', 0.084, 'wand', 'metal_rod', 'bar', 'metal_stick', 'cue']
senticnet['rodent'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'flora', 'eukaryote', 'endangered_species', 'carbon_monoxide', 'tree_animal']
senticnet['rodeo'] = [0.858, 0.706, 0, 0, '#joyful', '#interesting', 0.521, 'carnival', 'circus', 'fairground', 'fair', 'disneyland']
senticnet['roe'] = [-0.747, 0, 0.748, -0.815, '#angry', '#disgusting', -0.77, 'coral', 'caviar', 'caviare', 'shad_roe', 'seafood']
senticnet['rogue'] = [0, 0, 0, -0.905, '#disgusting', '#disgusting', -0.302, 'traitor', 'seaman', 'officer', 'leader', 'master']
senticnet['rogue_gallery'] = [-0.96, 0, 0.581, -0.597, '#sad', '#disgusting', -0.713, 'camp', 'pack', 'clique', 'coterie', 'ingroup']
senticnet['roguery'] = [-0.901, 0, 0.757, -0.566, '#sad', '#angry', -0.741, 'misbehavior', 'misdeed', 'hell', 'vandalism', 'hooliganism']
senticnet['roister'] = [0.592, -0.929, 0, 0.703, '#surprising', '#admirable', 0.741, 'racket', 'revel', 'make_whoopie', 'make_merry', 'make_happy']
senticnet['role'] = [-0.829, 0, 0.958, -0.557, '#sad', '#angry', -0.781, 'character', 'baddie', 'theatrical_baddie', 'part', 'persona']
senticnet['role_model'] = [0.966, -0.669, 0, 0.578, '#joyful', '#surprising', 0.738, 'nonesuch', 'nonsuch', 'ideal', 'nonpareil', 'apotheosis']
senticnet['role_play'] = [0.854, 0.971, 0, 0, '#joyful', '#interesting', 0.608, 'stage_play', 'play_part', 'part_of_play', 'act_part', 'drama']
senticnet['role_player'] = [-0.921, 0, 0.54, -0.507, '#sad', '#angry', -0.656, 'beguiler', 'slicker', 'name_dropper', 'ringer', 'deceiver']
senticnet['roll'] = [0, -0.06, 0, 0.065, '#surprising', '#admirable', 0.042, 'doughnut', 'poppy_seed', 'custard', 'bread', 'biscuit']
senticnet['roll_away'] = [0.081, 0, 0, 0.065, '#joyful', '#admirable', 0.049, 'dribble', 'wind_up', 'bounce_up_down', 'go_game', 'break_window']
senticnet['roll_ball'] = [-0.172, 0, -0.078, -0.044, '#sad', '#scared', -0.098, 'trade_baseball_card', 'bicycle_school', 'ring_doorbell', 'laugh_clown', 'throw_fit']
senticnet['roll_dice'] = [0.832, -0.811, 0, 0, '#joyful', '#surprising', 0.548, 'try_win', 'loose', 'strategize', 'keep_score', 'win']
senticnet['roll_downhill'] = [-0.118, 0, -0.052, 0, '#sad', '#scared', -0.057, 'field_ball', 'spring_up', 'fall_well', 'shovel_snow', 'fly_around']
senticnet['roll_over'] = [-0.073, 0, -0.049, 0, '#sad', '#scared', -0.041, 'collide', 'fall_off_chair', 'feel_terrible', 'fly_around', 'cross_bridge']
senticnet['roll_up'] = [-0.593, 0, 0.604, -0.951, '#angry', '#disgusting', -0.716, 'pile_up', 'run_up', 'collect', 'accumulate', 'amass']
senticnet['roller'] = [-0.038, 0.077, 0.048, 0.091, '#interesting', '#admirable', 0.027, 'near_beach', 'along_beach', 'like_sea', 'near_sea', 'depth']
senticnet['roller-coaster'] = [0, 0, -0.898, -0.8, '#scared', '#disgusting', -0.566, 'ferris_wheel', 'carnival_ride', 'carny', 'merry_go_round', 'fortune_teller']
senticnet['roller_coaster'] = [0.05, -0.043, 0, 0, '#joyful', '#surprising', 0.031, 'have_fun', 'motorcycle', 'bike', 'sports_car', 'scooter']
senticnet['roller_coaster_ride'] = [0, 0, -0.883, -0.995, '#scared', '#disgusting', -0.626, 'amusement_park', 'have_fun', 'drag_race', 'pia_lot_of_seat', 'roller_coaster']
senticnet['roller_skate'] = [0.05, -0.043, 0, 0, '#joyful', '#surprising', 0.031, 'skate', 'rollerblade', 'skateboard', 'ice_skate', 'skating']
senticnet['rolling_mill'] = [0.692, -0.53, 0, 0.68, '#joyful', '#admirable', 0.634, 'steel_factory', 'factory', 'mill', 'manufacturing_plant', 'manufactory']
senticnet['rolling_stone'] = [0.241, 0.185, -0.114, 0.16, '#joyful', '#interesting', 0.157, 'eclectic', 'rock_group', 'musical_group', 'sound_nice', 'music_group']
senticnet['roman'] = [0, 0.123, 0, 0.156, '#interesting', '#admirable', 0.093, 'unity', 'country_person', 'domain', 'form_government', 'united_country']
senticnet['romance'] = [0.974, 0.789, 0, 0.828, '#joyful', '#admirable', 0.864, 'foreplay', 'comedian', 'express_love', 'cherish', 'happy_feeling']
senticnet['romance_novel'] = [0.832, 0, 0, 0.823, '#joyful', '#admirable', 0.552, 'biography', 'torah', 'literature', 'chapter', 'news_story']
senticnet['romantic'] = [0.99, 0.885, 0, 0.91, '#joyful', '#admirable', 0.928, 'serene', 'cool', 'easy', 'thrill', 'tranquility']
senticnet['romantic_atmosphere'] = [0, 0.232, -0.106, 0.156, '#interesting', '#admirable', 0.094, 'light', 'eat_cake', 'birthday_party', 'candle', 'candle_light']
senticnet['romantic_date'] = [0.076, 0.083, 0, -0.064, '#joyful', '#interesting', 0.032, 'trattoria', 'pizzeria', 'place_eat', 'restaurant_diner', 'eatery']
senticnet['romantic_dinner'] = [0.701, 0.8, 0, 0.762, '#interesting', '#admirable', 0.754, 'use_chair', 'weekend', 'go_sleep', 'miss_work', 'smoke_wee']
senticnet['romanticist'] = [0.899, -0.879, 0, 0.564, '#joyful', '#surprising', 0.781, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['romeo_and_juliet'] = [0.713, 0.825, 0, 0.907, '#interesting', '#admirable', 0.815, 'romance', 'love', 'love_story', 'get_rid_of_enemy', 'love_city']
senticnet['rookery'] = [-0.55, 0, 0.996, -0.506, '#sad', '#angry', -0.684, 'pesthole', 'breeding_ground', 'tract', 'piece_of_land', 'piece_of_ground']
senticnet['rookie'] = [-0.88, 0, 0.968, -0.783, '#sad', '#angry', -0.877, 'novice', 'beginner', 'tyro', 'tiro', 'initiate']
senticnet['room_part'] = [0.84, 0.914, 0, 0, '#joyful', '#interesting', 0.585, 'horizontal_plane', 'shut', 'part_of_room', 'build_part', 'rectangular_shape']
senticnet['room_temperature'] = [0, 0.103, 0, 0, '#interesting', '#interesting', 0.034, 'load_dock', 'car_race', 'sea_level', 'smithsonian', 'auction']
senticnet['root_climber'] = [0.518, -0.519, 0, 0.65, '#surprising', '#admirable', 0.562, 'clematis', 'legume', 'leguminous_plant', 'climbing_fern', 'climber']
senticnet['root_evil'] = [0, 0.196, 0.105, 0.167, '#interesting', '#admirable', 0.086, 'measure_unit', 'measure', 'total_number', 'count', 'spatial_dimension']
senticnet['root_on'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerfully', 'cheerful', 'jolly_up', 'hearten', 'chirk_up']
senticnet['root_vegetable'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'kind_food', 'legume', 'japanese_food', 'popular_food', 'food_item']
senticnet['rootage'] = [-0.996, 0, 0.835, -0.582, '#sad', '#angry', -0.804, 'beginning', 'origin', 'root', 'wellspring', 'source']
senticnet['rooter'] = [0.703, -0.513, 0, 0.811, '#joyful', '#admirable', 0.676, 'enthusiast', 'partizan', 'partisan', 'aficionado', 'railbird']
senticnet['rooter_skunk'] = [-0.547, 0, 0.768, -0.503, '#sad', '#angry', -0.606, 'striped_skunk', 'hooded_skunk', 'hognosed_skunk', 'badger_skunk', 'polecat']
senticnet['rope'] = [0, 0.142, 0, 0.125, '#interesting', '#admirable', 0.089, 'pulley', 'weight_machine', 'ice_skate', 'tie', 'cord']
senticnet['rosary'] = [0.021, 0.281, 0, 0.261, '#interesting', '#admirable', 0.188, 'cathedral', 'christianity', 'catholic_church', 'church', 'chapel']
senticnet['rosebud'] = [0.029, 0, 0, 0.05, '#joyful', '#admirable', 0.026, 'flower_type', 'rise_plant', 'symbol_love', 'sign_love', 'rose']
senticnet['roseola'] = [-0.951, 0, 0.783, -0.689, '#sad', '#angry', -0.808, 'hypersensitivity_reaction', 'rash', 'efflorescence', 'hives', 'skin_rash']
senticnet['rosette'] = [-0.699, 0, 0.776, -0.788, '#angry', '#disgusting', -0.754, 'little_potato', 'russet_scab', 'stem_canker', 'rhizoctinia_disease', 'plant_disease']
senticnet['rosilla'] = [-0.767, 0, 0.76, -0.669, '#sad', '#angry', -0.732, 'herb', 'autumn_sneezeweed', 'orange_sneezeweed', 'owlclaws', 'sneezeweed']
senticnet['rosita'] = [-0.902, 0, 0.726, -0.534, '#sad', '#angry', -0.721, 'broad_leaved_centaury', 'centaury', 'lesser_centaury', 'tufted_centaury', 'seaside_centaury']
senticnet['rosy'] = [0.953, 0, 0, 0.865, '#joyful', '#admirable', 0.606, 'fortunate', 'rose_colored', 'rose_cheeked', 'blushful', 'flushed']
senticnet['rot'] = [0, 0, -0.942, -0.966, '#scared', '#disgusting', -0.636, 'say_prayer', 'fall_off_chair', 'put_box', 'feel_terrible', 'lift_leg']
senticnet['rotary_file'] = [0, 0.091, 0, 0, '#interesting', '#interesting', 0.03, 'computer_disk', 'computer', 'general_ledger', 'cd-rom', 'personal_computer']
senticnet['rotary_phone'] = [0, 0.707, 0, 0.986, '#interesting', '#admirable', 0.564, 'loop', 'horse_shoes', 'ring', 'gray_hair', 'dartboard']
senticnet['rotate'] = [0.056, 0.104, 0, 0.231, '#interesting', '#admirable', 0.13, 'rotate_movement', 'change_direction', 'go_around', 'revolve', 'ninety_degree']
senticnet['rotate_movement'] = [0.037, 0.087, 0, 0.259, '#interesting', '#admirable', 0.128, 'rotate', 'circular_motion', 'revolve', 'go_around', 'manoeuvre']
senticnet['rotating'] = [0, 0, 0.855, -0.738, '#angry', '#disgusting', -0.531, 'circumvolve', 'turn_out', 'revolve', 'rotate', 'go_around']
senticnet['rotation'] = [0.942, 0.761, 0, 0, '#joyful', '#interesting', 0.568, 'full_circle', 'rotate', 'rotate_movement', 'spiral', 'twist']
senticnet['rote'] = [-0.062, 0.237, -0.062, 0.226, '#interesting', '#admirable', 0.113, 'recollection', 'imaginary', 'brain_function', 'think_process', 'recall']
senticnet['rotgut'] = [-0.91, 0, 0.79, -0.685, '#sad', '#angry', -0.795, 'intoxicant', 'alcohol', 'alcoholic_drink', 'alcoholic_beverage', 'inebriant']
senticnet['rotten'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'mouldy_bread', 'green_bread', 'disgusting', 'taste_awful', 'mouldy']
senticnet['rotten_food'] = [0, 0, -0.843, -0.901, '#scared', '#disgusting', -0.581, 'dynamite_explosion', 'fall_sky', 'sour_milk', 'firebomb', 'cleaver']
senticnet['rotten_fruit'] = [-0.232, -0.095, 0, -0.24, '#sad', '#disgusting', -0.126, 'moldy_bread', 'bathroom_wall', 'dirty_kitchen', 'rotten_tomato', 'fallen_tree']
senticnet['rotten_tomato'] = [-0.232, -0.095, 0, -0.24, '#sad', '#disgusting', -0.126, 'moldy_bread', 'bathroom_wall', 'dirty_kitchen', 'rotten_fruit', 'fallen_tree']
senticnet['rottenness'] = [-0.557, 0, 0.605, -0.551, '#sad', '#angry', -0.571, 'decay', 'putrescence', 'putrefaction', 'corruption', 'putridness']
senticnet['rotund'] = [-0.958, 0, -0.93, 0, '#sad', '#scared', -0.629, 'weighty', 'pear-shaped', 'corpulent', 'obese', 'round']
senticnet['rotundity'] = [-0.943, 0, 0.65, -0.578, '#sad', '#angry', -0.724, 'manner_of_speaking', 'undertone', 'note', 'roundness', 'tone_of_voice']
senticnet['rough'] = [-0.715, 0, 0.8, -0.693, '#sad', '#angry', -0.736, 'approximative', 'inexact', 'approximate', 'loose', 'odd']
senticnet['rough_game'] = [0, -0.091, 0.011, 0.089, '#surprising', '#admirable', 0.056, 'rough_sport', 'type_of_sport', 'ball_sport', 'contact_sport', 'team_sport']
senticnet['rough_road'] = [-0.956, 0, 0.159, -0.941, '#sad', '#disgusting', -0.685, 'road', 'narrow', 'poky', 'narrow_road', 'dark_road']
senticnet['rough_sport'] = [0, -0.085, 0, 0.086, '#surprising', '#admirable', 0.057, 'type_of_sport', 'rough_game', 'team_sport', 'violent_sport', 'ball_sport']
senticnet['roughhewn'] = [-0.805, 0, 0.677, -0.809, '#sad', '#disgusting', -0.764, 'unhewn', 'unfattened', 'undressed', 'unfinished', 'raw']
senticnet['roughish'] = [-0.774, 0, 0.626, -0.786, '#sad', '#disgusting', -0.729, 'bumpy', 'scabrous', 'lepidote', 'leprose', 'unsmooth']
senticnet['roughneck'] = [-0.92, 0, 0.804, -0.51, '#sad', '#angry', -0.745, 'bullyboy', 'muscleman', 'muscle', 'skinhead', 'skin']
senticnet['roughness'] = [-0.502, 0, 0.552, -0.932, '#angry', '#disgusting', -0.662, 'nubbiness', 'tweediness', 'harshness', 'graininess', 'granularity']
senticnet['roughshod'] = [-0.91, 0, 0.521, -0.811, '#sad', '#disgusting', -0.747, 'bullying', 'peremptory', 'blustery', 'domineering', 'cavalier']
senticnet['round'] = [0, 0.977, 0, 0.718, '#interesting', '#admirable', 0.565, 'fill_with_sand', 'seen_night_sky', 'circular', 'circle_shape', 'no_corner']
senticnet['round_ball'] = [0, 0.077, 0.039, 0.154, '#interesting', '#admirable', 0.064, 'marbles', 'round_figure', 'almond', 'dome', 'sphere']
senticnet['round_bread'] = [0.054, -0.013, 0.036, 0.132, '#joyful', '#admirable', 0.054, 'bakery_item', 'bun', 'bake_treat', 'bake_goods', 'breakfast_food']
senticnet['round_brush'] = [0, -0.069, 0.076, -0.135, '#angry', '#disgusting', -0.047, 'moistener', 'tartar_control_toothpaste', 'hair_brush', 'toothpaste', 'toilet_paper']
senticnet['round_circle'] = [0.806, 0, 0, 0.765, '#joyful', '#admirable', 0.524, 'duh', 'driven_person', 'secret_agent', 'pointer', 'make_gold']
senticnet['round_figure'] = [0, 0.077, 0.039, 0.154, '#interesting', '#admirable', 0.064, 'marbles', 'dome', 'almond', 'round_ball', 'sphere']
senticnet['round_flat'] = [0.17, 0, 0.081, 0.184, '#joyful', '#admirable', 0.091, 'food_holder', 'food_server', 'flat_object', 'flattery', 'flatter']
senticnet['round_fruit'] = [0.034, 0.067, 0.064, 0.106, '#interesting', '#admirable', 0.048, 'green_fruit', 'edible_human', 'crunchy', 'red_fruit', 'juicy']
senticnet['round_hand'] = [-0.958, 0, 0.517, -0.536, '#sad', '#disgusting', -0.67, 'copperplate', 'hand', 'minuscule', 'italic', 'cursive']
senticnet['round_metal'] = [0, 0.172, 0.034, 0.151, '#interesting', '#admirable', 0.096, 'dense_water', 'smooth_surface', 'nickel', 'head_tail', 'shinny']
senticnet['round_object'] = [0.849, 0, 0, 0.811, '#joyful', '#admirable', 0.553, 'orb', 'circular_object', 'circle_shape', 'spherical_shape', 'circular_shape']
senticnet['round_orb'] = [0, 0.784, 0, 0.834, '#interesting', '#admirable', 0.539, 'spherical', 'three_dimensions', 'round', 'seen_night_sky', 'fill_with_sand']
senticnet['round_pastry'] = [0.09, -0.016, 0.02, 0.112, '#joyful', '#admirable', 0.066, 'bake_good', 'bake_goods', 'bake_treat', 'bakery_item', 'cover_ice']
senticnet['round_shape'] = [0, 0.76, 0, 0.815, '#interesting', '#admirable', 0.525, 'circular_shape', 'no_corner', 'round', 'circular', 'circle_shape']
senticnet['round_top'] = [0, 0.978, 0, 0.775, '#interesting', '#admirable', 0.584, 'spherical', 'fill_with_sand', 'round', 'round_orb', 'round_shape']
senticnet['round_trip_ticket'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'thruway', 'national_interstate_highway', 'farecard', 'traffic_artery', 'move_sidewalk']
senticnet['round_white'] = [0.902, 0.749, 0, 0, '#joyful', '#interesting', 0.55, 'oval_shape', 'frustrate_person', 'oval', 'baby_chicken', 'round_flat']
senticnet['rounded'] = [0.969, -0.542, 0, 0.806, '#joyful', '#admirable', 0.772, 'aspheric', 'aspherical', 'prolate', 'auriform', 'crescent']
senticnet['roundworm'] = [-0.743, 0, 0.94, -0.875, '#angry', '#disgusting', -0.853, 'fungal_infection', 'mycosis', 'kerion', 'tinea_pedis', 'athlete_foot']
senticnet['routine'] = [0.69, -0.542, 0, 0.759, '#joyful', '#admirable', 0.664, 'rut', 'groove', 'rat_race', 'procedure', 'process']
senticnet['rove'] = [-0.86, 0, 0.974, -0.802, '#sad', '#angry', -0.879, 'gad', 'move', 'gallivant', 'jazz_around', 'travel']
senticnet['rover'] = [0.052, 0.119, 0, 0.141, '#interesting', '#admirable', 0.104, 'neigh', 'domestic_animal', 'animal_type', 'animal', 'home_animal']
senticnet['row'] = [-0.818, 0, 0.52, -0.875, '#sad', '#disgusting', -0.738, 'batrachomyomachia', 'wrangle', 'dustup', 'quarrel', 'affray']
senticnet['row_boat'] = [-0.109, 0.07, -0.06, -0.082, '#sad', '#disgusting', -0.06, 'board_ship', 'shore_boat', 'battle_cancer', 'pier', 'weather_storm']
senticnet['row_house'] = [0.051, 0.162, 0.026, 0, '#joyful', '#interesting', 0.062, 'circular_route', 'human_hair', 'semi-truck', 'expressway', 'park_structure']
senticnet['row_seat'] = [0.052, 0.119, 0, 0.141, '#interesting', '#admirable', 0.104, 'cinema', 'theater', 'seat', 'chair', 'lounge_chair']
senticnet['rowboat'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'boat', 'big_boat', 'ship', 'large_boat', 'paddle_boat']
senticnet['rowdy'] = [-0.813, 0, 0.912, -0.673, '#sad', '#angry', -0.799, 'bullyboy', 'muscleman', 'muscle', 'skinhead', 'skin']
senticnet['royal'] = [0.059, 0.076, -0.059, 0.079, '#interesting', '#admirable', 0.052, 'noble', 'king', 'earl', 'duchess', 'duke']
senticnet['royal_flush'] = [0, 0.921, 0, 0.853, '#interesting', '#admirable', 0.591, 'thesis', 'volume_control', 'book_genre', 'myth', 'classic']
senticnet['royal_leader'] = [0.052, 0.073, 0, 0.079, '#interesting', '#admirable', 0.068, 'emperor', 'monarch', 'duchess', 'king', 'despot']
senticnet['royal_person'] = [0.97, 0, 0, 0.815, '#joyful', '#admirable', 0.595, 'royal_title', 'regal', 'royalty', 'social_rank', 'royal_leader']
senticnet['royal_purple'] = [0.591, -0.553, 0, 0.514, '#joyful', '#surprising', 0.553, 'violet', 'mauve', 'lavender', 'reddish_purple', 'purple']
senticnet['royal_title'] = [0.817, 0, 0, 0.924, '#joyful', '#admirable', 0.58, 'royal_person', 'noble', 'king', 'duke', 'regal']
senticnet['royalty'] = [0.06, 0.111, -0.048, 0.135, '#interesting', '#admirable', 0.086, 'regal', 'royal_person', 'monarch', 'royal_leader', 'king_queen']
senticnet['rub'] = [0, 0.712, 0, 0.86, '#interesting', '#admirable', 0.524, 'shake', 'touch', 'multiple_purposes', 'wiggle', 'wrap_around']
senticnet['rub_along'] = [-0.548, 0, 0.967, -0.792, '#angry', '#disgusting', -0.769, 'manage', 'make_out', 'cope', 'get_by', 'make_do']
senticnet['rub_eye'] = [-0.14, 0.216, -0.069, 0.162, '#interesting', '#admirable', 0.056, 'give_signal', 'change_position', 'walk_around', 'perambulate', 'pull_out']
senticnet['rub_two_stick_together'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'cigarette_lighter', 'strike_match', 'light_cigarette', 'light_match', 'magnify_glass']
senticnet['rubber'] = [-0.881, 0, 0.75, -0.855, '#sad', '#disgusting', -0.829, 'overshoe', 'galosh', 'golosh', 'arctic', 'gumshoe']
senticnet['rubber_ball'] = [0.881, 0.993, 0, 0, '#joyful', '#interesting', 0.625, 'ball', 'fielder', 'yo-yo', 'toy_ball', 'toy_marble']
senticnet['rubber_band'] = [0.045, 0.143, -0.114, 0.212, '#interesting', '#admirable', 0.095, 'pair_of_scissors', 'safety_pin', 'adjustable_wrench', 'clothespin', 'clip']
senticnet['rubber_duck'] = [0.036, 0.084, 0, 0, '#joyful', '#interesting', 0.04, 'toy', 'bath_toy', 'yo-yo', 'toy_ball', 'duck']
senticnet['rubberneck'] = [-0.653, 0, 0.943, -0.756, '#angry', '#disgusting', -0.784, 'holidaymaker', 'sightseer', 'excursionist', 'tripper', 'traveler']
senticnet['rubbery'] = [-0.039, 0.114, 0, 0.243, '#interesting', '#admirable', 0.106, 'widen', 'elongate', 'elasticity', 'grow_long', 'elongation']
senticnet['rubbish'] = [-0.88, 0, 0.851, -0.904, '#sad', '#disgusting', -0.878, 'store_trash', 'hold_trash', 'put_garbage', 'put_trash', 'garbage']
senticnet['rubbish_dump'] = [-0.707, 0, 0.611, -0.695, '#sad', '#disgusting', -0.671, 'dump', 'garbage_dump', 'trash_dump', 'garbage_heap', 'wasteyard']
senticnet['rubbish_heap'] = [-0.963, 0, 0.987, -0.726, '#sad', '#angry', -0.892, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'wasteyard']
senticnet['rubbishy'] = [-0.784, 0, 0.651, -0.564, '#sad', '#angry', -0.666, 'worthless', 'sorry', 'trashy', 'otiose', 'superfluous']
senticnet['rubble'] = [0, 0, 0.892, -0.767, '#angry', '#disgusting', -0.553, 'american_flag', 'asphalt', 'pothole', 'pavement', 'pave']
senticnet['rube'] = [-0.967, 0, 0.924, -0.865, '#sad', '#angry', -0.919, 'redneck', 'yokel', 'rustic', 'hick', 'hayseed']
senticnet['rubor'] = [-0.535, 0, 0.882, -0.601, '#angry', '#disgusting', -0.673, 'blepharitis', 'diverticulitis', 'epiglottitis', 'orchitis', 'prostatitis']
senticnet['ruck_up'] = [-0.694, 0, 0.692, -0.662, '#sad', '#angry', -0.683, 'wrinkle', 'crinkle', 'crease', 'crisp', 'ruckle']
senticnet['ruckle'] = [-0.694, 0, 0.692, -0.662, '#sad', '#angry', -0.683, 'wrinkle', 'crinkle', 'crease', 'crisp', 'ruck_up']
senticnet['ruddy'] = [0, 0, -0.926, -0.963, '#scared', '#disgusting', -0.63, 'reddish', 'florid', 'sanguine', 'red', 'rubicund']
senticnet['rude'] = [-0.748, 0, 0.85, -0.915, '#angry', '#disgusting', -0.838, 'pulverize', 'bad_action', 'violent_action', 'mean', 'cruel']
senticnet['rude_answer'] = [-0.91, 0, 0.969, -0.91, '#sad', '#angry', -0.93, 'negative', 'rude_reply', 'negative_response', 'rude_person', 'rude_man']
senticnet['rude_man'] = [-0.919, 0, 0.833, -0.945, '#sad', '#disgusting', -0.899, 'curse_word', 'bad_word', 'rude', 'bad_communication', 'curse']
senticnet['rude_person'] = [-0.976, 0, 0.246, -0.901, '#sad', '#disgusting', -0.708, 'get_drunk', 'accident', 'drink_alcohol', 'break_it', 'alcohol']
senticnet['rude_reply'] = [-0.91, 0, 0.969, -0.91, '#sad', '#angry', -0.93, 'negative', 'negative_response', 'rude_answer', 'rude_person', 'rude_man']
senticnet['rudeness'] = [-0.718, 0, 0.742, -0.748, '#angry', '#disgusting', -0.736, 'hand', 'human_hand', 'tong', 'thumb', 'fist']
senticnet['rue'] = [-0.893, 0.167, -0.612, 0.051, '#sad', '#scared', -0.429, 'compunction', 'self-reproach', 'contriteness', 'contritely', 'contrition']
senticnet['rueful'] = [-0.884, 0.178, -0.6, 0, '#sad', '#scared', -0.435, 'contrite', 'remorseful', 'ruthful', 'bereaved', 'sorrowing']
senticnet['ruefully'] = [-0.891, 0.168, -0.609, 0.05, '#sad', '#scared', -0.427, 'remorsefully', 'contritely', 'contrition', 'contriteness', 'attrition']
senticnet['ruefulness'] = [-0.866, 0.2, -0.577, 0, '#sad', '#scared', -0.414, 'regretful', 'sorrowful', 'sadly', 'sorrowfully', 'doleful']
senticnet['ruff'] = [0.022, -0.117, 0.014, 0.057, '#surprising', '#admirable', 0.061, 'wood', 'many_steps', 'franchise', 'stump', 'timber']
senticnet['ruffian'] = [-0.794, 0, 0.765, -0.919, '#sad', '#disgusting', -0.826, 'bullyboy', 'muscleman', 'muscle', 'skinhead', 'skin']
senticnet['ruffle'] = [0.522, -0.824, 0, 0.568, '#surprising', '#admirable', 0.638, 'adornment', 'goffer', 'gauffer', 'jabot', 'peplum']
senticnet['rug'] = [0.971, 0.83, 0, 0, '#joyful', '#interesting', 0.6, 'carpet', 'floor', 'thick_hair', 'walk_closet', 'linoleum']
senticnet['rugby_field'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'sport_activity', 'football_field', 'field', 'play_football', 'play_sport']
senticnet['ruggedness'] = [-0.535, 0, 0.765, -0.942, '#angry', '#disgusting', -0.747, 'jaggedness', 'unregularity', 'unevenness', 'irregularity', 'patchiness']
senticnet['ruin'] = [-0.097, -0.019, 0, -0.069, '#sad', '#disgusting', -0.049, 'break', 'smash', 'raze', 'wreck', 'damage']
senticnet['ruination'] = [-0.874, 0, 0.889, -0.621, '#sad', '#angry', -0.795, 'devastation', 'ruin', 'deterioration', 'blight', 'impairment']
senticnet['ruined_dinner'] = [-0.981, 0, 0.458, -0.947, '#sad', '#disgusting', -0.795, 'fire', 'ruined_meal', 'burn_food', 'ruined_lunch', 'waste_food']
senticnet['ruined_lunch'] = [-0.981, 0, 0.458, -0.947, '#sad', '#disgusting', -0.795, 'fire', 'ruined_meal', 'ruined_dinner', 'burn_food', 'waste_food']
senticnet['ruined_meal'] = [-0.981, 0, 0.458, -0.947, '#sad', '#disgusting', -0.795, 'fire', 'burn_food', 'ruined_dinner', 'ruined_lunch', 'waste_food']
senticnet['ruiner'] = [-0.583, 0, 0.714, -0.612, '#angry', '#disgusting', -0.636, 'waster', 'sleeper', 'destroyer', 'diversionist', 'undoer']
senticnet['rule'] = [0, 0.113, 0, 0.105, '#interesting', '#admirable', 0.073, 'regulation', 'edict', 'law', 'legislation', 'march_rear']
senticnet['rule_country'] = [-0.044, 0.15, 0, 0.062, '#interesting', '#admirable', 0.056, 'rule_nation', 'reign', 'protect_king', 'rule_government', 'world_domination']
senticnet['rule_government'] = [0, 0, -0.948, -0.715, '#scared', '#disgusting', -0.554, 'kingdom', 'dynasty', 'aboriginal', 'queen_of_england', 'imperial']
senticnet['rule_nation'] = [-0.044, 0.15, 0, 0.062, '#interesting', '#admirable', 0.056, 'rule_country', 'reign', 'protect_king', 'rule_government', 'world_domination']
senticnet['rule_world'] = [0, 0.964, 0, 0.724, '#interesting', '#admirable', 0.563, 'desire_win', 'try_forget', 'experience_life', 'experience_joy', 'raise_money']
senticnet['rum'] = [-0.044, 0.15, 0, 0.062, '#interesting', '#admirable', 0.056, 'brandy', 'scotch', 'vodka', 'bourbon', 'whisky']
senticnet['rumble'] = [-0.941, -0.913, -0.971, -0.813, '#sad', '#scared', -0.604, 'explosion', 'dynamite_explosion', 'bright_flash', 'disaster', 'earthquake']
senticnet['ruminate'] = [-0.985, 0, -0.938, 0, '#sad', '#scared', -0.641, 'think_over', 'chew_over', 'ponder', 'meditate', 'excogitate']
senticnet['rumination'] = [0.937, -0.939, 0, 0.933, '#joyful', '#surprising', 0.936, 'consideration', 'introspection', 'cogitation', 'study', 'speculation']
senticnet['ruminative'] = [0.841, 0.854, 0, 0, '#joyful', '#interesting', 0.565, 'pondering', 'broody', 'contemplative', 'meditative', 'think']
senticnet['rummage'] = [-0.855, 0, 0.583, -0.716, '#sad', '#disgusting', -0.718, 'muddle', 'fuddle', 'mare_nest', 'welter', 'clutter']
senticnet['rummy'] = [0.556, -0.791, 0, 0.755, '#surprising', '#admirable', 0.701, 'lush', 'alcoholic', 'alky', 'dipsomaniac', 'boozer']
senticnet['rumormonger'] = [-0.804, 0, 0.56, -0.608, '#sad', '#disgusting', -0.657, 'gossip', 'gossiper', 'gossipmonger', 'talk_too_much', 'blabbermouth']
senticnet['run_afoul'] = [-0.619, 0, 0.716, -0.822, '#angry', '#disgusting', -0.719, 'offend', 'violate', 'go_against', 'break', 'transgress']
senticnet['run_after_ball'] = [0, 0, 0, -0.783, '#disgusting', '#disgusting', -0.261, 'bungee_jump_from_high_bridge', 'asthma_attack', 'shout_top_voice', 'high_blood_pressure', 'go_gym']
senticnet['run_around'] = [0.708, 0.906, 0, 0, '#joyful', '#interesting', 0.538, 'field_ball', 'roll_downhill', 'like_play_game', 'drive_crazy', 'like_boy']
senticnet['run_away'] = [-0.961, 0, -0.844, 0, '#sad', '#scared', -0.602, 'jump', 'jump_over', 'hide_body', 'hurry_along', 'think_food']
senticnet['run_basis'] = [0.213, 0, 0, 0, '#joyful', '#joyful', 0.071, 'hit_ball_hard', 'step_up_plate', 'team_win', 'swing_bat', 'break_record']
senticnet['run_bath'] = [-0.074, 0, 0.026, 0, '#sad', '#angry', -0.033, 'soap_up', 'turn_water', 'fill_bathtub', 'dispense_water', 'launder']
senticnet['run_business'] = [0.373, 0.185, -0.074, 0.374, '#joyful', '#admirable', 0.286, 'complement', 'world_peace', 'good_sense_of_humor', 'strong_relationship', 'taken_seriously']
senticnet['run_car'] = [0, 0.818, 0, 0.746, '#interesting', '#admirable', 0.521, 'car_bus', 'make_go', 'vehicle', 'car_engine', 'car_steer']
senticnet['run_errand'] = [-0.924, 0, -0.763, 0, '#sad', '#scared', -0.562, 'waste_time', 'lost', 'scared', 'go_nowhere', 'anxious']
senticnet['run_event'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'encounter', 'finish_line', 'run_fast', 'gone', 'race']
senticnet['run_far'] = [-0.824, 0, -0.763, 0, '#sad', '#scared', -0.529, 'scare', 'terrify', 'fear', 'terror', 'run_away']
senticnet['run_fast'] = [0.853, 0, 0, 0.973, '#joyful', '#admirable', 0.609, 'sporty_guy', 'train_daily', 'run_lot', 'train_muscle', 'exercise']
senticnet['run_first_base'] = [0.047, 0, 0, 0.132, '#joyful', '#admirable', 0.06, 'strike_out', 'score_point', 'minor_injury', 'throw_ball', 'loose']
senticnet['run_into'] = [-0.536, 0, 0.57, -0.732, '#angry', '#disgusting', -0.613, 'bump_into', 'strike', 'hit', 'impinge_on', 'collide_with']
senticnet['run_into_difficulty'] = [-0.923, 0, 0.429, -0.924, '#sad', '#disgusting', -0.759, 'difficult', 'stress', 'anxiety', 'danger', 'dangerous']
senticnet['run_long_distance'] = [-0.857, 0, -0.719, -0.865, '#sad', '#disgusting', -0.814, 'get_exercise', 'train_marathon', 'run_marathon', 'high_blood_pressure', 'go_gym']
senticnet['run_long_time'] = [-0.065, -0.027, 0.021, -0.06, '#sad', '#disgusting', -0.04, 'clean_window', 'vacuum_carpet', 'repetitive_task', 'regular_exercise', 'exercise_daily']
senticnet['run_lot'] = [0.11, 0, 0, 0.095, '#joyful', '#admirable', 0.068, 'play_fetch', 'ride_car', 'chew_bone', 'play_human', 'run']
senticnet['run_marathon'] = [0.808, 0, 0, 0.704, '#joyful', '#admirable', 0.504, 'take_hike', 'like_play_game', 'burn_fat', 'eat_healthy_diet', 'gather_berry']
senticnet['run_office'] = [0.571, 0.573, 0, 0.774, '#interesting', '#admirable', 0.639, 'better_world', 'make_enemy', 'find_enemy', 'disagreement', 'religious_experience']
senticnet['run_out'] = [-0.987, 0, 0.989, -0.933, '#sad', '#angry', -0.97, 'run_out_of_time', 'run_out_of_money', 'lack_of_food', 'almost_finish', 'low_battery']
senticnet['run_out_booze'] = [-0.055, -0.054, 0, -0.163, '#sad', '#disgusting', -0.055, 'forgetfulness', 'stagger', 'slur_word', 'pass_out', 'loss_ofawareness']
senticnet['run_out_breath'] = [-0.999, 0, 0, -0.707, '#sad', '#disgusting', -0.569, 'breaheavily', 'get_out_breath', 'get_exhausted', 'heavy_breathe', 'become_wind']
senticnet['run_out_fuel'] = [0.907, 0.844, 0, 0, '#joyful', '#interesting', 0.584, 'first_class', 'shopping', 'travel_across_world', 'spending', 'cost_money']
senticnet['run_out_gas'] = [0, 0, -0.943, -0.77, '#scared', '#disgusting', -0.571, 'stop_red_light', 'shift_gear', 'arrive_destination', 'use_gas', 'hit_tree']
senticnet['run_out_ink'] = [0.798, 0.938, 0, 0, '#joyful', '#interesting', 0.579, 'proofread', 'think_write', 'use_word', 'learn_write', 'pick_up_pen']
senticnet['run_out_money'] = [-0.742, 0, -0.784, 0, '#sad', '#scared', -0.509, 'compare_price', 'bankruptcy', 'spend_much_money', 'comparison_shop', 'make_payment']
senticnet['run_out_of_money'] = [-0.987, 0, 0.989, -0.933, '#sad', '#angry', -0.97, 'run_out_of_time', 'almost_finish', 'lack_of_food', 'run_out', 'low_battery']
senticnet['run_out_of_patience'] = [0, 0.084, 0, 0.074, '#interesting', '#admirable', 0.053, 'constant', 'time', 'time_frame', 'short_time', 'time_description']
senticnet['run_out_of_time'] = [-0.987, 0, 0.989, -0.933, '#sad', '#angry', -0.97, 'almost_finish', 'run_out_of_money', 'lack_of_food', 'run_out', 'low_battery']
senticnet['run_out_paper'] = [-0.929, 0, 0.834, 0, '#sad', '#angry', -0.588, 'write_down', 'copyright', 'write_word', 'write_essay', 'realization']
senticnet['run_out_soap'] = [0, 0, 0.883, -0.767, '#angry', '#disgusting', -0.55, 'shower', 'rain', 'wash_away_dirt', 'wet_clothes', 'become_wet']
senticnet['run_out_time'] = [-0.731, 0, -0.806, 0, '#sad', '#scared', -0.512, 'win', 'strategize', 'lose', 'cost_fortune', 'loss']
senticnet['run_over_car'] = [-0.32, -0.068, 0, -0.213, '#sad', '#disgusting', -0.155, 'step_dog_poop', 'eaten_shark', 'cause_suffer', 'lose_team', 'leave_out']
senticnet['run_place'] = [-0.058, 0, 0.023, -0.049, '#sad', '#disgusting', -0.043, 'track', 'run_event', 'run', 'course', 'racetrack']
senticnet['run_president'] = [0, 0.796, 0, 0.983, '#interesting', '#admirable', 0.593, 'tell_lie', 'obey_law', 'state_opinion', 'settle_argument', 'fee_cat']
senticnet['run_quickly'] = [0.753, -0.892, 0, 0, '#joyful', '#surprising', 0.548, 'run_fast', 'chase_ball', 'run_out_breath', 'breath_heavily', 'wear_comfortable_clothes']
senticnet['run_race'] = [-0.067, -0.024, 0.035, 0, '#sad', '#angry', -0.026, 'race_other', 'run_long_distance', 'put_tennis_shoes', 'break_record', 'stretch_first']
senticnet['run_risk'] = [0.893, -0.606, 0, 0.758, '#joyful', '#admirable', 0.752, 'try', 'assay', 'essay', 'go_for_broke', 'luck_it']
senticnet['run_slowly'] = [-0.092, 0.104, 0, 0.099, '#interesting', '#admirable', 0.037, 'use_leg', 'take_step', 'wear_running_shoes', 'wear_good_shoes', 'act_quickly']
senticnet['run_too_fast'] = [0, 0, 0.933, -0.863, '#angry', '#disgusting', -0.599, 'feel_out_of_breath', 'muscle_cramp', 'throat_injury', 'breath_difficulty', 'epileptic_seizures']
senticnet['run_treadmill'] = [0, 0, 0, 0.072, '#admirable', '#admirable', 0.024, 'bluetooth', 'complete_thesis', 'dwarf_planet', 'insure', 'ridgeback']
senticnet['run_up'] = [-0.593, 0, 0.604, -0.951, '#angry', '#disgusting', -0.716, 'pile_up', 'roll_up', 'collect', 'accumulate', 'amass']
senticnet['run_water'] = [0, 0, 0, 0.093, '#admirable', '#admirable', 0.031, 'flowing_water', 'water_flow', 'ebb', 'water_movement', 'small_stream']
senticnet['runner'] = [-0.511, 0, 0.667, -0.65, '#angry', '#disgusting', -0.609, 'criminal', 'outlaw', 'malefactor', 'felon', 'crook']
senticnet['running_blackberry'] = [-0.922, 0, 0.912, -0.942, '#sad', '#disgusting', -0.925, 'true_blackberry', 'sand_blackberry', 'dewberry', 'dewberry_bush', 'blackberry_bush']
senticnet['running_hand'] = [-0.637, 0, 0.7, -0.901, '#angry', '#disgusting', -0.746, 'copperplate', 'hand', 'minuscule', 'italic', 'round_hand']
senticnet['running_shoes'] = [0, 0, 0, 0.093, '#admirable', '#admirable', 0.031, 'wear_shoes', 'wear_running_shoes', 'put_shoes', 'shoe', 'sport']
senticnet['running_suit'] = [-0.76, 0, 0.58, -0.507, '#sad', '#angry', -0.616, 'attire', 'garb', 'dress', 'gym_suit', 'activewear']
senticnet['running_water'] = [0, 0.082, 0, 0.214, '#interesting', '#admirable', 0.099, 'water_motion', 'water_movement', 'arm_movement', 'water_relate', 'water_action']
senticnet['runny_nose'] = [-0.063, 0.183, 0.651, -0.642, '#angry', '#disgusting', -0.391, 'allergic_reaction', 'chew', 'pierce', 'mastication', 'put_mouth']
senticnet['runtime_error'] = [-0.985, 0, 0.869, -0.803, '#sad', '#angry', -0.886, 'error', 'syntax_error', 'semantic_error', 'programming_error', 'computer_error']
senticnet['rupture'] = [-0.576, 0, 0.852, -0.745, '#angry', '#disgusting', -0.724, 'tease', 'bust', 'tear', 'rip_up', 'snap']
senticnet['rupturewort'] = [-0.725, 0, 0.64, -0.585, '#sad', '#angry', -0.65, 'pearlwort', 'pearlweed', 'flora', 'groundcover', 'whitlowwort']
senticnet['rural_area'] = [0.038, 0.079, 0.03, 0.083, '#interesting', '#admirable', 0.057, 'hat', 'country_side', 'large_area', 'big_hat', 'farm_area']
senticnet['ruralism'] = [0.563, -0.728, 0, 0.644, '#surprising', '#admirable', 0.645, 'idiom', 'idiomatic_expression', 'phrasal_idiom', 'set_phrase', 'phrase']
senticnet['rush'] = [-0.884, 0.178, -0.6, 0, '#sad', '#scared', -0.435, 'rush_job', 'rush_work', 'late', 'urgency', 'emergency']
senticnet['rush_job'] = [0, 0, 0, -0.963, '#disgusting', '#disgusting', -0.321, 'stand_alone', 'deal_card_player', 'forward_email', 'explain_everything', 'position_furniture']
senticnet['rush_work'] = [-0.08, -0.01, 0, -0.043, '#sad', '#disgusting', -0.038, 'push_limit', 'fly_plane', 'plan_day', 'start_car', 'travel_work']
senticnet['rushy'] = [-0.863, 0, 0.665, -0.616, '#sad', '#angry', -0.715, 'brambly', 'braky', 'wooded', 'scrubby', 'forested']
senticnet['russet_scab'] = [-0.699, 0, 0.776, -0.788, '#angry', '#disgusting', -0.754, 'little_potato', 'rhizoctinia_disease', 'stem_canker', 'rosette', 'plant_disease']
senticnet['rust_fungus'] = [-0.512, 0, 0.781, -0.851, '#angry', '#disgusting', -0.715, 'flax_rust', 'flax_rust_fungus', 'blister_rust', 'apple_rust', 'fungus']
senticnet['rustic'] = [-0.967, 0, 0.924, -0.865, '#sad', '#angry', -0.919, 'redneck', 'yokel', 'rube', 'hick', 'hayseed']
senticnet['rusticate'] = [-0.88, 0, 0.903, -0.504, '#sad', '#angry', -0.762, 'send_down', 'debar', 'expel', 'throw_out', 'kick_out']
senticnet['rustling'] = [0.937, -0.672, 0, 0.628, '#joyful', '#surprising', 0.746, 'thieving', 'larceny', 'theft', 'thievery', 'stealing']
senticnet['rusty_metal'] = [0, 0, 0, 0.089, '#admirable', '#admirable', 0.03, 'foil', 'lightweight_metal', 'make_out_metal', 'metal_type', 'metallic_element']
senticnet['rut'] = [-0.052, -0.006, 0, -0.08, '#sad', '#disgusting', -0.042, 'ass', 'butt', 'foreign_country', 'dog_show', 'asshole']
senticnet['ruth'] = [-0.928, 0, 0, -0.987, '#sad', '#disgusting', -0.638, 'sympathize', 'commiserate', 'commiseration', 'feel_sorry', 'pathos']
senticnet['ruthful'] = [-0.884, 0.178, -0.6, 0, '#sad', '#scared', -0.435, 'contrite', 'remorseful', 'rueful', 'bereaved', 'sorrowing']
senticnet['ruthfulness'] = [-0.894, 0.16, -0.612, 0.055, '#sad', '#scared', -0.43, 'mournfully', 'sorrowfulness', 'mournfulness', 'heartrending', 'heartbreaking']
senticnet['ruthlessness'] = [-0.71, 0, 0.795, 0, '#sad', '#angry', -0.502, 'mercilessness', 'unkind', 'cruelly', 'pitilessness', 'unassertively']
senticnet['rye_bread'] = [0.52, -0.693, 0, 0.639, '#surprising', '#admirable', 0.617, 'black_bread', 'pumpernickel', 'limpa', 'bread', 'breadstuff']
senticnet['saboteur'] = [-0.695, 0, 0.756, -0.991, '#angry', '#disgusting', -0.814, 'waster', 'sleeper', 'destroyer', 'ruiner', 'undoer']
senticnet['sac'] = [-0.987, 0, -0.753, 0, '#sad', '#scared', -0.58, 'money_transfer', 'business', 'income', 'finance', 'revenue']
senticnet['sachet'] = [0, -0.076, 0.109, -0.097, '#angry', '#disgusting', -0.043, 'prescription_medication', 'pantyhose', 'underwear', 'lingerie', 'shave_kit']
senticnet['sacking'] = [0.572, -0.716, 0, 0.895, '#surprising', '#admirable', 0.728, 'material', 'burlap', 'gunny', 'fabric', 'cloth']
senticnet['sacred'] = [0.041, 0.2, -0.063, 0.247, '#interesting', '#admirable', 0.142, 'vital', 'homophobic', 'good', 'general_term', 'nice']
senticnet['sacred_ibis'] = [0.797, -0.719, 0, 0.736, '#joyful', '#admirable', 0.751, 'wood_ibis', 'wood_stork', 'ibis', 'wading_bird', 'wader']
senticnet['sacrifice'] = [-0.1, 0.304, -0.212, 0.278, '#interesting', '#admirable', 0.09, 'play_blackjack', 'play_game_chess', 'play_chess', 'wish', 'play_checker']
senticnet['sad'] = [-0.919, 0, 0, 0, '#sad', '#sad', -0.306, 'unhappiness', 'misery', 'melancholy', 'depression', 'sorrow']
senticnet['sad_movie'] = [-0.059, 0, -0.071, 0, '#sad', '#scared', -0.043, 'cry', 'chop_onion', 'watch_sad_film', 'see_sad_show', 'see_chop_onion']
senticnet['sad_person'] = [-0.092, -0.027, -0.113, -0.228, '#scared', '#disgusting', -0.135, 'good_man', 'medic', 'felon', 'demon', 'buy_weapon']
senticnet['sadden'] = [-0.958, 0, 0, 0, '#sad', '#sad', -0.319, 'unhappy', 'dysphoric', 'forlornly', 'desolation', 'forlornness']
senticnet['sadly'] = [-0.862, 0.2, -0.57, 0, '#sad', '#scared', -0.411, 'ruefulness', 'doleful', 'regretful', 'sorrowful', 'sorrowfully']
senticnet['sadness'] = [-0.6, 0, 0, 0, '#sad', '#sad', -0.2, 'depression', 'deep_sadness', 'lament', 'feel_sorry', 'feeling_guilt']
senticnet['safe'] = [0.033, 0.186, 0, 0, '#joyful', '#interesting', 0.073, 'bank', 'bank_vault', 'wallet', 'government_agreement', 'coffer']
senticnet['safe_belt'] = [-0.732, 0, -0.977, 0, '#sad', '#scared', -0.57, 'brake_pedal', 'emergency_brake', 'stop', 'avoid_accident', 'brake']
senticnet['safe_deposit_box'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'slot', 'box', 'load_dock', 'diskette', 'emporium']
senticnet['safe_place'] = [0.122, 0.274, -0.064, 0.226, '#interesting', '#admirable', 0.186, 'stronghold', 'family_live', 'domestic_dwell', 'line_place', 'fortification']
senticnet['safe_sex'] = [0.944, 0.956, 0, 0, '#joyful', '#interesting', 0.633, 'sex', 'contraception', 'sexual_intercourse', 'fuck', 'become_aroused']
senticnet['safe_zone'] = [0.069, 0.152, 0, 0.088, '#interesting', '#admirable', 0.103, 'security', 'metal_detector', 'security_airport', 'security_area', 'security_system']
senticnet['safekeep'] = [0.025, 0.27, -0.119, 0.243, '#interesting', '#admirable', 0.14, 'keep_safe', 'store_dry_goods', 'store_stuff', 'secure', 'save']
senticnet['safety'] = [0.082, 0.319, -0.108, 0.147, '#interesting', '#admirable', 0.147, 'protect', 'defend', 'secure', 'guard', 'watch_over']
senticnet['safety_belt'] = [0.722, 0.865, 0, 0.748, '#interesting', '#admirable', 0.778, 'safety', 'traffic_light', 'slow_speed', 'avoid_crash', 'car']
senticnet['safety_cap'] = [-0.898, 0, -0.791, 0, '#sad', '#scared', -0.563, 'protect_head', 'helmet', 'keep_hair_place', 'cover_head', 'shade_eye']
senticnet['safety_device'] = [0.045, 0.143, -0.114, 0.212, '#interesting', '#admirable', 0.095, 'battery', 'remove_screw', 'hand_hold', 'gas_oil', 'hyper']
senticnet['safety_equipment'] = [0.044, -0.033, 0.037, 0.089, '#joyful', '#admirable', 0.043, 'lifebelt', 'save_life', 'lifeguard', 'life_jacket', 'life_preserver']
senticnet['safety_pin'] = [0.045, 0.143, -0.114, 0.212, '#interesting', '#admirable', 0.095, 'pair_of_scissors', 'rubber_band', 'adjustable_wrench', 'clothespin', 'clip']
senticnet['saga'] = [0.036, 0.219, 0, 0.19, '#interesting', '#admirable', 0.148, 'story', 'long_story', 'novel', 'fable', 'fiction']
senticnet['sagaciousness'] = [0.538, -0.511, 0, 0.872, '#joyful', '#admirable', 0.64, 'indiscreetness', 'judiciousness', 'injudiciousness', 'common_sense', 'good_sense']
senticnet['sagacity'] = [0.675, -0.719, 0, 0.987, '#surprising', '#admirable', 0.794, 'indiscreetness', 'judiciousness', 'injudiciousness', 'common_sense', 'good_sense']
senticnet['sagebrush_buttercup'] = [-0.793, 0, 0.837, -0.886, '#angry', '#disgusting', -0.839, 'sunray', 'wilding', 'wildflower', 'pasqueflower', 'pasque_flower']
senticnet['sail_around_world'] = [0.997, 0.755, 0, 0, '#joyful', '#interesting', 0.584, 'storm_out_room', 'voice_concern', 'forward_email', 'age_gracefully', 'bicycle_across_town']
senticnet['sail_ocean'] = [-0.036, 0.111, -0.061, 0.084, '#interesting', '#admirable', 0.033, 'carry_liquid', 'travel_over_water', 'transport_goods', 'carry_blood', 'cross_ocean']
senticnet['sail_out'] = [-0.05, 0.079, 0, 0.118, '#interesting', '#admirable', 0.049, 'deep_blue', 'water', 'sail', 'sea', 'full_water']
senticnet['sail_sailboat'] = [-0.086, 0, -0.068, -0.072, '#sad', '#disgusting', -0.075, 'kill_specific_group', 'hurt_animal', 'die_only_once', 'dig_grave', 'wave_flag']
senticnet['sail_sea'] = [0.051, 0.074, 0.049, 0.128, '#interesting', '#admirable', 0.068, 'stalin', 'water_transportation', 'power_gasoline', 'water_transport', 'travel_over_water']
senticnet['sail_ship'] = [-0.048, -0.01, 0, -0.068, '#sad', '#disgusting', -0.035, 'sailboat', 'fish_boat', 'battleship', 'oil_tanker', 'lifeboat']
senticnet['sailboat'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'ship', 'boat', 'yacht', 'big_boat', 'large_boat']
senticnet['sailor'] = [0, 0, 0, -0.074, '#disgusting', '#disgusting', -0.025, 'army_man', 'army_person', 'fighter', 'man', 'workman']
senticnet['saint'] = [0, 0.248, -0.083, 0.173, '#interesting', '#admirable', 0.113, 'god', 'minister', 'evangelist', 'rector', 'goddess']
senticnet['salacious'] = [0, 0, -0.916, -0.861, '#scared', '#disgusting', -0.592, 'lubricious', 'lewd', 'lustful', 'obscene', 'prurient']
senticnet['salad_bar'] = [0, 0.074, 0, 0.071, '#interesting', '#admirable', 0.048, 'grocery_cart', 'super_market', 'fruit_stand', 'candy_store', 'produce_store']
senticnet['salad_bowl'] = [0, 0, 0.066, -0.077, '#angry', '#disgusting', -0.048, 'container_cup', 'cup', 'grease_trap', 'dish', 'open_container']
senticnet['salad_dress'] = [0.046, -0.025, 0, 0, '#joyful', '#surprising', 0.024, 'dairy', 'milk_product', 'horse_farm', 'food_production', 'farm']
senticnet['salad_green'] = [0.636, -0.796, 0, 0.552, '#joyful', '#surprising', 0.661, 'lettuce', 'endive', 'green', 'curly_endive', 'food']
senticnet['salad_shaker'] = [0.053, -0.067, 0, 0, '#joyful', '#surprising', 0.04, 'blender', 'store_shelf', 'kitchen_tool', 'pliers', 'ladle']
senticnet['salary'] = [-0.044, 0.282, -0.087, 0.137, '#interesting', '#admirable', 0.096, 'wage', 'earn', 'earnings', 'income', 'money']
senticnet['sale'] = [-0.032, 0.268, -0.061, 0.178, '#interesting', '#admirable', 0.118, 'bargain', 'cheap_price', 'clearance', 'good_buy', 'afford']
senticnet['sale_in_gross'] = [0.865, -0.844, 0, 0.915, '#joyful', '#admirable', 0.875, 'grant', 'contract', 'contract_of_hazard', 'adhesion_contract', 'contract_of_adhesion']
senticnet['sale_price'] = [-0.04, 0.313, -0.05, 0.188, '#interesting', '#admirable', 0.137, 'amount_pay', 'monetary', 'amount_due', 'account_term', 'payment_amount']
senticnet['salinity'] = [-0.647, 0, 0.64, -0.737, '#sad', '#disgusting', -0.675, 'taste', 'taste_sensation', 'gustatory_sensation', 'taste_perception', 'gustatory_perception']
senticnet['salivation'] = [-0.058, 0, 0.01, -0.089, '#sad', '#disgusting', -0.052, 'loss_ofmoney', 'world_hunger', 'no_long_hungry', 'salivate', 'buy_steak']
senticnet['sally_forth'] = [-0.681, 0, 0.967, -0.657, '#sad', '#angry', -0.768, 'depart', 'start', 'part', 'start_out', 'set_forth']
senticnet['sally_out'] = [-0.589, 0, 0.694, -0.874, '#angry', '#disgusting', -0.719, 'depart', 'start', 'part', 'start_out', 'set_forth']
senticnet['salmon'] = [0.029, -0.049, 0, 0, '#joyful', '#surprising', 0.026, 'bagel', 'muffin', 'pie', 'cookie', 'toast']
senticnet['salmonid'] = [-0.861, 0, 0.941, -0.713, '#sad', '#angry', -0.838, 'salmon', 'trout', 'go_fishing', 'fish', 'catch_fish']
senticnet['salon'] = [-0.024, 0.122, 0, 0.137, '#interesting', '#admirable', 0.078, 'beauty_salon', 'barber_shop', 'barbershop', 'hair_salon', 'beauty_shop']
senticnet['saloon'] = [-0.769, 0, 0.75, -0.563, '#sad', '#angry', -0.694, 'public_house', 'pub', 'free_house', 'pothouse', 'gin_mill']
senticnet['salsa'] = [0.116, -0.028, 0.025, 0.156, '#joyful', '#admirable', 0.092, 'dance_move', 'latin_dance', 'body_movement', 'waltz', 'dance']
senticnet['salt_food'] = [-0.083, 0, 0, 0, '#sad', '#sad', -0.028, 'bone_chicken', 'unhealthy', 'brown_hamburger', 'play_jack', 'heat_meal']
senticnet['salt_pepper_shaker'] = [0.828, 0, 0, 0.739, '#joyful', '#admirable', 0.522, 'entree', 'soup', 'wine_glass', 'satiation', 'plate_silverware']
senticnet['salt_shaker'] = [0.062, -0.017, 0, 0, '#joyful', '#surprising', 0.026, 'hostess', 'bottle_wine', 'human_intelligence', 'patron', 'table_chair']
senticnet['saltine'] = [-0.955, 0, 0.762, -0.648, '#sad', '#angry', -0.788, 'cracker', 'soda_cracker', 'oyster_cracker', 'water_biscuit', 'graham_cracker']
senticnet['saltwater'] = [0, 0, -0.065, -0.036, '#scared', '#disgusting', -0.034, 'tidal_pool', 'coral_reef', 'fish_market', 'sea', 'reef']
senticnet['salty'] = [-0.051, 0.07, 0, 0.062, '#interesting', '#admirable', 0.027, 'fine_grain', 'grainy', 'powder', 'granulate', 'food_flavor']
senticnet['salutation'] = [0.873, 0, 0, 0.99, '#joyful', '#admirable', 0.621, 'welcome', 'aye', 'present', 'invitation', 'gift']
senticnet['salvager'] = [-0.736, 0, 0.822, -0.732, '#sad', '#angry', -0.763, 'succorer', 'succourer', 'recoverer', 'salvor', 'mortal']
senticnet['salvation'] = [0.05, 0.363, -0.091, 0.307, '#interesting', '#admirable', 0.21, 'faith', 'christ', 'prayer', 'spiritual', 'religious_purpose']
senticnet['salve'] = [-0.644, 0, 0.941, -0.923, '#angry', '#disgusting', -0.836, 'unction', 'carron_oil', 'ointment', 'unguent', 'balm']
senticnet['salvor'] = [-0.736, 0, 0.822, -0.732, '#sad', '#angry', -0.763, 'succorer', 'succourer', 'salvager', 'recoverer', 'mortal']
senticnet['same_again'] = [-0.034, 0.099, 0.034, 0.116, '#interesting', '#admirable', 0.049, 'brown', 'beautiful_well_useful', 'nocturnal', 'cute', 'small']
senticnet['same_answer'] = [-0.928, 0, 0.968, 0, '#sad', '#angry', -0.632, 'soft', 'biodegradable', 'repetitive', 'organic', 'animal_product']
senticnet['same_before'] = [0, 0.135, 0, 0.219, '#interesting', '#admirable', 0.118, 'same', 'precision', 'all_of_it', 'similar', 'small']
senticnet['same_clue'] = [-0.023, 0.068, 0, 0.134, '#interesting', '#admirable', 0.06, 'full_water', 'free_will', 'godliness', 'use_clean', 'majestic']
senticnet['same_interest'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'common_good', 'group_of_people', 'community', 'similar_like', 'common_interest']
senticnet['same_level'] = [0, 0.925, 0, 0.92, '#interesting', '#admirable', 0.615, 'yardstick', 'next_level', 'scale', 'measure_tool', 'level']
senticnet['same_parent'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'family_member', 'relative', 'family_relation', 'sister', 'female_sibling']
senticnet['same_time'] = [-0.046, 0.194, -0.106, 0.124, '#interesting', '#admirable', 0.055, 'together', 'musical_note', 'music_note', 'just_in_time', 'hand_in_hand']
senticnet['sameness'] = [0.039, 0.173, 0.077, 0.193, '#interesting', '#admirable', 0.109, 'typical', 'same', 'usual_ordinary', 'normal', 'usual']
senticnet['sample'] = [0, 0.23, -0.113, 0.206, '#interesting', '#admirable', 0.108, 'savor', 'consume', 'sweet_sour', 'mouth_activity', 'bad_odor']
senticnet['sample_distribution'] = [0.948, -0.992, 0, 0.549, '#joyful', '#surprising', 0.83, 'sampling', 'equidistribution', 'frequency_distribution', 'normal_distribution', 'distribution']
senticnet['sampling'] = [0.956, -0.839, 0, 0.755, '#joyful', '#surprising', 0.85, 'choice', 'option', 'random_sampling', 'stratified_sampling', 'representative_sampling']
senticnet['samurai'] = [0.086, -0.035, 0, 0, '#joyful', '#surprising', 0.04, 'soldier', 'army', 'attacker', 'military', 'infantry']
senticnet['sanctimonious'] = [0, 0, -0.939, -0.766, '#scared', '#disgusting', -0.568, 'pietistical', 'pietistic', 'pharisaic', 'holier-than-thou', 'pharisaical']
senticnet['sanction'] = [0.669, -0.569, 0, 0.734, '#joyful', '#admirable', 0.657, 'okay', 'approval', 'commendation', 'okey', 'okeh']
senticnet['sanctioned'] = [0.585, 0.652, -0.268, 0.313, '#joyful', '#interesting', 0.427, 'affirmative', 'approbative', 'approve', 'approbatory', 'plausive']
senticnet['sanctuary'] = [0.02, 0.276, 0, 0.275, '#interesting', '#admirable', 0.19, 'monastery', 'holy_place', 'religious_place', 'worship_place', 'capital_build']
senticnet['sand'] = [-0.061, 0, 0, -0.037, '#sad', '#disgusting', -0.033, 'friction', 'lack_of_water', 'dirt', 'abrasive', 'ground_material']
senticnet['sand_blackberry'] = [-0.922, 0, 0.912, -0.942, '#sad', '#disgusting', -0.925, 'true_blackberry', 'blackberry_bush', 'dewberry', 'dewberry_bush', 'running_blackberry']
senticnet['sand_flea'] = [0.96, -0.772, 0, 0.929, '#joyful', '#admirable', 0.887, 'whale_louse', 'beach_flea', 'sand_hopper', 'sandhopper', 'amphipod']
senticnet['sand_hopper'] = [0.96, -0.772, 0, 0.929, '#joyful', '#admirable', 0.887, 'whale_louse', 'beach_flea', 'amphipod', 'sandhopper', 'sand_flea']
senticnet['sand_paper'] = [0, -0.013, 0.027, -0.1, '#angry', '#disgusting', -0.038, 'chalk_board', 'obstacle', 'golf_place', 'paper', 'school_class']
senticnet['sand_rock'] = [0.047, 0.11, 0, 0, '#joyful', '#interesting', 0.052, 'near_sea', 'sandy', 'cover_sand', 'near_beach', 'beach']
senticnet['sandal'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'flip_flop', 'moccasin', 'shoe', 'footwear', 'shoe_type']
senticnet['sandaled'] = [-0.591, 0, 0.553, -0.768, '#sad', '#disgusting', -0.637, 'booted', 'slippered', 'roughshod', 'shod', 'wear_sandal']
senticnet['sandbagger'] = [0.69, -0.818, 0, 0.732, '#surprising', '#admirable', 0.747, 'slicker', 'beguiler', 'deceiver', 'cheat', 'cheater']
senticnet['sandboy'] = [-0.794, 0, 0.992, -0.937, '#angry', '#disgusting', -0.908, 'peddler', 'pedlar', 'packman', 'hawker', 'pitchman']
senticnet['sandwich'] = [0.943, 0, 0, 0.802, '#joyful', '#admirable', 0.582, 'pastry', 'breakfast', 'make_toast', 'dinner_meal', 'appetizer']
senticnet['sandwich_board'] = [0.952, -0.527, 0, 0.835, '#joyful', '#admirable', 0.771, 'billboard', 'hoarding', 'signboard', 'scoreboard', 'shingle']
senticnet['sandy_beach'] = [0, -0.033, 0.053, -0.057, '#angry', '#disgusting', -0.026, 'puddle', 'beach', 'waterfall', 'lake_river', 'bay']
senticnet['sane'] = [0.203, 0.077, 0, 0.189, '#joyful', '#admirable', 0.156, 'sea_shell', 'coast', 'seaside', 'sediment', 'shell']
senticnet['saneness'] = [0.972, -0.887, 0, 0.926, '#joyful', '#admirable', 0.928, 'reasonableness', 'rationality', 'lucidity', 'reason', 'mental_health']
senticnet['sanguinary'] = [0, 0, -0.75, -0.932, '#scared', '#disgusting', -0.561, 'bloodthirsty', 'slaughterous', 'gory', 'butcherly', 'sanguineous']
senticnet['sanguine'] = [0.507, 0.676, -0.266, 0.272, '#joyful', '#interesting', 0.396, 'sanguinity', 'sanguineness', 'optimistically', 'optimistic', 'encouragingly']
senticnet['sanguineness'] = [0.507, 0.676, -0.266, 0.272, '#joyful', '#interesting', 0.396, 'sanguine', 'sanguinity', 'optimistically', 'optimistic', 'encouragingly']
senticnet['sanguinity'] = [0.507, 0.676, -0.266, 0.272, '#joyful', '#interesting', 0.396, 'sanguine', 'sanguineness', 'optimistically', 'optimistic', 'encouragingly']
senticnet['sanies'] = [-0.663, 0, 0.806, -0.955, '#angry', '#disgusting', -0.808, 'gleet', 'humor', 'liquid_body_substance', 'bodily_fluid', 'body_fluid']
senticnet['sanitariness'] = [0.617, -0.592, 0, 0.805, '#joyful', '#admirable', 0.671, 'sanitation', 'hygiene', 'sterility', 'sanitary_condition', 'asepsis']
senticnet['sanitary'] = [0.063, 0, 0, 0.147, '#joyful', '#admirable', 0.07, 'cleanliness', 'keep_clean', 'get_rid_of_dirt', 'remove_dirt', 'dry_skin']
senticnet['sanitary_condition'] = [-0.563, 0, 0.856, -0.852, '#angry', '#disgusting', -0.757, 'cleanness', 'unsanitariness', 'dirtiness', 'uncleanness', 'sanitariness']
senticnet['sanitation'] = [0, 0.763, 0, 0.742, '#interesting', '#admirable', 0.502, 'hygiene', 'clean', 'remove_dirt', 'sanitary', 'ensure_proper_hygiene']
senticnet['sanity'] = [0.418, 0.103, 0, 0.373, '#joyful', '#admirable', 0.298, 'knowledgeable', 'look_night_sky', 'good_lover', 'taken_seriously', 'spice_life']
senticnet['sap'] = [0, 0, -0.94, -0.948, '#scared', '#disgusting', -0.629, 'tomfool', 'fool', 'cosh', 'blackjack', 'muggins']
senticnet['saphead'] = [0.917, -0.73, 0, 0.876, '#joyful', '#admirable', 0.841, 'morosoph', 'simpleton', 'flibbertigibbet', 'foolish_woman', 'simple']
senticnet['sapidity'] = [-0.622, 0, 0.512, -0.805, '#sad', '#disgusting', -0.646, 'vanilla', 'taste', 'lemon', 'taste_sensation', 'gustatory_sensation']
senticnet['sapience'] = [0.651, -0.737, 0, 0.975, '#surprising', '#admirable', 0.788, 'profoundness', 'profundity', 'sagacity', 'sagaciousness', 'discernment']
senticnet['sapphire'] = [0.418, 0.103, 0, 0.373, '#joyful', '#admirable', 0.298, 'bloodstone', 'turquoise', 'emerald', 'ruby', 'jade']
senticnet['saquinavir'] = [-0.818, 0, 0.767, -0.936, '#sad', '#disgusting', -0.84, 'antiviral', 'indinavir', 'nelfinavir', 'ritonavir', 'protease_inhibitor']
senticnet['sarcastic'] = [-0.773, 0, 0.537, -0.649, '#sad', '#disgusting', -0.653, 'grim', 'saturnine', 'sardonic', 'mordant', 'black']
senticnet['sardonic'] = [-0.773, 0, 0.537, -0.649, '#sad', '#disgusting', -0.653, 'grim', 'saturnine', 'sarcastic', 'mordant', 'black']
senticnet['sash'] = [-0.534, 0, 0.682, -0.748, '#angry', '#disgusting', -0.655, 'girdle', 'cincture', 'cummerbund', 'waistband', 'waistcloth']
senticnet['sass'] = [-0.958, 0, 0.941, -0.577, '#sad', '#angry', -0.825, 'reply', 'response', 'comeback', 'comebacking', 'backtalk']
senticnet['sassing'] = [-0.958, 0, 0.941, -0.577, '#sad', '#angry', -0.825, 'reply', 'response', 'sass', 'comeback', 'backtalk']
senticnet['satan'] = [0, 0, -0.994, -0.74, '#scared', '#disgusting', -0.578, 'deadly', 'evil', 'devil', 'hell', 'satanism']
senticnet['satanism'] = [0, 0, -0.994, -0.74, '#scared', '#disgusting', -0.578, 'deadly', 'evil', 'devil', 'hell', 'satan']
senticnet['satchel'] = [0, 0, 0.009, -0.063, '#angry', '#disgusting', -0.024, 'tote_bag', 'shoulder_bag', 'vanity_case', 'satchel_bag', 'card_case']
senticnet['satchel_bag'] = [0, -0.004, 0.051, -0.057, '#angry', '#disgusting', -0.035, 'eyeglass_case', 'checkbook_holder', 'tote_bag', 'lip_balm', 'checkbook_cover']
senticnet['sate'] = [0.334, 0.331, -0.11, 0.49, '#joyful', '#admirable', 0.348, 'attain_goal', 'inclusion', 'good_fortune', 'satisfy', 'again_and_again']
senticnet['sate_hunger'] = [0, 0, 0, 0.867, '#admirable', '#admirable', 0.289, 'eat_like_pig', 'eat_cookie', 'eat_breakfast_in_bed', 'eat_breakfast', 'diminish_own_hunger']
senticnet['satiable'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'gratifyingly', 'satisfactorily', 'comforting', 'satisfyingly', 'cheering']
senticnet['satiate'] = [-0.634, 0, 0.608, -0.748, '#sad', '#disgusting', -0.663, 'pall', 'take_in', 'take', 'ingest', 'have']
senticnet['satiate_hunger'] = [-0.027, 0.224, -0.07, 0.116, '#interesting', '#admirable', 0.081, 'provide_food', 'money_charge', 'make_eat', 'fee', 'payment']
senticnet['satiation'] = [0.717, 0, 0, 0.999, '#joyful', '#admirable', 0.572, 'entree', 'soup', 'wine_glass', 'salt_pepper_shaker', 'plate_silverware']
senticnet['satire'] = [0, -0.036, 0, 0.094, '#surprising', '#admirable', 0.043, 'commercial', 'sitcom', 'presentation', 'make_other_person_laugh', 'funny']
senticnet['satirist'] = [-0.166, -0.019, -0.176, -0.17, '#scared', '#disgusting', -0.164, 'make_others_laugh', 'laugh', 'mean_person', 'tell_others', 'make_fun']
senticnet['satirize'] = [-0.668, 0, 0.809, -0.565, '#sad', '#angry', -0.681, 'blackguard', 'roast', 'ridicule', 'guy', 'laugh_at']
senticnet['satisfaction'] = [0.653, 0.4, -0.205, 0.168, '#joyful', '#interesting', 0.339, 'elation', 'joy', 'contentment', 'pride', 'excitement']
senticnet['satisfactorily'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'gratifyingly', 'satiable', 'comforting', 'satisfyingly', 'cheering']
senticnet['satisfactoriness'] = [-0.997, 0, 0.878, -0.957, '#sad', '#disgusting', -0.944, 'adequacy', 'adequateness', 'acceptability', 'acceptableness', 'quality']
senticnet['satisfactory'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'gratifyingly', 'satiable', 'satisfactorily', 'comforting', 'satisfyingly']
senticnet['satisfiable'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'gratifyingly', 'satiable', 'satisfactorily', 'comforting', 'satisfyingly']
senticnet['satisfied'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'gratifyingly', 'satiable', 'satisfactorily', 'comforting', 'satisfyingly']
senticnet['satisfy'] = [0.937, 0, 0, 0, '#joyful', '#joyful', 0.312, 'gratify', 'fulfill', 'congratulate', 'gloat', 'glee']
senticnet['satisfy_appetite'] = [0.744, 0, 0, 0.741, '#joyful', '#admirable', 0.495, 'munch', 'able_eat', 'nourishment', 'replenish_energy', 'sustenance']
senticnet['satisfy_crave'] = [0.964, 0, 0, 0, '#joyful', '#joyful', 0.321, 'weight_gain', 'impress_girlfriend', 'eat_pizza', 'eat', 'become_little_hungry']
senticnet['satisfy_curiosity'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'broaden_horizon', 'find_out_world', 'educate', 'prepare_exam', 'expand_knowledge']
senticnet['satisfy_hunger'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'eat_drink', 'satisfy_crave', 'eat_pie', 'celebrate_wedding', 'fill_stomach']
senticnet['satisfy_need'] = [0, 0, 0, 0.1, '#admirable', '#admirable', 0.033, 'acquire_goods', 'get_need', 'acquire', 'make_rich', 'get_stuff']
senticnet['satisfy_sweet_tooth'] = [0.949, 0.878, 0, 0, '#joyful', '#interesting', 0.609, 'feel_content', 'spread_happiness', 'spend_time_with_friend', 'pleasure', 'give_pleasure']
senticnet['satisfying'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'gratifyingly', 'satiable', 'satisfactorily', 'comforting', 'satisfyingly']
senticnet['satisfyingly'] = [0.761, 0.603, -0.214, 0.333, '#joyful', '#interesting', 0.494, 'gratifyingly', 'satiable', 'satisfactorily', 'comforting', 'cheering']
senticnet['saturday'] = [0.967, 0.996, 0, 0.862, '#joyful', '#interesting', 0.942, 'party_time', 'new_baby', 'nativity', 'holiday', 'occasion']
senticnet['saturnine'] = [-0.773, 0, 0.537, -0.649, '#sad', '#disgusting', -0.653, 'grim', 'sarcastic', 'sardonic', 'mordant', 'black']
senticnet['sausage'] = [0.662, -0.636, 0, 0.628, '#joyful', '#surprising', 0.642, 'knackwurst', 'knockwurst', 'salami', 'frank', 'hotdog']
senticnet['savage'] = [-0.632, 0, 0.796, -0.776, '#angry', '#disgusting', -0.735, 'blindside', 'profane', 'assault', 'assail', 'violate']
senticnet['savagery'] = [-0.63, 0, 0.921, -0.621, '#sad', '#angry', -0.724, 'fury', 'wildness', 'ferocity', 'fierceness', 'furiousness']
senticnet['save'] = [-0.027, 0.336, -0.114, 0.251, '#interesting', '#admirable', 0.149, 'keep', 'give_back', 'gain', 'keep_safe', 'safekeep']
senticnet['save_data'] = [0.028, -0.602, 0, 0.354, '#surprising', '#admirable', 0.328, 'send_message', 'record_data', 'play_song', 'make_easy', 'perfect_skill']
senticnet['save_earth'] = [0.116, 0, 0.069, 0.118, '#joyful', '#admirable', 0.055, 'nice_weather', 'commute_work', 'car_repair', 'get_into_place', 'go_green']
senticnet['save_environment'] = [0.307, 0.163, 0, 0.374, '#joyful', '#admirable', 0.281, 'a_lot', 'good_listener', 'others_understand', 'eye_contact', 'human_contact']
senticnet['save_file'] = [0.069, 0, 0, 0, '#joyful', '#joyful', 0.023, 'backup', 'keep_file', 'use_computer', 'keep_document', 'file']
senticnet['save_information'] = [0.809, 0, 0, 0.794, '#joyful', '#admirable', 0.534, 'music_storage', 'keep_track', 'seventy', 'groove', 'store_music']
senticnet['save_life'] = [0.967, 0.996, 0, 0.862, '#joyful', '#interesting', 0.942, 'life', 'good_person', 'hero', 'safe', 'end_war']
senticnet['save_money'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'buy_cheaper', 'good_customer', 'better_price', 'sales', 'on_sale']
senticnet['save_someone_from_drowning'] = [0.042, 0.088, 0, 0, '#joyful', '#interesting', 0.043, 'jump_over_obstacle', 'hide_shell', 'catch_fly', 'swim', 'attempt_fly']
senticnet['save_space'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'find_motel', 'find_bedroom', 'find_car', 'find_hospice', 'cover_pillow']
senticnet['save_time'] = [0.045, 0.102, 0, 0, '#joyful', '#interesting', 0.049, 'ride_work', 'enjoy_food', 'enjoy_view', 'meet_new_friend', 'speed_up']
senticnet['save_up'] = [0.02, 0.131, -0.081, 0.279, '#interesting', '#admirable', 0.116, 'accumulate', 'retrieve', 'obtain', 'savings', 'bring_together']
senticnet['save_water'] = [0.107, 0.098, 0, 0.135, '#joyful', '#admirable', 0.113, 'go_green', 'respect_nature', 'reduce_pollution', 'go_on_foot', 'spread_seed']
senticnet['save_world'] = [0.745, 0, 0, 0.764, '#joyful', '#admirable', 0.503, 'know_new', 'become_wise', 'enlightenment', 'interest_job', 'fulfillment']
senticnet['saver'] = [0.88, 0, 0, 0.883, '#joyful', '#admirable', 0.588, 'succorer', 'rescuer', 'salvager', 'salvor', 'reedemer']
senticnet['saving'] = [0.953, -0.65, 0, 0.866, '#joyful', '#admirable', 0.823, 'economy_of_scale', 'retrenchment', 'curtailment', 'downsizing', 'action']
senticnet['savings'] = [0.065, 0.212, 0, 0.153, '#interesting', '#admirable', 0.143, 'check_account', 'money_inside', 'store_money', 'hold_money', 'teller']
senticnet['savings_account'] = [0, 0.32, -0.076, 0.156, '#interesting', '#admirable', 0.133, 'bank_loan', 'money_maker', 'bank_money', 'deposit', 'money_place']
senticnet['savor'] = [0.159, 0.112, -0.099, 0.129, '#joyful', '#admirable', 0.1, 'sweet_sour', 'sample', 'contagious', 'flavorful', 'put_mouth']
senticnet['savoriness'] = [-0.797, 0, 0.992, -0.884, '#angry', '#disgusting', -0.891, 'flavorsomeness', 'flavoursomeness', 'appetizingness', 'succulence', 'succulency']
senticnet['savorless'] = [-0.717, 0, 0.559, -0.957, '#sad', '#disgusting', -0.744, 'unseasoned', 'unsalted', 'flavorless', 'flavourless', 'tasteless']
senticnet['savory'] = [0.91, -0.993, 0, 0.779, '#joyful', '#surprising', 0.894, 'herb', 'delicious', 'summer_savory', 'eat_well', 'winter_savory']
senticnet['savvy'] = [0.836, 0, 0, 0.854, '#joyful', '#admirable', 0.563, 'grok', 'get_picture', 'intuit', 'intelligence', 'wit']
senticnet['saw'] = [0.739, -0.796, 0, 0, '#joyful', '#surprising', 0.512, 'knife', 'hatchet', 'cut_tool', 'dagger', 'axe']
senticnet['sawdust_saloon'] = [-0.814, 0, 0.553, -0.928, '#sad', '#disgusting', -0.765, 'bar', 'barroom', 'saloon', 'ginmill', 'taproom']
senticnet['saxifrage'] = [-0.854, 0, 0.894, -0.517, '#sad', '#angry', -0.755, 'herb', 'yellow_mountain_saxifrage', 'meadow_saxifrage', 'mossy_saxifrage', 'western_saxifrage']
senticnet['say_aha'] = [0.96, 0.902, 0, 0, '#joyful', '#interesting', 0.621, 'stare_off_space', 'think_past', 'scratch_head', 'brain_storm', 'come_up_idea']
senticnet['say_aloud'] = [-0.062, 0.16, 0.075, 0.078, '#interesting', '#admirable', 0.034, 'add_two_numbers_together', 'write_down', 'addition', 'concept', 'add_number']
senticnet['say_eureka'] = [-0.315, 0, -0.192, 0, '#sad', '#scared', -0.169, 'investigate_fact', 'look_fact', 'ask_many_questions', 'new_insight', 'look_clue']
senticnet['say_excuse'] = [-0.098, 0, -0.073, -0.13, '#sad', '#disgusting', -0.1, 'name_dog', 'quiet_mind', 'lift_leg', 'wet_pant', 'listen_bird']
senticnet['say_good_bye'] = [-0.025, 0.087, 0, 0.107, '#interesting', '#admirable', 0.056, 'excuse_oneself', 'step_aside', 'step_out', 'walk_away', 'open_mailbox']
senticnet['say_goodbye'] = [0.97, 0, 0, 0.975, '#joyful', '#admirable', 0.648, 'part_of_way', 'make_feel_better', 'kiss_other', 'little_hunger', 'think_funny']
senticnet['say_goodbye_to'] = [0.878, 0, 0, 0.919, '#joyful', '#admirable', 0.599, 'greet', 'salute', 'greet_each_other', 'wave_arm', 'attract_attention']
senticnet['say_grace'] = [-0.031, -0.05, 0.052, -0.051, '#angry', '#disgusting', -0.028, 'prepare_dinner', 'measure_ingredient', 'eat_soup', 'create_meal', 'prepare_meal']
senticnet['say_hello'] = [0.021, 0.093, -0.069, 0.119, '#interesting', '#admirable', 0.055, 'ask_name', 'end_conversation', 'introduce_oneself', 'make_eye_contact', 'say_hi']
senticnet['say_hi'] = [-0.044, 0, -0.057, 0, '#sad', '#scared', -0.034, 'talk_another_person', 'introduce_oneself', 'become_friend', 'make_eye_contact', 'say_hello']
senticnet['say_love'] = [0.94, 0.877, 0, 0, '#joyful', '#interesting', 0.606, 'surprise_friend', 'act_foolish', 'receive_gift', 'tear_paper', 'blow_out_candle']
senticnet['say_name'] = [0, 0.869, 0, 0.919, '#interesting', '#admirable', 0.596, 'dial_phone', 'chat', 'call_person', 'converse', 'talkative']
senticnet['say_no'] = [-0.822, 0, 0, -0.822, '#sad', '#disgusting', -0.548, 'file_complaint', 'meet_greet', 'forget_name', 'reply_question', 'desire_help']
senticnet['say_prayer'] = [-0.311, 0, -0.247, -0.103, '#sad', '#scared', -0.22, 'put_box', 'dig_hole', 'see_light', 'end_relationship', 'become_depressed']
senticnet['say_sorry'] = [-0.562, 0, -0.582, 0.294, '#sad', '#scared', -0.283, 'feel_sorry', 'get_reply', 'rely', 'make_promise', 'regret']
senticnet['say_thank'] = [0.764, 0, 0, 0.918, '#joyful', '#admirable', 0.561, 'feel_obligated', 'make_happy', 'express_love', 'give_present', 'show_affection']
senticnet['say_thank_you'] = [0.8, 0, 0, 0.845, '#joyful', '#admirable', 0.548, 'happy', 'good_feeling', 'make_happy', 'express_love', 'bring_happiness']
senticnet['say_welcome'] = [0.883, 0.872, 0, 0, '#joyful', '#interesting', 0.585, 'become_aroused', 'show_empathy', 'find_woman', 'love_oneself', 'love_back']
senticnet['say_word'] = [0, 0.83, 0, 0.945, '#interesting', '#admirable', 0.592, 'call_mom', 'talk_telephone', 'communicate', 'speak', 'talk']
senticnet['say_yes'] = [-0.061, 0.25, -0.184, 0.352, '#interesting', '#admirable', 0.119, 'consent', 'make_right', 'take', 'suggest', 'agree']
senticnet['scabiosa'] = [-0.827, 0, 0.619, -0.941, '#sad', '#disgusting', -0.796, 'sweet_scabious', 'pincushion_flower', 'mournful_widow', 'field_scabious', 'flower']
senticnet['scabious'] = [-0.967, 0, 0.655, -0.959, '#sad', '#disgusting', -0.86, 'sweet_scabious', 'pincushion_flower', 'mournful_widow', 'field_scabious', 'flower']
senticnet['scabrous'] = [-0.774, 0, 0.626, -0.786, '#sad', '#disgusting', -0.729, 'bumpy', 'unsmooth', 'lepidote', 'leprose', 'roughish']
senticnet['scalawag'] = [-0.625, 0, 0.768, -0.588, '#sad', '#angry', -0.66, 'rascal', 'rapscallion', 'holy_terror', 'scallywag', 'monkey']
senticnet['scald'] = [-0.042, -0.005, -0.062, -0.083, '#scared', '#disgusting', -0.061, 'fire_product', 'high_temperature', 'hot', 'heat', 'hotness']
senticnet['scale'] = [-0.996, 0, 0.786, -0.623, '#sad', '#angry', -0.802, 'measure', 'standard', 'wage_scale', 'wage_schedule', 'wind_scale']
senticnet['scale_of_measurement'] = [-0.558, 0, 0.796, -0.548, '#sad', '#angry', -0.634, 'measure', 'standard', 'wage_scale', 'wage_schedule', 'wind_scale']
senticnet['scale_wall'] = [0, 0.111, -0.05, 0.098, '#interesting', '#admirable', 0.053, 'go_up', 'move_upward', 'ascend', 'go_high', 'step_up']
senticnet['scaled'] = [-0.897, 0, 0.945, -0.894, '#sad', '#angry', -0.912, 'bulletproof', 'mailed', 'lightly_armored', 'lightly_armoured', 'armored']
senticnet['scallywag'] = [-0.625, 0, 0.768, -0.588, '#sad', '#angry', -0.66, 'rascal', 'rapscallion', 'scalawag', 'holy_terror', 'monkey']
senticnet['scalpel'] = [-0.053, -0.035, 0, -0.22, '#sad', '#disgusting', -0.079, 'stethoscope', 'tourniquet', 'vaccination', 'razor', 'machete']
senticnet['scaly'] = [0, 0, 0.073, 0, '#angry', '#angry', -0.024, 'cold-blooded', 'reptile', 'amphibian', 'frog', 'aquatic']
senticnet['scamp'] = [0.625, -0.905, 0, 0.756, '#surprising', '#admirable', 0.762, 'child', 'small_fry', 'tyke', 'tike', 'kid']
senticnet['scan'] = [-0.08, 0, 0.011, -0.046, '#sad', '#disgusting', -0.046, 'deflate', 'read_cover', 'obtain_information', 'upgrade', 'spread_out']
senticnet['scandal'] = [-0.062, 0.128, 0.707, -0.677, '#angry', '#disgusting', -0.439, 'embarrassment', 'peer_pressure', 'sudden', 'bad_feeling', 'public_embarrassment']
senticnet['scandalization'] = [-0.927, 0, 0.699, -0.936, '#sad', '#disgusting', -0.854, 'discourtesy', 'offense', 'outrage', 'affront', 'indignity']
senticnet['scandalize'] = [-0.987, 0, 0.733, -0.963, '#sad', '#disgusting', -0.894, 'churn_up', 'sicken', 'disgust', 'nauseate', 'revolt']
senticnet['scandalmongering'] = [0, 0, 0, -0.787, '#disgusting', '#disgusting', -0.262, 'sensationalistic', 'sensational', 'sensationally', 'inflame', 'fire_up']
senticnet['scandalous'] = [0, 0, 0.845, -0.967, '#angry', '#disgusting', -0.604, 'disgraceful', 'shameful', 'dishonorably', 'inglorious', 'dishonored']
senticnet['scantiness'] = [-0.82, 0, 0.855, -0.568, '#sad', '#angry', -0.748, 'insufficiency', 'sparseness', 'sparsity', 'abstemiousness', 'lack_of_quantity']
senticnet['scantness'] = [-0.7, 0, 0.746, -0.782, '#angry', '#disgusting', -0.743, 'insufficiency', 'sparseness', 'sparsity', 'abstemiousness', 'lack_of_quantity']
senticnet['scanty'] = [-0.949, 0, 0.952, -0.838, '#sad', '#angry', -0.913, 'miserable', 'meager', 'exiguous', 'spare', 'hardscrabble']
senticnet['scapegrace'] = [-0.515, 0, 0.571, -0.593, '#angry', '#disgusting', -0.56, 'miscreant', 'black_sheep', 'degenerate', 'wretch', 'pervert']
senticnet['scar'] = [-0.126, -0.004, -0.079, -0.145, '#sad', '#disgusting', -0.115, 'laceration', 'gash', 'cut_skin', 'abrasion', 'painful_injury']
senticnet['scarce'] = [0, 0, 0.961, -0.854, '#angry', '#disgusting', -0.605, 'least', 'little', 'small_amount', 'shortage', 'a_little']
senticnet['scarceness'] = [-0.881, 0, 0.732, -0.61, '#sad', '#angry', -0.741, 'paucity', 'insufficiency', 'rareness', 'infrequency', 'dearth']
senticnet['scarcity'] = [-0.521, 0, 0.732, -0.772, '#angry', '#disgusting', -0.675, 'paucity', 'insufficiency', 'rareness', 'infrequency', 'dearth']
senticnet['scare'] = [0, 0, -0.948, 0, '#scared', '#scared', -0.316, 'panic', 'frighten', 'humiliation', 'terror', 'fear']
senticnet['scare_away'] = [-0.944, 0, -0.868, 0, '#sad', '#scared', -0.604, 'scarily', 'scared', 'frighten_away', 'frighten_off', 'scare_off']
senticnet['scare_dog'] = [0, 0, -0.908, 0, '#scared', '#scared', -0.303, 'feel_hurt', 'get_arrested', 'feel_anger', 'grimace', 'slander']
senticnet['scare_off'] = [-0.7, 0, -0.869, 0, '#sad', '#scared', -0.523, 'scarily', 'scared', 'frighten_away', 'scare_away', 'frighten_off']
senticnet['scare_person'] = [0, 0, -0.952, 0, '#scared', '#scared', -0.317, 'circle_prey', 'get_rid_of_enemy', 'psychopath', 'hurt_others', 'end_live']
senticnet['scared'] = [-0.966, 0, -0.72, 0, '#sad', '#scared', -0.562, 'scarily', 'frighten_away', 'scare_away', 'frighten_off', 'scare_off']
senticnet['scared_of_insect'] = [-0.026, 0, 0.09, 0, '#sad', '#angry', -0.039, 'nuisance_insect', 'small_insect', 'fly_insect', 'bothersome_insect', 'annoy_bug']
senticnet['scarf'] = [0.702, 0, 0, 0, '#joyful', '#joyful', 0.234, 'jacket', 'shirt', 'slack', 'clothes', 'sweater']
senticnet['scarily'] = [-0.933, 0, -0.925, 0, '#sad', '#scared', -0.619, 'scared', 'frighten_away', 'scare_away', 'frighten_off', 'scare_off']
senticnet['scarlet'] = [0.035, 0, 0, 0.116, '#joyful', '#admirable', 0.05, 'maroon', 'color', 'bright_color', 'hair_colored', 'cool_color']
senticnet['scarlet_bush'] = [0.938, -0.773, 0, 0.944, '#joyful', '#admirable', 0.885, 'bush', 'hamelia', 'scarlet_hamelia', 'coloradillo', 'shrub']
senticnet['scarlet_hamelia'] = [0.938, -0.773, 0, 0.944, '#joyful', '#admirable', 0.885, 'bush', 'scarlet_bush', 'hamelia', 'coloradillo', 'shrub']
senticnet['scarred'] = [-0.85, 0, 0.804, -0.855, '#sad', '#disgusting', -0.836, 'blemished', 'flyblown', 'marred', 'acned', 'pimpled']
senticnet['scary'] = [0, 0, -0.704, 0, '#scared', '#scared', -0.235, 'ugly', 'frighten', 'terrible', 'horrible', 'fright']
senticnet['scary_movie'] = [0, 0, -0.809, 0, '#scared', '#scared', -0.27, 'horror_movie', 'political_rally', 'ball_game', 'pool_hall', 'tourist_site']
senticnet['scatology'] = [-0.9, 0, 0.987, -0.534, '#sad', '#angry', -0.807, 'filth', 'smut', 'vulgarism', 'dirty_word', 'obscenity']
senticnet['scattered'] = [-0.84, 0, 0.522, -0.989, '#sad', '#disgusting', -0.784, 'unconnected', 'confused', 'incoherent', 'disordered', 'garbled']
senticnet['scatty'] = [-0.714, 0, 0.906, -0.934, '#angry', '#disgusting', -0.851, 'absent', 'forgetful', 'distracted', 'distrait', 'inattentive']
senticnet['scavenge'] = [-0.664, 0, 0.663, -0.728, '#sad', '#disgusting', -0.685, 'make_clean', 'vacuum', 'preen', 'modify', 'dust']
senticnet['scavenger_cell'] = [0.565, -0.99, 0, 0.81, '#surprising', '#admirable', 0.788, 'somatic_cell', 'vegetative_cell', 'fixed_phagocyte', 'macrophage', 'free_phagocyte']
senticnet['scene'] = [-0.694, 0, 0.508, -0.937, '#sad', '#disgusting', -0.713, 'dark', 'darkness', 'light', 'shadow', 'field_of_honor']
senticnet['scenery'] = [0.05, -0.016, 0, 0.058, '#joyful', '#admirable', 0.041, 'vista', 'panorama', 'scenic', 'view', 'spectacular']
senticnet['scenic'] = [0.926, 0, 0, 0.826, '#joyful', '#admirable', 0.584, 'perspective', 'vista', 'view', 'aspect', 'see_view']
senticnet['scenic_view'] = [0, 0, 0, -0.073, '#disgusting', '#disgusting', -0.024, 'driftwood', 'sea_shell', 'naked_woman', 'shore', 'tidal_wave']
senticnet['scent'] = [0.779, 0, 0, 0.909, '#joyful', '#admirable', 0.563, 'aroma', 'fragrance', 'smell', 'smell_good', 'odor']
senticnet['scented'] = [0, -0.79, 0, 0.889, '#surprising', '#admirable', 0.56, 'nose', 'odourise', 'perfume', 'wind', 'odorize']
senticnet['sceptic'] = [-0.527, 0, 0.95, -0.788, '#angry', '#disgusting', -0.755, 'skeptic', 'pessimist', 'doubter', 'defeatist', 'negativist']
senticnet['schedule'] = [0.999, 0.953, 0, 0, '#joyful', '#interesting', 0.651, 'scheme', 'plan', 'eureka', 'know_start', 'timetable']
senticnet['schedule_appointment'] = [-0.067, 0, 0, -0.087, '#sad', '#disgusting', -0.051, 'make_appointment', 'go_hair_salon', 'put_nice_clothes', 'go_barber', 'shave_face']
senticnet['schedule_appointment_doctor'] = [-0.077, 0, -0.101, -0.111, '#scared', '#disgusting', -0.096, 'make_doctor_appointment', 'wear_clean_underwear', 'turn_head_cough', 'make_appointment_with_doctor', 'find_doctor']
senticnet['schedule_feeding'] = [-0.802, 0, 0.724, -0.706, '#sad', '#angry', -0.744, 'nursing', 'infant_feeding', 'demand_feeding', 'breast_feeding', 'feeding']
senticnet['schedule_time'] = [0, 0.89, 0, 0, '#interesting', '#interesting', 0.297, 'make_arrangement', 'go_airport', 'plan_ahead', 'decide_to_go_first', 'decide_want_go']
senticnet['scheme'] = [0.765, 0.899, 0, 0, '#joyful', '#interesting', 0.555, 'plan', 'blueprint', 'forethought', 'purpose', 'draw_blueprint']
senticnet['schizoid'] = [0, 0, 0.896, -0.962, '#angry', '#disgusting', -0.619, 'antisocial', 'sociopathic', 'psychopathic_personality', 'disturbance', 'personality_disorder']
senticnet['schizophrenia'] = [0, 0, -0.875, 0, '#scared', '#scared', -0.292, 'broken_finger', 'censorship', 'diabetes', 'ill_health', 'black_eye']
senticnet['schizophrenic'] = [-0.606, 0, 0.892, -0.921, '#angry', '#disgusting', -0.806, 'psycho', 'cataleptic', 'paranoid', 'paranoiac', 'sick_person']
senticnet['schizophrenic_disorder'] = [-0.227, -0.011, -0.133, -0.075, '#sad', '#scared', -0.141, 'clinical_problem', 'disorder', 'mental_disorder', 'disease', 'paraphrenia']
senticnet['schizophrenic_psychosis'] = [-0.227, -0.011, -0.133, -0.075, '#sad', '#scared', -0.141, 'clinical_problem', 'disease', 'mental_problem', 'disorder', 'paraphrenia']
senticnet['schmaltz'] = [-0.769, 0, 0.982, -0.547, '#sad', '#angry', -0.766, 'sentimentalism', 'emotionality', 'emotionalism', 'corn', 'sentimentality']
senticnet['schmoose'] = [-0.58, 0, 0.582, -0.795, '#angry', '#disgusting', -0.652, 'gossip', 'chitchat', 'chit_chat', 'gab', 'small_talk']
senticnet['schmooze'] = [-0.616, 0, 0.77, -0.909, '#angry', '#disgusting', -0.765, 'gossip', 'chitchat', 'chit_chat', 'gab', 'small_talk']
senticnet['schmoozer'] = [0.821, -0.818, 0, 0.709, '#joyful', '#surprising', 0.783, 'utterer', 'deipnosophist', 'interlocutor', 'conversational_partner', 'speaker']
senticnet['schnapps'] = [0.864, -0.641, 0, 0.525, '#joyful', '#surprising', 0.677, 'liquor', 'spirits', 'booze', 'hard_drink', 'hard_liquor']
senticnet['schnaps'] = [0.673, -0.956, 0, 0.712, '#surprising', '#admirable', 0.78, 'liquor', 'spirits', 'booze', 'hard_drink', 'hard_liquor']
senticnet['scholar'] = [0.098, 0, -0.048, 0.112, '#joyful', '#admirable', 0.054, 'research', 'teach_course', 'professor', 'lecturer', 'invent']
senticnet['scholarly'] = [0, 0.999, 0, 0.918, '#interesting', '#admirable', 0.639, 'erudite', 'donnish', 'pedantic', 'learned', 'bookish']
senticnet['scholarship'] = [0.941, -0.786, 0, 0.567, '#joyful', '#surprising', 0.765, 'prize', 'assistance', 'award', 'economic_aid', 'financial_aid']
senticnet['school_band'] = [0.023, 0.303, -0.087, 0.261, '#interesting', '#admirable', 0.167, 'high_choral', 'drum_set', 'band', 'string_quartet', 'choral']
senticnet['school_book'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'textbook', 'book', 'bookmark', 'science_book', 'book_magazine']
senticnet['school_bus'] = [0.06, 0.091, 0, 0.232, '#interesting', '#admirable', 0.128, 'bus', 'school', 'student', 'go_to_school', 'public_transport']
senticnet['school_choral'] = [0.023, 0.303, -0.087, 0.261, '#interesting', '#admirable', 0.167, 'chorus', 'drum_set', 'choral', 'string_quartet', 'band']
senticnet['school_class'] = [0, -0.013, 0.027, -0.1, '#angry', '#disgusting', -0.038, 'sand_paper', 'obstacle', 'golf_place', 'paper', 'chalk_board']
senticnet['school_course'] = [0, 0.084, 0, 0.065, '#interesting', '#admirable', 0.05, 'physic', 'chemistry', 'science', 'geology', 'college_major']
senticnet['school_crossing'] = [0.508, -0.726, 0, 0.727, '#surprising', '#admirable', 0.654, 'crosswalk', 'pelican_crossing', 'pedestrian_crossing', 'crossing', 'crossover']
senticnet['school_division'] = [-0.051, -0.013, 0.01, -0.044, '#sad', '#disgusting', -0.031, 'learning_place', 'student_place', 'group_student', 'college_course', 'school_session']
senticnet['school_end'] = [0.06, 0.091, 0, 0.232, '#interesting', '#admirable', 0.128, 'chime', 'ring_loudly', 'noise_maker', 'bell', 'bell_noise']
senticnet['school_grade'] = [-0.066, 0.18, 0, 0.143, '#interesting', '#admirable', 0.086, 'grade', 'multiple_choices', 'final', 'final_exam', 'evaluation']
senticnet['school_hall'] = [0.058, 0, 0, 0.088, '#joyful', '#admirable', 0.049, 'fashion_event', 'exhibition', 'art', 'football_stadium', 'sport_arena']
senticnet['school_level'] = [0.065, -0.021, 0.009, 0, '#joyful', '#surprising', 0.026, 'college_class', 'session', 'class', 'high_school', 'lecture']
senticnet['school_of_thought'] = [0.95, -0.772, 0, 0.578, '#joyful', '#surprising', 0.767, 'philosophy', 'doctrine', 'philosophical_system', 'amoralism', 'ism']
senticnet['school_paper'] = [0.097, 0.076, 0, 0.108, '#joyful', '#admirable', 0.094, 'topic', 'subject', 'method', 'one_of_thing', 'scientific_method']
senticnet['school_play'] = [0.793, -0.953, 0, 0, '#joyful', '#surprising', 0.582, 'play_ping_pong', 'musical_device', 'magic', 'stunt', 'family_activity']
senticnet['school_session'] = [0.739, 0.825, 0, 0.782, '#interesting', '#admirable', 0.782, 'academy', 'freshman', 'lesson', 'university', 'undergraduate']
senticnet['school_student'] = [-0.143, -0.003, 0, -0.111, '#sad', '#disgusting', -0.084, 'state_fact', 'understand_idea', 'educate_others', 'guess_answer', 'time_test']
senticnet['school_study'] = [0, 0.112, 0, 0.097, '#interesting', '#admirable', 0.07, 'math_relate', 'math_subject', 'exact', 'median', 'method']
senticnet['school_stuff'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'smart_technology', 'pencil_sharpener', 'office_stuff', 'electric_pencil_sharpener', 'pencil']
senticnet['school_subject'] = [0, 0.08, 0.032, 0.096, '#interesting', '#admirable', 0.048, 'geology', 'chemistry', 'geometric', 'physic', 'geographic']
senticnet['school_system'] = [0, 0.752, 0, 0.799, '#interesting', '#admirable', 0.517, 'school', 'time_waster', 'class', 'college', 'college_class']
senticnet['school_test'] = [-0.031, 0.086, 0.01, 0.091, '#interesting', '#admirable', 0.045, 'assignment', 'take_exam', 'write_thesis', 'write_term_paper', 'study']
senticnet['school_topic'] = [0, 0, -0.103, 0, '#scared', '#scared', -0.034, 'long_ago', 'past_event', 'history', 'school_subject', 'subject']
senticnet['school_work'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'assignment', 'learn_tool', 'text_book', 'homework', 'textbook']
senticnet['school_yard'] = [0.058, 0, 0, 0.088, '#joyful', '#admirable', 0.049, 'exhibition', 'fashion_show', 'art', 'football_stadium', 'sport_arena']
senticnet['school_year'] = [-0.053, 0, -0.049, 0, '#sad', '#scared', -0.034, 'learning_place', 'school_session', 'student_place', 'school_division', 'educational_institution']
senticnet['schoolchild'] = [0.521, 0.677, -0.276, 0.273, '#joyful', '#interesting', 0.398, 'further_education', 'protect_child', 'look_closely', 'go_to_school', 'register']
senticnet['schoolyard'] = [0, -0.013, 0.018, -0.076, '#angry', '#disgusting', -0.027, 'corner_two_streets', 'street_corner', 'city_street', 'school', 'junk_yard']
senticnet['sciatica'] = [-0.547, 0, 0.543, -0.63, '#sad', '#disgusting', -0.573, 'hurting', 'pain', 'trigeminal_neuralgia', 'tic_douloureux', 'neuralgia']
senticnet['science'] = [0.701, -0.778, 0, 0.659, '#joyful', '#surprising', 0.713, 'discipline', 'study', 'subject', 'natural_history', 'natural_science']
senticnet['science_book'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'textbook', 'book', 'bookmark', 'school_book', 'book_magazine']
senticnet['science_class'] = [0.2, 0.154, -0.08, 0.166, '#joyful', '#admirable', 0.147, 'laboratory', 'elementary_school', 'college_class', 'lab', 'school_session']
senticnet['science_fiction'] = [0.053, -0.019, 0, 0, '#joyful', '#surprising', 0.024, 'musical_composition', 'stereo', 'contralto', 'radio', 'music']
senticnet['science_fiction_book'] = [0.036, 0.219, 0, 0.19, '#interesting', '#admirable', 0.148, 'saga', 'book', 'book_genre', 'web_site', 'classic']
senticnet['science_lab'] = [-0.063, -0.026, -0.069, -0.031, '#sad', '#scared', -0.046, 'music_room', 'music_class', 'bluegrass_band', 'music_studio', 'music_shop']
senticnet['science_laboratory'] = [-0.043, -0.003, -0.051, -0.091, '#scared', '#disgusting', -0.061, 'history_book', 'science_class', 'laboratory', 'computer_lab', 'flower_garden']
senticnet['science_term'] = [-0.023, 0.166, 0, 0.203, '#interesting', '#admirable', 0.115, 'science', 'scientific', 'small_object', 'method', 'scientific_term']
senticnet['scientific'] = [-0.062, 0.193, 0, 0.224, '#interesting', '#admirable', 0.118, 'method', 'science_term', 'hypothesis', 'scientific_term', 'procedure']
senticnet['scientific_instrument'] = [0.562, -0.777, 0, 0.962, '#surprising', '#admirable', 0.767, 'console', 'instrument', 'accelerator', 'particle_accelerator', 'atom_smasher']
senticnet['scientific_method'] = [-0.059, 0.11, -0.092, 0.147, '#interesting', '#admirable', 0.035, 'experiment', 'hypothesis', 'prove_theory', 'test_hypothesis', 'procedure']
senticnet['scientific_statement'] = [-0.051, 0.216, -0.052, 0.194, '#interesting', '#admirable', 0.102, 'conjecture', 'hypothetical', 'supposition', 'educate_guess', 'theory']
senticnet['scientific_term'] = [-0.05, 0.168, -0.045, 0.263, '#interesting', '#admirable', 0.112, 'scientific', 'method', 'science_term', 'physic_term', 'science_laboratory']
senticnet['scientist'] = [-0.05, 0.168, -0.045, 0.263, '#interesting', '#admirable', 0.112, 'science', 'study_science', 'philosopher', 'science_lab', 'science_laboratory']
senticnet['sciolist'] = [-0.982, 0, 0.937, -0.689, '#sad', '#angry', -0.869, 'amateur', 'dabbler', 'mortal', 'dilettante', 'bird_watcher']
senticnet['scissor'] = [0, 0, -0.999, -0.941, '#scared', '#disgusting', -0.647, 'clipper', 'pair_of_scissors', 'push_pin', 'razor', 'thumb_tack']
senticnet['scissure'] = [0.719, -0.572, 0, 0.651, '#joyful', '#admirable', 0.647, 'chap', 'break', 'slit', 'gap', 'shift']
senticnet['sclerosis'] = [-0.783, 0, 0.764, -0.741, '#sad', '#angry', -0.763, 'osteosclerosis', 'disease', 'disseminated_sclerosis', 'multiple_sclerosis', 'pathology']
senticnet['sclerotinia'] = [-0.872, 0, 0.723, -0.946, '#sad', '#disgusting', -0.847, 'potato_wart_fungus', 'bottom_rot_fungus', 'potato_fungus', 'black_root_rot_fungus', 'fungus']
senticnet['scoff'] = [-0.806, 0, 0.512, -0.82, '#sad', '#disgusting', -0.713, 'bemock', 'jeer', 'tantalize', 'flout', 'chaff']
senticnet['scofflaw'] = [-0.535, 0, 0.825, -0.873, '#angry', '#disgusting', -0.744, 'criminal', 'outlaw', 'malefactor', 'felon', 'crook']
senticnet['scold'] = [0, 0, -0.871, 0, '#scared', '#scared', -0.29, 'reprimand', 'jail_time', 'feel_stressed', 'go_to_prison', 'feel_anger']
senticnet['scolder'] = [-0.718, 0, 0.972, -0.625, '#sad', '#angry', -0.772, 'scold', 'nag', 'harridan', 'nagger', 'common_scold']
senticnet['scolding'] = [-0.792, 0, 0.906, -0.769, '#sad', '#angry', -0.822, 'reprimand', 'wigging', 'rebuke', 'reproof', 'reproval']
senticnet['scope_out_information'] = [-0.05, 0.168, -0.045, 0.263, '#interesting', '#admirable', 0.112, 'find_information', 'enhance_knowledge', 'knowledge', 'find_out', 'information']
senticnet['score'] = [0.783, 0.71, 0, 0, '#joyful', '#interesting', 0.498, 'score_goal', 'accomplish', 'finalize', 'pot', 'make_point']
senticnet['score_goal'] = [0, 0, 0, 0.717, '#admirable', '#admirable', 0.239, 'score', 'make_point', 'accomplish_goal', 'success', 'score_point']
senticnet['score_home_run'] = [0.064, 0.203, 0.014, 0.202, '#interesting', '#admirable', 0.152, 'compete', 'compete_against', 'blue_ribbon', 'play_baseball', 'play_hockey']
senticnet['score_homer'] = [-0.039, 0.085, 0, 0.078, '#interesting', '#admirable', 0.041, 'compete_against', 'conquer_opponent', 'reach_advantage', 'score_home_run', 'win_baseball_game']
senticnet['score_point'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'score_home_run', 'score_goal', 'run_first_base', 'win_game', 'strike_out']
senticnet['score_touchdown'] = [0.924, 0.968, 0, 0.876, '#joyful', '#interesting', 0.923, 'win_game', 'score', 'make_crowd_wave', 'pride', 'score_goal']
senticnet['scorn'] = [0, 0, -0.785, 0, '#scared', '#scared', -0.262, 'despise', 'wicked', 'dislike', 'isolation', 'loathsome']
senticnet['scorpion'] = [0, 0, -0.872, 0, '#scared', '#scared', -0.291, 'beetle', 'many_insects', 'grasshopper', 'firefly', 'mouse']
senticnet['scotch'] = [0, -0.886, 0, 0.93, '#surprising', '#admirable', 0.605, 'score', 'economical', 'scotch_whiskey', 'spoil', 'scottish']
senticnet['scotch_tape'] = [0.783, 0.905, 0, 0, '#joyful', '#interesting', 0.563, 'handout', 'fountain_pen', 'pen', 'stamp_pad', 'scrap_paper']
senticnet['scoundrel'] = [-0.889, 0, 0.806, -0.638, '#sad', '#angry', -0.778, 'blackguard', 'cad', 'bounder', 'rogue', 'hound']
senticnet['scrabble'] = [0.737, -0.839, 0, 0, '#joyful', '#surprising', 0.525, 'verbosity', 'sport_play', 'excite_game', 'contest', 'fun_game']
senticnet['scrambled'] = [-0.988, 0, 0.811, -0.958, '#sad', '#disgusting', -0.919, 'unmethodical', 'upset', 'confused', 'disorganized', 'undone']
senticnet['scrap'] = [-0.033, 0, 0.072, -0.131, '#angry', '#disgusting', -0.079, 'sturdy', 'funny_look', 'mine_ore', 'elements', 'hard_rock']
senticnet['scrap_paper'] = [0, -0.027, 0.08, -0.04, '#angry', '#disgusting', -0.031, 'stamp_pad', 'pen', 'post_note', 'stationery', 'intern']
senticnet['scrape'] = [-0.112, -0.073, 0.015, -0.154, '#sad', '#disgusting', -0.069, 'laceration', 'gash', 'sever', 'open_wind', 'copy_paste']
senticnet['scrape_along'] = [-0.935, 0, 0.744, -0.961, '#sad', '#disgusting', -0.88, 'manage', 'make_out', 'cope', 'get_by', 'make_do']
senticnet['scrape_by'] = [-0.811, 0, 0.929, -0.523, '#sad', '#angry', -0.754, 'manage', 'make_out', 'cope', 'get_by', 'make_do']
senticnet['scrapheap'] = [-0.9, 0, 0.602, -0.895, '#sad', '#disgusting', -0.799, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'wasteyard']
senticnet['scratch'] = [-0.131, -0.034, 0.088, -0.187, '#sad', '#disgusting', -0.124, 'itch', 'cut_finger', 'sting', 'copy_paste', 'draw_blood']
senticnet['scratch_along'] = [-0.916, 0, 0.688, -0.792, '#sad', '#disgusting', -0.799, 'manage', 'make_out', 'cope', 'get_by', 'make_do']
senticnet['scratch_back'] = [-0.069, 0, 0, -0.046, '#sad', '#disgusting', -0.038, 'knock_door', 'eat_animal', 'hurt_animal', 'form_sentence', 'piece_together']
senticnet['scratch_head'] = [0, 0, 0.749, -0.724, '#angry', '#disgusting', -0.491, 'get_nervous', 'write_essay', 'chew_pencil', 'write_down', 'look_clock']
senticnet['scratch_itch'] = [0, 0, 0, -0.982, '#disgusting', '#disgusting', -0.327, 'wind_watch', 'knock_door', 'blow_up_balloon', 'drink_espresso', 'master_skill']
senticnet['scratchy'] = [0, 0, 0.102, -0.03, '#angry', '#disgusting', -0.044, 'fabric_type', 'type_of_cloth', 'fabric_material', 'woven_fabric', 'cloth_fabric']
senticnet['scrawl'] = [-0.509, 0, 0.739, -0.521, '#angry', '#disgusting', -0.59, 'squiggle', 'hand', 'chicken_scratch', 'handwriting', 'script']
senticnet['scrawny'] = [0, 0, 0.956, -0.963, '#angry', '#disgusting', -0.64, 'scraggy', 'boney', 'underweight', 'skinny', 'weedy']
senticnet['scream'] = [0, 0, -0.809, 0, '#scared', '#scared', -0.27, 'shout', 'yell', 'annoy_other_person', 'groan', 'cry_help']
senticnet['scream_real_loud'] = [0, 0.111, 0, 0.121, '#interesting', '#admirable', 0.077, 'know_language', 'use_language', 'speak_write', 'dial_telephone', 'ability_communicate']
senticnet['screaming'] = [0, 0, 0.799, -0.887, '#angry', '#disgusting', -0.562, 'shriek', 'screech', 'yell', 'howl', 'shout']
senticnet['screaming_meemies'] = [-0.729, 0, 0.526, -0.63, '#sad', '#disgusting', -0.628, 'mental_strain', 'nervous_strain', 'strain', 'jitters', 'nerves']
senticnet['screw'] = [0, -0.031, 0.012, 0.057, '#surprising', '#admirable', 0.025, 'power_drill', 'ratchet_screwdriver', 'nut_bolt', 'pulley', 'wrench']
senticnet['screw_up'] = [0, 0, 0.717, -0.801, '#angry', '#disgusting', -0.506, 'disrespect', 'meanness', 'cause_suffer', 'leave_out', 'feel_stressed']
senticnet['screwdriver'] = [0, 0, -0.757, -0.963, '#scared', '#disgusting', -0.573, 'power_drill', 'drill_bite', 'air_pump', 'adjustable_wrench', 'drill']
senticnet['scribble'] = [-0.928, 0, 0.655, -0.524, '#sad', '#angry', -0.702, 'squiggle', 'hand', 'chicken_scratch', 'handwriting', 'script']
senticnet['scrimpy'] = [-0.653, 0, 0.645, -0.765, '#sad', '#disgusting', -0.688, 'miserable', 'scanty', 'exiguous', 'spare', 'hardscrabble']
senticnet['scrimy'] = [-0.919, 0, 0.598, -0.522, '#sad', '#angry', -0.68, 'parsimonious', 'penurious', 'stingy', 'beggarly', 'chintzy']
senticnet['script'] = [-0.04, 0.069, 0, 0.075, '#interesting', '#admirable', 0.035, 'pencil_mark', 'use_ink', 'pen_and_paper', 'pencil_paper', 'use_pen']
senticnet['scripture'] = [0, 0.083, 0, 0.116, '#interesting', '#admirable', 0.066, 'prose', 'poetry', 'text', 'chapter', 'written_text']
senticnet['scroll'] = [0.022, 0, 0, 0.077, '#joyful', '#admirable', 0.033, 'wave', 'farewell', 'wave_wind', 'twist', 'wrap_around']
senticnet['scrotum'] = [0, 0, 0.021, -0.063, '#angry', '#disgusting', -0.028, 'skin', 'skeletal_system', 'shoulder', 'cuticle', 'groin']
senticnet['scrub'] = [0, 0.066, 0, 0.067, '#interesting', '#admirable', 0.044, 'wash_body', 'wash_oneself', 'soap_up', 'clean_oneself', 'use_water_soap']
senticnet['scrub_floor'] = [-0.106, 0, 0, 0, '#sad', '#sad', -0.035, 'refrigerate', 'mow_grass', 'fill_bottle', 'mop_floor', 'floor']
senticnet['scrubby'] = [-0.863, 0, 0.665, -0.616, '#sad', '#angry', -0.715, 'brambly', 'braky', 'rushy', 'wooded', 'forested']
senticnet['scrumble_egg'] = [0.995, 0, 0, 0.71, '#joyful', '#admirable', 0.568, 'beat_egg', 'heat_meal', 'pan', 'breakfast', 'food']
senticnet['scruple'] = [0.587, -0.839, 0, 0.907, '#surprising', '#admirable', 0.778, 'morality', 'wee_small_voice', 'small_voice', 'voice_of_conscience', 'sense_of_shame']
senticnet['scrutinize'] = [0, 0, -0.705, -0.763, '#scared', '#disgusting', -0.489, 'scrutinise', 'inspect', 'size_up', 'take_stock', 'audit']
senticnet['scrutiny'] = [-0.764, 0, 0, -0.734, '#sad', '#disgusting', -0.499, 'scan', 'checkup', 'medical_checkup', 'medical_examination', 'medical_exam']
senticnet['scuba_dive'] = [0.869, 0.948, 0, 0, '#joyful', '#interesting', 0.606, 'go_underwater', 'swim', 'fall_overboard', 'dive', 'pool_party']
senticnet['scuba_diver'] = [0, 0.07, 0, 0, '#interesting', '#interesting', 0.023, 'sunken_treasure', 'real_duck', 'urchin', 'mussel', 'gold_fish']
senticnet['scuba_gear'] = [-0.04, 0.069, 0, 0.075, '#interesting', '#admirable', 0.035, 'go_to_swimming_pool', 'scuba', 'learn_swimming', 'jump_into_water', 'enjoy_nature']
senticnet['scuff'] = [-0.541, 0, 0.612, -0.987, '#angry', '#disgusting', -0.713, 'carpet_slipper', 'mule', 'bootee', 'bootie', 'footwear']
senticnet['sculpt_gel'] = [-0.04, 0.069, 0, 0.075, '#interesting', '#admirable', 0.035, 'gel', 'hairstyle', 'hairdresser', 'cosmetic', 'hair_gel']
senticnet['sculpture'] = [0.044, 0, 0, 0.084, '#joyful', '#admirable', 0.043, 'art', 'art_object', 'painting', 'artwork', 'oil_paint']
senticnet['scumbag'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'douche', 'bastard', 'asshole', 'motherfucker', 'dick']
senticnet['scummy'] = [-0.722, 0, 0.569, -0.861, '#sad', '#disgusting', -0.717, 'abject', 'scurvy', 'miserable', 'contemptible', 'pathetic']
senticnet['scurrility'] = [-0.813, 0, 0.827, -0.53, '#sad', '#angry', -0.723, 'abuse', 'vilification', 'insult', 'revilement', 'contumely']
senticnet['scurvy'] = [-0.722, 0, 0.569, -0.861, '#sad', '#disgusting', -0.717, 'abject', 'contemptible', 'miserable', 'scummy', 'pathetic']
senticnet['scuttle'] = [0, 0, -0.911, -0.998, '#scared', '#disgusting', -0.636, 'skitter', 'hatchway', 'scamper', 'opening', 'scurry']
senticnet['scuttlebutt'] = [-0.709, 0, 0.965, -0.535, '#sad', '#angry', -0.736, 'earful', 'malicious_gossip', 'talk_of_town', 'talk', 'scandal']
senticnet['sea'] = [0.044, 0, 0, 0.084, '#joyful', '#admirable', 0.043, 'ocean', 'atlantic_ocean', 'sea_movement', 'pacific_ocean', 'lake']
senticnet['sea_bass'] = [0, 0.959, 0, 0.866, '#interesting', '#admirable', 0.608, 'fish_trout', 'catch_butterfly', 'fish_lake', 'fish_compliment', 'fish_stream']
senticnet['sea_bed'] = [-0.044, -0.015, 0.103, 0, '#sad', '#angry', -0.044, 'near_beach', 'along_beach', 'full_water', 'ocean_ground', 'salty']
senticnet['sea_bottom'] = [0.979, -0.75, 0, 0.764, '#joyful', '#admirable', 0.831, 'ocean_floor', 'sea_floor', 'ocean_bottom', 'seabed', 'twilight_zone']
senticnet['sea_breeze'] = [0.931, 0, 0, 0.898, '#joyful', '#admirable', 0.61, 'breeze', 'wind', 'breezy', 'air_movement', 'air']
senticnet['sea_change'] = [0.556, -0.923, 0, 0.762, '#surprising', '#admirable', 0.747, 'degeneration', 'improvement', 'betterment', 'transformation', 'strengthening']
senticnet['sea_floor'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'ocean_edge', 'ocean_floor', 'bottom_ocean', 'surface_earth', 'seabed']
senticnet['sea_god'] = [0.978, -0.88, 0, 0.785, '#joyful', '#surprising', 0.881, 'daemon', 'demigod', 'divinity', 'sun_god', 'goddess']
senticnet['sea_lawyer'] = [0.587, -0.67, 0, 0.729, '#surprising', '#admirable', 0.662, 'mariner', 'seaman', 'tar', 'old_salt', 'seafarer']
senticnet['sea_level'] = [0, 0.103, 0, 0, '#interesting', '#interesting', 0.034, 'room_temperature', 'car_race', 'load_dock', 'smithsonian', 'auction']
senticnet['sea_life'] = [-0.202, -0.108, 0.07, -0.245, '#sad', '#disgusting', -0.136, 'gill', 'flipper', 'seafood', 'swim_animal', 'fillet']
senticnet['sea_mammal'] = [0, -0.101, 0, 0, '#surprising', '#surprising', 0.034, 'mammal', 'type_of_animal', 'animal', 'baby_deer', 'water_mammal']
senticnet['sea_movement'] = [-0.813, 0, -0.853, 0, '#sad', '#scared', -0.555, 'ocean_movement', 'fast_water', 'water_motion', 'water_movement', 'ebb']
senticnet['sea_pollution'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'panda', 'hunting', 'air_pollution', 'global_warming', 'endangered_species']
senticnet['sea_power'] = [-0.841, 0, 0.86, -0.732, '#sad', '#angry', -0.811, 'strength', 'military_capability', 'military_strength', 'military_posture', 'posture']
senticnet['sea_shell'] = [0, 0, 0, -0.073, '#disgusting', '#disgusting', -0.024, 'driftwood', 'naked_woman', 'scenic_view', 'shore', 'tidal_wave']
senticnet['sea_shore'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'ocean_edge', 'water_beach', 'bottom_ocean', 'seashore', 'palm_tree']
senticnet['sea_view'] = [0.046, -0.03, 0, 0, '#joyful', '#surprising', 0.025, 'breeze', 'bay_window', 'natural_air', 'seashore', 'sand']
senticnet['sea_wee'] = [0, 0.709, 0, 0.812, '#interesting', '#admirable', 0.507, 'porpoise', 'many_fishes', 'seahorse', 'horizon', 'mermaid']
senticnet['seafood'] = [-0.943, 0, 0.891, -0.939, '#sad', '#disgusting', -0.924, 'peanut', 'cause_allergy', 'wrong_food', 'sick', 'allergy_symptom']
senticnet['seagoing_vessel'] = [0.042, 0, 0.033, 0.068, '#joyful', '#admirable', 0.026, 'stalin', 'sail_sea', 'yacht', 'hull', 'water_vehicle']
senticnet['seal'] = [-0.944, 0, 0.569, -0.721, '#sad', '#disgusting', -0.745, 'bitumastic', 'veneer', 'veneering', 'lacquer', 'coating']
senticnet['seal_of_approval'] = [0.682, -0.705, 0, 0.98, '#surprising', '#admirable', 0.789, 'prize', 'laurels', 'honorable_mention', 'aliyah', 'cachet']
senticnet['seal_off'] = [-0.78, 0, 0.725, -0.953, '#sad', '#disgusting', -0.819, 'assail', 'blockade', 'besiege', 'ebb', 'attack']
senticnet['seam'] = [-0.048, -0.01, 0.026, -0.127, '#sad', '#disgusting', -0.064, 'embroidery', 'cover_wind', 'use_needle', 'bandage', 'sew_term']
senticnet['seamanship'] = [0.764, -0.963, 0, 0.883, '#surprising', '#admirable', 0.87, 'boatmanship', 'acquirement', 'skill', 'accomplishment', 'acquisition']
senticnet['seamstress'] = [-0.039, -0.034, 0.056, -0.104, '#angry', '#disgusting', -0.055, 'embroidery', 'clothes_repair', 'use_needle', 'weave', 'woman_garment']
senticnet['search'] = [-0.072, 0.095, 0, 0.111, '#interesting', '#admirable', 0.045, 'seek_out', 'locate', 'look_behind', 'seek', 'find']
senticnet['search_information'] = [0.203, 0.077, 0, 0.189, '#joyful', '#admirable', 0.156, 'information', 'search', 'research', 'use_internet', 'check_email']
senticnet['search_internet'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'visit_library', 'buy_textbook', 'buy_book', 'use_telescope', 'study_history']
senticnet['search_item'] = [0.11, 0.253, -0.078, 0.146, '#interesting', '#admirable', 0.144, 'buy_diamond_ring', 'know_want', 'find_out_want', 'look_catalog', 'head_start']
senticnet['seashell'] = [0, 0.069, 0, 0.122, '#interesting', '#admirable', 0.064, 'sand_rock', 'sandy', 'sea_shell', 'sand', 'place_camp']
senticnet['seashore'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'ocean_edge', 'water_beach', 'bottom_ocean', 'sea_shore', 'palm_tree']
senticnet['seaside'] = [0.203, 0.077, 0, 0.189, '#joyful', '#admirable', 0.156, 'good_life', 'coast', 'relax', 'sediment', 'shell']
senticnet['seaside_centaury'] = [-0.902, 0, 0.726, -0.534, '#sad', '#angry', -0.721, 'broad_leaved_centaury', 'rosita', 'lesser_centaury', 'tufted_centaury', 'centaury']
senticnet['season_dish'] = [0.061, 0, 0, 0.078, '#joyful', '#admirable', 0.046, 'fry_fish', 'fry_egg', 'season_meal', 'fry_chicken', 'make_cake']
senticnet['season_food'] = [0, -0.906, 0, 0.93, '#surprising', '#admirable', 0.612, 'hungry', 'prepare_breakfast', 'set_table', 'open_refrigerator', 'prepare_dinner']
senticnet['season_meal'] = [0.061, 0, 0, 0.078, '#joyful', '#admirable', 0.046, 'fry_fish', 'fry_egg', 'fry_chicken', 'season_dish', 'make_cake']
senticnet['season_year'] = [-0.806, 0, -0.737, 0, '#sad', '#scared', -0.514, 'snowy', 'cool_temperature', 'coldness', 'ice_rain', 'chilly']
senticnet['seasoned_salt'] = [-0.866, 0, 0.982, -0.867, '#angry', '#disgusting', -0.905, 'flavorer', 'flavourer', 'flavoring', 'flavouring', 'seasoner']
senticnet['seasoner'] = [-0.866, 0, 0.982, -0.867, '#angry', '#disgusting', -0.905, 'flavorer', 'flavourer', 'flavoring', 'flavouring', 'seasoned_salt']
senticnet['seat'] = [0.033, -0.039, 0, 0, '#joyful', '#surprising', 0.024, 'chair', 'bench', 'couch', 'stool', 'coach_seat']
senticnet['seat_belt'] = [0.865, 0, 0, 0.984, '#joyful', '#admirable', 0.616, 'belt', 'see_well', 'lifesaver', 'life_coach', 'luck']
senticnet['seat_chair'] = [-0.049, 0, -0.062, -0.03, '#sad', '#scared', -0.047, 'leave_table', 'crowd_room', 'reciprocate', 'room_temperature', 'odds']
senticnet['seat_customer'] = [0.025, 0.084, 0, 0.062, '#interesting', '#admirable', 0.057, 'work_restaurant', 'serve', 'chore', 'cook_breakfast', 'take_order']
senticnet['seat_guest'] = [0.851, 0.99, 0, 0, '#joyful', '#interesting', 0.614, 'sit', 'sit_table', 'find_chair', 'clear_table', 'seat_person']
senticnet['seat_many_person'] = [-0.067, 0, -0.07, -0.036, '#sad', '#scared', -0.058, 'live_room', 'living_room', 'hotel_room', 'furniture_store', 'loft']
senticnet['seat_passenger'] = [0.928, 0.794, 0, 0, '#joyful', '#interesting', 0.574, 'travel_across_world', 'land_runway', 'cost_money', 'government_agreement', 'run_out_fuel']
senticnet['seat_person'] = [0.192, 0.132, -0.072, 0.25, '#joyful', '#admirable', 0.167, 'find_chair', 'place_to_sit', 'seat_guest', 'seat', 'sit_place']
senticnet['seaweed'] = [-0.659, 0, 0.523, -0.739, '#sad', '#disgusting', -0.64, 'confervoid_algae', 'alga', 'golden_algae', 'diatom', 'brown_algae']
senticnet['seborrheic_dermatitis'] = [-0.726, 0, 0.778, -0.98, '#angry', '#disgusting', -0.828, 'actinic_dermatitis', 'hypericism', 'diaper_rash', 'diaper_dermatitis', 'dermatitis']
senticnet['seborrheic_keratosis'] = [-0.848, 0, 0.581, -0.93, '#sad', '#disgusting', -0.786, 'keratosis_blennorrhagica', 'keratoderma_blennorrhagica', 'keratosis_pilaris', 'keratosis', 'verruca']
senticnet['sec'] = [0.192, 0.132, -0.072, 0.25, '#joyful', '#admirable', 0.167, 'know_time', 'past_present', 'unending', 'keep_track_time', 'remission']
senticnet['secern'] = [-0.636, 0, 0.657, -0.929, '#angry', '#disgusting', -0.741, 'separate', 'severalize', 'contrast', 'decouple', 'dissociate']
senticnet['secernate'] = [-0.565, 0, 0.592, -0.65, '#angry', '#disgusting', -0.602, 'separate', 'severalize', 'contrast', 'decouple', 'dissociate']
senticnet['second'] = [0.036, -0.04, 0, 0, '#joyful', '#surprising', 0.025, 'minute', 'minute_pendulum', 'hour', 'stopwatch', 'pendulum']
senticnet['second_base'] = [0, 0, -0.056, -0.067, '#scared', '#disgusting', -0.041, 'point_time', 'death_row', 'another_planet', 'loose_end', 'car_race']
senticnet['second_childhood'] = [-0.855, 0, 0.586, -0.792, '#sad', '#disgusting', -0.744, 'age', 'old_age', 'years', 'eld', 'geezerhood']
senticnet['second_hand'] = [-0.912, 0, 0.618, -0.932, '#sad', '#disgusting', -0.821, 'get_stolen', 'give_away', 'old_stuff', 'lose_wallet', 'away']
senticnet['second_sight'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'psychic_phenomenon', 'predict_future', 'parapsychology', 'precognition', 'foreknowledge']
senticnet['secondary'] = [0, 0, 0.828, -0.805, '#angry', '#disgusting', -0.544, 'lowly', 'petty', 'junior-grade', 'subaltern', 'lower-ranking']
senticnet['secondary_color'] = [0, 0.094, 0, 0, '#interesting', '#interesting', 0.031, 'color', 'painting', 'primary_color', 'bright_color', 'assortment']
senticnet['secrecy'] = [-0.137, -0.056, 0.009, -0.161, '#sad', '#disgusting', -0.084, 'pass_exam', 'please_teacher', 'demonstrate_knowledge', 'learn_fact', 'get_degree']
senticnet['secret'] = [0, 0.789, 0, 0.705, '#interesting', '#admirable', 0.498, 'untold', 'secret_agent', 'secret_organization', 'mysterious', 'mystic']
senticnet['secret_agent'] = [-0.054, 0.122, 0, 0.082, '#interesting', '#admirable', 0.05, 'critter', 'underground_animal', 'secret_organization', 'bad_eyesight', 'furry_creature']
senticnet['secret_organization'] = [0, 0, -0.788, -0.701, '#scared', '#disgusting', -0.496, 'soldier_group', 'army_unit', 'patriot', 'military_force', 'civil_war']
senticnet['secret_writing'] = [0.634, -0.738, 0, 0.974, '#surprising', '#admirable', 0.782, 'decompression', 'cryptography', 'coding', 'decipherment', 'steganography']
senticnet['secretary_bird'] = [-0.81, 0, 0.913, -0.858, '#angry', '#disgusting', -0.86, 'bird', 'hawk', 'eagle', 'vulture', 'bird_of_prey']
senticnet['secretiveness'] = [0.742, -0.839, 0, 0.889, '#surprising', '#admirable', 0.823, 'furtiveness', 'sneakiness', 'stealthiness', 'unsociability', 'unsociableness']
senticnet['sect'] = [0, 0.354, -0.116, 0.344, '#interesting', '#admirable', 0.194, 'jewish', 'protestant', 'religious', 'faith', 'spiritual']
senticnet['section'] = [0, 0.98, 0, 0.798, '#interesting', '#admirable', 0.593, 'part', 'segment', 'component', 'math_action', 'math_equation']
senticnet['secure'] = [0.07, 0.29, -0.093, 0.159, '#interesting', '#admirable', 0.142, 'hold_coin', 'safe', 'money_collector', 'hold_change', 'money_keeper']
senticnet['secureness'] = [-0.708, 0, 0.947, -0.957, '#angry', '#disgusting', -0.871, 'tautness', 'fixity', 'immovability', 'steadiness', 'firmness']
senticnet['security'] = [0.454, 0.661, -0.312, 0.337, '#joyful', '#interesting', 0.38, 'approval', 'sympathetic', 'close', 'fellow_feeling', 'sympathetically']
senticnet['security_airport'] = [0.069, 0.152, 0, 0.088, '#interesting', '#admirable', 0.103, 'security', 'safe_zone', 'metal_detector', 'security_area', 'security_system']
senticnet['security_area'] = [0.069, 0.152, 0, 0.088, '#interesting', '#admirable', 0.103, 'security', 'safe_zone', 'security_airport', 'metal_detector', 'security_system']
senticnet['security_belt'] = [0.928, 0.754, 0, 0, '#joyful', '#interesting', 0.561, 'life_ring', 'lifebelt', 'save_life', 'sailor', 'life_preserver']
senticnet['security_system'] = [0.069, 0.152, 0, 0.088, '#interesting', '#admirable', 0.103, 'security', 'safe_zone', 'security_airport', 'security_area', 'metal_detector']
senticnet['sedative'] = [0, 0, -0.709, -0.979, '#scared', '#disgusting', -0.563, 'lack_of_sleep', 'gyroscope', 'get_tired', 'exhaustion', 'tired_foot']
senticnet['seduction'] = [0.857, 0, 0, 0, '#joyful', '#joyful', 0.286, 'date', 'accuracy', 'sexy_woman', 'woo', 'enjoy_person']
senticnet['seductive'] = [0.969, -0.848, 0, 0.837, '#joyful', '#surprising', 0.885, 'alluring', 'enticing', 'tempting', 'beguiling', 'corrupting']
senticnet['sedum'] = [-0.592, 0, 0.942, -0.758, '#angry', '#disgusting', -0.764, 'livelong', 'herb', 'stonecrop', 'orpine', 'orpin']
senticnet['see_ability'] = [-0.039, 0.078, 0, 0.109, '#interesting', '#admirable', 0.049, 'vision', 'sight', 'eye_function', 'eye_sense', 'eyeball']
senticnet['see_action'] = [0.779, 0.787, 0, 0, '#joyful', '#interesting', 0.522, 'make_comparison', 'come_warranty', 'customer_service', 'see_movement', 'search']
senticnet['see_actor'] = [0.959, 0.809, 0, 0, '#joyful', '#interesting', 0.589, 'idol', 'fun', 'movie_actor', 'vip', 'fan']
senticnet['see_ad'] = [-0.76, 0, 0, -0.99, '#sad', '#disgusting', -0.583, 'eye_strain', 'learn_current_event', 'time_waste', 'change_opinion', 'find_out_new']
senticnet['see_advertisement'] = [-0.801, 0, 0, -0.746, '#sad', '#disgusting', -0.516, 'see_commercial', 'see_ad', 'eye_strain', 'laugh', 'learn_current_event']
senticnet['see_animal'] = [0.067, 0.083, -0.069, 0.15, '#interesting', '#admirable', 0.077, 'aquarium', 'zoo', 'animal', 'see_dog', 'see_cat']
senticnet['see_art'] = [0, -0.121, 0, 0, '#surprising', '#surprising', 0.04, 'read_news', 'read_letter', 'see_exhibit', 'hear_newsifact', 'hear_news']
senticnet['see_artifact'] = [0.056, -0.035, 0, 0.054, '#joyful', '#admirable', 0.048, 'analyze', 'stargazing', 'influence_public_decision', 'question_everything', 'examine']
senticnet['see_band'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'hear_sing', 'attend_rock_concert', 'see_beautiful_girl', 'hear_crowd_go_mad', 'go_stage']
senticnet['see_beautiful_girl'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'hear_sing', 'see_band', 'attend_rock_concert', 'hear_crowd_go_mad', 'go_stage']
senticnet['see_better'] = [-0.739, 0, 0, -0.864, '#sad', '#disgusting', -0.534, 'shatter', 'break_easily', 'open', 'magnify', 'shard']
senticnet['see_cat'] = [0.067, 0.083, -0.069, 0.15, '#interesting', '#admirable', 0.077, 'aquarium', 'zoo', 'animal', 'see_dog', 'see_animal']
senticnet['see_clearly'] = [0.067, 0.083, -0.069, 0.15, '#interesting', '#admirable', 0.077, 'see_better', 'wear_hat', 'put_liquid', 'procrastinate', 'drink_juice']
senticnet['see_commercial'] = [0.067, 0.083, -0.069, 0.15, '#interesting', '#admirable', 0.077, 'change_channel', 'see_advertisement', 'turn_on_tv', 'watch_commercial', 'sit_sofa']
senticnet['see_countryside'] = [0.872, 0.736, 0, 0, '#joyful', '#interesting', 0.536, 'sightsee', 'camera', 'electronics_device', 'charge_battery', 'go_to_another_place']
senticnet['see_different'] = [0.098, 0.165, -0.134, 0.284, '#interesting', '#admirable', 0.138, 'know', 'insight', 'learn', 'learn_much', 'great_understand']
senticnet['see_doctor'] = [-0.114, 0, -0.098, -0.117, '#sad', '#disgusting', -0.11, 'go_see_doctor', 'go_doctor', 'visit_doctor', 'blood_test', 'find_doctor']
senticnet['see_dog'] = [0, 0, -0.816, -0.871, '#scared', '#disgusting', -0.562, 'go_downhill', 'hit_tree', 'break_bone', 'break_leg', 'take_photo']
senticnet['see_dragon'] = [-0.646, 0, 0.911, -0.709, '#angry', '#disgusting', -0.755, 'headache', 'hallucinogen', 'illusion', 'distorted_vision', 'distorted_perception']
senticnet['see_exhibit'] = [0, -0.121, 0, 0, '#surprising', '#surprising', 0.04, 'read_news', 'read_letter', 'hear_news', 'see_artifact', 'see_art']
senticnet['see_eye'] = [-0.851, 0, -0.975, 0, '#sad', '#scared', -0.609, 'die_only_once', 'trust_friend', 'fight_other', 'wear_skirt', 'sleep_long_time']
senticnet['see_eye_dog'] = [0.056, 0.075, 0, 0.069, '#interesting', '#admirable', 0.067, 'slave_owner', 'future_robot', 'slave', 'type_of_dog', 'dog']
senticnet['see_far'] = [0.879, 0.897, 0, 0, '#joyful', '#interesting', 0.592, 'eat_dog', 'like_play', 'see_far_away', 'see_well_dark', 'control_weather']
senticnet['see_far_away'] = [0.93, -0.766, 0, 0, '#joyful', '#surprising', 0.565, 'want_know', 'see_star', 'take_beach', 'learn_history', 'learn_past']
senticnet['see_far_distance'] = [0, 0, -0.095, 0, '#scared', '#scared', -0.032, 'fall_dead', 'break_leg', 'take_photo', 'memory_loss', 'step_up']
senticnet['see_favorite_show'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'enjoy_film', 'watch_film', 'watch_movie', 'see_movie', 'take_film']
senticnet['see_film'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'show_movie', 'rewind', 'watch_movie', 'view_movie', 'jitters']
senticnet['see_fish'] = [0.751, 0, 0, 0, '#joyful', '#joyful', 0.25, 'wear_swimsuit', 'swim_underwater', 'family_fun', 'take_leak', 'explore_underwater']
senticnet['see_friend'] = [0.948, 0.744, 0, 0.984, '#joyful', '#admirable', 0.892, 'celebrate_occasion', 'celebrate_wedding', 'good_time', 'meet_member_opposite_sex', 'social_interaction']
senticnet['see_funny'] = [0.898, 0, 0, 0, '#joyful', '#joyful', 0.299, 'eat_candy', 'laugh_out_loud', 'laugh', 'laughter', 'entertain']
senticnet['see_future'] = [-0.053, 0.105, 0, 0.074, '#interesting', '#admirable', 0.042, 'come_up_new_idea', 'come_conclusion', 'figure_out', 'reach_conclusion', 'discuss_friend']
senticnet['see_happen'] = [-0.053, 0.105, 0, 0.074, '#interesting', '#admirable', 0.042, 'understand_current_event', 'get_news', 'learn_entertainment', 'view_art', 'keep_up_current_event']
senticnet['see_how_long_line'] = [-0.08, 0, 0, -0.07, '#sad', '#disgusting', -0.05, 'find_end_line', 'long_line', 'stand_queue', 'wait_patiently', 'wait_turn']
senticnet['see_idea_become_reality'] = [0.878, 0.777, 0, 0.85, '#joyful', '#admirable', 0.835, 'create_help_other_person', 'please_parent', 'give_assistance', 'make_better_world', 'get_contract']
senticnet['see_justice_done'] = [0, 0.097, 0, 0.059, '#interesting', '#admirable', 0.052, 'juror', 'judge', 'negotiator', 'punish_criminal', 'become_judge']
senticnet['see_know'] = [0, 0.926, 0, 0.824, '#interesting', '#admirable', 0.583, 'conduct_business', 'talk_person', 'make_hotel_reservation', 'make_deals', 'send_information']
senticnet['see_lawyer'] = [-0.219, 0.108, -0.134, 0, '#sad', '#scared', -0.082, 'hire_lawyer', 'hire_attorney', 'call_lawyer', 'contact_lawyer', 'go_court']
senticnet['see_light'] = [-0.285, 0, -0.238, -0.126, '#sad', '#scared', -0.216, 'put_box', 'battle_cancer', 'cry_help', 'say_prayer', 'go_scuba_dive']
senticnet['see_movement'] = [0, 0.927, 0, 0.875, '#interesting', '#admirable', 0.601, 'make_comparison', 'come_warranty', 'customer_service', 'see_action', 'search']
senticnet['see_movie'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'see_favorite_show', 'watch_film', 'watch_movie', 'enjoy_film', 'take_film']
senticnet['see_neighbor'] = [0, 0.097, 0, 0.059, '#interesting', '#admirable', 0.052, 'say_hi', 'neighbor', 'talk_neighbor', 'meet_neighbor', 'help_neighbor']
senticnet['see_new_place'] = [0.717, 0, 0, 0, '#joyful', '#joyful', 0.239, 'sightsee', 'see_world', 'enjoy_oneself', 'pastime', 'kill_time']
senticnet['see_night'] = [-0.103, 0, 0, -0.1, '#sad', '#disgusting', -0.068, 'spread_disease', 'go_stall', 'spot_prey', 'pet', 'hunt_food']
senticnet['see_ocean'] = [0.74, 0.784, 0, 0, '#joyful', '#interesting', 0.508, 'smooth_skin', 'complement', 'knowledgeable', 'taken_seriously', 'much_need']
senticnet['see_oneself'] = [0.97, -0.842, 0, 0, '#joyful', '#surprising', 0.604, 'experience_emotion', 'enjoy_art', 'masturbate', 'bored', 'fantasize']
senticnet['see_out'] = [0, 0.777, 0, 0.95, '#interesting', '#admirable', 0.576, 'look_out', 'look_outside', 'look_through', 'see_through', 'open_close']
senticnet['see_outside'] = [0, 0.89, 0, 0.875, '#interesting', '#admirable', 0.588, 'see_out', 'look_out', 'look_outside', 'open_close', 'house_front']
senticnet['see_performance'] = [0.806, 0.776, 0, 0.761, '#joyful', '#interesting', 0.781, 'appreciate_music', 'entertainment', 'music_lover', 'listen_pleasure', 'relieve_boredom']
senticnet['see_person'] = [0.114, 0.071, -0.059, 0.074, '#joyful', '#admirable', 0.067, 'go_club', 'go_art_gallery', 'social_skill', 'go_art_museum', 'amiable']
senticnet['see_picture'] = [0.114, 0.071, -0.059, 0.074, '#joyful', '#admirable', 0.067, 'picture', 'look_art', 'look_picture', 'take_picture', 'go_to_museum']
senticnet['see_play'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'buy_popcorn', 'go_movie_theater', 'drive_theater', 'go_to_theater', 'watch_movie']
senticnet['see_psychiatrist'] = [-0.109, -0.051, -0.114, -0.138, '#scared', '#disgusting', -0.103, 'think_again', 'use_gun', 'fire_weapon', 'wash_mouth_soap', 'lose_job']
senticnet['see_red'] = [-0.161, 0.179, 0.568, -0.612, '#angry', '#disgusting', -0.387, 'angrily', 'choler', 'ire', 'dander', 'hackles']
senticnet['see_sad_movie'] = [-0.059, 0, -0.071, 0, '#sad', '#scared', -0.043, 'cry', 'sad_movie', 'watch_sad_film', 'see_sad_show', 'chop_onion']
senticnet['see_sad_show'] = [-0.059, 0, -0.071, 0, '#sad', '#scared', -0.043, 'cry', 'sad_movie', 'watch_sad_film', 'chop_onion', 'see_sad_movie']
senticnet['see_show'] = [0.817, 0.78, 0, 0.971, '#joyful', '#admirable', 0.856, 'enjoy_performance', 'laugh_lot', 'make_out_date', 'feel_happy', 'go_date']
senticnet['see_sight'] = [0.932, 0, 0, 0, '#joyful', '#joyful', 0.311, 'travel', 'see_new_place', 'sightsee', 'see_countryside', 'go_to_another_place']
senticnet['see_sky'] = [0.798, 0.761, 0, 0, '#joyful', '#interesting', 0.52, 'explain_everything', 'deal_card_player', 'stand_alone', 'bridge_difference', 'forward_email']
senticnet['see_someone_play_game'] = [0.853, 0, 0, 0.711, '#joyful', '#admirable', 0.521, 'manga', 'cartoon', 'radio-control_helicopter', 'beat_off', 'anime']
senticnet['see_star'] = [0.804, 0, 0, 0.953, '#joyful', '#admirable', 0.586, 'experience_different_culture', 'see_actor', 'entertain_oneself', 'idolize_actor', 'see_oneself']
senticnet['see_star_night'] = [0.923, 0, 0, 0.777, '#joyful', '#admirable', 0.567, 'gather_berry', 'hang_picture_on_wall', 'recycle_paper', 'explain_everything', 'forward_email']
senticnet['see_sunrise'] = [-0.065, -0.05, 0.062, -0.066, '#sad', '#disgusting', -0.048, 'get_to_work_on_time', 'get_done', 'turn_off_alarm', 'work_hard', 'muscle_ache']
senticnet['see_through'] = [-0.034, 0.065, 0.012, 0.129, '#interesting', '#admirable', 0.049, 'clear_solid', 'see_thru', 'transparent', 'look_through', 'translucent']
senticnet['see_thru'] = [0, 0.759, 0, 0.716, '#interesting', '#admirable', 0.492, 'translucent', 'clear_solid', 'brittle', 'drink_container', 'transparent']
senticnet['see_to_it'] = [0.642, -0.532, 0, 0.575, '#joyful', '#admirable', 0.583, 'check', 'assure', 'see', 'insure', 'proofread']
senticnet['see_view'] = [0, 0.104, 0, 0.185, '#interesting', '#admirable', 0.096, 'scenic', 'quick_look', 'glimpse', 'ship_part', 'look']
senticnet['see_well'] = [0, 0, 0, 0.821, '#admirable', '#admirable', 0.274, 'speak_human_language', 'assert', 'build_city', 'live_forever', 'like_play']
senticnet['see_well_dark'] = [0.81, 0.834, 0, 0, '#joyful', '#interesting', 0.548, 'eat_dog', 'like_play', 'see_far_away', 'see_far', 'control_weather']
senticnet['see_world'] = [0.877, -0.922, 0, 0.795, '#joyful', '#surprising', 0.865, 'tourist', 'see_new_place', 'sightsee', 'kill_time', 'go_to_another_place']
senticnet['seeable'] = [0.654, -0.715, 0, 0.624, '#joyful', '#surprising', 0.664, 'viewable', 'gross', 'telescopic', 'panoptic', 'visual']
senticnet['seed'] = [0, 0.104, 0, 0.185, '#interesting', '#admirable', 0.096, 'seed_lawn', 'semen', 'pip', 'kernel', 'pit']
senticnet['seed_fern'] = [-0.772, 0, 0.585, -0.835, '#sad', '#disgusting', -0.731, 'progymnosperm', 'welwitschia', 'cycad', 'gymnosperm', 'pteridosperm']
senticnet['seed_lawn'] = [0.804, 0.945, 0, 0, '#joyful', '#interesting', 0.583, 'dig_grave', 'shoe_horse', 'bicycle_across_town', 'mine_diamond', 'age_gracefully']
senticnet['seed_plant'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'plant_seed', 'grow_flower', 'plant_garden', 'plant_flower', 'many_plants']
senticnet['seeing'] = [-0.739, 0, 0.814, -0.887, '#angry', '#disgusting', -0.813, 'contrast', 'perception', 'face_recognition', 'object_recognition', 'visual_space']
senticnet['seek'] = [-0.082, 0.107, -0.05, 0.185, '#interesting', '#admirable', 0.053, 'search', 'locate_out', 'locate', 'reveal', 'concede']
senticnet['seek_answer'] = [-0.07, -0.024, 0.014, -0.175, '#sad', '#disgusting', -0.078, 'report_news', 'learn_much', 'educate_oneself', 'know_world', 'increase_knowledge']
senticnet['seek_clarification'] = [0.932, 0.787, 0, 0, '#joyful', '#interesting', 0.573, 'learn_patience', 'discuss', 'understand_each_other', 'conformist_attitude', 'avoid_conflict']
senticnet['seek_entertainment'] = [0.705, 0, 0, 0.758, '#joyful', '#admirable', 0.488, 'interest_art', 'mindless_entertainment', 'see_actor', 'zone_out', 'eat_popcorn']
senticnet['seek_info'] = [0.757, 0.896, 0, 0.538, '#joyful', '#interesting', 0.73, 'ask_expert', 'remember_fact', 'remember_information', 'research', 'absorb_information']
senticnet['seek_justice'] = [-0.219, 0.108, -0.134, 0, '#sad', '#scared', -0.082, 'hire_lawyer', 'settle_dispute', 'verdict', 'call_lawyer', 'go_court']
senticnet['seek_knowledge'] = [0.757, 0, 0, 0, '#joyful', '#joyful', 0.252, 'add_knowledge', 'great_understand', 'know_fact', 'understand', 'learn']
senticnet['seek_out'] = [-0.067, 0.131, 0, 0.081, '#interesting', '#admirable', 0.048, 'columbus', 'find_america', 'eureka', 'find_out', 'aware']
senticnet['seek_psychiatric_help'] = [-0.073, 0, 0, -0.238, '#sad', '#disgusting', -0.104, 'prepare_go_jail', 'buy_weapon', 'find_victim', 'buy_gun', 'dangerous_weapon']
senticnet['seek_revenge'] = [-0.308, 0, -0.236, -0.206, '#sad', '#scared', -0.25, 'feel_remorse', 'die', 'feel_anger', 'imprisonment', 'death']
senticnet['seek_truth'] = [0, -0.938, 0, 0.997, '#surprising', '#admirable', 0.645, 'thirst_knowledge', 'teach_world', 'learn_new_fact', 'experience_new', 'learn_art']
senticnet['seek_understanding'] = [0, 0.802, 0, 0.921, '#interesting', '#admirable', 0.574, 'educate_others', 'tell_other_person', 'learn_fact', 'understand', 'increase_understand']
senticnet['seeker'] = [-0.029, 0, 0, -0.079, '#sad', '#disgusting', -0.036, 'manager', 'investigator', 'slut', 'chairperson', 'commuter']
senticnet['seemly'] = [0.83, 0.727, 0, 0, '#joyful', '#interesting', 0.519, 'comme_il_faut', 'comely', 'decorous', 'becoming', 'decent']
senticnet['seen_night_sky'] = [0.739, 0, 0, 0.791, '#joyful', '#admirable', 0.51, 'circle_shape', 'fill_with_sand', 'round_shape', 'ball_shape', 'round']
senticnet['segment'] = [0, 0.962, 0, 0.708, '#interesting', '#admirable', 0.557, 'part', 'component', 'portion', 'fraction', 'piece']
senticnet['segmented_worm'] = [-0.716, 0, 0.605, -0.623, '#sad', '#disgusting', -0.648, 'medicinal_leech', 'horseleech', 'annelid', 'annelid_worm', 'leech']
senticnet['seigneur'] = [-0.979, 0, 0.747, -0.741, '#sad', '#angry', -0.822, 'liege', 'liege_lord', 'master', 'overlord', 'lord']
senticnet['seigneury'] = [-0.711, 0, 0.917, -0.513, '#sad', '#angry', -0.714, 'demesne', 'estate', 'land', 'landed_estate', 'acre']
senticnet['seignior'] = [-0.971, 0, 0.798, -0.641, '#sad', '#angry', -0.803, 'liege', 'liege_lord', 'master', 'overlord', 'lord']
senticnet['seigniory'] = [-0.513, 0, 0.93, -0.857, '#angry', '#disgusting', -0.767, 'demesne', 'estate', 'land', 'landed_estate', 'acre']
senticnet['seizure'] = [-0.912, 0, -0.901, 0, '#sad', '#scared', -0.604, 'sequestration', 'kill_brain_cell', 'cry', 'bad_health', 'scared']
senticnet['selachian'] = [-0.54, 0, 0.983, -0.911, '#angry', '#disgusting', -0.811, 'elasmobranch', 'shark', 'hammerhead', 'cow_shark', 'mackerel_shark']
senticnet['seldom'] = [-0.706, 0, 0, -0.812, '#sad', '#disgusting', -0.506, 'worst', 'optional', 'change_someone_greatly', 'lass', 'temporary']
senticnet['select'] = [-0.051, 0.301, -0.079, 0.241, '#interesting', '#admirable', 0.137, 'selection', 'decision', 'make_choice', 'decide', 'choose']
senticnet['select_topic'] = [-0.051, 0.301, -0.079, 0.241, '#interesting', '#admirable', 0.137, 'topic', 'select', 'research_topic', 'decide', 'choose']
senticnet['selection'] = [0, 0.316, -0.127, 0.291, '#interesting', '#admirable', 0.16, 'select', 'decision', 'decide', 'choose', 'nominate']
senticnet['self-complacency'] = [0.788, 0.592, -0.207, 0.342, '#joyful', '#interesting', 0.505, 'complacent', 'complacency', 'complacence', 'self-satisfaction', 'self-complacent']
senticnet['self-complacent'] = [0.788, 0.592, -0.207, 0.342, '#joyful', '#interesting', 0.505, 'complacent', 'complacency', 'self-complacency', 'complacence', 'self-satisfaction']
senticnet['self-confidence'] = [0.468, 0.219, -0.209, 0.296, '#joyful', '#admirable', 0.258, 'good_emotion', 'like', 'better_person', 'ecstatic', 'enjoy']
senticnet['self-conscious'] = [0, 0, 0, 0.966, '#admirable', '#admirable', 0.322, 'self-consciousness', 'uncomfortableness', 'pride', 'bashfulness', 'mortification']
senticnet['self-consciousness'] = [0, 0, 0, 0.765, '#admirable', '#admirable', 0.255, 'self-conscious', 'uncomfortableness', 'happiness', 'bashfulness', 'mortification']
senticnet['self-deprecating'] = [-0.984, 0, 0, -0.937, '#sad', '#disgusting', -0.64, 'self-depreciation', 'submission', 'meekness', 'humbleness', 'demeaning']
senticnet['self-depreciation'] = [-0.951, 0, 0, -0.916, '#sad', '#disgusting', -0.622, 'self-deprecating', 'submission', 'meekness', 'humbleness', 'demeaning']
senticnet['self-discipline'] = [0.628, 0.57, 0, 0.579, '#joyful', '#admirable', 0.592, 'stressful_situation', 'part_of_band', 'beautiful_music', 'desire_information', 'chamber_music']
senticnet['self-disgust'] = [-0.714, 0, 0, -0.888, '#sad', '#disgusting', -0.534, 'self-hatred', 'humiliated', 'mortifying', 'mortified', 'shameful']
senticnet['self-distrust'] = [-0.752, 0, 0, -0.862, '#sad', '#disgusting', -0.538, 'diffidently', 'self-doubt', 'diffidence', 'shyness', 'hardheartedness']
senticnet['self-doubt'] = [-0.92, 0, 0, -0.747, '#sad', '#disgusting', -0.556, 'diffidently', 'self-distrust', 'diffidence', 'shyness', 'hardheartedness']
senticnet['self-esteem'] = [0.49, 0.652, -0.24, 0.233, '#joyful', '#interesting', 0.378, 'confident', 'encouragement', 'grateful', 'enthusiasm', 'thankful']
senticnet['self-fulfillment'] = [0.664, 0.903, 0, 0.597, '#joyful', '#interesting', 0.721, 'learn_sport', 'learn_new_skill', 'stimulate_mind', 'pass_knowledge', 'get_information']
senticnet['self-hatred'] = [-0.818, 0, 0, -0.952, '#sad', '#disgusting', -0.59, 'self-disgust', 'humiliated', 'mortifying', 'mortified', 'shameful']
senticnet['self-importance'] = [0.466, 0.663, -0.25, 0.228, '#joyful', '#interesting', 0.369, 'egotism', 'amour_propre', 'conceit', 'self-love', 'self-pride']
senticnet['self-love'] = [0.469, 0.661, -0.249, 0.23, '#joyful', '#interesting', 0.37, 'amour_propre', 'conceit', 'self-pride', 'egotism', 'self-importance']
senticnet['self-pity'] = [-0.879, 0.182, -0.592, 0, '#sad', '#scared', -0.43, 'mournful', 'bereaved', 'mourning', 'grieving', 'sorrowing']
senticnet['self-pride'] = [0.463, 0.662, -0.248, 0.225, '#joyful', '#interesting', 0.367, 'amour_propre', 'conceit', 'self-love', 'self-importance', 'egotism']
senticnet['self-reproach'] = [-0.894, 0.166, -0.614, 0.051, '#sad', '#scared', -0.43, 'compunction', 'rue', 'attrition', 'ruefully', 'contritely']
senticnet['self-satisfaction'] = [0.788, 0.592, -0.207, 0.342, '#joyful', '#interesting', 0.505, 'complacent', 'complacency', 'self-complacency', 'complacence', 'self-complacent']
senticnet['self-satisfied'] = [0.796, 0.588, -0.205, 0.344, '#joyful', '#interesting', 0.508, 'proudly', 'preen', 'smug', 'smugness', 'complacence']
senticnet['self_adhesive_label'] = [0.832, 0.738, 0, 0, '#joyful', '#interesting', 0.523, 'paper_punch', 'intern', 'memo_pad', 'notepad', 'paper_clip']
senticnet['self_confidence'] = [0.817, 0, 0, 0.982, '#joyful', '#admirable', 0.6, 'big_paycheck', 'look_beautiful', 'find_money', 'take_out_loan', 'slogan']
senticnet['self_contemplation'] = [0.08, 0.153, -0.125, 0.224, '#interesting', '#admirable', 0.111, 'meditation', 'introspection', 'soul_searching', 'self_examination', 'self_observation']
senticnet['self_defense'] = [0, 0, 0.963, -0.701, '#angry', '#disgusting', -0.555, 'target_practice', 'kill_enemy', 'kill_pest', 'murder', 'protect_country']
senticnet['self_discipline'] = [-0.053, 0.117, -0.115, 0.134, '#interesting', '#admirable', 0.028, 'time_effort', 'persistence', 'require', 'open_mind', 'new_experience']
senticnet['self_esteem'] = [0, 0, 0, 0.784, '#admirable', '#admirable', 0.261, 'live_well', 'better_life', 'accomplish_goal', 'live_long_happy_life', 'nice_place_to_live']
senticnet['self_examination'] = [0.08, 0.153, -0.125, 0.224, '#interesting', '#admirable', 0.111, 'meditation', 'self_contemplation', 'soul_searching', 'introspection', 'self_observation']
senticnet['self_expression'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'creative_expression', 'pastime', 'artistic_expression', 'date_activity', 'make_beautiful']
senticnet['self_observation'] = [0.08, 0.153, -0.125, 0.224, '#interesting', '#admirable', 0.111, 'meditation', 'self_contemplation', 'soul_searching', 'self_examination', 'introspection']
senticnet['self_protection'] = [0.059, 0.212, 0, 0.143, '#interesting', '#admirable', 0.138, 'safe', 'protect', 'protection', 'protect_family', 'self_esteem']
senticnet['self_respect'] = [0, 0, 0, 0.816, '#admirable', '#admirable', 0.272, 'financial_security', 'strong_relationship', 'qualify', 'happiness', 'prototype']
senticnet['self_satisfaction'] = [0.332, 0.103, -0.088, 0, '#joyful', '#interesting', 0.116, 'good_feeling', 'happiness', 'serenity', 'feel_good', 'become_happy']
senticnet['selfish'] = [0, 0, 0, -0.923, '#disgusting', '#disgusting', -0.308, 'ridiculous', 'ignorant', 'insane', 'medical_problem', 'end_life']
senticnet['selfishness'] = [-0.813, 0, 0.886, -0.656, '#sad', '#angry', -0.785, 'opportunism', 'greediness', 'rapaciousness', 'voraciousness', 'expedience']
senticnet['sell'] = [-0.038, 0.139, 0, 0.109, '#interesting', '#admirable', 0.07, 'exchange_money', 'purchase', 'sell_goods', 'make_rich', 'incur_debt']
senticnet['sell_beer'] = [0.217, -0.198, 0.096, 0, '#joyful', '#surprising', 0.106, 'like_win', 'long_tube', 'fun_place', 'recreational', 'get_hammered']
senticnet['sell_book'] = [-0.093, -0.024, 0.018, -0.082, '#sad', '#disgusting', -0.056, 'buy_magazine', 'explain_problem', 'buy_book', 'pick_tooth', 'purchase_book']
senticnet['sell_car'] = [0, 0, 0, -0.077, '#disgusting', '#disgusting', -0.026, 'car_dealership', 'truck_stop', 'vehicle', 'insurance', 'car']
senticnet['sell_food'] = [0, 0.115, 0, 0.106, '#interesting', '#admirable', 0.074, 'keep_food', 'keep_fresh', 'ship_goods', 'keep_safe', 'keep_food_spoil']
senticnet['sell_goods'] = [0, 0.078, 0, 0.099, '#interesting', '#admirable', 0.059, 'exchange_money', 'buy_sell', 'sell', 'make_rich', 'acquire_goods']
senticnet['sell_grocery_store'] = [0.04, 0, 0, 0.067, '#joyful', '#admirable', 0.036, 'find_plant', 'court_action', 'add_flavor', 'ingredient', 'preserve_food']
senticnet['sell_house'] = [-0.036, 0.149, -0.063, 0.14, '#interesting', '#admirable', 0.063, 'live_house', 'name_street', 'address', 'house_location', 'part_of_company']
senticnet['sell_insurance'] = [-0.075, 0, 0, -0.062, '#sad', '#disgusting', -0.046, 'finish_work', 'pay_child_support', 'work_team', 'get_out_of_bed', 'arrive_work']
senticnet['sell_item'] = [0, 0, 0.074, -0.036, '#angry', '#disgusting', -0.037, 'look_buy', 'sell_object', 'make_purchase', 'get_need', 'acquire_goods']
senticnet['sell_new_book'] = [0, 0, 0.937, -0.879, '#angry', '#disgusting', -0.605, 'make_porn', 'deal_drug', 'go_off_strike', 'go_public', 'open_business']
senticnet['sell_object'] = [0, 0, 0.074, -0.036, '#angry', '#disgusting', -0.037, 'look_buy', 'sell_item', 'make_purchase', 'get_need', 'acquire_goods']
senticnet['sell_out'] = [-0.045, 0.09, -0.155, -0.121, '#scared', '#disgusting', -0.077, 'bigot', 'censorship', 'loss_oflife', 'taunt', 'sleepless_night']
senticnet['sell_popcorn'] = [0.933, -0.757, 0, 0, '#joyful', '#surprising', 0.563, 'enter_theater', 'show_movie', 'watch_play', 'like_movie', 'proof_of_purchase']
senticnet['sell_sandwich'] = [0.046, 0.071, 0, 0.066, '#interesting', '#admirable', 0.061, 'go_grocery_store', 'go_supermarket', 'provide_family', 'money_buy', 'plan_meal']
senticnet['sell_stock'] = [-0.226, 0.15, -0.225, 0.09, '#sad', '#scared', -0.07, 'borrow_money', 'count_money', 'lack_money', 'negotiate', 'close_deal']
senticnet['sell_store'] = [0, 0.128, 0.046, 0.1, '#interesting', '#admirable', 0.061, 'store_bottle', 'ship_goods', 'increase_value', 'fill_glass', 'lick_finger']
senticnet['sell_stuff'] = [-0.041, 0.081, 0.037, 0.084, '#interesting', '#admirable', 0.029, 'small_shop', 'store', 'stock_exchange', 'shop', 'sell_goods']
senticnet['sell_ticket'] = [-0.082, 0.066, -0.054, -0.067, '#sad', '#disgusting', -0.046, 'collect_ticket', 'buy_ticket', 'purchase_ticket', 'pay_ticket', 'book_ticket']
senticnet['sell_vegetable'] = [-0.032, -0.004, 0.043, -0.076, '#angry', '#disgusting', -0.049, 'decide_eat', 'fix_breakfast', 'prepare_breakfast', 'piece_of_meat', 'choose_eat']
senticnet['seller'] = [-0.034, 0.119, 0, 0.095, '#interesting', '#admirable', 0.06, 'merchant', 'exchange_goods', 'trade', 'bazaar', 'vend']
senticnet['semantic_error'] = [-0.985, 0, 0.869, -0.803, '#sad', '#angry', -0.886, 'error', 'syntax_error', 'programming_error', 'runtime_error', 'computer_error']
senticnet['semblance'] = [-0.818, 0, 0.838, -0.758, '#sad', '#angry', -0.805, 'pretence', 'pretense', 'pretext', 'simulacrum', 'face_value']
senticnet['semester'] = [0, -0.018, -0.045, -0.082, '#scared', '#disgusting', -0.036, 'term', 'end_sentence', 'undergraduate', 'class', 'long_ago']
senticnet['semi-truck'] = [0.05, 0.086, 0, 0, '#joyful', '#interesting', 0.045, 'flight_terminal', 'traffic_artery', 'fire_hydrant', 'park_zone', 'human_hair']
senticnet['semiautomatic'] = [0.978, -0.576, 0, 0.793, '#joyful', '#admirable', 0.782, 'pistol', 'handgun', 'side_arm', 'shooting_iron', 'semiautomatic_firearm']
senticnet['semiautomatic_firearm'] = [0.978, -0.576, 0, 0.793, '#joyful', '#admirable', 0.782, 'pistol', 'handgun', 'side_arm', 'shooting_iron', 'semiautomatic']
senticnet['semiautomatic_pistol'] = [0.646, -0.79, 0, 0.572, '#joyful', '#surprising', 0.669, 'pistol', 'handgun', 'side_arm', 'shooting_iron', 'semiautomatic_firearm']
senticnet['semicircle'] = [0.966, 0, 0, 0.989, '#joyful', '#admirable', 0.652, 'circle', 'loop', 'arc', 'no_edge', 'trapezoid']
senticnet['semidarkness'] = [-0.62, 0, 0.72, -0.515, '#sad', '#angry', -0.618, 'overcast', 'dark', 'obscureness', 'darkness', 'dimness']
senticnet['semilunar_bone'] = [-0.744, 0, 0.598, -0.756, '#sad', '#disgusting', -0.699, 'lunate_bone', 'carpal', 'carpal_bone', 'triquetral', 'triquetral_bone']
senticnet['semilunar_cartilage'] = [-0.536, 0, 0.982, -0.671, '#angry', '#disgusting', -0.73, 'meniscus', 'gristle', 'fibrocartilage', 'hyaline_cartilage', 'arytenoid']
senticnet['semitone'] = [-0.652, 0, 0.681, -0.943, '#angry', '#disgusting', -0.759, 'tone', 'whole_tone', 'step', 'whole_step', 'musical_interval']
senticnet['senator'] = [0, 0.851, 0, 0.746, '#interesting', '#admirable', 0.532, 'egalitarian', 'politician', 'pioneer', 'gentleman', 'rogue']
senticnet['send'] = [0, 0.166, -0.134, 0.275, '#interesting', '#admirable', 0.102, 'deliver', 'give_out', 'express', 'post', 'cope']
senticnet['send_around'] = [0.517, -0.672, 0, 0.549, '#surprising', '#admirable', 0.579, 'circularize', 'circulate', 'pass_around', 'pass_on', 'distribute']
senticnet['send_back'] = [-0.078, 0.13, -0.073, 0.249, '#interesting', '#admirable', 0.076, 'write_back', 'retort', 'question_answer', 'elaborate', 'answer_back']
senticnet['send_card'] = [0.964, 0, 0, 0.751, '#joyful', '#admirable', 0.572, 'need_communicate', 'send_flower', 'yearly_celebration', 'show_care', 'send_gift']
senticnet['send_down'] = [-0.88, 0, 0.903, -0.504, '#sad', '#angry', -0.762, 'debar', 'rusticate', 'expel', 'throw_out', 'kick_out']
senticnet['send_email'] = [0, 0.924, 0, 0.963, '#interesting', '#admirable', 0.629, 'email', 'use_computer', 'access_internet', 'send_message', 'send_letter']
senticnet['send_flower'] = [0.928, 0, 0, 0.926, '#joyful', '#admirable', 0.618, 'keep_secret', 'tell', 'response', 'give_answer', 'dial_phone']
senticnet['send_gift'] = [0.845, 0, 0, 0.715, '#joyful', '#admirable', 0.52, 'need_communicate', 'send_flower', 'yearly_celebration', 'show_care', 'send_card']
senticnet['send_information'] = [0, -0.052, 0.011, 0.057, '#surprising', '#admirable', 0.033, 'stay_touch', 'communicate_friend', 'spread_meme', 'communicate_person', 'communication']
senticnet['send_letter'] = [0, 0.784, 0, 0.935, '#interesting', '#admirable', 0.573, 'email', 'use_computer', 'access_internet', 'send_message', 'send_email']
senticnet['send_mail'] = [0, 0.93, 0, 0.952, '#interesting', '#admirable', 0.627, 'snail_mail', 'postage', 'send_package', 'buy_stamp', 'send_letter']
senticnet['send_message'] = [0.107, 0.098, 0, 0.135, '#joyful', '#admirable', 0.113, 'record_data', 'make_sound', 'make_easy', 'make_noise', 'strum']
senticnet['send_money'] = [-0.066, 0.291, -0.113, 0.194, '#interesting', '#admirable', 0.102, 'give_cash', 'money_exchange', 'currency_exchange', 'settle_bill', 'money']
senticnet['send_package'] = [0, 0.922, 0, 0.795, '#interesting', '#admirable', 0.572, 'snail_mail', 'postage', 'send_mail', 'buy_stamp', 'send_letter']
senticnet['send_signal'] = [0.724, 0.923, 0, 0, '#joyful', '#interesting', 0.549, 'raise_voice', 'answer_phone', 'hunt_duck', 'answer_telephone', 'say_word']
senticnet['send_to_jail'] = [0, 0, 0, -0.775, '#disgusting', '#disgusting', -0.258, 'go_jail', 'go_to_prison', 'arrest', 'incarceration', 'injustice']
senticnet['send_to_prison'] = [-0.959, 0, -0.708, -0.966, '#sad', '#disgusting', -0.878, 'death_penalty', 'die', 'imprison', 'break_law', 'capital_punishment']
senticnet['sender'] = [0, -0.028, 0, 0.094, '#surprising', '#admirable', 0.041, 'letter', 'announcement', 'message', 'handset', 'word']
senticnet['sending'] = [-0.536, 0, 0.8, -0.642, '#angry', '#disgusting', -0.659, 'causing', 'causation', 'transmission', 'transmittal', 'transmitting']
senticnet['senega'] = [-0.706, 0, 0.769, -0.703, '#sad', '#angry', -0.726, 'subshrub', 'suffrutex', 'milkwort', 'orange_milkwort', 'yellow_milkwort']
senticnet['senile_dementia'] = [-0.947, 0, 0.821, -0.756, '#sad', '#angry', -0.841, 'predementedness', 'insanity', 'dementedness', 'senile_psychosis', 'alcoholic_dementia']
senticnet['senile_psychosis'] = [-0.947, 0, 0.821, -0.756, '#sad', '#angry', -0.841, 'presenile_dementia', 'insanity', 'senile_dementia', 'dementedness', 'alcoholic_dementia']
senticnet['senility'] = [-0.573, 0, 0.766, -0.759, '#angry', '#disgusting', -0.699, 'age', 'old_age', 'years', 'eld', 'geezerhood']
senticnet['senior'] = [0, -0.028, 0, 0.094, '#surprising', '#admirable', 0.041, 'professional', 'expert', 'experienced', 'skilled', 'trained']
senticnet['senior_citizen'] = [0.956, -0.703, 0, 0.653, '#joyful', '#surprising', 0.771, 'centenarian', 'nonagenarian', 'octogenarian', 'septuagenarian', 'sexagenarian']
senticnet['senior_status'] = [0.594, -0.688, 0, 0.957, '#surprising', '#admirable', 0.746, 'preeminence', 'eminence', 'high_status', 'higher_status', 'higher_rank']
senticnet['sensation'] = [0, 0.888, 0, 0.775, '#interesting', '#admirable', 0.554, 'sensual', 'feel_action', 'touch', 'physical_reaction', 'sense']
senticnet['sensational'] = [0, -0.761, 0, 0.708, '#surprising', '#admirable', 0.49, 'scandalmongering', 'sensationalistic', 'sensationally', 'inflame', 'fire_up']
senticnet['sensationalistic'] = [0, -0.962, 0, 0.988, '#surprising', '#admirable', 0.65, 'scandalmongering', 'sensational', 'sensationally', 'inflame', 'fire_up']
senticnet['sensationally'] = [0, -0.882, 0, 0.701, '#surprising', '#admirable', 0.528, 'scandalmongering', 'sensationalistic', 'sensational', 'inflame', 'fire_up']
senticnet['sense'] = [0, 0.152, -0.094, 0.225, '#interesting', '#admirable', 0.094, 'five_senses', 'human_sense', 'perceive', 'sensory_input', 'use_ear']
senticnet['sense_accomplishment'] = [0.712, 0.935, 0, 0.968, '#interesting', '#admirable', 0.872, 'accomplish_task', 'pass_exam', 'feel_good', 'pride', 'work_hard']
senticnet['sense_datum'] = [-0.592, 0, 0.653, -0.595, '#angry', '#disgusting', -0.613, 'masking', 'taste', 'threshold', 'perception', 'limen']
senticnet['sense_environment'] = [0, 0.938, 0, 0.714, '#interesting', '#admirable', 0.551, 'trip_person', 'eat_live', 'live_apartment', 'need_companionship', 'die_only_once']
senticnet['sense_experience'] = [-0.853, 0, 0.936, -0.908, '#angry', '#disgusting', -0.899, 'masking', 'taste', 'threshold', 'perception', 'limen']
senticnet['sense_fear'] = [-0.121, 0, -0.066, -0.033, '#sad', '#scared', -0.073, 'follow_person', 'stay_in_house', 'mark_territory', 'cause_accident', 'guide_blind']
senticnet['sense_impression'] = [-0.73, 0, 0.835, -0.532, '#sad', '#angry', -0.699, 'masking', 'taste', 'threshold', 'perception', 'limen']
senticnet['sense_joy'] = [0.814, 0, 0, 0, '#joyful', '#joyful', 0.271, 'experience_joy', 'lift_spirit', 'plan_party', 'think_funny', 'act_silly']
senticnet['sense_modality'] = [0.785, -0.995, 0, 0.981, '#surprising', '#admirable', 0.92, 'ear', 'absolute_pitch', 'perfect_pitch', 'modality', 'audition']
senticnet['sense_of_fulfillment'] = [0.354, 0.161, 0, -0.045, '#joyful', '#interesting', 0.157, 'share_knowledge', 'learn_oneself', 'increase_intelligence', 'inspiration', 'appreciation']
senticnet['sense_of_humor'] = [0.58, 0.651, -0.264, 0.308, '#joyful', '#interesting', 0.425, 'hear_joke', 'funny', 'laugh_loudly', 'start_laugh', 'smile']
senticnet['sense_of_right_and_wrong'] = [0.64, -0.522, 0, 0.895, '#joyful', '#admirable', 0.686, 'morality', 'wee_small_voice', 'small_voice', 'voice_of_conscience', 'sense_of_shame']
senticnet['sense_of_shame'] = [0.714, -0.583, 0, 0.667, '#joyful', '#admirable', 0.655, 'morality', 'wee_small_voice', 'small_voice', 'voice_of_conscience', 'moral_sense']
senticnet['sense_organ'] = [0, 0.097, 0, 0.118, '#interesting', '#admirable', 0.072, 'body_organ', 'ear', 'sensory_organ', 'human_organ', 'head_organ']
senticnet['sense_peace'] = [0.753, 0, 0, 0.908, '#joyful', '#admirable', 0.554, 'stress_relief', 'feel_good', 'feel_happy', 'enjoy_show', 'feel_relaxed']
senticnet['sense_pride'] = [0.318, 0.123, 0, 0, '#joyful', '#interesting', 0.147, 'great_joy', 'callus', 'sense_rhythm', 'keep_rhythm', 'arthritis']
senticnet['sense_rhythm'] = [0.318, 0.123, 0, 0, '#joyful', '#interesting', 0.147, 'keep_rhythm', 'put_music', 'arthritis', 'rhythm', 'skill']
senticnet['sense_satisfaction'] = [0, -0.787, 0, 0.881, '#surprising', '#admirable', 0.556, 'appreciate', 'become_better_person', 'beautiful', 'make_happy', 'tell_friend']
senticnet['sense_sound'] = [-0.03, 0.109, -0.06, 0.075, '#interesting', '#admirable', 0.031, 'hear_noise', 'use_ear', 'ear_work', 'ear_activity', 'stop_look']
senticnet['senseless'] = [-0.982, 0, 0.646, -0.982, '#sad', '#disgusting', -0.87, 'indefensible', 'reasonless', 'untenable', 'unreasonable', 'unwarranted']
senticnet['sensible'] = [0.843, -0.6, 0, 0.698, '#joyful', '#admirable', 0.714, 'levelheaded', 'sound', 'healthy', 'commonsense', 'commonsensible']
senticnet['sensitive'] = [-0.99, 0, 0, -0.801, '#sad', '#disgusting', -0.597, 'sensitive_skin', 'sensitive_teeth', 'weak', 'emotional_guy', 'sensitivity']
senticnet['sensitive_skin'] = [-0.972, 0, 0, -0.816, '#sad', '#disgusting', -0.596, 'sensitive', 'sensitive_teeth', 'weak', 'emotional_guy', 'sensitivity']
senticnet['sensitive_teeth'] = [0, 0, 0.841, -0.862, '#angry', '#disgusting', -0.568, 'sensitive_skin', 'sensitive', 'weak', 'emotional_guy', 'sensitivity']
senticnet['sensitivity'] = [0, 0, 0.826, -0.703, '#angry', '#disgusting', -0.51, 'oversensitive', 'touchy', 'huffy', 'feisty', 'hard']
senticnet['sensor'] = [0, 0.08, 0.036, 0.067, '#interesting', '#admirable', 0.037, 'complex_organ', 'sensory_organ', 'head_organ', 'vital_organ', 'part_of_face']
senticnet['sensorineural_hearing_loss'] = [-0.523, 0, 0.832, -0.58, '#angry', '#disgusting', -0.645, 'disability', 'disablement', 'handicap', 'impairment', 'hearing_disorder']
senticnet['sensory_input'] = [0, 0.131, -0.083, 0.239, '#interesting', '#admirable', 0.096, 'human_sense', 'ear_activity', 'vibration', 'five_senses', 'sensor']
senticnet['sensory_organ'] = [0, 0.114, 0.013, 0.097, '#interesting', '#admirable', 0.066, 'sense_organ', 'hold_glass', 'head_organ', 'organ_body', 'body_area']
senticnet['sensual'] = [0.723, 0, 0, 0.755, '#joyful', '#admirable', 0.493, 'feel_action', 'make_contact', 'hand_action', 'hand_movement', 'physical_contact']
senticnet['sensualist'] = [0.897, -0.961, 0, 0.785, '#joyful', '#surprising', 0.881, 'erotic', 'voluptuary', 'epicure', 'gourmet', 'gastronome']
senticnet['sentence_end'] = [0, 0.107, 0, 0.102, '#interesting', '#admirable', 0.07, 'full_stop', 'dot', 'punctuation', 'period', 'sport_score']
senticnet['sentence_part'] = [0.035, 0, 0, 0.116, '#joyful', '#admirable', 0.05, 'grammar_part', 'part_of_speech', 'written_language', 'school_paper', 'speech_part']
senticnet['sentient'] = [0.042, 0.156, -0.09, 0.155, '#interesting', '#admirable', 0.088, 'sentimental', 'social_creature', 'social_animal', 'fun_around', 'max']
senticnet['sentimental'] = [-0.736, 0, 0, -0.893, '#sad', '#disgusting', -0.543, 'phone_bill', 'delay', 'lose_sleep', 'stress', 'startle']
senticnet['sentimentalism'] = [0.825, -0.916, 0, 0.626, '#joyful', '#surprising', 0.789, 'treacle', 'glop', 'mush', 'slop', 'formulation']
senticnet['sentimentalist'] = [0.923, -0.888, 0, 0.825, '#joyful', '#surprising', 0.879, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['sentimentality'] = [-0.769, 0, 0.982, -0.547, '#sad', '#angry', -0.766, 'sentimentalism', 'emotionality', 'emotionalism', 'corn', 'schmaltz']
senticnet['sentinel'] = [0, 0, -0.77, -0.752, '#scared', '#disgusting', -0.507, 'watch', 'lookout', 'sentry', 'lookout_man', 'spotter']
senticnet['sepal'] = [0, 0, 0.076, -0.03, '#angry', '#disgusting', -0.035, 'cat_hair', 'achene', 'follicle', 'sleep_cat', 'cat']
senticnet['separate'] = [0, 0, -0.789, -0.988, '#scared', '#disgusting', -0.592, 'disunite', 'divide', 'part', 'differentiate', 'furcate']
senticnet['separate_egg'] = [-0.061, 0, 0.025, 0, '#sad', '#angry', -0.029, 'cook_dinner', 'make_bread', 'cook_meal', 'prepare_luggage', 'press_shirt']
senticnet['separate_room'] = [-0.791, 0, -0.887, 0, '#sad', '#scared', -0.559, 'enter_room', 'control_access', 'hang_door', 'go_build', 'go_through']
senticnet['separate_shower'] = [0.041, 0.086, 0.016, 0, '#joyful', '#interesting', 0.037, 'bath_shower', 'shower_head', 'shampoo_conditioner', 'plunger', 'tub']
senticnet['separated'] = [-0.091, 0.156, 0.661, -0.656, '#angry', '#disgusting', -0.417, 'detached', 'isolated', 'set-apart', 'distasteful', 'loathly']
senticnet['separation'] = [-0.824, 0, -0.825, 0, '#sad', '#scared', -0.55, 'split', 'slash', 'sever', 'divide', 'division']
senticnet['separative'] = [-0.668, 0, 0.502, -0.796, '#sad', '#disgusting', -0.655, 'adversative', 'oppositive', 'contrastive', 'alternative', 'disjunctive']
senticnet['septic'] = [-0.539, 0, 0.671, -0.558, '#angry', '#disgusting', -0.589, 'dirty', 'putrefactive', 'putrefacient', 'abscessed', 'contaminative']
senticnet['septic_sore_throat'] = [-0.821, 0, 0.609, -0.89, '#sad', '#disgusting', -0.773, 'inflammatory_disease', 'streptococcal_sore_throat', 'strep_throat', 'streptococcus_tonsilitis', 'pharyngitis']
senticnet['septic_tank'] = [0, 0, -0.827, -0.973, '#scared', '#disgusting', -0.6, 'riverbed', 'bottom_ocean', 'waterfall', 'down_drain', 'petri_dish']
senticnet['septicemic_plague'] = [-0.955, 0, 0.876, -0.895, '#sad', '#disgusting', -0.909, 'bubonic_plague', 'pestis_bubonica', 'glandular_plague', 'pestilence', 'pneumonic_plague']
senticnet['sepulcher'] = [-0.899, 0, 0.535, -0.686, '#sad', '#disgusting', -0.707, 'grave', 'tomb', 'chamber', 'monument', 'vault']
senticnet['sepulture'] = [-0.589, 0, 0.509, -0.836, '#sad', '#disgusting', -0.645, 'burial_chamber', 'sepulcher', 'bunker', 'chamber', 'bombproof']
senticnet['sequel'] = [-0.063, 0.122, -0.046, 0.113, '#interesting', '#admirable', 0.042, 'encounter', 'portray', 'reveal', 'episode', 'next_episode']
senticnet['sequence'] = [0.025, 0.116, 0.051, 0.163, '#interesting', '#admirable', 0.084, 'one_more', 'sequential_order', 'full_stop', 'twice', 'interval']
senticnet['sequential_order'] = [0.025, 0.116, 0.051, 0.163, '#interesting', '#admirable', 0.084, 'one_more', 'sequence', 'full_stop', 'twice', 'interval']
senticnet['sequester'] = [0, 0, -0.787, -0.828, '#scared', '#disgusting', -0.538, 'seize', 'seclude', 'attach', 'impound', 'confiscate']
senticnet['sequestration'] = [-0.747, 0, -0.932, 0, '#sad', '#scared', -0.56, 'seizure', 'kill_brain_cell', 'cry', 'bad_health', 'scared']
senticnet['sere'] = [0, 0, -0.932, -0.818, '#scared', '#disgusting', -0.583, 'sear', 'withered', 'dried-up', 'shrivelled', 'shriveled']
senticnet['serene'] = [0.873, 0, 0, 0.876, '#joyful', '#admirable', 0.583, 'tranquility', 'peace-loving', 'peace_of_mind', 'repose', 'heartsease']
senticnet['sereness'] = [-0.738, 0, 0.931, -0.821, '#angry', '#disgusting', -0.83, 'aridness', 'thirstiness', 'xerostomia', 'dry_mouth', 'dryness']
senticnet['serenity'] = [0.3, 0, 0, 0, '#joyful', '#joyful', 0.1, 'serene', 'tranquility', 'peacefulness', 'closeness', 'recreate']
senticnet['serf'] = [-0.088, 0, -0.145, 0, '#sad', '#scared', -0.078, 'farmer', 'peasant', 'servant', 'poor', 'villein']
senticnet['sergent'] = [0, 0, -0.075, -0.031, '#scared', '#disgusting', -0.035, 'army_person', 'fighter', 'police_man', 'warrior', 'army_man']
senticnet['sericeous'] = [-0.754, 0, 0.734, -0.825, '#sad', '#disgusting', -0.771, 'puberulent', 'haired', 'furlike', 'pappose', 'pilous']
senticnet['serious'] = [-0.834, 0, 0, -0.908, '#sad', '#disgusting', -0.581, 'wrong', 'insane', 'vengeance', 'impend_danger', 'hazardous']
senticnet['serious_accident'] = [-0.878, 0, -0.811, 0, '#sad', '#scared', -0.563, 'bang_head', 'automobile_accident', 'loss_ofawareness', 'brain_damage', 'unconscious']
senticnet['serious_injury'] = [-0.17, -0.047, -0.123, -0.251, '#sad', '#disgusting', -0.166, 'get_hurt', 'die', 'loss_oflife', 'feel_anger', 'arrest_police']
senticnet['serious_issue'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'problem', 'serious_problem', 'overrate', 'prohibitionist_society', 'blade_weapon']
senticnet['serious_music'] = [0.514, -0.586, 0, 0.927, '#surprising', '#admirable', 0.676, 'genre', 'fugue', 'chamber_music', 'opera', 'cantata']
senticnet['serious_problem'] = [-0.062, 0.123, 0.712, -0.678, '#angry', '#disgusting', -0.443, 'problem', 'serious_issue', 'overrate', 'prohibitionist_society', 'blade_weapon']
senticnet['serious_student'] = [0, 0, 0, 0.783, '#admirable', '#admirable', 0.261, 'student', 'graduate_student', 'good_student', 'hard_worker', 'drug_addict']
senticnet['seriously'] = [-0.786, 0, -0.915, 0, '#sad', '#scared', -0.567, 'devout', 'earnestness', 'earnestly', 'seriousness', 'in_earnest']
senticnet['seriousness'] = [-0.816, 0, -0.932, 0, '#sad', '#scared', -0.583, 'seriously', 'devout', 'earnestness', 'earnestly', 'in_earnest']
senticnet['serpent'] = [-0.764, 0, 0.676, -0.512, '#sad', '#angry', -0.651, 'viper', 'elapid', 'elapid_snake', 'worm_snake', 'blind_snake']
senticnet['servant'] = [-0.851, 0, 0.938, -0.879, '#angry', '#disgusting', -0.889, 'menial', 'lackey', 'flunky', 'flunkey', 'familiar']
senticnet['servant_boy'] = [-0.975, 0, 0.072, -0.911, '#sad', '#disgusting', -0.653, 'slave', 'female_slave', 'psychological_aggression', 'physical_aggression', 'verbal_aggression']
senticnet['serve'] = [0, 0.165, -0.089, 0.179, '#interesting', '#admirable', 0.085, 'bring_food', 'take_order', 'meet_need', 'help_person', 'free_slave']
senticnet['serve_beer'] = [0, 0.709, 0, 0, '#interesting', '#interesting', 0.236, 'buy_drink', 'drink_beer', 'invite_friend', 'pay_tab', 'throw_away_trash']
senticnet['serve_coffee'] = [0.108, 0.145, -0.091, 0, '#joyful', '#interesting', 0.054, 'drink_wine', 'choke_food', 'drink_fluid', 'drink_tea', 'suck']
senticnet['serve_cold'] = [0.28, 0.174, -0.05, 0.249, '#joyful', '#admirable', 0.218, 'tasty_good', 'make_fruit', 'delicious', 'high_calorie', 'soft_sweet']
senticnet['serve_dinner'] = [0.783, 0, 0, 0.789, '#joyful', '#admirable', 0.524, 'play_card_game', 'sit_around', 'eat_cereal', 'eat_lot', 'eat_food']
senticnet['serve_dish'] = [0.052, -0.041, 0.024, 0, '#joyful', '#surprising', 0.023, 'table_set', 'meal_time', 'dinner', 'dinner_table', 'table']
senticnet['serve_drink'] = [0.081, -0.058, 0, -0.032, '#joyful', '#surprising', 0.036, 'cut_food', 'drink_beer', 'drink_beverage', 'drink_much', 'pry_open']
senticnet['serve_food'] = [0, -0.174, 0, 0.244, '#surprising', '#admirable', 0.139, 'obtain_food', 'carry_food', 'take_order', 'consumption', 'make_dinner']
senticnet['serve_guest'] = [0.981, 0.731, 0, 0, '#joyful', '#interesting', 0.571, 'like', 'laugh_lot', 'change_mood', 'deafness', 'smoke_bowl']
senticnet['serve_hot'] = [0.067, 0.089, 0, 0.094, '#interesting', '#admirable', 0.083, 'liquid_food', 'hot_liquid', 'drinkable', 'fluid', 'better_cold']
senticnet['serve_jury'] = [-0.817, 0, 0.935, 0, '#sad', '#angry', -0.584, 'bang_gavel', 'verdict', 'register_vote', 'close_case', 'convict_criminal']
senticnet['serve_justice'] = [-0.744, 0, 0, -0.72, '#sad', '#disgusting', -0.488, 'get_divorce', 'stop_marry', 'justice', 'institute_civil_action', 'divorce']
senticnet['serve_liquid'] = [0.097, 0, 0, 0, '#joyful', '#joyful', 0.032, 'consume_food', 'eat_food', 'swallow', 'fill_up', 'drink_soup']
senticnet['serve_meal'] = [0.863, 0, 0, 0, '#joyful', '#joyful', 0.288, 'eat_food_off', 'eat_pudding', 'sit_around', 'eat_food', 'munch']
senticnet['serve_wine'] = [0.025, 0, 0.016, 0.067, '#joyful', '#admirable', 0.025, 'liquid', 'ferment_beverage', 'carbonate_drink', 'measure_liquid', 'good_drink']
senticnet['server'] = [0, 0.873, 0, 0.74, '#interesting', '#admirable', 0.538, 'wait_staff', 'manager', 'waitress', 'public_servant', 'waiter']
senticnet['service_car'] = [0.784, 0.822, 0, 0, '#joyful', '#interesting', 0.535, 'marry_man', 'date_woman', 'oil_hinge', 'man_post', 'date_man']
senticnet['service_station'] = [0.065, -0.021, 0.009, 0, '#joyful', '#surprising', 0.026, 'rest_area', 'motel_room', 'gas_station', 'buy_snack', 'go_toilet']
senticnet['serviceable'] = [0.986, -0.629, 0, 0.807, '#joyful', '#admirable', 0.807, 'operable', 'functional', 'user_friendly', 'usable', 'operational']
senticnet['servile'] = [0.981, -0.887, 0, 0.939, '#joyful', '#admirable', 0.936, 'slavelike', 'submissive', 'obsequious', 'subservient', 'slavish']
senticnet['session'] = [0.065, -0.021, 0.009, 0, '#joyful', '#surprising', 0.026, 'college_class', 'school_level', 'class', 'high_school', 'lecture']
senticnet['set'] = [-0.026, 0.192, 0, 0.263, '#interesting', '#admirable', 0.143, 'many_items', 'group', 'description', 'class', 'large_amount']
senticnet['set-apart'] = [-0.091, 0.156, 0.661, -0.656, '#angry', '#disgusting', -0.417, 'detached', 'isolated', 'separated', 'distasteful', 'loathly']
senticnet['set_about'] = [-0.885, 0, 0.854, -0.668, '#sad', '#angry', -0.802, 'approach', 'undertake', 'tackle', 'take_on', 'face_up']
senticnet['set_alarm'] = [-0.084, -0.038, 0.071, -0.075, '#sad', '#disgusting', -0.064, 'go_bed_early', 'set_alarm_clock', 'sleep_early', 'wind_down', 'sit_back_relax']
senticnet['set_alarm_clock'] = [-0.064, -0.041, 0.039, -0.063, '#sad', '#disgusting', -0.042, 'sleep_early', 'set_alarm', 'go_bed_early', 'finish_sleep', 'shut_off_alarm_clock']
senticnet['set_aside'] = [0.519, -0.991, 0, 0.741, '#surprising', '#admirable', 0.75, 'earmark', 'appropriate', 'allot', 'reserve', 'reserve_table']
senticnet['set_clock'] = [-0.081, 0, 0, 0, '#sad', '#sad', -0.027, 'floss_tooth', 'mine_gold', 'dress_oneself', 'near_destination', 'fly_around']
senticnet['set_down'] = [0, 0.136, 0.009, 0.174, '#interesting', '#admirable', 0.1, 'position', 'adjust', 'tennis_term', 'place', 'inclusion']
senticnet['set_example'] = [0, 0, 0, 0.8, '#admirable', '#admirable', 0.267, 'trust', 'improve', 'pleasant', 'enjoy_challenge', 'make_feel_good']
senticnet['set_fire'] = [-0.143, 0, -0.095, -0.143, '#sad', '#disgusting', -0.127, 'excessive_heat', 'burn_down_house', 'set_on_fire', 'arson', 'burn_hand']
senticnet['set_forth'] = [-0.681, 0, 0.967, -0.657, '#sad', '#angry', -0.768, 'depart', 'start', 'part', 'start_out', 'sally_forth']
senticnet['set_free'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'liberate', 'break_free', 'relief', 'freedom', 'free_will']
senticnet['set_goal'] = [0.557, 0.58, 0, 0.566, '#interesting', '#admirable', 0.568, 'focus_concentration', 'absorb_information', 'remember_fact', 'discover_fact', 'open_mind']
senticnet['set_instruction'] = [0, 0.177, 0, 0.199, '#interesting', '#admirable', 0.125, 'police_work', 'vocation', 'occupation', 'career', 'make_happen']
senticnet['set_key'] = [0, 0, 0.026, -0.069, '#angry', '#disgusting', -0.032, 'checkbook', 'spare_change', 'checkbook_cover', 'handbag', 'checkbook_holder']
senticnet['set_mood'] = [0.775, -0.899, 0, 0, '#joyful', '#surprising', 0.558, 'enjoy_down_time', 'unwind', 'stress_reduction', 'distraction', 'relaxation']
senticnet['set_off'] = [0, 0, -0.98, -0.835, '#scared', '#disgusting', -0.605, 'sensationalistic', 'scandalmongering', 'sensational', 'sensationally', 'fire_up']
senticnet['set_on'] = [-0.716, 0, 0.983, -0.722, '#angry', '#disgusting', -0.807, 'blindside', 'profane', 'assault', 'savage', 'violate']
senticnet['set_on_fire'] = [-0.141, 0, -0.214, -0.078, '#sad', '#scared', -0.144, 'heat_light', 'burn_down_house', 'arson', 'rapid_oxidation', 'flame']
senticnet['set_phrase'] = [0.563, -0.728, 0, 0.644, '#surprising', '#admirable', 0.645, 'idiom', 'idiomatic_expression', 'phrasal_idiom', 'ruralism', 'phrase']
senticnet['set_point'] = [0, 0.257, -0.133, 0.306, '#interesting', '#admirable', 0.143, 'sport', 'tennis', 'tennis_term', 'violent_action', 'match_point']
senticnet['set_stage'] = [0.891, 0, 0, 0.907, '#joyful', '#admirable', 0.599, 'piece_of_meat', 'food', 'performance', 'raw_fish', 'japanese_food']
senticnet['set_table'] = [-0.056, -0.005, 0.024, 0, '#sad', '#angry', -0.025, 'season_food', 'prepare_meal', 'prepare_breakfast', 'prepare_dinner', 'bone_chicken']
senticnet['set_timer'] = [-0.134, -0.085, 0.015, -0.215, '#sad', '#disgusting', -0.093, 'wake_up_early', 'set_alarm', 'lack_of_sleep', 'alarm', 'wake_up_call']
senticnet['set_up'] = [-0.101, 0.14, 0, 0.105, '#interesting', '#admirable', 0.048, 'build_house', 'put_up_construction', 'put_up', 'construct_skyscraper', 'erect']
senticnet['setback'] = [-0.737, 0, 0.591, -0.681, '#sad', '#disgusting', -0.67, 'whammy', 'happening', 'occurrence', 'occurrent', 'natural_event']
senticnet['settle'] = [0, 0.069, 0, 0.079, '#interesting', '#admirable', 0.049, 'work', 'settle_down', 'job', 'ask_person', 'dig_ground']
senticnet['settle_argument'] = [0.973, 0.734, 0, 0.897, '#joyful', '#admirable', 0.868, 'arrest_criminal', 'make_judgment', 'judge_person', 'go_court', 'tell_truth']
senticnet['settle_bill'] = [-0.087, 0.267, -0.101, 0.157, '#interesting', '#admirable', 0.079, 'send_money', 'earn_income', 'money_exchange', 'give_money', 'give_cash']
senticnet['settle_disagreement'] = [-0.055, -0.016, -0.045, -0.183, '#sad', '#disgusting', -0.089, 'conquer_enemy', 'kill_soldier', 'gain_territory', 'kill_enemy', 'protect_country']
senticnet['settle_dispute'] = [0, 0.112, 0, 0, '#interesting', '#interesting', 0.037, 'seek_justice', 'become_lawyer', 'convict_criminal', 'become_judge', 'see_justice_done']
senticnet['settle_down'] = [0.866, 0.984, 0, 0, '#joyful', '#interesting', 0.617, 'book_read', 'turn_off_tv', 'choose_book', 'study_book', 'purchase_book']
senticnet['settled'] = [0.04, -0.044, 0.152, -0.063, '#angry', '#disgusting', -0.044, 'stable', 'immobile', 'steady', 'stationary', 'stabilize']
senticnet['settlement'] = [0, 0, 0, 0.073, '#admirable', '#admirable', 0.024, 'large_area_land', 'settle_down', 'urban', 'village', 'rural']
senticnet['sever'] = [-0.082, -0.038, 0.042, -0.132, '#sad', '#disgusting', -0.073, 'slash', 'slit', 'lacerate', 'open_wind', 'copy_paste']
senticnet['several_people'] = [0.08, -0.028, 0, 0, '#joyful', '#surprising', 0.036, 'big_group', 'multitude', 'bunch_person', 'group_of_people', 'a_lot_of_people']
senticnet['several_types'] = [0.966, 0.833, 0, 0, '#joyful', '#interesting', 0.6, 'many_types', 'copper_wire', 'gas_stove', 'tape_player', 'control_room']
senticnet['severalize'] = [-0.945, 0, 0.736, -0.805, '#sad', '#disgusting', -0.829, 'separate', 'secern', 'secernate', 'differentiate', 'split_up']
senticnet['severance'] = [-0.032, 0.305, -0.076, 0.141, '#interesting', '#admirable', 0.113, 'owe', 'expense', 'afford', 'money_due', 'wage']
senticnet['severe'] = [-0.18, 0, -0.109, -0.105, '#sad', '#scared', -0.131, 'hurtful', 'hard', 'bloody', 'cause_bleed', 'laceration']
senticnet['severe_cold'] = [-0.969, 0, 0.172, -0.997, '#sad', '#disgusting', -0.713, 'cold_winter', 'cold', 'hypothermia', 'possibility_to_die', 'fear_to_die']
senticnet['severe_pain'] = [-0.2, 0, -0.259, -0.156, '#sad', '#scared', -0.205, 'feel_pain', 'poor_health', 'learn_disease', 'suffer', 'concern_health']
senticnet['severeness'] = [-0.534, 0, 0.733, -0.618, '#angry', '#disgusting', -0.628, 'distressfulness', 'intensiveness', 'intensity', 'foulness', 'seriousness']
senticnet['severity'] = [-0.98, 0, 0.883, -0.857, '#sad', '#angry', -0.907, 'distressfulness', 'intensiveness', 'intensity', 'foulness', 'seriousness']
senticnet['sew'] = [0, 0, -0.899, -0.969, '#scared', '#disgusting', -0.623, 'knit', 'thread_needle', 'needle_thread', 'use_needle', 'weave']
senticnet['sew_kit'] = [0, 0, -0.09, -0.074, '#scared', '#disgusting', -0.055, 'antibiotic', 'medicine', 'doctor', 'sleep_drug', 'medicine_chest']
senticnet['sew_machine'] = [0, 0, -0.769, -0.827, '#scared', '#disgusting', -0.532, 'needle', 'sew_needle', 'haircloth', 'needle_thread', 'oilcloth']
senticnet['sew_needle'] = [0, -0.025, 0.074, -0.133, '#angry', '#disgusting', -0.061, 'use_needle', 'needle', 'needle_thread', 'clothes_repair', 'sew_machine']
senticnet['sew_term'] = [-0.067, 0, 0, -0.088, '#sad', '#disgusting', -0.052, 'needle_thread', 'use_needle', 'doctor_tool', 'seam', 'bandage']
senticnet['sewer'] = [0, -0.003, 0.01, -0.108, '#angry', '#disgusting', -0.038, 'dump', 'trashcan', 'tunnel', 'incinerator', 'car_wash']
senticnet['sewn'] = [-0.848, 0, -0.967, 0, '#sad', '#scared', -0.605, 'use_needle', 'mend', 'wind_thread', 'doctor_tool', 'sew_term']
senticnet['sex'] = [0.989, 0.947, 0, 0, '#joyful', '#interesting', 0.645, 'safe_sex', 'contraception', 'sexual_intercourse', 'fuck', 'become_aroused']
senticnet['sex_act'] = [0.947, -0.811, 0, 0.656, '#joyful', '#surprising', 0.805, 'sexual_intercourse', 'intercourse', 'hank_panky', 'copulation', 'coitus']
senticnet['sex_crime'] = [-0.648, 0, 0.854, -0.83, '#angry', '#disgusting', -0.777, 'crime', 'bigamy', 'sexual_assault', 'sexual_abuse', 'regulatory_offence']
senticnet['sex_same_gender'] = [0, 0, 0.712, -0.895, '#angry', '#disgusting', -0.536, 'go_public', 'change_society', 'take_oath', 'give_plug', 'get_divorce']
senticnet['sex_shop'] = [-0.023, 0, 0.012, -0.044, '#sad', '#disgusting', -0.026, 'walmart', 'woman_purse', 'record_store', 'tailor_shop', 'sock_drawer']
senticnet['sex_toy'] = [0, 0, 0.723, -0.743, '#angry', '#disgusting', -0.489, 'duvet_cover', 'pillow_case', 'pillowcase', 'homosexual', 't_shirt']
senticnet['sex_with_stranger'] = [0.053, 0.127, -0.081, 0.134, '#interesting', '#admirable', 0.078, 'temporary_home', 'stay', 'sleep_on_couch', 'stay_overnight', 'remain']
senticnet['sex_without_condom'] = [-0.909, 0, 0.202, -1.0, '#sad', '#disgusting', -0.704, 'sickness', 'unsafe_sex', 'social_disease', 'std', 'sexually_transmitted_disease']
senticnet['sexiness'] = [0.927, -0.559, 0, 0.612, '#joyful', '#admirable', 0.699, 'sexual_desire', 'concupiscence', 'physical_attraction', 'prurience', 'pruriency']
senticnet['sexism'] = [-0.684, 0, 0.949, -0.63, '#sad', '#angry', -0.754, 'chauvinism', 'male_chauvinism', 'antifeminism', 'sexual_discrimination', 'discrimination']
senticnet['sexual'] = [0, 0.095, 0, 0.167, '#interesting', '#admirable', 0.087, 'fragrant', 'use_decoration', 'colorful', 'green', 'cultivate_yard']
senticnet['sexual_abuse'] = [-0.648, 0, 0.854, -0.83, '#angry', '#disgusting', -0.777, 'crime', 'bigamy', 'sexual_assault', 'regulatory_offence', 'sex_crime']
senticnet['sexual_activity'] = [0.93, 0.773, 0, 0, '#joyful', '#interesting', 0.568, 'ceiling_fan', 'tv_set', 'pay_tv', 'red_light_district', 'pornography']
senticnet['sexual_arousal'] = [0.877, 0.734, 0, 0, '#joyful', '#interesting', 0.537, 'arousal', 'foreplay', 'fall_love', 'orgasm', 'make_love']
senticnet['sexual_assault'] = [-0.648, 0, 0.854, -0.83, '#angry', '#disgusting', -0.777, 'crime', 'bigamy', 'regulatory_offence', 'sexual_abuse', 'sex_crime']
senticnet['sexual_attraction'] = [0.74, 0, 0, 0.706, '#joyful', '#admirable', 0.482, 'know_other', 'amiable', 'give_hug', 'giggle', 'smile']
senticnet['sexual_desire'] = [0.611, -0.882, 0, 0.883, '#surprising', '#admirable', 0.792, 'love', 'aphrodisia', 'lecherousness', 'lustfulness', 'amorousness']
senticnet['sexual_discrimination'] = [-0.684, 0, 0.949, -0.63, '#sad', '#angry', -0.754, 'chauvinism', 'male_chauvinism', 'antifeminism', 'sexism', 'discrimination']
senticnet['sexual_excitement'] = [0, 0, 0, 0.752, '#admirable', '#admirable', 0.251, 'prevent_pregnancy', 'contraception', 'safe_sex', 'sex', 'avoid_pregnancy']
senticnet['sexual_immorality'] = [-0.522, 0, 0.621, -0.919, '#angry', '#disgusting', -0.687, 'deviltry', 'devilry', 'irreverence', 'foul_play', 'iniquity']
senticnet['sexual_intercourse'] = [0.164, 0.144, -0.072, 0.135, '#joyful', '#interesting', 0.124, 'find_mate', 'warm_fuzzy_feeling', 'sex', 'safe_sex', 'find_partner']
senticnet['sexual_inversion'] = [0.807, -0.88, 0, 0.718, '#joyful', '#surprising', 0.802, 'sex', 'inversion', 'gayness', 'lesbianism', 'sapphism']
senticnet['sexual_perversion'] = [-0.848, 0, 0.882, -0.829, '#sad', '#angry', -0.853, 'perversion', 'fetishism', 'paraphilia', 'sodomy', 'buggery']
senticnet['sexual_pleasure'] = [0.801, 0.967, 0, 0, '#joyful', '#interesting', 0.589, 'foreplay', 'happiness', 'feel_joy', 'sense_peace', 'sit_sun']
senticnet['sexual_relationship'] = [0.692, -0.992, 0, 0.614, '#joyful', '#surprising', 0.766, 'intimacy', 'affaire', 'liaison', 'affair', 'involvement']
senticnet['sexual_stimulation'] = [0, 0.959, 0, 0.775, '#interesting', '#admirable', 0.578, 'sex', 'show_empathy', 'safe_sex', 'fuck', 'love_back']
senticnet['sexuality'] = [0.948, 0.75, 0, 0, '#joyful', '#interesting', 0.566, 'love', 'lust', 'show_empathy', 'love_another_person', 'love_oneself']
senticnet['sexually'] = [0.857, 0.823, 0, 0, '#joyful', '#interesting', 0.56, 'smart_man', 'husband_wife', 'gender', 'voyeur', 'wear_sunglasses']
senticnet['sexually_transmit_disease'] = [-0.952, 0, -0.764, -0.795, '#sad', '#disgusting', -0.837, 'cripple', 'influenza', 'infectious_disease', 'chicken_pox', 'overpay']
senticnet['sexually_transmitted_disease'] = [-0.909, 0, 0.202, -1.0, '#sad', '#disgusting', -0.704, 'sickness', 'unsafe_sex', 'social_disease', 'std', 'sex_without_condom']
senticnet['sexy'] = [0.137, 0.211, -0.112, 0.212, '#interesting', '#admirable', 0.149, 'familiar', 'female_human', 'sophisticated', 'feminine', 'contrary']
senticnet['sexy_clothes'] = [0.728, 0.977, 0, 0.939, '#interesting', '#admirable', 0.881, 'dress', 'night_dress', 'sexy', 'pretty', 'pleasure']
senticnet['sexy_girl'] = [0, 0.07, 0, 0.067, '#interesting', '#admirable', 0.046, 'clean', 'polish', 'shiny', 'looks_like_new', 'car_wash']
senticnet['sexy_woman'] = [0.857, 0, 0, 0, '#joyful', '#joyful', 0.286, 'date', 'accuracy', 'seduction', 'woo', 'enjoy_person']
senticnet['shack'] = [-0.025, 0, -0.049, -0.031, '#scared', '#disgusting', -0.035, 'small_house', 'small_room', 'mansion', 'art_gallery', 'motel_room']
senticnet['shad_roe'] = [-0.527, 0, 0.748, -0.926, '#angry', '#disgusting', -0.734, 'coral', 'caviar', 'caviare', 'hard_roe', 'seafood']
senticnet['shade_eye'] = [0, 0, -0.952, -0.74, '#scared', '#disgusting', -0.564, 'protect_head', 'helmet', 'keep_hair_place', 'safety_cap', 'cover_head']
senticnet['shade_sun'] = [-0.024, 0, -0.078, 0, '#sad', '#scared', -0.034, 'branch_out', 'move_wind', 'fall_dead', 'memory_loss', 'fall_floor']
senticnet['shadiness'] = [-0.722, 0, 0.742, -0.802, '#angry', '#disgusting', -0.755, 'illicitness', 'illegality', 'illegitimacy', 'unlawfulness', 'quality']
senticnet['shading'] = [-0.912, 0, 0.796, -0.872, '#sad', '#disgusting', -0.86, 'hatch', 'hatching', 'crosshatch', 'hachure', 'marking']
senticnet['shadow'] = [-0.72, 0, 0, -0.961, '#sad', '#disgusting', -0.56, 'evil', 'darkness', 'dark', 'sun_down', 'dark_side']
senticnet['shadowy'] = [-0.961, 0, 0.939, -0.605, '#sad', '#angry', -0.835, 'airy', 'insubstantial', 'stringy', 'wraithlike', 'ethereal']
senticnet['shady'] = [0, 0, -0.786, -0.966, '#scared', '#disgusting', -0.584, 'suspect', 'fishy', 'funny', 'louche', 'fly-by-night']
senticnet['shaft'] = [-0.17, 0, -0.098, -0.032, '#sad', '#scared', -0.1, 'lever', 'terrorist_home', 'tank', 'defence', 'police_car']
senticnet['shaggy_dog_story'] = [-0.522, 0, 0.538, -0.998, '#angry', '#disgusting', -0.686, 'gag', 'jest', 'jape', 'joke', 'laugh']
senticnet['shake'] = [-0.724, 0, -0.965, 0, '#sad', '#scared', -0.563, 'rub', 'earth_movement', 'wiggle', 'wrap_around', 'convulse']
senticnet['shake_hand'] = [0, 0.082, -0.068, 0.095, '#interesting', '#admirable', 0.036, 'say_hello', 'introduce_oneself', 'hunt_duck', 'know_other', 'say_hi']
senticnet['shake_up'] = [-0.754, 0, -0.978, 0, '#sad', '#scared', -0.577, 'thrilling', 'electrifying', 'sensational', 'sensationally', 'scandalmongering']
senticnet['shakespeare_play'] = [-0.04, -0.028, -0.094, 0, '#sad', '#scared', -0.035, 'present_play', 'perform_play', 'show_play', 'drama', 'stage_play']
senticnet['shako'] = [-0.588, 0, 0.632, -0.638, '#angry', '#disgusting', -0.619, 'skimmer', 'trilby', 'bearskin', 'busby', 'chapeau']
senticnet['shallow'] = [-0.057, -0.021, -0.075, 0, '#sad', '#scared', -0.037, 'tide', 'tidal_wave', 'surf_board', 'puddle', 'pier']
senticnet['shallow_water'] = [0, 0, -0.058, -0.074, '#scared', '#disgusting', -0.044, 'chlorine', 'swimmer', 'still_water', 'large_body', 'lifeguard']
senticnet['sham'] = [-0.609, 0, 0.813, -0.529, '#sad', '#angry', -0.65, 'warp', 'dissemble', 'feign', 'misrepresent', 'pretend']
senticnet['shame'] = [-0.617, 0.366, -0.394, -0.12, '#sad', '#scared', -0.255, 'dread', 'unhappy', 'fright', 'pity', 'humiliation']
senticnet['shamed'] = [-0.732, 0.305, -0.44, -0.059, '#sad', '#scared', -0.309, 'hangdog', 'miserably', 'pitiable', 'hapless', 'suffering']
senticnet['shamefaced'] = [-0.707, 0.317, -0.415, -0.071, '#sad', '#scared', -0.292, 'weepiness', 'painful', 'dolorous', 'lachrymose', 'tearfulness']
senticnet['shamefacedly'] = [-0.946, 0, -0.757, 0, '#sad', '#scared', -0.568, 'sheepishness', 'shamefacedness', 'confused', 'disordered', 'discombobulation']
senticnet['shamefacedness'] = [-0.761, 0, -0.812, 0, '#sad', '#scared', -0.524, 'shamefacedly', 'sheepishness', 'confused', 'disordered', 'discombobulation']
senticnet['shameful'] = [-0.783, 0, 0, -0.896, '#sad', '#disgusting', -0.56, 'disgraceful', 'dishonorably', 'inglorious', 'dishonored', 'shame']
senticnet['shamefully'] = [-0.946, 0, 0, -0.998, '#sad', '#disgusting', -0.648, 'disgraceful', 'shameful', 'dishonorably', 'inglorious', 'dishonored']
senticnet['shameless'] = [0, 0, 0, -0.959, '#disgusting', '#disgusting', -0.32, 'unethical', 'bad', 'obscene', 'indecent', 'immoral']
senticnet['shampoo'] = [0, -0.015, -0.056, -0.111, '#scared', '#disgusting', -0.051, 'fluoride_mouthwash', 'faucet_overflow', 'mouthwash', 'hot_faucet', 'disinfectant']
senticnet['shampoo_conditioner'] = [0.041, 0.086, 0.016, 0, '#joyful', '#interesting', 0.037, 'separate_shower', 'shower_head', 'bath_shower', 'plunger', 'tub']
senticnet['shamrock'] = [0, -0.009, 0.032, -0.051, '#angry', '#disgusting', -0.025, 'weed', 'little_gem_arborvita', 'lichen', 'moss', 'most_plants']
senticnet['shape'] = [0, 0.954, 0, 0.911, '#interesting', '#admirable', 0.622, 'polygon', 'fit', 'geometric_figure', 'geometric_shape', 'train_hard']
senticnet['shape_hair'] = [0, -0.012, 0.045, -0.041, '#angry', '#disgusting', -0.025, 'change_hairstyle', 'get_hair_colored', 'get_manicure', 'style_hair', 'dye_hair']
senticnet['shape_up'] = [0.981, 0.955, 0, 0.709, '#joyful', '#interesting', 0.882, 'better_shape', 'fit', 'healthy', 'exercise', 'go_to_gym']
senticnet['shapeless'] = [-0.646, 0, 0.557, -0.739, '#sad', '#disgusting', -0.647, 'formless', 'amorphous', 'unformed', 'unshaped', 'unshapen']
senticnet['shapely'] = [0.636, -0.954, 0, 0.664, '#surprising', '#admirable', 0.751, 'voluptuous', 'statuesque', 'sculptured', 'buxom', 'sculptural']
senticnet['shard'] = [-0.043, 0.096, 0, 0.093, '#interesting', '#admirable', 0.049, 'shatter', 'clear_solid', 'see_through', 'transparent', 'transparency']
senticnet['share_experience'] = [0.15, -0.07, -0.055, 0, '#joyful', '#surprising', 0.055, 'friendship', 'social', 'network', 'get_together', 'relay_information']
senticnet['share_feeling'] = [0, 0, 0, 0.848, '#admirable', '#admirable', 0.283, 'eye_contact', 'start_conversation', 'say_hello', 'talk_another_person', 'become_friend']
senticnet['share_idea'] = [0.751, 0, 0, 0, '#joyful', '#joyful', 0.25, 'exchange_idea', 'meeting', 'teach_new', 'transfer_knowledge', 'persuade']
senticnet['share_information'] = [0.903, 0.684, 0, 0.791, '#joyful', '#admirable', 0.793, 'exchange_idea', 'share_knowledge', 'express_opinion', 'exchange_information', 'social_life']
senticnet['share_knowledge'] = [0.786, 0.986, 0, 0.85, '#interesting', '#admirable', 0.874, 'learn_oneself', 'tell_information', 'increase_understand', 'tell_other_person', 'receive_information']
senticnet['share_opinion'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'point_out', 'help_another_person', 'ask_question', 'understand_idea', 'educate_others']
senticnet['share_others'] = [-0.856, 0, -0.974, 0, '#sad', '#scared', -0.61, 'keep_work', 'introspection', 'nostalgia', 'strong_feeling', 'become_distracted']
senticnet['share_secret'] = [-0.044, 0, -0.082, 0, '#sad', '#scared', -0.042, 'part_of_way', 'receive_email', 'forget_name', 'welcome_friend', 'say_love']
senticnet['share_thought'] = [0.657, 0.79, 0, 0.867, '#interesting', '#admirable', 0.771, 'teach_new', 'convey_information', 'express_idea', 'share_idea', 'communication']
senticnet['share_time'] = [-0.972, 0, -0.808, 0, '#sad', '#scared', -0.593, 'enjoy_company', 'feel_lonely', 'make_new_friend', 'get_know', 'get_know_better']
senticnet['shareholder'] = [0.254, 0.188, -0.082, 0.203, '#joyful', '#admirable', 0.188, 'cash', 'open_business', 'get_paid', 'earn_live', 'sell_new_book']
senticnet['shareware'] = [0.658, -0.924, 0, 0.553, '#joyful', '#surprising', 0.712, 'software', 'software_program', 'computer_software', 'software_system', 'software_package']
senticnet['shark'] = [-0.54, 0, 0.983, -0.911, '#angry', '#disgusting', -0.811, 'elasmobranch', 'selachian', 'hammerhead', 'cow_shark', 'mackerel_shark']
senticnet['sharp'] = [-0.054, -0.029, 0.05, -0.133, '#sad', '#disgusting', -0.069, 'dagger', 'machete', 'cut_tool', 'cut_tool_edge', 'use_knife']
senticnet['sharp_corner'] = [0, 0.078, 0.049, 0.08, '#interesting', '#admirable', 0.036, 'sharp_end', 'sharpness', 'geometric_object', 'sharp_edge', 'sport_score']
senticnet['sharp_edge'] = [0, 0, 0.085, -0.047, '#angry', '#disgusting', -0.044, 'blade', 'sharp', 'sharp_end', 'sharpness', 'knife_sharp']
senticnet['sharp_end'] = [0, 0, -0.955, -0.802, '#scared', '#disgusting', -0.586, 'geometric_object', 'indicate', 'sharp_corner', 'sharpness', 'sport_score']
senticnet['sharp_hurt'] = [-0.093, -0.04, 0, -0.095, '#sad', '#disgusting', -0.049, 'sever', 'tear_apart', 'cause_bleed', 'open_wind', 'painful_injury']
senticnet['sharp_nail'] = [0.04, -0.26, 0.08, 0.15, '#surprising', '#admirable', 0.123, 'pointy', 'sharp', 'straight_line', 'sharp_edge', 'stick']
senticnet['sharp_object'] = [0, 0, -0.978, -0.939, '#scared', '#disgusting', -0.639, 'pointy_object', 'use_knife', 'find_victim', 'knife_sharp', 'pin_needle']
senticnet['sharp_pain'] = [-0.989, 0, 0.92, -0.998, '#sad', '#disgusting', -0.969, 'shock', 'electric_shock', 'fear', 'pain', 'sharp']
senticnet['sharp_point'] = [0, 0, -0.888, -0.797, '#scared', '#disgusting', -0.562, 'sharp_nail', 'sharp', 'sharp_end', 'pointy', 'jag']
senticnet['sharp_tool'] = [-0.949, 0, 0.655, -0.959, '#sad', '#disgusting', -0.854, 'use_knife', 'use_blade', 'cut', 'cut_thing', 'dangerous']
senticnet['sharp_tooth'] = [-0.034, 0, 0.039, 0, '#sad', '#angry', -0.024, 'fur_keep_warm', 'no_hair', 'large_eye', 'tic', 'stick_out']
senticnet['sharp_weapon'] = [-0.92, 0, -0.823, 0, '#sad', '#scared', -0.581, 'dangerous_weapon', 'automatic', 'weapon', 'bayonet', 'big_gun']
senticnet['sharpen'] = [0.846, 0.995, 0, 0, '#joyful', '#interesting', 0.614, 'sharpen_pencil', 'display_information', 'smear', 'make_sketch', 'mark_piece_of_paper']
senticnet['sharpen_knife'] = [-0.1, 0, -0.052, -0.105, '#sad', '#disgusting', -0.086, 'ship_package', 'die_young', 'act_up', 'box_ear', 'shovel_snow']
senticnet['sharpen_pencil'] = [0.846, 0.995, 0, 0, '#joyful', '#interesting', 0.614, 'select_topic', 'knowledge_subject', 'research_topic', 'study_for_exam', 'add_number_together']
senticnet['sharpie'] = [0.947, -0.503, 0, 0.814, '#joyful', '#admirable', 0.755, 'goffer', 'gopher', 'actor', 'doer', 'worker']
senticnet['sharpness'] = [0.988, 0.967, 0, 0, '#joyful', '#interesting', 0.652, 'sharp_end', 'sharp_corner', 'point', 'sharp_edge', 'merge']
senticnet['sharpy'] = [0.941, -0.837, 0, 0.973, '#joyful', '#admirable', 0.917, 'goffer', 'gopher', 'actor', 'doer', 'worker']
senticnet['shatter'] = [-0.084, 0, -0.049, 0, '#sad', '#scared', -0.044, 'destroy', 'smash', 'break', 'pulverize', 'crush']
senticnet['shave'] = [-0.052, -0.028, 0.038, -0.07, '#sad', '#disgusting', -0.044, 'shave_beard', 'shave_leg', 'fix_hair', 'new_hair_style', 'trim_hair']
senticnet['shave_beard'] = [-0.043, -0.026, 0.057, -0.083, '#angry', '#disgusting', -0.052, 'cut_paper', 'trim_hair', 'shave_leg', 'use_scissor', 'cut_ribbon']
senticnet['shave_face'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'make_appointment', 'go_hair_salon', 'put_nice_clothes', 'go_barber', 'schedule_appointment']
senticnet['shave_head'] = [-0.038, -0.016, 0.018, -0.045, '#sad', '#disgusting', -0.028, 'dye_hair', 'cut_hair', 'change_hairstyle', 'haircut', 'go_get_haircut']
senticnet['shave_kit'] = [0.022, -0.015, 0.062, -0.099, '#angry', '#disgusting', -0.041, 'electric_toothbrush', 'moistener', 'hairbrush', 'shampoo_conditioner', 'hair_brush']
senticnet['shave_leg'] = [-0.062, -0.047, 0.064, -0.108, '#angry', '#disgusting', -0.062, 'shave', 'trim_hair', 'shave_beard', 'cut_paper', 'shorten_hair']
senticnet['shaving_cream'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'blank_check', 'pantyhose', 'address_book', 'shave_kit', 'lingerie']
senticnet['shear'] = [0, -0.036, 0.057, -0.089, '#angry', '#disgusting', -0.037, 'lamb_meat', 'bandage', 'ewe', 'mutton', 'seam']
senticnet['sheath'] = [-0.035, 0, 0, -0.116, '#sad', '#disgusting', -0.05, 'store_cloth', 'clothes_factory', 'case', 'sword', 'gun_store']
senticnet['shed_tear'] = [-0.244, -0.007, -0.445, 0, '#sad', '#scared', -0.227, 'cry', 'sadness', 'deep_sadness', 'loneliness', 'sob']
senticnet['sheep'] = [0.656, -0.817, 0, 0.909, '#surprising', '#admirable', 0.794, 'black_sheep', 'ewe', 'ram', 'tup', 'wether']
senticnet['sheepish'] = [-0.981, 0, 0, -0.906, '#sad', '#disgusting', -0.629, 'unenviable', 'abash', 'awkward', 'embarrassingly', 'embarrassing']
senticnet['sheepishness'] = [-0.957, 0, 0, -0.765, '#sad', '#disgusting', -0.574, 'shamefacedly', 'shamefacedness', 'confused', 'disordered', 'discombobulation']
senticnet['sheepskin'] = [0, 0.081, 0.015, 0.052, '#interesting', '#admirable', 0.039, 'white_cotton', 'fabric_material', 'woven_fabric', 'fabric', 'clothes_type']
senticnet['sheepskin_material'] = [0, 0.081, 0.015, 0.052, '#interesting', '#admirable', 0.039, 'white_cotton', 'fabric', 'woven_sheepskin', 'sheepskin', 'clothes_type']
senticnet['sheet_paper'] = [0.044, -0.026, 0, 0, '#joyful', '#surprising', 0.023, 'paperwork', 'piece_of_paper', 'staple_remover', 'board', 'whiteboard']
senticnet['shell_animal'] = [0.087, -0.041, 0, 0, '#joyful', '#surprising', 0.043, 'keep_in_cage', 'animal', 'home_animal', 'crab', 'lobster']
senticnet['shell_fish'] = [0.052, 0.066, 0, 0.106, '#interesting', '#admirable', 0.075, 'sometimes', 'seafood', 'marine_animal', 'ocean_animal', 'crustacean']
senticnet['shell_shock'] = [-0.754, 0, 0.87, -0.514, '#sad', '#angry', -0.713, 'battle_fatigue', 'combat_fatigue', 'combat_neurosis', 'posttraumatic_stress_disorder', 'anxiety_disorder']
senticnet['shelter'] = [0.035, 0.11, -0.046, 0.107, '#interesting', '#admirable', 0.069, 'live_area', 'residence', 'comfy', 'live_space', 'rest_place']
senticnet['shelter_deck'] = [0.831, -0.821, 0, 0.826, '#joyful', '#admirable', 0.826, 'deck', 'freeboard_deck', 'weather_deck', 'upper_deck', 'boat_deck']
senticnet['shelter_weather'] = [0.201, 0.067, 0.025, 0.15, '#joyful', '#admirable', 0.131, 'come_back_home', 'avoid_crash', 'reside', 'sit_airplane', 'reach_destination']
senticnet['shenanigan'] = [-0.609, 0, 0.866, -0.82, '#angry', '#disgusting', -0.765, 'misbehavior', 'misdeed', 'hell', 'vandalism', 'hooliganism']
senticnet['shepherd'] = [0.797, 0.909, 0, 0, '#joyful', '#interesting', 0.569, 'servant', 'goat', 'lamb', 'peasant', 'hog']
senticnet['shew'] = [0.825, -0.607, 0, 0.56, '#joyful', '#surprising', 0.664, 'stultify', 'prove_oneself', 'support', 'prove', 'negate']
senticnet['shield'] = [0.745, 0.85, 0, 0, '#joyful', '#interesting', 0.532, 'protective_cover', 'protective_covering', 'scale', 'protection', 'nipple_shield']
senticnet['shielded'] = [-0.898, 0, 0.627, -0.547, '#sad', '#angry', -0.691, 'protected', 'weatherproof', 'covert', 'stormproof', 'fortified']
senticnet['shift_gear'] = [-0.882, 0, -0.994, 0, '#sad', '#scared', -0.625, 'honk_horn', 'run_out_gas', 'stop_red_light', 'turn_steer_wheel', 'skid_mark']
senticnet['shigellosis'] = [-0.892, 0, 0.702, -0.671, '#sad', '#angry', -0.755, 'amebic_dysentery', 'amoebic_dysentery', 'dysentery', 'bacillary_dysentery', 'infectious_disease']
senticnet['shilling'] = [-0.081, 0.186, 0, 0.121, '#interesting', '#admirable', 0.075, 'cent', 'franc', 'dime', 'coin', 'dollar']
senticnet['shin'] = [-0.028, -0.02, 0.072, 0, '#sad', '#angry', -0.027, 'lower_body', 'thigh', 'human_limb', 'above_leg', 'two_feet']
senticnet['shin_splint'] = [0, 0, -0.813, -0.773, '#scared', '#disgusting', -0.529, 'heavy_breathe', 'get_out_breath', 'run_out_breath', 'become_wind', 'breathlessness']
senticnet['shine'] = [0.042, 0.126, -0.065, 0.165, '#interesting', '#admirable', 0.089, 'sparkle', 'shiny', 'shinny', 'gray', 'moonlight']
senticnet['shine_at'] = [-0.53, 0, 0.977, -0.544, '#angry', '#disgusting', -0.684, 'rank', 'outrank', 'surpass', 'excel_at', 'exceed']
senticnet['shine_car'] = [0, 0.76, 0, 0.73, '#interesting', '#admirable', 0.497, 'mine_diamond', 'close_together', 'bicycle_across_town', 'dig_grave', 'kill_specific_group']
senticnet['shine_light'] = [-0.081, 0.072, -0.121, 0, '#sad', '#scared', -0.043, 'burn_up', 'dig_up', 'dig_gold', 'light_up', 'shine_car']
senticnet['shine_shoes'] = [0, 0.799, 0, 0, '#interesting', '#interesting', 0.266, 'iron_shirt', 'sit_on_beach', 'dry_clothes', 'iron_clothes', 'absorb_moisture']
senticnet['shine_sun'] = [0.102, 0.095, -0.063, 0.091, '#joyful', '#interesting', 0.075, 'bright_light', 'light', 'radio_wave', 'bright', 'source_light']
senticnet['shine_up'] = [0.985, -0.759, 0, 0.894, '#joyful', '#admirable', 0.879, 'cozy_up', 'cotton_up', 'ingratiate', 'sidle_up', 'play_up']
senticnet['shinny'] = [0.031, 0, 0.028, 0.082, '#joyful', '#admirable', 0.028, 'type_of_metal', 'shiny', 'use_jewelry', 'magnetic', 'tin']
senticnet['shiny'] = [0.049, 0, 0.023, 0.095, '#joyful', '#admirable', 0.04, 'shinny', 'magnetic', 'use_jewelry', 'hard_plastic', 'tin']
senticnet['shiny_coat'] = [0, -0.013, 0.038, -0.118, '#angry', '#disgusting', -0.048, 'flesh', 'bone', 'skeletal_system', 'muscle', 'live_meat']
senticnet['shiny_metal'] = [-0.04, -0.021, 0.027, -0.031, '#sad', '#disgusting', -0.026, 'precious_metal', 'olympic_medal', 'many_different_kinds', 'bloodstone', 'valuable_metal']
senticnet['shiny_surface'] = [0.807, 0, 0, 0.738, '#joyful', '#admirable', 0.515, 'type_of_material', 'material_type', 'soft_cloth', 'shiny', 'hard_rock']
senticnet['ship'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'yacht', 'boat', 'sailboat', 'water_vehicle', 'speed_boat']
senticnet['ship_boat'] = [-0.026, -0.013, 0.069, -0.05, '#angry', '#disgusting', -0.044, 'harbor', 'water_body', 'water_transport', 'water_float', 'cabin']
senticnet['ship_company'] = [0.814, -0.878, 0, 0.918, '#surprising', '#admirable', 0.87, 'full_complement', 'company', 'work_force', 'workforce', 'manpower']
senticnet['ship_container'] = [0, 0, 0.088, 0, '#angry', '#angry', -0.029, 'carry_vessel', 'military_ship', 'big_boat', 'large_boat', 'ship']
senticnet['ship_goods'] = [0.725, 0, 0, 0.794, '#joyful', '#admirable', 0.506, 'squeeze', 'charge_credit_card', 'sit_toilet', 'choose_color', 'group_object']
senticnet['ship_home'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'go_home', 'port', 'bay', 'find_sea', 'lake']
senticnet['ship_package'] = [-0.114, 0, 0, -0.106, '#sad', '#disgusting', -0.073, 'sharpen_knife', 'act_up', 'die_young', 'crowd_elevator', 'bridge_difference']
senticnet['ship_part'] = [-0.047, 0.1, 0, 0.152, '#interesting', '#admirable', 0.068, 'look', 'glimpse', 'stare', 'quick_look', 'cabin']
senticnet['ship_sink'] = [-0.798, 0, -0.977, 0, '#sad', '#scared', -0.592, 'puddle', 'sandy_beach', 'dew', 'squirt', 'rain']
senticnet['shirt'] = [-0.047, 0.1, 0, 0.152, '#interesting', '#admirable', 0.068, 'pants', 'jacket', 'clothes', 'robe', 'garment']
senticnet['shirt_pocket'] = [0.026, 0.082, 0, 0, '#joyful', '#interesting', 0.036, 'account_department', 'office', 'stationery_store', 'accountant_office', 'desk_drawer']
senticnet['shit'] = [0, 0, 0, -0.997, '#disgusting', '#disgusting', -0.332, 'poop', 'chew_tobacco', 'detritus', 'barf', 'hike_trail']
senticnet['shite'] = [-0.699, 0, 0.936, -0.875, '#angry', '#disgusting', -0.837, 'stool', 'dejection', 'fecal_matter', 'shit', 'feces']
senticnet['shithead'] = [-0.79, 0, 0.935, -0.705, '#sad', '#angry', -0.81, 'stupid', 'stupid_person', 'stupe', 'dullard', 'dolt']
senticnet['shitting'] = [-0.808, 0, 0.952, -0.958, '#angry', '#disgusting', -0.906, 'shit', 'bowel_movement', 'movement', 'dump', 'asshole']
senticnet['shiver'] = [0, 0, -0.73, 0, '#scared', '#scared', -0.243, 'quiver', 'tingle', 'shudder', 'chill', 'cool']
senticnet['shivery'] = [-0.777, 0, -0.839, 0, '#sad', '#scared', -0.539, 'chilling', 'shuddery', 'apprehension', 'apprehensiveness', 'scare_off']
senticnet['shock_therapy'] = [-0.724, 0, 0.732, -0.595, '#sad', '#angry', -0.684, 'insulin_shock', 'insulin_shock_therapy', 'insulin_shock_treatment', 'metrazol_shock', 'metrazol_shock_therapy']
senticnet['shock_treatment'] = [-0.964, 0, 0.52, -0.546, '#sad', '#disgusting', -0.677, 'insulin_shock', 'insulin_shock_therapy', 'insulin_shock_treatment', 'metrazol_shock', 'metrazol_shock_therapy']
senticnet['shocked'] = [0, 0, -0.75, -0.862, '#scared', '#disgusting', -0.537, 'offend', 'floor', 'take_aback', 'ball_over', 'blow_out_of_water']
senticnet['shocking'] = [-0.927, 0, 0, -0.854, '#sad', '#disgusting', -0.594, 'disgraceful', 'shameful', 'dishonorably', 'inglorious', 'dishonored']
senticnet['shod'] = [-0.591, 0, 0.553, -0.768, '#sad', '#disgusting', -0.637, 'booted', 'slippered', 'roughshod', 'sandaled', 'wear_sandal']
senticnet['shodden'] = [-0.791, 0, 0.865, -0.89, '#angry', '#disgusting', -0.849, 'booted', 'slippered', 'roughshod', 'sandaled', 'wear_sandal']
senticnet['shoddiness'] = [-0.771, 0, 0.599, -0.528, '#sad', '#angry', -0.633, 'vanity', 'trashiness', 'damn', 'worthlessness', 'shit']
senticnet['shoddy'] = [0, 0, 0.863, -0.745, '#angry', '#disgusting', -0.536, 'jerry-built', 'tawdry', 'misleading', 'deceptive', 'cheapjack']
senticnet['shoe'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'flip_flop', 'moccasin', 'slipper', 'footwear', 'shoe_type']
senticnet['shoe_horse'] = [-0.714, 0, -0.744, 0, '#sad', '#scared', -0.486, 'bicycle_across_town', 'mine_diamond', 'dig_grave', 'blue_steel', 'kill_specific_group']
senticnet['shoe_lace'] = [0.03, 0, 0, 0.119, '#joyful', '#admirable', 0.05, 'decorate_oneself', 'propose_marriage', 'display_wealth', 'time_tracker', 'use_finger']
senticnet['shoe_shop'] = [-0.075, 0.228, 0.019, 0.089, '#interesting', '#admirable', 0.074, 'home_depot', 'lumberyard', 'furniture_store', 'front_porch', 'carpet_store']
senticnet['shoe_store'] = [-0.056, -0.047, 0.017, -0.056, '#sad', '#disgusting', -0.027, 'shoe_shop', 'hamper', 'attic', 'obstruct', 'closet']
senticnet['shoe_string'] = [-0.713, 0, 0.539, -0.889, '#sad', '#disgusting', -0.714, 'lace', 'shoestring', 'cord', 'bootlace', 'shoelace']
senticnet['shoe_type'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'type_of_shoes', 'shoe', 'footwear', 'flip_flop', 'casual_shoes']
senticnet['shoed'] = [-0.84, 0, 0.911, -0.604, '#sad', '#angry', -0.785, 'booted', 'slippered', 'roughshod', 'sandaled', 'wear_sandal']
senticnet['shoelace'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'sole', 'shoe', 'footwear', 'lace', 'string']
senticnet['shoestring'] = [-0.713, 0, 0.539, -0.889, '#sad', '#disgusting', -0.714, 'shoe_string', 'lace', 'cord', 'bootlace', 'shoelace']
senticnet['shoot'] = [-0.069, -0.065, -0.049, -0.193, '#sad', '#disgusting', -0.082, 'kill', 'shoot_person', 'fire_gun', 'shoot_cannon', 'fire_bullet']
senticnet['shoot_breeze'] = [0.695, -0.947, 0, 0.662, '#joyful', '#surprising', 0.768, 'schmooze', 'schmoose', 'shmooze', 'shmoose', 'jawbone']
senticnet['shoot_bullet'] = [-0.075, -0.043, -0.075, -0.124, '#sad', '#scared', -0.077, 'shoot_target', 'target_practice', 'kill_people', 'kill_pest', 'blow_up']
senticnet['shoot_cannon'] = [0, 0, 0.776, -0.77, '#angry', '#disgusting', -0.515, 'hit_target', 'shoot', 'shoot_person', 'kill', 'fire_gun']
senticnet['shoot_deer'] = [-0.996, 0, 0.696, -0.959, '#sad', '#disgusting', -0.884, 'gun', 'bullet', 'kill_deer', 'hurt', 'weapon']
senticnet['shoot_down_person'] = [-0.91, 0, 0.495, -0.995, '#sad', '#disgusting', -0.8, 'gun', 'bullet', 'rifle', 'weapon', 'shoot']
senticnet['shoot_gun'] = [-0.121, -0.085, -0.05, -0.209, '#sad', '#disgusting', -0.098, 'fire_gun', 'use_gun', 'shoot', 'fire_weapon', 'load_gun']
senticnet['shoot_person'] = [-0.741, 0, 0, -0.98, '#sad', '#disgusting', -0.574, 'shoot', 'choose_victim', 'shoot_cannon', 'murder_weapon', 'kill']
senticnet['shoot_range'] = [-0.056, -0.014, -0.092, -0.226, '#scared', '#disgusting', -0.12, 'underworld', 'gun_shop', 'combat', 'holster', 'war_zone']
senticnet['shoot_target'] = [-0.051, -0.051, -0.062, -0.157, '#scared', '#disgusting', -0.073, 'target_practice', 'shoot_bullet', 'kill_pest', 'self_defense', 'blow_up']
senticnet['shoot_up'] = [-0.93, 0, 0.292, -0.944, '#sad', '#disgusting', -0.722, 'shoot', 'gun', 'bullet', 'rifle', 'pistol']
senticnet['shoot_weapon'] = [0, 0, -0.883, 0, '#scared', '#scared', -0.294, 'automatic', 'gun', 'firearm', 'ammunition', 'pistol']
senticnet['shooter'] = [-0.85, 0, 0, -0.804, '#sad', '#disgusting', -0.551, 'gun', 'firearm', 'handgun', 'rifle', 'pistol']
senticnet['shooting_brake'] = [-0.539, 0, 0.905, -0.586, '#angry', '#disgusting', -0.677, 'beach_wagon', 'station_wagon', 'wagon', 'estate_car', 'beach_waggon']
senticnet['shooting_iron'] = [0.978, -0.576, 0, 0.793, '#joyful', '#admirable', 0.782, 'pistol', 'handgun', 'side_arm', 'semiautomatic', 'semiautomatic_firearm']
senticnet['shooting_movie'] = [0.956, 0.874, 0, 0, '#joyful', '#interesting', 0.61, 'director', 'director_chair', 'actor', 'important_person', 'movie']
senticnet['shop'] = [0, 0.124, -0.057, 0.203, '#interesting', '#admirable', 0.09, 'small_shop', 'stock_exchange', 'store', 'shop_grocery', 'music_store']
senticnet['shop_arcade'] = [0, 0, 0.016, -0.086, '#angry', '#disgusting', -0.034, 'dime_store', 'deli_store', 'vend_stand', 'bookshop', 'store']
senticnet['shop_bag'] = [0.095, 0, 0, 0, '#joyful', '#joyful', 0.032, 'plastic_bag', 'coffee_cup', 'bag', 'plastic', 'store_shelf']
senticnet['shop_complex'] = [0.966, 0.921, 0, 0.892, '#joyful', '#interesting', 0.926, 'disco', 'nightclub', 'dance_club', 'discotheque', 'fast_food_restaurant']
senticnet['shop_food'] = [0.757, 0.788, 0, 0, '#joyful', '#interesting', 0.515, 'purchase_grocery', 'buy_vegetable', 'buy_grocery', 'purchase_food', 'stock_merchandise']
senticnet['shop_grocery'] = [0.067, 0.162, -0.117, 0.192, '#interesting', '#admirable', 0.101, 'store', 'buy_grocery', 'purchase_grocery', 'buy_food', 'buy_snack']
senticnet['shop_list'] = [0.705, 0.967, 0, 0, '#joyful', '#interesting', 0.557, 'make_shop_list', 'write_note', 'make_list', 'go_shopping', 'go_to_supermarket']
senticnet['shop_mall'] = [0.771, 0, 0, 0, '#joyful', '#joyful', 0.257, 'shop', 'store', 'go_shopping', 'shopping_center', 'buy_stuff']
senticnet['shoplift'] = [-0.183, 0.138, -0.21, 0.086, '#sad', '#scared', -0.056, 'steal', 'rob', 'leave_without_pay', 'bad_citizen', 'robbery']
senticnet['shoplifter'] = [0.041, -0.023, 0.044, -0.106, '#angry', '#disgusting', -0.029, 'suntan_lotion', 'carton_milk', 'store_shelf', 'plastic_container', 'wax_dental_floss']
senticnet['shopper'] = [0.967, 0.707, 0, 0, '#joyful', '#interesting', 0.558, 'customer', 'clerk', 'patron', 'vintner', 'hairdresser']
senticnet['shopping_area'] = [0.95, 0, 0, 0.958, '#joyful', '#admirable', 0.636, 'outlet', 'sour_cream', 'leave_over', 'hand_print', 'taffy']
senticnet['shopping_center'] = [0.771, 0, 0, 0, '#joyful', '#joyful', 0.257, 'shop', 'store', 'shop_mall', 'go_shopping', 'buy_stuff']
senticnet['shore'] = [0, 0, 0, -0.073, '#disgusting', '#disgusting', -0.024, 'driftwood', 'sea_shell', 'scenic_view', 'naked_woman', 'tidal_wave']
senticnet['shore_bird'] = [0.786, -0.82, 0, 0.776, '#joyful', '#surprising', 0.794, 'red_phalarope', 'northern_phalarope', 'shorebird', 'phalarope', 'limicoline_bird']
senticnet['shore_boat'] = [-0.109, 0.07, -0.06, -0.082, '#sad', '#disgusting', -0.06, 'board_ship', 'row_boat', 'battle_cancer', 'pier', 'weather_storm']
senticnet['shore_up_wall'] = [-0.053, 0.111, 0, 0.12, '#interesting', '#admirable', 0.059, 'build_house', 'construct', 'build_wall', 'build_bridge', 'fix_car']
senticnet['short'] = [0, 0, -0.868, -0.895, '#scared', '#disgusting', -0.588, 'unretentive', 'poor', 'inadequate', 'little', 'forgetful']
senticnet['short_circuit'] = [-0.094, -0.018, -0.101, -0.201, '#scared', '#disgusting', -0.126, 'violence', 'siege', 'conflict', 'bloodshed', 'fight']
senticnet['short_cut'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'theme_park', 'combo_pass', 'save_time', 'multiple_entry', 'ticket']
senticnet['short_fall'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'shortage', 'scarceness', 'insufficient', 'in_dearth', 'poverty']
senticnet['short_form'] = [0.067, 0.162, -0.117, 0.192, '#interesting', '#admirable', 0.101, 'happy_together', 'informal', 'belong_person', 'care_giver', 'relate_person']
senticnet['short_hair'] = [-0.038, 0, -0.045, 0, '#sad', '#scared', -0.028, 'hair_become_short', 'little_hair', 'get_new_hairstyle', 'keep_hair_short', 'cold_head']
senticnet['short_line'] = [-0.892, 0, 0, -0.933, '#sad', '#disgusting', -0.608, 'sharp_corner', 'intention', 'embroidery', 'sharp_end', 'mend']
senticnet['short_subject'] = [0.789, -0.518, 0, 0.947, '#joyful', '#admirable', 0.751, 'flick', 'cartoon', 'animated_cartoon', 'toon', 'newsreel']
senticnet['short_temper'] = [-0.124, 0.13, 0.646, -0.64, '#angry', '#disgusting', -0.427, 'irascibility', 'quick_temper', 'irascible', 'choleric', 'ill_temper']
senticnet['short_tempered'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'pervert', 'horny', 'uncomfortable', 'uneasy', 'touchy']
senticnet['short_time'] = [0, 0.069, 0, 0.092, '#interesting', '#admirable', 0.054, 'time_frame', 'time_period', 'calendar_event', 'event', 'time_length']
senticnet['short_version'] = [-0.037, 0.271, -0.082, 0.303, '#interesting', '#admirable', 0.152, 'plea', 'game_show', 'movement_towards', 'award', 'suggest']
senticnet['shortage'] = [-0.837, 0, -0.882, -0.785, '#sad', '#scared', -0.835, 'little', 'sadness', 'small_amount', 'lack', 'absence']
senticnet['shorten'] = [-0.046, 0.127, -0.121, 0.223, '#interesting', '#admirable', 0.061, 'abbreviate', 'abridge', 'curtail', 'cut_short', 'shortcut']
senticnet['shorten_hair'] = [-0.04, -0.024, 0, -0.064, '#sad', '#disgusting', -0.027, 'trim_hair', 'short_hair', 'shave_beard', 'shave', 'get_new_hairstyle']
senticnet['shortness_breath'] = [-0.11, -0.045, -0.064, -0.126, '#sad', '#disgusting', -0.085, 'breathlessness', 'leg_cramp', 'get_out_breath', 'muscle_cramp', 'become_wind']
senticnet['shortsighted'] = [-0.638, 0, 0.867, -0.57, '#sad', '#angry', -0.692, 'myopic', 'short', 'improvident', 'unforesightful', 'thriftless']
senticnet['shotgun'] = [-0.964, 0, 0, -0.705, '#sad', '#disgusting', -0.556, 'hydrogen_bomb', 'rifle', 'revolver', 'pistol', 'gun']
senticnet['shoulder'] = [0, 0, 0, -0.081, '#disgusting', '#disgusting', -0.027, 'bowel', 'scrotum', 'anus', 'liver', 'waist']
senticnet['shoulder_bag'] = [0, -0.036, 0.038, -0.106, '#angry', '#disgusting', -0.036, 'tote_bag', 'satchel', 'fitting_room', 'vanity_case', 'lingerie']
senticnet['shoulder_burden'] = [-0.052, 0.072, 0.012, 0.066, '#interesting', '#admirable', 0.025, 'sink_water', 'open_mailbox', 'bell_cat', 'eat', 'eat_cheese']
senticnet['shoulder_pad'] = [-0.99, 0, 0.806, -0.677, '#sad', '#angry', -0.824, 'wear', 'biohazard_suit', 'coverall', 'protective_garment', 'wearable']
senticnet['shoulder_responsibility'] = [-0.13, 0, -0.061, 0, '#sad', '#scared', -0.064, 'sun_oneself', 'watch_d', 'throw_fit', 'battle_illness', 'honor_parent']
senticnet['shout'] = [-0.732, 0, 0.865, -0.878, '#angry', '#disgusting', -0.825, 'jeer', 'bad_surprise', 'abrupt', 'rude', 'mocking']
senticnet['shout_loudly'] = [-0.083, 0.089, 0, 0.097, '#interesting', '#admirable', 0.034, 'ride_bicycle_work', 'take_hike', 'stop_smoke', 'scream_real_loud', 'break_record']
senticnet['shout_top_voice'] = [0, 0, 0, -0.783, '#disgusting', '#disgusting', -0.261, 'bungee_jump_from_high_bridge', 'asthma_attack', 'run_after_ball', 'high_blood_pressure', 'go_gym']
senticnet['shouting'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'noisy', 'noise_pollution', 'blaring', 'make_sound', 'loud']
senticnet['shove_around'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'push', 'ram', 'barge', 'bang', 'jostle']
senticnet['shovel_snow'] = [0.903, 0.815, 0, 0, '#joyful', '#interesting', 0.573, 'fly_around', 'smoke_joint', 'blow_away', 'mine_gold', 'sit_floor']
senticnet['show'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'cinema', 'movie', 'watch_movie', 'theater', 'cctv']
senticnet['show_affection'] = [0.809, 0, 0, 0, '#joyful', '#joyful', 0.27, 'show_love', 'express_love', 'make_happy', 'show_care', 'say_thank_you']
senticnet['show_appreciation'] = [0.926, 0, 0, 0.868, '#joyful', '#admirable', 0.598, 'warm_feeling', 'show_love', 'demand', 'say_welcome', 'express_gratitude']
senticnet['show_around'] = [0, 0.084, 0, 0.083, '#interesting', '#admirable', 0.056, 'home_sweet_home', 'guest', 'take_care', 'offer_accommodation', 'host']
senticnet['show_care'] = [0.774, 0, 0, 0, '#joyful', '#joyful', 0.258, 'express_appreciation', 'celebrate_birthday', 'show_affection', 'make_happy', 'get_present']
senticnet['show_emotion'] = [-0.128, 0, -0.153, 0.051, '#sad', '#scared', -0.077, 'whine', 'jump_out', 'shed_tear', 'surprise_friend', 'eye_tear']
senticnet['show_empathy'] = [0, 0.776, 0, 0.966, '#interesting', '#admirable', 0.581, 'love_oneself', 'love_back', 'find_woman', 'care_deeply', 'say_welcome']
senticnet['show_feeling'] = [0.155, 0.199, -0.174, 0.2, '#interesting', '#admirable', 0.127, 'interaction', 'funny', 'demonstrate', 'activity', 'circus_performer']
senticnet['show_how'] = [0, 0.928, 0, 0.723, '#interesting', '#admirable', 0.55, 'form_of_communication', 'medium', 'grammar_part', 'computer_application', 'unit_language']
senticnet['show_id'] = [-0.035, 0, 0.017, -0.058, '#sad', '#disgusting', -0.037, 'order_hamburger', 'order_beer', 'money_credit', 'make_sure_enough_money', 'go_supermarket']
senticnet['show_know'] = [-0.063, -0.033, 0, -0.11, '#sad', '#disgusting', -0.047, 'receive_grade', 'get_grade', 'complete_course', 'test_knowledge', 'get_qualification']
senticnet['show_like'] = [0.762, 0.91, 0, 0, '#joyful', '#interesting', 0.557, 'give_pleasure', 'get_sex', 'amuse', 'good_time', 'get_to_know_person']
senticnet['show_love'] = [0.728, 0, 0, 0.933, '#joyful', '#admirable', 0.554, 'show_affection', 'express_love', 'make_happy', 'warm_feeling', 'lust']
senticnet['show_movie'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'see_film', 'enter_theater', 'cinema', 'watch_movie', 'watch_film']
senticnet['show_off'] = [0, 0, 0.981, -0.723, '#angry', '#disgusting', -0.568, 'get_out_of_house', 'funny_friend', 'social_bond', 'impress_girl', 'recreation']
senticnet['show_off_wealth'] = [0.077, -0.013, 0.045, 0.124, '#joyful', '#admirable', 0.056, 'make_pollution', 'transport_person', 'get_place', 'get_around_town', 'get_school']
senticnet['show_picture'] = [0, 0.07, 0.041, 0.058, '#interesting', '#admirable', 0.029, 'receive_information', 'share_information', 'share_thought', 'masturbate', 'interrupt']
senticnet['show_play'] = [0.883, 0.926, 0, 0, '#joyful', '#interesting', 0.603, 'present_play', 'perform_play', 'stage_play', 'drama', 'performance']
senticnet['show_respect'] = [0.711, 0, 0, 0.711, '#joyful', '#admirable', 0.474, 'polite', 'no_other_choice', 'stand_behind', 'say_thank_you', 'show_affection']
senticnet['show_sample'] = [0, 0.142, -0.082, 0.258, '#interesting', '#admirable', 0.106, 'description', 'example', 'show_how', 'sample', 'teach']
senticnet['show_support'] = [0.339, 0, -0.257, 0.419, '#joyful', '#admirable', 0.167, 'adore', 'cloud_judgment', 'feel_pleasure', 'have_fun', 'appreciate']
senticnet['show_ticket'] = [0.577, -0.502, 0, 0.901, '#joyful', '#admirable', 0.66, 'dress_nicely', 'dating', 'dinner', 'find_place_to_sit', 'restaurant']
senticnet['show_time'] = [-0.045, -0.029, 0.061, 0, '#sad', '#angry', -0.026, 'timekeeper', 'time', 'swiss_watch', 'device_measure_time', 'tell_time']
senticnet['show_tooth'] = [0.89, 0, 0, 0.8, '#joyful', '#admirable', 0.563, 'contagious', 'expression', 'facial_expression', 'mouth_movement', 'sniff']
senticnet['show_up'] = [0, 0.866, 0, 0.938, '#interesting', '#admirable', 0.601, 'show_up_time', 'go_abroad', 'enroll_school', 'available', 'sign_up']
senticnet['show_up_time'] = [-0.072, 0, 0, -0.065, '#sad', '#disgusting', -0.046, 'enroll_school', 'study_lot', 'a_lot_of_study', 'go_class', 'study_course_material']
senticnet['shower'] = [-0.091, 0, 0, 0, '#sad', '#sad', -0.03, 'water_garden', 'water_lawn', 'heater', 'adjust_water_temperature', 'cook']
senticnet['shower_cap'] = [0.179, 0.164, -0.052, 0.163, '#joyful', '#interesting', 0.151, 'cover_hair', 'hat', 'cap', 'head_wear', 'scarf']
senticnet['shower_curtain'] = [0, -0.029, 0.041, -0.102, '#angry', '#disgusting', -0.038, 'separate_shower', 'shampoo_conditioner', 'towel_bar', 'shower_head', 'toilet_brush']
senticnet['shower_down'] = [-0.837, 0, 0.87, -0.978, '#angry', '#disgusting', -0.895, 'precipitate', 'mizzle', 'rain_down', 'spit', 'patter']
senticnet['shower_gel'] = [0, 0.069, 0.023, 0.052, '#interesting', '#admirable', 0.033, 'soapy_water', 'wash_self', 'soap_water', 'soap_up', 'turn_water']
senticnet['shower_head'] = [0.041, 0.086, 0.016, 0, '#joyful', '#interesting', 0.037, 'separate_shower', 'bath_shower', 'shampoo_conditioner', 'plunger', 'tub']
senticnet['showman'] = [0.563, -0.81, 0, 0.577, '#surprising', '#admirable', 0.65, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['showmanship'] = [0.816, -0.596, 0, 0.538, '#joyful', '#surprising', 0.65, 'acquirement', 'skill', 'accomplishment', 'acquisition', 'attainment']
senticnet['showpiece'] = [0.507, -0.527, 0, 0.579, '#surprising', '#admirable', 0.538, 'curio', 'oddity', 'curiosity', 'peculiarity', 'oddment']
senticnet['showstopper'] = [0.654, -0.571, 0, 0.898, '#joyful', '#admirable', 0.708, 'routine', 'bit', 'number', 'act', 'turn']
senticnet['showtime'] = [0.813, -0.759, 0, 0.664, '#joyful', '#surprising', 0.745, 'point_in_time', 'threshold', 'birth', 'incipiency', 'incipience']
senticnet['showy'] = [0, 0, -0.919, -0.952, '#scared', '#disgusting', -0.624, 'jazzy', 'flashy', 'splashy', 'flamboyant', 'gaudy']
senticnet['showy_lady_slipper'] = [0.277, 0.161, 0, 0.337, '#joyful', '#admirable', 0.258, 'moccasin_flower', 'nerveroot', 'ladies_slipper', 'yellow_lady_slipper', 'clustered_lady_slipper']
senticnet['shrew'] = [-0.598, 0, 0.573, -0.56, '#sad', '#angry', -0.577, 'termagant', 'old_bag', 'disagreeable_woman', 'frump', 'hellcat']
senticnet['shrewdness'] = [0.545, -0.717, 0, 0.811, '#surprising', '#admirable', 0.691, 'foxiness', 'slyness', 'wiliness', 'craftiness', 'cunning']
senticnet['shriek'] = [0.545, -0.881, 0, 0.898, '#surprising', '#admirable', 0.775, 'cry', 'yell', 'call', 'outcry', 'shout']
senticnet['shrieking'] = [0.758, -0.751, 0, 0.683, '#joyful', '#surprising', 0.731, 'cry', 'yell', 'call', 'outcry', 'shout']
senticnet['shrill'] = [0, 0, 0.956, -0.76, '#angry', '#disgusting', -0.572, 'cry', 'yell', 'scream', 'hollo', 'call']
senticnet['shrine'] = [0.025, 0.251, 0.013, 0.165, '#interesting', '#admirable', 0.143, 'capital_build', 'monastery', 'sanctuary', 'temple', 'cathedral']
senticnet['shrink'] = [-0.996, 0, 0.327, -0.913, '#sad', '#disgusting', -0.745, 'shrinkage', 'clothes_shrinkage', 'become_small', 'remove_stain', 'fight_fire']
senticnet['shrinkage'] = [-0.996, 0, 0.327, -0.913, '#sad', '#disgusting', -0.745, 'shrink', 'clothes_shrink', 'become_small', 'remove_stain', 'fight_fire']
senticnet['shrug'] = [0, 0, -0.87, -0.853, '#scared', '#disgusting', -0.574, 'lunge', 'wiggle', 'push', 'progress', 'sway']
senticnet['shrug_off'] = [0.568, -0.996, 0, 0.638, '#surprising', '#admirable', 0.734, 'push_aside', 'brush_off', 'disregard', 'ignore', 'dismiss']
senticnet['shudder'] = [0, 0, -0.917, 0, '#scared', '#scared', -0.306, 'frisson', 'tingle', 'fond_regard', 'emotive', 'affective']
senticnet['shuddery'] = [-0.789, 0, 0, -0.87, '#sad', '#disgusting', -0.553, 'chilling', 'shivery', 'apprehension', 'apprehensiveness', 'scare_off']
senticnet['shuffle_card'] = [0.706, 0.968, 0, 0, '#joyful', '#interesting', 0.558, 'win', 'play_game', 'play_card', 'shuffle_card_machine', 'start_card_game']
senticnet['shuffle_card_machine'] = [0.861, 0.977, 0, 0, '#joyful', '#interesting', 0.613, 'win', 'play_game', 'play_card', 'shuffle_card', 'start_card_game']
senticnet['shunning'] = [0.602, -0.909, 0, 0.761, '#surprising', '#admirable', 0.757, 'rejection', 'escape', 'near_thing', 'aversion', 'averting']
senticnet['shut'] = [-0.939, 0, -0.998, -0.928, '#sad', '#scared', -0.955, 'shut_down', 'close_down', 'barrier', 'language_barrier', 'obstacle']
senticnet['shut_door'] = [-0.033, 0.13, -0.052, 0.126, '#interesting', '#admirable', 0.057, 'close_door', 'climb_to_top', 'lean_against', 'rush_job', 'see_sky']
senticnet['shut_down'] = [-0.124, 0, -0.101, 0, '#sad', '#scared', -0.075, 'collide', 'amount_nothing', 'fall_off_chair', 'fly_around', 'cross_bridge']
senticnet['shut_eye'] = [0.056, 0.083, 0, 0.051, '#joyful', '#interesting', 0.063, 'rest_night', 'lay_down', 'count_sheep', 'lie_down', 'comfortable_place_sleep']
senticnet['shut_in'] = [-0.996, 0, 0.327, -0.913, '#sad', '#disgusting', -0.745, 'close', 'shut', 'hide', 'confine', 'enclose']
senticnet['shut_off_alarm_clock'] = [-0.059, 0, 0.027, -0.048, '#sad', '#disgusting', -0.045, 'fall_out_bed', 'take_nap', 'yawn', 'asleep', 'feel_little_tired']
senticnet['shut_up'] = [-0.041, 0, 0, -0.066, '#sad', '#disgusting', -0.036, 'stop_talk', 'pay_attention', 'dry_mouth', 'hear_sound', 'able_hear']
senticnet['shutter'] = [-0.797, 0, -0.978, 0, '#sad', '#scared', -0.592, 'block', 'obstruct', 'close', 'clogged', 'occluded']
senticnet['shy'] = [-0.874, 0, 0, -0.718, '#sad', '#disgusting', -0.531, 'shyness', 'disconcert', 'diffidently', 'self-doubt', 'self-distrust']
senticnet['shyly'] = [-0.951, 0, 0, -0.977, '#sad', '#disgusting', -0.643, 'bashfully', 'timorousness', 'timidness', 'timidity', 'timidly']
senticnet['shyness'] = [-0.959, 0, 0, -0.768, '#sad', '#disgusting', -0.576, 'diffident', 'self-doubt', 'diffidently', 'diffidence', 'self-distrust']
senticnet['sibilate'] = [0.73, -0.865, 0, 0.609, '#joyful', '#surprising', 0.735, 'pronounce', 'enounce', 'say', 'sound_out', 'enunciate']
senticnet['sick'] = [-0.095, 0.077, 0.458, -0.625, '#angry', '#disgusting', -0.367, 'nausea', 'malice', 'mad', 'resentment', 'disgust']
senticnet['sick_joke'] = [-0.791, 0, 0.732, -0.699, '#sad', '#angry', -0.741, 'gag', 'jest', 'jape', 'joke', 'laugh']
senticnet['sick_of'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'disgustful']
senticnet['sick_person'] = [0, 0, -0.131, -0.176, '#scared', '#disgusting', -0.102, 'nurse', 'doctor', 'illness', 'elderly_person', 'cure']
senticnet['sicken'] = [-0.071, 0.137, 0.693, -0.671, '#angry', '#disgusting', -0.433, 'nauseate', 'repel', 'gross_out', 'loathsome', 'churn_up']
senticnet['sickening'] = [-0.062, 0.128, 0.707, -0.677, '#angry', '#disgusting', -0.439, 'sickish', 'turn_stomach', 'vile', 'noisome', 'nauseous']
senticnet['sickeningly'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['sickish'] = [-0.062, 0.128, 0.707, -0.677, '#angry', '#disgusting', -0.439, 'turn_stomach', 'vile', 'sickening', 'noisome', 'nauseous']
senticnet['sickness'] = [-0.909, 0, -0.949, 0, '#sad', '#scared', -0.619, 'illness', 'polio', 'malady', 'disease', 'ailment']
senticnet['side'] = [0.041, 0.09, 0.01, 0.124, '#interesting', '#admirable', 0.082, 'corner', 'sharpness', 'edge', 'right_angle', 'facet']
senticnet['side_arm'] = [0.978, -0.576, 0, 0.793, '#joyful', '#admirable', 0.782, 'pistol', 'handgun', 'semiautomatic', 'shooting_iron', 'semiautomatic_firearm']
senticnet['side_build'] = [0, -0.083, -0.054, 0.099, '#surprising', '#admirable', 0.043, 'phone_book', 'classify_ad', 'city_center', 'letter_alphabet', 'ads']
senticnet['side_chair'] = [0, -0.046, 0.068, -0.066, '#angry', '#disgusting', -0.029, 'box_tissue', 'stapler', 'tape_dispenser', 'box', 'ergonomic_chair']
senticnet['side_dish'] = [0.055, -0.015, 0, 0, '#joyful', '#surprising', 0.023, 'chocolate_pudding', 'green_bean', 'sweetness', 'whip_cream', 'sushi']
senticnet['side_effect'] = [-0.966, 0, 0.501, -0.927, '#sad', '#disgusting', -0.798, 'byproduct', 'wallop', 'effect', 'dent', 'fallout']
senticnet['side_face'] = [0, 0.089, 0.014, 0.134, '#interesting', '#admirable', 0.07, 'face_part', 'hold_glass', 'facial_feature', 'facial_part', 'near_mouth']
senticnet['side_house'] = [-0.056, 0.081, 0, 0.06, '#interesting', '#admirable', 0.028, 'leave_table', 'stock_food', 'reciprocate', 'shut_door', 'cross_room']
senticnet['side_of_bacon'] = [0.648, -0.539, 0, 0.94, '#joyful', '#admirable', 0.709, 'bacon_strip', 'flitch', 'bacon', 'gammon', 'cut_of_pork']
senticnet['side_road'] = [0, 0, 0, -0.069, '#disgusting', '#disgusting', -0.023, 'roadside', 'sidewalk', 'interstate', 'junk_yard', 'street']
senticnet['sideline'] = [-0.728, 0, 0.918, -0.546, '#sad', '#angry', -0.731, 'designate', 'depute', 'reduce', 'demote', 'delegate']
senticnet['sidesplitter'] = [-0.924, 0, 0.631, -0.51, '#sad', '#angry', -0.688, 'gag', 'jest', 'jape', 'joke', 'laugh']
senticnet['sidewalk'] = [0, 0, 0.033, -0.053, '#angry', '#disgusting', -0.029, 'freeway', 'roadside', 'avenue', 'pavement', 'boulevard']
senticnet['sideways'] = [0, 0.103, 0, 0.08, '#interesting', '#admirable', 0.061, 'tree_wood', 'forest', 'dead_tree', 'many_steps', 'wood']
senticnet['sidle_up'] = [0.985, -0.759, 0, 0.894, '#joyful', '#admirable', 0.879, 'cozy_up', 'cotton_up', 'shine_up', 'ingratiate', 'play_up']
senticnet['siege'] = [-0.074, 0, -0.108, -0.189, '#scared', '#disgusting', -0.124, 'battle', 'violence', 'conflict', 'fight', 'big_fight']
senticnet['sigh'] = [-0.194, -0.068, -0.21, 0, '#sad', '#scared', -0.112, 'breath', 'smell_odor', 'exhale', 'drool', 'say_excuse']
senticnet['sigh_relief'] = [0.932, 0, 0, 0, '#joyful', '#joyful', 0.311, 'relieve_tension', 'relax', 'give_thank', 'invigorate', 'feel_relaxed']
senticnet['sightsee'] = [0.932, 0, 0, 0, '#joyful', '#joyful', 0.311, 'travel', 'see_new_place', 'see_sight', 'see_countryside', 'go_to_another_place']
senticnet['sightseer'] = [-0.653, 0, 0.943, -0.756, '#angry', '#disgusting', -0.784, 'rubberneck', 'holidaymaker', 'excursionist', 'tripper', 'traveler']
senticnet['sigmoidoscope'] = [0.255, 0.182, -0.06, 0.314, '#joyful', '#admirable', 0.23, 'doctor_office', 'urethroscope', 'panendoscope', 'hospital', 'check_health']
senticnet['sign'] = [0.037, 0.073, 0, 0.098, '#interesting', '#admirable', 0.069, 'placard', 'indication', 'road_sign', 'post_notice', 'street_sign']
senticnet['sign_agreement'] = [0.81, 0.987, 0, 0, '#joyful', '#interesting', 0.599, 'price_goods', 'plan_retirement', 'mind_store', 'air_grievance', 'explain_everything']
senticnet['sign_autograph'] = [0.725, -0.927, 0, 0, '#joyful', '#surprising', 0.551, 'coincidence', 'math_homework', 'character_play', 'role', 'write']
senticnet['sign_contract'] = [-0.032, 0, -0.085, 0, '#sad', '#scared', -0.039, 'write', 'write_poem', 'medical_examination', 'medical_exam', 'make_shop_list']
senticnet['sign_document'] = [0.037, 0.073, 0, 0.098, '#interesting', '#admirable', 0.069, 'sign_autograph', 'sign', 'document', 'sign_signature', 'sign_up_class']
senticnet['sign_love'] = [0.848, 0.761, 0, 0, '#joyful', '#interesting', 0.536, 'flower', 'yellow_flower', 'flower_bloom', 'poisonous_plant', 'poppy']
senticnet['sign_name'] = [-0.051, 0, -0.067, 0, '#sad', '#scared', -0.039, 'think_need', 'sign_signature', 'bulletin', 'find_pen_and_paper', 'keep_file']
senticnet['sign_paper'] = [-0.167, -0.019, -0.177, 0.062, '#sad', '#scared', -0.088, 'heart_attack', 'criminal_activity', 'understand_fact', 'freedom', 'sign_document']
senticnet['sign_sickness'] = [-0.961, 0, 0.848, -0.824, '#sad', '#angry', -0.878, 'sneeze', 'allergy', 'runny_nose', 'flu', 'common_cold']
senticnet['sign_signature'] = [-0.051, 0, -0.067, 0, '#sad', '#scared', -0.039, 'think_need', 'sign_name', 'bulletin', 'find_pen_and_paper', 'keep_file']
senticnet['sign_up'] = [0, 0.093, 0, 0.07, '#interesting', '#admirable', 0.054, 'listen_advice', 'become_better_person', 'build_strength', 'new_experience', 'dress_success']
senticnet['sign_up_class'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'buy_textbook', 'read_textbook', 'read_book_subject', 'borrow_book', 'use_search_engine']
senticnet['signal'] = [0.053, 0.071, -0.053, 0.124, '#interesting', '#admirable', 0.065, 'warn', 'communicate', 'dictation', 'beckon', 'indication']
senticnet['signature'] = [-0.034, 0.117, -0.047, 0.079, '#interesting', '#admirable', 0.038, 'written_text', 'written_communication', 'information_source', 'sign', 'document']
senticnet['signboard'] = [0.952, -0.527, 0, 0.835, '#joyful', '#admirable', 0.771, 'billboard', 'hoarding', 'sandwich_board', 'scoreboard', 'shingle']
senticnet['significance'] = [0, 0.367, -0.111, 0.327, '#interesting', '#admirable', 0.194, 'significant', 'capitalize', 'good', 'important_thing', 'inclusion']
senticnet['significant'] = [0.04, 0.296, -0.051, 0.351, '#interesting', '#admirable', 0.212, 'significance', 'plus', 'ultimate', 'precision', 'important_thing']
senticnet['significant_other'] = [0.454, 0.32, -0.113, 0.336, '#joyful', '#admirable', 0.332, 'complement', 'compliment', 'world_peace', 'strong_relationship', 'companion']
senticnet['sildenafil'] = [-0.595, 0, 0.537, -0.577, '#sad', '#disgusting', -0.57, 'phentolamine', 'virility_drug', 'virility_drug_citrate', 'tadalafil', 'vardenafil']
senticnet['sildenafil_citrate'] = [-0.595, 0, 0.537, -0.577, '#sad', '#disgusting', -0.57, 'phentolamine', 'sildenafil', 'virility_drug', 'tadalafil', 'vardenafil']
senticnet['silence'] = [0.224, 0.224, -0.123, 0, '#joyful', '#interesting', 0.108, 'hush', 'peace', 'truce', 'seek_psychiatric_help', 'quiet']
senticnet['silent'] = [0, 0, -0.94, -0.71, '#scared', '#disgusting', -0.55, 'tacit', 'soundless', 'still', 'understood', 'mum']
senticnet['silent_movie'] = [-0.719, 0, 0.953, -0.767, '#angry', '#disgusting', -0.813, 'flick', 'movie', 'film', 'picture', 'moving_picture']
senticnet['silent_picture'] = [-0.621, 0, 0.551, -0.741, '#sad', '#disgusting', -0.638, 'flick', 'movie', 'film', 'picture', 'moving_picture']
senticnet['silents'] = [-0.71, 0, 0.618, -0.573, '#sad', '#angry', -0.634, 'flick', 'movie', 'film', 'picture', 'moving_picture']
senticnet['silicon'] = [-0.065, 0, 0.022, 0, '#sad', '#angry', -0.029, 'grainy', 'silicon_rubber', 'silica', 'salty', 'fine_grain']
senticnet['silicon_rubber'] = [-0.065, 0, 0.022, 0, '#sad', '#angry', -0.029, 'grainy', 'silicon', 'silica', 'salty', 'fine_grain']
senticnet['silk'] = [-0.035, 0, 0, -0.045, '#sad', '#disgusting', -0.027, 'cotton', 'asbestos', 'wool', 'cotton_boll', 'velvet']
senticnet['silkiness'] = [-0.643, 0, 0.835, -0.509, '#sad', '#angry', -0.662, 'sleekness', 'slickness', 'smoothness', 'powderiness', 'burnish']
senticnet['silky'] = [0.03, 0, 0, 0.093, '#joyful', '#admirable', 0.041, 'softness', 'soft_fabric', 'cloth_fabric', 'clothes_fabric', 'cloth_material']
senticnet['sill'] = [-0.063, 0, 0.028, 0, '#sad', '#angry', -0.03, 'polish', 'magnify', 'see_out', 'glaze', 'pane']
senticnet['silliness'] = [-0.884, 0, 0, -0.89, '#sad', '#disgusting', -0.591, 'laughter', 'laugh', 'stupidity', 'become_excited', 'terrible_misunderstand']
senticnet['silly'] = [0, 0, 0, -0.968, '#disgusting', '#disgusting', -0.323, 'winner_loser', 'fun', 'victorious', 'win_money', 'win_game']
senticnet['silver'] = [0, 0.793, 0, 0.815, '#interesting', '#admirable', 0.536, 'gold', 'metal', 'ash_gray', 'fluent', 'eloquent']
senticnet['silver_gray'] = [-0.513, 0, 0.651, -0.612, '#angry', '#disgusting', -0.592, 'gray', 'gray_hair', 'old', 'tattletale_gray', 'achromatic_color']
senticnet['silver_metal'] = [0.024, 0, 0, 0.05, '#joyful', '#admirable', 0.025, 'metal_container', 'thin_metal', 'metal_alloy', 'metal_type', 'common_name']
senticnet['silverfish'] = [-0.703, 0, 0.994, -0.99, '#angry', '#disgusting', -0.896, 'insect', 'bristletail', 'thysanuran_insect', 'jumping_bristletail', 'machilid']
senticnet['silverware_drawer'] = [0.036, -0.052, 0, 0, '#joyful', '#surprising', 0.029, 'neat', 'kitchen_drawer', 'cutlery_drawer', 'dine_table', 'table']
senticnet['silvery'] = [-0.7, 0, 0.617, -0.523, '#sad', '#angry', -0.613, 'achromatic', 'blackish', 'bluish_black', 'hueless', 'pitchy']
senticnet['similar'] = [0.14, 0.345, -0.201, 0.378, '#interesting', '#admirable', 0.221, 'good_etiquette', 'same', 'similarity', 'band_together', 'niceness']
senticnet['similar_like'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'same_interest', 'group_of_people', 'community', 'common_good', 'common_interest']
senticnet['similarity'] = [0.262, 0.325, -0.285, 0.387, '#interesting', '#admirable', 0.23, 'human_emotion', 'want_badly', 'yearn', 'pleasant_emotion', 'niceness']
senticnet['simile'] = [0.315, 0.329, -0.259, 0.382, '#interesting', '#admirable', 0.256, 'fresh_breath', 'attitude', 'similarity', 'grin', 'show_tooth']
senticnet['similitude'] = [-0.687, 0, 0.825, -0.86, '#angry', '#disgusting', -0.791, 'resemblance', 'comparison', 'equivalence', 'reflection', 'spitting_image']
senticnet['simmer'] = [-0.66, 0, 0.992, -0.658, '#sad', '#angry', -0.77, 'cold', 'boil', 'temperature', 'low_temperature', 'frigidity']
senticnet['simple'] = [0.857, 0, 0, 0.997, '#joyful', '#admirable', 0.618, 'straightforward', 'easy', 'uncomplicated', 'uninvolved', 'effortless']
senticnet['simple_fracture'] = [-0.812, 0, 0.745, -0.94, '#sad', '#disgusting', -0.832, 'injury', 'hairline_fracture', 'capillary_fracture', 'incomplete_fracture', 'fracture']
senticnet['simple_leaf'] = [-0.666, 0, 0.971, -0.753, '#angry', '#disgusting', -0.797, 'lyrate_leaf', 'needle', 'elliptic_leaf', 'hastate_leaf', 'obovate_leaf']
senticnet['simple_life'] = [0.302, 0, 0.084, 0.175, '#joyful', '#admirable', 0.131, 'expressive', 'form_of_art', 'sanity', 'art', 'knowledgeable']
senticnet['simple_mindedness'] = [-0.613, 0, 0.599, -0.571, '#sad', '#angry', -0.594, 'naiveness', 'simpleness', 'ingenuousness', 'artlessness', 'simplicity']
senticnet['simple_sugar'] = [-0.528, 0, 0.681, -0.768, '#angry', '#disgusting', -0.659, 'triose', 'tetrose', 'pentose', 'hexose', 'aldose']
senticnet['simpleness'] = [-0.613, 0, 0.599, -0.571, '#sad', '#angry', -0.594, 'simple_mindedness', 'naiveness', 'ingenuousness', 'artlessness', 'simplicity']
senticnet['simpleton'] = [0.776, -0.53, 0, 0.728, '#joyful', '#admirable', 0.678, 'saphead', 'muggins', 'tomfool', 'fool', 'booby']
senticnet['simplicity'] = [0.448, 0.292, 0.129, 0.224, '#joyful', '#interesting', 0.278, 'taken_seriously', 'much_need', 'knowledgeable', 'complement', 'remission']
senticnet['simulacrum'] = [-0.818, 0, 0.838, -0.758, '#sad', '#angry', -0.805, 'pretence', 'pretense', 'pretext', 'semblance', 'face_value']
senticnet['simulate'] = [0.559, -0.823, 0, 0.871, '#surprising', '#admirable', 0.751, 'model', 'conform_to', 'pattern', 'take_after', 'mock']
senticnet['simulated'] = [-0.5, 0, 0.97, -0.521, '#angry', '#disgusting', -0.664, 'imitative', 'apish', 'parrotlike', 'apelike', 'mimic']
senticnet['simulation'] = [-0.95, 0, 0.557, -0.668, '#sad', '#disgusting', -0.725, 'pretence', 'feigning', 'pretense', 'pretending', 'pretend']
senticnet['sin'] = [-0.246, 0.179, -0.281, 0, '#sad', '#scared', -0.116, 'vengeance', 'kidnap', 'wrong', 'take_life', 'revenge']
senticnet['sincere'] = [0, 0, 0, 0.835, '#admirable', '#admirable', 0.278, 'mutual_understand', 'give_hint', 'end_conversation', 'acknowledgment', 'others_understand']
senticnet['sincerity'] = [0, 0.829, 0, 0.981, '#interesting', '#admirable', 0.603, 'expectantly', 'anticipant', 'anticipative', 'expectant', 'earnest']
senticnet['sine'] = [0, 0.972, 0, 0.761, '#interesting', '#admirable', 0.578, 'electrical_unit', 'sea_movement', 'mathematic_sign', 'fast_water', 'ocean_movement']
senticnet['sine_qua_non'] = [0.695, -0.856, 0, 0.501, '#joyful', '#surprising', 0.684, 'essential_condition', 'prerequisite', 'responsibility', 'precondition', 'academic_requirement']
senticnet['sinewy'] = [0, -0.877, 0, 0.779, '#surprising', '#admirable', 0.552, 'fibrous', 'tendinous', 'stringy', 'unchewable', 'brawny']
senticnet['sinful'] = [0, 0, 0.753, -0.72, '#angry', '#disgusting', -0.491, 'deadly_sin', 'human_emotion', 'want_badly', 'demand', 'yearn']
senticnet['sing'] = [0.917, 0, 0, 0, '#joyful', '#joyful', 0.306, 'record_music', 'receive_applause', 'sing_song', 'produce_sound', 'hear_well']
senticnet['sing_along'] = [0.98, 0, 0, 0, '#joyful', '#joyful', 0.327, 'enjoy_music', 'tap_foot', 'hear_song', 'earring', 'tap_toe']
senticnet['sing_bird'] = [0.036, 0.127, 0.019, 0.225, '#interesting', '#admirable', 0.123, 'bird', 'batman', 'hatch', 'vulture', 'only_bird']
senticnet['sing_choir'] = [0.969, 0, 0, 0.928, '#joyful', '#admirable', 0.632, 'battle_disease', 'question_authority', 'battle_cancer', 'die', 'expire']
senticnet['sing_dance'] = [0.947, 0.807, 0, 0, '#joyful', '#interesting', 0.585, 'play_instrument', 'sound_beautiful', 'compose_music', 'lovely_music', 'strum']
senticnet['sing_group'] = [0, 0.171, 0.025, 0.144, '#interesting', '#admirable', 0.097, 'church', 'confession', 'monastery', 'chapel', 'synagogue']
senticnet['sing_in_rain'] = [0.02, 0.071, 0, 0.069, '#interesting', '#admirable', 0.053, 'funny_moment', 'crazy_moment', 'dance_in_rain', 'playful', 'dance']
senticnet['sing_microphone'] = [0.191, 0.165, -0.079, 0.114, '#joyful', '#interesting', 0.13, 'masculine', 'sophisticated', 'uneducated', 'contrary', 'sing']
senticnet['sing_song'] = [0.973, 0, 0, 0.878, '#joyful', '#admirable', 0.617, 'entertain_other_person', 'perform_on_stage', 'applause', 'receive_applause', 'hum']
senticnet['sing_well'] = [0.814, 0.773, 0, 0, '#joyful', '#interesting', 0.529, 'like_play', 'travel_fast_light', 'singer', 'live_ocean', 'control_weather']
senticnet['singer'] = [0.882, 0.901, 0, 0, '#joyful', '#interesting', 0.594, 'songwriter', 'vip', 'rock_group', 'guitar_player', 'violinist']
senticnet['single'] = [-0.028, 0.103, 0.069, 0.151, '#interesting', '#admirable', 0.052, 'do_it_yourself', 'unit_of_measurement', 'two_halves', 'enumeration', 'alone']
senticnet['single_celled'] = [0, 0.065, 0.021, 0.052, '#interesting', '#admirable', 0.032, 'microscopic', 'tiny_organism', 'microbe', 'heron', 'amoeba']
senticnet['single_paper'] = [0.044, -0.007, 0.009, 0.138, '#joyful', '#admirable', 0.06, 'flat_thin', 'white_paper', 'paper_piece', 'paper_square', 'game_piece']
senticnet['single_person'] = [0.077, 0.092, 0, 0, '#joyful', '#interesting', 0.056, 'person', 'oneself', 'multiple_people', 'uneducated', 'individual']
senticnet['single_tax'] = [0.559, -0.846, 0, 0.92, '#surprising', '#admirable', 0.775, 'taxation', 'income_tax', 'capital_gains_tax', 'capital_levy', 'departure_tax']
senticnet['single_woman'] = [0.077, 0.092, 0, 0, '#joyful', '#interesting', 0.056, 'single', 'woman', 'maiden', 'girl', 'unmarried']
senticnet['singular'] = [0, 0.099, 0.046, 0.187, '#interesting', '#admirable', 0.08, 'single', 'thing', 'skinny', 'uppercase_bug', 'alone']
senticnet['singular_form'] = [0, 0.994, 0, 0.98, '#interesting', '#admirable', 0.658, 'single', 'unit_of_measurement', 'singular', 'measurement_unit', 'item']
senticnet['singularity'] = [0, 0.131, 0.078, 0.129, '#interesting', '#admirable', 0.061, 'unique', 'array', 'widow', 'alone', 'single']
senticnet['sinister_person'] = [-0.999, 0, 0.905, -0.992, '#sad', '#disgusting', -0.965, 'bad', 'evil', 'evil_man', 'dangerous_person', 'killer']
senticnet['sink'] = [-0.025, 0, 0, -0.062, '#sad', '#disgusting', -0.029, 'down_drain', 'septic_tank', 'water_fountain', 'drain', 'flea_market']
senticnet['sink_ship'] = [-0.068, -0.067, 0, -0.199, '#sad', '#disgusting', -0.067, 'use_military', 'drop_airplane', 'kill_soldier', 'make_war', 'conquer_enemy']
senticnet['sink_water'] = [0, 0.07, 0.027, 0.14, '#interesting', '#admirable', 0.061, 'spring_up', 'bail_water', 'float_through_air', 'hold_two_together', 'travel_through_space']
senticnet['sinking'] = [-0.837, 0, -0.82, 0, '#sad', '#scared', -0.552, 'sinking_feeling', 'misgiving', 'qualm', 'scruple', 'insecurely']
senticnet['sinking_feeling'] = [-0.899, 0, -0.705, 0, '#sad', '#scared', -0.535, 'sinking', 'misgiving', 'qualm', 'scruple', 'insecurely']
senticnet['sinner'] = [-0.752, 0.288, -0.434, -0.058, '#sad', '#scared', -0.319, 'mind_control', 'contradiction', 'sin', 'obsession', 'evil']
senticnet['sip'] = [0.108, 0.1, 0, 0.109, '#joyful', '#admirable', 0.106, 'better_cold', 'gulp', 'potable_liquid', 'liquid_beverage', 'ingest']
senticnet['sir'] = [0.068, 0.134, -0.062, 0.121, '#interesting', '#admirable', 0.087, 'nobleman', 'ceo', 'leadership_position', 'country_leader', 'head_guy']
senticnet['siren'] = [-0.046, -0.028, 0.089, -0.142, '#angry', '#disgusting', -0.083, 'vacuum_cleaner', 'loudspeaker', 'collector', 'steam_locomotive', 'activist']
senticnet['sissified'] = [-0.63, 0, 0.986, -0.946, '#angry', '#disgusting', -0.854, 'womanish', 'effeminate', 'emasculate', 'cissy', 'unmanful']
senticnet['sister_house'] = [0, 0, -0.135, 0, '#scared', '#scared', -0.045, 'womb', 'anus', 'asshole', 'gone_moon', 'land_moon']
senticnet['sit'] = [0.068, 0.134, -0.062, 0.121, '#interesting', '#admirable', 0.087, 'sit_upon', 'sit_down', 'seat_guest', 'sit_at_theater', 'sit_around']
senticnet['sit_airplane'] = [-0.725, 0, -0.803, 0, '#sad', '#scared', -0.509, 'ride_airplane', 'work_pile_up', 'traveling_long_distance', 'come_back_home', 'fall_asleep']
senticnet['sit_around'] = [0.068, 0.134, -0.062, 0.121, '#interesting', '#admirable', 0.087, 'sit_upon', 'sit_down', 'seat_guest', 'sit', 'sit_on_beach']
senticnet['sit_at_theater'] = [0.172, 0.236, -0.135, 0.287, '#interesting', '#admirable', 0.187, 'watch_play', 'sell_ticket', 'watch_performance', 'attend_concert', 'popcorn']
senticnet['sit_back'] = [-0.519, 0, 0.738, -0.834, '#angry', '#disgusting', -0.697, 'relax', 'loosen_up', 'unbend', 'unwind', 'decompress']
senticnet['sit_back_relax'] = [-0.046, 0, -0.071, -0.101, '#scared', '#disgusting', -0.073, 'put_clothes_back', 'clock_out', 'quit_work', 'make_sex', 'stop_work']
senticnet['sit_bench'] = [-0.069, 0, 0, -0.073, '#sad', '#disgusting', -0.047, 'stop_bleed', 'make_look_better', 'change_color', 'make_house_look_better', 'fee_animal']
senticnet['sit_chair'] = [0.903, 0.796, 0, 0, '#joyful', '#interesting', 0.566, 'sit_down', 'take_break', 'stay_bed', 'lie_on_bed', 'go_sleep']
senticnet['sit_computer'] = [-0.1, 0, -0.058, 0, '#sad', '#scared', -0.053, 'rush_job', 'explain_everything', 'deal_card_player', 'stand_alone', 'forward_email']
senticnet['sit_dark'] = [0.855, -0.741, 0, 0, '#joyful', '#surprising', 0.532, 'no_sight', 'laugh', 'see_show', 'eat_popcorn', 'kill_brain_cell']
senticnet['sit_down'] = [-0.026, -0.016, 0.018, -0.11, '#sad', '#disgusting', -0.046, 'sit_chair', 'sit_upon', 'lie_on_bed', 'take_break', 'lean_back']
senticnet['sit_down_chair'] = [0.987, -0.762, 0, 0, '#joyful', '#surprising', 0.583, 'feel_sleepy', 'put_feet_up', 'digest', 'sit', 'clean_up_kitchen']
senticnet['sit_down_table'] = [0.959, 0.969, 0, 0, '#joyful', '#interesting', 0.643, 'hear_well', 'earring', 'tap_foot', 'sing_along', 'order_menu']
senticnet['sit_floor'] = [-0.091, 0, -0.065, 0, '#sad', '#scared', -0.052, 'smoke_joint', 'shovel_snow', 'fly_around', 'blow_away', 'hurt_animal']
senticnet['sit_furniture'] = [0.988, -0.795, 0, 0.65, '#joyful', '#surprising', 0.811, 'sit_place', 'find_chair', 'place_to_sit', 'bend_knee', 'chair']
senticnet['sit_in_shade'] = [-0.035, -0.007, 0, -0.094, '#sad', '#disgusting', -0.041, 'wear_suit', 'underwater', 'turn_aircon_on', 'hold_breath', 'think_food']
senticnet['sit_jury'] = [0.81, 0.749, 0, 0, '#joyful', '#interesting', 0.52, 'examine_evidence', 'consider_evidence', 'find_out_fact', 'decide_case', 'go_courtroom']
senticnet['sit_on_beach'] = [0.759, 0, 0, 0, '#joyful', '#joyful', 0.253, 'get_tan', 'enjoy_sun', 'summer', 'sunshine', 'dry_clothes']
senticnet['sit_on_desk'] = [0.068, 0.134, -0.062, 0.121, '#interesting', '#admirable', 0.087, 'sit', 'sit_chair', 'sit_upon', 'lie_on_bed', 'take_break']
senticnet['sit_out'] = [-0.907, 0, 0.729, -0.802, '#sad', '#disgusting', -0.813, 'bear_up', 'take_lying_down', 'swallow', 'live_with', 'tolerate']
senticnet['sit_outside'] = [0.755, -0.86, 0, 0, '#joyful', '#surprising', 0.538, 'work_pile_up', 'drink_cup_coffee', 'lean_back', 'put_feet_up', 'drink_coffee']
senticnet['sit_place'] = [0.209, 0.115, 0, 0.109, '#joyful', '#interesting', 0.144, 'sit_furniture', 'comfortable_sit', 'horizontal_surface', 'comfortable', 'comfortable_chair']
senticnet['sit_rest'] = [0.926, -0.824, 0, 0, '#joyful', '#surprising', 0.583, 'sit', 'go_home', 'take_nap', 'sit_back_relax', 'sit_airplane']
senticnet['sit_rock_chair'] = [-0.027, 0, 0, -0.065, '#sad', '#disgusting', -0.031, 'think_future', 'quiet_mind', 'miss_appointment', 'sleep_through', 'sleep_late']
senticnet['sit_seat'] = [0.815, -0.773, 0, 0, '#joyful', '#surprising', 0.529, 'buy_popcorn', 'get_ticket', 'find_seat', 'get_front', 'entertain']
senticnet['sit_sofa'] = [0.819, -0.805, 0, 0, '#joyful', '#surprising', 0.541, 'see_commercial', 'watch_commercial', 'fall_asleep', 'change_channel', 'become_bored']
senticnet['sit_stand'] = [0.933, -0.86, 0, 0, '#joyful', '#surprising', 0.598, 'see_star', 'see_far_away', 'go_art_museum', 'use_eye', 'perform_well']
senticnet['sit_still'] = [0.027, 0.104, 0, 0, '#joyful', '#interesting', 0.044, 'turn_aircon_on', 'sit_in_shade', 'take_off_shoes', 'hold_breath', 'lie_around']
senticnet['sit_sun'] = [0.797, 0, 0, 0, '#joyful', '#joyful', 0.266, 'time_think', 'enjoy_beauty', 'enjoy_oneself', 'good_mental_health', 'relax']
senticnet['sit_table'] = [-0.065, -0.004, 0.033, -0.045, '#sad', '#disgusting', -0.046, 'miss_appointment', 'clear_table', 'drink_coffee', 'stop_work', 'sleep_bed']
senticnet['sit_think'] = [0.885, 0.833, 0, 0, '#joyful', '#interesting', 0.573, 'think_creatively', 'brainstorm', 'think', 'scratch_head', 'hang_up']
senticnet['sit_toilet'] = [-0.748, 0, 0.805, 0, '#sad', '#angry', -0.518, 'gather_berry', 'hang_picture_on_wall', 'see_star_night', 'charge_credit_card', 'air_grievance']
senticnet['sit_up'] = [-0.042, 0.114, 0, 0.09, '#interesting', '#admirable', 0.054, 'feel_grateful', 'work_home', 'butter_toast', 'read_bedtime_story', 'ease_pain']
senticnet['sit_upon'] = [0.097, -0.014, 0, 0, '#joyful', '#surprising', 0.037, 'sleep_upon', 'overnight_guest', 'sleep', 'bed_time', 'good_sleep']
senticnet['site'] = [0.091, 0.09, 0, 0.134, '#joyful', '#admirable', 0.105, 'location', 'area', 'place', 'position', 'home']
senticnet['sitting_duck'] = [-0.539, 0, 0.591, -0.593, '#angry', '#disgusting', -0.574, 'mug', 'dupe', 'easy_mark', 'stooge', 'mortal']
senticnet['six_legs'] = [0, -0.077, 0.116, -0.087, '#angry', '#disgusting', -0.042, 'wing_insect', 'fly', 'small_bug', 'fly_away', 'small_insect']
senticnet['six_sides'] = [0, 0.081, 0.039, 0.196, '#interesting', '#admirable', 0.079, 'four_sides', 'polygon', 'geometric_figure', 'hexagon', 'parallelogram']
senticnet['size'] = [0, 0.1, 0.083, 0.152, '#interesting', '#admirable', 0.056, 'measure_unit', 'unit', 'measure', 'magnitude', 'mass_measure']
senticnet['size_up'] = [0, 0.14, 0.06, 0.237, '#interesting', '#admirable', 0.106, 'big_size', 'measure', 'fat', 'measure_pound', 'mass_measure']
senticnet['sized'] = [0.753, -0.945, 0, 0.965, '#surprising', '#admirable', 0.888, 'threepenny', 'size', 'eightpenny', 'fourpenny', 'ninepenny']
senticnet['skag'] = [-0.7, 0, 0.698, -0.578, '#sad', '#angry', -0.659, 'smack', 'hell_dust', 'nose_drops', 'thunder', 'diacetylmorphine']
senticnet['skanky'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['skate'] = [-0.889, 0, 0.778, -0.794, '#sad', '#disgusting', -0.82, 'climb_mountain', 'chop_down_tree', 'prune_tree', 'ski', 'jump_out_of_window']
senticnet['skate_ice'] = [0, 0.14, 0.06, 0.237, '#interesting', '#admirable', 0.106, 'skate', 'winter_sport', 'rollerblade', 'skateboard', 'ski']
senticnet['skate_rink'] = [0, 0, 0, -0.1, '#disgusting', '#disgusting', -0.033, 'ice_rink', 'skate', 'room_temperature', 'loose_end', 'another_planet']
senticnet['skateboard'] = [-0.183, 0, -0.142, -0.111, '#sad', '#scared', -0.145, 'fly_kite', 'walk_dog', 'ride_roller_coaster', 'rake_leave', 'jump_up_down']
senticnet['skedaddle'] = [-0.691, 0, 0.998, -0.84, '#angry', '#disgusting', -0.843, 'evasion', 'lam', 'break', 'escape', 'hegira']
senticnet['skeletal'] = [-0.892, 0, 0.892, 0, '#sad', '#angry', -0.595, 'gaunt', 'emaciated', 'haggard', 'bony', 'cadaverous']
senticnet['skeletal_muscle'] = [0.934, -0.62, 0, 0.79, '#joyful', '#admirable', 0.781, 'voluntary_muscle', 'deltoid', 'pterygoid_muscle', 'abductor', 'abductor_muscle']
senticnet['skeletal_system'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'artery', 'main_artery', 'groin', 'vein', 'muscle']
senticnet['skeleton'] = [0, 0, -0.044, -0.045, '#scared', '#disgusting', -0.03, 'inside_body', 'dog_treat', 'body', 'live_meat', 'flesh']
senticnet['skeptic'] = [-0.527, 0, 0.95, -0.788, '#angry', '#disgusting', -0.755, 'pessimist', 'sceptic', 'doubter', 'defeatist', 'negativist']
senticnet['skeptical'] = [0, 0, -0.791, -0.761, '#scared', '#disgusting', -0.517, 'unbelieving', 'sceptical', 'doubting', 'disbelieving', 'questioning']
senticnet['skepticism'] = [0, 0, 0.938, -0.823, '#angry', '#disgusting', -0.587, 'doubt', 'incertitude', 'dubiety', 'doubtfulness', 'dubiousness']
senticnet['sketch'] = [0, 0.074, 0, 0.06, '#interesting', '#admirable', 0.045, 'use_crayon', 'draw', 'pencil_art', 'make_sketch', 'like_paint']
senticnet['skewness'] = [-0.596, 0, 0.672, -0.831, '#angry', '#disgusting', -0.7, 'geometrical_irregularity', 'radial_asymmetry', 'lopsidedness', 'asymmetry', 'irregularity']
senticnet['ski'] = [-0.889, 0, 0.778, -0.794, '#sad', '#disgusting', -0.82, 'climb_mountain', 'skate', 'prune_tree', 'chop_down_tree', 'jump_out_of_window']
senticnet['ski_resort'] = [0, 0.069, 0, 0.065, '#interesting', '#admirable', 0.045, 'canyon', 'high_mountain', 'rocky_area', 'alp', 'high_place']
senticnet['skid'] = [-0.797, 0, -0.894, 0, '#sad', '#scared', -0.564, 'fall_over', 'lose_foot', 'lose_balance', 'almost_fall', 'before_fall']
senticnet['skid_mark'] = [-0.798, 0, 0.858, 0, '#sad', '#angry', -0.552, 'shift_gear', 'stop_red_light', 'change_gear', 'run_out_gas', 'car_crash']
senticnet['skier'] = [0, -0.031, -0.105, -0.073, '#scared', '#disgusting', -0.049, 'autumn', 'winter', 'avalanche', 'snow_fall', 'volcano']
senticnet['skiffle_group'] = [-0.507, 0, 0.902, -0.548, '#angry', '#disgusting', -0.652, 'gamelan', 'jug_band', 'pop_group', 'mariachi', 'ensemble']
senticnet['skill'] = [-0.031, 0.183, 0, 0.181, '#interesting', '#admirable', 0.111, 'talent', 'draw_blueprint', 'plan', 'blueprint', 'illustrate']
senticnet['skilled'] = [0.835, -0.687, 0, 0.9, '#joyful', '#admirable', 0.807, 'masterful', 'masterly', 'virtuoso', 'skillful', 'skill']
senticnet['skillfulness'] = [0.668, -0.87, 0, 0.606, '#joyful', '#surprising', 0.715, 'adeptness', 'adroitness', 'deftness', 'quickness', 'expertness']
senticnet['skim_through'] = [0.798, 0.744, 0, 0, '#joyful', '#interesting', 0.514, 'look_over', 'read_cover', 'take_look', 'read_through', 'read_fast']
senticnet['skimmer'] = [-0.588, 0, 0.632, -0.638, '#angry', '#disgusting', -0.619, 'chapeau', 'trilby', 'bearskin', 'busby', 'shako']
senticnet['skin'] = [0, 0, 0.021, -0.063, '#angry', '#disgusting', -0.028, 'scrotum', 'skeletal_system', 'shoulder', 'cuticle', 'groin']
senticnet['skin_cancer'] = [-0.095, 0, 0, -0.091, '#sad', '#disgusting', -0.062, 'underground_animal', 'under_ground', 'bury_body', 'sickness', 'underground']
senticnet['skin_care_article'] = [0.962, -0.994, 0, 0, '#joyful', '#surprising', 0.652, 'clipper', 'double_edge_razor', 'thumb_tack', 'pair_of_scissors', 'birth_control_pill']
senticnet['skin_cover'] = [0, 0.066, 0.041, 0.109, '#interesting', '#admirable', 0.045, 'flexible', 'often_red', 'rigid', 'human_organ', 'different_shape']
senticnet['skin_disease'] = [-0.898, 0, 0.998, -0.898, '#sad', '#angry', -0.931, 'erythema', 'flare', 'erythroderma', 'disease_of_skin', 'skin_disorder']
senticnet['skin_disorder'] = [-0.898, 0, 0.998, -0.898, '#sad', '#angry', -0.931, 'erythema', 'flare', 'skin_disease', 'disease_of_skin', 'erythroderma']
senticnet['skin_impurity'] = [-0.027, 0, 0.048, 0, '#sad', '#angry', -0.025, 'furry_creature', 'black_dot', 'big_mouse', 'underground_animal', 'small_rodent']
senticnet['skin_injury'] = [-0.057, 0, -0.072, -0.105, '#scared', '#disgusting', -0.078, 'char', 'burn_hot', 'burn_skin', 'burn', 'grow_yard']
senticnet['skin_irritation'] = [-0.702, 0, -0.831, -0.987, '#scared', '#disgusting', -0.84, 'body_hurt', 'ache', 'ouch', 'cut_skin', 'scar']
senticnet['skin_knee'] = [-0.2, -0.166, 0, -0.349, '#sad', '#disgusting', -0.128, 'get_hurt', 'fall_head', 'bloody_nose', 'injure', 'serious_injury']
senticnet['skin_rash'] = [-0.127, -0.085, 0.349, -0.407, '#angry', '#disgusting', -0.266, 'rash', 'irritation', 'itch', 'provocative', 'skin_irritation']
senticnet['skin_sensation'] = [-0.724, 0, 0.501, -0.576, '#sad', '#disgusting', -0.6, 'itch', 'urtication', 'itchiness', 'itching', 'tickle']
senticnet['skinhead'] = [-0.896, 0, 0.933, -0.932, '#angry', '#disgusting', -0.92, 'bullyboy', 'muscleman', 'muscle', 'hooligan', 'skin']
senticnet['skink'] = [-0.03, -0.017, -0.054, -0.121, '#scared', '#disgusting', -0.063, 'shit', 'wildflower', 'poop', 'wild_flower', 'dog_poop']
senticnet['skinny'] = [0, -0.8, 0, 0.733, '#surprising', '#admirable', 0.511, 'scrawny', 'underweight', 'boney', 'weedy', 'scraggy']
senticnet['skip'] = [-0.933, 0, -0.763, 0, '#sad', '#scared', -0.565, 'dribble', 'break_window', 'best_opponent', 'hit_hard', 'hit']
senticnet['skip_assignment'] = [-0.773, 0, 0.877, -0.947, '#angry', '#disgusting', -0.866, 'avoid_work', 'lazy', 'reject_involvement', 'skip_class', 'avoid_responsibility']
senticnet['skip_class'] = [-0.785, 0, 0, -0.978, '#sad', '#disgusting', -0.588, 'absent', 'skip_work', 'gone', 'avoid_work', 'lazy']
senticnet['skip_over'] = [-0.884, 0, 0.812, -0.64, '#sad', '#angry', -0.779, 'miss', 'neglect', 'overlook', 'drop', 'pretermit']
senticnet['skip_rope'] = [0.155, -0.11, 0.009, -0.056, '#joyful', '#surprising', 0.067, 'dance_well', 'relate_music', 'enter_contest', 'jump_around', 'cheer_up']
senticnet['skip_work'] = [-0.972, 0, 0, -0.993, '#sad', '#disgusting', -0.655, 'skip_class', 'absent', 'gone', 'avoid_work', 'lazy']
senticnet['skreigh'] = [-0.763, 0, 0.516, -0.857, '#sad', '#disgusting', -0.712, 'squall', 'call', 'cry', 'yell', 'scream']
senticnet['skull_bone'] = [-0.932, 0, 0.578, -0.906, '#sad', '#disgusting', -0.805, 'skull', 'death', 'kill', 'die', 'murder']
senticnet['sky_marshal'] = [0.74, -0.539, 0, 0.641, '#joyful', '#admirable', 0.64, 'air_marshal', 'marshal', 'lawman', 'law_officer', 'peace_officer']
senticnet['sky_object'] = [-0.088, 0, 0, 0, '#sad', '#sad', -0.029, 'thunder_storm', 'out_of_blue', 'blue_sky', 'up_high', 'blue_color']
senticnet['skydive'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'take_hike', 'exercise_daily', 'stay_up_night', 'climb_stair', 'staircase']
senticnet['skylight'] = [0.046, -0.03, 0, 0, '#joyful', '#surprising', 0.025, 'light', 'bay_window', 'air_conditioner', 'sky', 'lamp']
senticnet['skyscraper'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'build', 'tall_building', 'architect', 'find_suburb', 'large_build']
senticnet['slack'] = [-0.932, 0, 0.578, -0.906, '#sad', '#disgusting', -0.805, 'lazy', 'slack_off', 'careless', 'terrible', 'bad_flatmate']
senticnet['slack_off'] = [-0.927, 0, 0.757, -0.905, '#sad', '#disgusting', -0.863, 'let_up', 'far', 'die_away', 'abate', 'die']
senticnet['slacker'] = [-0.043, -0.021, 0.041, -0.039, '#sad', '#angry', -0.034, 'shoe', 'loafer', 'slipper', 'moccasin', 'flip_flop']
senticnet['slake'] = [0, 0, 0.932, -0.9, '#angry', '#disgusting', -0.611, 'quench', 'abate', 'allay', 'assuage', 'slack']
senticnet['slam'] = [0, 0.092, 0, 0.172, '#interesting', '#admirable', 0.088, 'build_open', 'hinge', 'entry', 'home_entrance', 'house_front']
senticnet['slam_dunk'] = [-0.91, 0, 0.795, -0.94, '#sad', '#disgusting', -0.882, 'ineluctability', 'unavoidability', 'predictability', 'sure_thing', 'inevitability']
senticnet['slammer'] = [-0.606, 0, 0.866, -0.613, '#angry', '#disgusting', -0.695, 'pokey', 'clink', 'holding_cell', 'jail', 'jailhouse']
senticnet['slander'] = [-0.888, 0, 0.874, -0.949, '#sad', '#disgusting', -0.904, 'injure', 'find_bank', 'get_hurt', 'find_subway_stop', 'die']
senticnet['slang'] = [-0.043, -0.021, 0.041, -0.039, '#sad', '#angry', -0.034, 'jargon', 'lingo', 'cant', 'chatspeak', 'unusual_language']
senticnet['slang_woman'] = [0.883, 0.799, 0, 0, '#joyful', '#interesting', 0.561, 'hot_woman', 'hen_baby', 'hot_babe', 'hen_child', 'baby_chicken']
senticnet['slant'] = [0, 0.106, 0, 0.064, '#interesting', '#admirable', 0.057, 'mountain_side', 'diagonal', 'incline', 'incline_plane', 'steep']
senticnet['slap'] = [-0.046, -0.007, -0.096, -0.036, '#sad', '#scared', -0.057, 'hit_hard', 'make_fist', 'spank', 'learn_lesson', 'feel_hurt']
senticnet['slash'] = [-0.087, -0.015, 0.03, -0.107, '#sad', '#disgusting', -0.07, 'sever', 'lacerate', 'slit', 'separation', 'tear_apart']
senticnet['slash_wrist'] = [-0.157, 0.101, -0.222, -0.093, '#sad', '#scared', -0.124, 'stop_breathe', 'chest_pain', 'die', 'loss_oflife', 'kill_oneself']
senticnet['slate'] = [0.083, -0.036, 0, 0, '#joyful', '#surprising', 0.04, 'good_view', 'bird_droppings', 'gable', 'nature', 'homeowner']
senticnet['slattern'] = [-0.866, 0, 0.926, -0.742, '#sad', '#angry', -0.845, 'tart', 'prostitute', 'harlot', 'bawd', 'sporting_lady']
senticnet['slaughter'] = [-0.671, 0, 0.938, -0.706, '#angry', '#disgusting', -0.772, 'massacre', 'mass_murder', 'carnage', 'bloodbath', 'butchery']
senticnet['slave'] = [0, 0, 0.998, -0.734, '#angry', '#disgusting', -0.577, 'personnel', 'attendant', 'manager', 'elect_official', 'gentleman']
senticnet['slave_owner'] = [0.056, 0.075, 0, 0.069, '#interesting', '#admirable', 0.067, 'see_eye_dog', 'future_robot', 'slave', 'type_of_dog', 'dog']
senticnet['slavery'] = [-0.852, 0, 0.882, -0.91, '#angry', '#disgusting', -0.881, 'slave', 'hardship', 'responsibility', 'drudgery', 'duty']
senticnet['slay'] = [-0.119, 0.079, -0.18, -0.043, '#sad', '#scared', -0.088, 'shoot', 'homicide', 'alibi', 'use_weapon', 'use_gun']
senticnet['slayer'] = [-0.628, 0, 0.94, -0.998, '#angry', '#disgusting', -0.855, 'poisoner', 'choker', 'mortal', 'executioner', 'public_executioner']
senticnet['slaying'] = [-0.547, 0, 0.669, -0.788, '#angry', '#disgusting', -0.668, 'massacre', 'mass_murder', 'carnage', 'assassination', 'bloodshed']
senticnet['sleaziness'] = [-0.774, 0, 0.748, -0.606, '#sad', '#angry', -0.709, 'ignobleness', 'ignobility', 'dishonorableness', 'unrespectability', 'disreputability']
senticnet['sleekness'] = [-0.643, 0, 0.835, -0.509, '#sad', '#angry', -0.662, 'smoothness', 'slickness', 'silkiness', 'powderiness', 'burnish']
senticnet['sleep_apnea'] = [-0.122, 0.07, -0.189, -0.125, '#scared', '#disgusting', -0.122, 'ill', 'sickness', 'unwell', 'malady', 'emergency']
senticnet['sleep_area'] = [0.956, 0.7, 0, 0, '#joyful', '#interesting', 0.552, 'sleep_place', 'comfy', 'rest_place', 'horizontal_surface', 'occur']
senticnet['sleep_back'] = [-0.092, -0.071, 0.02, -0.182, '#sad', '#disgusting', -0.074, 'learn_new_idea', 'choose_seat', 'fall_asleep', 'drink_cup_coffee', 'bed_time']
senticnet['sleep_bed'] = [-0.12, 0, -0.075, -0.046, '#sad', '#scared', -0.08, 'think_future', 'die_only_once', 'battle_illness', 'hurt_animal', 'honor_parent']
senticnet['sleep_cat'] = [0, -0.102, 0.112, -0.115, '#angry', '#disgusting', -0.042, 'cat_hair', 'cookie_crumb', 'coffee_table', 'dust_mite', 'dirty_sock']
senticnet['sleep_day'] = [-0.052, 0, 0, -0.055, '#sad', '#disgusting', -0.036, 'oversleep', 'toss_turn', 'pull_up_cover', 'take_afternoon_nap', 'look_out_window']
senticnet['sleep_disorder'] = [-0.791, 0, -0.941, 0, '#sad', '#scared', -0.577, 'medical_problem', 'ailment', 'sign_sickness', 'diagnose', 'emergency']
senticnet['sleep_dog'] = [-0.901, 0, 0, -0.869, '#sad', '#disgusting', -0.59, 'fallen_leaf', 'pine_cone', 'detritus', 'dead_leaf', 'truffle']
senticnet['sleep_drug'] = [-0.036, -0.007, -0.122, -0.202, '#scared', '#disgusting', -0.118, 'analgesic', 'medicine', 'ibuprofen', 'pill', 'antibiotic']
senticnet['sleep_early'] = [0.808, 0.803, 0, 0, '#joyful', '#interesting', 0.537, 'set_alarm_clock', 'go_bed_early', 'set_alarm', 'deep_sleep', 'take_nap']
senticnet['sleep_furniture'] = [0.203, 0.14, -0.053, 0.093, '#joyful', '#interesting', 0.128, 'good_night', 'inactivity', 'shut_eye', 'restful', 'cozy']
senticnet['sleep_in'] = [-0.621, 0, 0.944, -0.729, '#angry', '#disgusting', -0.765, 'catnap', 'sleep_late', 'catch_some_z', 'rest', 'practice_bundling']
senticnet['sleep_late'] = [-0.621, 0, 0.944, -0.729, '#angry', '#disgusting', -0.765, 'catnap', 'catch_some_z', 'sleep_in', 'rest', 'practice_bundling']
senticnet['sleep_long_time'] = [-0.121, 0, -0.083, -0.044, '#sad', '#scared', -0.083, 'trust_friend', 'fight_other', 'think_food', 'sense_fear', 'die_only_once']
senticnet['sleep_lot'] = [0.847, 0.871, 0, 0.903, '#interesting', '#admirable', 0.874, 'rejuvenation', 'recuperate', 'rest_dream', 'feel_refreshed', 'get_rest']
senticnet['sleep_master_bedroom'] = [0.263, 0, 0.047, 0.193, '#joyful', '#admirable', 0.136, 'know_everything', 'control_weather', 'dream_job', 'live_ocean', 'travel_fast_light']
senticnet['sleep_night'] = [0.06, -0.05, 0, 0, '#joyful', '#surprising', 0.037, 'go_sleep', 'want_sleep', 'sleep_sometimes', 'sleep', 'rest']
senticnet['sleep_on_couch'] = [0.03, 0, 0, 0.081, '#joyful', '#admirable', 0.037, 'comfy', 'occur', 'sleep_area', 'stay', 'temporary_home']
senticnet['sleep_pill'] = [-0.051, -0.013, 0.039, 0, '#sad', '#angry', -0.026, 'work_day', 'hard_day_at_work', 'tired', 'lose', 'gyroscope']
senticnet['sleep_place'] = [0.068, 0, 0.029, 0.103, '#joyful', '#admirable', 0.047, 'sleep_area', 'comfy', 'rest_place', 'horizontal_surface', 'sleep_furniture']
senticnet['sleep_sometimes'] = [0.173, -0.007, 0, 0.058, '#joyful', '#admirable', 0.079, 'go_sleep', 'sleep', 'sleep_night', 'want_sleep', 'weekend']
senticnet['sleep_soundly'] = [0.1, 0.111, -0.086, 0.142, '#interesting', '#admirable', 0.089, 'sleep_long_time', 'sense_fear', 'mark_territory', 'stay_in_house', 'follow_person']
senticnet['sleep_talking'] = [-0.531, 0, 0.762, -0.668, '#angry', '#disgusting', -0.654, 'defense', 'unconscious_process', 'somniloquy', 'somniloquism', 'condensation']
senticnet['sleep_tent'] = [0.095, 0.204, -0.123, 0.174, '#interesting', '#admirable', 0.117, 'go_outdoors', 'careful', 'keep_dry', 'pitch_tent', 'warm_up']
senticnet['sleep_through'] = [-0.106, -0.005, 0, -0.099, '#sad', '#disgusting', -0.067, 'drink_espresso', 'plan_retirement', 'trade_stock', 'think_future', 'sail_around_world']
senticnet['sleep_time'] = [0.1, 0.104, 0, 0, '#joyful', '#interesting', 0.068, 'closing_time', 'rest_night', 'rest_dream', 'shut_eye', 'inactivity']
senticnet['sleep_together'] = [0.718, -0.571, 0, 0.991, '#joyful', '#admirable', 0.76, 'have', 'pair', 'take', 'couple', 'fornicate']
senticnet['sleep_under'] = [0.049, 0, 0, 0.052, '#joyful', '#admirable', 0.034, 'bed_cover', 'bed', 'berth', 'cover_furniture', 'mattress']
senticnet['sleep_upon'] = [0.717, 0.92, 0, 0, '#joyful', '#interesting', 0.546, 'comfortable_place_sleep', 'place_sleep', 'shut_eye', 'laze', 'good_sleep']
senticnet['sleep_well'] = [0.849, 0, 0, 0, '#joyful', '#joyful', 0.283, 'get_rest', 'feel_little_tired', 'get_over_illness', 'get_sleep', 'lie_back']
senticnet['sleep_with'] = [0.872, -0.509, 0, 0.935, '#joyful', '#admirable', 0.772, 'have', 'pair', 'take', 'couple', 'fornicate']
senticnet['sleeper'] = [-0.583, 0, 0.714, -0.612, '#angry', '#disgusting', -0.636, 'waster', 'diversionist', 'destroyer', 'ruiner', 'undoer']
senticnet['sleeper_cell'] = [0.942, -0.797, 0, 0.561, '#joyful', '#surprising', 0.767, 'cadre', 'terrorist_cell', 'radical_cell', 'political_unit', 'political_entity']
senticnet['sleepiness'] = [0, 0, 0, -0.769, '#disgusting', '#disgusting', -0.256, 'stop_activity', 'sleepy', 'rest_up', 'need_to_rest', 'tired']
senticnet['sleeping'] = [0, 0, -0.905, 0, '#scared', '#scared', -0.302, 'comfortable_position', 'asleep', 'take_nap', 'lie_back', 'comfort']
senticnet['sleeping_pill'] = [-0.993, 0, -0.736, 0, '#sad', '#scared', -0.576, 'lower_stress', 'use_energy', 'good_fun', 'help_sleep', 'stay_physically_fit']
senticnet['sleeping_sickness'] = [-0.552, 0, 0.757, -0.528, '#sad', '#angry', -0.612, 'rubor', 'redness', 'cephalitis', 'sleepy_sickness', 'epidemic_encephalitis']
senticnet['sleepless_night'] = [-0.325, 0.072, -0.158, -0.17, '#sad', '#disgusting', -0.194, 'put_in_jail', 'injustice', 'go_jail', 'arrest', 'go_to_prison']
senticnet['sleepwalk'] = [-0.824, 0, -0.902, 0, '#sad', '#scared', -0.575, 'close_eye', 'cover_oneself_with_blanket', 'fall_out_bed', 'wear_pyjamas', 'count_sheep']
senticnet['sleepy'] = [-0.881, 0, 0, -0.85, '#sad', '#disgusting', -0.577, 'rest_up', 'need_to_rest', 'sleepiness', 'stop_activity', 'regain_energy']
senticnet['sleepy_sickness'] = [-0.552, 0, 0.757, -0.528, '#sad', '#angry', -0.612, 'rubor', 'redness', 'sleeping_sickness', 'cephalitis', 'epidemic_encephalitis']
senticnet['sleeveless'] = [-0.608, 0, 0.761, -0.849, '#angry', '#disgusting', -0.739, 'vain', 'bootless', 'fruitless', 'futile', 'unproductive']
senticnet['sleigh'] = [0, -0.037, 0.059, -0.053, '#angry', '#disgusting', -0.025, 'autumn', 'snow', 'put_warm_clothes', 'snow_fall', 'cold_weather']
senticnet['slew'] = [0, 0, 0.869, -0.745, '#angry', '#disgusting', -0.538, 'great_deal', 'flock', 'batch', 'slide', 'deal']
senticnet['slice'] = [-0.061, -0.027, 0.068, -0.09, '#angry', '#disgusting', -0.064, 'cut_up', 'sever', 'slash', 'cut', 'separation']
senticnet['slice_meat'] = [0.794, 0.933, 0, 0, '#joyful', '#interesting', 0.576, 'meat', 'toast', 'make_flour', 'bake_bread', 'bread']
senticnet['slickness'] = [-0.643, 0, 0.835, -0.509, '#sad', '#angry', -0.662, 'sleekness', 'smoothness', 'silkiness', 'powderiness', 'burnish']
senticnet['slide'] = [0.129, 0, 0, 0, '#joyful', '#joyful', 0.043, 'incline_plane', 'boulder', 'ramp', 'hill_mountain', 'rock']
senticnet['slideway'] = [-0.9, 0, 0.749, -0.719, '#sad', '#angry', -0.789, 'chute', 'slide', 'gutter', 'sloping_trough', 'cullis']
senticnet['sliding_scale'] = [0.687, -0.98, 0, 0.666, '#joyful', '#surprising', 0.778, 'scale', 'scale_of_measurement', 'graduated_table', 'ordered_series', 'wage_scale']
senticnet['slight'] = [-0.863, 0, 0.772, -0.734, '#sad', '#angry', -0.79, 'discourtesy', 'snub', 'cold_shoulder', 'offense', 'cut']
senticnet['slim'] = [0.191, 0.072, 0.068, 0.246, '#joyful', '#admirable', 0.147, 'fit_clothes', 'thin', 'live_healthy_life', 'strong_body', 'live_long_healthy_life']
senticnet['sliminess'] = [-0.97, 0, 0.536, -0.583, '#sad', '#disgusting', -0.696, 'lousiness', 'vileness', 'odiousness', 'unpleasantness', 'blatancy']
senticnet['slimy'] = [0, 0, -0.878, -0.88, '#scared', '#disgusting', -0.586, 'unworthy', 'despicable', 'ugly', 'slimed', 'vile']
senticnet['slinky'] = [0, -0.132, 0, 0, '#surprising', '#surprising', 0.044, 'toy_car', 'toy_soldier', 'action_figure', 'beanie_baby', 'toy_ball']
senticnet['slip_down'] = [-0.953, 0, 0.275, -0.968, '#sad', '#disgusting', -0.732, 'fall', 'fall_down', 'knee_injury', 'injury', 'painful']
senticnet['slip_fall'] = [-0.18, -0.035, -0.053, -0.101, '#sad', '#disgusting', -0.1, 'need_clean', 'fall_dead', 'absorb_moisture', 'hurt_back', 'hit_car']
senticnet['slip_off'] = [-0.988, 0, 0.674, -0.933, '#sad', '#disgusting', -0.865, 'fall_off', 'edge', 'slide', 'drop_down', 'fall_down']
senticnet['slipper'] = [0, -0.132, 0, 0, '#surprising', '#surprising', 0.044, 'shoe', 'moccasin', 'flip_flop', 'footwear', 'casual_shoes']
senticnet['slipper_orchid'] = [-0.923, 0, 0.619, -0.935, '#sad', '#disgusting', -0.826, 'moccasin_flower', 'nerveroot', 'showy_lady_slipper', 'yellow_lady_slipper', 'clustered_lady_slipper']
senticnet['slippered'] = [-0.591, 0, 0.553, -0.768, '#sad', '#disgusting', -0.637, 'booted', 'shod', 'roughshod', 'sandaled', 'wear_sandal']
senticnet['slippery'] = [-0.988, 0, 0.674, -0.933, '#sad', '#disgusting', -0.865, 'wet_floor', 'black_liquid', 'oily_road', 'slick', 'dangerous']
senticnet['slit'] = [-0.07, -0.035, 0.026, -0.151, '#sad', '#disgusting', -0.071, 'sever', 'open_wind', 'copy_paste', 'laceration', 'cause_bleed']
senticnet['slob'] = [-0.564, 0, 0.655, -0.859, '#angry', '#disgusting', -0.693, 'slovenly_woman', 'slut', 'trollop', 'slattern', 'litterer']
senticnet['slogan'] = [0.06, 0.181, -0.087, 0.231, '#interesting', '#admirable', 0.128, 'wealthy', 'alms', 'down_payment', 'advertisment', 'small_detail']
senticnet['sloping_trough'] = [-0.9, 0, 0.749, -0.719, '#sad', '#angry', -0.789, 'chute', 'slide', 'slideway', 'gutter', 'cullis']
senticnet['sloppiness'] = [-0.562, 0, 0.909, -0.626, '#angry', '#disgusting', -0.699, 'unkemptness', 'disorder', 'slovenliness', 'untidiness', 'disorderliness']
senticnet['slosh'] = [0, -0.048, 0.059, -0.086, '#angry', '#disgusting', -0.032, 'squirt', 'dirty_water', 'mud', 'puddle', 'sludge']
senticnet['slosh_around'] = [-0.879, 0, 0.682, -0.533, '#sad', '#angry', -0.698, 'swash', 'spatter', 'splatter', 'plash', 'splash']
senticnet['sloth'] = [-0.984, 0, 0.83, -0.604, '#sad', '#angry', -0.806, 'disinclination', 'indisposition', 'hesitancy', 'reluctance', 'hesitation']
senticnet['slothfulness'] = [-0.912, 0, 0.883, -0.634, '#sad', '#angry', -0.81, 'disinclination', 'indisposition', 'hesitancy', 'reluctance', 'hesitation']
senticnet['slouch'] = [-0.773, 0, 0.503, -0.932, '#sad', '#disgusting', -0.736, 'butcher', 'fuckup', 'incompetent', 'bungler', 'blunderer']
senticnet['slough'] = [-0.682, 0, 0.916, -0.912, '#angry', '#disgusting', -0.837, 'dry_gangrene', 'cold_gangrene', 'mumification_necrosis', 'mummification', 'pathology']
senticnet['sloven'] = [-0.632, 0, 0.683, -0.969, '#angry', '#disgusting', -0.761, 'slovenly_woman', 'slut', 'trollop', 'slattern', 'litterer']
senticnet['slovenliness'] = [-0.562, 0, 0.909, -0.626, '#angry', '#disgusting', -0.699, 'unkemptness', 'disorder', 'untidiness', 'sloppiness', 'disorderliness']
senticnet['slovenly_person'] = [-0.873, 0, 0.96, -0.97, '#angry', '#disgusting', -0.934, 'slovenly_woman', 'slut', 'trollop', 'slattern', 'litterer']
senticnet['slovenly_woman'] = [-0.564, 0, 0.655, -0.859, '#angry', '#disgusting', -0.693, 'slob', 'slut', 'trollop', 'slattern', 'litterer']
senticnet['slow'] = [-0.988, 0, 0.674, -0.933, '#sad', '#disgusting', -0.865, 'retarded', 'slow_pace', 'stupid', 'slow_car', 'slow_vehicle']
senticnet['slow_car'] = [-0.988, 0, 0.674, -0.933, '#sad', '#disgusting', -0.865, 'retarded', 'slow_pace', 'stupid', 'slow', 'slow_vehicle']
senticnet['slow_dance'] = [0.208, -0.114, 0, -0.035, '#joyful', '#surprising', 0.096, 'dance', 'old_dance', 'enter_contest', 'dancer', 'stout']
senticnet['slow_food'] = [0.06, -0.012, 0, 0, '#joyful', '#surprising', 0.024, 'eat_food', 'restaurant', 'meal', 'italian_cuisine', 'italian_restaurant']
senticnet['slow_heart_beat'] = [0.995, -0.879, 0, 0, '#joyful', '#surprising', 0.625, 'feel_refreshed', 'feel_little_tired', 'rejuvenation', 'feel_good', 'relax']
senticnet['slow_pace'] = [0.71, 0, 0, 0.852, '#joyful', '#admirable', 0.521, 'like_run', 'human_movement', 'use_foot', 'fast_walk', 'move_forward']
senticnet['slow_speed'] = [0.722, 0.865, 0, 0.748, '#interesting', '#admirable', 0.778, 'safety', 'traffic_light', 'avoid_crash', 'safety_belt', 'car']
senticnet['slow_traffic'] = [-0.066, -0.019, -0.108, 0, '#sad', '#scared', -0.052, 'storm_fortress', 'guard_bank', 'fight_war', 'fight_enemy', 'conquer_nation']
senticnet['slow_vehicle'] = [-0.988, 0, 0.674, -0.933, '#sad', '#disgusting', -0.865, 'retarded', 'slow_pace', 'stupid', 'slow_car', 'slow']
senticnet['slowness'] = [-0.602, 0, 0.827, -0.762, '#angry', '#disgusting', -0.73, 'amentia', 'mental_retardation', 'backwardness', 'subnormality', 'retardation']
senticnet['sludge'] = [0, -0.048, 0.059, -0.086, '#angry', '#disgusting', -0.032, 'squirt', 'dirty_water', 'mud', 'slosh', 'puddle']
senticnet['slug'] = [-0.023, -0.021, 0, -0.091, '#sad', '#disgusting', -0.031, 'piece_of_metal', 'gunpowder', 'ammunition', 'lethal', 'projectile']
senticnet['sluggishness'] = [-0.975, 0, 0.992, -0.866, '#sad', '#angry', -0.944, 'lassitude', 'hibernation', 'lethargy', 'torpidity', 'physical_condition']
senticnet['sluice'] = [-0.771, 0, 0.583, -0.609, '#sad', '#disgusting', -0.654, 'rain', 'rain_down', 'sheet', 'rain_bucket', 'rain_buckets_down']
senticnet['sluice_down'] = [-0.771, 0, 0.583, -0.609, '#sad', '#disgusting', -0.654, 'rain', 'rain_down', 'sheet', 'sluice', 'rain_bucket']
senticnet['slum'] = [-0.767, 0, 0, 0, '#sad', '#sad', -0.256, 'broken', 'home', 'homeless_shelter', 'crack_house', 'poor']
senticnet['slumber'] = [0.946, 0.9, 0, 0, '#joyful', '#interesting', 0.615, 'berth', 'sleep_under', 'use_bed', 'political_debate', 'bed']
senticnet['slump'] = [-0.996, 0, 0.691, -0.655, '#sad', '#angry', -0.781, 'depression', 'economic_crisis', 'exigency', 'crisis', 'juncture']
senticnet['slur_word'] = [-0.963, 0, 0, -0.959, '#sad', '#disgusting', -0.641, 'forgetfulness', 'run_out_booze', 'loss_ofawareness', 'bang_head', 'hangover']
senticnet['slush'] = [0.032, -0.039, 0, 0, '#joyful', '#surprising', 0.024, 'frozen_water', 'glacier', 'come_down', 'water_fall', 'water_drop']
senticnet['slush_around'] = [-0.541, 0, 0.583, -0.813, '#angry', '#disgusting', -0.646, 'swash', 'spatter', 'splatter', 'plash', 'splash']
senticnet['slushy'] = [0, 0, -0.843, -0.729, '#scared', '#disgusting', -0.524, 'drippy', 'maudlin', 'bathetic', 'hokey', 'mawkish']
senticnet['slut'] = [-0.544, 0, 0.691, -0.966, '#angry', '#disgusting', -0.734, 'adulterer', 'trollop', 'libertine', 'adulteress', 'fornicatress']
senticnet['slyboots'] = [-0.524, 0, 0.669, -0.662, '#angry', '#disgusting', -0.618, 'beguiler', 'slicker', 'deceiver', 'cheat', 'cheater']
senticnet['smack'] = [-0.7, 0, 0.698, -0.578, '#sad', '#angry', -0.659, 'diacetylmorphine', 'hell_dust', 'nose_drops', 'thunder', 'skag']
senticnet['small'] = [-0.05, 0, -0.12, -0.168, '#scared', '#disgusting', -0.113, 'reduced', 'tiny', 'small_size', 'narrow', 'poor']
senticnet['small_adult'] = [0, 0.074, -0.047, 0.054, '#interesting', '#admirable', 0.027, 'young_kid', 'human_offspring', 'young_people', 'small_boy', 'little_person']
senticnet['small_amount'] = [-0.99, 0, 0, -0.709, '#sad', '#disgusting', -0.566, 'least', 'little', 'a_little', 'shortage', 'scarce']
senticnet['small_animal'] = [0.959, 0, 0, 0.929, '#joyful', '#admirable', 0.629, 'small_cat', 'cute', 'pet', 'baby_cat', 'curious_animal']
senticnet['small_apartment'] = [0, -0.062, 0, 0.062, '#surprising', '#admirable', 0.041, 'box', 'small_box', 'owner_house', 'veterinarian_office', 'pet_shop']
senticnet['small_ball'] = [0.042, -0.02, 0.035, 0.065, '#joyful', '#admirable', 0.031, 'food_container', 'metal_cylinder', 'metal_container', 'cylinder', 'storage_container']
senticnet['small_bed'] = [0, -0.028, -0.083, -0.059, '#scared', '#disgusting', -0.038, 'mattress', 'sleep_furniture', 'master_bedroom', 'cradle', 'pillow']
senticnet['small_bite'] = [0.807, 0.763, 0, 0, '#joyful', '#interesting', 0.523, 'broken', 'little_bite', 'need_eat_meal', 'find_road', 'repair']
senticnet['small_boat'] = [0.766, 0.862, 0, 0, '#joyful', '#interesting', 0.543, 'jetty', 'water_vehicle', 'military_ship', 'ship', 'big_breadbox']
senticnet['small_book'] = [0, 0.103, 0, 0.057, '#interesting', '#admirable', 0.053, 'tale', 'narrative', 'print_material', 'journal', 'newspaper_story']
senticnet['small_boulder'] = [0, 0, 0.935, -0.808, '#angry', '#disgusting', -0.581, 'music_type', 'type_of_music', 'music_genre', 'valuable_gem', 'rock_music']
senticnet['small_box'] = [0, -0.062, 0, 0.062, '#surprising', '#admirable', 0.041, 'box', 'owner_house', 'small_apartment', 'veterinarian_office', 'pet_shop']
senticnet['small_boy'] = [0.033, 0, 0, 0.055, '#joyful', '#admirable', 0.029, 'young_kid', 'little_person', 'helpless', 'small_adult', 'small_kid']
senticnet['small_breast'] = [-0.934, 0, 0.846, 0, '#sad', '#angry', -0.593, 'swamp', 'boring', 'flat_tire', 'flat_foot', 'flatness']
senticnet['small_bug'] = [-0.043, -0.028, 0.108, -0.062, '#angry', '#disgusting', -0.062, 'small_insect', 'nuisance_insect', 'small_fly', 'fly_away', 'annoy_bug']
senticnet['small_building'] = [0, 0.108, 0, 0.175, '#interesting', '#admirable', 0.094, 'build_structure', 'city_area', 'architecture', 'building', 'manufacture_plant']
senticnet['small_cat'] = [0.959, 0, 0, 0.929, '#joyful', '#admirable', 0.629, 'baby_cat', 'little_animal', 'rodent', 'small_animal', 'feline']
senticnet['small_change'] = [0, 0.154, 0.076, 0.088, '#interesting', '#admirable', 0.055, 'dollar_change', 'money_change', 'currency_unit', 'small_coin', 'money_coin']
senticnet['small_child'] = [0, 0.154, 0.076, 0.088, '#interesting', '#admirable', 0.055, 'youth', 'young_child', 'childhood', 'kid', 'child']
senticnet['small_circle'] = [0, 0.788, 0, 0.892, '#interesting', '#admirable', 0.56, 'round_shape', 'make_gold', 'roundness', 'curve', 'round_flat']
senticnet['small_city'] = [0, 0, 0, 0.104, '#admirable', '#admirable', 0.035, 'downtown', 'city', 'village', 'govern', 'govern_city']
senticnet['small_coin'] = [0, 0.114, 0.073, 0.11, '#interesting', '#admirable', 0.05, 'money_coin', 'small_money', 'small_currency', 'american_coin', 'money_change']
senticnet['small_creature'] = [0.02, 0.071, 0, 0.069, '#interesting', '#admirable', 0.053, 'many_animals', 'little_animal', 'chihuahua', 'panda', 'cute_animal']
senticnet['small_currency'] = [0, 0.117, 0.072, 0.134, '#interesting', '#admirable', 0.06, 'small_money', 'metal_money', 'money_coin', 'small_coin', 'penny_dime']
senticnet['small_cut'] = [-0.087, 0, 0, -0.081, '#sad', '#disgusting', -0.056, 'blown', 'mistake', 'injury', 'bloody', 'gash']
senticnet['small_detail'] = [0.232, 0.178, -0.172, 0.223, '#joyful', '#admirable', 0.154, 'fame', 'alms', 'find_money', 'better_life', 'accolade']
senticnet['small_dog'] = [-0.06, 0, -0.046, 0, '#sad', '#scared', -0.035, 'dog', 'red-bellied_black_snake', 'eastern_brown_snake', 'wiener_dog', 'puma']
senticnet['small_dot'] = [0, 0.121, 0.085, 0.122, '#interesting', '#admirable', 0.053, 'sharp_end', 'geometric_object', 'sport_score', 'sharp_corner', 'reason_why']
senticnet['small_earth'] = [0.893, 0, 0, 0.807, '#joyful', '#admirable', 0.567, 'heavenly_body', 'celestial_body', 'around_earth', 'earth', 'hemisphere']
senticnet['small_elephant'] = [0.711, 0.792, 0, 0.93, '#interesting', '#admirable', 0.811, 'carnivore', 'house_animal', 'household_animal', 'large_cat', 'good_pet']
senticnet['small_fish'] = [0.053, 0.073, -0.065, 0.104, '#interesting', '#admirable', 0.055, 'coral', 'aquatic_life', 'horizon', 'ocean', 'waves']
senticnet['small_flower'] = [0, 0.109, 0, 0.109, '#interesting', '#admirable', 0.073, 'like_flower', 'garden_plant', 'plant_yard', 'use_decoration', 'use_salad']
senticnet['small_fly'] = [-0.038, -0.028, 0.138, -0.077, '#angry', '#disgusting', -0.075, 'small_bug', 'annoy_bug', 'parasite', 'fly_away', 'tiny_insect']
senticnet['small_fruit'] = [0.05, 0, 0.047, 0.068, '#joyful', '#admirable', 0.024, 'tree_fruit', 'yellow_fruit', 'delicious_fruit', 'vine_fruit', 'red_fruit']
senticnet['small_fry'] = [0.592, -0.931, 0, 0.935, '#surprising', '#admirable', 0.819, 'child', 'child_prodigy', 'tyke', 'tike', 'kid']
senticnet['small_furry'] = [0.046, 0.085, 0, 0.061, '#interesting', '#admirable', 0.064, 'high_animal', 'furry_creature', 'omnivore', 'small_rodent', 'dog']
senticnet['small_grain'] = [0, 0.065, 0.064, 0.079, '#interesting', '#admirable', 0.027, 'granular', 'white_grain', 'granule', 'food_type', 'staple_food']
senticnet['small_group'] = [0.028, 0.12, 0.068, 0.176, '#interesting', '#admirable', 0.085, 'elite', 'number_person', 'count_person', 'oligarchy', 'enumeration']
senticnet['small_home'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'family_home', 'residence', 'home_build', 'domicile', 'dwell_place']
senticnet['small_horse'] = [0, -0.114, 0.022, 0.06, '#surprising', '#admirable', 0.051, 'donkey', 'little_horse', 'male_cow', 'hoof_animal', 'pony']
senticnet['small_house'] = [-0.025, 0, -0.049, -0.031, '#scared', '#disgusting', -0.035, 'shack', 'small_room', 'mansion', 'art_gallery', 'motel_room']
senticnet['small_human'] = [0, 0.1, 0, 0.117, '#interesting', '#admirable', 0.072, 'cute', 'duh', 'diverse', 'small_person', 'tiny_animal']
senticnet['small_indefinite_amount'] = [-0.63, 0, 0.791, -0.681, '#angry', '#disgusting', -0.701, 'little', 'pinch', 'modicum', 'dreg', 'indefinite_quantity']
senticnet['small_indefinite_quantity'] = [-0.75, 0, 0.614, -0.617, '#sad', '#disgusting', -0.66, 'little', 'pinch', 'modicum', 'dreg', 'indefinite_quantity']
senticnet['small_insect'] = [-0.037, -0.029, 0.106, -0.053, '#angry', '#disgusting', -0.056, 'nuisance_insect', 'small_bug', 'tiny_insect', 'annoy_bug', 'fly_insect']
senticnet['small_kid'] = [0.025, 0.073, -0.052, 0.1, '#interesting', '#admirable', 0.049, 'little_person', 'boy_girl', 'small_boy', 'young_kid', 'young_people']
senticnet['small_lake'] = [-0.059, 0, 0.058, 0, '#sad', '#angry', -0.039, 'ocean', 'lake', 'aquarium', 'pacific_ocean', 'pond']
senticnet['small_light'] = [-0.074, 0, 0, -0.054, '#sad', '#disgusting', -0.043, 'cover_stone', 'find_garden', 'walk', 'cover_floor', 'meander']
senticnet['small_man'] = [0, 0.72, 0, 0.847, '#interesting', '#admirable', 0.522, 'masculine', 'gender', 'hold_child', 'female_person', 'male_person']
senticnet['small_money'] = [0, 0.112, 0.072, 0.132, '#interesting', '#admirable', 0.057, 'small_currency', 'money_coin', 'small_coin', 'metal_money', 'money_change']
senticnet['small_object'] = [0, 0.944, 0, 0.922, '#interesting', '#admirable', 0.622, 'microscopic', 'small_unit', 'basic_unit', 'tiny_organism', 'unit']
senticnet['small_ocean'] = [-0.065, 0.07, 0.03, 0.138, '#interesting', '#admirable', 0.038, 'along_beach', 'depth', 'deep', 'oceanside', 'full_water']
senticnet['small_part'] = [0, 0.908, 0, 0.989, '#interesting', '#admirable', 0.632, 'segment', 'component', 'part', 'portion', 'fraction']
senticnet['small_particle'] = [0, 0.081, 0.044, 0.106, '#interesting', '#admirable', 0.048, 'particle', 'tiny_particle', 'small_object', 'tiny', 'small']
senticnet['small_pebble'] = [-0.04, -0.037, 0.057, -0.041, '#angry', '#disgusting', -0.034, 'small_rock', 'small_stone', 'ground_material', 'precious_gem', 'gem_stone']
senticnet['small_person'] = [0, 0.1, 0, 0.117, '#interesting', '#admirable', 0.072, 'cute', 'small_human', 'diverse', 'duh', 'tiny_animal']
senticnet['small_piece'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'dust_particle', 'spangle', 'stripe', 'particle', 'oxide']
senticnet['small_place'] = [0, 0.101, 0.009, 0.124, '#interesting', '#admirable', 0.072, 'large_number', 'push_together', 'location', 'vicinity', 'big_place']
senticnet['small_river'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'river', 'fresh_water', 'small_stream', 'river_bank', 'water']
senticnet['small_rock'] = [0, 0, 0, -0.868, '#disgusting', '#disgusting', -0.289, 'fine_grain', 'grainy', 'small_stone', 'grit', 'powder']
senticnet['small_rodent'] = [-0.139, 0, 0.013, -0.081, '#sad', '#disgusting', -0.078, 'blind', 'dig_tunnel', 'underground_animal', 'big_mouse', 'bad_eyesight']
senticnet['small_room'] = [0, 0.123, 0.024, 0.135, '#interesting', '#admirable', 0.078, 'hold_place', 'microscopic', 'carry_around', 'tiny_organism', 'structural_support']
senticnet['small_round'] = [0.812, 0, 0, 0.821, '#joyful', '#admirable', 0.544, 'floppy', 'sugary', 'delicious', 'eatable', 'creamy']
senticnet['small_seat'] = [-0.971, 0, 0, -0.772, '#sad', '#disgusting', -0.581, 'sofa_bed', 'airline_seat', 'beanbag_chair', 'hide-a-bed_sofa', 'chair']
senticnet['small_shop'] = [0, 0.731, 0, 0.881, '#interesting', '#admirable', 0.537, 'hold_small_item', 'carry_goods', 'hold_flower', 'hold_item', 'hold_grocery']
senticnet['small_size'] = [-0.785, 0, 0.717, 0, '#sad', '#angry', -0.501, 'liquid_unit', 'small', 'mass_measure', 'small_amount', 'measure_unit']
senticnet['small_stone'] = [0, 0, 0.073, 0, '#angry', '#angry', -0.024, 'small_rock', 'ground_material', 'small_pebble', 'grainy', 'fine_grain']
senticnet['small_stream'] = [-0.869, 0, 0.951, 0, '#sad', '#angry', -0.607, 'water_passage', 'flowing_water', 'waterway', 'water_feature', 'water_area']
senticnet['small_street'] = [0, 0, 0.078, 0, '#angry', '#angry', -0.026, 'street_city', 'black_pavement', 'walkway', 'pave', 'dark_road']
senticnet['small_talk'] = [-0.515, 0, 0.545, -0.911, '#angry', '#disgusting', -0.657, 'gossip', 'chitchat', 'chit_chat', 'gab', 'chat']
senticnet['small_tree'] = [0.024, 0, 0.01, 0.08, '#joyful', '#admirable', 0.031, 'plant_part', 'large_plant', 'leafy', 'part_of_plant', 'foliage']
senticnet['small_unit'] = [0, 0.718, 0, 0.918, '#interesting', '#admirable', 0.545, 'microscopic', 'basic_unit', 'small_object', 'tiny_organism', 'unit']
senticnet['small_voice'] = [0.714, -0.583, 0, 0.667, '#joyful', '#admirable', 0.655, 'morality', 'wee_moral_sense', 'moral_sense', 'voice_of_conscience', 'sense_of_shame']
senticnet['smaller'] = [-0.719, 0, 0.992, 0, '#sad', '#angry', -0.57, 'numeral', 'list_number', 'lesser', 'measure_unit', 'two_halves']
senticnet['smallpox'] = [-0.079, 0, -0.225, -0.159, '#scared', '#disgusting', -0.154, 'gonorrhea', 'infectious_disease', 'psychoneurosis', 'sickness', 'polio']
senticnet['smart'] = [0.995, 0.801, 0, 0.968, '#joyful', '#admirable', 0.921, 'acquire_knowledge', 'comprehend', 'know_how', 'accumulate_knowledge', 'increase_knowledge']
senticnet['smart_aleck'] = [-0.955, 0, 0.772, -0.894, '#sad', '#disgusting', -0.874, 'upstart', 'wiseacre', 'snob', 'snooty', 'unpleasant_person']
senticnet['smart_animal'] = [0.029, 0, 0.018, 0.059, '#joyful', '#admirable', 0.023, 'domestic_animal', 'big_animal', 'hoof_mammal', 'large_mammal', 'cat']
senticnet['smart_creature'] = [0.024, 0.102, -0.068, 0.074, '#interesting', '#admirable', 0.044, 'monkey', 'large_mammal', 'pack_animal', 'mammal', 'marine_mammal']
senticnet['smart_dog'] = [0.039, 0, 0, 0.059, '#joyful', '#admirable', 0.033, 'big_dog', 'dog_cat', 'canine', 'pet', 'domesticated_animal']
senticnet['smart_man'] = [-0.883, 0, 0, 0, '#sad', '#sad', -0.294, 'moan', 'common_emotion', 'depress_person', 'child_cry', 'severe_pain']
senticnet['smart_person'] = [0, 0, 0, 0.913, '#admirable', '#admirable', 0.304, 'good_band', 'kit', 'wiseman', 'oblivion', 'high_school_band']
senticnet['smart_technology'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'cool_moment', 'electric_fan', 'relax', 'refreshing', 'wind']
senticnet['smartness'] = [0.995, 0.801, 0, 0.968, '#joyful', '#admirable', 0.921, 'smart', 'experience', 'wisdom', 'intelligent', 'intelligence']
senticnet['smash'] = [-0.06, -0.016, -0.117, 0, '#sad', '#scared', -0.054, 'raze', 'wreck', 'destroy', 'break', 'break_apart']
senticnet['smash_hit'] = [0.625, -0.905, 0, 0.54, '#joyful', '#surprising', 0.69, 'smash', 'bang', 'smasher', 'strike', 'hit']
senticnet['smasher'] = [0.796, -0.75, 0, 0.941, '#joyful', '#admirable', 0.829, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['smear'] = [0, 0.101, 0.039, 0.054, '#interesting', '#admirable', 0.039, 'wipe_tear', 'press_enter', 'smudge', 'push_button', 'scratch_back']
senticnet['smell'] = [0.944, 0, 0, 0.978, '#joyful', '#admirable', 0.641, 'fragrance', 'scent', 'aroma', 'smell_flower', 'smell_good']
senticnet['smell_bad'] = [-0.755, 0.154, -0.643, 0.142, '#sad', '#scared', -0.367, 'evil', 'awful', 'bad_person', 'bad', 'harmful_human']
senticnet['smell_better'] = [0.085, 0, 0, 0.069, '#joyful', '#admirable', 0.051, 'ensure_proper_hygiene', 'smell_nice', 'remove_stain', 'feel_clean', 'smell_good']
senticnet['smell_clean'] = [0, 0, 0.943, -0.8, '#angry', '#disgusting', -0.581, 'fight_fire', 'soapy', 'feel_dirty', 'dirty', 'filthy']
senticnet['smell_flower'] = [0.829, 0, 0, 0, '#joyful', '#joyful', 0.276, 'thank_parent', 'travel_space', 'eat_potato', 'crowd_elevator', 'check_mail']
senticnet['smell_food'] = [-0.042, 0, 0, -0.066, '#sad', '#disgusting', -0.036, 'eat_salad', 'masticate', 'enjoy_food', 'sell_vegetable', 'drink_wine']
senticnet['smell_good'] = [0.081, 0, 0, 0.086, '#joyful', '#admirable', 0.056, 'smell_nice', 'feel_clean', 'sexy', 'smell_better', 'smell_clean']
senticnet['smell_good_food'] = [0.087, -0.061, 0, 0, '#joyful', '#surprising', 0.049, 'pumpkin_pie', 'ice_cream', 'chocolate_dessert', 'delicious', 'chewy']
senticnet['smell_like_fish'] = [0, 0, 0, -0.87, '#disgusting', '#disgusting', -0.29, 'smelly_foot', 'bad_hair_day', 'unattractive', 'suffer_fool', 'brain_tumor']
senticnet['smell_nice'] = [0.118, 0, 0, 0.099, '#joyful', '#admirable', 0.072, 'feel_clean', 'smell_clean', 'smell_good', 'smell_better', 'feel_fresh']
senticnet['smell_odor'] = [-0.088, 0, -0.084, 0, '#sad', '#scared', -0.057, 'age_well', 'feel_heat', 'crowd_elevator', 'close_together', 'remove_splinter']
senticnet['smell_smoke'] = [-0.101, 0, 0, -0.072, '#sad', '#disgusting', -0.058, 'explain_everything', 'deal_card_player', 'visit_grandmother', 'stand_alone', 'storm_out_room']
senticnet['smell_up'] = [-0.674, 0, 0.503, -0.67, '#sad', '#disgusting', -0.616, 'stink_up', 'odorize', 'stink_out', 'incense', 'perfume']
senticnet['smelly_foot'] = [0, 0, 0, -0.87, '#disgusting', '#disgusting', -0.29, 'chicken_pox', 'lose_team', 'cause_suffer', 'disrespect', 'leave_out']
senticnet['smelt'] = [0, 0, -0.951, -0.891, '#scared', '#disgusting', -0.614, 'smell', 'reek', 'smack', 'smell_out', 'sense']
senticnet['smile'] = [0.997, 0, 0, 0, '#joyful', '#joyful', 0.332, 'sneer', 'start_laugh', 'hear_joke', 'smile_laugh', 'giggle']
senticnet['smile_child'] = [0, 0.089, 0.023, 0.053, '#interesting', '#admirable', 0.04, 'pass_gene', 'child', 'young_child', 'overpopulation', 'great_performance']
senticnet['smile_laugh'] = [0.759, 0, 0, 0, '#joyful', '#joyful', 0.253, 'start_laugh', 'sense_of_humor', 'giggle', 'smile', 'hear_joke']
senticnet['smirch'] = [-0.879, 0, 0.994, -0.853, '#sad', '#angry', -0.909, 'fingermark', 'blemish', 'mar', 'defect', 'blotch']
senticnet['smirk'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'simper', 'please', 'content', 'satisfy', 'gratify']
senticnet['smithsonian'] = [0, 0, -0.056, -0.037, '#scared', '#disgusting', -0.031, 'loose_end', 'another_planet', 'death_row', 'auction', 'car_race']
senticnet['smithsonian_institution'] = [0, 0.087, -0.07, 0.1, '#interesting', '#admirable', 0.039, 'institution', 'tundra', 'children_story', 'natural_history_museum', 'cartoon']
senticnet['smog'] = [0, 0, -0.073, 0, '#scared', '#scared', -0.024, 'vapor', 'gaseous', 'haze', 'smoke', 'bad_habit']
senticnet['smoke'] = [-0.766, 0, 0, -0.95, '#sad', '#disgusting', -0.572, 'addiction', 'drug', 'embarrassment', 'cigarette', 'disappointment']
senticnet['smoke_alarm'] = [0, 0.101, -0.05, 0.059, '#interesting', '#admirable', 0.037, 'make_toy', 'frame_picture', 'equity', 'buy_paint_brush', 'buy_paint']
senticnet['smoke_bowl'] = [-0.926, 0, 0, -0.792, '#sad', '#disgusting', -0.573, 'like', 'laugh_lot', 'change_mood', 'deafness', 'serve_guest']
senticnet['smoke_cigar'] = [-0.106, 0, -0.054, -0.031, '#sad', '#scared', -0.064, 'deal_card', 'bicycle_across_town', 'mine_diamond', 'wind_watch', 'kill_specific_group']
senticnet['smoke_cigarette'] = [0, -0.003, -0.058, -0.128, '#scared', '#disgusting', -0.061, 'age_prematurely', 'cause_mental_illness', 'smoke_pipe', 'light_cigar', 'light_pipe']
senticnet['smoke_joint'] = [0.714, 0.748, 0, 0, '#joyful', '#interesting', 0.487, 'shovel_snow', 'fly_around', 'blow_away', 'mine_gold', 'explain_everything']
senticnet['smoke_marijuana'] = [0, 0.931, 0, 0, '#interesting', '#interesting', 0.31, 'football', 'rake_leave', 'spray_paint_grafitti', 'juggle', 'play_hide_seek']
senticnet['smoke_pipe'] = [0.031, 0, -0.081, -0.088, '#scared', '#disgusting', -0.046, 'smoke_cigarette', 'smoke', 'cinder', 'tobacco_product', 'smoke_tobacco']
senticnet['smoke_pot'] = [0.992, 0.728, 0, 0.834, '#joyful', '#admirable', 0.851, 'win_contest', 'laugh_lot', 'experience_pleasure', 'go_date', 'enjoy_performance']
senticnet['smoke_tobacco'] = [-0.904, 0, 0.713, -0.975, '#sad', '#disgusting', -0.864, 'smoke', 'cigarette', 'tobacco', 'cigar', 'lung_cancer']
senticnet['smoke_wee'] = [0.979, 0.824, 0, 0, '#joyful', '#interesting', 0.601, 'miss_work', 'take_break', 'lie_on_bed', 'watch_tv', 'sleep_upon']
senticnet['smooth'] = [0.337, 0.37, -0.159, 0.256, '#joyful', '#interesting', 0.268, 'type_of_material', 'material_type', 'soft_cloth', 'soft', 'soft_fabric']
senticnet['smooth_out'] = [0.939, -0.501, 0, 0.733, '#joyful', '#admirable', 0.724, 'disembarrass', 'clear', 'relieve', 'smooth', 'disembody']
senticnet['smooth_skin'] = [0.352, 0.142, 0, 0.281, '#joyful', '#admirable', 0.258, 'knowledgeable', 'complement', 'much_need', 'see_ocean', 'good_sense_of_humor']
senticnet['smooth_surface'] = [0.039, 0.099, 0, 0.164, '#interesting', '#admirable', 0.101, 'magnetic', 'heavy_element', 'tin', 'dense_air', 'weigh_much']
senticnet['smooth_wood'] = [0.082, -0.006, 0, 0, '#joyful', '#surprising', 0.029, 'empty_place', 'free_seat', 'farm', 'few_people', 'serf']
senticnet['smoothie'] = [0.078, 0, 0, 0, '#joyful', '#joyful', 0.026, 'glass_water', 'whisky', 'cold_water', 'lemonade', 'coke']
senticnet['smoothness'] = [-0.643, 0, 0.835, -0.509, '#sad', '#angry', -0.662, 'sleekness', 'slickness', 'silkiness', 'powderiness', 'burnish']
senticnet['smoothy'] = [0.666, -0.709, 0, 0.666, '#joyful', '#surprising', 0.68, 'pretender', 'phony', 'phoney', 'hypocrite', 'dissembler']
senticnet['smorgasbord'] = [0, 0.839, 0, 0.912, '#interesting', '#admirable', 0.584, 'miscellany', 'assortment', 'mixture', 'miscellanea', 'mixed_bag']
senticnet['smother'] = [0, 0, 0.766, 0, '#angry', '#angry', -0.255, 'cover_face', 'slay', 'berth', 'bed', 'seduce']
senticnet['smothering'] = [-0.786, 0, 0.543, -0.565, '#sad', '#disgusting', -0.631, 'dyspneic', 'dyspnoeic', 'dyspneal', 'dyspnoeal', 'breathless']
senticnet['smug'] = [-0.872, 0, 0, -0.915, '#sad', '#disgusting', -0.596, 'smugness', 'proudly', 'self_satisfied', 'preen', 'complacence']
senticnet['smuggler'] = [-0.877, 0, 0.574, -0.736, '#sad', '#disgusting', -0.729, 'criminal', 'outlaw', 'malefactor', 'felon', 'crook']
senticnet['smugness'] = [0.803, 0.585, -0.202, 0.347, '#joyful', '#interesting', 0.511, 'smug', 'proudly', 'self-satisfied', 'preen', 'complacence']
senticnet['smut'] = [-0.806, 0, 0.899, -0.524, '#sad', '#angry', -0.743, 'filth', 'profanity', 'expletive', 'curse_word', 'swearword']
senticnet['smut_fungus'] = [-0.935, 0, 0.699, -0.91, '#sad', '#disgusting', -0.848, 'onion_smut', 'head_smut', 'stinking_smut', 'flag_smut_fungus', 'covered_smut']
senticnet['snack'] = [0.986, 0.943, 0, 0, '#joyful', '#interesting', 0.643, 'need_food', 'a_little_hungry', 'dead_hungry', 'prepare_food', 'fill_stomach']
senticnet['snack_bar'] = [0.789, 0.814, 0, 0, '#joyful', '#interesting', 0.534, 'expensive', 'first_class_airplane_seat', 'airplane_seat', 'sofa_bed', 'spend_money']
senticnet['snail'] = [-0.059, -0.045, 0.037, -0.084, '#sad', '#disgusting', -0.045, 'slow', 'spider', 'slug', 'bug', 'ant']
senticnet['snail_mail'] = [0, 0, 0, 0.159, '#admirable', '#admirable', 0.053, 'send_mail', 'postage', 'message', 'unit_language', 'correspondence']
senticnet['snake'] = [-0.687, 0, 0.611, -0.597, '#sad', '#angry', -0.632, 'viper', 'elapid', 'elapid_snake', 'worm_snake', 'blind_snake']
senticnet['snake_belly'] = [0, 0, 0.933, -0.866, '#angry', '#disgusting', -0.6, 'mess', 'trap', 'dirty_kitchen', 'dirty_house', 'cornfield']
senticnet['snake_pit'] = [-0.753, 0, 0.547, -0.577, '#sad', '#disgusting', -0.626, 'insane_asylum', 'booby_hatch', 'crazy_house', 'cuckoo_nest', 'funny_farm']
senticnet['snap'] = [-0.576, 0, 0.852, -0.745, '#angry', '#disgusting', -0.724, 'tease', 'bust', 'tear', 'rupture', 'rip_up']
senticnet['snappishness'] = [-0.598, 0, 0.911, -0.831, '#angry', '#disgusting', -0.78, 'biliousness', 'peevishness', 'pettishness', 'querulousness', 'surliness']
senticnet['snappy'] = [0, -0.858, 0, 0.876, '#surprising', '#admirable', 0.578, 'nipping', 'whipping', 'snappish', 'crisp', 'frosty']
senticnet['snarl'] = [-0.605, 0, 0.631, -0.681, '#angry', '#disgusting', -0.639, 'quandary', 'perplexity', 'dilemma', 'confusion', 'secret']
senticnet['snarling'] = [0, 0, -0.979, -0.728, '#scared', '#disgusting', -0.569, 'entangle', 'tangle', 'snarl_up', 'snap', 'mat']
senticnet['snatch'] = [-0.753, 0, 0.794, -0.585, '#sad', '#angry', -0.711, 'jerk', 'weightlift', 'military_press', 'clean', 'bench_press']
senticnet['snatch_up'] = [0.981, -0.727, 0, 0.638, '#joyful', '#surprising', 0.782, 'swoop', 'swoop_up', 'seize', 'prehend', 'clutch']
senticnet['sneak'] = [0, 0.949, 0, 0.707, '#interesting', '#admirable', 0.552, 'sneak_out', 'thoughtfulness', 'consider', 'brain_function', 'thief']
senticnet['sneak_out'] = [0.921, 0.785, 0, 0, '#joyful', '#interesting', 0.569, 'sneak', 'thoughtfulness', 'consider', 'brain_function', 'thief']
senticnet['sneaker'] = [0.859, 0.702, 0, 0, '#joyful', '#interesting', 0.52, 'shoe', 'slipper', 'moccasin', 'flip_flop', 'footwear']
senticnet['sneaky'] = [0, 0, 0, -0.923, '#disgusting', '#disgusting', -0.308, 'know_like', 'make_selection', 'moolah', 'go_to_shopping_mall', 'go_department_store']
senticnet['sneer'] = [0.033, 0, 0.04, -0.227, '#angry', '#disgusting', -0.078, 'smile', 'start_laugh', 'make_others_laugh', 'hear_joke', 'make_fun']
senticnet['sneeze'] = [0, 0.761, 0, 0.986, '#interesting', '#admirable', 0.582, 'allergy', 'groan', 'runny_nose', 'sign_sickness', 'loud_cry']
senticnet['sneezeweed'] = [-0.767, 0, 0.76, -0.669, '#sad', '#angry', -0.732, 'herb', 'autumn_sneezeweed', 'orange_sneezeweed', 'owlclaws', 'rosilla']
senticnet['snit'] = [-0.85, 0, 0.564, -0.924, '#sad', '#disgusting', -0.779, 'miff', 'impatience', 'botheration', 'bummer', 'pinprick']
senticnet['snitch'] = [-0.672, 0, 0.546, -0.633, '#sad', '#disgusting', -0.617, 'fink', 'betrayer', 'betrayerer', 'sneak', 'stoolpigeon']
senticnet['snitcher'] = [-0.672, 0, 0.546, -0.633, '#sad', '#disgusting', -0.617, 'fink', 'snitch', 'betrayer', 'sneak', 'stoolpigeon']
senticnet['sniveling'] = [0, 0, -0.957, -0.828, '#scared', '#disgusting', -0.595, 'whine', 'blubber', 'sniffle', 'snuffle', 'blub']
senticnet['sniveller'] = [-0.747, 0, 0.68, -0.586, '#sad', '#angry', -0.671, 'whiner', 'complainer', 'moaner', 'kvetch', 'crybaby']
senticnet['snob'] = [-0.026, 0, 0, -0.067, '#sad', '#disgusting', -0.031, 'french_person', 'snooty', 'full_of_oneself', 'full_of_shit', 'french']
senticnet['snobbery'] = [-0.948, 0, 0.687, -0.75, '#sad', '#disgusting', -0.795, 'clannishness', 'cliquishness', 'exclusiveness', 'arrogance', 'haughtiness']
senticnet['snobbishness'] = [-0.779, 0, 0.532, -0.911, '#sad', '#disgusting', -0.741, 'clannishness', 'cliquishness', 'exclusiveness', 'arrogance', 'haughtiness']
senticnet['snobbism'] = [-0.888, 0, 0.666, -0.639, '#sad', '#angry', -0.731, 'clannishness', 'cliquishness', 'exclusiveness', 'arrogance', 'haughtiness']
senticnet['snobby'] = [-0.026, 0, 0, -0.067, '#sad', '#disgusting', -0.031, 'snooty', 'look_down_on', 'snob', 'french', 'full_of_shit']
senticnet['snooker'] = [-0.66, 0, 0.771, -0.954, '#angry', '#disgusting', -0.795, 'delude', 'deceive', 'cozen', 'play_trick_on', 'lead_on']
senticnet['snoopiness'] = [-0.909, 0, 0.865, -0.772, '#sad', '#angry', -0.849, 'nosiness', 'curiousness', 'prying', 'curiosity', 'wonder']
senticnet['snooty'] = [-0.026, 0, 0, -0.067, '#sad', '#disgusting', -0.031, 'snobby', 'look_down_on', 'snob', 'french', 'full_of_shit']
senticnet['snore'] = [-0.159, -0.06, 0, -0.081, '#sad', '#disgusting', -0.06, 'prevent_cavity', 'miss_appointment', 'go_dentist', 'jump_off_bridge', 'unplug']
senticnet['snorkel'] = [0, -0.008, 0.018, -0.069, '#angry', '#disgusting', -0.026, 'ship_package', 'sharpen_knife', 'swim_lake', 'snow_ski', 'pick_team']
senticnet['snow'] = [0.936, 0.998, 0, 0, '#joyful', '#interesting', 0.645, 'cold_weather', 'arctic', 'ice', 'cold', 'without_human_habitation']
senticnet['snow_board'] = [0.107, 0.098, 0, 0.135, '#joyful', '#admirable', 0.113, 'snow_ski', 'go_moon', 'sleep_late', 'lean_against', 'swim_ocean']
senticnet['snow_fall'] = [0, -0.031, -0.105, -0.073, '#scared', '#disgusting', -0.049, 'autumn', 'winter', 'skier', 'avalanche', 'volcano']
senticnet['snow_hill'] = [0, 0.087, 0.022, 0.142, '#interesting', '#admirable', 0.069, 'high_land', 'cover_snow', 'landscape_feature', 'tall', 'beautiful_look']
senticnet['snow_ski'] = [0.107, 0.098, 0, 0.135, '#joyful', '#admirable', 0.113, 'snow_board', 'go_moon', 'sleep_late', 'lean_against', 'swim_ocean']
senticnet['snow_storm'] = [-0.176, -0.073, 0, -0.159, '#sad', '#disgusting', -0.087, 'cold_hot', 'rain_snow', 'rainy', 'natural_phenomenon', 'weather_type']
senticnet['snowball'] = [0.107, 0.098, 0, 0.135, '#joyful', '#admirable', 0.113, 'snow', 'ball', 'ski', 'snowboard', 'have_fun']
senticnet['snowed_in'] = [0.786, 0.888, 0, 0, '#joyful', '#interesting', 0.558, 'work_pile_up', 'miss_work', 'restless', 'feel_little_tired', 'take_nap']
senticnet['snowflake'] = [0.831, 0.893, 0, 0, '#joyful', '#interesting', 0.575, 'tumble', 'dew', 'hailstone', 'rain', 'drop']
senticnet['snub'] = [-0.267, -0.022, 0, -0.202, '#sad', '#disgusting', -0.149, 'car_wreck', 'broken_finger', 'fall_head', 'ignore', 'bad_luck']
senticnet['snuggle'] = [0.808, 0, 0, 0, '#joyful', '#joyful', 0.269, 'fall_asleep', 'relax_mind', 'cover_oneself_with_blanket', 'make_out', 'bed_time']
senticnet['soak'] = [-0.809, 0, 0.962, -0.553, '#sad', '#angry', -0.775, 'sop', 'douse', 'dowse', 'drench', 'bedraggle']
senticnet['soak_hot_tub'] = [-0.093, -0.026, 0.048, -0.155, '#sad', '#disgusting', -0.09, 'take_dump', 'go_potty', 'go_pee', 'use_toilet', 'wash_up']
senticnet['soak_hotspring'] = [-0.035, 0, -0.087, 0, '#sad', '#scared', -0.041, 'urinate', 'pee', 'know_re_healthy', 'empty_bladder', 'get_front_line']
senticnet['soap_bubble'] = [-0.559, 0, 0.869, -0.838, '#angry', '#disgusting', -0.755, 'air_bubble', 'foam', 'froth', 'bubble', 'globule']
senticnet['soap_up'] = [-0.074, 0, 0.026, 0, '#sad', '#angry', -0.033, 'dispense_water', 'turn_water', 'fill_bathtub', 'run_bath', 'launder']
senticnet['soap_water'] = [0, 0.069, 0.023, 0.052, '#interesting', '#admirable', 0.033, 'soapy_water', 'wash_self', 'shower_gel', 'soap_up', 'turn_water']
senticnet['soapy_water'] = [0, 0.069, 0.023, 0.052, '#interesting', '#admirable', 0.033, 'shower_gel', 'wash_self', 'soap_water', 'soap_up', 'turn_water']
senticnet['soar'] = [-0.028, -0.046, 0.055, -0.075, '#angry', '#disgusting', -0.037, 'aviation', 'wing_insect', 'bird', 'wing', 'flap_wing']
senticnet['sob'] = [-0.961, 0, 0, 0, '#sad', '#sad', -0.32, 'weep', 'bawl', 'shed_tear', 'cry_hard', 'wail']
senticnet['sober'] = [-0.172, 0, -0.056, -0.075, '#sad', '#disgusting', -0.101, 'get_done', 'work_hard', 'finish_task', 'get_work_done', 'study_animal']
senticnet['soberness'] = [-0.573, 0, 0.841, -0.508, '#sad', '#angry', -0.641, 'somberness', 'sombreness', 'gravity', 'stodginess', 'graveness']
senticnet['soccer_field'] = [0.048, 0.077, 0, -0.031, '#joyful', '#interesting', 0.031, 'baseball_diamond', 'outhouse', 'memorial', 'baseball_field', 'city_park']
senticnet['soccer_game'] = [0, -0.003, -0.062, -0.089, '#scared', '#disgusting', -0.049, 'sport_event', 'toy_box', 'hockey_game', 'stadium', 'disneyland']
senticnet['sociability'] = [-0.648, 0, 0.574, -0.89, '#sad', '#disgusting', -0.704, 'gregariousness', 'ambiversion', 'openness', 'nakedness', 'extraversion']
senticnet['sociable'] = [0.935, 0, 0, 0.829, '#joyful', '#admirable', 0.588, 'feel_content', 'make_feel_better', 'celebrate_special_occasion', 'survival', 'express_appreciation']
senticnet['sociableness'] = [-0.878, 0, 0.505, -0.849, '#sad', '#disgusting', -0.744, 'gregariousness', 'ambiversion', 'openness', 'nakedness', 'extraversion']
senticnet['social'] = [0.15, -0.07, -0.055, 0, '#joyful', '#surprising', 0.055, 'friendship', 'share_experience', 'network', 'get_together', 'relay_information']
senticnet['social_acceptance'] = [0.052, 0, -0.048, 0.07, '#joyful', '#admirable', 0.025, 'smell_better', 'ensure_proper_hygiene', 'prevent_disease', 'smell_good', 'look_presentable']
senticnet['social_activity'] = [0.161, -0.092, 0, 0.073, '#joyful', '#surprising', 0.109, 'social_event', 'athletic', 'fun_exercise', 'recreational', 'healthful']
senticnet['social_affair'] = [0.544, -0.677, 0, 0.653, '#surprising', '#admirable', 0.625, 'get_together', 'bee', 'love_feast', 'company', 'function']
senticnet['social_animal'] = [0.932, 0.931, 0, 0.78, '#joyful', '#interesting', 0.881, 'good_friend', 'feel_comfort', 'fun_around', 'good_pet', 'social_creature']
senticnet['social_bond'] = [0.166, -0.052, 0.044, -0.046, '#joyful', '#surprising', 0.043, 'impress_girl', 'relieve_stress', 'enjoy_outdoors', 'attract_mate', 'become_popular']
senticnet['social_class'] = [0.036, 0.129, 0, 0.068, '#interesting', '#admirable', 0.078, 'status', 'military_order', 'army_position', 'rank', 'general']
senticnet['social_climber'] = [-0.745, 0, 0.786, -0.967, '#angry', '#disgusting', -0.833, 'junior', 'unpleasant_person', 'disagreeable_person', 'climber', 'arriviste']
senticnet['social_club'] = [0.967, -0.982, 0, 0.64, '#joyful', '#surprising', 0.863, 'club', 'jockey_club', 'society', 'guild', 'gild']
senticnet['social_connection'] = [-0.066, 0.291, -0.113, 0.194, '#interesting', '#admirable', 0.102, 'communicate_idea', 'communicate_with_others', 'communicate_family', 'social_life', 'exchange_information']
senticnet['social_convention'] = [0, 0.827, 0, 0.955, '#interesting', '#admirable', 0.594, 'enter_place', 'stand', 'cover_floor', 'meander', 'progress']
senticnet['social_creature'] = [0.047, 0.087, 0, 0.08, '#interesting', '#admirable', 0.071, 'social_animal', 'smart_animal', 'omnivore', 'live_animal', 'large_mouse']
senticnet['social_disease'] = [-0.611, 0, 0.899, -0.622, '#angry', '#disgusting', -0.711, 'venereal_disease', 'venereal_infection', 'dose', 'sexually_transmitted_disease', 'gonorrhoea']
senticnet['social_drink'] = [0.974, 0.811, 0, 0, '#joyful', '#interesting', 0.595, 'social_gathering', 'meet_up', 'gala', 'gathering', 'happy_time']
senticnet['social_event'] = [0.158, -0.108, 0.018, -0.057, '#joyful', '#surprising', 0.064, 'get_together', 'radical', 'enjoyable', 'social_activity', 'amusement']
senticnet['social_exclusion'] = [-0.25, 0, -0.174, -0.082, '#sad', '#scared', -0.169, 'exclusion', 'exclusion_zone', 'isolation', 'unless', 'except']
senticnet['social_gathering'] = [0.663, -0.843, 0, 0.8, '#surprising', '#admirable', 0.769, 'get_together', 'fun_time', 'social_drink', 'meet_up', 'gala']
senticnet['social_group'] = [0.124, 0.101, -0.047, 0.135, '#joyful', '#admirable', 0.104, 'team_up', 'group_of_people', 'organize_group', 'member', 'group']
senticnet['social_insect'] = [0, -0.032, 0.072, -0.062, '#angry', '#disgusting', -0.034, 'vermin', 'arthropod', 'fly_insect', 'type_of_animal', 'small_animal']
senticnet['social_insurance'] = [0.753, -0.621, 0, 0.959, '#joyful', '#admirable', 0.778, 'assistance', 'relief', 'economic_aid', 'financial_aid', 'public_assistance']
senticnet['social_interaction'] = [0.735, 0, 0, 0.783, '#joyful', '#admirable', 0.506, 'get_hammered', 'get_drunk', 'meet_member_opposite_sex', 'good_time', 'get_to_know_person']
senticnet['social_life'] = [0.82, 0.997, 0, 0.973, '#interesting', '#admirable', 0.93, 'exchange_information', 'relay_information', 'exchange_idea', 'give_information', 'keep_in_touch']
senticnet['social_occasion'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'celebrate_holiday', 'express_appreciation', 'celebrate_special_occasion', 'joke_around', 'get_sex']
senticnet['social_rank'] = [0, 0.906, 0, 0.719, '#interesting', '#admirable', 0.542, 'royal_title', 'royal_person', 'earl', 'duke', 'noble']
senticnet['social_reformer'] = [-0.736, 0, 0.778, -0.717, '#sad', '#angry', -0.744, 'dry', 'insurgent', 'militant', 'passive_resister', 'demonstrator']
senticnet['social_skill'] = [0.149, 0.09, 0, 0.158, '#joyful', '#admirable', 0.132, 'go_abroad', 'invite', 'visit', 'go_club', 'outgo_personality']
senticnet['social_status'] = [0.044, 0.124, -0.07, 0.124, '#interesting', '#admirable', 0.074, 'designation', 'caste', 'status', 'well_known', 'distinction']
senticnet['social_welfare'] = [0.812, -0.912, 0, 0.647, '#joyful', '#surprising', 0.79, 'assistance', 'relief', 'economic_aid', 'financial_aid', 'social_insurance']
senticnet['socialism'] = [0.032, 0.255, -0.086, 0.168, '#interesting', '#admirable', 0.123, 'parliament', 'feudalism', 'empire', 'democracy', 'political']
senticnet['socialist'] = [0.707, 0.773, 0, 0, '#joyful', '#interesting', 0.493, 'kill', 'make_someone_sick', 'result_death', 'murder_another_person', 'kill_pest']
senticnet['socialization'] = [0.96, 0.548, 0, 0.684, '#joyful', '#admirable', 0.731, 'nothing_better', 'relay_information', 'get_together_friend', 'entertainment_education', 'spread_knowledge']
senticnet['socialize_with_friend'] = [0.96, 0.548, 0, 0.684, '#joyful', '#admirable', 0.731, 'friend', 'socialize', 'spend_time_with_friend', 'chit_chat', 'meet_new_person']
senticnet['society'] = [0.092, 0.112, -0.087, 0.052, '#joyful', '#interesting', 0.056, 'egalitarian_society', 'urban', 'group_of_people', 'colony', 'social_group']
senticnet['sociopathic'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'antisocial', 'attitude', 'disorder', 'weird_behavior', 'unfriendly']
senticnet['sock'] = [0.805, 0.746, 0, 0, '#joyful', '#interesting', 0.517, 'foot', 'footwear', 'leg_wear', 'shoe', 'man_clothes']
senticnet['sock_drawer'] = [-0.028, 0, 0, -0.047, '#sad', '#disgusting', -0.025, 'woman_purse', 'suitcase', 'pocket', 'back_sofa', 'pant_pocket']
senticnet['socket'] = [0.681, -0.632, 0, 0.647, '#joyful', '#admirable', 0.653, 'hip_socket', 'tooth_socket', 'alveolus', 'acetabulum', 'cotyloid_cavity']
senticnet['sod'] = [-0.131, 0, 0, -0.071, '#sad', '#disgusting', -0.067, 'grass', 'butter_bread', 'fill_bottle', 'scrub_floor', 'sward']
senticnet['soda'] = [0.078, 0, 0, 0, '#joyful', '#joyful', 0.026, 'coke', 'sprite', 'cola', 'beverage', 'soft_drink']
senticnet['soda_cracker'] = [-0.955, 0, 0.762, -0.648, '#sad', '#angry', -0.788, 'saltine', 'cracker', 'oyster_cracker', 'water_biscuit', 'graham_cracker']
senticnet['soda_machine'] = [0, 0, 0, -0.069, '#disgusting', '#disgusting', -0.023, 'newsstand', 'bookshop', 'walmart', 'shoe_store', 'hooker']
senticnet['sodomy'] = [-0.848, 0, 0.882, -0.829, '#sad', '#angry', -0.853, 'perversion', 'fetishism', 'paraphilia', 'sexual_perversion', 'buggery']
senticnet['sofa'] = [0.897, 0, 0, 0.737, '#joyful', '#admirable', 0.545, 'magazine_rack', 'dentist_chair', 'couch', 'dentist_chair_bed', 'mattress']
senticnet['sofa_bed'] = [0.75, 0.954, 0, 0, '#joyful', '#interesting', 0.568, 'airline_seat', 'small_seat', 'beanbag_chair', 'hide-a-bed_sofa', 'chair']
senticnet['sofa_hide_bed'] = [0.726, 0, 0, 0.722, '#joyful', '#admirable', 0.483, 'sofa_bed', 'armchair', 'club_chair', 'chair', 'rock_chair']
senticnet['soft'] = [0.097, 0.07, 0.009, 0.148, '#joyful', '#admirable', 0.102, 'biodegradable', 'material_type', 'fabric_type', 'softness', 'fuzzy']
senticnet['soft-boiled'] = [0, 0.728, 0, 0.716, '#interesting', '#admirable', 0.481, 'soft', 'softheartedness', 'sympathetically', 'empathetically', 'empathic']
senticnet['soft_cloth'] = [0.03, 0.069, 0, 0.168, '#interesting', '#admirable', 0.089, 'softness', 'curly', 'texture', 'soft_fabric', 'fuzzy']
senticnet['soft_diet'] = [-0.637, 0, 0.819, -0.997, '#angry', '#disgusting', -0.818, 'light_diet', 'diet', 'spoon_food', 'bland_diet', 'ulcer_diet']
senticnet['soft_drink'] = [0.087, -0.003, 0, 0, '#joyful', '#surprising', 0.03, 'juice', 'apple_juice', 'orange_juice', 'ice_tea', 'cider']
senticnet['soft_drug'] = [-0.946, 0, 0.517, -0.757, '#sad', '#disgusting', -0.74, 'narcotic', 'bhang', 'cannabis', 'marijuana', 'marihuana']
senticnet['soft_fabric'] = [0, 0.975, 0, 0.889, '#interesting', '#admirable', 0.621, 'cloth_material', 'fabric_type', 'clothes_fabric', 'dry_clean', 'cloth_fabric']
senticnet['soft_hard'] = [0.118, -0.06, 0.075, 0.086, '#joyful', '#admirable', 0.063, 'malleable', 'dance_type', 'attract', 'adjust', 'pedal']
senticnet['soft_heart'] = [0, 0.883, 0, 0.794, '#interesting', '#admirable', 0.559, 'softhearted', 'softheartedness', 'generous', 'empathetically', 'empathic']
senticnet['soft_metal'] = [0.728, 0.977, 0, 0.939, '#interesting', '#admirable', 0.881, 'air_pressure', 'altitude', 'air_density', 'heavy_air', 'dense_air']
senticnet['soft_skin'] = [0.177, 0.083, 0, 0.166, '#joyful', '#admirable', 0.142, 'keep_clothes_clean', 'arm_around_neck', 'make_pretty', 'cover_table', 'clean_cloth']
senticnet['soft_spot'] = [0.478, 0.674, -0.265, 0.259, '#joyful', '#interesting', 0.382, 'protectively', 'protectiveness', 'fond_regard', 'affectional', 'affective']
senticnet['soft_sweet'] = [0.14, 0.111, -0.079, 0.223, '#joyful', '#admirable', 0.132, 'sugary', 'round_pastry', 'sweet', 'bakery_item', 'cover_ice']
senticnet['soft_touch'] = [0.13, 0.2, -0.093, 0.272, '#interesting', '#admirable', 0.17, 'nice', 'soft', 'biodegradable', 'happiness', 'texture']
senticnet['soft_white'] = [0.069, 0.112, 0, 0.167, '#interesting', '#admirable', 0.116, 'type_of_material', 'material_type', 'fabric_type', 'cloth_fabric', 'cloth_material']
senticnet['soft_wood'] = [0, 0, 0.029, -0.043, '#angry', '#disgusting', -0.024, 'franchise', 'tree_type', 'tree_wood', 'wood', 'cellulose']
senticnet['softhearted'] = [0, 0.811, 0, 0.704, '#interesting', '#admirable', 0.505, 'soft_heart', 'softheartedness', 'generous', 'empathetically', 'empathic']
senticnet['softheartedness'] = [0, 0.91, 0, 0.903, '#interesting', '#admirable', 0.604, 'soft', 'softhearted', 'sympathetically', 'empathetically', 'empathic']
senticnet['softie'] = [-0.918, 0, 0.681, -0.818, '#sad', '#disgusting', -0.806, 'chicken', 'softy', 'doormat', 'crybaby', 'wimp']
senticnet['softly'] = [0.266, 0.372, -0.276, 0.39, '#interesting', '#admirable', 0.251, 'good_manner', 'courteous', 'soft_touch', 'kindly', 'yearn']
senticnet['softness'] = [0.06, 0.079, 0, 0.097, '#interesting', '#admirable', 0.079, 'soft_fabric', 'silky', 'fabric_type', 'type_of_cloth', 'clothes_material']
senticnet['software'] = [-0.849, 0, 0.689, -0.907, '#sad', '#disgusting', -0.815, 'authoring_language', 'authoring_language_program', 'computer_authoring_language', 'authoring_language_system', 'authoring_language_package']
senticnet['software_company'] = [0.062, 0.212, 0, 0, '#joyful', '#interesting', 0.091, 'business', 'corporation', 'company', 'start_up', 'government_agreement']
senticnet['software_crash'] = [-0.123, -0.089, 0.085, -0.14, '#sad', '#disgusting', -0.086, 'old_technology', 'roar', 'mosquito', 'groan', 'itch']
senticnet['software_error'] = [-0.91, 0, 0.903, -0.705, '#sad', '#angry', -0.839, 'error', 'syntax_error', 'semantic_error', 'runtime_error', 'computer_error']
senticnet['software_package'] = [-0.849, 0, 0.689, -0.907, '#sad', '#disgusting', -0.815, 'software', 'software_program', 'computer_software', 'software_system', 'authoring_language']
senticnet['software_program'] = [-0.849, 0, 0.689, -0.907, '#sad', '#disgusting', -0.815, 'software', 'authoring_language', 'computer_software', 'software_system', 'software_package']
senticnet['software_system'] = [-0.849, 0, 0.689, -0.907, '#sad', '#disgusting', -0.815, 'software', 'software_program', 'computer_software', 'authoring_language', 'software_package']
senticnet['softy'] = [-0.918, 0, 0.681, -0.818, '#sad', '#disgusting', -0.806, 'chicken', 'doormat', 'softie', 'crybaby', 'wimp']
senticnet['soggy'] = [0, 0, -0.796, -0.935, '#scared', '#disgusting', -0.577, 'marshy', 'mucky', 'muddy', 'boggy', 'miry']
senticnet['soil_earth'] = [-0.072, 0, 0.014, 0, '#sad', '#angry', -0.029, 'ground_material', 'abrasive', 'inner_planet', 'cold_night', 'small_rock']
senticnet['soiled'] = [-0.717, 0, 0.839, -0.762, '#angry', '#disgusting', -0.773, 'draggled', 'befouled', 'filthy', 'nasty', 'scummy']
senticnet['sol'] = [0.061, 0, 0, 0.067, '#joyful', '#admirable', 0.043, 'star', 'celestial_body', 'sun', 'celestial_object', 'solar']
senticnet['solace'] = [0.661, 0.641, -0.24, 0.309, '#joyful', '#interesting', 0.457, 'comfortableness', 'comfortably', 'nigh', 'belonging', 'euphoric']
senticnet['solar_cell'] = [0, 0, -0.074, -0.169, '#scared', '#disgusting', -0.081, 'radio_wave', 'sun', 'cosmic_ray', 'x-ray', 'gamma_ray']
senticnet['solar_energy'] = [-0.791, 0, 0.997, -0.687, '#sad', '#angry', -0.825, 'energy', 'alternative_energy', 'solar_power', 'wind_generation', 'wind_power']
senticnet['solar_power'] = [-0.791, 0, 0.997, -0.687, '#sad', '#angry', -0.825, 'energy', 'solar_energy', 'alternative_energy', 'wind_generation', 'wind_power']
senticnet['solar_system'] = [0.979, 0.917, 0, 0, '#joyful', '#interesting', 0.632, 'ufo', 'milky', 'space_junk', 'galaxy', 'martian']
senticnet['solaris'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'unix', 'window', 'many_windows', 'train_window', 'doorway']
senticnet['soldier'] = [-0.029, 0, -0.076, -0.18, '#scared', '#disgusting', -0.095, 'army', 'fight_man', 'warrior', 'samurai', 'infantry']
senticnet['soldier_group'] = [0.736, 0.739, 0, 0, '#joyful', '#interesting', 0.492, 'military', 'attacker', 'army', 'arm_force', 'samurai']
senticnet['soldiering'] = [0.753, -0.604, 0, 0.551, '#joyful', '#surprising', 0.636, 'acquirement', 'skill', 'accomplishment', 'acquisition', 'attainment']
senticnet['soldiership'] = [0.646, -0.9, 0, 0.684, '#surprising', '#admirable', 0.743, 'acquirement', 'skill', 'accomplishment', 'acquisition', 'attainment']
senticnet['sole'] = [0.723, 0.803, 0, 0, '#joyful', '#interesting', 0.509, 'heel', 'foot_part', 'type_of_shoes', 'shoe_type', 'high_heel']
senticnet['solemnity'] = [0, 0.934, 0, 0.792, '#interesting', '#admirable', 0.575, 'wistful', 'pensiveness', 'musing', 'pondering', 'contemplative']
senticnet['solicit'] = [0.857, -0.569, 0, 0.721, '#joyful', '#admirable', 0.716, 'ask_for', 'lobby', 'quest', 'canvass', 'buttonhole']
senticnet['solicitation'] = [0.772, -0.592, 0, 0.532, '#joyful', '#surprising', 0.632, 'appeal', 'touch', 'prayer', 'beggary', 'begging']
senticnet['solicitor'] = [0.053, 0.122, -0.078, 0.086, '#interesting', '#admirable', 0.061, 'attorney', 'lawyer', 'jury', 'decide_guilt', 'prosecutor']
senticnet['solicitous'] = [0.997, 0, 0, 0.716, '#joyful', '#admirable', 0.571, 'concerned', 'caring', 'attentive', 'mindful', 'interested']
senticnet['solicitously'] = [0, 0.981, 0, 0.954, '#interesting', '#admirable', 0.645, 'solicitude', 'concern', 'solicitous', 'care', 'attentive']
senticnet['solicitousness'] = [0.714, 0.721, 0, 0, '#joyful', '#interesting', 0.478, 'solicitude', 'solicitous', 'solicitously', 'misgiving', 'scruple']
senticnet['solicitude'] = [0.781, 0, 0, 0.767, '#joyful', '#admirable', 0.516, 'solicitousness', 'solicitous', 'solicitously', 'mindfulness', 'consideration']
senticnet['solid'] = [0.047, 0.069, 0.025, 0.133, '#interesting', '#admirable', 0.075, 'construction_material', 'opaque', 'hard_material', 'hard', 'substance']
senticnet['solid_basis'] = [0, 0.991, 0, 0.804, '#interesting', '#admirable', 0.598, 'pillar', 'sustain', 'back_bone', 'structure', 'help_people']
senticnet['solid_fuel'] = [0, 0, 0, 0.073, '#admirable', '#admirable', 0.024, 'fire_starter', 'organic_substance', 'renewable_resource', 'use_fuel', 'tree_product']
senticnet['solid_ground'] = [0.703, -0.579, 0, 0.918, '#joyful', '#admirable', 0.733, 'land', 'dry_land', 'earth', 'ground', 'wonderland']
senticnet['solid_liquid'] = [0, 0.803, 0, 0.784, '#interesting', '#admirable', 0.529, 'combustible', 'state_matter', 'natural_resource', 'liquid_fuel', 'fossil_fuel']
senticnet['solid_room_temperature'] = [0, 0.76, 0, 0.936, '#interesting', '#admirable', 0.565, 'hard_rock', 'hard_mineral', 'hard_plastic', 'hard_material', 'hard']
senticnet['solid_surface'] = [-0.121, -0.031, 0.091, 0, '#sad', '#angry', -0.06, 'use_leg', 'wear_running_shoes', 'wear_good_shoes', 'take_step', 'act_quickly']
senticnet['solid_water'] = [0.085, -0.063, 0, 0, '#joyful', '#surprising', 0.049, 'soap', 'drizzle', 'bubbly', 'foam', 'ivory']
senticnet['solidification'] = [-0.553, 0, 0.689, -0.944, '#angry', '#disgusting', -0.729, 'natural_process', 'natural_action', 'activity', 'congealment', 'congelation']
senticnet['solidifying'] = [-0.961, 0, 0.682, -0.831, '#sad', '#disgusting', -0.825, 'natural_process', 'natural_action', 'activity', 'congealment', 'congelation']
senticnet['solidness'] = [-0.639, 0, 0.694, -0.667, '#angry', '#disgusting', -0.667, 'tangibility', 'tangibleness', 'palpability', 'reality', 'corporality']
senticnet['solitary'] = [-0.845, 0, 0, 0, '#sad', '#sad', -0.282, 'precision', 'small', 'alone', 'single', 'widow']
senticnet['solitude'] = [0.75, 0.954, 0, 0, '#joyful', '#interesting', 0.568, 'alone', 'sit_dark', 'single', 'blackout', 'sociopathic']
senticnet['solo'] = [0.899, 0.726, 0, 0, '#joyful', '#interesting', 0.542, 'concert', 'measure_angle', 'make_drawing', 'make_beautiful_music', 'listen_heart']
senticnet['solon'] = [0.8, -0.796, 0, 0.751, '#joyful', '#surprising', 0.782, 'elder_statesman', 'stateswoman', 'politician', 'politico', 'pol']
senticnet['solution'] = [-0.075, 0.186, -0.102, 0.181, '#interesting', '#admirable', 0.063, 'get_answer', 'question_start', 'explanation', 'query', 'inquire']
senticnet['solution_to_problem'] = [0.87, 0.831, 0, 0.93, '#joyful', '#admirable', 0.877, 'know_fact', 'great_understand', 'gain_insight', 'understand', 'trivia']
senticnet['solve'] = [0.849, 0.79, 0, 0.793, '#joyful', '#admirable', 0.811, 'learn_new_word', 'fantasize', 'mind_boggle', 'see_oneself', 'introspection']
senticnet['solve_big_problem'] = [0.487, 0.675, -0.267, 0.266, '#joyful', '#interesting', 0.387, 'collective_intelligence', 'gather_intelligence', 'intelligent', 'team_work', 'clever']
senticnet['solve_equation'] = [-0.165, 0, 0, -0.067, '#sad', '#disgusting', -0.077, 'guess_answer', 'master_skill', 'love_pet', 'master_new_skill', 'borrow_book_from_library']
senticnet['solve_mystery'] = [-0.102, 0.094, 0, -0.103, '#sad', '#disgusting', -0.037, 'come_conclusion', 'find_answer', 'forget_else', 'study_fact', 'resolve_problem']
senticnet['solve_problem'] = [0.919, 0.724, 0, 0, '#joyful', '#interesting', 0.548, 'look_clue', 'make_decision', 'revelation', 'deduce', 'consider_option']
senticnet['solve_puzzle'] = [-0.091, 0, 0, -0.068, '#sad', '#disgusting', -0.053, 'beat_off', 'play_board_game', 'television_view', 'smoke_marijuana', 'rake_leave']
senticnet['solvent'] = [0.727, -0.843, 0, 0.966, '#surprising', '#admirable', 0.845, 'medium', 'acetone', 'propanone', 'dimethyl_ketone', 'chlorobenzene']
senticnet['somatic_cell'] = [-0.665, 0, 0.877, -0.642, '#sad', '#angry', -0.728, 'mast_cell', 'mastocyte', 'labrocyte', 'target_cell', 'phagocyte']
senticnet['somatic_sensation'] = [-0.78, 0, 0.669, -0.894, '#sad', '#disgusting', -0.781, 'pain_sensation', 'painful_sensation', 'prickling', 'tingling', 'pain']
senticnet['somberness'] = [-0.798, 0.257, -0.471, -0.036, '#sad', '#scared', -0.349, 'gloomful', 'glooming', 'darkness', 'gloominess', 'gloomily']
senticnet['sombreness'] = [-0.573, 0, 0.841, -0.508, '#sad', '#angry', -0.641, 'somberness', 'stodginess', 'gravity', 'soberness', 'graveness']
senticnet['some'] = [0, 0, -0.725, -0.873, '#scared', '#disgusting', -0.533, 'close_to', 'approximately', 'just_about', 'roughly', 'about']
senticnet['some_place'] = [0.215, 0.194, -0.204, 0.279, '#joyful', '#admirable', 0.161, 'rendezvous', 'sweatshop', 'work_in_garden', 'ball_game', 'babysitter']
senticnet['someone_else'] = [0, 0.119, -0.054, 0.11, '#interesting', '#admirable', 0.058, 'replacement', 'class', 'undergraduate', 'replace', 'substitute']
senticnet['somersault'] = [-0.03, 0.074, -0.062, 0.176, '#interesting', '#admirable', 0.053, 'revolve', 'spring_leak', 'rotate_movement', 'wrap_around', 'turn_around']
senticnet['somerset'] = [-0.502, 0, 0.73, -0.686, '#angry', '#disgusting', -0.639, 'flip', 'acrobatic_stunt', 'acrobatic_feat', 'somersault', 'tumble']
senticnet['something_burn'] = [-0.948, 0, 0.994, -0.959, '#angry', '#disgusting', -0.967, 'fire', 'burn', 'flame', 'heat', 'start_fire']
senticnet['something_terrible'] = [-0.983, 0, 0.7, -0.901, '#sad', '#disgusting', -0.861, 'terrible', 'problem', 'trouble', 'bad_feeling', 'mess']
senticnet['something_to_do'] = [0.101, -0.048, 0.104, -0.16, '#angry', '#disgusting', -0.038, 'like_compete', 'exercise_mind', 'play_friend', 'enjoyment', 'pastime']
senticnet['something_to_tell'] = [0.801, 0.779, 0, 0, '#joyful', '#interesting', 0.527, 'child_book', 'interesting_story', 'good_story', 'scholar', 'nice_ending']
senticnet['sometimes'] = [0.052, 0.066, 0, 0.106, '#interesting', '#admirable', 0.075, 'shell_fish', 'seafood', 'marine_animal', 'ocean_animal', 'crustacean']
senticnet['sometimes_bad'] = [0, 0.728, 0, 0.726, '#interesting', '#admirable', 0.485, 'battle_disease', 'see_light', 'feel_love', 'fear_death', 'end_war']
senticnet['sometimes_green'] = [-0.063, 0.09, 0, 0.073, '#interesting', '#admirable', 0.033, 'grassy', 'cultivate_yard', 'generic', 'poisonous_human', 'nutritious']
senticnet['sometimes_painful'] = [0.853, 0.763, 0, 0, '#joyful', '#interesting', 0.539, 'physical_reaction', 'gape', 'ouch', 'hurtful', 'blown']
senticnet['somniloquism'] = [-0.531, 0, 0.762, -0.668, '#angry', '#disgusting', -0.654, 'defense', 'sleep_talking', 'somniloquy', 'unconscious_process', 'condensation']
senticnet['somniloquy'] = [-0.531, 0, 0.762, -0.668, '#angry', '#disgusting', -0.654, 'defense', 'sleep_talking', 'unconscious_process', 'somniloquism', 'condensation']
senticnet['somnolence'] = [-0.827, 0, 0.663, -0.508, '#sad', '#angry', -0.666, 'obtuseness', 'dullness', 'sleepiness', 'drowsiness', 'oscitance']
senticnet['son_of_bitch'] = [-0.667, 0, 0.595, -0.837, '#sad', '#disgusting', -0.7, 'bastard', 'dickhead', 'mother_fucker', 'motherfucker', 'disagreeable_person']
senticnet['song'] = [0.077, -0.026, 0.049, 0.053, '#joyful', '#admirable', 0.036, 'melody', 'lyrics', 'music_note', 'lyric', 'pop_music']
senticnet['song_and_dance'] = [-0.934, 0, 0.739, -0.969, '#sad', '#disgusting', -0.881, 'prevarication', 'fairytale', 'fairy_tale', 'fairy_story', 'fib']
senticnet['song_lyric'] = [0.075, -0.007, 0.057, 0.085, '#joyful', '#admirable', 0.037, 'lyrics', 'like_poetry', 'lyric', 'piece_of_music', 'melody']
senticnet['song_title'] = [0.169, 0.13, -0.166, 0.536, '#joyful', '#admirable', 0.223, 'song', 'inclusion', 'music', 'right', 'all_right']
senticnet['songbook'] = [0, 0.176, 0, 0.216, '#interesting', '#admirable', 0.131, 'choir_stall', 'worshiper', 'pew', 'fundamentalist', 'pulpit']
senticnet['songwriter'] = [0.937, 0, 0, 0, '#joyful', '#joyful', 0.312, 'music', 'classical', 'composer', 'band_play', 'rock_band']
senticnet['sonic'] = [0.036, 0, 0, 0.176, '#joyful', '#admirable', 0.071, 'vibration', 'audio', 'ear_activity', 'audible', 'decibel']
senticnet['sonnet'] = [0.069, 0, 0, 0.124, '#joyful', '#admirable', 0.064, 'rhyme', 'like_poetry', 'poem', 'song_lyric', 'form_of_art']
senticnet['soon'] = [0, 0.071, 0, 0, '#interesting', '#interesting', 0.024, 'early', 'light_in_sky', 'sunrise', 'day_part', 'part_of_day']
senticnet['soot'] = [0, 0, -0.713, 0, '#scared', '#scared', -0.238, 'ash', 'cinder', 'combustion', 'flue', 'flame']
senticnet['soot_black'] = [-0.604, 0, 0.895, -0.541, '#sad', '#angry', -0.68, 'coal_black', 'jet_black', 'pitch_black', 'black', 'achromatic_color']
senticnet['soothe'] = [0.712, 0, 0, 0, '#joyful', '#joyful', 0.237, 'serenity', 'euphoria', 'serene', 'tranquility', 'cheer']
senticnet['soothing'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'calmly', 'quieten', 'assuasive', 'tranquillize', 'cool_down']
senticnet['sop'] = [0.908, 0.725, 0, 0, '#joyful', '#interesting', 0.544, 'puddle', 'toilet_tank', 'liquid_water', 'finger_paint', 'bread']
senticnet['sophisticate'] = [-0.897, 0, 0.89, -0.775, '#sad', '#angry', -0.854, 'doctor', 'doctor_up', 'corrupt', 'spoil', 'adulterate']
senticnet['sophisticated'] = [0, 0.869, 0, 0.733, '#interesting', '#admirable', 0.534, 'common_man', 'lovely', 'elegant', 'contrary', 'feminine']
senticnet['soporific'] = [0, 0, -0.757, -0.88, '#scared', '#disgusting', -0.546, 'somnific', 'hypnotic', 'hypnogogic', 'somniferous', 'soporiferous']
senticnet['soprano'] = [0.052, -0.027, 0, 0, '#joyful', '#surprising', 0.026, 'chord', 'singer', 'melodic_noise', 'instrumental', 'amplifier']
senticnet['sorcerer'] = [-0.62, 0, 0.964, -0.652, '#angry', '#disgusting', -0.745, 'exorcist', 'enchanter', 'magus', 'sorceress', 'witch_doctor']
senticnet['sorcery'] = [-0.798, 0, 0.506, -0.931, '#sad', '#disgusting', -0.745, 'magic', 'thaumaturgy', 'enchantment', 'witchcraft', 'witchery']
senticnet['sore'] = [-0.171, 0, 0.256, -0.453, '#angry', '#disgusting', -0.293, 'cut_skin', 'ache', 'abrasion', 'laceration', 'gash']
senticnet['sore_back'] = [-0.979, 0, 0, 0, '#sad', '#sad', -0.326, 'back_pain', 'backache', 'broken_leg', 'become_exhausted', 'dog_bark']
senticnet['sore_butt'] = [0.847, 0.806, 0, 0, '#joyful', '#interesting', 0.551, 'win_loose', 'keep_score', 'roll_dice', 'win_game', 'play_game']
senticnet['sore_foot'] = [0.848, 0.749, 0, 0, '#joyful', '#interesting', 0.532, 'become_tired', 'leg_cramp', 'fatigue', 'tiredness', 'get_tired_leg']
senticnet['sore_knee'] = [0.833, 0.923, 0, 0, '#joyful', '#interesting', 0.585, 'get_tired', 'tiredness', 'breaheavily', 'run_out_breath', 'feel_tired']
senticnet['sore_leg'] = [0.902, 0.993, 0, 0, '#joyful', '#interesting', 0.632, 'breaheavily', 'heavy_breathe', 'get_exhausted', 'exhaustion', 'see_neighbor']
senticnet['sore_muscle'] = [-0.93, 0, -0.918, 0, '#sad', '#scared', -0.616, 'pull_muscle', 'become_exhausted', 'increased_heart_rate', 'breathlessness', 'tired_leg']
senticnet['sore_stomach'] = [-0.029, -0.018, 0, -0.125, '#sad', '#disgusting', -0.045, 'sew_term', 'needle_thread', 'use_needle', 'seam', 'cut_fabric']
senticnet['sore_throat'] = [-0.889, 0, 0, 0, '#sad', '#sad', -0.296, 'get_laugh', 'tooth_hurt', 'choke_death', 'gain_weight', 'feel_satisfied']
senticnet['soreness'] = [-0.89, 0, -0.834, 0, '#sad', '#scared', -0.575, 'contusion', 'injury', 'concern_health', 'physical_injury', 'strengthful']
senticnet['sorrow'] = [-0.8, 0, 0, 0, '#sad', '#sad', -0.267, 'heartache', 'grief', 'heartbreak', 'woe', 'guilty_conscience']
senticnet['sorrower'] = [-0.843, 0, 0.523, -0.51, '#sad', '#angry', -0.625, 'unfortunate', 'unfortunate_person', 'weeper', 'pallbearer', 'bearer']
senticnet['sorrowful'] = [-0.87, 0.193, -0.581, 0, '#sad', '#scared', -0.419, 'regretful', 'ruefulness', 'mournful', 'sadly', 'self-pity']
senticnet['sorrowfully'] = [-0.855, 0.21, -0.562, 0, '#sad', '#scared', -0.402, 'doleful', 'sadly', 'dolefully', 'ruefulness', 'wretched']
senticnet['sorrowfulness'] = [-0.894, 0.16, -0.612, 0.055, '#sad', '#scared', -0.43, 'mournfully', 'ruthfulness', 'mournfulness', 'heartrending', 'heartbreaking']
senticnet['sorrowing'] = [-0.884, 0.175, -0.599, 0, '#sad', '#scared', -0.436, 'bereaved', 'grief-stricken', 'bereft', 'grieving', 'mourning']
senticnet['sorry'] = [-0.878, 0.203, -0.6, 0.06, '#sad', '#scared', -0.405, 'ruthful', 'contrite', 'remorseful', 'rueful', 'sorrowing']
senticnet['sort'] = [0, 0.174, -0.059, 0.224, '#interesting', '#admirable', 0.113, 'neat_tidy', 'arrange', 'neatness', 'clean_sink', 'tidy_up']
senticnet['sort_clothes'] = [-0.043, 0, 0.03, 0, '#sad', '#angry', -0.024, 'use_water', 'use_soap', 'buy_wash_powder', 'clothes_dirty', 'laundry']
senticnet['sort_mail'] = [-0.045, 0.212, 0, 0.09, '#interesting', '#admirable', 0.086, 'price', 'cost', 'expense', 'item_value', 'value']
senticnet['sot'] = [0.749, -0.728, 0, 0.896, '#joyful', '#admirable', 0.791, 'lush', 'alcoholic', 'alky', 'dipsomaniac', 'boozer']
senticnet['sottishness'] = [-0.529, 0, 0.542, -0.938, '#angry', '#disgusting', -0.67, 'intoxication', 'drunkenness', 'inebriation', 'inebriety', 'tipsiness']
senticnet['soubrette'] = [0.814, -0.937, 0, 0.781, '#joyful', '#surprising', 0.844, 'girl', 'miss', 'missy', 'young_lady', 'young_woman']
senticnet['soud_system'] = [0, 0, -0.049, -0.066, '#scared', '#disgusting', -0.038, 'television_set', 'remove_control', 'tv_set', 'christian_fundamentalist', 'stair_down']
senticnet['soul'] = [0.042, 0.146, 0, 0, '#joyful', '#interesting', 0.063, 'skeletal_system', 'main_artery', 'nape', 'artery', 'tendon']
senticnet['soul_searching'] = [0.08, 0.153, -0.125, 0.224, '#interesting', '#admirable', 0.111, 'meditation', 'self_contemplation', 'introspection', 'self_examination', 'self_observation']
senticnet['sound'] = [0.036, 0, 0, 0.11, '#joyful', '#admirable', 0.049, 'animal_sound', 'noise', 'decibel', 'loudness', 'audio']
senticnet['sound_alarm'] = [-0.09, 0, 0.025, -0.037, '#sad', '#disgusting', -0.051, 'make_a_lot_of_noise', 'compose_music', 'tune_instrument', 'perform_on_stage', 'strum']
senticnet['sound_bad'] = [0.062, -0.138, 0.16, -0.185, '#angry', '#disgusting', -0.048, 'fail', 'broken', 'string_break', 'bad', 'make_sound']
senticnet['sound_beautiful'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'instrumental', 'symphony', 'concert', 'music', 'violin']
senticnet['sound_control_room'] = [0.136, -0.056, -0.046, -0.03, '#joyful', '#surprising', 0.039, 'theater_hall', 'rehearse_room', 'theater_box', 'amphitheater', 'soundstage']
senticnet['sound_good'] = [0.915, 0, 0, 0.845, '#joyful', '#admirable', 0.587, 'delight_sense', 'great_joy', 'feel_refreshed', 'happiness', 'self_satisfaction']
senticnet['sound_judgment'] = [0.828, -0.904, 0, 0.874, '#surprising', '#admirable', 0.869, 'perspicacity', 'judgment', 'fair', 'objectiveness', 'fair_judgment']
senticnet['sound_like'] = [0, 0.136, 0, 0.199, '#interesting', '#admirable', 0.112, 'recall', 'remember', 'game_part', 'remind_of', 'push_together']
senticnet['sound_loud'] = [-0.058, -0.006, 0.059, 0, '#sad', '#angry', -0.037, 'beep', 'strum', 'make_noise', 'compose_music', 'make_a_lot_of_noise']
senticnet['sound_lovely'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'agree', 'make_beautiful_music', 'chamber_music', 'play_stringed_instrument', 'make_music']
senticnet['sound_make'] = [0.845, 0.789, 0, 0.806, '#joyful', '#admirable', 0.813, 'vocal_music', 'melody', 'lullaby', 'tune', 'lyric']
senticnet['sound_nice'] = [0.241, 0.185, -0.114, 0.16, '#joyful', '#interesting', 0.157, 'eclectic', 'rock_group', 'musical_group', 'rolling_stone', 'music_group']
senticnet['sound_off'] = [-0.906, 0, 0.725, -0.861, '#sad', '#disgusting', -0.831, 'quetch', 'kvetch', 'complain', 'bemoan', 'plain']
senticnet['sound_out'] = [-0.035, 0.084, 0, 0.112, '#interesting', '#admirable', 0.054, 'finite', 'spell_wrong', 'color_red', 'hue', 'bright_red']
senticnet['sound_pressure_level'] = [-0.934, 0, 0.698, -0.857, '#sad', '#disgusting', -0.83, 'candlepower', 'light_intensity', 'acoustic_power', 'intensity', 'threshold_level']
senticnet['sound_system'] = [0.049, 0.167, -0.053, 0.295, '#interesting', '#admirable', 0.153, 'four_sides', 'dolby_surround', 'bass', 'movie', 'surround']
senticnet['sound_wave'] = [0.115, 0, 0.042, 0.066, '#joyful', '#admirable', 0.046, 'loud_sound', 'boom', 'decibel', 'loud_noise', 'loudness']
senticnet['sounding'] = [-0.631, 0, 0.857, -0.711, '#angry', '#disgusting', -0.733, 'shallow', 'facile', 'ostensible', 'superficial', 'looking']
senticnet['soundproof'] = [-0.9, 0, 0.657, -0.644, '#sad', '#angry', -0.734, 'imperviable', 'mothproof', 'resistant', 'proof', 'greaseproof']
senticnet['soundstage'] = [0.136, -0.056, -0.046, -0.03, '#joyful', '#surprising', 0.039, 'theater_hall', 'rehearse_room', 'theater_box', 'sound_control_room', 'amphitheater']
senticnet['soup'] = [-0.08, 0, 0, 0, '#sad', '#sad', -0.027, 'needy', 'come_house', 'quiet_child', 'prepare_supper', 'salt_food']
senticnet['soupy'] = [0, 0, -0.788, -0.833, '#scared', '#disgusting', -0.54, 'maudlin', 'hokey', 'drippy', 'mawkish', 'bathetic']
senticnet['sour'] = [0, 0, -0.806, -0.721, '#scared', '#disgusting', -0.509, 'work', 'acidity', 'ferment', 'tartness', 'turn']
senticnet['sour_cream'] = [0.706, 0.979, 0, 0, '#joyful', '#interesting', 0.562, 'tofu', 'sour_milk', 'peanut_butter', 'mayonnaise', 'cottage_cheese']
senticnet['sour_milk'] = [-0.104, -0.049, 0, -0.155, '#sad', '#disgusting', -0.07, 'lasagna', 'frozen_food', 'green_bean', 'tofu', 'horseradish']
senticnet['sour_taste'] = [0.045, 0.141, -0.054, 0.065, '#interesting', '#admirable', 0.066, 'kernel', 'starch', 'ginger', 'cereal_crop', 'pea']
senticnet['source'] = [0, 0.911, 0, 0.813, '#interesting', '#admirable', 0.575, 'bulletin', 'replicate', 'current_event', 'computer_command', 'paper_write']
senticnet['source_code'] = [0, 0, 0, 0.07, '#admirable', '#admirable', 0.023, 'buffoon', 'computer', 'browser', 'dvd', 'clown']
senticnet['source_electricity'] = [0.033, 0.075, 0, 0.153, '#interesting', '#admirable', 0.087, 'switch', 'find_tape', 'turn_computer_on', 'read_manual', 'buy_computer']
senticnet['source_information'] = [0.494, 0.673, -0.269, 0.25, '#joyful', '#interesting', 0.383, 'information', 'report_event', 'read_news', 'review_book', 'report_news']
senticnet['source_light'] = [0.026, 0, 0, 0.116, '#joyful', '#admirable', 0.047, 'bright_yellow', 'celestial_body', 'limitless', 'around_earth', 'sol']
senticnet['souring'] = [-0.931, 0, 0.997, -0.506, '#sad', '#angry', -0.811, 'decay', 'mildew', 'mold', 'mould', 'spoiling']
senticnet['sourness'] = [-0.78, 0, 0.969, -0.785, '#angry', '#disgusting', -0.845, 'acidity', 'acidulousness', 'taste', 'taste_sensation', 'gustatory_sensation']
senticnet['sourpuss'] = [-0.874, 0, 0.693, -0.645, '#sad', '#angry', -0.737, 'unwelcome_person', 'picklepuss', 'troublemaker', 'trouble_maker', 'troubler']
senticnet['southern_red_oak'] = [0.672, -0.696, 0, 0.831, '#surprising', '#admirable', 0.733, 'red_oak', 'swamp_red_oak', 'turkey_oak', 'northern_red_oak', 'oak']
senticnet['southernwood'] = [-0.669, 0, 0.811, -0.781, '#angry', '#disgusting', -0.754, 'subshrub', 'suffrutex', 'old_woman', 'mugwort', 'wormwood']
senticnet['sow'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'needlework', 'hoe', 'cultivate', 'pip', 'vegetable_field']
senticnet['soya'] = [-0.705, 0, 0.606, -0.723, '#sad', '#disgusting', -0.678, 'common_bean', 'bean', 'goa_bean', 'mung_bean', 'mung']
senticnet['spa'] = [0.891, 0.994, 0, 0, '#joyful', '#interesting', 0.628, 'igloo', 'another_planet', 'death_row', 'loose_end', 'car_race']
senticnet['space_between'] = [0.045, 0.092, 0.06, 0.22, '#interesting', '#admirable', 0.099, 'how_far', 'distance', 'distance_measure', 'length_measurement', 'measurement_unit']
senticnet['space_junk'] = [0.924, 0.705, 0, 0, '#joyful', '#interesting', 0.543, 'ufo', 'milky', 'martian', 'galaxy', 'solar_system']
senticnet['space_travel'] = [0.076, 0.085, -0.047, 0, '#joyful', '#interesting', 0.038, 'travel', 'space', 'rock_climb', 'anarchy', 'secret_organization']
senticnet['spacious'] = [0.075, 0.115, 0, 0.124, '#interesting', '#admirable', 0.105, 'wide_open', 'shelter', 'house_place', 'live_environment', 'natural']
senticnet['spam'] = [-0.05, -0.039, 0.023, -0.095, '#sad', '#disgusting', -0.043, 'moldy_food', 'celery', 'paper_product', 'orange_juice', 'after_lunch']
senticnet['spang'] = [0.746, -0.881, 0, 0.723, '#joyful', '#surprising', 0.783, 'strike', 'run_into', 'hit', 'impinge_on', 'collide_with']
senticnet['spangle'] = [0.087, -0.075, 0.062, 0, '#joyful', '#surprising', 0.033, 'small_piece', 'dust_particle', 'stripe', 'letter', 'oxide']
senticnet['spanish_restaurant'] = [0.039, 0.089, 0.023, 0, '#joyful', '#interesting', 0.035, 'steak_house', 'tapas', 'french_restaurant', 'paella', 'restaurant_diner']
senticnet['spank'] = [-0.247, 0, -0.194, 0, '#sad', '#scared', -0.147, 'mock', 'prison_sentence', 'wrongdoing', 'jail_time', 'violent_action']
senticnet['spare'] = [0.902, 0.76, 0, 0, '#joyful', '#interesting', 0.554, 'extra', 'rest', 'fresh', 'catch_breath', 'relief']
senticnet['spare_change'] = [0.05, 0.139, 0.037, 0, '#joyful', '#interesting', 0.051, 'bank_machine', 'piggy_bank', 'billfold', 'cash_register', 'bank_account']
senticnet['spare_enemy'] = [0.76, -0.593, 0, 0.713, '#joyful', '#admirable', 0.689, 'spareness', 'magnanimous', 'generous', 'forgiving', 'deal_gently']
senticnet['spare_time'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'watch_good_movie', 'good_sense_of_humor', 'able_read', 'unzip', 'strong_relationship']
senticnet['spare_tire'] = [0, 0.831, 0, 0.871, '#interesting', '#admirable', 0.567, 'dashboard', 'battery', 'seatbelt', 'car_stereo', 'brake_pedal']
senticnet['spareness'] = [0.76, -0.593, 0, 0.713, '#joyful', '#admirable', 0.689, 'spare_enemy', 'magnanimous', 'generous', 'forgiving', 'deal_gently']
senticnet['spark'] = [0.778, 0.833, 0, 0, '#joyful', '#interesting', 0.537, 'flame', 'fire', 'heat_light', 'rapid_oxidation', 'huge_fire']
senticnet['sparkle'] = [0.064, 0.07, 0, 0.184, '#interesting', '#admirable', 0.106, 'shine', 'shiny', 'recyclable', 'versatile', 'godliness']
senticnet['sparkling_water'] = [0.032, -0.022, -0.045, -0.087, '#scared', '#disgusting', -0.026, 'liquid', 'carbonate_drink', 'sweet', 'soda', 'drink']
senticnet['sparrow'] = [-0.109, 0, -0.09, 0, '#sad', '#scared', -0.066, 'quail', 'wren', 'chicken_egg', 'chicken', 'stork']
senticnet['sparseness'] = [-0.57, 0, 0.769, -0.862, '#angry', '#disgusting', -0.734, 'lack_of_quality', 'meagreness', 'poorness', 'scantiness', 'scantness']
senticnet['sparsity'] = [-0.819, 0, 0.986, -0.94, '#angry', '#disgusting', -0.915, 'lack_of_quality', 'meagreness', 'poorness', 'scantiness', 'scantness']
senticnet['spasm'] = [-0.029, 0, -0.093, -0.084, '#scared', '#disgusting', -0.069, 'stitch', 'tourniquet', 'sew_term', 'bandage', 'cure']
senticnet['spasmodic'] = [-0.872, 0, 0.722, -0.579, '#sad', '#angry', -0.724, 'stray', 'sporadic', 'unpredictable', 'isolated', 'irregular']
senticnet['spastic'] = [-0.569, 0, 0.849, -0.618, '#angry', '#disgusting', -0.679, 'convulsive', 'arrhythmic', 'jerky', 'spasmodic', 'unsteady']
senticnet['spat'] = [-0.52, 0, 0.805, -0.764, '#angry', '#disgusting', -0.696, 'wrangle', 'dustup', 'quarrel', 'row', 'word']
senticnet['spate'] = [-0.86, 0, 0.503, -0.654, '#sad', '#disgusting', -0.672, 'large_indefinite_quantity', 'large_indefinite_amount', 'deluge', 'flood', 'inundation']
senticnet['spatial_dimension'] = [0, 0.732, 0, 0.815, '#interesting', '#admirable', 0.516, 'measurement', 'time_interval', 'length', 'time', 'interval']
senticnet['spatter'] = [-0.879, 0, 0.682, -0.533, '#sad', '#angry', -0.698, 'swash', 'slosh_around', 'splatter', 'plash', 'splash']
senticnet['spatula'] = [0.03, -0.05, 0, 0.059, '#surprising', '#admirable', 0.046, 'platter', 'fork', 'spoon', 'tablespoon', 'bowl']
senticnet['spay'] = [-0.785, 0, 0.91, -0.917, '#angry', '#disgusting', -0.871, 'castrate', 'neuter', 'alter', 'emasculate', 'desex']
senticnet['speak'] = [0, -0.003, 0, 0.124, '#surprising', '#admirable', 0.042, 'orate', 'verbal_communication', 'phone_conversation', 'speech', 'spoken']
senticnet['speak_clearly'] = [0.963, 0, 0, 0.929, '#joyful', '#admirable', 0.631, 'become_artist', 'give_speech', 'show_how', 'recite_poem', 'put_costume']
senticnet['speak_english'] = [0.981, 0.936, 0, 0, '#joyful', '#interesting', 0.639, 'forward_email', 'deal_card_player', 'stand_alone', 'bridge_difference', 'explain_everything']
senticnet['speak_foreign_language'] = [0.931, 0.864, 0, 0, '#joyful', '#interesting', 0.598, 'roll_dice', 'try_win', 'minor_injury', 'try_best', 'loose']
senticnet['speak_human_language'] = [0.81, 0.953, 0, 0, '#joyful', '#interesting', 0.588, 'like_play', 'human_language', 'eat_dog', 'control_weather', 'travel_fast_light']
senticnet['speak_loudly'] = [0.027, 0, 0.01, 0.142, '#joyful', '#admirable', 0.053, 'dial_telephone', 'phone_conversation', 'dial_phone', 'telephone_ring', 'use_phone']
senticnet['speak_mind'] = [0.729, 0.919, 0, 0, '#joyful', '#interesting', 0.549, 'learn_listen', 'voice_opinion', 'receive_email', 'reply_question', 'post_letter']
senticnet['speak_organ'] = [0, 0.079, 0, 0.112, '#interesting', '#admirable', 0.064, 'protrusion', 'face_part', 'near_mouth', 'facial_feature', 'facial_part']
senticnet['speak_out'] = [0, 0.82, 0, 0.968, '#interesting', '#admirable', 0.596, 'tell', 'breath_sigh_relief', 'compromise', 'make_statement', 'discuss']
senticnet['speak_up'] = [0.995, 0.96, 0, 0, '#joyful', '#interesting', 0.652, 'think_first', 'think_say', 'speak_mind', 'know_talk', 'raise_hand']
senticnet['speaker'] = [0.034, -0.026, 0, 0.057, '#joyful', '#admirable', 0.039, 'female_television_connector', 'channel_selector', 'power_switch', 'tuner', 'radio']
senticnet['speaking'] = [0.563, -0.592, 0, 0.612, '#surprising', '#admirable', 0.589, 'whispering', 'voicelessness', 'whisper', 'susurration', 'speech']
senticnet['special'] = [0, 0.931, 0, 0.785, '#interesting', '#admirable', 0.572, 'join_together', 'event', 'occurrence', 'special_occasion', 'function']
senticnet['special_day'] = [0.117, -0.094, -0.085, 0, '#joyful', '#surprising', 0.042, 'yearly_celebration', 'party_time', 'annual_celebration', 'special_time', 'occasion']
senticnet['special_event'] = [0.882, 0, 0, 0, '#joyful', '#joyful', 0.294, 'celebration', 'special_occasion', 'special_time', 'special_day', 'party_time']
senticnet['special_happen'] = [0.885, 0.7, 0, 0, '#joyful', '#interesting', 0.528, 'special_moment', 'special_time', 'birthday_party', 'type_of_party', 'celebration']
senticnet['special_moment'] = [0.779, 0, 0, 0, '#joyful', '#joyful', 0.26, 'special_happen', 'special_time', 'celebration', 'special_event', 'occasion']
senticnet['special_occasion'] = [0.846, 0, 0, 0, '#joyful', '#joyful', 0.282, 'celebrate_birthday', 'celebration', 'special_event', 'party_time', 'child_birthday']
senticnet['special_person'] = [0, 0.983, 0, 0.924, '#interesting', '#admirable', 0.636, 'male_parent', 'member_of_family', 'male_relative', 'family_relationship_term', 'family_member']
senticnet['special_pleading'] = [0.886, -0.586, 0, 0.792, '#joyful', '#admirable', 0.755, 'argument', 'straw_man', 'strawman', 'vicious_circle', 'specious_argument']
senticnet['special_relativity'] = [-0.69, 0, 0.83, -0.997, '#angry', '#disgusting', -0.839, 'general_relativity', 'general_theory_of_relativity', 'general_relativity_theory', 'relativity', 'special_theory_of_relativity']
senticnet['special_theory_of_relativity'] = [-0.69, 0, 0.83, -0.997, '#angry', '#disgusting', -0.839, 'general_relativity', 'general_theory_of_relativity', 'general_relativity_theory', 'special_relativity', 'relativity']
senticnet['special_time'] = [0.9, 0, 0, 0, '#joyful', '#joyful', 0.3, 'special_day', 'special_moment', 'occurrence', 'yearly_celebration', 'special_happen']
senticnet['specialist'] = [0, 0.727, 0, 0.991, '#interesting', '#admirable', 0.573, 'connoisseur', 'surgeon', 'physician', 'accomplice', 'medical_person']
senticnet['specialness'] = [0.631, -0.611, 0, 0.739, '#joyful', '#admirable', 0.66, 'individualism', 'individuality', 'individuation', 'idiosyncrasy', 'foible']
senticnet['species'] = [0.051, 0.075, 0, 0.113, '#interesting', '#admirable', 0.08, 'live_organism', 'fauna', 'alive', 'live_creature', 'honey_insect']
senticnet['specious'] = [-0.527, 0, 0.651, -0.542, '#angry', '#disgusting', -0.573, 'feigned', 'dissimulative', 'insincere', 'hypocritical', 'fulsome']
senticnet['specious_argument'] = [0.886, -0.586, 0, 0.792, '#joyful', '#admirable', 0.755, 'argument', 'straw_man', 'strawman', 'vicious_circle', 'special_pleading']
senticnet['speckle'] = [-0.583, 0, 0.561, -0.622, '#sad', '#disgusting', -0.589, 'spot', 'worn_spot', 'dapple', 'patch', 'fleck']
senticnet['speckled'] = [0, 0, -0.994, -0.915, '#scared', '#disgusting', -0.636, 'specked', 'flecked', 'stipple', 'dotted', 'bespeckle']
senticnet['spectacle'] = [0.026, -0.166, -0.05, 0.076, '#surprising', '#admirable', 0.073, 'monocle', 'eyeglass', 'contact_lens', 'lens', 'sheer']
senticnet['spectacular'] = [0, 0, 0, 0.098, '#admirable', '#admirable', 0.033, 'vista', 'perspective', 'scenic', 'panorama', 'view']
senticnet['spectator'] = [0.639, -0.919, 0, 0.718, '#surprising', '#admirable', 0.759, 'cheerer', 'gawker', 'percipient', 'rubberneck', 'starer']
senticnet['spectrum'] = [-0.073, 0.078, 0, 0.078, '#interesting', '#admirable', 0.028, 'red_blue', 'red_orange', 'green_yellow', 'hue_tint', 'yellow_green']
senticnet['speculate'] = [-0.823, 0, 0.98, -0.912, '#angry', '#disgusting', -0.905, 'formulate', 'expect', 'retrace', 'explicate', 'reconstruct']
senticnet['speculator'] = [-0.786, 0, 0.944, -0.511, '#sad', '#angry', -0.747, 'loser', 'gambler', 'mortal', 'better', 'bettor']
senticnet['speculum'] = [-0.024, 0, -0.083, -0.127, '#scared', '#disgusting', -0.078, 'cystoscope', 'scope_out_information', 'gastroscope', 'stethoscope', 'light_instrument']
senticnet['speech'] = [0, 0, 0, 0.13, '#admirable', '#admirable', 0.043, 'say', 'orate', 'spoken', 'verbal_communication', 'oration']
senticnet['speech_defect'] = [-0.786, 0, 0.96, -0.647, '#sad', '#angry', -0.798, 'upset', 'dysarthria', 'dysphonia', 'disorder', 'lallation']
senticnet['speech_disorder'] = [-0.516, 0, 0.822, -0.662, '#angry', '#disgusting', -0.667, 'upset', 'dysarthria', 'dysphonia', 'disorder', 'lallation']
senticnet['speech_part'] = [0, 0.085, -0.049, 0.222, '#interesting', '#admirable', 0.086, 'grammar_part', 'unit_language', 'retort', 'enunciation', 'written_language']
senticnet['speech_production'] = [0.945, -0.686, 0, 0.824, '#joyful', '#admirable', 0.818, 'whispering', 'voicelessness', 'whisper', 'susurration', 'speech']
senticnet['speechless'] = [-0.567, 0, 0.509, -0.832, '#sad', '#disgusting', -0.636, 'aphasic', 'aphonic', 'inarticulate', 'unarticulated', 'dumb']
senticnet['speed'] = [0, 0.119, 0, 0.16, '#interesting', '#admirable', 0.093, 'speedy', 'fast', 'velocity', 'quickness', 'locomotion']
senticnet['speed_boat'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'yacht', 'boat', 'sailboat', 'water_vehicle', 'ship']
senticnet['speed_up'] = [0.032, 0.261, -0.157, 0.198, '#interesting', '#admirable', 0.111, 'fast', 'arrive_destination', 'no_stop', 'take_action', 'gain_speed']
senticnet['speeding_ticket'] = [-0.317, -0.028, 0, -0.247, '#sad', '#disgusting', -0.179, 'pollution', 'screw_up', 'car_wreck', 'parking_ticket', 'feel_stressed']
senticnet['speedy'] = [0, 0.091, 0.031, 0.181, '#interesting', '#admirable', 0.08, 'quick_movement', 'fast', 'quickness', 'quick_motion', 'quick']
senticnet['spell'] = [-0.052, 0, -0.045, 0, '#sad', '#scared', -0.032, 'knack', 'scribble', 'mark_paper', 'record_information', 'use_pencil']
senticnet['spell_wrong'] = [-0.184, 0, 0, 0, '#sad', '#sad', -0.061, 'warm_color', 'make_mistake', 'color', 'secondary_color', 'primary_color']
senticnet['spend'] = [-0.062, 0.232, 0, 0.115, '#interesting', '#admirable', 0.095, 'bill_pay', 'owe_money', 'money', 'money_spend', 'give_cash']
senticnet['spend_a_lot_of_money'] = [-0.039, 0, 0, -0.052, '#sad', '#disgusting', -0.03, 'spend_much_money', 'comparison_shop', 'spend_money', 'window_shop', 'check_price']
senticnet['spend_family_time'] = [0, 0.736, 0, 0.919, '#interesting', '#admirable', 0.552, 'familial_relationship', 'spend_quality_time', 'family_relation', 'family_time', 'dad']
senticnet['spend_little_money'] = [-0.086, 0.118, 0.017, 0.105, '#interesting', '#admirable', 0.04, 'hold_card', 'pay_off', 'dumpster_dive', 'barter', 'make_offer']
senticnet['spend_lot'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'expensive', 'high_price', 'unaffordable', 'overprice', 'immoderate']
senticnet['spend_money'] = [-0.034, -0.016, 0.02, -0.034, '#sad', '#disgusting', -0.024, 'purchase_gift', 'buy_clothes', 'pay_cash', 'pay_credit_card', 'buy_milk']
senticnet['spend_much_money'] = [-0.086, 0, 0, -0.072, '#sad', '#disgusting', -0.053, 'spend_a_lot_of_money', 'window_shop', 'comparison_shop', 'check_price', 'make_payment']
senticnet['spend_quality_time'] = [0, 0.772, 0, 0.832, '#interesting', '#admirable', 0.535, 'familial_relationship', 'spend_family_time', 'family_relation', 'family_time', 'dad']
senticnet['spend_time'] = [0.958, 0, 0, 0, '#joyful', '#joyful', 0.319, 'waste_time', 'understand_culture', 'bored', 'enjoy_entertainment', 'learn_other_culture']
senticnet['spend_time_together'] = [0.084, 0.075, 0, 0.107, '#joyful', '#admirable', 0.089, 'play_on_grass', 'play_board_game', 'talk_oneself', 'become_adult', 'play_hide_seek']
senticnet['spend_time_with_child'] = [0.809, 0, 0, 0.791, '#joyful', '#admirable', 0.533, 'amuse', 'enjoyment', 'spend_time_with_friend', 'keep_child_occupy', 'entertainment']
senticnet['spend_time_with_friend'] = [0.897, 0.959, 0, 0, '#joyful', '#interesting', 0.619, 'friend', 'hang_out', 'party', 'fun', 'hang_out_with_friend']
senticnet['sperm'] = [0.038, 0.132, -0.083, 0.095, '#interesting', '#admirable', 0.061, 'baby_born', 'sexual_intercourse', 'pregnant', 'fuck', 'mate']
senticnet['sperm_bank'] = [0, 0.098, 0, 0, '#interesting', '#interesting', 0.033, 'bed', 'mattress', 'political_debate', 'seduce', 'bead']
senticnet['spherical'] = [0, 0.977, 0, 0.878, '#interesting', '#admirable', 0.618, 'seen_night_sky', 'round', 'fill_with_sand', 'round_orb', 'three_dimensions']
senticnet['spherical_shape'] = [0.034, -0.073, 0.068, 0.103, '#surprising', '#admirable', 0.047, 'use_sport', 'bouncy', 'round_object', 'orb', 'circular_object']
senticnet['spice_life'] = [0.399, 0.189, 0.01, 0.376, '#joyful', '#admirable', 0.318, 'taken_seriously', 'knowledgeable', 'complement', 'good_sense_of_humor', 'much_need']
senticnet['spiciness'] = [0.743, -0.508, 0, 0.959, '#joyful', '#admirable', 0.737, 'zest', 'sharpness', 'hotness', 'piquance', 'piquancy']
senticnet['spick_and_span'] = [0.986, 0, 0, 0, '#joyful', '#joyful', 0.329, 'personal_cleanliness', 'cleanness', 'wipe_up_spill', 'clean', 'clean_carpet']
senticnet['spicy'] = [0.076, 0, 0.037, 0.065, '#joyful', '#admirable', 0.035, 'serve_cold', 'tasty_good', 'tasty', 'sour', 'high_calorie']
senticnet['spicy_food'] = [0.889, 0, 0, 0.934, '#joyful', '#admirable', 0.608, 'able_eat', 'nourishment', 'replenish_energy', 'eat_pie', 'sustenance']
senticnet['spider'] = [0, -0.063, 0.097, -0.08, '#angry', '#disgusting', -0.038, 'moth', 'ant', 'mite', 'bed_bug', 'caterpillar']
senticnet['spider_flower'] = [-0.81, 0, 0.699, -0.526, '#sad', '#angry', -0.678, 'herb', 'cleome', 'spider_plant', 'stinking_clover', 'herbaceous_plant']
senticnet['spider_plant'] = [-0.81, 0, 0.699, -0.526, '#sad', '#angry', -0.678, 'herb', 'spider_flower', 'cleome', 'stinking_clover', 'herbaceous_plant']
senticnet['spiffy'] = [0, 0, -0.874, -0.763, '#scared', '#disgusting', -0.546, 'raffish', 'natty', 'dashing', 'dapper', 'jaunty']
senticnet['spike'] = [0.759, 0.8, 0, 0, '#joyful', '#interesting', 0.52, 'tack', 'foot_part', 'casual_shoes', 'gauntlet', 'pin']
senticnet['spikelet'] = [-0.849, 0, 0.987, -0.777, '#sad', '#angry', -0.871, 'thorn', 'sticker', 'pricker', 'prickle', 'glochid']
senticnet['spiky'] = [0, 0.795, 0, 0.719, '#interesting', '#admirable', 0.505, 'flora', 'large_breadbox', 'domesticate', 'live_organism', 'driven_person']
senticnet['spill'] = [-0.159, -0.051, -0.083, -0.125, '#sad', '#disgusting', -0.105, 'tongue', 'choke', 'no_long_hungry', 'bite_tongue', 'digest']
senticnet['spill_coffee'] = [0, -0.004, -0.057, -0.075, '#scared', '#disgusting', -0.043, 'stop_think', 'cry', 'cry_hard', 'fall_off_chair', 'thump']
senticnet['spill_food_clothes'] = [-0.076, 0, 0, -0.061, '#sad', '#disgusting', -0.046, 'eat_salad', 'drink_tea', 'talk_other', 'wind_watch', 'drink_milk']
senticnet['spill_milk'] = [0.888, 0.707, 0, 0, '#joyful', '#interesting', 0.532, 'drink_orange_juice', 'read_paper', 'drop_food', 'smell_food', 'choke']
senticnet['spill_over'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'flat', 'dirty_floor', 'bucket_overflow', 'float', 'spoil_wood_floor']
senticnet['spin'] = [0.038, 0, 0.031, 0.124, '#joyful', '#admirable', 0.044, 'rotate', 'rotate_movement', 'change_direction', 'move', 'go_around']
senticnet['spin_silk'] = [0, 0.081, 0.015, 0.052, '#interesting', '#admirable', 0.039, 'cotton', 'fabric_material', 'sheepskin', 'woven_fabric', 'woven_cloth']
senticnet['spin_thread'] = [0, 0.078, 0.014, 0.108, '#interesting', '#admirable', 0.057, 'fragrant', 'sexual', 'use_decoration', 'green', 'pink']
senticnet['spina_bifida'] = [-0.985, 0, 0.899, -0.732, '#sad', '#angry', -0.872, 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder', 'congenital_abnormality']
senticnet['spinal_curvature'] = [-0.942, 0, 0.87, -0.902, '#sad', '#disgusting', -0.905, 'lordosis', 'kyphosis', 'humpback', 'hunchback', 'abnormality']
senticnet['spiracle'] = [-0.935, 0, 0.607, -0.67, '#sad', '#disgusting', -0.737, 'blowhole', 'stigma', 'orifice', 'opening', 'porta']
senticnet['spiral'] = [0.112, -0.016, 0.057, 0.159, '#joyful', '#admirable', 0.077, 'rotation', 'curve', 'rotate', 'rotate_movement', 'swirl']
senticnet['spire'] = [0, 0.227, 0.025, 0.221, '#interesting', '#admirable', 0.141, 'steeple', 'catholic_church', 'chapel', 'christianity', 'altar']
senticnet['spirit'] = [0, 0.751, 0, 0.775, '#interesting', '#admirable', 0.509, 'ghost', 'soul', 'mind_control', 'angel', 'god']
senticnet['spirit_up'] = [0.759, -0.735, 0, 0.684, '#joyful', '#surprising', 0.726, 'enliven', 'liven', 'liven_up', 'invigorate', 'animate']
senticnet['spirited'] = [0.716, -0.57, 0, 0.681, '#joyful', '#admirable', 0.656, 'vibrant', 'vivacious', 'con_brio', 'lively', 'dashing']
senticnet['spiritedness'] = [0.811, -0.717, 0, 0.837, '#joyful', '#admirable', 0.788, 'chirpiness', 'spirit', 'sprightliness', 'liveliness', 'activity']
senticnet['spiritize'] = [0.968, -0.767, 0, 0.583, '#joyful', '#surprising', 0.773, 'riddle', 'diffuse', 'permeate', 'pervade', 'penetrate']
senticnet['spiritless'] = [-0.952, 0, 0.59, -0.677, '#sad', '#disgusting', -0.74, 'dispirited', 'heartless', 'apathetic', 'bloodless', 'listless']
senticnet['spiritlessness'] = [-0.778, 0, 0.5, -0.751, '#sad', '#disgusting', -0.676, 'apathy', 'indifference', 'passivity', 'inertia', 'inactiveness']
senticnet['spirits_of_wine'] = [-0.915, 0, 0.65, -0.594, '#sad', '#angry', -0.72, 'absolute_alcohol', 'ethyl_alcohol', 'denatured_alcohol', 'alcohol', 'plant_product']
senticnet['spiritual'] = [0.038, 0.337, -0.09, 0.32, '#interesting', '#admirable', 0.202, 'religious', 'faith', 'religious_purpose', 'religion', 'prayer']
senticnet['spirituality'] = [0.037, 0.293, 0, 0.269, '#interesting', '#admirable', 0.2, 'religious_purpose', 'prayer', 'judaism', 'christianity', 'religion']
senticnet['spironolactone'] = [-0.763, 0, 0.681, -0.578, '#sad', '#angry', -0.674, 'corticosteroid', 'corticoid', 'adrenal_cortical_steroid', 'antihypertensive', 'antihypertensive_drug']
senticnet['spirt'] = [-0.592, 0, 0.753, -0.549, '#sad', '#angry', -0.631, 'discharge', 'spray', 'spritz', 'outpouring', 'run']
senticnet['spit'] = [-0.837, 0, 0.87, -0.978, '#angry', '#disgusting', -0.895, 'precipitate', 'mizzle', 'shower_down', 'rain_down', 'patter']
senticnet['spite'] = [-0.028, 0.125, 0.672, -0.667, '#angry', '#disgusting', -0.414, 'venom', 'malice', 'offensive', 'animosity', 'despise']
senticnet['spiteful'] = [-0.031, 0.157, 0.698, -0.661, '#angry', '#disgusting', -0.411, 'vengefulness', 'vindictively', 'vengefully', 'revengefully', 'vindictive']
senticnet['spitefulness'] = [-0.041, 0.164, 0.685, -0.658, '#angry', '#disgusting', -0.407, 'maliciousness', 'maliciously', 'maleficence', 'malefic', 'malign']
senticnet['spitting_image'] = [-0.894, 0, 0.58, -0.723, '#sad', '#disgusting', -0.732, 'resemblance', 'comparison', 'equivalence', 'reflection', 'alikeness']
senticnet['splash'] = [0.817, 0, 0, 0.764, '#joyful', '#admirable', 0.527, 'wade', 'traveling_water', 'drown', 'catch_shark', 'catch_catfish']
senticnet['splash_water'] = [-0.023, -0.024, 0.076, -0.054, '#angry', '#disgusting', -0.043, 'wear_raincoat', 'wet', 'feel_cold', 'camp_out', 'carry_umbrella']
senticnet['splatter'] = [-0.879, 0, 0.682, -0.533, '#sad', '#angry', -0.698, 'swash', 'spatter', 'slosh_around', 'plash', 'splash']
senticnet['spleen'] = [-0.092, 0.124, 0.609, -0.609, '#angry', '#disgusting', -0.395, 'irascibility', 'short_temper', 'quick_temper', 'choleric', 'irascible']
senticnet['splendid'] = [0.919, 0, 0, 0.734, '#joyful', '#admirable', 0.551, 'splendiferous', 'glorious', 'excellent', 'resplendent', 'first-class']
senticnet['split'] = [0.927, 0.791, 0, 0, '#joyful', '#interesting', 0.573, 'separation', 'divide', 'division', 'slash', 'bagle']
senticnet['split_end'] = [0.892, 0.961, 0, 0, '#joyful', '#interesting', 0.618, 'late', 'get_dark', 'rainy_day', 'tardiness', 'house_look_better']
senticnet['split_up'] = [0.804, -0.951, 0, 0.813, '#surprising', '#admirable', 0.856, 'break', 'split', 'separate', 'part', 'dissociate']
senticnet['splodge'] = [0.991, -0.69, 0, 0.822, '#joyful', '#admirable', 0.834, 'spot', 'smirch', 'daub', 'smudge', 'blot']
senticnet['splotch'] = [0.87, -0.5, 0, 0.584, '#joyful', '#admirable', 0.651, 'spot', 'smirch', 'daub', 'smudge', 'blot']
senticnet['splurge'] = [-0.818, 0, 0.936, -0.579, '#sad', '#angry', -0.778, 'pedantry', 'bluster', 'ostentation', 'ritz', 'display']
senticnet['spoil'] = [0.713, 0.998, 0, 0, '#joyful', '#interesting', 0.57, 'kid', 'playtime', 'little_child', 'brat', 'child']
senticnet['spoil_food'] = [0, 0, 0, -0.725, '#disgusting', '#disgusting', -0.242, 'smelly_foot', 'cripple', 'influenza', 'chicken_pox', 'sexually_transmit_disease']
senticnet['spoil_wood_floor'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'flat', 'dirty_floor', 'spill_over', 'float', 'bucket_overflow']
senticnet['spoilage'] = [-0.088, -0.046, 0.023, -0.076, '#sad', '#disgusting', -0.047, 'tier', 'make_toast', 'house_smell_good', 'get_hot', 'bread_crumb']
senticnet['spoiling'] = [-0.931, 0, 0.997, -0.506, '#sad', '#angry', -0.811, 'decay', 'mildew', 'mold', 'mould', 'souring']
senticnet['spoilsport'] = [-0.65, 0, 0.87, -0.827, '#angry', '#disgusting', -0.782, 'worrier', 'fusspot', 'worrywart', 'unwelcome_person', 'killjoy']
senticnet['spoilt'] = [-0.622, 0, 0.863, -0.991, '#angry', '#disgusting', -0.825, 'destroyed', 'wrecked', 'impoverished', 'blighted', 'extinguished']
senticnet['spoke'] = [-0.034, -0.068, 0.052, 0.087, '#surprising', '#admirable', 0.023, 'wheel', 'two_wheels', 'gear', 'bumper', 'steer_wheel']
senticnet['spoken'] = [0, 0.779, 0, 0.737, '#interesting', '#admirable', 0.505, 'verbalize', 'speech', 'orate', 'verbal_communication', 'verbal']
senticnet['spoken_language'] = [0, -0.047, 0.021, 0.07, '#surprising', '#admirable', 0.032, 'talk', 'oration', 'talkative', 'voice_communication', 'make_call']
senticnet['sponge_up'] = [0.72, -0.764, 0, 0.695, '#joyful', '#surprising', 0.726, 'mop_up', 'blot', 'wipe_up', 'mop', 'suck_up']
senticnet['spontaneous'] = [0.98, 0, 0, 0.942, '#joyful', '#admirable', 0.641, 'natural', 'impulsive', 'instinctive', 'unprompted', 'easy']
senticnet['spook'] = [-0.165, -0.048, -0.315, 0, '#sad', '#scared', -0.144, 'cry', 'big_monster', 'shock', 'common_emotion', 'fear']
senticnet['spoon'] = [0.03, -0.05, 0, 0.059, '#surprising', '#admirable', 0.046, 'fork', 'hot_table', 'chopstick', 'bowl', 'saltshaker']
senticnet['spoon_feed'] = [0, -0.072, 0, 0, '#surprising', '#surprising', 0.024, 'feed', 'feed_baby', 'bake_bread', 'make_ice', 'bake_cookie']
senticnet['spoon_food'] = [-0.637, 0, 0.819, -0.997, '#angry', '#disgusting', -0.818, 'light_diet', 'soft_diet', 'diet', 'bland_diet', 'ulcer_diet']
senticnet['spoon_fork'] = [0.03, -0.05, 0, 0.059, '#surprising', '#admirable', 0.046, 'grease_trap', 'glass_front_cupboard', 'fork', 'spoon', 'utensil']
senticnet['sporadic'] = [-0.872, 0, 0.722, -0.579, '#sad', '#angry', -0.724, 'stray', 'spasmodic', 'unpredictable', 'isolated', 'irregular']
senticnet['sport_accident'] = [-0.937, 0, 0.643, -0.951, '#sad', '#disgusting', -0.844, 'fall_down', 'car_accident', 'stumble', 'accident', 'hurt_yourself']
senticnet['sport_activity'] = [0.057, -0.013, 0, 0.15, '#joyful', '#admirable', 0.073, 'human_motion', 'human_movement', 'water_activity', 'vigorous_activity', 'water_sport']
senticnet['sport_arena'] = [0.058, 0, 0, 0.088, '#joyful', '#admirable', 0.049, 'school_yard', 'fashion_show', 'art', 'football_stadium', 'exhibition']
senticnet['sport_ball'] = [0.908, 0.999, 0, 0, '#joyful', '#interesting', 0.636, 'toy_ball', 'sport_bat', 'toy_marble', 'toy_soldier', 'beanie_baby']
senticnet['sport_bat'] = [0.854, 0.871, 0, 0, '#joyful', '#interesting', 0.575, 'sport_ball', 'fielder', 'toy_ball', 'water_gun', 'toy_soldier']
senticnet['sport_competition'] = [0, 0, 0, 0.879, '#admirable', '#admirable', 0.293, 'competition', 'win_competition', 'race', 'match', 'championship']
senticnet['sport_equipment'] = [0.927, 0.869, 0, 0, '#joyful', '#interesting', 0.599, 'sport_ball', 'frisbee', 'toy_ball', 'toy_marble', 'baseball']
senticnet['sport_event'] = [0.025, 0.246, 0, 0.226, '#interesting', '#admirable', 0.166, 'game', 'disneyland', 'ballpark', 'hockey_game', 'hockey_rink']
senticnet['sport_game'] = [0, -0.088, 0.015, 0.053, '#surprising', '#admirable', 0.042, 'team_sport', 'violent_sport', 'type_of_sport', 'rough_sport', 'popular_sport_america']
senticnet['sport_goods_store'] = [0, 0.306, -0.053, 0.287, '#interesting', '#admirable', 0.18, 'luggage_compartment', 'toy_box', 'toy_store', 'girl_room', 'gym']
senticnet['sport_highlight'] = [0.026, 0.227, 0, 0.233, '#interesting', '#admirable', 0.162, 'best_moment', 'highlight', 'football_highlight', 'television_news', 'put_in_evidence']
senticnet['sport_person'] = [0, -0.075, 0.024, 0.081, '#surprising', '#admirable', 0.044, 'popular_sport_america', 'team_sport', 'american_sport', 'rough_sport', 'popular_game']
senticnet['sport_play'] = [0.998, 0.946, 0, 0, '#joyful', '#interesting', 0.648, 'excite_game', 'ball_sport', 'team_sport', 'rough_game', 'fun_sport']
senticnet['sport_score'] = [0.991, 0, 0, 0, '#joyful', '#joyful', 0.33, 'sharp_end', 'sharp_corner', 'indicate', 'geometric_object', 'full_stop']
senticnet['sport_stadium'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'train_station', 'government_office', 'cable_car', 'baggage_compartment', 'terminal']
senticnet['sport_store'] = [0.035, -0.015, 0.009, 0.063, '#joyful', '#admirable', 0.035, 'daycare', 'gym', 'soccer_game', 'gym_locker', 'football_stadium']
senticnet['sport_stuff'] = [0.059, -0.049, 0.014, 0, '#joyful', '#surprising', 0.031, 'sport_equipment', 'golf_bag', 'golf', 'sport_store', 'bag']
senticnet['sport_team'] = [0.046, 0.125, 0.022, 0.184, '#interesting', '#admirable', 0.111, 'direct_person', 'stalin', 'water_vehicle', 'sail_sea', 'seagoing_vessel']
senticnet['sporting_goods'] = [0.52, -0.972, 0, 0.916, '#surprising', '#admirable', 0.803, 'sports_equipment', 'weight', 'mat', 'free_weight', 'exercising_weight']
senticnet['sporting_lady'] = [-0.602, 0, 0.994, -0.783, '#angry', '#disgusting', -0.793, 'slattern', 'camp_follower', 'call_girl', 'comfort_woman', 'ianfu']
senticnet['sports_car'] = [-0.792, 0, 0.695, -0.871, '#sad', '#disgusting', -0.786, 'car', 'auto', 'automobile', 'machine', 'motorcar']
senticnet['sports_expert'] = [0, 0.109, -0.102, 0.235, '#interesting', '#admirable', 0.081, 'sport', 'extreme_sport', 'adrenaline', 'extreme', 'skydiving']
senticnet['sports_fan'] = [0.747, -0.562, 0, 0.683, '#joyful', '#admirable', 0.664, 'enthusiast', 'partizan', 'partisan', 'aficionado', 'railbird']
senticnet['sportswear'] = [-0.852, 0, 0.553, -0.632, '#sad', '#disgusting', -0.679, 'attire', 'garb', 'dress', 'gym_suit', 'running_suit']
senticnet['sporty_guy'] = [0, 0.792, 0, 0.747, '#interesting', '#admirable', 0.513, 'run_fast', 'train_daily', 'run_lot', 'train_muscle', 'exercise']
senticnet['sporty_person'] = [0.769, 0, 0, 0, '#joyful', '#joyful', 0.256, 'health', 'become_strong', 'feel_better', 'better_health', 'increase_muscle_mass']
senticnet['spot'] = [-0.043, 0.146, 0, 0.152, '#interesting', '#admirable', 0.085, 'woolly_animal', 'same_again', 'pure', 'nocturnal', 'big_person']
senticnet['spot_pass'] = [-0.92, 0, 0.835, -0.682, '#sad', '#angry', -0.812, 'aerial', 'lateral', 'forward_pass', 'lateral_pass', 'passing']
senticnet['spot_prey'] = [-0.103, 0, 0, -0.1, '#sad', '#disgusting', -0.068, 'spread_disease', 'go_stall', 'see_night', 'pet', 'hunt_food']
senticnet['spot_promote'] = [0.897, -0.929, 0, 0.645, '#joyful', '#surprising', 0.824, 'kick_upstairs', 'promote', 'elevate', 'upgrade', 'advance']
senticnet['spotless'] = [0, 0, -0.866, -0.738, '#scared', '#disgusting', -0.535, 'spic-and-span', 'spick-and-span', 'spic', 'immaculate', 'speckless']
senticnet['spotted'] = [0, 0, -0.786, -0.872, '#scared', '#disgusting', -0.553, 'spy', 'recognise', 'located', 'recognize', 'descry']
senticnet['spotted_barramundi'] = [0.565, -0.697, 0, 0.787, '#surprising', '#admirable', 0.683, 'species', 'saratoga', 'fish_species', 'spotted_bonytongue', 'northern_barramundi']
senticnet['spotted_bonytongue'] = [0.565, -0.697, 0, 0.787, '#surprising', '#admirable', 0.683, 'species', 'saratoga', 'spotted_barramundi', 'fish_species', 'northern_barramundi']
senticnet['spotted_fever'] = [-0.738, 0, 0.599, -0.96, '#sad', '#disgusting', -0.766, 'rickettsial_disease', 'trench_fever', 'rickettsialpox', 'typhus', 'typhus_fever']
senticnet['spousal_relationship'] = [-0.875, 0, 0.524, -0.762, '#sad', '#disgusting', -0.72, 'marriage', 'matrimony', 'union', 'bigamy', 'wedlock']
senticnet['spouse'] = [0.112, 0.262, -0.164, 0.23, '#interesting', '#admirable', 0.147, 'husband', 'relationship', 'wife', 'marriage', 'male_child']
senticnet['sprain'] = [-0.837, 0, 0.509, -0.84, '#sad', '#disgusting', -0.729, 'wrench', 'injury', 'harm', 'hurt', 'trauma']
senticnet['sprain_ankle'] = [0, 0, -0.912, 0, '#scared', '#scared', -0.304, 'out_breath', 'get_injured', 'pull_muscle', 'breahard', 'blister_foot']
senticnet['spray_paint_grafitti'] = [0.983, 0, 0, 0, '#joyful', '#joyful', 0.328, 'sex', 'watch_porn', 'eat_pussy', 'masturbation', 'beat_off']
senticnet['spread'] = [0.849, -0.547, 0, 0.543, '#joyful', '#surprising', 0.646, 'diffusion', 'dispersion', 'scattering', 'invasion', 'irradiation']
senticnet['spread_butter'] = [-0.095, -0.085, 0.039, -0.182, '#sad', '#disgusting', -0.077, 'cut_food', 'lacerate', 'pierce', 'chop_wood', 'slash']
senticnet['spread_disease'] = [0, -0.041, 0.063, -0.14, '#angry', '#disgusting', -0.054, 'fly_high', 'orgasm', 'try_forget', 'spot_prey', 'buzz']
senticnet['spread_germ'] = [0, 0, 0, -0.959, '#disgusting', '#disgusting', -0.32, 'feel_comfortable', 'age_prematurely', 'use_thermometer', 'feel_warm', 'addiction']
senticnet['spread_happiness'] = [0.986, 0, 0, 0.828, '#joyful', '#admirable', 0.605, 'get_happy', 'comedian', 'pleasure', 'give_pleasure', 'feel_different']
senticnet['spread_idea'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'make_money', 'explain_idea', 'ego_boost', 'get_published', 'promote']
senticnet['spread_information'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'wander_around', 'organize_information', 'transfer_information', 'process_data', 'communicate_with_others']
senticnet['spread_knowledge'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'spread_information', 'spread_news', 'get_information', 'expand_knowledge', 'knowledge']
senticnet['spread_love'] = [0, 0.095, -0.054, 0.132, '#interesting', '#admirable', 0.058, 'purchase_goods', 'buy', 'buy_cheap_item', 'purchase_gift', 'buy_gum']
senticnet['spread_meme'] = [0.072, -0.02, 0, 0, '#joyful', '#surprising', 0.031, 'stay_touch', 'communicate_friend', 'send_information', 'give_comfort', 'communicate_thought']
senticnet['spread_news'] = [0.551, 0.914, 0, 0.817, '#interesting', '#admirable', 0.761, 'report_event', 'pass_information', 'review_book', 'tell_information', 'offer_opinion']
senticnet['spread_out'] = [-0.1, 0, 0, 0, '#sad', '#sad', -0.033, 'deflate', 'read_cover', 'look_behind', 'upgrade', 'scan']
senticnet['spread_seed'] = [0.107, 0.098, 0, 0.135, '#joyful', '#admirable', 0.113, 'go_green', 'respect_nature', 'save_water', 'go_on_foot', 'reduce_pollution']
senticnet['spread_wing'] = [-0.097, 0, -0.053, -0.051, '#sad', '#scared', -0.067, 'fight_other', 'die_only_once', 'honor_parent', 'eat_potato', 'bug_person']
senticnet['spread_word'] = [0.211, 0.114, 0, 0.262, '#joyful', '#admirable', 0.196, 'others_understand', 'a_lot', 'touch_heart', 'express_opinion', 'make_progress']
senticnet['spreadable'] = [0.033, 0, 0, 0.203, '#joyful', '#admirable', 0.079, 'thick_liquid', 'edible_human', 'liquid_substance', 'round_fruit', 'descriptive']
senticnet['sprightliness'] = [0.546, -0.732, 0, 0.583, '#surprising', '#admirable', 0.62, 'irrepressibility', 'spiritedness', 'brio', 'bright', 'delicacy']
senticnet['spring_action'] = [-0.122, 0, -0.047, -0.05, '#sad', '#disgusting', -0.073, 'sun_oneself', 'throw_fit', 'watch_d', 'laugh_clown', 'battle_illness']
senticnet['spring_leak'] = [-0.027, 0.206, -0.102, 0.291, '#interesting', '#admirable', 0.123, 'carry', 'raise_up', 'haul', 'tote', 'lift_object']
senticnet['spring_up'] = [-0.065, 0, -0.053, 0, '#sad', '#scared', -0.039, 'hold_two_together', 'float_through_air', 'travel_through_space', 'spring', 'fly_around']
senticnet['sprite'] = [0.071, 0, 0, 0, '#joyful', '#joyful', 0.024, 'soda', 'coke', 'cola', 'soft_drink', 'cool_drink']
senticnet['spritz'] = [-0.592, 0, 0.753, -0.549, '#sad', '#angry', -0.631, 'discharge', 'spray', 'spirt', 'outpouring', 'run']
senticnet['spurious'] = [0, 0, -0.826, -0.903, '#scared', '#disgusting', -0.576, 'misbegotten', 'inauthentic', 'misbegot', 'bastardly', 'specious']
senticnet['spurn'] = [-0.664, 0, 0.82, -0.792, '#angry', '#disgusting', -0.759, 'snub', 'rebuff', 'repel', 'refuse', 'decline']
senticnet['spurt'] = [-0.762, 0, 0.794, -0.915, '#angry', '#disgusting', -0.824, 'discharge', 'spray', 'spritz', 'outpouring', 'run']
senticnet['spy'] = [0, 0, 0, -0.914, '#disgusting', '#disgusting', -0.305, 'inventor', 'finish_college', 'cheat', 'hard_worker', 'biological_machine']
senticnet['squabble'] = [-0.637, 0, 0.982, -0.881, '#angry', '#disgusting', -0.833, 'wrangle', 'dustup', 'quarrel', 'row', 'word']
senticnet['squalid'] = [-0.786, 0, 0.837, 0, '#sad', '#angry', -0.541, 'flyblown', 'seamy', 'seedy', 'sordid', 'sleazy']
senticnet['squall'] = [-0.763, 0, 0.516, -0.857, '#sad', '#disgusting', -0.712, 'skreigh', 'call', 'cry', 'yell', 'scream']
senticnet['squanderer'] = [0.878, -0.676, 0, 0.951, '#joyful', '#admirable', 0.835, 'spendthrift', 'waster', 'wastrel', 'spender', 'scattergood']
senticnet['square'] = [0, 0.789, 0, 0.897, '#interesting', '#admirable', 0.562, 'rectangle', 'four_sides', 'rhombus', 'cube', 'four_corners']
senticnet['square_dance'] = [0.81, 0, 0, 0.921, '#joyful', '#admirable', 0.577, 'form_of_music', 'style_music', 'good_music', 'music', 'beautiful_music']
senticnet['square_shape'] = [0, 0, 0, 0.092, '#admirable', '#admirable', 0.031, 'shape', 'inside_house', 'house_part', 'four_walls', 'house_area']
senticnet['squash'] = [-0.562, 0, 0.696, -0.964, '#angry', '#disgusting', -0.741, 'winter_squash', 'acorn_winter_squash', 'hubbard_winter_squash', 'turban_winter_squash', 'butternut_winter_squash']
senticnet['squash_bug'] = [-0.037, -0.097, 0.111, -0.206, '#angry', '#disgusting', -0.086, 'mole_cricket', 'gypsy_moth', 'cucumber_beetle', 'japanese_beetle', 'mosquito']
senticnet['squash_court'] = [0.024, 0.152, -0.065, 0.236, '#interesting', '#admirable', 0.116, 'basketball_court', 'play_sport', 'tennis_game', 'playground_equipment', 'gymnasium']
senticnet['squeak'] = [-0.177, -0.049, 0.035, -0.081, '#sad', '#disgusting', -0.081, 'bad_music', 'annoy_sound', 'high_music_note', 'bang', 'loud']
senticnet['squeak_by'] = [-0.562, 0, 0.962, -0.501, '#sad', '#angry', -0.675, 'manage', 'make_out', 'cope', 'get_by', 'make_do']
senticnet['squealer'] = [-0.735, 0, 0.946, -0.599, '#sad', '#angry', -0.76, 'fink', 'snitch', 'snitcher', 'sneak', 'stoolpigeon']
senticnet['squeeze'] = [0, 0.78, 0, 0.967, '#interesting', '#admirable', 0.582, 'choose_color', 'charge_credit_card', 'sit_toilet', 'ship_goods', 'group_object']
senticnet['squeeze_by'] = [-0.948, 0, 0.899, -0.564, '#sad', '#angry', -0.804, 'manage', 'make_out', 'cope', 'get_by', 'make_do']
senticnet['squeeze_out'] = [-0.534, 0, 0.825, -0.769, '#angry', '#disgusting', -0.709, 'displace', 'fire', 'give_notice', 'can', 'dismiss']
senticnet['squelched'] = [-0.725, 0, 0.728, -0.5, '#sad', '#angry', -0.651, 'quelled', 'suppressed', 'burked', 'quenched', 'unreleased']
senticnet['squib_bomb'] = [-0.968, 0, 0.394, -0.908, '#sad', '#disgusting', -0.757, 'explosion', 'get_hurt', 'blow_up', 'detonate', 'get_bomb']
senticnet['squiggle'] = [-0.842, 0, 0.579, -0.747, '#sad', '#disgusting', -0.723, 'cacography', 'hand', 'chicken_scratch', 'handwriting', 'script']
senticnet['squint'] = [-0.898, 0, 0.709, -0.641, '#sad', '#angry', -0.749, 'divergent_strabismus', 'exotropia', 'walleye', 'abnormality', 'abnormalcy']
senticnet['squire'] = [-0.14, 0.104, -0.232, 0.081, '#sad', '#scared', -0.062, 'samurai', 'knight', 'private', 'high_rank', 'general']
senticnet['squirrel'] = [0, 0, -0.073, 0, '#scared', '#scared', -0.024, 'nymph', 'mole', 'nightly_ritual', 'rabbit', 'impairment_person']
senticnet['stab'] = [-0.16, -0.073, -0.073, -0.214, '#sad', '#disgusting', -0.125, 'cause_injury', 'hurt_person', 'maim', 'elephant_sit_chest', 'parry']
senticnet['stab_knife'] = [0.73, 0.994, 0, 0, '#joyful', '#interesting', 0.575, 'feel_remorse', 'imprisonment', 'strangle', 'hide_evidence', 'feel_anger']
senticnet['stab_to_death'] = [-1.0, 0, 0.346, -0.978, '#sad', '#disgusting', -0.775, 'kill', 'murder', 'death', 'kill_person', 'kill_someone']
senticnet['stability'] = [-0.026, 0, -0.064, 0, '#sad', '#scared', -0.03, 'run_lot', 'ride_car', 'chew_bone', 'play_human', 'play_fetch']
senticnet['stabilize'] = [0.04, -0.044, 0.152, -0.063, '#angry', '#disgusting', -0.044, 'stable', 'immobile', 'steady', 'settled', 'stationary']
senticnet['stable'] = [0.034, 0, 0, 0.064, '#joyful', '#admirable', 0.033, 'barn', 'graze_field', 'steady', 'barn_field', 'farmyard']
senticnet['stack'] = [0, 0, 0, 0.16, '#admirable', '#admirable', 0.053, 'make_fruit', 'layer', 'soft_sweet', 'bake_goods', 'cover_ice']
senticnet['stacking_game'] = [0.081, 0.095, 0, 0, '#joyful', '#interesting', 0.059, 'children_toy', 'build_tower_out_toy_block', 'play', 'children_funtime', 'playroom']
senticnet['stadium'] = [0.079, -0.107, 0.046, 0, '#joyful', '#surprising', 0.047, 'arena', 'auditorium', 'television_station', 'music_hall', 'movie_theater']
senticnet['stadium_stand'] = [0.036, -0.033, 0, 0, '#joyful', '#surprising', 0.023, 'bleacher', 'stadium', 'female_television_connector', 'speaker', 'goalie']
senticnet['staff'] = [0.12, -0.123, 0, 0.106, '#joyful', '#surprising', 0.116, 'metal_stick', 'bart', 'club', 'association', 'wand']
senticnet['stage'] = [0.964, 0.972, 0, 0, '#joyful', '#interesting', 0.645, 'thespian', 'performance', 'drama', 'performer', 'actor']
senticnet['stage_border'] = [0, 0.117, -0.077, 0.094, '#interesting', '#admirable', 0.045, 'balcony', 'row_seat', 'stage_entrance', 'theater_seat', 'theater_box']
senticnet['stage_curtain'] = [0.881, 0.928, 0, 0, '#joyful', '#interesting', 0.603, 'satire', 'game_toy', 'new_movie', 'thespian', 'open_night']
senticnet['stage_dancing'] = [-0.954, 0, 0.992, -0.633, '#sad', '#angry', -0.86, 'interpretive_dance', 'interpretive_dancing', 'interpretative_dance', 'interpretative_dancing', 'modern_dance']
senticnet['stage_door'] = [0, 0.117, -0.077, 0.094, '#interesting', '#admirable', 0.045, 'curtain', 'balcony', 'backdrop', 'stage_border', 'row_seat']
senticnet['stage_entrance'] = [0, 0.117, -0.077, 0.094, '#interesting', '#admirable', 0.045, 'stage_border', 'row_seat', 'balcony', 'theater_seat', 'theater_box']
senticnet['stage_fright'] = [-0.403, 0.267, -0.173, -0.281, '#sad', '#disgusting', -0.197, 'hysteria', 'nervous', 'uneasiness', 'anxious', 'hopeless']
senticnet['stage_play'] = [0, 0.711, 0, 0.892, '#interesting', '#admirable', 0.534, 'drama', 'role_play', 'play_part', 'part_of_play', 'present_play']
senticnet['stage_production'] = [0.044, -0.085, 0, -0.028, '#joyful', '#surprising', 0.034, 'stage_show', 'child_game', 'fool_around', 'kid_activity', 'fun_activity']
senticnet['stage_show'] = [0.044, -0.085, 0, -0.028, '#joyful', '#surprising', 0.034, 'stage_production', 'child_game', 'fool_around', 'kid_activity', 'fun_activity']
senticnet['stagger'] = [-0.116, 0, -0.087, -0.121, '#sad', '#disgusting', -0.108, 'run_out_booze', 'hit_car', 'vomit', 'cross_bridge', 'lower_standard']
senticnet['staggering'] = [0.044, -0.662, 0, 0.362, '#surprising', '#admirable', 0.356, 'astounding', 'stupefying', 'astonishing', 'bewilder', 'shocking']
senticnet['staginess'] = [-0.562, 0, 0.505, -0.953, '#sad', '#disgusting', -0.673, 'unnaturalness', 'pretence', 'pretension', 'artificiality', 'theatricality']
senticnet['stagnancy'] = [-0.657, 0, 0.793, -0.817, '#angry', '#disgusting', -0.756, 'halt', 'extinction', 'inactiveness', 'stagnation', 'stasis']
senticnet['stagnation'] = [-0.657, 0, 0.793, -0.817, '#angry', '#disgusting', -0.756, 'halt', 'extinction', 'stagnancy', 'inactiveness', 'stasis']
senticnet['stain'] = [0, -0.018, 0.046, -0.065, '#angry', '#disgusting', -0.031, 'varnish', 'brush', 'dye', 'pigment', 'canvas']
senticnet['stain_clothes'] = [0, -0.038, -0.065, -0.12, '#scared', '#disgusting', -0.049, 'grow_yard', 'burn', 'char', 'stain', 'dirty']
senticnet['stain_glass'] = [-0.045, 0.18, 0, 0.215, '#interesting', '#admirable', 0.117, 'see_out', 'house_open', 'color_glass', 'open_close', 'look_out']
senticnet['stained'] = [0, 0, -0.991, -0.925, '#scared', '#disgusting', -0.639, 'varnished', 'tarnish', 'maculate', 'sully', 'defile']
senticnet['stainless_steel'] = [0.707, 0, 0, 0.783, '#joyful', '#admirable', 0.497, 'spanner', 'gold', 'strong_material', 'platinum', 'heavy_element']
senticnet['stair'] = [0, 0, 0.095, 0, '#angry', '#angry', -0.032, 'build_part', 'flat', 'inanimate_object', 'large_rock', 'hard_surface']
senticnet['stair_down'] = [0.956, 0, 0, 0.8, '#joyful', '#admirable', 0.585, 'master_control', 'christian_fundamentalist', 'master', 'stair_rail', 'control']
senticnet['stair_rail'] = [0.859, 0.917, 0, 0, '#joyful', '#interesting', 0.592, 'fire_hydrant', 'fire_extinguisher', 'christian_fundamentalist', 'extinguisher', 'reception_desk']
senticnet['staircase'] = [-0.068, 0, 0, 0, '#sad', '#sad', -0.023, 'picture_scene', 'take_photograph', 'paint_ceiling', 'frame_picture', 'climb_ladder']
senticnet['stake'] = [0.034, 0.111, -0.094, 0.148, '#interesting', '#admirable', 0.066, 'ant_hill', 'hike_trail', 'tress', 'fallen_leaf', 'oak']
senticnet['stakeholder'] = [-0.902, 0, 0.859, -0.958, '#sad', '#disgusting', -0.906, 'mortal', 'neutral', 'person', 'individual', 'someone']
senticnet['stalk'] = [-0.053, 0, 0.04, -0.05, '#sad', '#disgusting', -0.048, 'farm_food', 'grown_food', 'edible_plant', 'farm_plant', 'farm_vegetable']
senticnet['stalker'] = [-0.752, 0.288, -0.434, -0.058, '#sad', '#scared', -0.319, 'addicted', 'obsessed_love', 'addiction', 'obsession', 'weird']
senticnet['stalwart'] = [-0.532, 0, 0.798, -0.73, '#angry', '#disgusting', -0.687, 'husky', 'hardy', 'sturdy', 'chesty', 'robust']
senticnet['stammer'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'come_across', 'tripped_over', 'lose_balance', 'stumble', 'stutter']
senticnet['stamp_battery'] = [-0.98, 0, 0.521, -0.773, '#sad', '#disgusting', -0.758, 'battery', 'stamp_mill', 'quartz_battery', 'quartz_mill', 'factory']
senticnet['stamp_mill'] = [-0.98, 0, 0.521, -0.773, '#sad', '#disgusting', -0.758, 'battery', 'stamp_battery', 'quartz_battery', 'quartz_mill', 'factory']
senticnet['stamp_pad'] = [0.023, -0.056, 0.063, -0.087, '#angry', '#disgusting', -0.024, 'intern', 'memo_pad', 'pen', 'paper_punch', 'paper_clip']
senticnet['stamping_mill'] = [-0.78, 0, 0.699, -0.808, '#sad', '#disgusting', -0.762, 'battery', 'stamp_battery', 'quartz_battery', 'quartz_mill', 'factory']
senticnet['stance'] = [0, 0.784, 0, 0.995, '#interesting', '#admirable', 0.593, 'line_place', 'placement', 'replace', 'place', 'position']
senticnet['stand_alone'] = [0.891, 0.978, 0, 0, '#joyful', '#interesting', 0.623, 'deal_card_player', 'forward_email', 'bridge_difference', 'explain_everything', 'position_furniture']
senticnet['stand_around'] = [0.822, 0.934, 0, 0, '#joyful', '#interesting', 0.585, 'waste_time', 'check_time', 'wait_person', 'watch_other_person', 'get_tired']
senticnet['stand_behind'] = [0, 0.919, 0, 0.968, '#interesting', '#admirable', 0.629, 'find_line_stand', 'see_how_long_line', 'find_line', 'find_end_line', 'wait_patiently']
senticnet['stand_fast'] = [-0.733, 0, 0.835, -0.576, '#sad', '#angry', -0.715, 'stand_pat', 'hold_firm', 'insist', 'maintain', 'stand_firm']
senticnet['stand_field'] = [0.064, 0.08, 0, 0.151, '#interesting', '#admirable', 0.098, 'driven_person', 'hairy', 'cute', 'stand', 'smart_animal']
senticnet['stand_firm'] = [-0.571, 0, 0.612, -0.97, '#angry', '#disgusting', -0.718, 'hold_off', 'defy', 'withstand', 'hold_up', 'fight']
senticnet['stand_in_line'] = [0, 0, 0, -0.11, '#disgusting', '#disgusting', -0.037, 'stand_queue', 'wait_line', 'get_line', 'carve_niche', 'wait_turn']
senticnet['stand_out'] = [0.082, -0.084, 0, 0, '#joyful', '#surprising', 0.055, 'express_oneself', 'go_public', 'sex_same_gender', 'provocateur', 'interview_day']
senticnet['stand_pat'] = [-0.733, 0, 0.835, -0.576, '#sad', '#angry', -0.715, 'insist', 'hold_firm', 'stand_fast', 'maintain', 'stand_firm']
senticnet['stand_queue'] = [0, 0, 0, -0.101, '#disgusting', '#disgusting', -0.034, 'wait_line', 'stand_in_line', 'carve_niche', 'get_line', 'wait_turn']
senticnet['stand_still'] = [0, 0.915, 0, 0.941, '#interesting', '#admirable', 0.619, 'long_last', 'roll_over', 'stretch_out', 'weather_storm', 'near_destination']
senticnet['stand_up'] = [-0.028, -0.021, 0.062, -0.105, '#angry', '#disgusting', -0.058, 'jump_up_down', 'tie_shoelace', 'jump_rope', 'hike', 'skate']
senticnet['stand_upon'] = [0.814, 0.869, 0, 0, '#joyful', '#interesting', 0.561, 'walk_upon', 'bend_leg', 'stand', 'keep_foot_warm', 'lower_body']
senticnet['standard'] = [0.026, 0.299, -0.114, 0.257, '#interesting', '#admirable', 0.156, 'character_trait', 'usual', 'characteristic', 'reliable', 'axiom']
senticnet['standard_candle'] = [-0.639, 0, 0.897, -0.915, '#angry', '#disgusting', -0.817, 'cd-rom', 'international_candle', 'candle', 'candela', 'candlepower_unit']
senticnet['standardize'] = [-0.91, 0, 0.637, -0.598, '#sad', '#angry', -0.715, 'gauge', 'govern', 'regulate', 'regularize', 'order']
senticnet['standing'] = [0.829, -0.826, 0, 0.986, '#joyful', '#admirable', 0.88, 'ranking', 'importance', 'honor', 'laurels', 'prominence']
senticnet['stanza'] = [0, 0.8, 0, 0.934, '#interesting', '#admirable', 0.578, 'like_poetry', 'refrain', 'song_lyric', 'verse', 'rhyme']
senticnet['staple'] = [0, -0.049, 0.078, -0.063, '#angry', '#disgusting', -0.031, 'labeler', 'paper_fastener', 'paper_clip', 'scrap_paper', 'stapler']
senticnet['staple_food'] = [0.088, 0.149, 0, 0.107, '#interesting', '#admirable', 0.115, 'food', 'grain', 'starchy_food', 'cereal', 'yeast']
senticnet['staple_remover'] = [0.044, -0.026, 0, 0, '#joyful', '#surprising', 0.023, 'sheet_paper', 'piece_of_paper', 'paperwork', 'board', 'whiteboard']
senticnet['stapler'] = [0, -0.046, 0.068, -0.066, '#angry', '#disgusting', -0.029, 'side_chair', 'box_tissue', 'tape_dispenser', 'box', 'ergonomic_chair']
senticnet['star'] = [0.977, -0.934, 0, 0.583, '#joyful', '#surprising', 0.831, 'giant', 'variable', 'supernova', 'supergiant', 'binary_star']
senticnet['star_anise'] = [0.95, 0, 0, 0.78, '#joyful', '#admirable', 0.577, 'fruit_tree', 'baby_flower', 'carpel', 'strawberry', 'fig']
senticnet['star_film'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'star_movie', 'win_award', 'present_award', 'recite_poem', 'knock_door']
senticnet['star_movie'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'present_award', 'put_costume', 'star_film', 'recite_poem', 'win_award']
senticnet['star_planet'] = [0, 0.747, 0, 0.998, '#interesting', '#admirable', 0.582, 'heavenly_body', 'around_earth', 'celestial_body', 'limitless', 'nothingness']
senticnet['star_stripe'] = [0, 0.077, 0, 0.091, '#interesting', '#admirable', 0.056, 'banner', 'infrastructure', 'emblem', 'logo', 'symbol']
senticnet['star_wars'] = [0, 0.222, -0.148, 0.223, '#interesting', '#admirable', 0.099, 'form_government', 'political_system', 'domain', 'government_person', 'control']
senticnet['starchy_food'] = [0.026, 0.08, 0.043, 0.064, '#interesting', '#admirable', 0.042, 'eat_rice', 'white_brown', 'asian', 'indian_food', 'staple_food']
senticnet['stardom'] = [0, 0.793, 0, 0.91, '#interesting', '#admirable', 0.568, 'superstar', 'vip', 'accomplishment', 'performance', 'concert']
senticnet['stare'] = [0, 0, 0, -0.825, '#disgusting', '#disgusting', -0.275, 'leg_cramp', 'become_tired', 'fatigue', 'sore_foot', 'tiredness']
senticnet['stare_off_space'] = [0, 0.843, 0, 0.859, '#interesting', '#admirable', 0.567, 'say_aha', 'think_past', 'scratch_head', 'brain_storm', 'come_conclusion']
senticnet['stare_sun'] = [0.851, 0.904, 0, 0, '#joyful', '#interesting', 0.585, 'gyroscope', 'lose', 'ball_bounce', 'bicycle_tire', 'tire']
senticnet['starer'] = [0.728, -0.699, 0, 0.757, '#joyful', '#admirable', 0.728, 'looker', 'spectator', 'viewer', 'watcher', 'witness']
senticnet['starfish'] = [0, 0, -0.076, 0, '#scared', '#scared', -0.025, 'many_fishes', 'seahorse', 'porpoise', 'plankton', 'sea_wee']
senticnet['stargazer'] = [-0.644, 0, 0.524, -0.598, '#sad', '#disgusting', -0.589, 'bum', 'dreamer', 'daydreamer', 'escapist', 'wishful_thinker']
senticnet['staring'] = [-0.932, 0, 0.096, -0.929, '#sad', '#disgusting', -0.652, 'fear', 'look_at_fearfully', 'afraid_of', 'threat', 'dangerous']
senticnet['stark'] = [0, 0, -0.925, -0.7, '#scared', '#disgusting', -0.542, 'blunt', 'stern', 'crude', 'austere', 'severe']
senticnet['start'] = [-0.041, 0.228, -0.104, 0.238, '#interesting', '#admirable', 0.107, 'start_off', 'finish', 'begin', 'tow', 'come']
senticnet['start_adventure'] = [0, 0.276, -0.138, 0.309, '#interesting', '#admirable', 0.149, 'end_point', 'start', 'new_chapter', 'inclusion', 'commence']
senticnet['start_business'] = [-0.075, 0.228, 0.019, 0.089, '#interesting', '#admirable', 0.074, 'throw_party', 'business', 'start_up', 'take_over_world', 'invest_money']
senticnet['start_car'] = [-0.08, -0.01, 0, -0.043, '#sad', '#disgusting', -0.038, 'push_limit', 'fly_plane', 'plan_day', 'rush_work', 'travel_work']
senticnet['start_car_engine'] = [0, 0.757, 0, 0.811, '#interesting', '#admirable', 0.523, 'find_car_key', 'car', 'drive_license', 'car_key', 'transportation']
senticnet['start_card_game'] = [0.822, 0.837, 0, 0, '#joyful', '#interesting', 0.553, 'win', 'play_game', 'play_card', 'shuffle_card_machine', 'shuffle_card']
senticnet['start_college'] = [0.087, 0.248, -0.194, 0.31, '#interesting', '#admirable', 0.15, 'enroll', 'enroll_school', 'enroll_class', 'pay_tuition', 'matriculate']
senticnet['start_computer'] = [-0.041, 0.228, -0.104, 0.238, '#interesting', '#admirable', 0.107, 'start', 'computer', 'surf_internet', 'check_mail', 'use_computer']
senticnet['start_conversation'] = [0.175, -0.031, 0, 0, '#joyful', '#surprising', 0.069, 'hump_leg', 'talk_person', 'become_friend', 'talk_friend', 'chat']
senticnet['start_end'] = [0.044, 0, 0, 0.206, '#joyful', '#admirable', 0.083, 'begin_end', 'omega', 'regularly', 'book_content', 'vocabulary']
senticnet['start_engine'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'use_car', 'burn_gasoline', 'steer_car', 'turn_ignition', 'put_gear']
senticnet['start_family'] = [0, 0.863, 0, 0.739, '#interesting', '#admirable', 0.534, 'reproduce', 'procreate', 'copulate', 'cause_cold', 'kiss']
senticnet['start_fight'] = [0, 0, 0.885, -0.963, '#angry', '#disgusting', -0.616, 'die_young', 'go_scuba_dive', 'form_sentence', 'lower_standard', 'end_relationship']
senticnet['start_fire'] = [-0.957, 0, 0.475, -0.917, '#sad', '#disgusting', -0.783, 'light_cigarette', 'create_flame', 'ruin', 'create_fire', 'burn_forest']
senticnet['start_flame_fire'] = [0, 0, -0.849, -0.858, '#scared', '#disgusting', -0.569, 'play_fire', 'make_campfire', 'light_fire', 'start_fire', 'strike_match']
senticnet['start_laugh'] = [0, 0.924, 0, 0.827, '#interesting', '#admirable', 0.584, 'make_others_laugh', 'laugh', 'have_fun', 'happiness', 'make_fun']
senticnet['start_move'] = [0.731, 0.729, 0, 0.866, '#joyful', '#admirable', 0.775, 'stand_behind', 'able_run', 'conform', 'stand', 'go_end']
senticnet['start_new_day'] = [-0.069, 0, 0.044, -0.121, '#sad', '#disgusting', -0.078, 'get_out_of_bed', 'find_job', 'hard_work', 'work_oneself', 'different_day']
senticnet['start_off'] = [-0.041, 0.228, -0.104, 0.238, '#interesting', '#admirable', 0.107, 'start', 'finish', 'begin', 'tow', 'come']
senticnet['start_out'] = [-0.681, 0, 0.967, -0.657, '#sad', '#angry', -0.768, 'depart', 'start', 'part', 'sally_forth', 'set_forth']
senticnet['start_over'] = [-0.133, 0.083, -0.063, -0.093, '#sad', '#disgusting', -0.069, 'wait_patiently', 'learn_patience', 'find_end_line', 'come_early', 'conformist_attitude']
senticnet['start_project'] = [0.229, 0.127, 0, 0, '#joyful', '#interesting', 0.119, 'return_work', 'begin_work', 'work_box_office', 'write_program', 'go_work']
senticnet['start_run'] = [0, 0.883, 0, 0.994, '#interesting', '#admirable', 0.626, 'wrap_around', 'multiple_purposes', 'wave', 'rub', 'farewell']
senticnet['start_sweat'] = [0.917, 0.816, 0, 0, '#joyful', '#interesting', 0.578, 'sweat', 'breath_heavily', 'heavy_breathe', 'sore_leg', 'become_fatigued']
senticnet['start_talk'] = [0, 0.733, 0, 0.893, '#interesting', '#admirable', 0.542, 'talk', 'know_language', 'start_conversation', 'discuss', 'engage_conversation']
senticnet['start_up'] = [0.062, 0.212, 0, 0, '#joyful', '#interesting', 0.091, 'business', 'corporation', 'company', 'software_company', 'government_agreement']
senticnet['start_war'] = [-0.098, 0.091, -0.067, -0.092, '#sad', '#disgusting', -0.055, 'fight_battle', 'go_war', 'keep_peace', 'defeat_enemy', 'protect_oneself']
senticnet['starting_time'] = [0.932, -0.955, 0, 0.662, '#joyful', '#surprising', 0.85, 'point_in_time', 'threshold', 'birth', 'incipiency', 'incipience']
senticnet['startle'] = [0.958, 0.826, 0, 0, '#joyful', '#interesting', 0.595, 'trauma', 'freak_out', 'feel_hurt', 'embarrassment', 'psychoneurosis']
senticnet['starvation'] = [-0.733, 0, -0.839, 0, '#sad', '#scared', -0.524, 'cause_death', 'attack_enemy', 'lose_war', 'get_killed', 'die']
senticnet['starve'] = [-0.713, 0, 0, 0, '#sad', '#sad', -0.238, 'make_fun', 'confine', 'obey_traffic_law', 'shade_eye', 'do_anything']
senticnet['starved'] = [-0.713, 0, 0.692, -0.818, '#sad', '#disgusting', -0.741, 'famished', 'hungry', 'ravenous', 'esurient', 'peckish']
senticnet['starving'] = [-0.604, 0, 0.766, -0.746, '#angry', '#disgusting', -0.705, 'unfed', 'underfed', 'undernourished', 'starved', 'malnourished']
senticnet['starwort'] = [-0.642, 0, 0.555, -0.627, '#sad', '#disgusting', -0.608, 'herb', 'common_chickweed', 'stitchwort', 'greater_stitchwort', 'chickweed']
senticnet['stasis'] = [-0.657, 0, 0.793, -0.817, '#angry', '#disgusting', -0.756, 'halt', 'extinction', 'stagnancy', 'stagnation', 'inactiveness']
senticnet['stat'] = [0.049, 0.067, 0, 0.18, '#interesting', '#admirable', 0.099, 'name_state', 'unity', 'large_state', 'frequency', 'preparedness']
senticnet['state'] = [0.927, -0.66, 0, 0.648, '#joyful', '#surprising', 0.745, 'commonwealth', 'eparchy', 'administrative_district', 'administrative_division', 'territorial_division']
senticnet['state_america'] = [0.08, 0, -0.071, 0.133, '#joyful', '#admirable', 0.047, 'name_state', 'state', 'usa', 'united_states', 'large_state']
senticnet['state_fact'] = [-0.137, 0, -0.045, -0.037, '#sad', '#scared', -0.073, 'lower_expectation', 'guess_answer', 'erase_blackboard', 'voice_opinion', 'help_another_person']
senticnet['state_head'] = [0.052, 0.102, 0, 0.119, '#interesting', '#admirable', 0.091, 'country_leader', 'prime_minister', 'emperor', 'ceo', 'royalty']
senticnet['state_highway'] = [0.782, -0.582, 0, 0.547, '#joyful', '#surprising', 0.637, 'autobahn', 'autostrada', 'turnpike', 'toll_road', 'highway']
senticnet['state_matter'] = [0, 0.758, 0, 0.954, '#interesting', '#admirable', 0.571, 'gas_oil', 'natural_resource', 'fossil_fuel', 'combustible', 'petroleum']
senticnet['state_name'] = [-0.169, 0, -0.045, 0, '#sad', '#scared', -0.071, 'bicycle_school', 'thank_parent', 'laugh_clown', 'roll_ball', 'throw_fit']
senticnet['state_obvious'] = [0.721, 0.888, 0, 0, '#joyful', '#interesting', 0.536, 'thank_parent', 'honor_parent', 'throw_fit', 'watch_d', 'lose_key']
senticnet['state_of_mind'] = [0, 0.977, 0, 0.995, '#interesting', '#admirable', 0.657, 'human_emotion', 'good_emotion', 'liberate', 'mind_state', 'open_mind']
senticnet['state_of_nature'] = [-0.898, 0, 0.565, -0.547, '#sad', '#angry', -0.67, 'primitiveness', 'crudeness', 'crudity', 'primitivism', 'rudeness']
senticnet['state_opinion'] = [0, 0, 0, 0.739, '#admirable', '#admirable', 0.246, 'spring_action', 'see_star_night', 'recycle_paper', 'visit_grandmother', 'forward_email']
senticnet['state_park'] = [0.026, 0, 0, 0.073, '#joyful', '#admirable', 0.033, 'park', 'arboretum', 'meadow', 'grass', 'backyard']
senticnet['stateliness'] = [-0.539, 0, 0.993, -0.886, '#angry', '#disgusting', -0.806, 'expansiveness', 'expansivity', 'impressiveness', 'loftiness', 'excellence']
senticnet['statement'] = [-0.039, 0.136, -0.093, 0.246, '#interesting', '#admirable', 0.083, 'comment', 'retort', 'answer_back', 'remark', 'feedback']
senticnet['statesman'] = [0.69, -0.581, 0, 0.626, '#joyful', '#admirable', 0.632, 'elder_statesman', 'stateswoman', 'politician', 'politico', 'pol']
senticnet['static'] = [-0.829, 0, 0.99, -0.872, '#angry', '#disgusting', -0.897, 'motionless', 'rigid', 'inactive', 'still', 'nonmoving']
senticnet['static_electricity'] = [0, 0.751, 0, 0.72, '#interesting', '#admirable', 0.49, 'electric_current', 'static', 'electric', 'shock', 'jolt']
senticnet['station_wagon'] = [-0.056, 0, 0, -0.122, '#sad', '#disgusting', -0.059, 'plane_land', 'floss', 'floss_tooth', 'ornament', 'wear_dress']
senticnet['stationary'] = [0.04, -0.044, 0.152, -0.063, '#angry', '#disgusting', -0.044, 'stable', 'immobile', 'steady', 'settled', 'stabilize']
senticnet['stationery'] = [0.026, 0.082, 0, 0, '#joyful', '#interesting', 0.036, 'intern', 'note_pad', 'memo_pad', 'paper_punch', 'stamp_pad']
senticnet['stationery_store'] = [0.026, 0.082, 0, 0, '#joyful', '#interesting', 0.036, 'account_department', 'office', 'accountant_office', 'shirt_pocket', 'desk_drawer']
senticnet['statistical_distribution'] = [0.623, -0.647, 0, 0.754, '#surprising', '#admirable', 0.675, 'sampling', 'equidistribution', 'frequency_distribution', 'normal_distribution', 'sample_distribution']
senticnet['statue'] = [0.085, 0, 0, 0.073, '#joyful', '#admirable', 0.053, 'sculpture', 'art_object', 'yellow_ribbon', 'artwork', 'monument']
senticnet['status'] = [0.03, 0.167, -0.102, 0.19, '#interesting', '#admirable', 0.095, 'designation', 'social_class', 'classification', 'military_order', 'champion']
senticnet['status_symbol'] = [0.25, 0.078, 0.019, 0.282, '#joyful', '#admirable', 0.197, 'german_car', 'fast_car', 'head_gear', 'head_cover', 'head_wear']
senticnet['statutory_offence'] = [-0.625, 0, 0.565, -0.78, '#sad', '#disgusting', -0.657, 'crime', 'bigamy', 'sexual_assault', 'sexual_abuse', 'sex_crime']
senticnet['statutory_offense'] = [-0.963, 0, 0.733, -0.81, '#sad', '#disgusting', -0.835, 'crime', 'bigamy', 'sexual_assault', 'sexual_abuse', 'sex_crime']
senticnet['staunch'] = [0.889, 0.727, 0, 0, '#joyful', '#interesting', 0.539, 'stanch', 'steadfast', 'unswerving', 'stem', 'halt']
senticnet['stay'] = [0.053, 0.127, -0.081, 0.134, '#interesting', '#admirable', 0.078, 'temporary_home', 'stay_overnight', 'sleep_on_couch', 'place_sleep', 'remain']
senticnet['stay_alert'] = [0.027, 0.179, -0.073, 0.122, '#interesting', '#admirable', 0.085, 'take_exam', 'take_final_exam', 'take_examination', 'take_final', 'take_midterm']
senticnet['stay_alive'] = [0, 0.759, 0, 0.894, '#interesting', '#admirable', 0.551, 'sustain_life', 'like_taste', 'live', 'get_oxygen', 'survive']
senticnet['stay_awake'] = [0, 0.08, 0, 0.179, '#interesting', '#admirable', 0.086, 'drink_coffee', 'hold_beverage', 'find_toilet', 'hold_liquid', 'hold_soda']
senticnet['stay_bed'] = [0.719, 0.762, 0, 0, '#joyful', '#interesting', 0.494, 'sit_down', 'take_break', 'sit_chair', 'lie_on_bed', 'go_sleep']
senticnet['stay_calm'] = [0.251, 0.207, -0.082, 0.18, '#joyful', '#interesting', 0.185, 'coffee_break', 'work_break', 'inactivity', 'recover', 'cease_fire']
senticnet['stay_dry'] = [-0.025, 0, 0.094, -0.187, '#angry', '#disgusting', -0.102, 'keep_dry', 'switch_off', 'cover_body', 'protect_rain', 'make_drape']
senticnet['stay_dry_rain'] = [-0.078, 0, 0, -0.031, '#sad', '#disgusting', -0.036, 'block_sun', 'wet', 'lower_body_temperature', 'catch_rain', 'stay_dry']
senticnet['stay_fit'] = [0, 0.741, 0, 0.92, '#interesting', '#admirable', 0.554, 'get_shape', 'lose_weight', 'stay_healthy', 'eat_healthily', 'do_exercise']
senticnet['stay_healthy'] = [0, 0.799, 0, 0.878, '#interesting', '#admirable', 0.559, 'maintain_good_health', 'eat_healthily', 'do_exercise', 'stay_fit', 'eat_well']
senticnet['stay_home'] = [-0.124, 0, -0.074, -0.109, '#sad', '#disgusting', -0.102, 'sit_on_beach', 'use_thermometer', 'clean_sink', 'absorb_moisture', 'procrastinate']
senticnet['stay_in_house'] = [-0.121, 0, -0.066, -0.033, '#sad', '#scared', -0.073, 'follow_person', 'cause_accident', 'mark_territory', 'sense_fear', 'guide_blind']
senticnet['stay_out_jail'] = [-0.25, 0.073, -0.277, 0, '#sad', '#scared', -0.151, 'no_choice', 'deserve', 'take_out_loan', 'down_payment', 'feel_smug']
senticnet['stay_out_trouble'] = [0, 0.93, 0, 0.767, '#interesting', '#admirable', 0.566, 'warm_feeling', 'necessity', 'demand', 'show_love', 'look_after']
senticnet['stay_overnight'] = [0.053, 0.127, -0.081, 0.134, '#interesting', '#admirable', 0.078, 'temporary_home', 'stay', 'sleep_on_couch', 'sex_with_stranger', 'remain']
senticnet['stay_physically_fit'] = [0, 0.74, 0, 0.805, '#interesting', '#admirable', 0.515, 'get_healthy', 'build_muscle', 'improve_self-image', 'increase_muscle_mass', 'healthy_live']
senticnet['stay_school'] = [0, 0.978, 0, 0.835, '#interesting', '#admirable', 0.604, 'study_hard', 'read_lot', 'make_parent_happy', 'study_course_material', 'earn_degree']
senticnet['stay_shape'] = [0.071, 0, 0, 0, '#joyful', '#joyful', 0.024, 'build_muscle', 'improve_health', 'become_fit', 'exercise', 'good_health']
senticnet['stay_sober'] = [-0.082, 0, 0.039, 0, '#sad', '#angry', -0.04, 'open_car_door', 'put_key_ignition', 'find_car_key', 'close_window', 'start_car_engine']
senticnet['stay_still'] = [0, 0.105, 0, 0.128, '#interesting', '#admirable', 0.078, 'step_out', 'step_aside', 'step_forward', 'put_sock', 'meander']
senticnet['stay_touch'] = [0.072, -0.02, 0, 0, '#joyful', '#surprising', 0.031, 'give_comfort', 'communicate_friend', 'send_information', 'spread_meme', 'communicate_thought']
senticnet['stay_touch_friend'] = [0.12, 0.092, 0.017, 0.17, '#joyful', '#admirable', 0.122, 'talk_oneself', 'discuss_issue', 'sleep_late', 'say_love', 'make_progress']
senticnet['stay_up_night'] = [-0.109, 0, 0, 0, '#sad', '#sad', -0.036, 'climb_stair', 'exercise_daily', 'break_record', 'jump_up_down', 'take_hike']
senticnet['stay_warm'] = [0.101, 0, 0, 0, '#joyful', '#joyful', 0.034, 'keep_warm', 'keep_warm_winter', 'provide_warmth', 'keep_someone_warm', 'provide_heat']
senticnet['stay_well'] = [0, 0.747, 0, 0.731, '#interesting', '#admirable', 0.493, 'maintain_health', 'check_health', 'diagnose_illness', 'keep_body_healthy', 'think_clearly']
senticnet['stay_with_family'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'holiday', 'easter_bunny', 'eat_delicious_food', 'day_off', 'relax']
senticnet['stay_young'] = [0.755, 0.994, 0, 0, '#joyful', '#interesting', 0.583, 'measure_person', 'cycle', 'era', 'many_years', 'know_time']
senticnet['staying_power'] = [0.989, -0.806, 0, 0.569, '#joyful', '#surprising', 0.788, 'strength', 'tolerance', 'stamina', 'endurance', 'sufferance']
senticnet['std'] = [-0.392, -0.074, -0.099, -0.32, '#sad', '#disgusting', -0.246, 'broken_heart', 'schizophrenia', 'broken_finger', 'disability', 'diabetes']
senticnet['steadiness'] = [0.644, -0.882, 0, 0.834, '#surprising', '#admirable', 0.787, 'resoluteness', 'firmness_of_purpose', 'firmness', 'resolve', 'resolution']
senticnet['steak_house'] = [0.039, 0.089, 0.023, 0, '#joyful', '#interesting', 0.035, 'spanish_restaurant', 'tapas', 'french_restaurant', 'paella', 'restaurant_diner']
senticnet['steak_sauce'] = [-0.756, 0, 0.593, -0.591, '#sad', '#angry', -0.647, 'taco_sauce', 'chili_sauce', 'condiment', 'duck_sauce', 'hoisin_sauce']
senticnet['steal_car'] = [-0.079, 0, 0, 0, '#sad', '#sad', -0.026, 'find_wallet', 'bring_money', 'new_car', 'find_car_key', 'license']
senticnet['steal_client'] = [-0.927, 0, 0.784, -0.912, '#sad', '#disgusting', -0.874, 'enemy', 'bad_customer', 'competitor', 'disloyal', 'buy_cheaper']
senticnet['steal_document'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'thief', 'steal', 'steal_idea', 'hide_evidence', 'bad_person']
senticnet['steal_idea'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'thief', 'steal', 'steal_document', 'hide_evidence', 'bad_person']
senticnet['steal_money'] = [0, 0.82, 0, 0.993, '#interesting', '#admirable', 0.604, 'burglary', 'theft', 'stick_up', 'robbery', 'rob']
senticnet['steal_paint'] = [-0.045, -0.03, 0.069, 0, '#sad', '#angry', -0.028, 'make_pretty', 'paint_nail', 'remove_paint', 'dust_furniture', 'vacuum_floor']
senticnet['steal_store'] = [-0.121, 0.065, -0.067, 0, '#sad', '#scared', -0.041, 'bridge_difference', 'stand_alone', 'deal_card_player', 'explain_everything', 'forward_email']
senticnet['stealing'] = [-0.106, 0, -0.053, -0.24, '#sad', '#disgusting', -0.133, 'thieving', 'larceny', 'theft', 'thievery', 'fraudulent_intent']
senticnet['steam'] = [0.07, -0.03, 0.023, 0, '#joyful', '#surprising', 0.026, 'vapor', 'haze', 'mist', 'misty', 'summer_weather']
senticnet['steam_engine'] = [0, 0.828, 0, 0.959, '#interesting', '#admirable', 0.596, 'noise', 'loud_noise', 'loudness', 'amplifier', 'loud_sound']
senticnet['steam_locomotive'] = [-0.046, -0.028, 0.089, -0.142, '#angry', '#disgusting', -0.083, 'vacuum_cleaner', 'loudspeaker', 'collector', 'siren', 'activist']
senticnet['steam_turbine'] = [-0.976, 0, 0.658, -0.606, '#sad', '#angry', -0.747, 'gas_turbine', 'hydroelectric_turbine', 'impulse_turbine', 'reaction_turbine', 'turbine']
senticnet['steamed'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['steamroll'] = [0.859, -0.929, 0, 0.901, '#surprising', '#admirable', 0.896, 'coerce', 'hale', 'pressure', 'force', 'squeeze']
senticnet['steamy'] = [0.041, 0.072, -0.05, 0.091, '#interesting', '#admirable', 0.051, 'warm_air', 'gaseous', 'hot_air', 'vapor', 'steam']
senticnet['steel_factory'] = [0.692, -0.53, 0, 0.68, '#joyful', '#admirable', 0.634, 'rolling_mill', 'factory', 'mill', 'manufacturing_plant', 'manufactory']
senticnet['steel_mill'] = [0.641, -0.561, 0, 0.6, '#joyful', '#admirable', 0.601, 'rolling_mill', 'factory', 'mill', 'manufacturing_plant', 'manufactory']
senticnet['steel_pen'] = [0.023, -0.054, 0.069, -0.09, '#angry', '#disgusting', -0.027, 'stamp_pad', 'ballpoint_pen', 'intern', 'paper_punch', 'paper_fastener']
senticnet['steel_plant'] = [0.757, -0.677, 0, 0.685, '#joyful', '#admirable', 0.706, 'rolling_mill', 'factory', 'mill', 'manufacturing_plant', 'manufactory']
senticnet['steel_wool'] = [0.921, 0, 0, 0.731, '#joyful', '#admirable', 0.551, 'moistener', 'paper_towel', 'toilet_paper', 'toilet_brush', 'bath_shower']
senticnet['steelworks'] = [0.56, -0.558, 0, 0.807, '#joyful', '#admirable', 0.642, 'rolling_mill', 'factory', 'mill', 'manufacturing_plant', 'manufactory']
senticnet['steep'] = [0, 0.092, 0.016, 0.074, '#interesting', '#admirable', 0.05, 'incline', 'knoll', 'up_hill', 'slant', 'mountain_side']
senticnet['steeple'] = [0.029, 0.233, 0.019, 0.246, '#interesting', '#admirable', 0.163, 'catholic_church', 'christianity', 'chapel', 'worship_place', 'cathedral']
senticnet['steer'] = [0, 0.922, 0, 0.783, '#interesting', '#admirable', 0.568, 'car_movement', 'steer_car', 'car_action', 'navigate', 'turn_ignition']
senticnet['steer_car'] = [0, 0, 0, 0.159, '#admirable', '#admirable', 0.053, 'car_travel', 'car_action', 'control_car', 'car_movement', 'passenger_car']
senticnet['steer_wheel'] = [0.041, -0.087, 0, 0.056, '#surprising', '#admirable', 0.061, 'engine', 'wheel', 'motor', 'axle', 'two_wheels']
senticnet['stem_canker'] = [-0.699, 0, 0.776, -0.788, '#angry', '#disgusting', -0.754, 'little_potato', 'russet_scab', 'rhizoctinia_disease', 'rosette', 'plant_disease']
senticnet['stench'] = [0, 0.073, 0, 0.092, '#interesting', '#admirable', 0.055, 'false_tooth', 'scent', 'waste_water', 'sniff', 'odor']
senticnet['stenosis'] = [-0.815, 0, 0.684, -0.813, '#sad', '#disgusting', -0.771, 'rhinostenosis', 'enterostenosis', 'laryngostenosis', 'aortic_stenosis', 'mitral_stenosis']
senticnet['step'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'walk_up', 'get_floor_another', 'rung', 'go_up_down', 'climb_up']
senticnet['step_aside'] = [-0.025, 0.087, 0, 0.107, '#interesting', '#admirable', 0.056, 'say_good_bye', 'excuse_oneself', 'step_out', 'walk_away', 'open_mailbox']
senticnet['step_dancing'] = [0.818, -0.619, 0, 0.743, '#joyful', '#admirable', 0.727, 'tap_dancing', 'tap_dance', 'dancing', 'dance', 'terpsichore']
senticnet['step_dog_poop'] = [0, 0, 0.962, -0.883, '#angry', '#disgusting', -0.615, 'get_hit_by_car', 'broken_window', 'broken_wrist', 'step_dog_shit', 'trip_fall_down']
senticnet['step_dog_shit'] = [0, 0, 0.753, -0.888, '#angry', '#disgusting', -0.547, 'broken_window', 'broken_wrist', 'broken_leg', 'sprain_ankle', 'bloody_nose']
senticnet['step_down'] = [-0.894, 0, 0.925, -0.844, '#sad', '#angry', -0.888, 'vacate', 'resign', 'give_up', 'renounce', 'depart']
senticnet['step_forward'] = [-0.089, 0.106, 0, 0.125, '#interesting', '#admirable', 0.047, 'step', 'step_out', 'brave', 'courage', 'stand_out']
senticnet['step_out'] = [-0.089, 0.106, 0, 0.125, '#interesting', '#admirable', 0.047, 'step_aside', 'meander', 'walk_away', 'step_forward', 'stay_still']
senticnet['step_up'] = [0.023, 0.212, -0.132, 0.172, '#interesting', '#admirable', 0.092, 'awaken', 'levitate', 'rise_up', 'come_up', 'raise_up']
senticnet['step_up_plate'] = [0.048, 0, 0, 0.092, '#joyful', '#admirable', 0.047, 'find_other_player', 'know_how_play_baseball', 'babe_ruth', 'contest', 'game_chess']
senticnet['stepping_motor'] = [0.67, -0.912, 0, 0.805, '#surprising', '#admirable', 0.796, 'electric_motor', 'engine', 'stepper', 'motor', 'machine']
senticnet['stereo'] = [0.052, -0.113, 0.02, 0, '#joyful', '#surprising', 0.048, 'radio', 'tuner', 'speaker', 'soprano', 'loudspeaker']
senticnet['sterile'] = [0, 0, 0.962, -0.883, '#angry', '#disgusting', -0.615, 'sterility', 'barrenness', 'barren', 'infertile', 'impotent']
senticnet['sternness'] = [0.529, -0.755, 0, 0.578, '#surprising', '#admirable', 0.621, 'asperity', 'grimness', 'rigor', 'hardship', 'rigorousness']
senticnet['stet'] = [-0.823, 0, 0.546, -0.733, '#sad', '#disgusting', -0.701, 'nullify', 'invalidate', 'annul', 'void', 'quash']
senticnet['stethoscope'] = [0.255, 0.182, -0.06, 0.314, '#joyful', '#admirable', 0.23, 'doctor_office', 'cystoscope', 'medical_instrument', 'gastroscope', 'medical_equipment']
senticnet['stevedore'] = [0, 0, -0.952, -0.844, '#scared', '#disgusting', -0.599, 'docker', 'lumper', 'loader', 'longshoreman', 'dock_worker']
senticnet['stew'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'main_course', 'cream_soup', 'soup', 'ragout', 'goulash']
senticnet['stewing'] = [0, 0, 0.716, 0, '#angry', '#angry', -0.239, 'antsy', 'fidgety', 'fretful', 'fidgetiness', 'anxiousness']
senticnet['sthene'] = [-0.641, 0, 0.678, -0.705, '#angry', '#disgusting', -0.675, 'pound', 'dyne', 'newton', 'force_unit', 'poundal']
senticnet['stick'] = [0.08, -0.463, 0.037, 0.204, '#surprising', '#admirable', 0.237, 'long_stick', 'wand', 'walk_stick', 'twig', 'cue']
senticnet['stick_butter'] = [0.061, -0.049, 0, 0, '#joyful', '#surprising', 0.037, 'heat_element', 'bake_oven', 'find_recipe', 'grill', 'food_bake']
senticnet['stick_eraser'] = [0.975, 0.811, 0, 0, '#joyful', '#interesting', 0.595, 'eraser_holder', 'pencil_sharpener', 'clipboard', 'intern', 'electric_pencil_sharpener']
senticnet['stick_in'] = [-0.69, 0, 0.883, -0.912, '#angry', '#disgusting', -0.828, 'feed_in', 'enclose', 'insert', 'inclose', 'put_in']
senticnet['stick_mud'] = [-0.107, -0.084, 0, -0.127, '#sad', '#disgusting', -0.05, 'stick_wall', 'car_race', 'room_temperature', 'loose_end', 'auction']
senticnet['stick_out'] = [0.753, -0.909, 0, 0.572, '#joyful', '#surprising', 0.745, 'bag', 'overhang', 'thrust', 'push_up', 'spear']
senticnet['stick_paper'] = [0.041, -0.343, 0.065, 0.085, '#surprising', '#admirable', 0.135, 'stick_together', 'stick', 'sharp_nail', 'hold_together', 'walk_stick']
senticnet['stick_together'] = [0.786, 0.921, 0, 0, '#joyful', '#interesting', 0.569, 'stick_paper', 'white_paper', 'crumple', 'paper_piece', 'piece_of_paper']
senticnet['stick_up'] = [0, 0.735, 0, 0.739, '#interesting', '#admirable', 0.491, 'steal_money', 'theft', 'burglary', 'robbery', 'rob']
senticnet['stick_wall'] = [0, 0.726, 0, 0.902, '#interesting', '#admirable', 0.543, 'tunnel', 'international_space_station', 'cavern', 'car_race', 'auction']
senticnet['sticker'] = [-0.024, 0.246, 0.009, 0.15, '#interesting', '#admirable', 0.121, 'money_amount', 'item_worth', 'like_cost', 'value_amount', 'item_value']
senticnet['sticky'] = [0.873, 0.708, 0, 0, '#joyful', '#interesting', 0.527, 'ugly', 'confusedly', 'discombobulation', 'confusing', 'confused']
senticnet['sticky_floor'] = [0.913, 0.754, 0, 0, '#joyful', '#interesting', 0.556, 'row_seat', 'stage_entrance', 'projector', 'theater_box', 'balcony_seat']
senticnet['sticky_substance'] = [0.025, -0.009, 0, 0.125, '#joyful', '#admirable', 0.053, 'goo', 'adhesive', 'flour_water', 'insert', 'thick_liquid']
senticnet['stiff'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'stiff_neck', 'rigid', 'inflexible', 'harsh', 'immovable']
senticnet['stiff_neck'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'stiff', 'rigid', 'inflexible', 'harsh', 'immovable']
senticnet['stiffness'] = [0.998, 0.716, 0, 0, '#joyful', '#interesting', 0.571, 'shin_splint', 'get_out_breath', 'become_wind', 'get_exhausted', 'run_out_breath']
senticnet['stifle'] = [0.033, -0.197, 0.203, -0.229, '#angry', '#disgusting', -0.067, 'antiquate', 'optional', 'kleenex', 'key_chain', 'sachet']
senticnet['stigma'] = [-0.883, 0, 0, -0.779, '#sad', '#disgusting', -0.554, 'mark', 'emblem', 'religious_sign', 'stain', 'brand']
senticnet['still'] = [-0.829, 0, 0.99, -0.872, '#angry', '#disgusting', -0.897, 'motionless', 'rigid', 'inactive', 'nonmoving', 'static']
senticnet['still_water'] = [0.718, 0, 0, 0, '#joyful', '#joyful', 0.239, 'water_container', 'clean_water', 'dampness', 'water', 'cool_water']
senticnet['stillborn'] = [-0.705, 0, 0.919, -0.732, '#angry', '#disgusting', -0.785, 'childless', 'unsuccessful', 'acarpous', 'abortive', 'unfruitful']
senticnet['stillborn_infant'] = [-0.514, 0, 0.747, -0.944, '#angry', '#disgusting', -0.735, 'neonate', 'premature_baby', 'preterm_baby', 'premature_infant', 'preterm_infant']
senticnet['stillness'] = [0.449, 0.305, -0.192, 0.222, '#joyful', '#interesting', 0.261, 'calm', 'peace', 'serenity', 'quiet', 'tranquility']
senticnet['stimulate'] = [0, 0.741, 0, 0.842, '#interesting', '#admirable', 0.528, 'sensationalistic', 'sensational', 'scandalmongering', 'sensationally', 'set_off']
senticnet['stimulate_appetite'] = [0.032, 0.075, 0, 0, '#joyful', '#interesting', 0.036, 'alcohol', 'aperitif', 'beverage', 'adult_drink', 'bartender']
senticnet['stimulate_mind'] = [0.868, 0.99, 0, 0, '#joyful', '#interesting', 0.619, 'get_informed', 'expand_horizon', 'acculturation', 'appreciate_art', 'enjoy_story']
senticnet['stimulating'] = [0.645, 0.637, -0.239, 0.299, '#joyful', '#interesting', 0.447, 'gladdened', 'tickle_pink', 'inebriate', 'exalt', 'beatify']
senticnet['stimulation'] = [0.341, 0, 0, 0.088, '#joyful', '#admirable', 0.143, 'good_lover', 'personal_fulfillment', 'lower_stress', 'sit_sun', 'look_night_sky']
senticnet['stimulative'] = [0.95, -0.951, 0, 0.769, '#joyful', '#surprising', 0.89, 'adrenocorticotropic', 'adrenocorticotrophic', 'stimulant', 'stimulating', 'excitant']
senticnet['sting'] = [-0.103, -0.02, -0.074, -0.135, '#sad', '#disgusting', -0.097, 'dislocation', 'welt', 'ache', 'laceration', 'abrasion']
senticnet['sting_insect'] = [-0.936, 0, 0.879, -0.986, '#sad', '#disgusting', -0.934, 'bee', 'pain', 'painful', 'sharp_pain', 'sharp']
senticnet['sting_operation'] = [0.931, -0.714, 0, 0.63, '#joyful', '#surprising', 0.758, 'hustle', 'con', 'bunco', 'sting', 'bunco_game']
senticnet['stingy'] = [-0.919, 0, 0.598, -0.522, '#sad', '#angry', -0.68, 'parsimonious', 'penurious', 'scrimy', 'beggarly', 'chintzy']
senticnet['stink'] = [0, 0, 0.883, -0.767, '#angry', '#disgusting', -0.55, 'feel_dirty', 'remove_stain', 'clean_up', 'clean_up_mess', 'dry_hair']
senticnet['stink_mess'] = [0.935, 0, 0, 0, '#joyful', '#joyful', 0.312, 'clean_up_kitchen', 'feel_dirty', 'remove_stain', 'stink', 'clean_up']
senticnet['stink_out'] = [-0.674, 0, 0.503, -0.67, '#sad', '#disgusting', -0.616, 'stink_up', 'smell_up', 'odorize', 'incense', 'perfume']
senticnet['stink_up'] = [-0.674, 0, 0.503, -0.67, '#sad', '#disgusting', -0.616, 'odorize', 'smell_up', 'stink_out', 'incense', 'perfume']
senticnet['stinkiness'] = [-0.978, 0, 0.537, -0.695, '#sad', '#disgusting', -0.737, 'body_odor', 'aroma', 'scent', 'olfactory_property', 'smell']
senticnet['stinking'] = [-0.868, 0, 0.644, -0.886, '#sad', '#disgusting', -0.799, 'frowsty', 'fetid', 'foetid', 'smelly', 'malodorous']
senticnet['stinking_chamomile'] = [0.782, -0.695, 0, 0.684, '#joyful', '#surprising', 0.72, 'mayweed', 'stinking_mayweed', 'composite_plant', 'dog_fennel', 'oxeye_daisy']
senticnet['stinking_clover'] = [-0.81, 0, 0.699, -0.526, '#sad', '#angry', -0.678, 'herb', 'spider_flower', 'spider_plant', 'cleome', 'herbaceous_plant']
senticnet['stinking_mayweed'] = [0.782, -0.695, 0, 0.684, '#joyful', '#surprising', 0.72, 'mayweed', 'composite_plant', 'stinking_chamomile', 'dog_fennel', 'oxeye_daisy']
senticnet['stinking_smut'] = [-0.935, 0, 0.699, -0.91, '#sad', '#disgusting', -0.848, 'onion_smut', 'head_smut', 'smut_fungus', 'flag_smut_fungus', 'covered_smut']
senticnet['stinky'] = [0, 0, 0.943, -0.8, '#angry', '#disgusting', -0.581, 'fight_fire', 'filthy', 'dirty', 'stink', 'fall_mud']
senticnet['stint'] = [0, -0.015, 0.037, -0.046, '#angry', '#disgusting', -0.023, 'limit_time', 'restrict', 'deadline', 'limit', 'restriction']
senticnet['stinting'] = [0, -0.887, 0, 0.728, '#surprising', '#admirable', 0.538, 'scrimp', 'economical', 'scant', 'frugal', 'skimp']
senticnet['stir'] = [0, 0.977, 0, 0.797, '#interesting', '#admirable', 0.591, 'sensationally', 'sensational', 'sensationalistic', 'scandalmongering', 'set_off']
senticnet['stir_coffee'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'eat_food', 'eat_pudding', 'eat_cereal', 'satisfy_appetite', 'able_eat']
senticnet['stir_paint'] = [0.165, 0.069, 0.028, 0.057, '#joyful', '#interesting', 0.088, 'make_paint', 'buy_paint_brush', 'wall_art', 'buy_paint', 'pick_up_brush']
senticnet['stir_paint_brush'] = [0.165, 0.069, 0.028, 0.057, '#joyful', '#interesting', 0.088, 'make_paint', 'buy_paint', 'wall_art', 'stir_paint', 'pick_up_brush']
senticnet['stir_pot'] = [0, -0.081, 0, 0, '#surprising', '#surprising', 0.027, 'peel_potato', 'chop_vegetable', 'burn_food', 'heat_pot_water', 'cut_vegetable']
senticnet['stir_up'] = [0, 0.706, 0, 0.886, '#interesting', '#admirable', 0.531, 'incite', 'fire_up', 'instigate', 'inflame', 'tumult']
senticnet['stitch'] = [-0.036, -0.003, -0.057, -0.089, '#scared', '#disgusting', -0.06, 'bandage', 'needle_thread', 'sew_term', 'spasm', 'suture']
senticnet['stitchery'] = [0.548, -0.611, 0, 0.556, '#surprising', '#admirable', 0.572, 'patchwork', 'darn', 'mend', 'stitch', 'applique']
senticnet['stitchwort'] = [-0.642, 0, 0.555, -0.627, '#sad', '#disgusting', -0.608, 'herb', 'common_chickweed', 'chickweed', 'greater_chickweed', 'starwort']
senticnet['stochasticity'] = [-0.897, 0, 0.972, -0.502, '#sad', '#angry', -0.79, 'unsteadiness', 'haphazardness', 'unregularity', 'variability', 'fitfulness']
senticnet['stock'] = [0.021, 0.079, 0.011, 0.118, '#interesting', '#admirable', 0.069, 'hang_hanger', 'store_dress', 'keep_clothes', 'leg_wear', 'store_shoes']
senticnet['stock_exchange'] = [-0.037, 0.125, 0, 0.105, '#interesting', '#admirable', 0.064, 'switch', 'small_shop', 'shop', 'return_goods', 'sell_stuff']
senticnet['stock_food'] = [-0.119, 0, -0.046, 0, '#sad', '#scared', -0.055, 'forward_email', 'mind_store', 'deal_card_player', 'position_furniture', 'explain_everything']
senticnet['stock_market'] = [-0.025, 0.254, 0, 0.181, '#interesting', '#admirable', 0.137, 'wall_street', 'merchant', 'trade', 'exchange_goods', 'market']
senticnet['stock_merchandise'] = [-0.063, 0, 0.035, 0, '#sad', '#angry', -0.033, 'buy_grocery', 'purchase_food', 'buy_vegetable', 'purchase_grocery', 'shop_food']
senticnet['stockholder'] = [0.069, 0.07, 0, 0.116, '#interesting', '#admirable', 0.085, 'entrepreneur', 'invest_money', 'move_around', 'traveling_person', 'guilty_person']
senticnet['stocking'] = [0, -0.048, 0.074, -0.05, '#angry', '#disgusting', -0.025, 'nightgown', 'garment', 'judo', 'kimono', 'apparel']
senticnet['stodginess'] = [-0.573, 0, 0.841, -0.508, '#sad', '#angry', -0.641, 'somberness', 'sombreness', 'gravity', 'soberness', 'graveness']
senticnet['stole_goods'] = [-0.931, 0, 0.945, -0.932, '#angry', '#disgusting', -0.936, 'prison_breaker', 'escape_prison', 'illegal', 'escape_justice', 'break_rule']
senticnet['stolen'] = [-0.203, 0.101, -0.131, -0.049, '#sad', '#scared', -0.094, 'die_painfully', 'get_hurt', 'kill_other_person', 'end_life', 'arrest_police']
senticnet['stolidity'] = [0, 0, 0.709, -0.923, '#angry', '#disgusting', -0.544, 'apathetic', 'unemotionality', 'passionless', 'indifference', 'phlegm']
senticnet['stomach'] = [-0.993, 0, 0.871, -0.559, '#sad', '#angry', -0.808, 'endure', 'brook', 'tolerate', 'bear_up', 'abide']
senticnet['stomach_ache'] = [0.052, -0.045, -0.058, -0.203, '#scared', '#disgusting', -0.055, 'indigestion', 'make_little_hungry', 'full_stomach', 'sick', 'become_full']
senticnet['stomach_flu'] = [-0.756, 0, 0.84, -0.633, '#sad', '#angry', -0.743, 'angina', 'gastroenteritis', 'inflammatory_disease', 'intestinal_flu', 'pelvic_inflammatory_disease']
senticnet['stomach_full'] = [-0.085, -0.043, 0, -0.128, '#sad', '#disgusting', -0.057, 'wipe_mouth_napkin', 'tuberculosis', 'use_fork', 'swallow', 'eat']
senticnet['stomach_pain'] = [-0.06, 0, -0.157, -0.124, '#scared', '#disgusting', -0.114, 'severe_pain', 'discomfort', 'physical_reaction', 'choke_death', 'embarrassment']
senticnet['stomach_problem'] = [0.841, 0.885, 0, 0, '#joyful', '#interesting', 0.575, 'decrease_hunger', 'feel_full', 'upset_stomach', 'get_fat', 'a_little_hungry']
senticnet['stomach_rumble'] = [0.796, 0.851, 0, 0, '#joyful', '#interesting', 0.549, 'hungry', 'delicious_food', 'nice_meal', 'meal', 'snack']
senticnet['stone_crab'] = [-0.698, 0, 0.766, -0.826, '#angry', '#disgusting', -0.763, 'crab', 'swimming_crab', 'rock_crab', 'fiddler_crab', 'pea_crab']
senticnet['stone_dead'] = [-0.901, 0, 0.718, -0.906, '#sad', '#disgusting', -0.842, 'dead_person', 'death_bed', 'grave', 'corpse', 'coffin']
senticnet['stonecrop'] = [-0.592, 0, 0.942, -0.758, '#angry', '#disgusting', -0.764, 'livelong', 'herb', 'sedum', 'orpine', 'orpin']
senticnet['stonewaller'] = [-0.839, 0, 0.682, -0.873, '#sad', '#disgusting', -0.798, 'obstructor', 'obstructer', 'obstructionist', 'resister', 'thwarter']
senticnet['stoning'] = [-0.839, 0, 0.924, -0.79, '#sad', '#angry', -0.851, 'kick_in_butt', 'licking', 'whacking', 'corporal_punishment', 'lapidation']
senticnet['stooge'] = [-0.539, 0, 0.591, -0.593, '#angry', '#disgusting', -0.574, 'mug', 'sitting_duck', 'easy_mark', 'dupe', 'mortal']
senticnet['stool'] = [0.087, -0.051, 0.01, -0.041, '#joyful', '#surprising', 0.029, 'chair', 'cocktail_cabinet', 'seat', 'armchair', 'couch']
senticnet['stoolpigeon'] = [-0.672, 0, 0.546, -0.633, '#sad', '#disgusting', -0.617, 'fink', 'snitch', 'snitcher', 'sneak', 'betrayer']
senticnet['stop'] = [-0.998, 0, 0.893, -0.703, '#sad', '#angry', -0.865, 'halt', 'quit', 'red_light', 'eight_sides', 'finish']
senticnet['stop_activity'] = [0.72, 0.839, 0, 0, '#joyful', '#interesting', 0.52, 'sleepiness', 'sleepy', 'rest_up', 'need_to_rest', 'mouth_open']
senticnet['stop_bleed'] = [-0.122, 0, 0, -0.094, '#sad', '#disgusting', -0.072, 'fee_animal', 'check_oneself_mirror', 'look_out_window', 'write_on_notebook', 'turn_off_engine']
senticnet['stop_breathe'] = [-0.203, 0, -0.281, -0.081, '#sad', '#scared', -0.188, 'slash_wrist', 'end_life', 'loss_oflife', 'death', 'religious_fundamentalist']
senticnet['stop_crime'] = [0, 0.777, 0, 0.791, '#interesting', '#admirable', 0.523, 'tail_suspect', 'arrest_criminal', 'fine_person', 'direct_traffic', 'settle_argument']
senticnet['stop_drink'] = [-0.072, 0, 0, -0.055, '#sad', '#disgusting', -0.042, 'go_potty', 'wash_up', 'use_toilet', 'wear_sock', 'camp_out']
senticnet['stop_eat'] = [-0.98, 0, 0.017, -0.974, '#sad', '#disgusting', -0.657, 'die', 'ill', 'sickness', 'need_cure', 'stop']
senticnet['stop_eating'] = [-0.028, -0.026, 0.049, -0.033, '#angry', '#disgusting', -0.028, 'talk_family', 'eat_burger', 'full', 'eat_pizza', 'swallow_food']
senticnet['stop_fire'] = [0, 0, 0.027, -0.044, '#angry', '#disgusting', -0.024, 'fire_engine', 'fire_hydrant', 'fire_truck', 'emergency', 'stop_sign']
senticnet['stop_hunger'] = [0.985, 0, 0, 0.731, '#joyful', '#admirable', 0.572, 'channel_surf', 'feel_content', 'entertain_friend', 'quiet_down', 'feel_satisfaction']
senticnet['stop_hungry'] = [-0.032, 0, -0.05, 0, '#sad', '#scared', -0.027, 'eat_sandwich', 'chew_food', 'eat_beef', 'feed_child', 'eat_much']
senticnet['stop_listen'] = [0.074, -0.008, 0, 0, '#joyful', '#surprising', 0.027, 'move_tongue', 'dry_mouth', 'make_eye_contact', 'start_talk', 'make_unusual_face']
senticnet['stop_living'] = [-0.973, 0, 0.061, -0.908, '#sad', '#disgusting', -0.647, 'end_of_life', 'pass_away', 'death', 'die_person', 'lose_life']
senticnet['stop_look'] = [0.216, 0.198, -0.124, 0.237, '#joyful', '#admirable', 0.176, 'ear_work', 'sense', 'use_ear', 'like_see', 'five_senses']
senticnet['stop_marry'] = [-0.854, 0, 0.954, -0.863, '#angry', '#disgusting', -0.89, 'get_divorce', 'divorce', 'sad', 'cry', 'break_up']
senticnet['stop_move'] = [-0.045, -0.029, 0, -0.141, '#sad', '#disgusting', -0.052, 'become_unconscious', 'unplug', 'hit_oneself_head', 'take_nap', 'lose_consciousness']
senticnet['stop_procrastinate'] = [0.835, 0.862, 0, 0, '#joyful', '#interesting', 0.566, 'chore', 'make_happen', 'pick_up_trash', 'intuition', 'elbow_grease']
senticnet['stop_red_light'] = [0.032, 0.261, -0.157, 0.198, '#interesting', '#admirable', 0.111, 'run_out_gas', 'shift_gear', 'arrive_destination', 'use_gas', 'stop_stop_sign']
senticnet['stop_sign'] = [0, 0, 0.027, -0.044, '#angry', '#disgusting', -0.024, 'fire_engine', 'fire_hydrant', 'street_sign', 'streetlight', 'fire_truck']
senticnet['stop_smoke'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'go_gym', 'work_out', 'eat_right', 'eat_little', 'exercise']
senticnet['stop_stop_sign'] = [-0.035, -0.067, 0.078, -0.16, '#angry', '#disgusting', -0.069, 'honk_horn', 'stop_traffic_light', 'stop_red_light', 'press_brake', 'turn_steer_wheel']
senticnet['stop_suspect'] = [0, 0.769, 0, 0, '#interesting', '#interesting', 0.256, 'direct_traffic', 'traffic_police', 'traffic_jam', 'stop_crime', 'fine_violator']
senticnet['stop_talk'] = [0.708, 0, 0, 0, '#joyful', '#joyful', 0.236, 'shut_up', 'hear_voice', 'listen_news', 'hear_sound', 'ability_hear']
senticnet['stop_talking'] = [0, 0, 0, -0.07, '#disgusting', '#disgusting', -0.023, 'rude', 'end_conversation', 'period', 'end_sentence', 'second']
senticnet['stop_think'] = [0, 0, -0.122, -0.058, '#scared', '#disgusting', -0.06, 'stop_move', 'hit_oneself_head', 'lose_consciousness', 'blackout', 'become_unconscious']
senticnet['stop_traffic_light'] = [0.806, 0.935, 0, 0, '#joyful', '#interesting', 0.58, 'stop_stop_sign', 'honk_horn', 'press_accelerator', 'stop_red_light', 'shift_gear']
senticnet['stop_walk'] = [-0.094, 0, 0.037, 0, '#sad', '#angry', -0.044, 'coordination', 'use_leg', 'act_quickly', 'put_shoes', 'bend_over']
senticnet['stop_watch'] = [-0.022, -0.042, 0.053, -0.115, '#angry', '#disgusting', -0.049, 'stopwatch', 'clock', 'hourglass', 'timepiece', 'watch']
senticnet['stop_work'] = [0, -0.016, 0.017, -0.113, '#angry', '#disgusting', -0.038, 'wind_down', 'take_nap', 'sit_back_relax', 'nap', 'take_rest']
senticnet['stopgap'] = [-0.973, 0, 0.84, -0.528, '#sad', '#angry', -0.78, 'pis_aller', 'last_resort', 'temporary_expedient', 'makeshift', 'expedient']
senticnet['stopper'] = [0.586, -0.589, 0, 0.844, '#surprising', '#admirable', 0.673, 'routine', 'bit', 'number', 'act', 'turn']
senticnet['stopwatch'] = [0.93, 0.841, 0, 0, '#joyful', '#interesting', 0.59, 'clock', 'hourglass', 'watch', 'timepiece', 'hour']
senticnet['storage'] = [0, 0.085, 0.011, 0.119, '#interesting', '#admirable', 0.064, 'store_stuff', 'store_dish', 'store_clothes', 'storage_place', 'hold_cupcake']
senticnet['storage_area'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'inside_house', 'small_room', 'store', 'storage_facility', 'wall']
senticnet['storage_box'] = [0, 0, 0, -0.924, '#disgusting', '#disgusting', -0.308, 'dirty_magazine', 'dust_mite', 'cookie_crumb', 'old_sock', 'dirty_sock']
senticnet['storage_container'] = [0, 0.849, 0, 0.787, '#interesting', '#admirable', 0.545, 'type_of_container', 'food_container', 'metal_container', 'metal_cylinder', 'drink_container']
senticnet['storage_device'] = [0, 0.065, 0.028, 0.153, '#interesting', '#admirable', 0.063, 'media', 'glossy', 'medium', 'symbol', 'written']
senticnet['storage_facility'] = [0.024, 0.17, 0, 0.113, '#interesting', '#admirable', 0.102, 'load_dock', 'storage_place', 'lock_box', 'government_office', 'treasure_chest']
senticnet['storage_furniture'] = [0.05, -0.085, 0, -0.038, '#joyful', '#surprising', 0.032, 'plastic_bag', 'refrigerator', 'tube', 'water_bottle', 'electric_fan']
senticnet['storage_item'] = [0.935, 0.991, 0, 0, '#joyful', '#interesting', 0.642, 'gay_person', 'bikini', 'jeans', 'pair_of_pants', 'dirty_magazine']
senticnet['storage_place'] = [-0.033, 0.069, 0, 0.064, '#interesting', '#admirable', 0.033, 'crate', 'storage', 'storage_facility', 'warehouse', 'sack']
senticnet['storage_space'] = [0, 0.16, 0, 0.217, '#interesting', '#admirable', 0.126, 'group_company', 'neat_tidy', 'hang_clothes', 'arrange', 'clothes_storage']
senticnet['store_belonging'] = [0.722, 0, 0, 0.791, '#joyful', '#admirable', 0.504, 'keep_bathroom_dry', 'sexual_activity', 'privacy', 'red_light_district', 'sexual_pleasure']
senticnet['store_blanket'] = [0, 0.94, 0, 0.813, '#interesting', '#admirable', 0.584, 'store_goods', 'store_dish', 'store_object', 'store_clothes', 'store_junk']
senticnet['store_book'] = [-0.055, 0.077, 0, 0.058, '#interesting', '#admirable', 0.027, 'choose_book', 'ability_read', 'purchase_book', 'sell_book', 'hold_book']
senticnet['store_bottle'] = [0, 0.128, 0.046, 0.1, '#interesting', '#admirable', 0.061, 'sell_store', 'ship_goods', 'increase_value', 'fill_glass', 'lick_finger']
senticnet['store_checkbook'] = [0.023, 0.085, 0, 0.061, '#interesting', '#admirable', 0.056, 'carry_paper', 'store_document', 'organize_document', 'carry_document', 'keep_paper_together']
senticnet['store_cloth'] = [-0.06, -0.028, 0.029, -0.13, '#sad', '#disgusting', -0.064, 'store_dress', 'protective_cover', 'make_suit', 'clothes', 'keep_clothes']
senticnet['store_clothes'] = [0, 0.869, 0, 0.786, '#interesting', '#admirable', 0.552, 'hang_up_clothes', 'clothes_storage', 'clothes', 'hang_clothes', 'storage_space']
senticnet['store_container'] = [-0.041, 0.085, 0.019, 0.085, '#interesting', '#admirable', 0.037, 'reflect_light', 'hue_tint', 'tint', 'red_orange', 'green_yellow']
senticnet['store_data'] = [0, -0.027, 0.137, -0.072, '#angry', '#disgusting', -0.061, 'store_information', 'set_goal', 'go_meet', 'reboot', 'schedule_time']
senticnet['store_dish'] = [0.035, -0.015, 0.009, 0.063, '#joyful', '#admirable', 0.035, 'container', 'jar', 'contain', 'hold_cupcake', 'carton']
senticnet['store_document'] = [0, 0.101, 0, 0, '#interesting', '#interesting', 0.034, 'organize_document', 'carry_paper', 'keep_paper_together', 'bind_paper_together', 'keep_paper']
senticnet['store_dress'] = [-0.036, -0.033, 0.067, 0, '#sad', '#angry', -0.023, 'organize_clothes', 'clothes', 'store_staff', 'item_clothes', 'protective_cover']
senticnet['store_dry_goods'] = [0, 0.133, -0.045, 0.217, '#interesting', '#admirable', 0.102, 'store_stuff', 'hold_small_item', 'hold', 'store_goods', 'hold_stuff']
senticnet['store_file'] = [-0.071, 0.122, 0, 0.081, '#interesting', '#admirable', 0.044, 'store_paper', 'outer', 'star_planet', 'around_earth', 'orbit_earth']
senticnet['store_film'] = [0, 0.772, 0, 0.853, '#interesting', '#admirable', 0.542, 'record_film', 'proof_of_purchase', 'watch_television', 'use_television', 'view_video']
senticnet['store_food'] = [0.08, -0.026, 0.028, 0.057, '#joyful', '#admirable', 0.045, 'keep_food_cool', 'keep_food_spoil', 'prepare_dinner', 'make_cake', 'flavor_food']
senticnet['store_garage'] = [0, 0.135, -0.087, 0.123, '#interesting', '#admirable', 0.057, 'rise', 'lift', 'arise', 'go_upstairs', 'reflect_water']
senticnet['store_goods'] = [0, 0.113, -0.048, 0.216, '#interesting', '#admirable', 0.094, 'store_blanket', 'store_dry_goods', 'store_tool', 'pack_clothes', 'store_object']
senticnet['store_ice'] = [0.793, 0, 0, 0.778, '#joyful', '#admirable', 0.524, 'cool_car_engine', 'keep_cold', 'cool_food', 'keep_cool', 'keep_cool_cream']
senticnet['store_ice_cream'] = [0.071, 0, 0, 0.053, '#joyful', '#admirable', 0.041, 'store_meat', 'store_ice', 'keep_cold', 'hold_soda', 'keep_food_cold']
senticnet['store_information'] = [0.851, 0.781, 0, 0.772, '#joyful', '#interesting', 0.801, 'spread_information', 'record_information', 'learn_spell', 'like_read', 'collect_information']
senticnet['store_item'] = [0, 0.133, 0, 0.173, '#interesting', '#admirable', 0.102, 'hold_cupcake', 'store_dish', 'storage', 'store_object', 'ware']
senticnet['store_junk'] = [0, 0.979, 0, 0.94, '#interesting', '#admirable', 0.64, 'store_goods', 'store_dish', 'store_object', 'store_clothes', 'store_blanket']
senticnet['store_knowledge'] = [0, 0.133, 0, 0.173, '#interesting', '#admirable', 0.102, 'store', 'knowledge', 'gain_information', 'study', 'earn_knowledge']
senticnet['store_liquid'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'hold_liquid', 'hold_soda', 'serve_wine', 'hold_beverage', 'drink']
senticnet['store_meat'] = [0.069, 0, 0, 0, '#joyful', '#joyful', 0.023, 'store_ice_cream', 'keep_drink_cold', 'store_ice', 'keep_cold', 'hold_soda']
senticnet['store_money'] = [0, 0.183, 0, 0.079, '#interesting', '#admirable', 0.087, 'hold_money', 'require_signature', 'money_holder', 'money_storage', 'save_money']
senticnet['store_music'] = [-0.044, 0.182, -0.081, 0.139, '#interesting', '#admirable', 0.065, 'music_storage', 'groove', 'cassette', 'seventy', 'keep_track']
senticnet['store_object'] = [0, 0.106, -0.084, 0.145, '#interesting', '#admirable', 0.056, 'hold_many', 'keep_stuff', 'decide_want', 'sell_insurance', 'try']
senticnet['store_paper'] = [-0.056, 0.14, 0, 0.061, '#interesting', '#admirable', 0.048, 'store_file', 'store_document', 'keep_paper', 'hold_paper', 'partition']
senticnet['store_pen'] = [0, 0.091, 0, 0.079, '#interesting', '#admirable', 0.057, 'hold_document', 'make_note', 'hold_paper', 'write_paper', 'write_word']
senticnet['store_photo'] = [0.994, 0.924, 0, 0.926, '#joyful', '#admirable', 0.948, 'stressful_situation', 'chamber_music', 'beautiful_music', 'music', 'part_of_band']
senticnet['store_record'] = [0, 0.091, 0, 0.079, '#interesting', '#admirable', 0.057, 'record', 'store', 'music_storage', 'store_music', 'list_item']
senticnet['store_refrigerator'] = [0.045, -0.053, 0, -0.029, '#joyful', '#surprising', 0.023, 'refrigerator', 'cold_storage', 'icebox', 'restaurant_storage_area', 'icy']
senticnet['store_shelf'] = [0.095, 0, 0, 0, '#joyful', '#joyful', 0.032, 'shop_bag', 'coffee_cup', 'bag', 'plastic', 'plastic_bag']
senticnet['store_shoes'] = [-0.059, -0.013, 0.062, 0, '#sad', '#angry', -0.036, 'store_dress', 'keep_clothes', 'organize_clothes', 'hang_hanger', 'wear_clothes']
senticnet['store_staff'] = [-0.036, -0.033, 0.067, 0, '#sad', '#angry', -0.023, 'organize_clothes', 'clothes', 'store_dress', 'item_clothes', 'protective_cover']
senticnet['store_stuff'] = [0, 0.109, 0, 0.189, '#interesting', '#admirable', 0.099, 'hold_stuff', 'store_dry_goods', 'storage', 'hold_cupcake', 'keep_safe']
senticnet['store_tool'] = [0, 0.16, -0.076, 0.255, '#interesting', '#admirable', 0.113, 'car_action', 'store_goods', 'move_object', 'conveyance', 'hold_stuff']
senticnet['store_towel'] = [0.118, 0.128, 0, 0.132, '#interesting', '#admirable', 0.126, 'store_stuff', 'store_clothes', 'storage', 'store_dry_goods', 'hold_stuff']
senticnet['store_trash'] = [0.982, 0.742, 0, 0, '#joyful', '#interesting', 0.575, 'hold_trash', 'put_garbage', 'garbage', 'rubbish', 'put_trash']
senticnet['store_vegetable'] = [0.072, 0.144, 0, 0.168, '#interesting', '#admirable', 0.128, 'groceries', 'vegetable_fruit', 'fruit_vegetable', 'fresh_vegetable', 'vegetarian_food']
senticnet['storied'] = [-0.838, 0, 0.896, -0.959, '#angry', '#disgusting', -0.898, 'glorious', 'incandescent', 'higlorious', 'divine', 'empyreal']
senticnet['stork'] = [-0.029, 0, -0.057, 0, '#sad', '#scared', -0.029, 'wren', 'bird', 'quail', 'sparrow', 'chick']
senticnet['storm'] = [-0.782, 0, 0.906, -0.545, '#sad', '#angry', -0.744, 'rainstorm', 'atmospheric_phenomenon', 'northeaster', 'noreaster', 'hailstorm']
senticnet['storm_castle'] = [-0.038, 0, 0, -0.062, '#sad', '#disgusting', -0.033, 'storm_fortress', 'advance_battle', 'fight_war', 'fight_enemy', 'wage_war']
senticnet['storm_center'] = [-0.71, 0, 0.71, -0.675, '#sad', '#angry', -0.698, 'hurly_burly', 'kerfuffle', 'commotion', 'disruption', 'disturbance']
senticnet['storm_fortress'] = [-0.043, -0.008, 0, -0.08, '#sad', '#disgusting', -0.038, 'fight_war', 'wage_war', 'fight_enemy', 'advance_battle', 'conquer_nation']
senticnet['storm_out_room'] = [0.84, 0.721, 0, 0, '#joyful', '#interesting', 0.52, 'sail_around_world', 'voice_concern', 'forward_email', 'deal_card_player', 'speak_english']
senticnet['storminess'] = [-0.699, 0, 0.835, -0.562, '#sad', '#angry', -0.699, 'roughness', 'inclemency', 'bad_weather', 'inclementness', 'windiness']
senticnet['stormproof'] = [-0.898, 0, 0.627, -0.547, '#sad', '#angry', -0.691, 'shielded', 'weatherproof', 'covert', 'protected', 'fortified']
senticnet['stormy'] = [0.126, 0, 0, 0, '#joyful', '#joyful', 0.042, 'natural_phenomenon', 'rain_wind', 'rain_storm', 'weather_phenomenon', 'weather_type']
senticnet['story'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'fable', 'long_story', 'novel', 'saga', 'editorial']
senticnet['storyteller'] = [-0.633, 0, 0.88, -0.941, '#angry', '#disgusting', -0.818, 'beguiler', 'slicker', 'perjurer', 'false_witness', 'prevaricator']
senticnet['stout'] = [0.209, -0.027, 0, 0, '#joyful', '#surprising', 0.079, 'old_dance', 'dance', 'slow_dance', 'dancer', 'enter_contest']
senticnet['stoutness'] = [-0.728, 0, 0.973, -0.579, '#sad', '#angry', -0.76, 'exogenous_obesity', 'blubber', 'fat', 'embonpoint', 'corpulency']
senticnet['stow_away'] = [-0.091, 0, -0.141, 0.086, '#sad', '#scared', -0.049, 'set_aside', 'put_away', 'push_aside', 'preserve', 'leave']
senticnet['strabismus'] = [-0.88, 0, 0.762, -0.525, '#sad', '#angry', -0.722, 'divergent_strabismus', 'exotropia', 'walleye', 'abnormality', 'abnormalcy']
senticnet['straggler'] = [-0.648, 0, 0.879, -0.98, '#angry', '#disgusting', -0.836, 'drone', 'poke', 'dawdler', 'laggard', 'lagger']
senticnet['straight'] = [0.844, 0, 0, 0, '#joyful', '#joyful', 0.281, 'ahead', 'late_time', 'preparedness', 'past_present', 'wait']
senticnet['straight_line'] = [-0.041, 0.074, 0.019, 0.071, '#interesting', '#admirable', 0.028, 'sharpness', 'sharp_end', 'sharp_corner', 'near_end', 'edge']
senticnet['straighten_hair'] = [0, -0.053, 0.016, 0.053, '#surprising', '#admirable', 0.03, 'dress_nice', 'improve_image', 'change_appearance', 'haircut', 'dye_hair']
senticnet['straightforward'] = [0.033, 0.125, 0, 0.131, '#interesting', '#admirable', 0.096, 'direction', 'compass_direction', 'indicate', 'end_point', 'red_light']
senticnet['strain'] = [-0.084, -0.032, -0.076, -0.137, '#sad', '#disgusting', -0.088, 'injury', 'soreness', 'pain', 'hurt', 'dislocation']
senticnet['strain_muscle'] = [-0.096, -0.063, 0.035, -0.102, '#sad', '#disgusting', -0.057, 'get_sweaty', 'pull_muscle', 'tired_leg', 'physical_exertion', 'sweat']
senticnet['straining'] = [-0.59, 0, 0.942, -0.727, '#angry', '#disgusting', -0.753, 'sweat', 'effort', 'elbow_grease', 'exertion', 'travail']
senticnet['straiten'] = [-0.692, 0, 0.804, -0.589, '#sad', '#angry', -0.695, 'discommode', 'incommode', 'inconvenience', 'put_out', 'disoblige']
senticnet['straitjacket'] = [-0.964, 0, 0.581, -0.792, '#sad', '#disgusting', -0.779, 'deterrent', 'handicap', 'balk', 'baulk', 'impediment']
senticnet['strand'] = [-0.887, 0, 0.693, -0.838, '#sad', '#disgusting', -0.806, 'maroon', 'desolate', 'walk_out', 'expose', 'ditch']
senticnet['strange'] = [0, 0, 0, -0.801, '#disgusting', '#disgusting', -0.267, 'uneducated', 'homophobic', 'guilty_crime', 'weird', 'uncanny']
senticnet['strangeness'] = [-0.561, 0, 0.977, -0.869, '#angry', '#disgusting', -0.802, 'freakishness', 'quaintness', 'abnormality', 'queerness', 'crotchet']
senticnet['stranger'] = [-0.978, 0, 0.783, -0.601, '#sad', '#angry', -0.787, 'outsider', 'foreigner', 'intruder', 'interloper', 'trespasser']
senticnet['strangle'] = [0, 0, 0, -0.773, '#disgusting', '#disgusting', -0.258, 'hear_bad_news', 'stab_knife', 'broken_finger', 'imprisonment', 'black_eye']
senticnet['strap'] = [0.892, 0.712, 0, 0, '#joyful', '#interesting', 0.535, 'mitten', 'man_clothes', 'bra', 'gauntlet', 'tie']
senticnet['strategize'] = [-0.072, -0.02, 0.066, -0.091, '#sad', '#disgusting', -0.07, 'strategy', 'try_best', 'roll_dice', 'lose_game', 'try_win']
senticnet['strategy'] = [0.681, -0.851, 0, 0.605, '#joyful', '#surprising', 0.712, 'contrivance', 'bubble', 'house_of_cards', 'stratagem', 'waiting_game']
senticnet['stratified_sampling'] = [0.956, -0.839, 0, 0.755, '#joyful', '#surprising', 0.85, 'choice', 'option', 'random_sampling', 'sampling', 'representative_sampling']
senticnet['straw'] = [0.771, 0, 0, 0.85, '#joyful', '#admirable', 0.54, 'part_of_dinner', 'drink_water', 'ethanol', 'lemonade', 'beer']
senticnet['straw_man'] = [-0.921, 0, 0.952, -0.679, '#sad', '#angry', -0.851, 'beguiler', 'slicker', 'deceiver', 'cheat', 'cheater']
senticnet['strawberry_jam'] = [-0.61, 0, 0.513, -0.976, '#sad', '#disgusting', -0.7, 'conserve', 'preserve', 'jam', 'strawberry_preserves', 'conserves']
senticnet['strawberry_preserves'] = [-0.61, 0, 0.513, -0.976, '#sad', '#disgusting', -0.7, 'conserve', 'preserve', 'strawberry_jam', 'jam', 'conserves']
senticnet['strawflower'] = [-0.934, 0, 0.691, -0.971, '#sad', '#disgusting', -0.865, 'cudweed', 'everlasting_flower', 'composite', 'composite_plant', 'pink_paper_daisy']
senticnet['strawman'] = [-0.952, 0, 0.625, -0.719, '#sad', '#disgusting', -0.765, 'beguiler', 'slicker', 'deceiver', 'cheat', 'cheater']
senticnet['stray'] = [0, 0.077, 0, 0.092, '#interesting', '#admirable', 0.056, 'stay_in_house', 'follow_person', 'cause_accident', 'mark_territory', 'jump_up']
senticnet['strayer'] = [-0.51, 0, 0.757, -0.511, '#angry', '#disgusting', -0.593, 'drone', 'poke', 'dawdler', 'laggard', 'lagger']
senticnet['streak'] = [-0.663, 0, 0.616, -0.708, '#sad', '#disgusting', -0.662, 'flicker', 'coruscation', 'flash', 'glint', 'gleam']
senticnet['stream_ocean'] = [0, 0, 0, 0.073, '#admirable', '#admirable', 0.024, 'reflect_image', 'stream_river', 'pour', 'cool_car_engine', 'liquid_drink']
senticnet['stream_river'] = [0, 0, 0, 0.073, '#admirable', '#admirable', 0.024, 'reflect_image', 'stream_ocean', 'pour', 'cool_car_engine', 'liquid_drink']
senticnet['streamer'] = [0.176, -0.121, -0.125, 0.182, '#joyful', '#admirable', 0.118, 'invitation', 'tribute', 'debut', 'dance', 'alcohol']
senticnet['street'] = [0.078, 0.088, -0.071, 0, '#joyful', '#interesting', 0.032, 'wide_street', 'freeway', 'small_street', 'country_road', 'road']
senticnet['street_child'] = [-0.531, 0, 0.891, -0.843, '#angry', '#disgusting', -0.755, 'fry', 'kid', 'minor', 'tike', 'small_fry']
senticnet['street_city'] = [0, 0, 0.078, 0, '#angry', '#angry', -0.026, 'black_pavement', 'small_street', 'walkway', 'pave', 'dark_road']
senticnet['street_corner'] = [0, 0, 0.018, -0.07, '#angry', '#disgusting', -0.029, 'corner_two_streets', 'city_street', 'junction', 'junk_yard', 'street']
senticnet['street_light'] = [0.038, 0.116, 0, 0.095, '#interesting', '#admirable', 0.083, 'road_sign', 'traffic_sign', 'panhandler', 'street_sign', 'intersection']
senticnet['street_sign'] = [0.038, 0.116, 0, 0.095, '#interesting', '#admirable', 0.083, 'road_sign', 'traffic_sign', 'panhandler', 'street_light', 'intersection']
senticnet['streetlight'] = [0.919, 0.838, 0, 0, '#joyful', '#interesting', 0.586, 'grass_clipping', 'homeless_people', 'litter', 'fallen_leaf', 'traffic_light']
senticnet['strength'] = [0, 0.967, 0, 0.702, '#interesting', '#admirable', 0.556, 'physical_strength', 'power', 'force', 'like_electricity', 'form_of_energy']
senticnet['strengthen'] = [0.669, -0.814, 0, 0.515, '#joyful', '#surprising', 0.666, 'undergird', 'secure', 'reenforce', 'vitalize', 'reinforce']
senticnet['strengthen_heart'] = [0.08, -0.063, 0.045, 0, '#joyful', '#surprising', 0.033, 'build_endurance', 'get_physically_fit', 'keep_fit', 'enjoy_outdoors', 'keep_shape']
senticnet['strengthen_muscle'] = [0.879, 0.91, 0, 0, '#joyful', '#interesting', 0.596, 'build_strength', 'feel_better_oneself', 'become_better', 'improvement', 'increase_energy']
senticnet['strengthful'] = [0.915, 0.719, 0, 0, '#joyful', '#interesting', 0.545, 'bad_knee', 'injury', 'bruise', 'broken_bone', 'hurt']
senticnet['strenuosity'] = [-0.709, 0, 0.703, -0.534, '#sad', '#angry', -0.649, 'athleticism', 'vigor', 'forcefulness', 'force', 'strength']
senticnet['strenuous'] = [0.138, -0.018, 0, 0.051, '#joyful', '#admirable', 0.069, 'competition', 'winter_sport', 'recreational', 'competitive', 'give_dog_exercise']
senticnet['strenuousness'] = [-0.646, 0, 0.928, -0.703, '#angry', '#disgusting', -0.759, 'difficulty', 'arduousness', 'effortfulness', 'laboriousness', 'operoseness']
senticnet['strep_throat'] = [-0.909, 0, 0.636, -0.959, '#sad', '#disgusting', -0.835, 'pain', 'hurt', 'injury', 'take_medicine', 'need_cure']
senticnet['streptococcal_sore_throat'] = [-0.821, 0, 0.609, -0.89, '#sad', '#disgusting', -0.773, 'inflammatory_disease', 'pharyngitis', 'strep_throat', 'streptococcus_tonsilitis', 'septic_sore_throat']
senticnet['streptococcus_tonsilitis'] = [-0.821, 0, 0.609, -0.89, '#sad', '#disgusting', -0.773, 'inflammatory_disease', 'streptococcal_sore_throat', 'strep_throat', 'pharyngitis', 'septic_sore_throat']
senticnet['stress'] = [-0.788, 0, 0, -0.858, '#sad', '#disgusting', -0.549, 'stressful_job', 'lose_sleep', 'hate_boss', 'a_lot_of_stress', 'lose_hair']
senticnet['stress_incontinence'] = [-0.776, 0, 0.966, -0.518, '#sad', '#angry', -0.753, 'overflow_incontinence', 'incontinency', 'incontinence', 'enuresis', 'urge_incontinence']
senticnet['stress_out'] = [-0.177, -0.028, -0.049, -0.162, '#sad', '#disgusting', -0.12, 'lose_wallet', 'go_debt', 'meet_friends', 'push_cart', 'walk_exercise']
senticnet['stress_reduction'] = [0.846, 0.976, 0, 0.766, '#joyful', '#interesting', 0.863, 'feel_relaxed', 'relax_muscle', 'become_relaxed', 'stress_relief', 'relax']
senticnet['stress_relief'] = [0.845, 0, 0, 0.813, '#joyful', '#admirable', 0.553, 'sense_peace', 'stress_reduction', 'reduce_stress', 'feel_happy', 'relaxation']
senticnet['stressed'] = [0.921, 0.817, 0, 0, '#joyful', '#interesting', 0.579, 'end_conversation', 'sad', 'uncomfortable', 'hang_up', 'commit_suicide']
senticnet['stressful'] = [-0.861, 0, 0.547, -0.671, '#sad', '#disgusting', -0.693, 'dreadful', 'vexing', 'harsh', 'disagreeable', 'trying']
senticnet['stressful_job'] = [-0.125, 0.084, -0.198, -0.125, '#sad', '#scared', -0.121, 'medical_person', 'call_doctor', 'physician', 'treat_illness', 'patient']
senticnet['stressful_situation'] = [0.062, -0.037, 0.116, -0.096, '#angry', '#disgusting', -0.038, 'bad_music', 'noise', 'stress', 'a_lot_of_work', 'crying_baby']
senticnet['stretch'] = [-0.106, -0.008, 0.023, 0, '#sad', '#angry', -0.04, 'put_running_shoes', 'put_jogging_shoes', 'run_slowly', 'wear_good_shoes', 'wear_running_shoes']
senticnet['stretch_first'] = [-0.054, -0.008, 0.035, 0, '#sad', '#angry', -0.027, 'put_tennis_shoes', 'join_gym', 'run_long_distance', 'stretch_muscle', 'run']
senticnet['stretch_leg'] = [0.07, 0, 0.032, 0.054, '#joyful', '#admirable', 0.031, 'get_out', 'move_body', 'get_fresh_air', 'active', 'move_around']
senticnet['stretch_muscle'] = [0.07, 0, 0.032, 0.054, '#joyful', '#admirable', 0.031, 'muscle', 'exercise', 'jogging', 'warm_up', 'stretch_out']
senticnet['stretch_out'] = [0, 0.08, 0, 0.117, '#interesting', '#admirable', 0.066, 'stand_still', 'go_home', 'pull_out', 'advance_civilization', 'stretch']
senticnet['stretchy'] = [-0.043, -0.052, 0, 0.112, '#surprising', '#admirable', 0.04, 'child_toy', 'toy', 'dark_corner', 'spherical_shape', 'stretch']
senticnet['striated_muscle'] = [0.95, -0.626, 0, 0.756, '#joyful', '#admirable', 0.777, 'voluntary_muscle', 'deltoid', 'pterygoid_muscle', 'abductor', 'abductor_muscle']
senticnet['strict'] = [-0.031, 0.197, -0.132, 0.233, '#interesting', '#admirable', 0.089, 'axiom', 'govern', 'kingly', 'obedience', 'control']
senticnet['stricture'] = [-0.56, 0, 0.806, -0.762, '#angry', '#disgusting', -0.709, 'rhinostenosis', 'enterostenosis', 'laryngostenosis', 'aortic_stenosis', 'mitral_stenosis']
senticnet['strident'] = [0, 0, -0.933, -0.947, '#scared', '#disgusting', -0.627, 'fricative', 'clamant', 'clamorous', 'blatant', 'vociferous']
senticnet['strike'] = [-0.909, 0, 0.636, -0.959, '#sad', '#disgusting', -0.835, 'beat', 'crash', 'knock', 'force', 'collide']
senticnet['strike_against'] = [0.087, 0.113, -0.087, 0, '#joyful', '#interesting', 0.038, 'matchbox', 'find_match', 'cigarette_lighter', 'match', 'use_lighter']
senticnet['strike_ball'] = [0, 0, -0.808, -0.833, '#scared', '#disgusting', -0.547, 'leg_hurt', 'dog_bite', 'get_injured', 'become_exhausted', 'broken_leg']
senticnet['strike_blow'] = [0.965, -0.661, 0, 0.776, '#joyful', '#admirable', 0.801, 'bear_upon', 'affect', 'impact', 'bear_on', 'touch']
senticnet['strike_down'] = [-0.654, 0, 0.561, -0.58, '#sad', '#disgusting', -0.598, 'stet', 'set_aside', 'break', 'cancel', 'annul']
senticnet['strike_match'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'rub_two_stick_together', 'cigarette_lighter', 'light_cigarette', 'light_match', 'magnify_glass']
senticnet['strike_out'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'run_first_base', 'throw_ball', 'score_point', 'score_goal', 'stand_around']
senticnet['string'] = [-0.024, -0.037, 0.061, -0.076, '#angry', '#disgusting', -0.041, 'filament', 'thread', 'suture', 'rope', 'cord']
senticnet['string_break'] = [0.062, -0.138, 0.16, -0.185, '#angry', '#disgusting', -0.048, 'fail', 'broken', 'sound_bad', 'bad', 'make_sound']
senticnet['string_quartet'] = [-0.045, -0.043, -0.045, -0.05, '#sad', '#scared', -0.032, 'high_school_band', 'music_shop', 'drum_set', 'music_concert', 'music_store']
senticnet['string_quartette'] = [0.552, -0.61, 0, 0.588, '#surprising', '#admirable', 0.583, 'barbershop_quartet', 'string_quartet', 'quartette', 'musical_organization', 'musical_group']
senticnet['string_up'] = [0.733, -0.711, 0, 0.877, '#joyful', '#admirable', 0.774, 'crucify', 'kill', 'burn', 'hang', 'put_to_death']
senticnet['stringed_musical_instrument'] = [-0.036, -0.009, 0.018, -0.082, '#sad', '#disgusting', -0.042, 'reed_instrument', 'use_jazz_music', 'instrument_music', 'musical_instrument', 'listen_music']
senticnet['stringent'] = [-0.756, 0, 0.982, -0.958, '#angry', '#disgusting', -0.899, 'needy', 'demanding', 'stern', 'exacting', 'exigent']
senticnet['stringy'] = [-0.961, 0, 0.939, -0.605, '#sad', '#angry', -0.835, 'airy', 'shadowy', 'insubstantial', 'wraithlike', 'ethereal']
senticnet['strip'] = [0, 0, -0.091, -0.044, '#scared', '#disgusting', -0.045, 'naked', 'remove_clothes', 'make_appointment_with_doctor', 'disrobe', 'turn_head_cough']
senticnet['strip_club'] = [0.103, 0, 0, 0, '#joyful', '#joyful', 0.034, 'restaurant', 'brewery', 'club', 'pool_hall', 'men_club']
senticnet['strip_joint'] = [0, 0, -0.102, 0, '#scared', '#scared', -0.034, 'television_station', 'hockey_rink', 'movie_theater', 'movie_studio', 'wedding_ceremony']
senticnet['strip_show'] = [0.993, -0.967, 0, 0.917, '#joyful', '#surprising', 0.959, 'strip', 'fan_dance', 'striptease', 'nude_dancing', 'bubble_dance']
senticnet['stripe'] = [0.942, -0.61, 0, 0.908, '#joyful', '#admirable', 0.82, 'adornment', 'cigar_band', 'hatband', 'neckband', 'pinstripe']
senticnet['striped'] = [-0.054, 0, 0.047, 0, '#sad', '#angry', -0.034, 'animal_skin', 'waterproof', 'white_soft', 'animal_hide', 'fuzzy']
senticnet['striped_skunk'] = [-0.547, 0, 0.768, -0.503, '#sad', '#angry', -0.606, 'polecat', 'hooded_skunk', 'hognosed_skunk', 'badger_skunk', 'rooter_skunk']
senticnet['stripper'] = [0.783, 0.747, 0, 0, '#joyful', '#interesting', 0.51, 'pervert', 'healthy_person', 'philanthropist', 'arsonist', 'nazi']
senticnet['strive'] = [0.184, 0.263, -0.12, 0.329, '#interesting', '#admirable', 0.219, 'wear_necklace', 'list_item', 'experience_life', 'talk_oneself', 'cross_room']
senticnet['stroke'] = [-0.909, 0, 0.636, -0.959, '#sad', '#disgusting', -0.835, 'heart_attack', 'disease', 'hit', 'shock', 'smash']
senticnet['stroll'] = [0, 0.78, 0, 0.954, '#interesting', '#admirable', 0.578, 'walk_along', 'gait', 'take_step', 'run_slowly', 'locomotion']
senticnet['strong'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'durable', 'rigid', 'sturdy', 'hard', 'heavy']
senticnet['strong_body'] = [0, 0, 0, 0.744, '#admirable', '#admirable', 0.248, 'live_long_healthy_life', 'live_ripe_old_age', 'live_healthy_life', 'live_well', 'long_lifespan']
senticnet['strong_desire'] = [0.035, 0.388, -0.311, 0.334, '#interesting', '#admirable', 0.149, 'want_badly', 'yearn', 'essential', 'dream', 'needful']
senticnet['strong_dislike'] = [-0.906, 0, 0.48, -0.998, '#sad', '#disgusting', -0.795, 'deep_resentment', 'hate', 'hatred', 'enemy', 'animosity']
senticnet['strong_drink'] = [0.071, 0, 0, 0, '#joyful', '#joyful', 0.024, 'alcoholic_drink', 'alcoholic_beverage', 'fizzy', 'popular_soda', 'ferment_beverage']
senticnet['strong_emotion'] = [0, 1, 0, 0, '#interesting', '#interesting', 0.333, 'interest', 'interesting', 'mood', 'attention', 'emotion']
senticnet['strong_endurance'] = [0.856, 0.928, 0, 0.828, '#joyful', '#interesting', 0.871, 'sport', 'endurance_exercise', 'champion', 'win_marathon', 'competition']
senticnet['strong_feeling'] = [0, 0.069, 0, 0.108, '#interesting', '#admirable', 0.059, 'desire_entertain', 'good_emotion', 'love', 'strong_emotion', 'love_another_person']
senticnet['strong_material'] = [0.03, 0, 0.021, 0.065, '#joyful', '#admirable', 0.025, 'hard_rock', 'elements', 'silver', 'magnetic', 'tin_aluminium']
senticnet['strong_muscle'] = [0.068, 0, 0.027, 0.079, '#joyful', '#admirable', 0.04, 'eat_little', 'eat_right', 'exercise_regularly', 'exercise', 'eat_healthy']
senticnet['strong_pain'] = [-0.917, 0, 0.513, -0.932, '#sad', '#disgusting', -0.787, 'cause_someone_embarrassment', 'cause_bleeding', 'cause_strong_pain', 'kill_person', 'beat_person']
senticnet['strong_person'] = [0.034, 0.066, 0, 0, '#joyful', '#interesting', 0.033, 'big_guy', 'strength', 'fearless', 'wrestler', 'body_building']
senticnet['strong_personality'] = [0, 0.819, 0, 0.924, '#interesting', '#admirable', 0.581, 'character', 'personality', 'computer_type', 'riddle', 'mystery']
senticnet['strong_relationship'] = [0.568, 0.302, -0.118, 0.39, '#joyful', '#admirable', 0.381, 'good_sense_of_humor', 'world_peace', 'complement', 'run_business', 'develop_talent']
senticnet['strong_smell'] = [-0.027, -0.044, -0.092, -0.272, '#scared', '#disgusting', -0.116, 'poison', 'nuclear_weapon', 'shoot', 'explosive', 'grenade']
senticnet['strong_suit'] = [0.553, -0.8, 0, 0.908, '#surprising', '#admirable', 0.754, 'long_suit', 'collection', 'aggregation', 'accumulation', 'assemblage']
senticnet['strong_taste'] = [0.152, 0.099, -0.07, 0.107, '#joyful', '#admirable', 0.096, 'dark_beer', 'ale', 'cocktail', 'convulse', 'beer']
senticnet['strong_wind'] = [-0.039, -0.02, 0, -0.122, '#sad', '#disgusting', -0.047, 'gore', 'wind', 'cover_fur', 'heal_wind', 'welt']
senticnet['stronghold'] = [0.08, 0.228, 0, 0.135, '#interesting', '#admirable', 0.148, 'secure', 'hold_coin', 'money_collector', 'safe_place', 'safe']
senticnet['structural_support'] = [-0.031, 0.112, -0.076, 0.144, '#interesting', '#admirable', 0.05, 'dog_toy', 'dog_treat', 'human_part', 'body_organ', 'in_person']
senticnet['structure'] = [0.061, 0.179, 0, 0.177, '#interesting', '#admirable', 0.139, 'construction', 'large_structure', 'support_wall', 'place_where_people_live', 'edifice']
senticnet['struggle'] = [-0.13, -0.047, -0.082, -0.164, '#sad', '#disgusting', -0.11, 'conflict', 'big_fight', 'fight', 'combat', 'clash']
senticnet['strum'] = [0, -0.038, 0.082, -0.067, '#angry', '#disgusting', -0.037, 'make_noise', 'make_sound', 'low_note', 'play_song', 'make_music']
senticnet['strut'] = [0, 0.075, 0, 0.2, '#interesting', '#admirable', 0.092, 'stride', 'foot_motion', 'gait', 'foot_action', 'foot_movement']
senticnet['stub_toe'] = [0, 0, -0.901, 0, '#scared', '#scared', -0.3, 'suffer_fool', 'disrespect', 'cause_suffer', 'lose_team', 'lyme_disease']
senticnet['stubborn'] = [0, 0, -0.901, 0, '#scared', '#scared', -0.3, 'obstinate', 'persistent', 'pigheaded', 'mulish', 'headstrong']
senticnet['stubbornness'] = [-0.633, 0, 0.942, -0.528, '#sad', '#angry', -0.701, 'impenitence', 'obstinacy', 'obstinance', 'bullheadedness', 'pigheadedness']
senticnet['stuck'] = [-0.633, 0, 0.829, -0.794, '#angry', '#disgusting', -0.752, 'stuffiness', 'blocked', 'problem', 'traffic', 'congestion']
senticnet['student_home'] = [0, 0, 0.012, -0.063, '#angry', '#disgusting', -0.025, 'shack', 'cabin', 'hostel', 'dormitory', 'college_dorm']
senticnet['student_place'] = [0.053, -0.12, 0.015, -0.036, '#joyful', '#surprising', 0.041, 'after_school', 'learning_place', 'school_session', 'campus', 'professor']
senticnet['student_study'] = [0, -0.005, 0.049, -0.063, '#angry', '#disgusting', -0.036, 'educational_place', 'place_learn', 'educational_facility', 'learning_place', 'educational_institution']
senticnet['studio'] = [-0.025, 0, -0.049, -0.031, '#scared', '#disgusting', -0.035, 'art_gallery', 'art_piece', 'visual_communication', 'artist', 'museum']
senticnet['study'] = [0.061, 0.179, 0, 0.177, '#interesting', '#admirable', 0.139, 'study_lot', 'go_to_school', 'pass_exam', 'prepare_exam', 'go_to_university']
senticnet['study_abroad'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'overseas', 'another_country', 'abroad', 'elsewhere', 'live_abroad']
senticnet['study_animal'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'read_book', 'explore_nature', 'study', 'read_science_book', 'watch_animal_documentary']
senticnet['study_biology'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'question_teacher', 'guess_answer', 'finish_test', 'study_library', 'solve_equation']
senticnet['study_book'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'read_story', 'sleep_back', 'learn_read', 'turn_light', 'study_library']
senticnet['study_carefully'] = [-0.051, 0.105, 0, 0.064, '#interesting', '#admirable', 0.039, 'dance_joy', 'bind_agreement', 'absolutely', 'balance_check_account', 'perform_service']
senticnet['study_course_material'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'study', 'work_hard', 'study_lot', 'go_class', 'study_material']
senticnet['study_fact'] = [0.796, 0.998, 0, 0, '#joyful', '#interesting', 0.598, 'come_up_new_idea', 'reach_conclusion', 'analysis', 'come_up_idea', 'make_right_decision']
senticnet['study_for_exam'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'prepare_exam', 'study', 'pass_test', 'study_hard', 'pass_exam']
senticnet['study_group'] = [-0.049, 0, -0.1, 0, '#sad', '#scared', -0.05, 'further_education', 'play_golf', 'help_another_person', 'teach_class', 'group_student']
senticnet['study_hard'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'pass_exam', 'finish_college', 'get_degree', 'prepare_exam', 'study_lot']
senticnet['study_history'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'study', 'read_history_book', 'history', 'prepare_exam', 'pass_exam']
senticnet['study_language'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'study', 'language', 'read_english_book', 'wanderlust', 'discover_new_culture']
senticnet['study_library'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'borrow_book_from_library', 'study', 'prepare_exam', 'read_book', 'library']
senticnet['study_lot'] = [-0.089, -0.01, 0, -0.125, '#sad', '#disgusting', -0.068, 'a_lot_of_study', 'study_material', 'revise', 'study_course_material', 'study_hard']
senticnet['study_material'] = [-0.1, 0, 0, -0.115, '#sad', '#disgusting', -0.072, 'revise', 'study_lot', 'a_lot_of_study', 'study_hard', 'know_stuff']
senticnet['study_math'] = [0.031, 0.07, 0.025, 0.07, '#interesting', '#admirable', 0.049, 'use_computer', 'use_technology', 'calculator', 'use_calculator', 'math_exercises']
senticnet['study_medicine'] = [0, 0.933, 0, 0.843, '#interesting', '#admirable', 0.592, 'pass_exam', 'become_nurse', 'become_doctor', 'go_to_school', 'medical_school']
senticnet['study_of_life'] = [0, -0.131, -0.053, 0.08, '#surprising', '#admirable', 0.053, 'science', 'school', 'student', 'study_material', 'biology_book']
senticnet['study_of_structure'] = [0, 0.078, 0, 0.096, '#interesting', '#admirable', 0.058, 'animal', 'anatomy', 'body_organ', 'analysis', 'human_organ']
senticnet['study_person'] = [-0.071, 0, 0.013, -0.069, '#sad', '#disgusting', -0.051, 'subject_study', 'subject', 'school_course', 'school_class', 'geology']
senticnet['study_physic'] = [-0.156, 0, -0.128, -0.135, '#sad', '#disgusting', -0.14, 'fail_test', 'guess_answer', 'succeed_school', 'master_new_skill', 'question_teacher']
senticnet['study_science'] = [0, 0.873, 0, 0, '#interesting', '#interesting', 0.291, 'look_up_dictionary_word', 'borrow_book_from_library', 'read_book', 'read_science_book', 'prepare_exam']
senticnet['study_subject'] = [0.798, 0.754, 0, 0.779, '#joyful', '#admirable', 0.777, 'learn_science', 'take_course', 'attend_class', 'learn_subject', 'memorize']
senticnet['study_test'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'pass_test', 'study_material', 'test', 'study_hard', 'pass_exam']
senticnet['stuff'] = [0.057, 0.141, -0.064, 0.162, '#interesting', '#admirable', 0.099, 'belongings', 'thing', 'personal_item', 'guarantee', 'madonna']
senticnet['stuff_and_nonsense'] = [-0.683, 0, 0.956, -0.723, '#angry', '#disgusting', -0.787, 'meaninglessness', 'nonsense', 'bunk', 'nonsensicality', 'hokum']
senticnet['stuff_animal'] = [0, -0.16, 0, 0, '#surprising', '#surprising', 0.053, 'toy', 'action_figure', 'toy_soldier', 'toy_car', 'beanie_baby']
senticnet['stuff_face'] = [0, 0, 0.042, -0.047, '#angry', '#disgusting', -0.03, 'make_sandwich', 'eat_potato_chip', 'eat', 'munch', 'able_eat']
senticnet['stuff_pillow'] = [0.033, -0.073, 0, 0, '#joyful', '#surprising', 0.035, 'girdle', 'write_suicide_note', 'write', 'witting', 'become_dull']
senticnet['stuff_use_calculation'] = [0, 0.066, 0.06, 0.075, '#interesting', '#admirable', 0.027, 'viewer', 'capoeira_angola', 'dwarf_planet', 'bluetooth', 'ridgeback']
senticnet['stuffiness'] = [-0.633, 0, 0.829, -0.794, '#angry', '#disgusting', -0.752, 'congestion', 'blocked', 'problem', 'traffic', 'stuck']
senticnet['stultify'] = [0.687, -0.842, 0, 0.513, '#joyful', '#surprising', 0.681, 'shew', 'prove', 'demonstrate', 'show', 'establish']
senticnet['stumble'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'come_across', 'tripped_over', 'lose_balance', 'stammer', 'stutter']
senticnet['stun'] = [0, 0, 0.88, -0.963, '#angry', '#disgusting', -0.614, 'dazed', 'stunned', 'stupefied', 'stupefy', 'dumbstricken']
senticnet['stung'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['stunned'] = [0, -0.596, -0.049, 0.331, '#surprising', '#admirable', 0.293, 'stupefied', 'stun', 'dazed', 'dumbfound', 'mystify']
senticnet['stunning'] = [0.898, 0, 0, 0.972, '#joyful', '#admirable', 0.623, 'stupefy', 'daze', 'sandbag', 'arresting', 'bedaze']
senticnet['stunt'] = [0, 0.846, 0, 0.962, '#interesting', '#admirable', 0.603, 'act', 'portray', 'play_ping_pong', 'school_play', 'dangerous']
senticnet['stunt_man'] = [-0.573, 0, 0.932, -0.504, '#sad', '#angry', -0.67, 'backup', 'substitute', 'reliever', 'relief', 'backup_man']
senticnet['stunt_woman'] = [-0.942, 0, 0.715, -0.81, '#sad', '#disgusting', -0.822, 'backup', 'substitute', 'reliever', 'relief', 'backup_man']
senticnet['stupe'] = [-0.775, 0, 0.714, -0.853, '#sad', '#disgusting', -0.781, 'dunce', 'dunderhead', 'numskull', 'blockhead', 'bonehead']
senticnet['stupefaction'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'surprise', 'stupor', 'stupefy', 'astonishment', 'amazement']
senticnet['stupefied'] = [0, -0.861, 0, 0, '#surprising', '#surprising', 0.287, 'surprised', 'astonished', 'amazed', 'stupefaction', 'stupefy']
senticnet['stupefy'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'nonplus', 'thunderstruck', 'stupefaction', 'dumfounded', 'mystify']
senticnet['stupefying'] = [0.044, -0.662, 0, 0.362, '#surprising', '#admirable', 0.356, 'astounding', 'surprise', 'dumbfound', 'stupefaction', 'stupefy']
senticnet['stupid'] = [0, 0, 0.937, 0, '#angry', '#angry', -0.312, 'dumb', 'idiot', 'newbie', 'low_experience', 'asshole']
senticnet['stupid_person'] = [-0.093, -0.028, 0, -0.09, '#sad', '#disgusting', -0.052, 'boardwalk', 'tourist', 'pass_exam', 'apple_tree', 'learn_fact']
senticnet['stupidity'] = [0, 0, 0.79, -0.741, '#angry', '#disgusting', -0.51, 'addiction', 'emotional_pain', 'disappointment', 'embarrassment', 'blackout']
senticnet['stupor'] = [0.746, 0.94, 0, 0, '#joyful', '#interesting', 0.562, 'daze', 'fulgurant', 'eye-popping', 'fulgurous', 'dazzling']
senticnet['stuporous'] = [-0.567, 0, 0.577, -0.619, '#angry', '#disgusting', -0.588, 'foggy', 'groggy', 'logy', 'lethargic', 'dazed']
senticnet['sturdy'] = [0, 0, 0.03, -0.128, '#angry', '#disgusting', -0.053, 'hard_material', 'hard_mineral', 'hard', 'hard_rock', 'construction_vehicle']
senticnet['stutter'] = [-0.274, -0.023, 0, -0.216, '#sad', '#disgusting', -0.156, 'move_tongue', 'look_eye', 'dry_mouth', 'open_close_mouth', 'use_voice']
senticnet['style'] = [0.072, 0.107, -0.047, 0.161, '#interesting', '#admirable', 0.098, 'clothes_style', 'glamour', 'fashion', 'stylish', 'fancy_clothes']
senticnet['style_hair'] = [0, 0.98, 0, 0.974, '#interesting', '#admirable', 0.651, 'new_hair_style', 'personal_groom', 'fix_hair', 'change_hair_style', 'haircut']
senticnet['style_music'] = [0.136, -0.092, 0.087, -0.033, '#joyful', '#surprising', 0.036, 'form_of_music', 'pop_music', 'tune', 'rhythm', 'music']
senticnet['style_of_architecture'] = [0.578, -0.957, 0, 0.979, '#surprising', '#admirable', 0.838, 'perpendicular', 'perpendicular_style', 'architectural_style', 'gothic_architecture', 'type_of_architecture']
senticnet['stylish'] = [0.043, -0.011, 0, 0.169, '#joyful', '#admirable', 0.074, 'fancy_clothes', 'frilly', 'protective_cover', 'wear', 'formal_clothes']
senticnet['stylishness'] = [0.554, -0.847, 0, 0.742, '#surprising', '#admirable', 0.714, 'elegance', 'jauntiness', 'rakishness', 'nattiness', 'dapperness']
senticnet['subatomic_particle'] = [0.022, 0.073, 0, 0.14, '#interesting', '#admirable', 0.078, 'elementary_particle', 'electron', 'proton_neutron', 'neutron', 'proton']
senticnet['subdue'] = [-0.501, 0, 0.936, -0.951, '#angry', '#disgusting', -0.796, 'quash', 'keep_down', 'reduce', 'repress', 'oppress']
senticnet['subdued'] = [0, -0.925, 0, 0.704, '#surprising', '#admirable', 0.543, 'quash', 'keep_down', 'subjugate', 'repress', 'reduce']
senticnet['subject'] = [-0.048, 0.087, 0, 0.054, '#interesting', '#admirable', 0.031, 'school_subject', 'subject_school', 'school_class', 'chemistry', 'school_course']
senticnet['subject_area'] = [-0.846, 0, 0.585, -0.852, '#sad', '#disgusting', -0.761, 'subject', 'discipline', 'study', 'graphology', 'subject_field']
senticnet['subject_case'] = [0.843, -0.602, 0, 0.97, '#joyful', '#admirable', 0.805, 'oblique', 'oblique_case', 'nominative', 'nominative_case', 'grammatical_case']
senticnet['subject_field'] = [-0.846, 0, 0.585, -0.852, '#sad', '#disgusting', -0.761, 'subject', 'discipline', 'study', 'subject_area', 'graphology']
senticnet['subject_school'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'college_major', 'geology', 'physic', 'chemistry', 'biology']
senticnet['subject_study'] = [-0.046, 0, 0, -0.054, '#sad', '#disgusting', -0.033, 'chemistry', 'study_person', 'college_major', 'school_course', 'school_class']
senticnet['subjective'] = [0.054, 0.221, -0.12, 0.236, '#interesting', '#admirable', 0.13, 'abstract', 'exclamation', 'versatile', 'nice', 'personal_preference']
senticnet['submarine'] = [0, 0, 0, -0.072, '#disgusting', '#disgusting', -0.024, 'battleship', 'lifeboat', 'titanic', 'large_ship', 'canoe']
senticnet['submerge'] = [-0.778, 0, 0.511, -0.536, '#sad', '#disgusting', -0.608, 'founder', 'subside', 'fall', 'settle', 'go_under']
senticnet['submission'] = [0, 0.73, 0, 0.907, '#interesting', '#admirable', 0.546, 'submit', 'submissive', 'lose_war', 'lose_battle', 'obey']
senticnet['submissive'] = [0.679, -0.947, 0, 0.661, '#joyful', '#surprising', 0.762, 'bowing', 'cringing', 'groveling', 'sub', 'wormlike']
senticnet['submit'] = [0.884, 0.967, 0, 0, '#joyful', '#interesting', 0.617, 'submission', 'submissive', 'lose_war', 'lose_battle', 'obey']
senticnet['subnormal'] = [-0.583, 0, 0.814, -0.54, '#sad', '#angry', -0.646, 'atypical', 'irregular', 'vicarious', 'supernormal', 'abnormal']
senticnet['subnormality'] = [-0.602, 0, 0.827, -0.762, '#angry', '#disgusting', -0.73, 'slowness', 'mental_retardation', 'backwardness', 'amentia', 'retardation']
senticnet['subordinateness'] = [0.875, -0.724, 0, 0.584, '#joyful', '#surprising', 0.728, 'subservientness', 'subservience', 'servant', 'handmaid', 'handmaiden']
senticnet['suborn'] = [-0.806, 0, 0.885, -0.8, '#sad', '#angry', -0.83, 'misdirect', 'deprave', 'vitiate', 'profane', 'demoralize']
senticnet['subscribe_magazine'] = [0.896, 0, 0, 0, '#joyful', '#joyful', 0.299, 'walk_exercise', 'pay_dinner', 'buy_candy', 'gain_interest', 'buy_soda']
senticnet['subscriber'] = [0.687, -0.502, 0, 0.8, '#joyful', '#admirable', 0.663, 'friend', 'champion', 'supporter', 'protagonist', 'admirer']
senticnet['subshrub'] = [-0.801, 0, 0.555, -0.681, '#sad', '#disgusting', -0.679, 'bush', 'wormwood', 'milkwort', 'germander', 'centaury']
senticnet['subside'] = [-0.778, 0, 0.511, -0.536, '#sad', '#disgusting', -0.608, 'founder', 'go_under', 'fall', 'settle', 'submerge']
senticnet['subsidence'] = [-0.894, 0, 0.926, -0.708, '#sad', '#angry', -0.843, 'reprieve', 'respite', 'hiatus', 'abatement', 'suspension']
senticnet['subsidiarity'] = [0.845, -0.773, 0, 0.834, '#joyful', '#admirable', 0.817, 'subservientness', 'subservience', 'servant', 'handmaid', 'handmaiden']
senticnet['subsidizer'] = [0.883, -0.664, 0, 0.732, '#joyful', '#admirable', 0.76, 'giver', 'donor', 'presenter', 'bestower', 'conferrer']
senticnet['substance'] = [0.049, 0, 0, 0.113, '#joyful', '#admirable', 0.054, 'solid', 'hard_material', 'construction_material', 'hard', 'calcium']
senticnet['substance_abuse'] = [-0.608, 0, 0.598, -0.633, '#sad', '#disgusting', -0.613, 'abuse', 'misuse', 'alcohol_abuse', 'alcoholic_abuse', 'alcoholism_abuse']
senticnet['substantial'] = [0.944, 0.98, 0, 0, '#joyful', '#interesting', 0.641, 'substantive', 'material', 'significant', 'real', 'hearty']
senticnet['substantiate'] = [0, 0, -0.722, -0.969, '#scared', '#disgusting', -0.564, 'corroborate', 'support', 'confirm', 'affirm', 'sustain']
senticnet['substantiation'] = [0.84, -0.979, 0, 0.713, '#joyful', '#surprising', 0.844, 'proof', 'bed_check', 'crosscheck', 'parity_check', 'redundancy_check']
senticnet['substitute'] = [0, 0.119, -0.054, 0.11, '#interesting', '#admirable', 0.058, 'replacement', 'class', 'undergraduate', 'replace', 'someone_else']
senticnet['subtract'] = [-0.077, 0.137, 0, 0.132, '#interesting', '#admirable', 0.064, 'payoff', 'get_work_done', 'muscle_ache', 'win_medal', 'make_small']
senticnet['suburban_shop_mall'] = [0, 0, 0.051, -0.032, '#angry', '#disgusting', -0.028, 'large_city_shop_mall', 'mini_mall', 'corner_shop', 'corner_grocery', 'large_food_store']
senticnet['subversive'] = [-0.789, 0, -0.751, 0, '#sad', '#scared', -0.513, 'revolutionist', 'subverter', 'insurgent', 'seditious', 'revolutionary']
senticnet['subversive_activity'] = [-0.848, 0, 0.744, -0.581, '#sad', '#angry', -0.724, 'subversion', 'overthrow', 'termination', 'ending', 'conclusion']
senticnet['subvert'] = [-0.717, 0, 0.932, -0.505, '#sad', '#angry', -0.718, 'refuse', 'disobey', 'decline', 'balk', 'baulk']
senticnet['subway'] = [0, 0, 0, -0.079, '#disgusting', '#disgusting', -0.026, 'bus_stop', 'fast_food', 'train_station', 'railway_station', 'gas_station']
senticnet['subway_pass'] = [0, 0, 0.024, -0.065, '#angry', '#disgusting', -0.03, 'transit_ticket', 'bus_pass', 'train_ticket', 'passenger_ticket', 'transit_card']
senticnet['subway_platform'] = [0.831, 0, 0, 0.796, '#joyful', '#admirable', 0.542, 'train_station', 'subway_stop', 'parking_lot', 'subway_station', 'park_structure']
senticnet['subway_station'] = [0.025, 0.136, 0, 0, '#joyful', '#interesting', 0.054, 'town_hall', 'courthouse', 'city_hall', 'public_place', 'bus_station']
senticnet['subway_stop'] = [0.881, 0, 0, 0.852, '#joyful', '#admirable', 0.578, 'train_station', 'subway_platform', 'parking_lot', 'subway_station', 'park_structure']
senticnet['succade'] = [-0.952, 0, 0.845, -0.679, '#sad', '#angry', -0.825, 'grapefruit_peel', 'lemon_peel', 'orange_peel', 'candied_fruit', 'candied_citrus_peel']
senticnet['succeed'] = [0.588, -0.759, 0, 0.55, '#joyful', '#surprising', 0.632, 'clear', 'pan_out', 'reach', 'bring_off', 'luck_out']
senticnet['succeed_carrier'] = [0, 0.069, 0, 0.108, '#interesting', '#admirable', 0.059, 'succeed_school', 'create_questions', 'create_thought', 'creative_mind', 'creative_soul']
senticnet['succeed_school'] = [0.601, 0.647, -0.266, 0.322, '#joyful', '#interesting', 0.435, 'bicycle_school', 'love_pet', 'borrow_book_from_library', 'question_teacher', 'solve_equation']
senticnet['succeeder'] = [0.622, -0.888, 0, 0.915, '#surprising', '#admirable', 0.808, 'great', 'highflier', 'highflyer', 'natural', 'mortal']
senticnet['succeeding'] = [0.7, 0, 0, 0.757, '#joyful', '#admirable', 0.486, 'consecutive', 'ensuing', 'following', 'undermentioned', 'prosper']
senticnet['success'] = [0.889, 0, 0, 0, '#joyful', '#joyful', 0.296, 'succeed', 'increase_self_esteem', 'increase_self-esteem', 'help_others', 'achievement']
senticnet['successful'] = [0.98, -0.746, 0, 0.984, '#joyful', '#admirable', 0.903, 'prosperous', 'flourishing', 'palmy', 'prospering', 'thriving']
senticnet['successfulness'] = [0.971, -0.717, 0, 0.656, '#joyful', '#surprising', 0.781, 'wellbeing', 'human_flourishing', 'eudaimonia', 'upbeat', 'strength']
senticnet['succinic_acid'] = [-0.652, 0, 0.935, -0.968, '#angry', '#disgusting', -0.852, 'acid', 'hexanedioic_acid', 'adipic_acid', 'carboxylic_acid', 'valeric_acid']
senticnet['succor'] = [0.759, -0.784, 0, 0.918, '#surprising', '#admirable', 0.82, 'solace', 'assist', 'help', 'assistance', 'mercy']
senticnet['succorer'] = [-0.736, 0, 0.822, -0.732, '#sad', '#angry', -0.763, 'recoverer', 'succourer', 'salvager', 'salvor', 'mortal']
senticnet['succourer'] = [-0.736, 0, 0.822, -0.732, '#sad', '#angry', -0.763, 'succorer', 'recoverer', 'salvager', 'salvor', 'mortal']
senticnet['succuba'] = [-0.793, 0, 0.92, -0.752, '#sad', '#angry', -0.822, 'evil_spirit', 'incubus', 'succubus', 'daemon', 'dybbuk']
senticnet['succubus'] = [-0.793, 0, 0.92, -0.752, '#sad', '#angry', -0.822, 'evil_spirit', 'incubus', 'daemon', 'succuba', 'dybbuk']
senticnet['succulence'] = [-0.797, 0, 0.992, -0.884, '#angry', '#disgusting', -0.891, 'flavorsomeness', 'flavoursomeness', 'savoriness', 'appetizingness', 'succulency']
senticnet['succulency'] = [-0.797, 0, 0.992, -0.884, '#angry', '#disgusting', -0.891, 'flavorsomeness', 'flavoursomeness', 'savoriness', 'succulence', 'appetizingness']
senticnet['succumb'] = [-0.77, 0, -0.855, 0, '#sad', '#scared', -0.542, 'give_in', 'submit', 'accept', 'defer', 'yield']
senticnet['suck'] = [-0.891, 0, 0.691, -0.839, '#sad', '#disgusting', -0.807, 'choke_food', 'drink_tea', 'spill_food_clothes', 'welcome_friend', 'talk_other']
senticnet['suck_up'] = [0.72, -0.764, 0, 0.695, '#joyful', '#surprising', 0.726, 'mop_up', 'blot', 'wipe_up', 'mop', 'sponge_up']
senticnet['sucker_punch'] = [0.705, -0.606, 0, 0.913, '#joyful', '#admirable', 0.741, 'lick', 'clout', 'poke', 'punch', 'biff']
senticnet['suction'] = [0.928, 0.837, 0, 0, '#joyful', '#interesting', 0.588, 'nothing', 'none', 'void', 'emptiness', 'outside_atmosphere']
senticnet['sudation'] = [-0.584, 0, 0.773, -0.797, '#angry', '#disgusting', -0.718, 'perspiration', 'sweating', 'diaphoresis', 'polyhidrosis', 'hidrosis']
senticnet['sudden'] = [0, 0, 0, -0.783, '#disgusting', '#disgusting', -0.261, 'suddenly', 'precipitous', 'immediate', 'unexpected', 'sudden_asthma_attack']
senticnet['sudden_asthma_attack'] = [0, 0, 0, -0.783, '#disgusting', '#disgusting', -0.261, 'shock', 'scared', 'run_after_ball', 'high_blood_pressure', 'go_gym']
senticnet['suddenly'] = [0, 0.783, 0, 0.744, '#interesting', '#admirable', 0.509, 'sudden', 'unexpected', 'obvious', 'special', 'reaction']
senticnet['suffer'] = [-0.871, 0, -0.867, 0, '#sad', '#scared', -0.579, 'bloody', 'hurt', 'pain', 'physical_pain', 'inflict_pain']
senticnet['suffer_fool'] = [-0.448, -0.134, -0.048, -0.379, '#sad', '#disgusting', -0.247, 'lyme_disease', 'brain_tumor', 'disrespect', 'cause_suffer', 'lose_team']
senticnet['sufferer'] = [-0.589, 0, 0.893, -0.742, '#angry', '#disgusting', -0.741, 'unfortunate', 'dyspeptic', 'invalid', 'psychoneurotic', 'psychotic']
senticnet['suffering'] = [-0.727, 0.304, -0.418, -0.073, '#sad', '#scared', -0.305, 'miserably', 'pitiable', 'piteous', 'hapless', 'pitiful']
senticnet['suffice'] = [0.277, 0.161, 0, 0.337, '#joyful', '#admirable', 0.258, 'go_around', 'fulfill', 'conform', 'go_long_way', 'satisfy']
senticnet['sufficiency'] = [-0.56, 0, 0.711, -0.977, '#angry', '#disgusting', -0.749, 'null', 'zero', 'quantity', 'relative_quantity', 'measure']
senticnet['sufficient'] = [0.258, 0.357, -0.088, 0.351, '#interesting', '#admirable', 0.293, 'satisfaction', 'acceptable', 'serenity', 'feel_ok', 'tolerable']
senticnet['suffocate'] = [0, 0, -0.898, 0, '#scared', '#scared', -0.299, 'destroy_live', 'kill_people', 'murder', 'elephant_sit_chest', 'take_life']
senticnet['suffocating'] = [-0.902, 0, 0.66, -0.931, '#sad', '#disgusting', -0.831, 'dyspneic', 'dyspnoeic', 'dyspneal', 'dyspnoeal', 'breathless']
senticnet['suffocative'] = [-0.902, 0, 0.63, -0.54, '#sad', '#angry', -0.691, 'dyspneic', 'dyspnoeic', 'dyspneal', 'dyspnoeal', 'breathless']
senticnet['suffrutex'] = [-0.765, 0, 0.576, -0.807, '#sad', '#disgusting', -0.716, 'bush', 'wormwood', 'milkwort', 'germander', 'centaury']
senticnet['sugar_free'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'diet_coke', 'carbonated_drink', 'energy_drink', 'drink', 'beverage']
senticnet['sugar_substitute'] = [-0.089, 0.106, 0, 0.125, '#interesting', '#admirable', 0.047, 'sugar', 'tracle', 'molasses', 'add_sugar', 'black_treacle']
senticnet['sugar_water'] = [0.728, -0.517, 0, 0.811, '#joyful', '#admirable', 0.685, 'beverage', 'drinkable', 'potable', 'bottled_water', 'drinking_water']
senticnet['sugariness'] = [-0.783, 0, 0.542, -0.941, '#sad', '#disgusting', -0.755, 'taste', 'taste_sensation', 'gustatory_sensation', 'taste_perception', 'gustatory_perception']
senticnet['sugary'] = [0.107, 0, 0, 0.187, '#joyful', '#admirable', 0.098, 'round_pastry', 'sweet', 'soft_sweet', 'bake_good', 'bakery_item']
senticnet['suggest'] = [-0.035, 0.323, -0.23, 0.437, '#interesting', '#admirable', 0.165, 'request', 'permission', 'proclamation', 'plea', 'ask']
senticnet['suggestibility'] = [-0.787, 0, 0.6, -0.616, '#sad', '#disgusting', -0.668, 'susceptibility', 'sensitivity', 'capacity', 'reactivity', 'predisposition']
senticnet['suggestion'] = [0, 0.313, -0.206, 0.403, '#interesting', '#admirable', 0.17, 'suggest', 'affirmation', 'propose', 'demand', 'intend']
senticnet['suicide'] = [-0.106, -0.053, -0.129, -0.24, '#scared', '#disgusting', -0.141, 'old_age', 'get_lung_cancer', 'capital_punishment', 'kill', 'execute']
senticnet['suit_of_armor'] = [0.939, -0.632, 0, 0.653, '#joyful', '#admirable', 0.741, 'vest', 'waistcoat', 'body_armor', 'bulletproof_vest', 'coat_of_mail']
senticnet['suit_up'] = [0.959, 0.965, 0, 0, '#joyful', '#interesting', 0.641, 'gather_team', 'form_team', 'buy_ball', 'join_team', 'hoop']
senticnet['suitability'] = [0.541, -0.594, 0, 0.527, '#joyful', '#surprising', 0.554, 'fitness', 'quality', 'fittingness', 'convenience', 'appropriateness']
senticnet['suitableness'] = [0.958, -0.954, 0, 0.509, '#joyful', '#surprising', 0.807, 'fitness', 'quality', 'fittingness', 'convenience', 'appropriateness']
senticnet['suitcase'] = [-0.028, 0, 0, -0.047, '#sad', '#disgusting', -0.025, 'woman_purse', 'sock_drawer', 'pocket', 'back_sofa', 'pant_pocket']
senticnet['sulfa'] = [0.551, -0.753, 0, 0.817, '#surprising', '#admirable', 0.707, 'antibacterial', 'sulfamethoxazole', 'sulfisoxazole', 'sulfadiazine', 'sulfacetamide']
senticnet['sulfa_drug'] = [0.869, -0.722, 0, 0.764, '#joyful', '#admirable', 0.785, 'antibacterial', 'sulfamethoxazole', 'sulfisoxazole', 'sulfadiazine', 'sulfacetamide']
senticnet['sulfonamide'] = [0.721, -0.95, 0, 0.554, '#joyful', '#surprising', 0.742, 'antibacterial', 'sulfamethoxazole', 'sulfisoxazole', 'sulfadiazine', 'sulfacetamide']
senticnet['sulfurous_acid'] = [-0.912, 0, 0.24, -0.93, '#sad', '#disgusting', -0.694, 'acid', 'dangerous', 'danger', 'kill_person', 'poison']
senticnet['sulk'] = [0.056, 0.105, 0.786, -0.681, '#angry', '#disgusting', -0.435, 'huffishness', 'sulkiness', 'hover', 'loom', 'bulk_large']
senticnet['sulkiness'] = [0.056, 0.105, 0.786, -0.681, '#angry', '#disgusting', -0.435, 'huffishness', 'sulk', 'hover', 'loom', 'bulk_large']
senticnet['sulky'] = [-0.296, 0.2, 0.49, -0.615, '#angry', '#disgusting', -0.4, 'queasy', 'outrageous', 'horrid', 'angrily', 'see_red']
senticnet['sullenness'] = [-0.959, 0, 0.694, -0.949, '#sad', '#disgusting', -0.867, 'ill_nature', 'moroseness', 'crabbiness', 'crabbedness', 'crankiness']
senticnet['sullied'] = [0, 0, 0.821, -0.985, '#angry', '#disgusting', -0.602, 'taint', 'cloud', 'defile', 'sully', 'corrupt']
senticnet['sulpha'] = [0.636, -0.878, 0, 0.932, '#surprising', '#admirable', 0.815, 'antibacterial', 'sulfamethoxazole', 'sulfisoxazole', 'sulfadiazine', 'sulfacetamide']
senticnet['sultan'] = [0.07, 0, 0, 0.051, '#joyful', '#admirable', 0.04, 'despot', 'duke', 'king', 'duchess', 'earl']
senticnet['sum'] = [-0.024, 0.216, 0.06, 0.141, '#interesting', '#admirable', 0.091, 'total_number', 'tally', 'total', 'list_number', 'count']
senticnet['sum_total'] = [0, 0.175, 0.084, 0.133, '#interesting', '#admirable', 0.075, 'total_number', 'all_of_it', 'sum', 'total', 'count']
senticnet['summarize'] = [-0.106, 0, 0, -0.127, '#sad', '#disgusting', -0.078, 'reflect', 'stare_off_space', 'keep_word', 'think_past', 'mind_boggle']
senticnet['summary'] = [0, 0.175, 0.084, 0.133, '#interesting', '#admirable', 0.075, 'brief', 'recap', 'abridgement', 'resume', 'report']
senticnet['summer_savory'] = [0.91, -0.993, 0, 0.779, '#joyful', '#surprising', 0.894, 'herb', 'delicious', 'savory', 'eat_well', 'winter_savory']
senticnet['summer_vacation'] = [0.977, 0.828, 0, 0, '#joyful', '#interesting', 0.602, 'hunt_fish', 'out_place', 'getaway', 'outdoor_activity', 'vacation']
senticnet['summer_weather'] = [0.109, 0, -0.067, 0.073, '#joyful', '#admirable', 0.038, 'steam', 'haze', 'misty', 'vapor', 'mist']
senticnet['summer_winter'] = [0.093, 0, 0, 0, '#joyful', '#joyful', 0.031, 'snowy', 'season_year', 'fall_spring', 'chilly', 'winter']
senticnet['summit'] = [0.083, 0.073, 0.015, 0, '#joyful', '#interesting', 0.047, 'peak', 'top', 'good_view', 'pinnacle', 'great_view']
senticnet['sumo_wrestler'] = [0, 0.128, 0.01, 0.093, '#interesting', '#admirable', 0.07, 'giant', 'capitol_build', 'tall_man', 'egret', 'capital_build']
senticnet['sun_beach'] = [0.929, 0, 0, 0, '#joyful', '#joyful', 0.31, 'shine_light', 'close_together', 'keep_dry', 'smoke_joint', 'shovel_snow']
senticnet['sun_block'] = [0, 0.128, 0, 0.058, '#interesting', '#admirable', 0.062, 'no_light', 'shade', 'without_light', 'protect_from_sun', 'dark_area']
senticnet['sun_burn'] = [-0.907, 0, 0.209, -0.927, '#sad', '#disgusting', -0.681, 'burn_skin', 'erythema', 'fire', 'lighting', 'hurt_skin']
senticnet['sun_cover'] = [0, 0.071, 0, 0.078, '#interesting', '#admirable', 0.05, 'block_sun', 'no_sun', 'cool_temperature', 'nice_day', 'overcast']
senticnet['sun_down'] = [-0.096, 0, -0.066, 0, '#sad', '#scared', -0.054, 'night', 'darkness', 'moon_star', 'dusk', 'day_end']
senticnet['sun_god'] = [0.978, -0.88, 0, 0.785, '#joyful', '#surprising', 0.881, 'daemon', 'demigod', 'sea_god', 'divinity', 'goddess']
senticnet['sun_itself'] = [-0.089, 0, 0, -0.087, '#sad', '#disgusting', -0.059, 'eat_egg', 'eat_cat_food', 'eat_healthy_diet', 'surprise_person', 'eat_better']
senticnet['sun_oneself'] = [-0.128, 0, -0.055, 0, '#sad', '#scared', -0.061, 'watch_d', 'throw_fit', 'laugh_clown', 'battle_illness', 'shoulder_responsibility']
senticnet['sun_up'] = [0.051, 0.16, -0.095, 0.144, '#interesting', '#admirable', 0.087, 'come_up', 'get_up', 'rise', 'awaken', 'levitate']
senticnet['sunbathe'] = [0.099, 0, 0, 0.116, '#joyful', '#admirable', 0.072, 'question_everything', 'examine', 'bounce_up_down', 'amuse_child', 'add_two_numbers']
senticnet['sunbather'] = [-0.051, -0.016, 0.047, -0.053, '#sad', '#disgusting', -0.045, 'young_child', 'child', 'youngster', 'youth', 'sunshine']
senticnet['sunbeam'] = [-0.507, 0, 0.75, -0.951, '#angry', '#disgusting', -0.736, 'beam', 'beam_of_light', 'light_beam', 'ray', 'ray_of_light']
senticnet['sunblock'] = [0.872, 0.91, 0, 0, '#joyful', '#interesting', 0.594, 'sunscreen', 'wear_sunscreen', 'go_to_beach', 'sunny_day', 'summertime']
senticnet['sunburn'] = [0, 0, -0.797, 0, '#scared', '#scared', -0.266, 'dislocation', 'burn_skin', 'cut_skin', 'pain', 'ache']
senticnet['sunburned'] = [-0.734, 0, -0.908, 0, '#sad', '#scared', -0.547, 'eaten_shark', 'broken_window', 'step_dog_shit', 'fall_head', 'broken_limb']
senticnet['sunday'] = [0.975, 0.92, 0, 0.868, '#joyful', '#interesting', 0.921, 'religious_event', 'happy_event', 'ceremony', 'tradition', 'religious']
senticnet['sunday_afternoon'] = [0, 0.876, 0, 0.977, '#interesting', '#admirable', 0.618, 'breakfast_bed', 'hug', 'eat_together', 'make_love', 'give_birth_child']
senticnet['sunday_punch'] = [-0.983, 0, 0.808, -0.609, '#sad', '#angry', -0.8, 'poke', 'clout', 'lick', 'punch', 'biff']
senticnet['sundown'] = [-0.083, 0, -0.045, 0, '#sad', '#scared', -0.043, 'get_dark', 'night_time', 'day_end', 'dark_outside', 'dusk']
senticnet['sundowner'] = [-0.943, 0, 0.839, -0.539, '#sad', '#angry', -0.774, 'hobo', 'tramp', 'beachcomber', 'bum', 'drifter']
senticnet['sundry'] = [-0.826, 0, 0.756, -0.516, '#sad', '#angry', -0.699, 'inhomogeneous', 'nonuniform', 'assorted', 'heterogeneous', 'mixed']
senticnet['sung'] = [0.988, 0, 0, 0.865, '#joyful', '#admirable', 0.618, 'instrumental', 'vocal_music', 'melodic_noise', 'lyric', 'piece_of_music']
senticnet['sunglasses'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'walking_stick', 'blind_person', 'disabled', 'poor_visual_perception', 'vision_loss']
senticnet['sunk'] = [-0.747, 0, 0.792, -0.577, '#sad', '#angry', -0.705, 'unsuccessful', 'unplaced', 'out', 'pointless', 'defeated']
senticnet['sunken_treasure'] = [-0.048, 0, -0.052, 0, '#sad', '#scared', -0.033, 'coral', 'fish_equipment', 'small_fish', 'aquatic_life', 'fly_fish']
senticnet['sunny'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'weather', 'four_seasons', 'fall_spring', 'rain_snow', 'climate']
senticnet['sunny_day'] = [0.135, 0.122, 0, 0.089, '#joyful', '#interesting', 0.115, 'hot_sun', 'good_weather', 'striped', 'no_sun', 'fluffy']
senticnet['sunny_weather'] = [0.833, 0.927, 0, 0, '#joyful', '#interesting', 0.587, 'no_color', 'transparency', 'clarity', 'intelligent', 'water_color']
senticnet['sunray'] = [-0.622, 0, 0.762, -0.7, '#angry', '#disgusting', -0.695, 'beam', 'beam_of_light', 'light_beam', 'ray', 'ray_of_light']
senticnet['sunrise'] = [0, 0.071, 0, 0, '#interesting', '#interesting', 0.024, 'sun', 'dawn', 'begin_day', 'light_in_sky', 'daylight']
senticnet['sunset'] = [0.062, 0.072, 0, 0, '#joyful', '#interesting', 0.045, 'wood_duck', 'dim', 'darkness', 'after_sundown', 'no_light']
senticnet['sunshine'] = [0.891, 0, 0, 0.758, '#joyful', '#admirable', 0.55, 'just_fun', 'good_mental_health', 'sun', 'enjoyable', 'power_electricity']
senticnet['sunstroke'] = [0, 0, -0.084, -0.12, '#scared', '#disgusting', -0.068, 'burn_skin', 'cancer', 'ultraviolet', 'erythema', 'expose_skin_sun']
senticnet['suntan'] = [-0.969, 0, 0.636, -0.646, '#sad', '#disgusting', -0.75, 'burn', 'tan', 'hyperpigmentation', 'sunburn', 'physical_condition']
senticnet['suntan_lotion'] = [0.041, -0.023, 0.044, -0.106, '#angry', '#disgusting', -0.029, 'shoplifter', 'carton_milk', 'store_shelf', 'plastic_container', 'wax_dental_floss']
senticnet['super'] = [0.117, -0.249, 0, 0.423, '#surprising', '#admirable', 0.263, 'better_good', 'most_good', 'carry_lunch', 'high_quality', 'really_good']
senticnet['super_angry'] = [0, 0, 0.748, 0, '#angry', '#angry', -0.249, 'wet_pant', 'tell_lie', 'feel_sad', 'correct_mistake', 'feel_angry']
senticnet['super_glue'] = [0, 0.985, 0, 0.895, '#interesting', '#admirable', 0.627, 'fix', 'glue', 'fastener_binder', 'stick_together', 'repair']
senticnet['super_market'] = [0, 0.074, 0, 0.071, '#interesting', '#admirable', 0.048, 'grocery_cart', 'salad_bar', 'fruit_stand', 'candy_store', 'produce_store']
senticnet['superannuated'] = [-0.909, 0, 0.517, -0.92, '#sad', '#disgusting', -0.782, 'outdated', 'obsolescent', 'disused', 'obsolete', 'noncurrent']
senticnet['superbia'] = [0.563, -0.998, 0, 0.729, '#surprising', '#admirable', 0.763, 'lordliness', 'mortal_sin', 'deadly_sin', 'arrogance', 'haughtiness']
senticnet['superbly'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'terrific', 'wondrously', 'tremendous', 'marvelous', 'wondrous']
senticnet['supercilious'] = [0, 0, -0.749, -0.932, '#scared', '#disgusting', -0.56, 'imperious', 'haughty', 'disdainful', 'lordly', 'overbearing']
senticnet['supererogation'] = [-0.863, 0, 0.945, -0.718, '#sad', '#angry', -0.842, 'sweat', 'effort', 'elbow_grease', 'exertion', 'travail']
senticnet['superficial'] = [-0.631, 0, 0.857, -0.711, '#angry', '#disgusting', -0.733, 'shallow', 'facile', 'ostensible', 'sounding', 'looking']
senticnet['superfluous'] = [-0.784, 0, 0.651, -0.564, '#sad', '#angry', -0.666, 'rubbishy', 'sorry', 'trashy', 'otiose', 'worthless']
senticnet['superhero'] = [0, 0.701, 0, 0.832, '#interesting', '#admirable', 0.511, 'version', 'grizzly_bear', 'brown_bear', 'elf', 'book_poetry']
senticnet['superhighway'] = [0.989, -0.51, 0, 0.603, '#joyful', '#admirable', 0.701, 'autobahn', 'autostrada', 'turnpike', 'toll_road', 'highway']
senticnet['superior'] = [0, 0.782, 0, 0.995, '#interesting', '#admirable', 0.592, 'stalin', 'sail_sea', 'well_done', 'supervisor', 'small_ocean']
senticnet['superiority'] = [0.757, -0.827, 0, 0.982, '#surprising', '#admirable', 0.855, 'first_class', 'choiceness', 'first_water', 'fineness', 'quality']
senticnet['superlative'] = [0.112, -0.003, 0.013, 0.383, '#joyful', '#admirable', 0.162, 'excellence', 'well_done', 'high_quality', 'ultimate', 'greatness']
senticnet['supernaturalism'] = [-0.983, 0, 0.891, -0.607, '#sad', '#angry', -0.827, 'exorcism', 'dispossession', 'magic', 'thaumaturgy', 'belief']
senticnet['supernaturalness'] = [-0.685, 0, 0.863, -0.694, '#angry', '#disgusting', -0.747, 'pretension', 'artificiality', 'affectedness', 'unnaturalness', 'largeness']
senticnet['supernormal'] = [-0.583, 0, 0.814, -0.54, '#sad', '#angry', -0.646, 'atypical', 'irregular', 'vicarious', 'abnormal', 'subnormal']
senticnet['supersede'] = [-0.812, 0, 0.854, -0.823, '#angry', '#disgusting', -0.83, 'replace', 'cover', 'supplant', 'deputize', 'supervene_upon']
senticnet['supersonic'] = [-0.998, 0, 0.798, -0.716, '#sad', '#angry', -0.837, 'silent', 'voiceless', 'unsounded', 'breathed', 'inaudible']
senticnet['superstition'] = [0, 0.207, -0.091, 0.143, '#interesting', '#admirable', 0.086, 'preach', 'pulpit', 'preacher', 'judaism', 'prayer']
senticnet['supervene'] = [-0.873, 0, 0.858, -0.776, '#sad', '#angry', -0.836, 'pass_off', 'fall_out', 'occur', 'happen', 'hap']
senticnet['supervene_upon'] = [-0.812, 0, 0.854, -0.823, '#angry', '#disgusting', -0.83, 'replace', 'cover', 'supplant', 'supersede', 'deputize']
senticnet['supervisor'] = [0.031, 0.101, 0, 0, '#joyful', '#interesting', 0.044, 'chief', 'commander', 'leader', 'ambassador', 'master']
senticnet['supine'] = [-0.783, 0, 0.95, -0.731, '#sad', '#angry', -0.821, 'drooping', 'crooked', 'weeping', 'prone', 'unerect']
senticnet['supplant'] = [-0.812, 0, 0.854, -0.823, '#angry', '#disgusting', -0.83, 'replace', 'cover', 'deputize', 'supersede', 'supervene_upon']
senticnet['suppleness'] = [-0.549, 0, 0.909, -0.973, '#angry', '#disgusting', -0.81, 'bendability', 'pliancy', 'pliantness', 'flexibility', 'flexibleness']
senticnet['supplicant'] = [0, 0, -0.776, -0.821, '#scared', '#disgusting', -0.532, 'suppliant', 'requester', 'petitioner', 'supplicatory', 'prayer']
senticnet['supply'] = [0, 0.931, 0, 0.893, '#interesting', '#admirable', 0.608, 'hand_out', 'given', 'donate', 'provide', 'contain']
senticnet['supply_answer'] = [-0.118, 0, 0.016, 0, '#sad', '#angry', -0.045, 'answer_question', 'school_student', 'communicate_other_person', 'convince', 'transfer_knowledge']
senticnet['support'] = [0, 0.333, -0.265, 0.292, '#interesting', '#admirable', 0.12, 'provide', 'assistance', 'hold_up', 'support_wall', 'assist']
senticnet['support_bridge'] = [-0.023, 0.245, -0.17, 0.297, '#interesting', '#admirable', 0.116, 'carry', 'continue', 'tow', 'carry_object', 'haul']
senticnet['support_cause'] = [0.112, 0.178, -0.055, 0.143, '#interesting', '#admirable', 0.126, 'win_marathon', 'challenge_oneself', 'prove_fitness', 'enjoy_competition', 'earn_a_lot_of_money']
senticnet['support_family'] = [0, 0.129, -0.052, 0.1, '#interesting', '#admirable', 0.059, 'earn_money', 'make_live', 'get_job_done', 'provide_service', 'need_earn_money']
senticnet['support_mother_culture'] = [0.084, 0.359, -0.055, 0.295, '#interesting', '#admirable', 0.228, 'belief', 'faith', 'religious', 'religious_purpose', 'christian']
senticnet['support_roof'] = [0, 0.192, -0.101, 0.205, '#interesting', '#admirable', 0.099, 'support_wall', 'interior', 'load_bear', 'furnish', 'build_support']
senticnet['support_structure'] = [0, 0.824, 0, 0.959, '#interesting', '#admirable', 0.594, 'pillar', 'structural_support', 'vertical', 'support_wall', 'walk_device']
senticnet['support_wall'] = [-0.027, 0.262, -0.116, 0.258, '#interesting', '#admirable', 0.126, 'build_support', 'construct', 'construction', 'structure', 'load_bear']
senticnet['supportive'] = [0.9, -0.742, 0, 0.721, '#joyful', '#surprising', 0.788, 'accessary', 'demonstrative_of', 'encouraging', 'certificatory', 'supporting']
senticnet['supposal'] = [-0.694, 0, 0.806, -0.742, '#angry', '#disgusting', -0.747, 'hypothesis', 'theory', 'base', 'possibility', 'presumption']
senticnet['suppose'] = [-0.957, 0, 0.822, -0.882, '#sad', '#disgusting', -0.887, 'hypothecate', 'speculate', 'conjecture', 'mature', 'formulate']
senticnet['suppose_impartial'] = [0.826, 0.728, 0, 0, '#joyful', '#interesting', 0.518, 'hot', 'opposite_cold', 'type_of_valley', 'heat', 'warm']
senticnet['supposition'] = [-0.028, 0.156, -0.045, 0.151, '#interesting', '#admirable', 0.078, 'theory', 'hypothesis', 'hypothetical', 'scientific_statement', 'experiment']
senticnet['suppress'] = [-0.691, 0, 0.89, -0.707, '#angry', '#disgusting', -0.763, 'still', 'burke', 'moderate', 'hush_up', 'quell']
senticnet['suppressed'] = [-0.725, 0, 0.728, -0.5, '#sad', '#angry', -0.651, 'quelled', 'squelched', 'burked', 'quenched', 'unreleased']
senticnet['suppuration'] = [-0.525, 0, 0.538, -0.959, '#angry', '#disgusting', -0.674, 'sanies', 'pus', 'purulence', 'gleet', 'ichor']
senticnet['supremacy'] = [0.516, -0.837, 0, 0.985, '#surprising', '#admirable', 0.779, 'superiority', 'transcendence', 'transcendency', 'dominance', 'ascendance']
senticnet['supreme'] = [0.02, 0.273, -0.104, 0.295, '#interesting', '#admirable', 0.161, 'tenet', 'almighty', 'official', 'nobility', 'axiom']
senticnet['supreme_court'] = [-0.03, 0.154, -0.074, 0.122, '#interesting', '#admirable', 0.057, 'lawyer', 'wear_robe', 'judge_jury', 'arbiter', 'arbitrator']
senticnet['sure_thing'] = [-0.91, 0, 0.795, -0.94, '#sad', '#disgusting', -0.882, 'ineluctability', 'unavoidability', 'predictability', 'slam_dunk', 'inevitability']
senticnet['surf_board'] = [-0.057, -0.021, -0.075, 0, '#sad', '#scared', -0.037, 'tide', 'tidal_wave', 'shallow', 'puddle', 'pier']
senticnet['surf_internet'] = [0.02, 0.273, -0.104, 0.295, '#interesting', '#admirable', 0.161, 'internet', 'use_computer', 'search_information', 'check_email', 'send_email']
senticnet['surf_net'] = [0.978, 0.83, 0, 0, '#joyful', '#interesting', 0.603, 'operate_computer', 'entertainment', 'kill_time', 'research', 'browse_web']
senticnet['surf_web'] = [-0.901, 0, 0, -0.723, '#sad', '#disgusting', -0.541, 'use_internet', 'hack', 'read_magazine', 'surf_net', 'read_letter']
senticnet['surface_earth'] = [0, 0, 0.012, -0.085, '#angry', '#disgusting', -0.032, 'riverbed', 'waterfall', 'underground', 'ground', 'lawn']
senticnet['surfer'] = [0, 0, 0, 0.078, '#admirable', '#admirable', 0.026, 'water_relate', 'water_splash', 'tsunami', 'water_form', 'hand_gesture']
senticnet['surge'] = [-0.798, 0, 0.59, -0.567, '#sad', '#angry', -0.652, 'debris_surge', 'debris_storm', 'flowing', 'onrush', 'flow']
senticnet['surgeon'] = [-0.036, 0.068, -0.165, -0.099, '#scared', '#disgusting', -0.077, 'physician', 'nurse', 'doctor', 'doctor_surgery', 'merlin']
senticnet['surgery'] = [-0.117, -0.009, -0.083, -0.219, '#sad', '#disgusting', -0.137, 'hospital', 'illness', 'doctor_visit', 'heal', 'concern_health']
senticnet['surgical_knife'] = [0.932, -0.521, 0, 0.534, '#joyful', '#admirable', 0.662, 'lancet', 'catling', 'lance', 'scalpel', 'knife']
senticnet['surgical_operation'] = [-0.502, 0, 0.596, -0.766, '#angry', '#disgusting', -0.621, 'operation', 'surgery', 'angioplasty', 'surgical_procedure', 'surgical_process']
senticnet['surgical_procedure'] = [-0.502, 0, 0.596, -0.766, '#angry', '#disgusting', -0.621, 'operation', 'surgery', 'surgical_operation', 'angioplasty', 'surgical_process']
senticnet['surgical_process'] = [-0.502, 0, 0.596, -0.766, '#angry', '#disgusting', -0.621, 'operation', 'surgery', 'surgical_operation', 'surgical_procedure', 'angioplasty']
senticnet['surliness'] = [-0.598, 0, 0.911, -0.831, '#angry', '#disgusting', -0.78, 'biliousness', 'peevishness', 'pettishness', 'snappishness', 'querulousness']
senticnet['surmountable'] = [-0.996, 0, 0.641, -0.765, '#sad', '#disgusting', -0.801, 'navigable', 'negotiable', 'passable', 'climbable', 'traversable']
senticnet['surpass'] = [0.77, 0, 0, 0.791, '#joyful', '#admirable', 0.52, 'outrank', 'shine_at', 'excel_at', 'exceed', 'excel']
senticnet['surpliced'] = [-0.533, 0, 0.937, -0.802, '#angry', '#disgusting', -0.757, 'gowned', 'petticoated', 'clad', 'arrayed', 'caparisoned']
senticnet['surprise'] = [0.936, 0.969, 0, 0, '#joyful', '#interesting', 0.635, 'surprised', 'surprise_party', 'wow', 'uncanny', 'astonishment']
senticnet['surprise_friend'] = [0.749, 0.767, 0, 0, '#joyful', '#interesting', 0.505, 'blow_out_candle', 'act_foolish', 'receive_gift', 'tear_paper', 'say_love']
senticnet['surprise_party'] = [0, -0.6, 0, 0, '#surprising', '#surprising', 0.2, 'surprised', 'surprise', 'wow', 'uncanny', 'astonishment']
senticnet['surprise_person'] = [-0.112, -0.043, 0, -0.106, '#sad', '#disgusting', -0.058, 'pierce', 'spread_butter', 'taste_flavor', 'digest', 'clean_up_kitchen']
senticnet['surprised'] = [0.045, -0.664, 0, 0.363, '#surprising', '#admirable', 0.357, 'astonishingly', 'amazingly', 'surprising', 'surprisedly', 'surprisingly']
senticnet['surprisedly'] = [0.045, -0.664, 0, 0.363, '#surprising', '#admirable', 0.357, 'astonishingly', 'amazingly', 'surprised', 'surprising', 'surprisingly']
senticnet['surprising'] = [0.045, -0.664, 0, 0.363, '#surprising', '#admirable', 0.357, 'astonishingly', 'amazingly', 'surprise', 'surprisedly', 'surprisingly']
senticnet['surprisingly'] = [0.736, 0, 0, 0.768, '#joyful', '#admirable', 0.501, 'astonishingly', 'amazingly', 'alteration', 'peripety', 'bombshell']
senticnet['surrealistic'] = [-0.93, 0, 0.94, -0.772, '#sad', '#angry', -0.881, 'delusive', 'phantasmagoric', 'phantasmagorical', 'unrealistic', 'wild']
senticnet['surrender'] = [-0.38, 0.212, -0.238, -0.117, '#sad', '#scared', -0.174, 'defeat', 'terror', 'military_action', 'lose_battle', 'cruelty']
senticnet['surreptitious'] = [0, 0, -0.93, -0.999, '#scared', '#disgusting', -0.643, 'stealthy', 'furtive', 'clandestine', 'sneaky', 'undercover']
senticnet['surround'] = [0.049, 0.167, -0.053, 0.295, '#interesting', '#admirable', 0.153, 'four_sides', 'around', 'six_sides', 'neighborhood', 'dolby_surround']
senticnet['surround_ocean'] = [0, 0, 0.082, 0, '#angry', '#angry', -0.027, 'surround_water', 'land_mass', 'land_area', 'sea', 'large_land_mass']
senticnet['surround_water'] = [0, 0, 0.072, 0, '#angry', '#angry', -0.024, 'surround_ocean', 'land_mass', 'land_area', 'surround', 'large_land_mass']
senticnet['survey'] = [-0.045, 0.1, 0.051, 0.137, '#interesting', '#admirable', 0.047, 'find_number', 'regularly', 'list_number', 'calculator', 'navigation']
senticnet['survival'] = [0.843, 0.823, 0, 0, '#joyful', '#interesting', 0.555, 'sustain_life', 'sustenance', 'nutrition', 'keep_alive', 'satisfy_hunger']
senticnet['survival_species'] = [0, 0.815, 0, 0.933, '#interesting', '#admirable', 0.583, 'ejaculate', 'pass_gene', 'ecstasy', 'lower_standard_live', 'ejaculation']
senticnet['survive'] = [0.855, 0.841, 0, 0, '#joyful', '#interesting', 0.565, 'stay_alive', 'get_oxygen', 'like_taste', 'alive', 'crave']
senticnet['susceptibility'] = [-0.787, 0, 0.6, -0.616, '#sad', '#disgusting', -0.668, 'suggestibility', 'sensitivity', 'capacity', 'reactivity', 'predisposition']
senticnet['susceptible'] = [0.933, -0.755, 0, 0.89, '#joyful', '#admirable', 0.859, 'amenable', 'tractable', 'pliable', 'capable', 'vulnerable']
senticnet['susceptibleness'] = [-0.691, 0, 0.945, -0.652, '#sad', '#angry', -0.763, 'suggestibility', 'sensitivity', 'capacity', 'reactivity', 'predisposition']
senticnet['sushi_restaurant'] = [0, 0, -0.065, -0.036, '#scared', '#disgusting', -0.034, 'coral_reef', 'saltwater', 'tidal_pool', 'fish_market', 'reef']
senticnet['suspect'] = [0, 0, -0.829, -0.823, '#scared', '#disgusting', -0.551, 'murder_suspect', 'robbery_suspect', 'rape_suspect', 'murder', 'doubt']
senticnet['suspend'] = [-0.076, 0, -0.061, 0, '#sad', '#scared', -0.046, 'capital_punishment', 'destroy_building', 'reverse', 'jump_off_cliff', 'kill_self']
senticnet['suspense'] = [-0.076, 0, -0.061, 0, '#sad', '#scared', -0.046, 'anxiety', 'apprehension', 'insecurity', 'tension', 'horror_movie']
senticnet['suspenseful'] = [0, 0, 0.862, -0.794, '#angry', '#disgusting', -0.552, 'suspensive', 'nail-biting', 'cliff-hanging', 'apathetically', 'concern']
senticnet['suspension'] = [-0.076, 0, -0.061, 0, '#sad', '#scared', -0.046, 'steer_wheel', 'gear_shift', 'chassis', 'brake_pedal', 'air_vent']
senticnet['suspension_bridge'] = [0.807, 0.851, 0, 0, '#joyful', '#interesting', 0.553, 'bridge', 'under_bridge', 'golden_gate_bridge', 'side_road', 'roadside']
senticnet['suspensive'] = [-0.076, 0, -0.061, 0, '#sad', '#scared', -0.046, 'suspenseful', 'suspense', 'anxiety', 'tension', 'apprehension']
senticnet['suspicion'] = [-0.229, 0.087, -0.321, 0.105, '#sad', '#scared', -0.119, 'citation', 'problem', 'jeopardy', 'effect', 'exclusion']
senticnet['suspicious'] = [0, 0, -0.894, -0.941, '#scared', '#disgusting', -0.612, 'mistrustful', 'untrusting', 'leery', 'fishy', 'wary']
senticnet['suss_out'] = [0.559, -0.643, 0, 0.949, '#surprising', '#admirable', 0.717, 'watch_over', 'keep_an_eye_on', 'watch', 'study', 'observe']
senticnet['sustain_life'] = [0.716, 0.823, 0, 0, '#joyful', '#interesting', 0.513, 'survive', 'stay_alive', 'live', 'like_taste', 'get_oxygen']
senticnet['sustained'] = [0.876, 0.808, 0, 0, '#joyful', '#interesting', 0.561, 'dogging', 'persisting', 'continuous', 'consecutive', 'perpetual']
senticnet['suture'] = [-0.036, -0.044, 0.079, -0.092, '#angry', '#disgusting', -0.054, 'string', 'bandage', 'filament', 'thread', 'needle_thread']
senticnet['svelte'] = [0, 0, -0.814, -0.979, '#scared', '#disgusting', -0.598, 'urbane', 'refined', 'slim', 'lithesome', 'polished']
senticnet['swad'] = [-0.635, 0, 0.862, -0.523, '#sad', '#angry', -0.673, 'knot', 'bunch', 'tuft', 'tussock', 'agglomeration']
senticnet['swagger_stick'] = [0.609, -0.744, 0, 0.716, '#surprising', '#admirable', 0.69, 'malacca', 'sword', 'cane', 'sword_cane', 'sword_stick']
senticnet['swallow_food'] = [0, -0.01, 0.014, -0.102, '#angry', '#disgusting', -0.035, 'burp', 'prepare_ingredient', 'say_grace', 'measure_ingredient', 'add_spice']
senticnet['swallow_semen'] = [0.915, 0.868, 0, 0, '#joyful', '#interesting', 0.594, 'learn_world', 'find_information', 'see_exhibit', 'see_artifact', 'learn_subject']
senticnet['swamp'] = [0.831, 0.914, 0, 0, '#joyful', '#interesting', 0.582, 'flatness', 'boring', 'flat_tire', 'flat_foot', 'small_breast']
senticnet['swamp_chestnut_oak'] = [0.776, -0.6, 0, 0.568, '#joyful', '#surprising', 0.648, 'chestnut_oak', 'chinquapin_oak', 'chinkapin_oak', 'yellow_chestnut_oak', 'basket_oak']
senticnet['swamp_locust'] = [-0.856, 0, 0.5, -0.709, '#sad', '#disgusting', -0.688, 'courbaril', 'water_locust', 'locust_tree', 'honey_locust', 'black_locust']
senticnet['swamp_red_oak'] = [0.672, -0.696, 0, 0.831, '#surprising', '#admirable', 0.733, 'southern_red_oak', 'red_oak', 'turkey_oak', 'northern_red_oak', 'oak']
senticnet['swan_down'] = [0.814, -0.539, 0, 0.624, '#joyful', '#admirable', 0.659, 'feather', 'plume', 'duck_down', 'goose_down', 'down_feather']
senticnet['swank'] = [0.915, -0.809, 0, 0.58, '#joyful', '#surprising', 0.768, 'elegance', 'jauntiness', 'rakishness', 'nattiness', 'dapperness']
senticnet['swap'] = [-0.055, 0.241, -0.06, 0.286, '#interesting', '#admirable', 0.137, 'give_take', 'barter', 'exchange_goods', 'transaction', 'lower_price']
senticnet['sward'] = [-0.131, 0, 0, -0.071, '#sad', '#disgusting', -0.067, 'grass', 'butter_bread', 'fill_bottle', 'scrub_floor', 'sod']
senticnet['swash'] = [-0.879, 0, 0.682, -0.533, '#sad', '#angry', -0.698, 'slosh_around', 'spatter', 'splatter', 'plash', 'splash']
senticnet['swashbuckler'] = [-0.558, 0, 0.967, -0.777, '#angry', '#disgusting', -0.767, 'madcap', 'tearaway', 'lunatic', 'hothead', 'daredevil']
senticnet['swat'] = [-0.025, 0, 0.077, 0, '#sad', '#angry', -0.034, 'record', 'file_bill', 'webpage', 'store_record', 'ideal']
senticnet['swear'] = [-0.258, 0.089, -0.282, 0.141, '#sad', '#scared', -0.103, 'make_promise', 'investigation', 'reply_question', 'ask', 'deliberate']
senticnet['swear_lot'] = [-0.228, 0, -0.15, -0.15, '#sad', '#scared', -0.176, 'bigot', 'censorship', 'kidnap', 'intolerance', 'bad_word']
senticnet['swearword'] = [-0.806, 0, 0.899, -0.524, '#sad', '#angry', -0.743, 'filth', 'smut', 'expletive', 'curse_word', 'profanity']
senticnet['sweat'] = [0.929, 0.77, 0, 0, '#joyful', '#interesting', 0.566, 'heavy_breathe', 'tired_leg', 'pull_muscle', 'get_tired', 'breathlessness']
senticnet['sweat_lot'] = [0.862, 0.921, 0, 0, '#joyful', '#interesting', 0.594, 'swear', 'feel_out_breath', 'get_sweaty', 'tired_leg', 'get_tired']
senticnet['sweater_girl'] = [0.73, -0.802, 0, 0.826, '#surprising', '#admirable', 0.786, 'girl', 'miss', 'missy', 'young_lady', 'young_woman']
senticnet['sweating'] = [-0.584, 0, 0.773, -0.797, '#angry', '#disgusting', -0.718, 'perspiration', 'polyhidrosis', 'diaphoresis', 'sudation', 'hidrosis']
senticnet['sweaty'] = [0.912, 0.767, 0, 0, '#joyful', '#interesting', 0.56, 'pull_muscle', 'heart_rate_increase', 'heavy_breathe', 'get_exhausted', 'tire']
senticnet['sweaty_person'] = [0.854, 0.996, 0, 0, '#joyful', '#interesting', 0.617, 'underwear', 'bikini', 'pulley', 'swimsuit', 'lifeguard']
senticnet['sweep'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'cleanness', 'dust_furniture', 'clean_floor', 'vacuum_floor', 'clean']
senticnet['sweep_aside'] = [-0.967, 0, 0.005, -0.914, '#sad', '#disgusting', -0.629, 'discard', 'reject', 'dismiss', 'scrap', 'throw_away']
senticnet['sweep_floor'] = [-0.069, 0, 0, 0, '#sad', '#sad', -0.023, 'wash_window', 'dry_clothes', 'wash_dog', 'mop_floor', 'bind_book']
senticnet['sweep_over'] = [0.627, -0.651, 0, 0.968, '#surprising', '#admirable', 0.749, 'overwhelm', 'overpower', 'benight', 'whelm', 'overcome']
senticnet['sweet'] = [0.112, 0, 0, 0.141, '#joyful', '#admirable', 0.084, 'aftertaste', 'sweet_food', 'bake_good', 'round_pastry', 'eatable']
senticnet['sweet_buckeye'] = [-0.579, 0, 0.582, -0.65, '#angry', '#disgusting', -0.604, 'horse_chestnut', 'dwarf_buckeye', 'bottlebrush_buckeye', 'red_buckeye', 'particolored_buckeye']
senticnet['sweet_dream'] = [0.172, 0, 0, 0.086, '#joyful', '#admirable', 0.086, 'wear_pyjamas', 'comfortable_place_sleep', 'lie_back', 'nap', 'toss_turn']
senticnet['sweet_drink'] = [0.863, 0, 0, 0.724, '#joyful', '#admirable', 0.529, 'water', 'bottle_water', 'beer', 'plastic_container', 'convenience_store']
senticnet['sweet_food'] = [0.084, 0, 0.024, 0.091, '#joyful', '#admirable', 0.05, 'bake_good', 'bake_product', 'sweet', 'eatable', 'yummy']
senticnet['sweet_fruit'] = [0.226, 0.124, 0.046, 0.255, '#joyful', '#admirable', 0.186, 'green_fruit', 'round_fruit', 'crunchy', 'red_fruit', 'small_fruit']
senticnet['sweet_grass'] = [-0.766, 0, 0.513, -0.722, '#sad', '#disgusting', -0.667, 'foxtail', 'foxtail_grass', 'manna_grass', 'meadow_grass', 'wood_meadowgrass']
senticnet['sweet_pickle'] = [-0.818, 0, 0.543, -0.63, '#sad', '#disgusting', -0.664, 'caper', 'gherkin', 'relish', 'dill_pickle', 'pickle']
senticnet['sweet_roll'] = [-0.594, 0, 0.643, -0.536, '#sad', '#angry', -0.591, 'cross_bun', 'hot_cross_bun', 'bear_paw', 'bear_claw', 'bun']
senticnet['sweet_scabious'] = [-0.827, 0, 0.619, -0.941, '#sad', '#disgusting', -0.796, 'scabiosa', 'pincushion_flower', 'mournful_widow', 'field_scabious', 'flower']
senticnet['sweet_sour'] = [0.041, 0.101, -0.053, 0.153, '#interesting', '#admirable', 0.081, 'flavorful', 'taste_good', 'flavor', 'yummy', 'savor']
senticnet['sweet_talker'] = [0.946, -0.913, 0, 0.664, '#joyful', '#surprising', 0.841, 'pretender', 'phony', 'phoney', 'hypocrite', 'dissembler']
senticnet['sweet_taste'] = [0.16, 0, 0.039, 0.121, '#joyful', '#admirable', 0.081, 'taste_bitter', 'sweetness', 'sweet', 'sweet_food', 'after_taste']
senticnet['sweet_tooth'] = [0, 0.074, 0, 0.071, '#interesting', '#admirable', 0.048, 'candy', 'sweet', 'sugar', 'candy_store', 'chocolate']
senticnet['sweet_treat'] = [0.096, -0.004, 0.025, 0.077, '#joyful', '#admirable', 0.051, 'sweet', 'food_item', 'bake_good', 'round_pastry', 'morning_food']
senticnet['sweeten'] = [0.9, -0.849, 0, 0.673, '#joyful', '#surprising', 0.807, 'sugarcoat', 'honey', 'glaze', 'change_taste', 'sugar']
senticnet['sweetener'] = [0.53, -0.64, 0, 0.934, '#surprising', '#admirable', 0.701, 'aspartame', 'honey', 'saccharin', 'sugar', 'refined_sugar']
senticnet['sweetening'] = [0.54, -0.91, 0, 0.579, '#surprising', '#admirable', 0.676, 'aspartame', 'honey', 'saccharin', 'sugar', 'refined_sugar']
senticnet['sweetness'] = [0.032, 0, 0, 0.089, '#joyful', '#admirable', 0.04, 'taste_bitter', 'bake_product', 'sweet_food', 'flavor', 'eatable']
senticnet['sweetness_and_light'] = [0.554, -0.503, 0, 0.502, '#joyful', '#surprising', 0.52, 'amiability', 'affability', 'affableness', 'amiableness', 'bonhomie']
senticnet['swell'] = [0, 0.164, -0.112, 0.132, '#interesting', '#admirable', 0.061, 'tide', 'ocean_tide', 'sea_movement', 'ocean_movement', 'farewell']
senticnet['swell_up'] = [-0.992, 0, 0.68, -0.902, '#sad', '#disgusting', -0.858, 'bloat', 'blister', 'vesicate', 'belly', 'belly_out']
senticnet['swelled_head'] = [-0.845, 0, 0.969, -0.685, '#sad', '#angry', -0.833, 'posturing', 'conceitedness', 'egotism', 'boastfulness', 'vainglory']
senticnet['swelling'] = [-0.572, 0, 0.857, -0.786, '#angry', '#disgusting', -0.738, 'edema', 'oedema', 'hydrops', 'dropsy', 'bloat']
senticnet['swift'] = [0, 0.075, 0, 0.079, '#interesting', '#admirable', 0.051, 'haste', 'rabbit', 'chipmunk', 'rapid', 'squirrel']
senticnet['swim_animal'] = [-0.202, -0.108, 0.07, -0.245, '#sad', '#disgusting', -0.136, 'gill', 'sea_life', 'seafood', 'flipper', 'fillet']
senticnet['swim_lake'] = [0.827, 0.981, 0, 0, '#joyful', '#interesting', 0.603, 'swim_ocean', 'smoke_joint', 'fly_around', 'bug_person', 'shovel_snow']
senticnet['swim_ocean'] = [0, 0.086, 0, 0, '#interesting', '#interesting', 0.029, 'mow_lawn', 'weight_lift', 'sit_in_shade', 'cut_grass', 'trust_friend']
senticnet['swim_sea'] = [0.816, 0, 0, 0, '#joyful', '#joyful', 0.272, 'fee_cat', 'visit_grandmother', 'swim_ocean', 'appear_beautiful', 'hot_summer']
senticnet['swim_swimmingpool'] = [0.879, 0, 0, 0, '#joyful', '#joyful', 0.293, 'snow_ski', 'swim_ocean', 'swim_water', 'wear_suit', 'fight_other']
senticnet['swim_underwater'] = [0.751, 0, 0, 0, '#joyful', '#joyful', 0.25, 'wear_swimsuit', 'see_fish', 'family_fun', 'take_leak', 'explore_underwater']
senticnet['swim_water'] = [0.879, 0, 0, 0, '#joyful', '#joyful', 0.293, 'snow_ski', 'swim_ocean', 'swim_swimmingpool', 'wear_suit', 'fight_other']
senticnet['swiming_pool'] = [0, 0.733, 0, 0.81, '#interesting', '#admirable', 0.514, 'swim', 'water_activity', 'movement_of_water', 'water_sport', 'backstroke']
senticnet['swimmer'] = [0, 0, -0.058, -0.074, '#scared', '#disgusting', -0.044, 'chlorine', 'lifeguard', 'still_water', 'large_body', 'shallow_water']
senticnet['swimming_crab'] = [-0.698, 0, 0.766, -0.826, '#angry', '#disgusting', -0.763, 'stone_crab', 'crab', 'rock_crab', 'fiddler_crab', 'pea_crab']
senticnet['swimming_pool'] = [0.021, 0, 0, 0.076, '#joyful', '#admirable', 0.032, 'pool', 'pond', 'bay', 'lake', 'swimsuit']
senticnet['swimsuit'] = [-0.032, -0.029, 0.059, -0.096, '#angry', '#disgusting', -0.053, 'shore', 'bottom_ocean', 'swim', 'ocean_floor', 'pacific']
senticnet['swindle'] = [-0.914, 0, 0.85, -0.766, '#sad', '#angry', -0.843, 'fraud_in_fact', 'positive_fraud', 'mail_fraud', 'fraud', 'rig']
senticnet['swindler'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'gouger', 'confidence_man', 'defrauder', 'conman', 'fraud']
senticnet['swine_flu'] = [0.998, -0.546, 0, 0.957, '#joyful', '#admirable', 0.834, 'contagious_disease', 'contagion', 'swine_influenza', 'grippe', 'respiratory_disease']
senticnet['swine_influenza'] = [0.998, -0.546, 0, 0.957, '#joyful', '#admirable', 0.834, 'contagious_disease', 'contagion', 'grippe', 'swine_flu', 'respiratory_disease']
senticnet['swing_arm'] = [0.213, 0.273, -0.136, 0.29, '#interesting', '#admirable', 0.213, 'trip', 'stumble', 'almost_fall', 'move_upwards', 'come_pair']
senticnet['swing_bat'] = [-0.037, -0.082, 0.094, -0.084, '#angry', '#disgusting', -0.044, 'hit_ball_with_bat', 'hit_ball', 'step_up_plate', 'strike_out', 'miss_ball']
senticnet['swing_set'] = [0, 0, 0.735, -0.708, '#angry', '#disgusting', -0.481, 'noise_pollution', 'roadway_square', 'fresh_air', 'dog_poop', 'wildflower']
senticnet['swirl'] = [0.15, 0, 0, 0.202, '#joyful', '#admirable', 0.117, 'dance_move', 'waltz', 'twirl_around', 'sway', 'salsa']
senticnet['swiss_army_knife'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'address_book', 'get_rich', 'ladle', 'blank_check', 'whisk']
senticnet['swiss_watch'] = [0, 0.823, 0, 0.883, '#interesting', '#admirable', 0.569, 'time', 'clock_face', 'tell_time', 'timekeeper', 'device_measure_time']
senticnet['switch'] = [0, 0.108, 0, 0.202, '#interesting', '#admirable', 0.103, 'source_electricity', 'read_instruction_manual', 'find_tape', 'find_address', 'turn']
senticnet['switch_button'] = [-0.054, 0.081, 0, 0.12, '#interesting', '#admirable', 0.049, 'shut_door', 'turn_knob', 'enter_door', 'wave_hello', 'open_mailbox']
senticnet['switch_computer'] = [0.027, 0.099, 0.009, 0, '#joyful', '#interesting', 0.039, 'find_computer', 'turn_computer_on', 'a_lot_of_time', 'buy_computer', 'connect_internet']
senticnet['switch_off'] = [0.224, 0.169, -0.076, 0, '#joyful', '#interesting', 0.106, 'sun_beach', 'cool_room', 'keep_dry', 'stay_dry', 'cold_outside']
senticnet['switch_on'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'energy', 'use_fuel', 'energy_use', 'use_electricity', 'use_transport']
senticnet['switch_on_light'] = [0.937, 0, 0, 0.828, '#joyful', '#admirable', 0.588, 'create_light', 'light_candle', 'light_match', 'turn_on_torch', 'create_flame']
senticnet['switch_on_radio'] = [0, 0, 0, 0.882, '#admirable', '#admirable', 0.294, 'listen_cd', 'turn_on_radio', 'radio', 'listen_music', 'put_radio']
senticnet['switch_television'] = [0, 0, -0.059, -0.044, '#scared', '#disgusting', -0.034, 'turn_television', 'turn_tv', 'turn_television_set', 'switch_tv', 'find_tv']
senticnet['switch_tv'] = [-0.049, 0, 0, -0.035, '#sad', '#disgusting', -0.028, 'turn_television', 'near_tv', 'turn_tv_set', 'turn_television_set', 'turn_on_tv']
senticnet['switchblade_knife'] = [0.818, -0.956, 0, 0.695, '#joyful', '#surprising', 0.823, 'jackknife', 'clasp_knife', 'penknife', 'switchblade', 'pocket_knife']
senticnet['swoon'] = [-0.608, 0, 0.541, -0.525, '#sad', '#angry', -0.558, 'zonk_out', 'pass_out', 'faint', 'conk', 'change_state']
senticnet['swoop_up'] = [0.981, -0.727, 0, 0.638, '#joyful', '#surprising', 0.782, 'swoop', 'snatch_up', 'seize', 'prehend', 'clutch']
senticnet['sword'] = [0.741, 0.922, 0, 0, '#joyful', '#interesting', 0.554, 'gun_knife', 'atomic_bomb', 'hydrogen_bomb', 'hatchet', 'nuclear_bomb']
senticnet['sword_cane'] = [0.609, -0.744, 0, 0.716, '#surprising', '#admirable', 0.69, 'malacca', 'sword', 'swagger_stick', 'cane', 'sword_stick']
senticnet['sword_stick'] = [0.609, -0.744, 0, 0.716, '#surprising', '#admirable', 0.69, 'malacca', 'sword', 'swagger_stick', 'sword_cane', 'cane']
senticnet['swordplay'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'witty_remark', 'cross_talking', 'banter', 'wordplay', 'jester']
senticnet['swordsman'] = [0.771, -0.688, 0, 0.967, '#joyful', '#admirable', 0.809, 'combatant', 'battler', 'belligerent', 'fighter', 'scrapper']
senticnet['swordsmanship'] = [0.978, -0.857, 0, 0.736, '#joyful', '#surprising', 0.857, 'acquirement', 'skill', 'accomplishment', 'acquisition', 'attainment']
senticnet['sycophant'] = [-0.79, 0, 0.648, -0.864, '#sad', '#disgusting', -0.767, 'apple_polisher', 'bootlicker', 'fawner', 'servant', 'groveler']
senticnet['syllable'] = [0.055, 0, 0.028, 0.128, '#joyful', '#admirable', 0.052, 'idiom', 'remark', 'rhetoric', 'word', 'note']
senticnet['symbol'] = [0.043, 0.159, 0, 0.25, '#interesting', '#admirable', 0.151, 'unit_language', 'written_message', 'vowel', 'handwritten', 'punctuation']
senticnet['symbol_authority'] = [0.041, -0.05, 0, 0.083, '#surprising', '#admirable', 0.058, 'uniform', 'respect_law', 'justice', 'get_away_crime', 'change_society']
senticnet['symbol_love'] = [0.098, 0.185, -0.17, 0.249, '#interesting', '#admirable', 0.121, 'flower_type', 'sign_love', 'upward_movement', 'rise_plant', 'levitate']
senticnet['symbolic'] = [0.025, 0.238, -0.053, 0.25, '#interesting', '#admirable', 0.153, 'drawn', 'wall_hang', 'like_paint', 'artwork', 'craft']
senticnet['symbolic_logic'] = [0.629, -0.792, 0, 0.758, '#surprising', '#admirable', 0.726, 'system_of_rules', 'logical_system', 'mathematical_logic', 'formal_logic', 'system']
senticnet['symbolism'] = [0.19, 0.203, -0.157, 0.211, '#interesting', '#admirable', 0.149, 'propose_marriage', 'display_wealth', 'engage', 'holy_matrimony', 'similarity']
senticnet['symmetrical'] = [0.073, -0.094, 0.067, 0.105, '#surprising', '#admirable', 0.068, 'use_sport', 'spherical_shape', 'round_object', 'orb', 'bouncy']
senticnet['sympathetic'] = [0, 0, 0, 0.799, '#admirable', '#admirable', 0.266, 'adoration', 'confidence', 'enthusiasm', 'grateful', 'anticipation']
senticnet['sympathetic_strike'] = [-0.772, 0, 0.505, -0.503, '#sad', '#angry', -0.593, 'wildcat_strike', 'sympathy_strike', 'work_stoppage', 'walkout', 'job_action']
senticnet['sympathetically'] = [0, 0.751, 0, 0.8, '#interesting', '#admirable', 0.517, 'empathetically', 'empathic', 'empathetic', 'kind-heartedness', 'kindheartedness']
senticnet['sympathize'] = [-0.722, 0, 0, -0.88, '#sad', '#disgusting', -0.534, 'sympathetic', 'sympathetically', 'pity', 'sympathize_with', 'sympathy']
senticnet['sympathize_with'] = [0.83, 0.922, 0, 0, '#joyful', '#interesting', 0.584, 'compassionateness', 'feel_for', 'condole_with', 'sympathize', 'commiserate']
senticnet['sympathy'] = [0, 0.983, 0, 0.968, '#interesting', '#admirable', 0.65, 'empathy', 'kindness', 'sympathize', 'sympathize_with', 'sympathetic']
senticnet['sympathy_strike'] = [-0.772, 0, 0.505, -0.503, '#sad', '#angry', -0.593, 'wildcat_strike', 'work_stoppage', 'sympathetic_strike', 'walkout', 'job_action']
senticnet['symphony'] = [0.445, 0.37, -0.142, 0.483, '#joyful', '#admirable', 0.385, 'sing', 'music_studio', 'music_room', 'choir_orchestra', 'choir']
senticnet['symphony_hall'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'orchestra_play', 'orchestra_seat', 'music', 'orchestra_pit', 'concert_hall']
senticnet['symphony_orchestra'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'sing', 'music_studio', 'music_room', 'choir', 'symphony']
senticnet['symposium'] = [0.445, 0.37, -0.142, 0.483, '#joyful', '#admirable', 0.385, 'meeting', 'conference', 'convention', 'assembly', 'reunion']
senticnet['symptom'] = [-0.17, 0.086, -0.185, -0.068, '#sad', '#scared', -0.112, 'sign_sickness', 'body_reaction', 'ailment', 'unpleasant', 'sign']
senticnet['synagogue'] = [0, 0.209, 0.026, 0.184, '#interesting', '#admirable', 0.122, 'church', 'confession', 'temple', 'cathedral', 'monastery']
senticnet['syncopate'] = [-0.5, 0, 0.598, -0.809, '#angry', '#disgusting', -0.636, 'temper', 'corrupt', 'cushion', 'modify', 'spoil']
senticnet['syndactylism'] = [0.545, -0.621, 0, 0.946, '#surprising', '#admirable', 0.704, 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder', 'congenital_abnormality']
senticnet['syndactyly'] = [0.618, -0.6, 0, 0.546, '#joyful', '#surprising', 0.588, 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder', 'congenital_abnormality']
senticnet['synergism'] = [0.662, -0.793, 0, 0.919, '#surprising', '#admirable', 0.791, 'activity', 'natural_process', 'natural_action', 'potentiation', 'action']
senticnet['synovitis'] = [-0.819, 0, 0.789, -0.516, '#sad', '#angry', -0.708, 'rubor', 'redness', 'inflammation', 'tenosynovitis', 'tendosynovitis']
senticnet['syntax_error'] = [-0.985, 0, 0.869, -0.803, '#sad', '#angry', -0.886, 'error', 'programming_error', 'semantic_error', 'runtime_error', 'computer_error']
senticnet['syringe'] = [-0.029, 0, -0.124, -0.197, '#scared', '#disgusting', -0.117, 'x-ray_machine', 'medical_record', 'latex_glove', 'medicine', 'doctor_examination_room']
senticnet['system'] = [0, 0.172, 0, 0.138, '#interesting', '#admirable', 0.103, 'motherboard', 'cpu', 'hard_drive', 'computer_program', 'computer_disk']
senticnet['system_abstract_think'] = [-0.073, 0.147, 0, 0.074, '#interesting', '#admirable', 0.049, 'think_carefully', 'look_detail', 'contemplate', 'cogitate', 'logic']
senticnet['system_of_logic'] = [0.73, -0.587, 0, 0.768, '#joyful', '#admirable', 0.695, 'system_of_rules', 'symbolic_logic', 'mathematical_logic', 'formal_logic', 'system']
senticnet['system_of_rules'] = [0.661, -0.666, 0, 0.685, '#surprising', '#admirable', 0.671, 'ethical_code', 'theosophy', 'anthroposophy', 'logic', 'method']
senticnet['t-shirt'] = [0.041, 0.119, 0.017, 0, '#joyful', '#interesting', 0.048, 'shirt', 'robe', 'jacket', 'underwear', 'jeans']
senticnet['t_shirt'] = [0.856, 0.836, 0, 0, '#joyful', '#interesting', 0.564, 'duvet_cover', 'pillow_case', 'pillowcase', 'homosexual', 'sex_toy']
senticnet['tab'] = [0.041, 0.119, 0.017, 0, '#joyful', '#interesting', 0.048, 'account_book', 'fountain_pen', 'general_ledger', 'scrap_paper', 'scotch_tape']
senticnet['tabby_cat'] = [0.144, 0.134, -0.045, 0.238, '#joyful', '#admirable', 0.157, 'cat', 'written_word', 'kitty', 'baby_dog', 'dog']
senticnet['tabes'] = [-0.869, 0, 0.738, -0.93, '#sad', '#disgusting', -0.846, 'amyotrophia', 'amyotrophy', 'wasting_away', 'kraurosis', 'symptom']
senticnet['table'] = [0.036, -0.052, 0, 0, '#joyful', '#surprising', 0.029, 'gate_leg_table', 'kitchen_drawer', 'silverware_drawer', 'dine_table', 'cutlery_drawer']
senticnet['table_chair'] = [0.062, -0.017, 0, 0, '#joyful', '#surprising', 0.026, 'hostess', 'bottle_wine', 'human_intelligence', 'patron', 'salt_shaker']
senticnet['table_manner'] = [0, 0.932, 0, 0.931, '#interesting', '#admirable', 0.621, 'nanotechnology', 'class', 'manner', 'school_study', 'school_session']
senticnet['table_set'] = [0.052, -0.041, 0.024, 0, '#joyful', '#surprising', 0.023, 'dinner_table', 'meal_time', 'dinner', 'serve_dish', 'table']
senticnet['table_tennis'] = [0.059, -0.049, 0.014, 0, '#joyful', '#surprising', 0.031, 'golf', 'rugby', 'soccer', 'football', 'play_golf']
senticnet['tablespoon'] = [0.03, -0.05, 0, 0.059, '#surprising', '#admirable', 0.046, 'spoon', 'fork', 'spatula', 'utensil', 'bowl']
senticnet['tablet'] = [0.132, 0.1, 0.063, 0.159, '#joyful', '#admirable', 0.109, 'technology', 'phone', 'pad', 'use_technology', 'computer']
senticnet['taboo'] = [0.758, 0, 0, 0.747, '#joyful', '#admirable', 0.502, 'creepy', 'difficult_play', 'fun', 'competitive', 'just_fun']
senticnet['tabu'] = [-0.79, 0, 0.627, -0.816, '#sad', '#disgusting', -0.744, 'taboo', 'bias', 'tendentiousness', 'irrational_hostility', 'experimenter_bias']
senticnet['tabula_rasa'] = [0.992, -0.66, 0, 0.536, '#joyful', '#surprising', 0.729, 'nous', 'mind', 'brain', 'psyche', 'head']
senticnet['tabular_array'] = [0.757, -0.635, 0, 0.501, '#joyful', '#surprising', 0.631, 'panoply', 'row', 'table', 'array', 'matrix']
senticnet['tachycardia'] = [-0.83, 0, 0.987, -0.504, '#sad', '#angry', -0.774, 'heart_block', 'atrioventricular_block', 'bradycardia', 'ventricular_fibrillation', 'arrhythmia']
senticnet['tack'] = [0, -0.051, 0.079, -0.095, '#angry', '#disgusting', -0.041, 'c_clamp', 'thumb_tack', 'pin', 'pliers', 'without_space']
senticnet['tackle'] = [0.908, 0.869, 0, 0, '#joyful', '#interesting', 0.592, 'swing_bat', 'injured', 'sprain_ankle', 'fall_down', 'twist_ankle']
senticnet['tacky'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'wet', 'sticky', 'gluey', 'viscous', 'gooey']
senticnet['taco'] = [0.132, 0.1, 0.063, 0.159, '#joyful', '#admirable', 0.109, 'chime', 'school_end', 'ring_loudly', 'noise_maker', 'vital']
senticnet['taco_sauce'] = [-0.756, 0, 0.593, -0.591, '#sad', '#angry', -0.647, 'condiment', 'chili_sauce', 'steak_sauce', 'duck_sauce', 'hoisin_sauce']
senticnet['tact'] = [0.594, -0.603, 0, 0.813, '#surprising', '#admirable', 0.67, 'considerateness', 'delicacy', 'thoughtfulness', 'consideration', 'finesse']
senticnet['tactfulness'] = [0.83, -0.892, 0, 0.987, '#surprising', '#admirable', 0.903, 'considerateness', 'delicacy', 'thoughtfulness', 'consideration', 'finesse']
senticnet['tactical_maneuver'] = [-0.825, 0, 0.739, -0.509, '#sad', '#angry', -0.691, 'fake', 'juke', 'maneuver', 'manoeuvre', 'feint']
senticnet['tactual_sensation'] = [-0.943, 0, 0.827, -0.553, '#sad', '#angry', -0.774, 'cutaneous_sensation', 'haptic_sensation', 'skin_sensation', 'perception', 'creepiness']
senticnet['tadalafil'] = [-0.595, 0, 0.537, -0.577, '#sad', '#disgusting', -0.57, 'phentolamine', 'sildenafil', 'sildenafil_citrate', 'virility_drug', 'vardenafil']
senticnet['taffy'] = [0.037, -0.007, 0, 0.12, '#joyful', '#admirable', 0.055, 'bread_crumb', 'candy', 'bun', 'sweet', 'gush']
senticnet['tag'] = [0, 0.249, 0, 0.171, '#interesting', '#admirable', 0.14, 'amount_pay', 'value_amount', 'item_value', 'sticker', 'amount_money']
senticnet['tagger'] = [0.978, -0.722, 0, 0.527, '#joyful', '#surprising', 0.742, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['tai_chi'] = [0, 0.805, 0, 0.967, '#interesting', '#admirable', 0.591, 'energy', 'convert_energy', 'emotion', 'human_emotion', 'sentiment']
senticnet['tail'] = [0.028, 0, 0.013, 0.061, '#joyful', '#admirable', 0.025, 'paw', 'pointy_ear', 'fur_keep_warm', 'mane', 'claw']
senticnet['tail_suspect'] = [0, 0.902, 0, 0.746, '#interesting', '#admirable', 0.549, 'stop_crime', 'arrest_criminal', 'fine_person', 'direct_traffic', 'settle_argument']
senticnet['tailor_shop'] = [0.897, 0.948, 0, 0, '#joyful', '#interesting', 0.615, 'modern_home', 'home', 'relative_house', 'apartment', 'furniture_store']
senticnet['taipan'] = [-0.517, 0, 0.582, -0.976, '#angry', '#disgusting', -0.692, 'death_adder', 'ophidian', 'serpent', 'krait', 'elapid']
senticnet['take'] = [-0.044, 0.271, -0.207, 0.386, '#interesting', '#admirable', 0.135, 'take_away', 'obtain', 'permission', 'distribute', 'achieve']
senticnet['take_aback'] = [-0.569, 0, 0.897, -0.651, '#angry', '#disgusting', -0.706, 'shock', 'floor', 'ball_over', 'blow_out_of_water', 'galvanize']
senticnet['take_action'] = [-0.042, 0.131, -0.055, 0.186, '#interesting', '#admirable', 0.073, 'react', 'posture', 'do_something', 'activity', 'take_initiative']
senticnet['take_after'] = [0.559, -0.823, 0, 0.871, '#surprising', '#admirable', 0.751, 'model', 'conform_to', 'pattern', 'simulate', 'mock']
senticnet['take_afternoon_nap'] = [0.041, 0.074, 0, 0, '#joyful', '#interesting', 0.038, 'stretch_out', 'home_sweet_home', 'return_home', 'sit_back_relax', 'go_home']
senticnet['take_aim'] = [0.781, -0.719, 0, 0.595, '#joyful', '#surprising', 0.698, 'take', 'direct', 'aim', 'train', 'draw_bead_on']
senticnet['take_airplane'] = [0.729, 0.974, 0, 0, '#joyful', '#interesting', 0.568, 'travel', 'fast', 'faster', 'travel_fast', 'drive_fast']
senticnet['take_apart'] = [-0.119, 0, 0, -0.064, '#sad', '#disgusting', -0.061, 'use_screwdriver', 'brush_off', 'read_cover', 'upgrade', 'deflate']
senticnet['take_aspirin'] = [-0.241, 0, -0.231, -0.161, '#sad', '#scared', -0.211, 'chest_pain', 'poor_health', 'feel_pain', 'experience_pain', 'go_hospital']
senticnet['take_away'] = [-0.241, 0, -0.231, -0.161, '#sad', '#scared', -0.211, 'grab', 'steal', 'remove', 'take_off', 'take_out']
senticnet['take_back'] = [-0.12, 0.311, -0.084, 0.309, '#interesting', '#admirable', 0.139, 'rote', 'thoughtfulness', 'think_process', 'brain_function', 'imaginary']
senticnet['take_bath'] = [0.928, 0.778, 0, 0, '#joyful', '#interesting', 0.569, 'nice_clothes', 'put_clean_clothes', 'put_nice_clothes', 'change_clothes', 'take_shower']
senticnet['take_beach'] = [0.838, 0.954, 0, 0, '#joyful', '#interesting', 0.597, 'experience_new', 'learn_new_fact', 'learn_art', 'learn_book', 'intrigue']
senticnet['take_bite'] = [0.808, 0, 0, 0, '#joyful', '#joyful', 0.269, 'wash_first', 'use_tooth', 'buy_market', 'chew', 'put_napkin_lap']
senticnet['take_book'] = [-0.109, -0.026, 0.027, -0.218, '#sad', '#disgusting', -0.109, 'learn_how_read', 'turn_page', 'learn_read', 'learn_book', 'open_book']
senticnet['take_break'] = [0.251, 0.207, -0.082, 0.18, '#joyful', '#interesting', 0.185, 'middle_day', 'work_break', 'inactivity', 'recover', 'coffee_break']
senticnet['take_breath'] = [-0.037, -0.028, 0, -0.099, '#sad', '#disgusting', -0.036, 'feel_refreshed', 'feel_little_tired', 'slow_heart_beat', 'late_work', 'take_nap']
senticnet['take_bull_by_horns'] = [-0.635, 0, 0.559, -0.828, '#sad', '#disgusting', -0.674, 'confront', 'breast', 'front', 'encounter', 'oppose']
senticnet['take_bus'] = [-0.047, -0.014, 0, -0.062, '#sad', '#disgusting', -0.032, 'fly_airplane', 'go_drive', 'move_car', 'drive_to_work', 'drive_car']
senticnet['take_car_drive'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'out_car', 'avoid_fall', 'move_car', 'drive_car', 'go_drive']
senticnet['take_care'] = [0, 0.873, 0, 0.791, '#interesting', '#admirable', 0.555, 'watch_over', 'give_help', 'precaution', 'help_out', 'make_right']
senticnet['take_care_child'] = [0, 0.876, 0, 0.938, '#interesting', '#admirable', 0.605, 'lower_standard_live', 'cum', 'pass_gene', 'raise_child', 'pregnancy']
senticnet['take_care_of_pet'] = [0, -0.069, 0.046, 0.09, '#surprising', '#admirable', 0.038, 'discipline', 'dog_show', 'circus', 'training', 'animal']
senticnet['take_chance'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'try', 'assay', 'enjoy_challenge', 'wish_luck', 'go_for_it']
senticnet['take_charge'] = [-0.045, 0.183, -0.091, 0.117, '#interesting', '#admirable', 0.055, 'oversee', 'death_wish', 'man_ship', 'campaign', 'file_complaint']
senticnet['take_child'] = [0, 0.812, 0, 0.796, '#interesting', '#admirable', 0.536, 'orphan', 'become_parent', 'love_one', 'have_much', 'progeny']
senticnet['take_class'] = [-0.04, 0, 0.04, -0.083, '#sad', '#angry', -0.054, 'choose_subject', 'study_lot', 'a_lot_of_study', 'show_up_time', 'revise']
senticnet['take_clothes'] = [-0.026, -0.006, 0.039, -0.05, '#angry', '#disgusting', -0.036, 'undress', 'remove_clothes', 'take_off_clothes', 'take_clothes_off', 'naked']
senticnet['take_clothes_off'] = [-0.044, 0, -0.055, 0, '#sad', '#scared', -0.033, 'fill_bathtub', 'fill_bathtub_water', 'run_bath', 'turn_water', 'disrobe']
senticnet['take_cold_shower'] = [-0.188, -0.027, 0.058, -0.234, '#sad', '#disgusting', -0.151, 'open_eye', 'eye_open', 'turn_on_tv', 'near_tv', 'rend_movie']
senticnet['take_course'] = [0.798, 0.754, 0, 0.779, '#joyful', '#admirable', 0.777, 'learn_science', 'attend_class', 'study_subject', 'learn_subject', 'memorize']
senticnet['take_court'] = [0.782, 0.714, 0, 0, '#joyful', '#interesting', 0.499, 'lawyer', 'settle_dispute', 'seek_justice', 'arbitrator', 'call_lawyer']
senticnet['take_crap'] = [0, 0, 0, -0.947, '#disgusting', '#disgusting', -0.316, 'good_vision', 'stay_sober', 'find_car_key', 'open_car_door', 'put_key_ignition']
senticnet['take_cruise'] = [0.028, -0.037, 0.059, -0.101, '#angry', '#disgusting', -0.032, 'go_sea', 'windsurf', 'kayak', 'go_dive', 'sailboat']
senticnet['take_day_off'] = [0.16, 0.143, -0.086, 0.055, '#joyful', '#interesting', 0.091, 'finish_work', 'make_life_easy', 'move_furniture', 'accomplish_task', 'help_person']
senticnet['take_deep_breath'] = [-0.082, -0.009, 0.033, -0.118, '#sad', '#disgusting', -0.075, 'set_timer', 'yawn', 'look_out_window', 'drink_soda', 'listen_tape']
senticnet['take_dive'] = [-0.959, 0, 0.597, -0.933, '#sad', '#disgusting', -0.83, 'dissemble', 'feign', 'sham', 'pretend', 'affect']
senticnet['take_down'] = [-0.756, 0, 0.632, -0.825, '#sad', '#disgusting', -0.738, 'depress', 'move', 'displace', 'incline', 'reef']
senticnet['take_drug'] = [0, 0, 0.967, -0.929, '#angry', '#disgusting', -0.632, 'sleep_well', 'meditate', 'feel_refreshed', 'take_breath', 'get_over_illness']
senticnet['take_dump'] = [-0.093, -0.026, 0.048, -0.155, '#sad', '#disgusting', -0.09, 'soak_hot_tub', 'go_potty', 'go_pee', 'use_toilet', 'wash_up']
senticnet['take_easy'] = [0, 0.824, 0, 0, '#interesting', '#interesting', 0.275, 'relax', 'recuperate', 'take_nap', 'lie_back', 'take_rest']
senticnet['take_exam'] = [-0.031, 0.086, 0.01, 0.091, '#interesting', '#admirable', 0.045, 'write_term_paper', 'flash_card', 'take_final', 'flash_cardination', 'take_midterm']
senticnet['take_examination'] = [-0.031, 0.086, 0.01, 0.091, '#interesting', '#admirable', 0.045, 'write_term_paper', 'take_exam', 'take_final', 'flash_card', 'take_midterm']
senticnet['take_father_offspring'] = [0, 0.868, 0, 0.965, '#interesting', '#admirable', 0.611, 'familial_relationship', 'sibling', 'family_relation', 'mother_brother', 'kin']
senticnet['take_film'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'see_favorite_show', 'watch_film', 'watch_movie', 'see_movie', 'enjoy_film']
senticnet['take_final'] = [-0.031, 0.086, 0.01, 0.091, '#interesting', '#admirable', 0.045, 'write_term_paper', 'take_exam', 'flash_card', 'take_examination', 'take_midterm']
senticnet['take_final_exam'] = [0.027, 0.179, -0.073, 0.122, '#interesting', '#admirable', 0.085, 'take_exam', 'stay_alert', 'take_examination', 'take_final', 'take_midterm']
senticnet['take_firm_stand'] = [-0.824, 0, 0.827, -0.898, '#angry', '#disgusting', -0.85, 'stand_pat', 'hold_firm', 'stand_fast', 'maintain', 'stand_firm']
senticnet['take_for'] = [0.894, -0.515, 0, 0.907, '#joyful', '#admirable', 0.772, 'consider', 'view', 'regard', 'reckon', 'see']
senticnet['take_for_granted'] = [0.863, -0.947, 0, 0.986, '#surprising', '#admirable', 0.932, 'postulate', 'posit', 'assume', 'presume', 'presuppose']
senticnet['take_friend_out'] = [-0.035, -0.048, 0.069, -0.101, '#angry', '#disgusting', -0.052, 'make_reservation', 'purchase_ticket', 'bring_money', 'buy_ticket_theater', 'make_sure_money']
senticnet['take_hike'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'climb_stair', 'exercise_daily', 'stay_up_night', 'skydive', 'staircase']
senticnet['take_holiday'] = [0.847, 0.738, 0, 0.908, '#joyful', '#admirable', 0.831, 'take_time_off_work', 'travel_to_another_place', 'catch_catfish', 'pack_luggage', 'get_away']
senticnet['take_home'] = [0, 0.915, 0, 0.988, '#interesting', '#admirable', 0.634, 'bill_pay', 'settle_bill', 'send_money', 'financial_transaction', 'give_cash']
senticnet['take_in'] = [-0.994, 0, 0.553, -0.528, '#sad', '#angry', -0.692, 'cannibalize', 'take', 'ingest', 'have', 'consume']
senticnet['take_initiative'] = [-0.042, 0.131, -0.055, 0.186, '#interesting', '#admirable', 0.073, 'react', 'posture', 'take_action', 'behave', 'do_something']
senticnet['take_it_easy'] = [-0.627, 0, 0.628, -0.965, '#angry', '#disgusting', -0.74, 'relax', 'loosen_up', 'unbend', 'unwind', 'decompress']
senticnet['take_kindly_to'] = [0.794, -0.664, 0, 0.699, '#joyful', '#admirable', 0.719, 'give_lift', 'tend', 'incline', 'lean', 'run']
senticnet['take_leak'] = [-0.03, 0.11, 0, 0.128, '#interesting', '#admirable', 0.069, 'freestyle', 'flip', 'jump_air', 'backstroke', 'go_underwater']
senticnet['take_lesson'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'learn_read_music', 'take_music_lesson', 'a_lot_of_practice', 'put_music', 'press_key']
senticnet['take_life'] = [-0.721, 0, 0.623, -0.688, '#sad', '#disgusting', -0.677, 'murder_another_person', 'kill_person', 'kill', 'commit_murder', 'kill_man']
senticnet['take_look'] = [0.883, 0, 0, 0.976, '#joyful', '#admirable', 0.62, 'skim_through', 'read_cover', 'look_over', 'read_through', 'read_fast']
senticnet['take_lying_down'] = [-0.51, 0, 0.589, -0.664, '#angry', '#disgusting', -0.588, 'endure', 'brook', 'tolerate', 'stomach', 'abide']
senticnet['take_medicine'] = [-0.964, 0, 0.636, -0.982, '#sad', '#disgusting', -0.861, 'sick', 'sickness', 'need_cure', 'mental_disease', 'disease']
senticnet['take_message'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'leave_message', 'message', 'recall_message', 'send_message', 'read_message']
senticnet['take_metro'] = [0, 0.923, 0, 0.737, '#interesting', '#admirable', 0.553, 'hitchhike', 'take_walk', 'take_bus', 'go_to_another_place', 'ask_for_lift']
senticnet['take_midterm'] = [-0.031, 0.086, 0.01, 0.091, '#interesting', '#admirable', 0.045, 'write_term_paper', 'take_exam', 'take_final', 'take_examination', 'flash_card']
senticnet['take_money'] = [-0.058, 0.114, 0, 0.115, '#interesting', '#admirable', 0.057, 'use_money', 'money_bank', 'make_sure_enough_money', 'take_out_wallet', 'find_wallet']
senticnet['take_movie'] = [0.071, 0.079, 0, 0.075, '#interesting', '#admirable', 0.075, 'give_hug', 'become_aroused', 'find_partner', 'know_other', 'find_mate']
senticnet['take_music_lesson'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'find_teacher', 'take_lesson', 'learn_read_music', 'learn_how_to_sing', 'look_up_word_in_dictionary']
senticnet['take_nap'] = [0.747, 0.964, 0, 0, '#joyful', '#interesting', 0.57, 'lie_back', 'feel_little_tired', 'nap', 'laze', 'asleep']
senticnet['take_note'] = [0.986, 0.526, 0, 0.746, '#joyful', '#admirable', 0.753, 'take_note_class', 'collect_information', 'listen_lecture', 'finish_book', 'jot_down_note']
senticnet['take_note_class'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'write_note', 'take_note', 'make_note', 'jot_down_idea', 'write_word']
senticnet['take_number'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'use_phone', 'call_number', 'write_number', 'contact', 'add_number']
senticnet['take_oath'] = [0, -0.043, 0.02, 0.079, '#surprising', '#admirable', 0.034, 'take_stand', 'promise', 'marry', 'change_society', 'get_married']
senticnet['take_off'] = [0, 0.095, 0, 0.074, '#interesting', '#admirable', 0.056, 'buy_wash_powder', 'water_soap', 'turn_faucet', 'laundry_detergent', 'fill_bathtub_water']
senticnet['take_off_clothes'] = [0.714, -0.583, 0, 0.667, '#joyful', '#admirable', 0.655, 'take_clothes_off', 'fill_bathtub_water', 'turn_water', 'remove_clothes', 'remove_cloth']
senticnet['take_off_coat'] = [0.801, 0, 0, 0.812, '#joyful', '#admirable', 0.538, 'check_time', 'eat_peanut', 'wear_clothes', 'arrive_work', 'think_dog']
senticnet['take_off_glass'] = [-0.027, -0.012, 0.019, -0.064, '#sad', '#disgusting', -0.033, 'turn_off_light', 'put_pyjamas', 'wear_pyjamas', 'close_eye', 'lay_down']
senticnet['take_off_shoes'] = [0, -0.025, 0.027, -0.133, '#angry', '#disgusting', -0.045, 'go_pee', 'undress', 'brush_tooth', 'go_bathroom', 'remove_clothes']
senticnet['take_on'] = [-0.885, 0, 0.854, -0.668, '#sad', '#angry', -0.802, 'approach', 'undertake', 'tackle', 'face_up', 'set_about']
senticnet['take_order'] = [0, 0.104, 0, 0.082, '#interesting', '#admirable', 0.062, 'chore', 'scrub_floor', 'serve', 'quit_work', 'finish_work']
senticnet['take_out'] = [0.032, 0.093, -0.06, 0.069, '#interesting', '#admirable', 0.045, 'injection', 'aim', 'construction_work', 'spear', 'gunfire']
senticnet['take_out_loan'] = [-0.064, 0.151, 0, 0.075, '#interesting', '#admirable', 0.054, 'need_money', 'much_money', 'earn_wage', 'need_make_money', 'balance_check_account']
senticnet['take_out_trash'] = [0, 0.976, 0, 0.837, '#interesting', '#admirable', 0.604, 'part_of_family', 'father_child', 'babysit', 'mother_child', 'relationship']
senticnet['take_out_wallet'] = [-0.047, 0, 0.03, 0, '#sad', '#angry', -0.026, 'use_atm', 'carry_wallet', 'carry_credit_card', 'decide_buy', 'look_price']
senticnet['take_over'] = [0, 0.333, -0.219, 0.384, '#interesting', '#admirable', 0.166, 'compel', 'ownership', 'movement_towards', 'imperative', 'permission']
senticnet['take_over_world'] = [-0.069, 0, 0, 0, '#sad', '#sad', -0.023, 'throw_party', 'screwdriver', 'start_business', 'drill_hole', 'find_build']
senticnet['take_pain'] = [-0.903, 0, 0.031, -0.928, '#sad', '#disgusting', -0.621, 'pain', 'hurt', 'injury', 'cry', 'ache']
senticnet['take_phone_call'] = [0.756, 0.79, 0, 0, '#joyful', '#interesting', 0.515, 'conversation', 'chat_friend', 'communicate', 'talk_far_away', 'chat']
senticnet['take_photo'] = [0.891, 0.827, 0, 0, '#joyful', '#interesting', 0.573, 'fall_ground', 'fall', 'fall_over', 'break_neck', 'crash_car']
senticnet['take_photograph'] = [0, 0.333, -0.219, 0.384, '#interesting', '#admirable', 0.166, 'take_picture', 'picture', 'video', 'use_camera', 'photograph']
senticnet['take_picture'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'point_out', 'try_understand', 'desire_travel', 'share_opinion', 'blink']
senticnet['take_place'] = [0, 0.067, 0, 0.062, '#interesting', '#admirable', 0.043, 'social_skill', 'show_up', 'go_abroad', 'go_new_place', 'visit']
senticnet['take_pulse'] = [0, 0.108, 0.01, 0.121, '#interesting', '#admirable', 0.073, 'use_screwdriver', 'tool', 'study_physic', 'medical_equipment', 'garden_implement']
senticnet['take_responsibility'] = [0, 0.817, 0, 0.856, '#interesting', '#admirable', 0.558, 'enter_door', 'bicycle_store', 'turn_knob', 'carry_suitcase', 'broomstick']
senticnet['take_rest'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'feel_refreshed', 'sleep', 'feel_little_tired', 'put_feet_up', 'rejuvenation']
senticnet['take_revenge'] = [0.921, 0.992, 0, 0, '#joyful', '#interesting', 0.638, 'revenge', 'experience_emotion', 'even_out', 'vengeful', 'waste_time']
senticnet['take_risk'] = [0, 0, 0, -0.9, '#disgusting', '#disgusting', -0.3, 'end_argument', 'finish_task', 'cry_help', 'buy_stock', 'let_down']
senticnet['take_seat'] = [0.745, 0, 0, 0.867, '#joyful', '#admirable', 0.537, 'find_seat', 'watch_commercial', 'pay_attention', 'label', 'look_picture']
senticnet['take_shirt_off'] = [-0.142, 0, -0.104, -0.15, '#sad', '#disgusting', -0.132, 'hurt_back', 'hurt_oneself', 'break_leg', 'win_championship', 'hope_win']
senticnet['take_shit'] = [-0.118, -0.006, 0.023, -0.215, '#sad', '#disgusting', -0.117, 'look_picture', 'learn_new_idea', 'point_out', 'learn_quickly', 'complete_sentence']
senticnet['take_shortcut'] = [-0.936, 0, 0.072, -0.983, '#sad', '#disgusting', -0.664, 'cheat', 'fool', 'trick', 'short_cut', 'crime']
senticnet['take_shower'] = [0, 0.716, 0, 0.741, '#interesting', '#admirable', 0.486, 'clean_clothes', 'get_clean', 'become_clean', 'clean_body', 'wash_clothes']
senticnet['take_shower_bath'] = [0.06, 0.076, 0, 0.071, '#interesting', '#admirable', 0.069, 'take_shower', 'go_out_public', 'take_bath', 'bath', 'wash_up']
senticnet['take_sleep_pill'] = [-0.057, -0.043, 0.054, -0.077, '#sad', '#disgusting', -0.048, 'no_effort', 'turn_off_alarm_clock', 'lie_down_close_eye', 'lie_down_bed', 'count_sheep']
senticnet['take_sleeping_pill'] = [-0.086, 0, -0.18, -0.145, '#scared', '#disgusting', -0.137, 'ail', 'ill', 'go_hospital', 'unconscious', 'feel_sick']
senticnet['take_stand'] = [0, -0.043, 0.02, 0.079, '#surprising', '#admirable', 0.034, 'take_oath', 'promise', 'marry', 'change_society', 'get_married']
senticnet['take_step'] = [-0.092, 0.104, 0, 0.099, '#interesting', '#admirable', 0.037, 'use_leg', 'act_quickly', 'wear_running_shoes', 'wear_good_shoes', 'run_slowly']
senticnet['take_temperature'] = [0, 0.7, 0, 0.704, '#interesting', '#admirable', 0.468, 'fever', 'thermometer', 'high_temperature', 'hot_weather', 'temperature_measurement']
senticnet['take_test'] = [0, 0.769, 0, 0, '#interesting', '#interesting', 0.256, 'study_test', 'pass_test', 'knowledge_power', 'get_grade', 'make_parent_happy']
senticnet['take_ticket'] = [0, 0.769, 0, 0, '#interesting', '#interesting', 0.256, 'direct_play', 'face_music', 'shade_eye', 'give_signal', 'do_anything']
senticnet['take_time'] = [0, 0, 0, 0.875, '#admirable', '#admirable', 0.292, 'meditate', 'watch_others', 'wait_bus', 'conserve_energy', 'go_home']
senticnet['take_time_off_work'] = [0.95, 0.953, 0, 0, '#joyful', '#interesting', 0.634, 'get_work', 'take_vacation', 'see_new_place', 'go_holiday', 'sightsee']
senticnet['take_to_task'] = [-0.897, 0, 0.923, -0.737, '#sad', '#angry', -0.852, 'castigate', 'tell_off', 'brush_down', 'chasten', 'objurgate']
senticnet['take_train'] = [-0.072, -0.003, 0.009, 0, '#sad', '#angry', -0.026, 'leave_house', 'decide_to_go', 'open_front_door', 'know_go', 'find_museum']
senticnet['take_trip'] = [-0.059, 0.176, -0.066, 0.125, '#interesting', '#admirable', 0.059, 'bus_ride', 'buy_vending_machine', 'ride_subway', 'ride_train', 'acquire']
senticnet['take_turn'] = [-0.087, 0, 0, -0.073, '#sad', '#disgusting', -0.053, 'get_front', 'get_ticket', 'learn_patience', 'wait_patiently', 'conformist_attitude']
senticnet['take_up'] = [0.869, -0.598, 0, 0.66, '#joyful', '#admirable', 0.709, 'assimilate', 'absorb', 'reabsorb', 'resorb', 'imbibe']
senticnet['take_up_time'] = [0.78, 0.732, 0, 0, '#joyful', '#interesting', 0.504, 'late', 'debt', 'deadline', 'stress', 'little_time']
senticnet['take_vacation'] = [0.194, 0.118, 0, 0.216, '#joyful', '#admirable', 0.176, 'accomplish', 'work_oneself', 'find_job', 'acquire_wealth', 'catch_train']
senticnet['take_vitamin'] = [0, 0.075, 0, 0.063, '#interesting', '#admirable', 0.046, 'eat_healthy_food', 'eat_healthy', 'eat_right', 'exercise_often', 'eat_little']
senticnet['take_vitamin_food'] = [0.863, 0.875, 0, 0.935, '#interesting', '#admirable', 0.891, 'live_healthy_lifestyle', 'live_long_life', 'eat_healthy', 'good_nutrition', 'eat_well']
senticnet['take_walk'] = [0, 0.855, 0, 0.83, '#interesting', '#admirable', 0.562, 'hitchhike', 'ask_for_lift', 'take_bus', 'go_to_another_place', 'take_metro']
senticnet['take_wallet'] = [-0.061, 0, 0.033, 0, '#sad', '#angry', -0.031, 'make_list', 'plan_advance', 'drive_to_store', 'go_department_store', 'go_shopping']
senticnet['taken'] = [-0.049, 0.156, -0.079, 0.109, '#interesting', '#admirable', 0.046, 'category', 'final', 'school_grade', 'distinction', 'school_division']
senticnet['taken_seriously'] = [0.42, 0.219, 0, 0.435, '#joyful', '#admirable', 0.358, 'complement', 'much_need', 'knowledgeable', 'good_sense_of_humor', 'spice_life']
senticnet['taking'] = [-0.629, 0, 0.7, -0.838, '#angry', '#disgusting', -0.722, 'take', 'issue', 'return', 'payback', 'proceeds']
senticnet['tale'] = [-0.034, 0.169, -0.071, 0.218, '#interesting', '#admirable', 0.094, 'saga', 'fiction', 'fable', 'story', 'long_story']
senticnet['talebearer'] = [-0.682, 0, 0.726, -0.741, '#angry', '#disgusting', -0.716, 'gossip', 'gossiper', 'gossipmonger', 'gossip_girl', 'rumormonger']
senticnet['talent'] = [0.073, 0.228, -0.109, 0.263, '#interesting', '#admirable', 0.152, 'creativity', 'blueprint', 'skill', 'expressive', 'competence']
senticnet['taleteller'] = [-0.786, 0, 0.571, -0.774, '#sad', '#disgusting', -0.71, 'gossip', 'gossiper', 'gossipmonger', 'talk_back', 'rumormonger']
senticnet['talipes'] = [0.582, -0.667, 0, 0.661, '#surprising', '#admirable', 0.637, 'talipes_equinus', 'deformity', 'malformation', 'talipes_valgus', 'talipes_calcaneus']
senticnet['talipes_calcaneus'] = [0.582, -0.667, 0, 0.661, '#surprising', '#admirable', 0.637, 'talipes_equinus', 'deformity', 'malformation', 'talipes_valgus', 'talipes']
senticnet['talipes_equinus'] = [0.582, -0.667, 0, 0.661, '#surprising', '#admirable', 0.637, 'talipes', 'deformity', 'malformation', 'talipes_valgus', 'talipes_calcaneus']
senticnet['talipes_valgus'] = [0.582, -0.667, 0, 0.661, '#surprising', '#admirable', 0.637, 'talipes_equinus', 'deformity', 'malformation', 'talipes', 'talipes_calcaneus']
senticnet['talk'] = [-0.611, 0, 0.981, -0.983, '#angry', '#disgusting', -0.858, 'pious_platitude', 'nothingness', 'jazz', 'malarkey', 'malarky']
senticnet['talk_another_person'] = [0.099, 0.167, -0.059, 0.165, '#interesting', '#admirable', 0.124, 'handshake', 'know_language', 'use_language', 'another_person', 'find_another_person']
senticnet['talk_back'] = [-0.786, 0, 0.571, -0.774, '#sad', '#disgusting', -0.71, 'gossip', 'gossiper', 'gossipmonger', 'taleteller', 'rumormonger']
senticnet['talk_companion'] = [0, 0.716, 0, 0.741, '#interesting', '#admirable', 0.486, 'take_number', 'ask_menu', 'order_dinner', 'learn_patience', 'place_order']
senticnet['talk_dirty'] = [-0.991, 0, 0.142, -0.914, '#sad', '#disgusting', -0.682, 'rude', 'uneducated', 'flirt', 'scoundrel', 'satyr']
senticnet['talk_doctor'] = [-0.182, 0, -0.188, -0.121, '#sad', '#scared', -0.164, 'take_shirt_off', 'check_up', 'get_naked', 'see_doctor', 'find_out_healthy']
senticnet['talk_family'] = [-0.027, -0.03, 0.038, -0.072, '#angry', '#disgusting', -0.036, 'stop_eat', 'eat_burger', 'order_pizza', 'use_fork', 'talk_friend']
senticnet['talk_far_away'] = [0.907, 0.725, 0, 0, '#joyful', '#interesting', 0.544, 'conversation', 'take_phone_call', 'communicate', 'chat_friend', 'talk']
senticnet['talk_friend'] = [0.175, -0.031, 0, 0, '#joyful', '#surprising', 0.069, 'hump_leg', 'talk_person', 'become_friend', 'start_conversation', 'chat']
senticnet['talk_hairdresser'] = [-0.09, 0, 0, -0.045, '#sad', '#disgusting', -0.045, 'hair_get_short', 'bad_haircut', 'hair_wash', 'hair_become_short', 'keep_hair_short']
senticnet['talk_interest_person'] = [0.103, -0.132, 0.045, 0.094, '#joyful', '#surprising', 0.095, 'express_opinion', 'engage_conversation', 'misunderstanding', 'know_story', 'exchange_idea']
senticnet['talk_lawyer'] = [-0.049, 0.135, 0, 0.074, '#interesting', '#admirable', 0.053, 'lawyer', 'take_court', 'call_lawyer', 'seek_justice', 'settle_dispute']
senticnet['talk_lot'] = [0.931, 0.809, 0, 0, '#joyful', '#interesting', 0.58, 'boring_talk', 'yawn', 'bore_person', 'logorrheic', 'boring_activity']
senticnet['talk_loud'] = [-0.997, 0, 0.216, -0.921, '#sad', '#disgusting', -0.711, 'make_noise', 'talk_too_much', 'annoy', 'annoy_your_dad', 'annoy_your_mom']
senticnet['talk_loudly'] = [-0.949, 0, 0.137, -0.949, '#sad', '#disgusting', -0.678, 'cry', 'shout', 'scream', 'yell', 'weep']
senticnet['talk_man'] = [0.035, 0, 0, 0.183, '#joyful', '#admirable', 0.073, 'written_language', 'spoken', 'verbal_communication', 'speak', 'speech']
senticnet['talk_much'] = [0, 0, 0, -0.736, '#disgusting', '#disgusting', -0.245, 'convince', 'brag', 'discuss', 'transfer_knowledge', 'communicate_other_person']
senticnet['talk_neighbor'] = [-0.131, -0.067, 0.063, -0.17, '#sad', '#disgusting', -0.099, 'grow_impatient', 'think_dog', 'boredom', 'act_bored', 'whistle_happy_tune']
senticnet['talk_nonsense'] = [-0.954, 0, 0.479, -0.907, '#sad', '#disgusting', -0.78, 'nonsense', 'crazy', 'fool', 'mental_disease', 'mental_problem']
senticnet['talk_of_town'] = [-0.709, 0, 0.965, -0.535, '#sad', '#angry', -0.736, 'earful', 'malicious_gossip', 'scuttlebutt', 'talk', 'scandal']
senticnet['talk_on_phone'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'friend', 'communication', 'call_friend', 'chat', 'talk_spouse']
senticnet['talk_oneself'] = [0.133, 0.134, -0.05, 0.188, '#interesting', '#admirable', 0.135, 'go_moon', 'avoid_pain', 'sleep_late', 'love_pet', 'experience_life']
senticnet['talk_other'] = [-0.076, 0, -0.046, 0, '#sad', '#scared', -0.041, 'drink_espresso', 'eat_pasta', 'deal_card_player', 'eat_potato', 'stand_alone']
senticnet['talk_other_person'] = [0.794, 0.769, 0, 0.866, '#joyful', '#admirable', 0.81, 'hunt_duck', 'shake_hand', 'help_another', 'call_mom', 'say_hello']
senticnet['talk_person'] = [0, 0.926, 0, 0.824, '#interesting', '#admirable', 0.583, 'see_know', 'conduct_business', 'make_hotel_reservation', 'make_deals', 'send_information']
senticnet['talk_shit'] = [0, 0, 0.726, -0.941, '#angry', '#disgusting', -0.556, 'irritate', 'idiot', 'vex', 'rude', 'awful']
senticnet['talk_show'] = [0.827, -0.935, 0, 0.759, '#joyful', '#surprising', 0.84, 'party', 'use_party', 'birthday_party', 'gift_shop', 'gift_box']
senticnet['talk_spouse'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'friend', 'communication', 'talk_on_phone', 'chat', 'call_friend']
senticnet['talk_telephone'] = [0, 0.868, 0, 0.858, '#interesting', '#admirable', 0.575, 'call_mom', 'hunt_duck', 'make_telephone_call', 'answer_phone', 'talk_other_person']
senticnet['talk_through_one_hat'] = [-0.728, 0, 0.791, -0.94, '#angry', '#disgusting', -0.82, 'dissemble', 'feign', 'sham', 'pretend', 'affect']
senticnet['talk_to_an_expert'] = [0.612, 0.99, 0, 0.713, '#interesting', '#admirable', 0.772, 'cure_disease', 'find_cure', 'find_doctor', 'call_doctor', 'find']
senticnet['talk_to_exwife'] = [0, 0, -0.743, -0.821, '#scared', '#disgusting', -0.521, 'bad_connection', 'pay_off', 'pay_fee', 'grow_impatient', 'hate']
senticnet['talk_to_travel_agent'] = [-0.062, 0, 0.011, -0.028, '#sad', '#disgusting', -0.034, 'buy_plane_ticket', 'buy_airplane_ticket', 'decide_want_go', 'plan_time', 'decide_to_go']
senticnet['talk_too_much'] = [-0.906, 0, 0.877, -0.911, '#sad', '#disgusting', -0.898, 'annoy_person', 'bored_person', 'tired_person', 'boring_movie', 'boring_show']
senticnet['talkative'] = [0, 0, 0, 0.13, '#admirable', '#admirable', 0.043, 'verbalize', 'verbal', 'orate', 'no_fun', 'discourse']
senticnet['talking'] = [-0.763, 0, 0.578, -0.913, '#sad', '#disgusting', -0.751, 'pious_platitude', 'nothingness', 'jazz', 'malarkey', 'malarky']
senticnet['talking_to'] = [-0.634, 0, 0.556, -0.513, '#sad', '#angry', -0.568, 'reprimand', 'rebuke', 'reproof', 'reproval', 'reprehension']
senticnet['tall'] = [0.036, 0.138, 0.058, 0.223, '#interesting', '#admirable', 0.113, 'big', 'really_big', 'large', 'beautiful_look', 'huge']
senticnet['tall_building'] = [-0.057, -0.032, 0.018, -0.083, '#sad', '#disgusting', -0.042, 'build', 'nuclear_power_plant', 'skyscraper', 'construction_site', 'construct_building']
senticnet['tall_buttercup'] = [-0.808, 0, 0.632, -0.71, '#sad', '#disgusting', -0.717, 'herb', 'meadow_buttercup', 'buttercup', 'tall_crowfoot', 'tall_field_buttercup']
senticnet['tall_crowfoot'] = [-0.808, 0, 0.632, -0.71, '#sad', '#disgusting', -0.717, 'herb', 'meadow_buttercup', 'tall_buttercup', 'buttercup', 'tall_field_buttercup']
senticnet['tall_field_buttercup'] = [-0.808, 0, 0.632, -0.71, '#sad', '#disgusting', -0.717, 'herb', 'meadow_buttercup', 'tall_buttercup', 'tall_crowfoot', 'buttercup']
senticnet['tall_mallow'] = [-0.714, 0, 0.983, -0.628, '#sad', '#angry', -0.775, 'bush', 'musk_mallow', 'mus_rose', 'common_mallow', 'mallow']
senticnet['tall_man'] = [0, 0.098, -0.064, 0.118, '#interesting', '#admirable', 0.051, 'egret', 'broad', 'wide', 'wood_structure', 'large']
senticnet['tall_person'] = [0.072, 0, 0, 0.073, '#joyful', '#admirable', 0.048, 'large_plant', 'small_tree', 'plant_part', 'plant_big', 'green_leave']
senticnet['tall_play_basketball'] = [0, 0.715, 0, 0.782, '#interesting', '#admirable', 0.499, 'altruistic', 'better', 'advantage', 'want_badly', 'precise']
senticnet['tally'] = [0.024, 0.162, 0.072, 0.181, '#interesting', '#admirable', 0.098, 'count', 'total_number', 'all_of_it', 'numeral', 'ordinal']
senticnet['tame'] = [0.118, 0.28, -0.203, 0.216, '#interesting', '#admirable', 0.137, 'friend_person', 'sense_fear', 'mark_territory', 'trip_person', 'care_deeply']
senticnet['tamed'] = [0.778, -0.795, 0, 0.665, '#joyful', '#surprising', 0.746, 'gentle', 'docile', 'tame', 'sweet', 'domesticated']
senticnet['tan'] = [-0.969, 0, 0.636, -0.646, '#sad', '#disgusting', -0.75, 'burn', 'hyperpigmentation', 'sunhyperpigmentation', 'sunburn', 'physical_condition']
senticnet['tan_lotion'] = [0.739, 0, 0, 0.917, '#joyful', '#admirable', 0.552, 'suntan_lotion', 'hair_conditioner', 'dandruff_shampoo', 'hair_shape_gel', 'fluoride_toothpaste']
senticnet['tan_skin'] = [0.756, 0.713, 0, 0, '#joyful', '#interesting', 0.49, 'become_fat', 'flatulence', 'feel_rejuvenated', 'entropy', 'make_angry']
senticnet['tang'] = [0.071, 0, 0, 0, '#joyful', '#joyful', 0.024, 'smoothie', 'glass_water', 'drink', 'caffeine', 'lemonade']
senticnet['tangent'] = [-0.026, 0, 0.074, 0, '#sad', '#angry', -0.033, 'diagonal', 'incline_plane', 'downward', 'mountain_side', 'angle']
senticnet['tangerine'] = [0.028, -0.015, 0.063, -0.057, '#angry', '#disgusting', -0.026, 'apple', 'cranberry', 'green_apple', 'lime', 'orange']
senticnet['tangibility'] = [-0.639, 0, 0.694, -0.667, '#angry', '#disgusting', -0.667, 'corporality', 'tangibleness', 'palpability', 'reality', 'solidness']
senticnet['tangible'] = [0.053, -0.107, 0.014, -0.048, '#joyful', '#surprising', 0.033, 'look_scary', 'forgetful', 'theoretical', 'forgotten', 'material_type']
senticnet['tangibleness'] = [-0.639, 0, 0.694, -0.667, '#angry', '#disgusting', -0.667, 'tangibility', 'corporality', 'palpability', 'reality', 'solidness']
senticnet['tangled'] = [0, 0, 0.753, -0.798, '#angry', '#disgusting', -0.517, 'enmeshed', 'intermeshed', 'rootbound', 'matted', 'knotty']
senticnet['tank'] = [0.959, 0.791, 0, 0, '#joyful', '#interesting', 0.583, 'cannon', 'artillery', 'grenade', 'machine_gun', 'atomic_bomb']
senticnet['tank_destroyer'] = [-0.716, 0, 0.585, -0.514, '#sad', '#angry', -0.605, 'tank', 'armored_vehicle', 'armored_car', 'armoured_car', 'armored_personnel_carrier']
senticnet['tanning'] = [-0.845, 0, 0.557, -0.796, '#sad', '#disgusting', -0.733, 'corporal_punishment', 'lashing', 'whipping', 'whacking', 'flogging']
senticnet['tantalize'] = [-0.806, 0, 0.512, -0.82, '#sad', '#disgusting', -0.713, 'bemock', 'jeer', 'scoff', 'flout', 'chaff']
senticnet['tantrum'] = [-0.127, 0.138, 0.626, -0.62, '#angry', '#disgusting', -0.412, 'conniption', 'irascibility', 'irascible', 'choleric', 'quick_temper']
senticnet['tap'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'tuner', 'glass_of_water', 'rattle', 'run_water', 'vibration']
senticnet['tap_dance'] = [0.764, -0.526, 0, 0.866, '#joyful', '#admirable', 0.719, 'tap_dancing', 'hoofing', 'bachata', 'dance', 'salsa']
senticnet['tap_dancing'] = [0.764, -0.526, 0, 0.866, '#joyful', '#admirable', 0.719, 'hoofing', 'tap_dance', 'bachata', 'dance', 'salsa']
senticnet['tap_foot'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'impatience', 'impatient', 'wait_for', 'angry', 'anger']
senticnet['tap_toe'] = [0.901, 0, 0, 0.74, '#joyful', '#admirable', 0.547, 'tap_foot', 'sing_along', 'hear_song', 'earring', 'adjust_volume']
senticnet['tape_dispenser'] = [0, -0.044, 0.057, -0.079, '#angry', '#disgusting', -0.031, 'white-out', 'letter_scale', 'paper_punch', 'stapler', 'paper_fastener']
senticnet['tape_machine_room'] = [0, 0, -0.84, 0, '#scared', '#scared', -0.28, 'bad_karma', 'spoil_food', 'anxiety_disorder', 'anthrax', 'bad_food']
senticnet['tape_player'] = [0.09, -0.032, 0.015, 0, '#joyful', '#surprising', 0.036, 'dvd_player', 'several_types', 'copper_wire', 'control_room', 'technician']
senticnet['tape_television_show'] = [-0.047, 0.082, 0, 0.066, '#interesting', '#admirable', 0.034, 'record_television_show', 'turn_on_dvd_player', 'view_film_home', 'view_video', 'watch_television_show']
senticnet['taproom'] = [-0.814, 0, 0.553, -0.928, '#sad', '#disgusting', -0.765, 'bar', 'barroom', 'saloon', 'ginmill', 'sawdust_saloon']
senticnet['taradiddle'] = [-0.842, 0, 0.815, -0.603, '#sad', '#angry', -0.753, 'prevarication', 'fairytale', 'fairy_tale', 'fairy_story', 'song_and_dance']
senticnet['tardiness'] = [0.955, 0.901, 0, 0, '#joyful', '#interesting', 0.619, 'late', 'get_dark', 'rainy_day', 'split_end', 'house_look_better']
senticnet['target'] = [-0.026, 0, 0.016, -0.048, '#sad', '#disgusting', -0.03, 'hatchet', 'sharp_weapon', 'piece_of_metal', 'aim', 'projectile']
senticnet['target_cell'] = [-0.665, 0, 0.877, -0.642, '#sad', '#angry', -0.728, 'mast_cell', 'mastocyte', 'labrocyte', 'somatic_cell', 'phagocyte']
senticnet['target_practice'] = [-0.999, 0, 0, -0.74, '#sad', '#disgusting', -0.58, 'shoot_target', 'shoot_bullet', 'kill_pest', 'self_defense', 'murder']
senticnet['tarnish'] = [-0.034, 0, 0, -0.036, '#sad', '#disgusting', -0.023, 'cobalt', 'use_construction', 'many_shades', 'dye', 'gray']
senticnet['tarot_card'] = [0, 0.083, -0.053, 0.142, '#interesting', '#admirable', 0.057, 'credit', 'buck', 'riches', 'store_checkbook', 'psychic']
senticnet['tarradiddle'] = [-0.579, 0, 0.868, -0.517, '#sad', '#angry', -0.655, 'prevarication', 'fairytale', 'fairy_tale', 'fairy_story', 'song_and_dance']
senticnet['tart'] = [0.039, 0, 0.027, 0.141, '#joyful', '#admirable', 0.051, 'sugary', 'edible', 'delicious', 'peelable', 'edible_human']
senticnet['tart_up'] = [-0.519, 0, 0.576, -0.56, '#angry', '#disgusting', -0.552, 'ornament', 'grace', 'decorate', 'adorn', 'embellish']
senticnet['tartar_control_toothpaste'] = [0.877, 0.85, 0, 0, '#joyful', '#interesting', 0.576, 'gel_toothpaste', 'wax_dental_floss', 'dental_floss', 'toothpaste', 'fluoride_toothpaste']
senticnet['tartness'] = [-0.563, 0, 0.567, -0.534, '#sad', '#angry', -0.555, 'acidity', 'acidulousness', 'taste', 'taste_sensation', 'gustatory_sensation']
senticnet['task'] = [-0.037, 0.136, -0.091, 0.105, '#interesting', '#admirable', 0.038, 'chore', 'hire_help', 'police_work', 'career', 'job']
senticnet['taste'] = [0.961, 0, 0, 0.802, '#joyful', '#admirable', 0.588, 'food', 'put_mouth', 'tastebud', 'sour_taste', 'tongue']
senticnet['taste_awful'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'mouldy_bread', 'rotten', 'disgusting', 'green_bread', 'mouldy']
senticnet['taste_bitter'] = [0.09, 0, 0.025, 0.098, '#joyful', '#admirable', 0.054, 'sweetness', 'sweet_taste', 'flavor', 'sweet', 'bake_product']
senticnet['taste_flavor'] = [-0.112, -0.043, 0, -0.106, '#sad', '#disgusting', -0.058, 'pierce', 'spread_butter', 'surprise_person', 'digest', 'clean_up_kitchen']
senticnet['taste_food'] = [0.976, 0.786, 0, 0, '#joyful', '#interesting', 0.587, 'eat_animal', 'eat_pasta', 'close_together', 'hurt_animal', 'butter_toast']
senticnet['taste_good'] = [0.859, 0.867, 0, 0, '#joyful', '#interesting', 0.575, 'joy', 'digestion', 'get_fat', 'fill_stomach', 'overeat']
senticnet['taste_perception'] = [-0.93, 0, 0.537, -0.572, '#sad', '#disgusting', -0.68, 'taste', 'taste_sensation', 'gustatory_sensation', 'astringence', 'gustatory_perception']
senticnet['taste_property'] = [-0.799, 0, 0.58, -0.885, '#sad', '#disgusting', -0.755, 'bitter', 'bitterness', 'acidity', 'unpalatability', 'unpalatableness']
senticnet['taste_sensation'] = [-0.93, 0, 0.537, -0.572, '#sad', '#disgusting', -0.68, 'taste', 'astringence', 'gustatory_sensation', 'taste_perception', 'gustatory_perception']
senticnet['taste_sour'] = [0, 0, 0.084, -0.039, '#angry', '#disgusting', -0.041, 'love_child', 'raise_child', 'pass_gene', 'overpopulation', 'smile_child']
senticnet['taste_sugar'] = [0.907, 0.794, 0, 0.771, '#joyful', '#interesting', 0.824, 'cookie', 'fresh_food', 'good_taste_food', 'brownie', 'pie']
senticnet['taste_sweet'] = [0.911, 0.813, 0, 0, '#joyful', '#interesting', 0.575, 'enjoy_company_friend', 'enjoy_day', 'laugh_joke', 'comfort_friend', 'entertain_person']
senticnet['tasteful'] = [0.737, -0.854, 0, 0.623, '#joyful', '#surprising', 0.738, 'understated', 'esthetic', 'aesthetic', 'artistic', 'unostentatious']
senticnet['tasteless'] = [-0.717, 0, 0.559, -0.957, '#sad', '#disgusting', -0.744, 'unseasoned', 'unsalted', 'flavorless', 'flavourless', 'savorless']
senticnet['tasty'] = [0.076, 0, 0.032, 0.106, '#joyful', '#admirable', 0.05, 'delicious', 'good_eat', 'yummy', 'edible', 'eatable']
senticnet['tasty_food'] = [0.157, 0, 0.014, 0.107, '#joyful', '#admirable', 0.083, 'sweet', 'sweet_treat', 'bake_good', 'sweet_food', 'bake_product']
senticnet['tasty_good'] = [0.154, 0.112, 0, 0.193, '#joyful', '#admirable', 0.153, 'serve_cold', 'delicious', 'make_fruit', 'high_calorie', 'like_candy']
senticnet['tattered'] = [-0.843, 0, 0.653, -0.885, '#sad', '#disgusting', -0.794, 'battered', 'woebegone', 'worn', 'derelict', 'raddled']
senticnet['tattler'] = [-0.782, 0, 0.581, -0.698, '#sad', '#disgusting', -0.687, 'gossip', 'gossiper', 'gossipmonger', 'talk_back', 'rumormonger']
senticnet['tattletale'] = [-0.545, 0, 0.583, -0.519, '#sad', '#angry', -0.549, 'gossip', 'gossiper', 'gossipmonger', 'rumormonger', 'talk_back']
senticnet['tattletale_gray'] = [-0.513, 0, 0.651, -0.612, '#angry', '#disgusting', -0.592, 'silver_gray', 'gray_hair', 'old', 'gray', 'achromatic_color']
senticnet['taunt'] = [0, 0, 0.898, -0.735, '#angry', '#disgusting', -0.544, 'make_mad', 'win_battle', 'serious_injury', 'get_hurt', 'beaten']
senticnet['tautness'] = [-0.748, 0, 0.723, -0.594, '#sad', '#angry', -0.688, 'tone', 'tonicity', 'tonus', 'condition', 'status']
senticnet['tavern'] = [0.747, 0, 0, 0.829, '#joyful', '#admirable', 0.525, 'liquor_store', 'bar', 'pub', 'drinking_place', 'martini']
senticnet['tawdry'] = [0, 0, -0.945, -0.934, '#scared', '#disgusting', -0.626, 'flashy', 'garish', 'cheap', 'brassy', 'flash']
senticnet['tax'] = [-0.285, 0, -0.238, -0.126, '#sad', '#scared', -0.216, 'payment', 'owe', 'rend', 'bribe', 'reward']
senticnet['tax_bracket'] = [0.763, -0.677, 0, 0.945, '#joyful', '#admirable', 0.795, 'set', 'income_bracket', 'bracket', 'income', 'price_bracket']
senticnet['taxation'] = [0.559, -0.846, 0, 0.92, '#surprising', '#admirable', 0.775, 'single_tax', 'income_tax', 'capital_gains_tax', 'capital_levy', 'departure_tax']
senticnet['taxi_cab'] = [0.04, 0.144, -0.074, 0.122, '#interesting', '#admirable', 0.077, 'another_place', 'abroad', 'foreign_country', 'transit', 'elsewhere']
senticnet['taxonomic_group'] = [-0.96, 0, 0.556, -0.872, '#sad', '#disgusting', -0.796, 'animal_group', 'group', 'genotype', 'clade', 'biological_group']
senticnet['tchotchke'] = [-0.932, 0, 0.607, -0.678, '#sad', '#disgusting', -0.739, 'miss', 'girl', 'missy', 'young_lady', 'young_woman']
senticnet['tea'] = [0.092, 0, 0, 0, '#joyful', '#joyful', 0.031, 'coffee', 'green_tea', 'ice_tea', 'juice', 'part_of_dinner']
senticnet['tea_break'] = [0.789, -0.68, 0, 0.729, '#joyful', '#admirable', 0.733, 'refreshment', 'nosh', 'coffee_break', 'collation', 'meal']
senticnet['tea_cup'] = [0.126, 0.084, 0.031, 0.175, '#joyful', '#admirable', 0.118, 'sip', 'like_food', 'wet_cold', 'potable_liquid', 'watery']
senticnet['teach'] = [0.818, 0.85, 0, 0.753, '#joyful', '#interesting', 0.807, 'offer_opinion', 'teach_student', 'education', 'learn_new_information', 'teach_child']
senticnet['teach_child'] = [0.737, 0, 0, 0.94, '#joyful', '#admirable', 0.559, 'teach', 'share_knowledge', 'understand_idea', 'offer_opinion', 'educate_others']
senticnet['teach_class'] = [0.737, 0, 0, 0.94, '#joyful', '#admirable', 0.559, 'teach_lesson', 'professor', 'school_student', 'teacher', 'go_to_class']
senticnet['teach_computer'] = [0.737, 0, 0, 0.94, '#joyful', '#admirable', 0.559, 'teach', 'computer_lesson', 'teacher', 'teach_lesson', 'teach_class']
senticnet['teach_course'] = [0.098, 0, -0.048, 0.112, '#joyful', '#admirable', 0.054, 'research', 'scholar', 'professor', 'lecturer', 'invent']
senticnet['teach_lesson'] = [0.98, 0, 0, 0.85, '#joyful', '#admirable', 0.61, 'vengeance', 'retribution', 'revenge', 'correct_behavior', 'go_jail']
senticnet['teach_new'] = [0.925, 0, 0, 0.974, '#joyful', '#admirable', 0.633, 'teach_new_skill', 'share_idea', 'exchange_idea', 'share_thought', 'start_talk']
senticnet['teach_new_skill'] = [0.925, 0, 0, 0.974, '#joyful', '#admirable', 0.633, 'teach_new', 'share_idea', 'exchange_idea', 'share_thought', 'start_talk']
senticnet['teach_open_mind'] = [0.826, 0.881, 0, 0, '#joyful', '#interesting', 0.569, 'finish_test', 'act_bored', 'master_new_skill', 'master_skill', 'succeed_school']
senticnet['teach_other_person'] = [0.929, 0.861, 0, 0.862, '#joyful', '#admirable', 0.884, 'answer_question', 'learn_language', 'understand_better', 'memorize', 'commit_to_memory']
senticnet['teach_others'] = [0.98, 0, 0, 0.794, '#joyful', '#admirable', 0.591, 'become_expert', 'understand', 'clarification', 'trivia', 'discover_new']
senticnet['teach_person'] = [0.826, 0.881, 0, 0, '#joyful', '#interesting', 0.569, 'teach_student', 'learn_evolution', 'obtain_degree', 'get_high_education', 'listen_teacher']
senticnet['teach_school'] = [0.893, 0.975, 0, 0, '#joyful', '#interesting', 0.623, 'feel_hurt', 'teach_to_read', 'become_sad', 'find_school', 'get_sick']
senticnet['teach_student'] = [0.8, 0, 0, 0.914, '#joyful', '#admirable', 0.571, 'teach_person', 'learn_evolution', 'teach', 'offer_opinion', 'listen_teacher']
senticnet['teach_to_read'] = [0.826, 0.881, 0, 0, '#joyful', '#interesting', 0.569, 'teach_new', 'teach_person', 'teach_student', 'read', 'listen']
senticnet['teach_world'] = [0.928, 0.846, 0, 0, '#joyful', '#interesting', 0.591, 'thirst_knowledge', 'seek_truth', 'learn_new_fact', 'experience_new', 'learn_art']
senticnet['teacher'] = [0.8, 0, 0, 0.914, '#joyful', '#admirable', 0.571, 'professor', 'teach', 'school', 'lecturer', 'teach_lesson']
senticnet['teacher_pupil'] = [0.061, 0.179, 0, 0.177, '#interesting', '#admirable', 0.139, 'text_book', 'professor', 'group_student', 'lecturer', 'pupil']
senticnet['teaching'] = [0.548, -0.982, 0, 0.769, '#surprising', '#admirable', 0.766, 'education', 'teaching_reading', 'spoonfeeding', 'lecture', 'catechesis']
senticnet['teaching_reading'] = [0.548, -0.982, 0, 0.769, '#surprising', '#admirable', 0.766, 'education', 'teaching', 'spoonfeeding', 'lecture', 'catechesis']
senticnet['team_lose'] = [-0.873, 0, 0.987, -0.843, '#sad', '#angry', -0.901, 'winner_loser', 'competitiveness', 'win_money', 'passive', 'win']
senticnet['team_play'] = [0.72, 0, 0, 0.982, '#joyful', '#admirable', 0.567, 'teamwork', 'gather_together', 'play_together', 'play', 'coperation']
senticnet['team_sport'] = [0, -0.091, 0.019, 0.075, '#surprising', '#admirable', 0.049, 'rough_sport', 'ball_sport', 'rough_game', 'popular_sport_america', 'type_of_sport']
senticnet['team_up'] = [0.087, 0.15, 0, 0.151, '#interesting', '#admirable', 0.129, 'group_of_people', 'group', 'social_group', 'mass_person', 'organize_group']
senticnet['team_win'] = [0.338, 0.104, 0.046, 0.094, '#joyful', '#interesting', 0.163, 'team_win_game', 'win_game', 'run_basis', 'hit_ball_hard', 'lose_game']
senticnet['team_win_game'] = [0.367, 0.143, 0, 0.06, '#joyful', '#interesting', 0.19, 'team_win', 'win_game', 'hit_home_run', 'lose_game', 'extreme_elation']
senticnet['team_work'] = [0.487, 0.675, -0.267, 0.266, '#joyful', '#interesting', 0.387, 'solve_big_problem', 'gather_intelligence', 'intelligent', 'collective_intelligence', 'clever']
senticnet['teamwork'] = [0.808, 0.881, 0, 0, '#joyful', '#interesting', 0.563, 'win', 'strategize', 'try_best', 'catch_ball', 'lose_game']
senticnet['teapot'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'water_inside', 'water_spray', 'filter', 'bodily_waste', 'different_type']
senticnet['tear'] = [-0.107, -0.042, -0.127, -0.154, '#scared', '#disgusting', -0.115, 'cry', 'cry_hard', 'weep', 'tear_eye', 'sob']
senticnet['tear_apart'] = [-0.124, 0, -0.058, -0.057, '#sad', '#scared', -0.08, 'painful_injury', 'destroy', 'cause_bleed', 'sever', 'open_wind']
senticnet['tear_eye'] = [-0.044, -0.045, -0.076, -0.171, '#scared', '#disgusting', -0.082, 'emotional_reaction', 'make_others_laugh', 'cry_hard', 'shed_tear', 'start_laugh']
senticnet['tear_paper'] = [-0.125, -0.022, -0.09, 0, '#sad', '#scared', -0.064, 'master_skill', 'shoulder_responsibility', 'throw_fit', 'watch_d', 'sun_oneself']
senticnet['tear_up'] = [-0.959, 0, 0.423, -0.974, '#sad', '#disgusting', -0.785, 'cry', 'weep', 'tear', 'scream', 'shout']
senticnet['tearaway'] = [-0.558, 0, 0.967, -0.777, '#angry', '#disgusting', -0.767, 'madcap', 'swashbuckler', 'lunatic', 'hothead', 'daredevil']
senticnet['tearful'] = [-0.71, 0.312, -0.4, -0.08, '#sad', '#scared', -0.293, 'lachrymose', 'weeping', 'dolorous', 'tearfulness', 'weepiness']
senticnet['tearfulness'] = [-0.71, 0.312, -0.4, -0.08, '#sad', '#scared', -0.293, 'lachrymose', 'tearful', 'weeping', 'dolorous', 'weepiness']
senticnet['tease'] = [-0.964, 0, 0, -0.715, '#sad', '#disgusting', -0.56, 'think_funny', 'experience_joy', 'act_silly', 'embarrass_oneself', 'giggle']
senticnet['teased'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'mocked', 'tormented', 'bothered', 'annoyed', 'ridiculed']
senticnet['teasing'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['teaspoon'] = [-0.025, 0.167, 0.042, 0.142, '#interesting', '#admirable', 0.081, 'tea', 'kitchen_tool', 'knife', 'fork', 'spoon']
senticnet['technologic_car'] = [0.086, 0, 0, 0.13, '#joyful', '#admirable', 0.072, 'gas_electric', 'go_green', 'electric_car', 'large_automobile', 'large_car']
senticnet['technology'] = [0.083, 0.144, -0.048, 0.165, '#interesting', '#admirable', 0.115, 'golf_place', 'nanotechnology', 'topic', 'school_course', 'school_class']
senticnet['technophobe'] = [-0.973, 0, 0.62, -0.727, '#sad', '#disgusting', -0.773, 'obstructor', 'obstructer', 'naysayer', 'obstructionist', 'resister']
senticnet['teddy_bear'] = [0, -0.068, 0, 0, '#surprising', '#surprising', 0.023, 'collectible', 'beanbag', 'paper_airplane', 'barbie_doll', 'beanie_baby']
senticnet['tedious'] = [-0.078, 0, -0.048, 0, '#sad', '#scared', -0.042, 'lack_interest', 'lack_brightness', 'boring', 'become_dull', 'dark']
senticnet['tedium'] = [-0.124, -0.118, 0.052, -0.2, '#sad', '#disgusting', -0.086, 'lack_of_sleep', 'get_work_done', 'lose', 'tired_foot', 'written_paper']
senticnet['tee'] = [-0.025, 0.167, 0.042, 0.142, '#interesting', '#admirable', 0.081, 'religious_significance', 'stand', 'refuge', 'chess_game', 'out_place']
senticnet['teen'] = [-0.059, -0.024, 0, -0.045, '#sad', '#disgusting', -0.027, 'schoolchild', 'student', 'graduate_student', 'college_student', 'serious_student']
senticnet['teeth_whitening'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'beautiful_smile', 'smile', 'clean_teeth', 'white_tooth', 'dentist']
senticnet['teething'] = [-0.548, 0, 0.696, -0.673, '#angry', '#disgusting', -0.639, 'precocious_dentition', 'growth', 'growing', 'maturation', 'development']
senticnet['telegraph'] = [0.089, -0.017, 0, 0.117, '#joyful', '#admirable', 0.074, 'email', 'telephone_kiosk', 'phone', 'fax', 'handset']
senticnet['telekinesis'] = [-0.8, 0, 0.62, -0.712, '#sad', '#disgusting', -0.711, 'parapsychology', 'psychokinesis', 'clairvoyance', 'second_sight', 'extrasensory_perception']
senticnet['telephone_book'] = [0, -0.07, 0.091, -0.077, '#angry', '#disgusting', -0.033, 'bobby_pin', 'telephone_index', 'hairpin', 'clip', 'wave_clip']
senticnet['telephone_booth'] = [0.053, 0.1, 0, 0, '#joyful', '#interesting', 0.051, 'registry_office', 'lodgings', 'board_room', 'cubicle', 'reception_area']
senticnet['telephone_computer'] = [0.074, 0.069, 0.036, 0.055, '#joyful', '#interesting', 0.054, 'computer', 'browser', 'efficient', 'computer_manufacturer', 'modem']
senticnet['telephone_directory'] = [0, 0.076, 0, 0.066, '#interesting', '#admirable', 0.047, 'old_testament', 'religious_tract', 'cook_book', 'magazine', 'a_lot_of_books']
senticnet['telephone_index'] = [0, -0.07, 0.091, -0.077, '#angry', '#disgusting', -0.033, 'bobby_pin', 'wave_clip', 'hairpin', 'clip', 'telephone_book']
senticnet['telephone_kiosk'] = [0.089, -0.017, 0, 0.117, '#joyful', '#admirable', 0.074, 'email', 'telegraph', 'phone', 'fax', 'handset']
senticnet['telephone_number'] = [0, -0.034, 0.135, -0.042, '#angry', '#disgusting', -0.048, 'look_up_phone_number', 'read_email', 'find_phone_number', 'pass_information', 'give_information']
senticnet['telephone_pole'] = [0.087, -0.147, 0.06, 0, '#joyful', '#surprising', 0.058, 'phone', 'communication', 'cork', 'stick_paper', 'birch']
senticnet['telephone_ring'] = [0, -0.043, 0.018, 0.072, '#surprising', '#admirable', 0.032, 'dial_phone', 'phone_conversation', 'speak_loudly', 'call', 'use_phone']
senticnet['telephone_room'] = [0.035, -0.01, 0.027, 0.085, '#joyful', '#admirable', 0.034, 'telephone', 'cellphone', 'find_phone_number', 'phone', 'use_telephone']
senticnet['telescope'] = [0, 0.087, -0.07, 0.1, '#interesting', '#admirable', 0.039, 'binoculars', 'read_glass', 'eyeglass', 'camera', 'monocle']
senticnet['television'] = [0, 0.117, -0.077, 0.094, '#interesting', '#admirable', 0.045, 'theater_seat', 'theater_box', 'sticky_floor', 'stage_entrance', 'balcony']
senticnet['television_channel'] = [-0.09, 0.166, -0.146, 0.198, '#interesting', '#admirable', 0.043, 'television_station', 'tv_studio', 'watch_tv', 'radio_station', 'tv_station']
senticnet['television_news'] = [0.026, 0.227, 0, 0.233, '#interesting', '#admirable', 0.162, 'best_moment', 'sport_highlight', 'football_highlight', 'highlight', 'put_in_evidence']
senticnet['television_program'] = [0.162, -0.206, 0, 0.232, '#surprising', '#admirable', 0.2, 'tv_show', 'cartoon', 'children_story', 'tv_series', 'flower_shop']
senticnet['television_set'] = [0, 0, -0.049, -0.066, '#scared', '#disgusting', -0.038, 'soud_system', 'remove_control', 'tv_set', 'christian_fundamentalist', 'stair_down']
senticnet['television_station'] = [0, 0.07, 0, 0.071, '#interesting', '#admirable', 0.047, 'movie_studio', 'broadcast', 'stadium', 'film_studio', 'record_studio']
senticnet['television_view'] = [-0.091, 0, 0, -0.068, '#sad', '#disgusting', -0.053, 'beat_off', 'play_board_game', 'solve_puzzle', 'smoke_marijuana', 'rake_leave']
senticnet['tell_apart'] = [0.933, -0.638, 0, 0.59, '#joyful', '#surprising', 0.72, 'contradistinguish', 'severalize', 'differentiate', 'secern', 'secernate']
senticnet['tell_day'] = [0, 0.827, 0, 0.84, '#interesting', '#admirable', 0.556, 'impress_person', 'get_know', 'look_sexy', 'find_new_friend', 'visit_friend']
senticnet['tell_everyone'] = [0.074, 0.359, -0.224, 0.337, '#interesting', '#admirable', 0.182, 'newscaster', 'identify', 'make_right', 'proposition', 'request']
senticnet['tell_friend'] = [0.997, 0.929, 0, 0.941, '#joyful', '#admirable', 0.956, 'lose_track_time', 'get_excited', 'boredom', 'bored', 'kill_brain_cell']
senticnet['tell_funny_joke'] = [0.759, 0, 0, 0.975, '#joyful', '#admirable', 0.578, 'find_funny', 'tell_joke', 'laugh', 'sense_of_humor', 'good_joke']
senticnet['tell_information'] = [0.972, 0.734, 0, 0.517, '#joyful', '#interesting', 0.741, 'pass_information', 'share_knowledge', 'offer_opinion', 'tell_other_person', 'transfer_knowledge']
senticnet['tell_joke'] = [0.721, 0, 0, 0.969, '#joyful', '#admirable', 0.563, 'tell_funny_joke', 'applause', 'smile_laugh', 'embarrass_oneself', 'talk_much']
senticnet['tell_lie'] = [-0.945, 0, 0.507, -0.936, '#sad', '#disgusting', -0.796, 'tell_untruth', 'untruth', 'dishonesty', 'deceit', 'fraud']
senticnet['tell_love'] = [0.778, 0.956, 0, 0.706, '#joyful', '#interesting', 0.813, 'say_love', 'make_sale', 'draw_diagram', 'discuss_issue', 'receive_gift']
senticnet['tell_many_person'] = [0.733, 0.961, 0, 0, '#joyful', '#interesting', 0.565, 'express_information', 'illustrate_point', 'talk_far_away', 'express_oneself', 'communicate']
senticnet['tell_name'] = [0, 0.854, 0, 0.963, '#interesting', '#admirable', 0.606, 'hump_leg', 'introduce_oneself', 'say_hello', 'talkative', 'verbal']
senticnet['tell_off'] = [-0.856, 0, 0.631, -0.664, '#sad', '#disgusting', -0.717, 'call_on_carpet', 'take_to_task', 'chide', 'berate', 'bawl_out']
senticnet['tell_other_person'] = [-0.231, -0.054, -0.068, -0.166, '#sad', '#disgusting', -0.137, 'increase_understand', 'seek_understanding', 'learn_oneself', 'share_knowledge', 'offer_opinion']
senticnet['tell_others'] = [0.058, -0.063, -0.141, -0.07, '#scared', '#disgusting', -0.03, 'make_others_laugh', 'laugh', 'make_fun', 'start_laugh', 'laugh_out_loud']
senticnet['tell_secret'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'reply_question', 'state_fact', 'voice_opinion', 'share_opinion', 'keep_word']
senticnet['tell_story'] = [0.047, -0.063, 0, -0.032, '#joyful', '#surprising', 0.026, 'convey_information', 'evoke_emotion', 'express_idea', 'recite_poem', 'share_thought']
senticnet['tell_time'] = [0, 0.184, -0.065, 0.235, '#interesting', '#admirable', 0.118, 'swiss_watch', 'timekeeper', 'measure_passage_time', 'timekeep', 'time_event']
senticnet['tell_truth'] = [-0.102, 0.227, -0.195, 0.248, '#interesting', '#admirable', 0.059, 'tell_story', 'make_judgment', 'testify', 'arrest_criminal', 'call_police']
senticnet['tell_untruth'] = [-0.936, 0, 0.049, -0.985, '#sad', '#disgusting', -0.657, 'lie', 'fraud', 'dishonesty', 'untruth', 'deceit']
senticnet['tell_why'] = [-0.127, 0.179, -0.142, 0.204, '#interesting', '#admirable', 0.038, 'elaborate', 'inquire', 'request', 'explain', 'yes_no']
senticnet['teller'] = [0, 0.186, 0, 0.075, '#interesting', '#admirable', 0.087, 'money_inside', 'check_account', 'savings', 'money_storage', 'store_money']
senticnet['telltale'] = [-0.766, 0, 0.573, -0.685, '#sad', '#disgusting', -0.675, 'gossip', 'gossiper', 'gossipmonger', 'talk_back', 'rumormonger']
senticnet['temp'] = [0, 0.125, -0.055, 0.078, '#interesting', '#admirable', 0.049, 'measure_heat', 'temperature_measurement', 'measure_degree', 'temperature_measure', 'celsius']
senticnet['temper'] = [0, 0, 0.751, -0.818, '#angry', '#disgusting', -0.523, 'mood', 'humor', 'irritation', 'chasten', 'anneal']
senticnet['temperament'] = [-0.92, 0, 0.53, -0.67, '#sad', '#disgusting', -0.707, 'ill_nature', 'disagreeableness', 'unfriendliness', 'bloodthirstiness', 'aloneness']
senticnet['temperance'] = [0.916, -0.737, 0, 0.797, '#joyful', '#admirable', 0.817, 'natural_virtue', 'abstemiousness', 'dryness', 'sobriety', 'restraint']
senticnet['temperature'] = [-0.66, 0, 0.992, -0.658, '#sad', '#angry', -0.77, 'cold', 'boil', 'simmer', 'low_temperature', 'frigidity']
senticnet['temperature_measure'] = [0.053, 0.097, 0.036, 0.052, '#joyful', '#interesting', 0.055, 'temperature_measurement', 'celsius', 'measure_heat', 'heat_measure', 'measure_degree']
senticnet['temperature_measurement'] = [0.053, 0.092, 0.027, 0.062, '#interesting', '#admirable', 0.06, 'temperature_measure', 'measure_heat', 'celsius', 'heat_measure', 'measure_degree']
senticnet['tempest'] = [-0.961, 0, 0.581, -0.909, '#sad', '#disgusting', -0.817, 'hurly_burly', 'kerfuffle', 'commotion', 'disruption', 'disturbance']
senticnet['tempestuous'] = [-0.5, 0, 0.982, -0.85, '#angry', '#disgusting', -0.777, 'unpeaceable', 'stormy', 'unpeaceful', 'militant', 'belligerent']
senticnet['temple'] = [0, 0.247, 0.025, 0.218, '#interesting', '#admirable', 0.147, 'cathedral', 'chapel', 'church', 'catholic_church', 'confession']
senticnet['temporal_arteritis'] = [-0.853, 0, 0.657, -0.868, '#sad', '#disgusting', -0.793, 'pulseless_disease', 'arteritis', 'rubor', 'redness', 'polyarteritis']
senticnet['temporariness'] = [-0.877, 0, 0.744, -0.54, '#sad', '#angry', -0.72, 'impermanence', 'transience', 'transiency', 'transitoriness', 'mortality']
senticnet['temporary'] = [0.101, -0.237, 0.031, 0.105, '#surprising', '#admirable', 0.137, 'end_soon', 'stick', 'seldom', 'walk_stick', 'lift']
senticnet['temporary_expedient'] = [-0.973, 0, 0.84, -0.528, '#sad', '#angry', -0.78, 'pis_aller', 'last_resort', 'expedient', 'makeshift', 'stopgap']
senticnet['temporary_home'] = [0.092, 0, 0.012, 0.059, '#joyful', '#admirable', 0.046, 'place_sleep', 'save_space', 'stay', 'reside', 'sleep_upon']
senticnet['temporary_house'] = [0, 0.087, -0.055, 0.058, '#interesting', '#admirable', 0.03, 'hunt_fish', 'rest_place', 'counselor', 'summer_vacation', 'shelter']
senticnet['temporary_shelter'] = [0.196, 0.077, 0, 0.064, '#joyful', '#interesting', 0.112, 'lower_temperature', 'reduce_temperature', 'remove_heat', 'entertain_company', 'get_meal']
senticnet['temporary_state'] = [0.964, -0.592, 0, 0.982, '#joyful', '#admirable', 0.846, 'case', 'thinking_cap', 'frame_of_mind', 'psychological_state', 'psychological_condition']
senticnet['temptation'] = [0.712, 0, 0, 0, '#joyful', '#joyful', 0.237, 'woman', 'adam_and_eve', 'peach', 'green_apple', 'plum']
senticnet['tempting'] = [0, 0, -0.91, -0.958, '#scared', '#disgusting', -0.623, 'invite', 'allure', 'entice', 'lure', 'charm']
senticnet['ten_fingers'] = [0.754, 0.903, 0, 0, '#joyful', '#interesting', 0.552, 'hand', 'two_hands', 'forearm', 'five_fingers', 'wrist']
senticnet['ten_toes'] = [-0.04, 0, 0.059, 0, '#sad', '#angry', -0.033, 'human_limb', 'two_feet', 'thigh', 'lower_body', 'body_limb']
senticnet['tenacious'] = [0.905, 0.816, 0, 0, '#joyful', '#interesting', 0.574, 'retentive', 'long', 'dogged', 'dour', 'recollective']
senticnet['tend'] = [0, 0.37, -0.275, 0.283, '#interesting', '#admirable', 0.126, 'thoughtful', 'attitude', 'look_after', 'certainty', 'type_of_bear']
senticnet['tendency'] = [0.831, 0, 0, 0.865, '#joyful', '#admirable', 0.565, 'understanding', 'propensity', 'leaning', 'favor', 'proclivity']
senticnet['tendentiousness'] = [-0.79, 0, 0.627, -0.816, '#sad', '#disgusting', -0.744, 'taboo', 'tabu', 'bias', 'irrational_hostility', 'experimenter_bias']
senticnet['tender'] = [0, 0.742, 0, 0.893, '#interesting', '#admirable', 0.545, 'affectionate', 'lovesome', 'fond', 'contemplative', 'broody']
senticnet['tenderheartedness'] = [0.709, 0, 0, 0.853, '#joyful', '#admirable', 0.521, 'tenderly', 'feel_for', 'compassionateness', 'sympathize_with', 'condole_with']
senticnet['tenderly'] = [0.868, 0.745, 0, 0, '#joyful', '#interesting', 0.538, 'tenderheartedness', 'feel_for', 'compassionateness', 'sympathize_with', 'condole_with']
senticnet['tenderness'] = [0, 0.82, 0, 0.987, '#interesting', '#admirable', 0.602, 'lovesome', 'affectionate', 'fond', 'hopeful', 'expectantly']
senticnet['tendinitis'] = [-0.781, 0, 0.554, -0.878, '#sad', '#disgusting', -0.738, 'rubor', 'redness', 'inflammation', 'tennis_elbow', 'lateral_epicondylitis']
senticnet['tendonitis'] = [-0.413, 0, -0.284, -0.058, '#sad', '#scared', -0.252, 'carpal_tunnel_syndrome', 'health_issue', 'breaking_news', 'print_word', 'grade_paper']
senticnet['tendosynovitis'] = [-0.819, 0, 0.789, -0.516, '#sad', '#angry', -0.708, 'rubor', 'redness', 'inflammation', 'tenosynovitis', 'synovitis']
senticnet['tenesmus'] = [-0.56, 0, 0.981, -0.676, '#angry', '#disgusting', -0.739, 'muscle_spasm', 'blepharospasm', 'twitch', 'twitching', 'vellication']
senticnet['tennis_ball'] = [0.92, 0.77, 0, 0, '#joyful', '#interesting', 0.563, 'yo-yo', 'ball', 'basketball', 'sport_ball', 'ping_pong_paddle']
senticnet['tennis_elbow'] = [-0.98, 0, 0.678, -0.956, '#sad', '#disgusting', -0.871, 'rubor', 'redness', 'inflammation', 'epicondylitis', 'lateral_epicondylitis']
senticnet['tennis_game'] = [0.024, 0.152, -0.065, 0.236, '#interesting', '#admirable', 0.116, 'basketball_court', 'play_sport', 'playground_equipment', 'squash_court', 'gymnasium']
senticnet['tennis_match'] = [0, 0.11, 0, 0.061, '#interesting', '#admirable', 0.057, 'middle_road', 'room_temperature', 'car_race', 'tennis', 'loose_end']
senticnet['tennis_term'] = [0, 0.257, -0.133, 0.306, '#interesting', '#admirable', 0.143, 'sport', 'tennis', 'set_point', 'violent_action', 'match_point']
senticnet['tenonitis'] = [-0.738, 0, 0.778, -0.916, '#angry', '#disgusting', -0.811, 'rubor', 'redness', 'inflammation', 'tennis_elbow', 'lateral_epicondylitis']
senticnet['tenosynovitis'] = [-0.819, 0, 0.789, -0.516, '#sad', '#angry', -0.708, 'rubor', 'redness', 'inflammation', 'synovitis', 'tendosynovitis']
senticnet['tense'] = [-0.175, 0.154, -0.289, 0.073, '#sad', '#scared', -0.079, 'doctor_visit', 'bad_feeling', 'consequence', 'symptom', 'physical_reaction']
senticnet['tenseness'] = [-0.845, 0, 0.982, -0.924, '#angry', '#disgusting', -0.917, 'tone', 'tonicity', 'tonus', 'condition', 'status']
senticnet['tensile_strength'] = [0.8, -0.908, 0, 0.675, '#joyful', '#surprising', 0.794, 'indestructibility', 'durability', 'continuity', 'persistence', 'changelessness']
senticnet['tension'] = [-0.193, 0, 0, -0.225, '#sad', '#disgusting', -0.139, 'act_smart', 'paralysis', 'get_fight', 'head_hurt', 'make_mistake']
senticnet['tensity'] = [-0.627, 0, 0.81, -0.613, '#sad', '#angry', -0.683, 'tone', 'tonicity', 'tonus', 'condition', 'status']
senticnet['tentative'] = [-0.604, 0, 0.722, -0.843, '#angry', '#disgusting', -0.723, 'undetermined', 'undecided', 'unsettled', 'unresolved', 'open']
senticnet['terbinafine'] = [0.562, -0.543, 0, 0.949, '#joyful', '#admirable', 0.685, 'antifungal', 'antifungal_agent', 'fungicide', 'antimycotic', 'antimycotic_agent']
senticnet['tergiversate'] = [-0.977, 0, 0.737, -0.555, '#sad', '#angry', -0.756, 'deceive', 'sandbag', 'betray', 'lead_astray', 'misinform']
senticnet['term'] = [0, 0.257, -0.133, 0.306, '#interesting', '#admirable', 0.143, 'word', 'notion', 'section', 'season', 'date']
senticnet['termagant'] = [-0.598, 0, 0.573, -0.56, '#sad', '#angry', -0.577, 'disagreeable_woman', 'old_bag', 'shrew', 'frump', 'hellcat']
senticnet['terminal_disease'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'broken_heart', 'std', 'foolish', 'bad_feeling', 'complication']
senticnet['terminal_illness'] = [-0.973, 0, -0.941, -0.767, '#sad', '#scared', -0.894, 'ill_health', 'influenza', 'ridiculous', 'chicken_pox', 'pollute_air']
senticnet['terminate'] = [-0.224, 0.086, -0.22, 0, '#sad', '#scared', -0.119, 'demolish', 'maim', 'unbearable', 'eliminate', 'take_life']
senticnet['terminate_someone_employment'] = [-0.955, 0, 0.164, -0.975, '#sad', '#disgusting', -0.698, 'fired', 'unemployed', 'become_poor', 'need_money', 'need_new_job']
senticnet['termination'] = [-0.848, 0, 0.744, -0.581, '#sad', '#angry', -0.724, 'subversion', 'subversive_activity', 'overthrow', 'ending', 'conclusion']
senticnet['terrain'] = [-0.032, 0.091, 0, 0.094, '#interesting', '#admirable', 0.051, 'earth', 'flat_land', 'geographical_feature', 'dirt_soil', 'acreage']
senticnet['terrible'] = [-0.963, 0, -0.963, -0.78, '#sad', '#scared', -0.902, 'dread', 'fearful', 'horrible', 'hysteria', 'embarrass']
senticnet['terrible_crime'] = [-0.923, 0, 0.095, -0.91, '#sad', '#disgusting', -0.643, 'mess', 'distressingly_bad', 'awful_event', 'bad_influence', 'terrible_loss']
senticnet['terrible_event'] = [-0.868, 0, -0.924, -0.919, '#scared', '#disgusting', -0.904, 'tragedy', 'hamlet', 'perpetrator', 'play_person', 'play_in_theater']
senticnet['terrible_injury'] = [-0.925, 0, 0.742, -0.999, '#sad', '#disgusting', -0.889, 'painful', 'injury', 'hurt', 'pain', 'blood']
senticnet['terrible_loss'] = [-0.923, 0, 0.095, -0.91, '#sad', '#disgusting', -0.643, 'mess', 'distressingly_bad', 'terrible_crime', 'bad_influence', 'awful_event']
senticnet['terrible_misunderstand'] = [0.723, 0.926, 0, 0, '#joyful', '#interesting', 0.55, 'make_fun', 'laughter', 'laugh', 'silliness', 'forget_trouble']
senticnet['terrific'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'wondrously', 'tremendous', 'awesome', 'wondrous', 'marvelous']
senticnet['terrifically'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'terrific', 'wondrously', 'tremendous', 'marvelous', 'wondrous']
senticnet['terrified'] = [0.837, 0.85, 0, 0, '#joyful', '#interesting', 0.562, 'panic-struck', 'panic-stricken', 'panicked', 'panicky', 'frightened']
senticnet['terrify'] = [-0.998, 0, -0.744, -0.947, '#sad', '#disgusting', -0.896, 'car_wreck', 'get_hurt', 'bad_hair_day', 'ridiculous', 'dismay']
senticnet['territorial_division'] = [0.858, -0.891, 0, 0.719, '#joyful', '#surprising', 0.823, 'mandatory', 'administrative_district', 'administrative_division', 'district', 'borderland']
senticnet['territorial_dominion'] = [0.737, -0.555, 0, 0.884, '#joyful', '#admirable', 0.725, 'mandatory', 'administrative_district', 'administrative_division', 'territorial_division', 'borderland']
senticnet['territory'] = [0, 0.076, 0, 0, '#interesting', '#interesting', 0.025, 'region', 'land', 'land_mass', 'political_unit', 'landmass']
senticnet['terror'] = [0, 0, -1, 0, '#scared', '#scared', -0.333, 'scare', 'humiliation', 'fear', 'upset', 'shame']
senticnet['terrorism'] = [-0.884, 0, -0.986, -0.72, '#sad', '#scared', -0.863, 'kill_person', 'cut_oneself', 'murder_another_person', 'kill', 'kill_man']
senticnet['terrorist'] = [-0.912, 0, -0.723, -0.904, '#sad', '#disgusting', -0.846, 'soldier', 'medic', 'enemy', 'warrior', 'victim']
senticnet['terrorist_action'] = [-0.971, 0, 0.775, -0.95, '#sad', '#disgusting', -0.899, 'die', 'cut_throat', 'death', 'kill', 'dead_person']
senticnet['terrorist_attack'] = [-0.972, 0, 0.7, -0.964, '#sad', '#disgusting', -0.879, 'issue', 'difficult', 'complicated', 'big_issue', 'problem']
senticnet['terrorist_cell'] = [0.942, -0.797, 0, 0.561, '#joyful', '#surprising', 0.767, 'sleeper_cell', 'cadre', 'radical_cell', 'political_unit', 'political_entity']
senticnet['terrorist_corporation'] = [-0.947, 0, 0.622, -0.912, '#sad', '#disgusting', -0.827, 'bad_team', 'terrorist_group', 'bad_company', 'terrorism', 'bad_guy']
senticnet['terrorist_group'] = [-0.947, 0, 0.622, -0.912, '#sad', '#disgusting', -0.827, 'bad_team', 'bad_company', 'terrorist_corporation', 'terrorism', 'bad_guy']
senticnet['terrorist_home'] = [-0.912, 0, 0.453, -0.907, '#sad', '#disgusting', -0.757, 'war', 'bomb', 'fight_war', 'kill_person', 'weapon']
senticnet['terrorist_organization'] = [-0.947, 0, 0.622, -0.912, '#sad', '#disgusting', -0.827, 'bad_organization', 'terrorist_group', 'bad_company', 'terrorism', 'terrorist_corporation']
senticnet['terrorize'] = [-0.789, 0, -0.775, -0.953, '#sad', '#disgusting', -0.839, 'hurt_others', 'destroy_live', 'terrorism', 'death_destruction', 'murder']
senticnet['terseness'] = [-0.666, 0, 0.812, -0.881, '#angry', '#disgusting', -0.786, 'laconism', 'laconicism', 'conciseness', 'concision', 'pithiness']
senticnet['test'] = [0.928, -0.879, 0, 0.679, '#joyful', '#surprising', 0.829, 'field_trial', 'field_test', 'alpha_test', 'beta_test', 'road_test']
senticnet['test_hypothesis'] = [0.763, 0, 0, 0.719, '#joyful', '#admirable', 0.494, 'hypothesis', 'big_bang', 'theory', 'prove_theory', 'experiment']
senticnet['test_knowledge'] = [-0.092, -0.005, -0.059, -0.068, '#sad', '#disgusting', -0.071, 'show_know', 'complete_course', 'get_grade', 'get_qualification', 'receive_grade']
senticnet['test_mettle'] = [0.885, 0.946, 0, 0, '#joyful', '#interesting', 0.61, 'like_compete', 'competition', 'victory', 'winner_loser', 'win_money']
senticnet['test_strength'] = [0.032, 0, 0, 0.052, '#joyful', '#admirable', 0.028, 'prove_physical_endurance', 'maintain_muscle_strength', 'release_energy', 'physical_activity', 'get_fit']
senticnet['test_tube'] = [0.032, 0, 0, 0.052, '#joyful', '#admirable', 0.028, 'bunsen', 'chemistry_equipment', 'test', 'chemistry', 'tube']
senticnet['testicle'] = [0.087, -0.037, 0, 0.063, '#joyful', '#admirable', 0.062, 'puppet', 'bouncy', 'curly', 'throw_object', 'glove_leather']
senticnet['testify'] = [-0.217, 0.16, -0.194, 0.057, '#sad', '#scared', -0.065, 'murder', 'make_judgment', 'call_police', 'arrest_criminal', 'tell_truth']
senticnet['testimony'] = [0, 0.722, 0, 0.74, '#interesting', '#admirable', 0.487, 'trial', 'justice', 'negotiator', 'jury', 'judgment']
senticnet['testiness'] = [-0.892, 0, 0.943, -0.561, '#sad', '#angry', -0.799, 'ill_humor', 'distemper', 'pet', 'crossness', 'touchiness']
senticnet['testy'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'bad_tempered', 'nervous', 'neurasthenic', 'irritable', 'cranky']
senticnet['tetrose'] = [-0.528, 0, 0.681, -0.768, '#angry', '#disgusting', -0.659, 'triose', 'simple_sugar', 'pentose', 'hexose', 'aldose']
senticnet['text_book'] = [0.73, 0.763, 0, 0, '#joyful', '#interesting', 0.498, 'note_book', 'classroom_chair', 'learn_tool', 'atheist', 'lecturer']
senticnet['textbook'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'science_book', 'note_book', 'lecture_hall', 'school_book', 'book_magazine']
senticnet['textual_criticism'] = [0.587, -0.948, 0, 0.659, '#surprising', '#admirable', 0.731, 'critique', 'review', 'explication_de_texte', 'literary_criticism', 'new_criticism']
senticnet['texture'] = [0.027, 0.089, 0, 0.156, '#interesting', '#admirable', 0.091, 'softness', 'soft_fabric', 'cloth_material', 'natural_material', 'fabric_type']
senticnet['thank'] = [0.865, 0, 0, 0.958, '#joyful', '#admirable', 0.608, 'forgive', 'comfort_friend', 'propose_woman', 'give_assistance', 'agree']
senticnet['thank_parent'] = [-0.143, 0, -0.052, 0, '#sad', '#scared', -0.065, 'laugh_clown', 'throw_fit', 'watch_d', 'sun_oneself', 'honor_parent']
senticnet['thankful'] = [0.898, 0, 0, 0.808, '#joyful', '#admirable', 0.569, 'adorably', 'fondly', 'endearingly', 'lovingly', 'loving']
senticnet['thankfulness'] = [0.488, 0.661, -0.256, 0.244, '#joyful', '#interesting', 0.379, 'appreciativeness', 'gratefulness', 'unafraid', 'intrepidly', 'audacious']
senticnet['thanksgiving'] = [0.934, 0, 0, 0.847, '#joyful', '#admirable', 0.594, 'celebration', 'birth', 'mother_womb', 'new_baby', 'holiday']
senticnet['thanksgiving_dinner'] = [0.937, 0, 0, 0.828, '#joyful', '#admirable', 0.588, 'bakery', 'produce_section', 'fruit_bowl', 'dinner_meal', 'fast_food']
senticnet['thaumaturge'] = [-0.725, 0, 0.901, -0.559, '#sad', '#angry', -0.728, 'exorcist', 'enchanter', 'magus', 'sorceress', 'witch_doctor']
senticnet['thaumaturgist'] = [-0.896, 0, 0.653, -0.994, '#sad', '#disgusting', -0.848, 'exorcist', 'enchanter', 'magus', 'sorceress', 'witch_doctor']
senticnet['thaumaturgy'] = [0.7, -0.628, 0, 0.58, '#joyful', '#surprising', 0.636, 'white_magic', 'mojo', 'juju', 'conjuration', 'supernaturalism']
senticnet['thaw'] = [0, 0.104, -0.093, 0.146, '#interesting', '#admirable', 0.052, 'fermentation', 'slush', 'water_inside', 'give_water', 'obtain_water']
senticnet['theater'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'cinema', 'watch_movie', 'show', 'cctv', 'movie']
senticnet['theater_box'] = [0, 0.117, -0.077, 0.094, '#interesting', '#admirable', 0.045, 'theater_seat', 'sticky_floor', 'balcony_seat', 'row_seat', 'projector']
senticnet['theater_critic'] = [0.811, -0.63, 0, 0.959, '#joyful', '#admirable', 0.8, 'drama_critic', 'critic', 'professional', 'art_critic', 'literary_critic']
senticnet['theater_hall'] = [0.136, -0.056, -0.046, -0.03, '#joyful', '#surprising', 0.039, 'amphitheater', 'rehearse_room', 'theater_box', 'sound_control_room', 'soundstage']
senticnet['theater_of_absurd'] = [0.734, -0.604, 0, 0.612, '#joyful', '#admirable', 0.65, 'drama', 'playlet', 'miracle_play', 'morality_play', 'mystery_play']
senticnet['theater_seat'] = [0, -0.035, -0.073, -0.05, '#scared', '#disgusting', -0.029, 'theater_box', 'movie_theater_seat', 'sticky_floor', 'movie_screen', 'row_seat']
senticnet['theater_ticket'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'movie_ticket', 'ticket', 'go_to_theater', 'theater_seat', 'sit_at_theater']
senticnet['theater_wing'] = [0, 0.117, -0.077, 0.094, '#interesting', '#admirable', 0.045, 'theater_box', 'balcony', 'movie_theater_seat', 'stage_border', 'watch_performance']
senticnet['theatrical_role'] = [-0.829, 0, 0.958, -0.557, '#sad', '#angry', -0.781, 'character', 'role', 'baddie', 'part', 'persona']
senticnet['theatricality'] = [-0.562, 0, 0.505, -0.953, '#sad', '#disgusting', -0.673, 'unnaturalness', 'pretence', 'pretension', 'staginess', 'artificiality']
senticnet['theft'] = [0, 0, 0.941, -0.809, '#angry', '#disgusting', -0.583, 'steal_money', 'burglary', 'stick_up', 'felony', 'rob']
senticnet['theme'] = [0, 0.838, 0, 0.848, '#interesting', '#admirable', 0.562, 'conclusion', 'play', 'plan', 'scheme', 'excuse']
senticnet['theme_park'] = [0.709, 0, 0, 0.989, '#joyful', '#admirable', 0.566, 'combo_pass', 'short_cut', 'save_time', 'multiple_entry', 'ticket']
senticnet['theologize'] = [-0.991, 0, 0.827, -0.541, '#sad', '#angry', -0.786, 'treat', 'cover', 'handle', 'plow', 'deal']
senticnet['theology'] = [0.664, -0.577, 0, 0.981, '#joyful', '#admirable', 0.741, 'theodicy', 'homiletics', 'discipline', 'study', 'subject']
senticnet['theoretical'] = [0.03, -0.05, 0, 0.059, '#surprising', '#admirable', 0.046, 'unending', 'irrelevant', 'past_present', 'time_amount', 'constant']
senticnet['theorize'] = [0.754, -0.514, 0, 0.604, '#joyful', '#admirable', 0.624, 'reconstruct', 'retrace', 'explicate', 'expect', 'formulate']
senticnet['theory'] = [0, 0.2, -0.064, 0.186, '#interesting', '#admirable', 0.107, 'supposition', 'hypothesis', 'hypothetical', 'experiment', 'scientific_statement']
senticnet['therapeutic'] = [-0.601, 0, 0.544, -0.628, '#sad', '#disgusting', -0.591, 'remedy', 'cure', 'antidote', 'curative', 'atropine']
senticnet['therapeutic_rehabilitation'] = [0.641, -0.784, 0, 0.721, '#surprising', '#admirable', 0.715, 'correctional_rehabilitation', 'physical_rehabilitation', 'physical_restoration', 'rehabilitation', 'vocational_rehabilitation']
senticnet['therapist'] = [0, 0.726, 0, 0.922, '#interesting', '#admirable', 0.549, 'nurse', 'emergency_ward', 'doctor', 'doctor_examination_room', 'clinic']
senticnet['therapy'] = [0.053, -0.308, 0, 0, '#joyful', '#surprising', 0.12, 'electrocution', 'spread_happiness', 'pleasure', 'make_someone_happy', 'enjoyment']
senticnet['thermal'] = [0.03, 0.068, -0.061, 0.062, '#interesting', '#admirable', 0.033, 'pacific_northwest', 'american_forest', 'treetop', 'bath', 'hot_air']
senticnet['thermic_fever'] = [-0.721, 0, 0.762, -0.795, '#angry', '#disgusting', -0.759, 'heat_exhaustion', 'heat_prostration', 'prostration', 'sunstroke', 'heat_hyperpyrexia']
senticnet['thermometer'] = [0, 0.972, 0, 0.858, '#interesting', '#admirable', 0.61, 'fever', 'take_temperature', 'high_temperature', 'hot_weather', 'temperature_measurement']
senticnet['thermonuclear_war'] = [-0.141, -0.087, 0.031, -0.224, '#sad', '#disgusting', -0.103, 'war', 'attack_enemy', 'heart_beat_fast', 'bomb', 'missile']
senticnet['thesaurus'] = [-0.056, 0.084, 0, 0.062, '#interesting', '#admirable', 0.03, 'vocabulary', 'translation', 'book_library', 'book_poetry', 'book_genre']
senticnet['thespian'] = [-0.022, -0.016, -0.106, 0, '#sad', '#scared', -0.037, 'actor', 'balcony_seat', 'performance', 'stage_entrance', 'sticky_floor']
senticnet['thick'] = [0.08, 0, 0, 0.2, '#joyful', '#admirable', 0.093, 'thing', 'large', 'wide', 'big_size', 'big']
senticnet['thick_hair'] = [0.18, 0, 0.074, 0.115, '#joyful', '#admirable', 0.074, 'rug', 'floor', 'carpet', 'floor_cover', 'walk_closet']
senticnet['thick_jacket'] = [0.053, -0.013, -0.052, 0.121, '#joyful', '#admirable', 0.045, 'coat', 'keep_warm', 'winter_clothes', 'sweater', 'winter_glove']
senticnet['thick_liquid'] = [0, 0, 0, 0.163, '#admirable', '#admirable', 0.054, 'two-dimensional', 'spreadable', 'wall_cover', 'latex', 'black_stuff']
senticnet['thick_substance'] = [0, 0, 0, -0.964, '#disgusting', '#disgusting', -0.321, 'phlegm', 'viscous_substance', 'mucous_substance', 'disgusting', 'disgust']
senticnet['thief'] = [-0.973, 0, 0.676, -0.963, '#sad', '#disgusting', -0.871, 'violent', 'beat', 'thrash', 'merciless', 'beat_violently']
senticnet['thievery'] = [-0.106, 0, -0.053, -0.24, '#sad', '#disgusting', -0.133, 'thieving', 'larceny', 'theft', 'fraudulent_intent', 'stealing']
senticnet['thieving'] = [-0.518, 0, 0.717, -0.758, '#angry', '#disgusting', -0.664, 'raid', 'embezzlement', 'plunderage', 'larceny', 'theft']
senticnet['thin'] = [0, 0, 0.752, -0.914, '#angry', '#disgusting', -0.555, 'dilute', 'reduce', 'melt_off', 'cut', 'lose_weight']
senticnet['thin_herd'] = [-0.22, -0.153, 0.021, -0.21, '#sad', '#disgusting', -0.099, 'get_hurt', 'find_farm', 'die_painfully', 'corner_prey', 'arrest_police']
senticnet['thin_metal'] = [0.057, 0, 0.012, 0.08, '#joyful', '#admirable', 0.042, 'rust', 'foil', 'tin', 'aluminium', 'magnet']
senticnet['thin_wood'] = [0.026, 0, 0, 0.084, '#joyful', '#admirable', 0.037, 'write_material', 'book_paper', 'book', 'paper', 'book_content']
senticnet['think'] = [0.918, 0.855, 0, 0, '#joyful', '#interesting', 0.591, 'brainstorm', 'put_two_together', 'recollection', 'make_right_decision', 'brain_function']
senticnet['think_about'] = [0.707, -0.972, 0, 0.521, '#joyful', '#surprising', 0.733, 'consider', 'mind', 'look_at', 'take', 'think']
senticnet['think_about_someone'] = [0.87, 0.822, 0, 0.717, '#joyful', '#interesting', 0.803, 'buy_diamond_ring', 'determine_need', 'find_out_want', 'search_item', 'buy_ring']
senticnet['think_again'] = [-0.106, 0, -0.053, -0.24, '#sad', '#disgusting', -0.133, 'prepare_army', 'make_enemy', 'join_military', 'buy_gun', 'buy_weapon']
senticnet['think_ahead'] = [0.994, 0.9, 0, 0, '#joyful', '#interesting', 0.631, 'move_pawn', 'prioritize', 'ponder', 'think_hard', 'think_creatively']
senticnet['think_carefully'] = [-0.073, 0.147, 0, 0.074, '#interesting', '#admirable', 0.049, 'system_abstract_think', 'look_detail', 'contemplate', 'cogitate', 'logic']
senticnet['think_cat'] = [-0.035, 0, -0.055, 0, '#sad', '#scared', -0.03, 'cat', 'tabby_cat', 'written_word', 'kitty', 'baby_dog']
senticnet['think_clearly'] = [0.18, 0.087, -0.07, 0.084, '#joyful', '#interesting', 0.094, 'much_energy', 'improve_self-image', 'keep_body_healthy', 'look_attractive', 'feel_better_oneself']
senticnet['think_creatively'] = [0.701, 0, 0, 0.866, '#joyful', '#admirable', 0.522, 'brainstorm', 'use_word', 'reach_conclusion', 'prioritize', 'think']
senticnet['think_critically'] = [0.76, 0.79, 0, 0, '#joyful', '#interesting', 0.517, 'think_issue', 'correct_mistake', 'lose_key', 'age_gracefully', 'master_new_skill']
senticnet['think_dog'] = [-0.204, -0.008, 0, -0.199, '#sad', '#disgusting', -0.132, 'act_bored', 'check_time', 'grow_impatient', 'become_impatient', 'finish_test']
senticnet['think_first'] = [0.738, 0.892, 0, 0, '#joyful', '#interesting', 0.543, 'speak_up', 'use_language', 'choose_topic', 'know_talk', 'think_say']
senticnet['think_food'] = [-0.128, 0, -0.064, 0, '#sad', '#scared', -0.064, 'trust_friend', 'fight_other', 'sleep_long_time', 'die_only_once', 'wear_suit']
senticnet['think_funny'] = [0.833, 0, 0, 0.807, '#joyful', '#admirable', 0.547, 'experience_joy', 'act_silly', 'tease', 'laugh_loudly', 'laugh_out_loud']
senticnet['think_future'] = [0, 0.955, 0, 0, '#interesting', '#interesting', 0.318, 'see_star_night', 'wave_flag', 'gather_berry', 'hang_picture_on_wall', 'wind_watch']
senticnet['think_hard'] = [0.927, 0.714, 0, 0, '#joyful', '#interesting', 0.547, 'use_brain', 'focus_attention', 'ponder', 'figure_out', 'reach_conclusion']
senticnet['think_idea'] = [-0.069, 0.224, 0, 0.133, '#interesting', '#admirable', 0.096, 'check_spelling', 'idea', 'logic', 'learn_spell', 'use_word']
senticnet['think_issue'] = [-0.119, 0, -0.064, -0.041, '#sad', '#scared', -0.075, 'think_critically', 'lose_key', 'master_new_skill', 'wind_watch', 'wrong_another_person']
senticnet['think_logically'] = [0, 0, 0, 0.846, '#admirable', '#admirable', 0.282, 'ask_question', 'investigate_fact', 'research_subject', 'become_enlighten', 'form_opinion']
senticnet['think_need'] = [0, 0.784, 0, 0.703, '#interesting', '#admirable', 0.496, 'bind_paper_together', 'paper_plane', 'keep_paper_together', 'pen_and_paper', 'fasten_paper_together']
senticnet['think_of'] = [0.541, -0.868, 0, 0.85, '#surprising', '#admirable', 0.753, 'qualify', 'bear_in_mind', 'mind', 'keep_note', 'characterize']
senticnet['think_outside_box'] = [0.738, 0.763, 0, 0, '#joyful', '#interesting', 0.5, 'think_creatively', 'put_two_together', 'brainstorm', 'reach_conclusion', 'think']
senticnet['think_past'] = [-0.809, 0, 0.703, 0, '#sad', '#angry', -0.504, 'become_frustrated', 'introspection', 'keep_work', 'reflect', 'keep_word']
senticnet['think_process'] = [-0.082, 0.273, -0.071, 0.192, '#interesting', '#admirable', 0.104, 'brain_function', 'thoughtfulness', 'put_two_together', 'think_through', 'hang_up']
senticnet['think_rationally'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'learn_much', 'report_news', 'educate_oneself', 'learn', 'analysis']
senticnet['think_say'] = [0.77, 0.998, 0, 0, '#joyful', '#interesting', 0.589, 'speak_up', 'use_language', 'think_first', 'know_talk', 'choose_topic']
senticnet['think_sex'] = [0, 0.875, 0, 0.963, '#interesting', '#admirable', 0.613, 'change_mind', 'alter_state_consciousness', 'invigorate', 'hallucinate', 'loss_of_consciousness']
senticnet['think_sick'] = [0, 0, 0.962, -0.754, '#angry', '#disgusting', -0.572, 'cure_illness', 'learn_disease', 'concern_health', 'find_out_healthy', 'ill']
senticnet['think_story'] = [0, -0.755, 0, 0, '#surprising', '#surprising', 0.252, 'writer_cramp', 'scratch_head', 'think_past', 'hand_cramp', 'stare_off_space']
senticnet['think_through'] = [0.936, 0.757, 0, 0, '#joyful', '#interesting', 0.564, 'forget_else', 'recognize_pattern', 'gather_fact', 'study_fact', 'solve_mystery']
senticnet['think_too_much'] = [-0.943, 0, 0.866, -0.929, '#sad', '#disgusting', -0.913, 'mull_over', 'anxiety', 'hate_somebody', 'bad_feeling', 'bad_memory']
senticnet['think_write'] = [0.824, 0.887, 0, 0, '#joyful', '#interesting', 0.57, 'find_paper', 'learn_write', 'proofread', 'pick_up_pen', 'learn_spell']
senticnet['thinkable'] = [0.878, -0.678, 0, 0.631, '#joyful', '#surprising', 0.729, 'ponderable', 'presumable', 'supposable', 'surmisable', 'conceivable']
senticnet['thinker'] = [0, 0.155, 0, 0, '#interesting', '#interesting', 0.052, 'idea', 'brain_activity', 'new_think', 'analysis', 'make_right_decision']
senticnet['thinking'] = [0.676, -0.652, 0, 0.893, '#joyful', '#admirable', 0.74, 'reasoning', 'consideration', 'logical_thinking', 'abstract_thought', 'excogitation']
senticnet['thinking_cap'] = [0.964, -0.592, 0, 0.982, '#joyful', '#admirable', 0.846, 'case', 'frame_of_mind', 'temporary_state', 'psychological_state', 'psychological_condition']
senticnet['thinness'] = [0, 0, 0.111, 0, '#angry', '#angry', -0.037, 'small', 'kilometer', 'width', 'thin', 'land_measurement']
senticnet['third_degree'] = [-0.587, 0, 0.701, -0.979, '#angry', '#disgusting', -0.756, 'inquisition', 'interview', 'catechism', 'deposition', 'interrogatory']
senticnet['third_world_country'] = [0, 0, -0.107, -0.108, '#scared', '#disgusting', -0.072, 'normal_human_body', 'morgue', 'emergency_room', 'body', 'human_body']
senticnet['thirst'] = [-0.875, 0, -0.717, -0.961, '#sad', '#disgusting', -0.851, 'avid', 'eagerly', 'eagerness', 'avidity', 'avidness']
senticnet['thirst_knowledge'] = [-0.971, 0, 0, -0.846, '#sad', '#disgusting', -0.606, 'use_thermometer', 'pay_close_attention', 'form_opinion', 'new_insight', 'change_plan']
senticnet['thirstily'] = [0.532, 0.657, -0.257, 0.268, '#joyful', '#interesting', 0.4, 'keenness', 'eagerly', 'eagerness', 'avidity', 'avidness']
senticnet['thirstiness'] = [-0.738, 0, 0.931, -0.821, '#angry', '#disgusting', -0.83, 'aridness', 'dryness', 'xerostomia', 'dry_mouth', 'sereness']
senticnet['thirty'] = [0, -0.003, 0.063, -0.037, '#angry', '#disgusting', -0.032, 'day_month', 'date', 'calendar', 'day', 'time_measurement']
senticnet['thong'] = [0.725, 0.947, 0, 0, '#joyful', '#interesting', 0.557, 'blouse', 'sock', 'nightgown', 'tie', 'vest']
senticnet['thorn'] = [-0.668, 0, 0.859, -0.827, '#angry', '#disgusting', -0.785, 'pain_in_ass', 'pain', 'pain_in_neck', 'annoyance', 'bother']
senticnet['thorny'] = [0, 0, -0.827, -0.782, '#scared', '#disgusting', -0.536, 'barbellate', 'briery', 'bristled', 'briary', 'barbed']
senticnet['thoroughfare'] = [0, 0, 0.033, -0.045, '#angry', '#disgusting', -0.026, 'boulevard', 'lane', 'curb', 'intersection', 'avenue']
senticnet['thought'] = [0.74, 0.956, 0, 0, '#joyful', '#interesting', 0.565, 'brain_function', 'brainstorm', 'think', 'thoughtfulness', 'new_think']
senticnet['thought_process'] = [0.513, -0.811, 0, 0.917, '#surprising', '#admirable', 0.747, 'reasoning', 'consideration', 'logical_thinking', 'abstract_thought', 'excogitation']
senticnet['thoughtful'] = [0.03, 0.358, -0.252, 0.299, '#interesting', '#admirable', 0.145, 'attitude', 'certainty', 'strong_feeling', 'prefer', 'tend']
senticnet['thoughtfulness'] = [-0.085, 0.298, -0.124, 0.189, '#interesting', '#admirable', 0.093, 'think_process', 'brain_function', 'consideration', 'brainstorm', 'hang_up']
senticnet['thoughtless'] = [0.561, -0.912, 0, 0.563, '#surprising', '#admirable', 0.679, 'unthinking', 'inconsiderate', 'unreflective', 'unthoughtful', 'unconsidered']
senticnet['thousand_dollar'] = [0.056, 0.179, 0, 0.107, '#interesting', '#admirable', 0.114, 'walmart', 'warehouse', 'drugstore', 'sex_shop', 'storage_facility']
senticnet['thrall'] = [0.723, -0.624, 0, 0.924, '#joyful', '#admirable', 0.757, 'bonded_labor', 'servitude', 'serfdom', 'serfhood', 'vassalage']
senticnet['thrash'] = [-0.103, 0, -0.065, 0, '#sad', '#scared', -0.056, 'violent', 'beat', 'beat_violently', 'no_mercy', 'thief']
senticnet['thread'] = [-0.036, -0.044, 0.079, -0.092, '#angry', '#disgusting', -0.054, 'string', 'bandage', 'suture', 'filament', 'needle_filament']
senticnet['thread_needle'] = [-0.026, -0.019, 0.028, -0.125, '#angry', '#disgusting', -0.053, 'use_needle', 'needle_thread', 'sew_term', 'sew', 'mend']
senticnet['threadbare'] = [0, 0, -0.883, -0.795, '#scared', '#disgusting', -0.559, 'banal', 'shopworn', 'commonplace', 'old-hat', 'hackneyed']
senticnet['threat'] = [-0.188, 0, -0.173, -0.109, '#sad', '#scared', -0.157, 'violent', 'hazardous', 'unsafe', 'wrong', 'demolish']
senticnet['threaten'] = [-0.931, 0, -0.917, -0.84, '#sad', '#scared', -0.896, 'destroy_live', 'take_life', 'death_destruction', 'get_rid_of_enemy', 'defend_oneself']
senticnet['three_dimensional'] = [0, 0.967, 0, 0.886, '#interesting', '#admirable', 0.618, 'geometrical_shape', 'geometric_shape', 'geometry_shape', 'no_edge', 'ball_shape']
senticnet['three_dimensions'] = [0, 0.885, 0, 0.758, '#interesting', '#admirable', 0.548, 'no_edge', 'circle_shape', 'round_orb', 'orb', 'ball_shape']
senticnet['three_legs'] = [0.827, 0.857, 0, 0, '#joyful', '#interesting', 0.561, 'hold_canvas', 'foot', 'two_feet', 'leg', 'type_of_shoes']
senticnet['three_syllables'] = [0.776, 0.736, 0, 0, '#joyful', '#interesting', 0.504, 'unbearable', 'separate', 'halve', 'many_floors', 'tear_apart']
senticnet['threshold'] = [0, 0.098, 0, 0.089, '#interesting', '#admirable', 0.062, 'wood_panel', 'wooden_structure', 'hinge', 'entrance_room', 'corridor']
senticnet['threshold_level'] = [-0.934, 0, 0.698, -0.857, '#sad', '#disgusting', -0.83, 'candlepower', 'light_intensity', 'acoustic_power', 'sound_pressure_level', 'intensity']
senticnet['thrift_store'] = [-0.03, 0, 0, -0.038, '#sad', '#disgusting', -0.023, 'store', 'laundromat', 'department_store', 'walmart', 'government_office']
senticnet['thriftless'] = [-0.638, 0, 0.867, -0.57, '#sad', '#angry', -0.692, 'myopic', 'short', 'shortsighted', 'unforesightful', 'improvident']
senticnet['thrifty'] = [0.722, -0.744, 0, 0.554, '#joyful', '#surprising', 0.673, 'saving', 'economical', 'scotch', 'frugal', 'sparing']
senticnet['thrill'] = [0.89, 0.819, 0, 0, '#joyful', '#interesting', 0.57, 'closeness', 'cheer_up', 'console', 'euphoria', 'cheer']
senticnet['thrill_ride'] = [0.056, -0.019, 0.036, 0.073, '#joyful', '#admirable', 0.037, 'amusement_park', 'have_fun', 'drag_race', 'enjoyment', 'roller_coaster']
senticnet['thrilling'] = [0, 0.767, 0, 1.0, '#interesting', '#admirable', 0.589, 'electrifying', 'scandalmongering', 'sensationalistic', 'sensational', 'sensationally']
senticnet['throat_injury'] = [0, 0, 0.933, -0.863, '#angry', '#disgusting', -0.599, 'feel_out_of_breath', 'muscle_cramp', 'breath_difficulty', 'run_too_fast', 'epileptic_seizures']
senticnet['throb'] = [0, 0.904, 0, 0.874, '#interesting', '#admirable', 0.593, 'blown', 'beat', 'hurtful', 'gash', 'ouch']
senticnet['throne'] = [0.054, 0.081, 0, 0.113, '#interesting', '#admirable', 0.083, 'king_queen', 'noble', 'king', 'duchess', 'royal']
senticnet['throng'] = [-0.11, -0.024, -0.112, -0.117, '#scared', '#disgusting', -0.105, 'crowd', 'mass', 'crush', 'mob', 'group']
senticnet['throughway'] = [0.798, -0.846, 0, 0.833, '#surprising', '#admirable', 0.826, 'autobahn', 'autostrada', 'turnpike', 'toll_road', 'highway']
senticnet['throw_away'] = [0.87, 0.994, 0, 0, '#joyful', '#interesting', 0.621, 'abandon', 'put_away', 'discard', 'give_up', 'abandonment']
senticnet['throw_away_garbage'] = [0.942, 0.852, 0, 0, '#joyful', '#interesting', 0.598, 'clean_house', 'sit_on_beach', 'remove_spot', 'absorb_moisture', 'iron_clothes']
senticnet['throw_away_trash'] = [0.993, -0.695, 0, 0.715, '#joyful', '#admirable', 0.801, 'find_restroom', 'find_toilet', 'full_bladder', 'serve_beer', 'unzip_pant']
senticnet['throw_ball'] = [0.054, 0.081, 0, 0.113, '#interesting', '#admirable', 0.083, 'play_bowling', 'play_game', 'catch_ball', 'play_baseball', 'play_basketball']
senticnet['throw_fit'] = [-0.132, 0, -0.055, 0, '#sad', '#scared', -0.062, 'watch_d', 'sun_oneself', 'laugh_clown', 'battle_illness', 'honor_parent']
senticnet['throw_football'] = [0.082, 0, 0, 0.183, '#joyful', '#admirable', 0.088, 'pass_ball', 'dance_move', 'jump_around', 'pretzel', 'swirl']
senticnet['throw_frisbee'] = [-0.108, 0, -0.045, 0, '#sad', '#scared', -0.051, 'explain_everything', 'deal_card_player', 'forward_email', 'stand_alone', 'page_person']
senticnet['throw_in'] = [-0.531, 0, 0.612, -0.796, '#angry', '#disgusting', -0.646, 'impart', 'lend', 'contribute', 'add', 'bestow']
senticnet['throw_object'] = [0.993, 0.791, 0, 0, '#joyful', '#interesting', 0.595, 'use_sport', 'spherical_shape', 'bouncy', 'circular_object', 'child_toy']
senticnet['throw_out'] = [-0.88, 0, 0.903, -0.504, '#sad', '#angry', -0.762, 'send_down', 'rusticate', 'expel', 'debar', 'kick_out']
senticnet['throw_party'] = [-0.069, 0, 0, 0, '#sad', '#sad', -0.023, 'drill_hole', 'screwdriver', 'start_business', 'take_over_world', 'find_build']
senticnet['throw_up'] = [0.836, 0.741, 0, 0, '#joyful', '#interesting', 0.526, 'slur_word', 'forgetfulness', 'hangover', 'run_out_booze', 'stagger']
senticnet['thrown_away'] = [-0.114, 0, 0, -0.051, '#sad', '#disgusting', -0.055, 'thrown_out', 'hold_garbage', 'put_bag', 'radioactive', 'crumble']
senticnet['thrown_out'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'thrown_away', 'recycle', 'made_out_of_plastic', 'further_knowledge', 'make_paper']
senticnet['thrust'] = [-0.06, -0.03, 0, -0.069, '#sad', '#disgusting', -0.033, 'parry', 'elephant_sit_chest', 'stab', 'cut_down_tree', 'cause_injury']
senticnet['thrust_ahead'] = [-0.793, 0, 0.776, -0.702, '#sad', '#angry', -0.757, 'rush', 'race', 'hotfoot', 'hasten', 'hie']
senticnet['thruway'] = [0, 0, 0.012, -0.064, '#angry', '#disgusting', -0.025, 'national_interstate_highway', 'thoroughfare', 'traffic_artery', 'round_trip_ticket', 'farecard']
senticnet['thug'] = [-0.529, 0, 0.981, -0.613, '#angry', '#disgusting', -0.708, 'criminal', 'bully', 'outlaw', 'malefactor', 'felon']
senticnet['thumb_down'] = [0, 0.95, 0, 0.766, '#interesting', '#admirable', 0.572, 'boo', 'complaint', 'bad', 'dislike', 'sad']
senticnet['thumb_tack'] = [0, -0.064, 0.094, -0.11, '#angry', '#disgusting', -0.047, 'push_pin', 'tack', 'glue_stick', 'letter_opener', 'ball_point_pen']
senticnet['thumbstall'] = [-0.587, 0, 0.992, -0.874, '#angry', '#disgusting', -0.818, 'mask', 'blind', 'watch_crystal', 'cladding', 'protective_cover']
senticnet['thump'] = [0, -0.004, -0.057, -0.075, '#scared', '#disgusting', -0.043, 'stop_think', 'cry', 'cry_hard', 'fall_off_chair', 'spill_coffee']
senticnet['thunder'] = [0.045, 0, 0, 0.088, '#joyful', '#admirable', 0.044, 'loud_sound', 'boom', 'rain_storm', 'sound_wave', 'rain_wind']
senticnet['thunder_storm'] = [0, 0.996, 0, 0.984, '#interesting', '#admirable', 0.66, 'atmosphere', 'bird_fly', 'air_breathe', 'lung', 'breathe']
senticnet['thundershower'] = [-0.872, 0, 0.91, -0.78, '#sad', '#angry', -0.854, 'storm', 'rainstorm', 'rain', 'line_storm', 'equinoctial_storm']
senticnet['thunderstorm'] = [0.841, 0, 0, 0.968, '#joyful', '#admirable', 0.603, 'blizzard', 'snow_storm', 'storm', 'weather', 'rainy']
senticnet['thunderstruck'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'surprise', 'baffle', 'stupefy', 'dumbfounded', 'stupefaction']
senticnet['thurifer'] = [-0.677, 0, 0.994, -0.503, '#sad', '#angry', -0.725, 'altar_boy', 'reverend', 'acolyte', 'clergyman', 'man_of_cloth']
senticnet['thwart'] = [0, 0.161, -0.134, 0.229, '#interesting', '#admirable', 0.085, 'prevent', 'halt', 'continue', 'accept', 'fill']
senticnet['thwarted'] = [0.942, 0.817, 0, 0, '#joyful', '#interesting', 0.586, 'disappointed', 'defeatism', 'frustrated', 'foiled', 'discomfited']
senticnet['thwarter'] = [-0.839, 0, 0.682, -0.873, '#sad', '#disgusting', -0.798, 'obstructor', 'obstructer', 'obstructionist', 'resister', 'stonewaller']
senticnet['thyreophoran'] = [-0.927, 0, 0.64, -0.529, '#sad', '#angry', -0.699, 'perching_bird', 'percher', 'animal_order', 'marginocephalian', 'euronithopod']
senticnet['thyrotoxicosis'] = [-0.533, 0, 0.667, -0.556, '#angry', '#disgusting', -0.585, 'exophthalmic_goiter', 'glandular_disease', 'gland_disease', 'glandular_disorder', 'adenosis']
senticnet['thysanuran_insect'] = [-0.703, 0, 0.994, -0.99, '#angry', '#disgusting', -0.896, 'insect', 'bristletail', 'silverfish', 'jumping_bristletail', 'machilid']
senticnet['thysanuron'] = [-0.733, 0, 0.774, -0.946, '#angry', '#disgusting', -0.818, 'insect', 'bristletail', 'silverfish', 'jumping_bristletail', 'machilid']
senticnet['tiara'] = [-0.626, 0, 0.961, -0.544, '#sad', '#angry', -0.71, 'crown', 'diadem', 'jeweled_headdress', 'headdress', 'headgear']
senticnet['tic'] = [0.732, 0.706, 0, 0, '#joyful', '#interesting', 0.479, 'worm_intestine', 'fur_keep_warm', 'bald', 'bad_breath', 'claw']
senticnet['tic_douloureux'] = [-0.547, 0, 0.543, -0.63, '#sad', '#disgusting', -0.573, 'hurting', 'pain', 'trigeminal_neuralgia', 'neuralgia', 'sciatica']
senticnet['ticket_booth'] = [0, 0, -0.063, -0.092, '#scared', '#disgusting', -0.052, 'ticket_office', 'ticket_window', 'ticket_box', 'box_office', 'passenger_terminal']
senticnet['ticket_box'] = [0, -0.008, -0.077, -0.073, '#scared', '#disgusting', -0.047, 'ticket_office', 'box_office', 'sticky_floor', 'row_seat', 'ticket_booth']
senticnet['ticket_counter'] = [0.734, 0, 0, 0.834, '#joyful', '#admirable', 0.523, 'newspaper_stand', 'taxiway', 'runway', 'flight_terminal', 'aircraft_roadway']
senticnet['ticket_office'] = [0, 0, -0.072, -0.095, '#scared', '#disgusting', -0.056, 'ticket_box', 'ticket_booth', 'box_office', 'ticket_window', 'theater_ticket']
senticnet['ticket_taker'] = [0.764, 0, 0, 0.855, '#joyful', '#admirable', 0.54, 'sound_control_room', 'beat_box', 'microphone_boom', 'speaker', 'contralto']
senticnet['ticket_turnstile'] = [0.203, 0.111, 0, 0.089, '#joyful', '#interesting', 0.134, 'ticket_taker', 'other_person', 'go_friend', 'movie_star', 'opus_ticket']
senticnet['ticket_window'] = [0, 0, -0.064, -0.068, '#scared', '#disgusting', -0.044, 'ticket_booth', 'ticket_box', 'box_office', 'ticket_office', 'movie_ticket']
senticnet['tickle'] = [0, -0.099, -0.056, 0.064, '#surprising', '#admirable', 0.036, 'express_how_funny', 'hear_funny_joke', 'laugh_joke', 'howl_laughter', 'see_beautiful_girl']
senticnet['tickle_pink'] = [0.645, 0.637, -0.239, 0.299, '#joyful', '#interesting', 0.447, 'gladdened', 'stimulating', 'inebriate', 'exalt', 'beatify']
senticnet['tidal_pool'] = [0, 0, -0.065, -0.036, '#scared', '#disgusting', -0.034, 'coral_reef', 'saltwater', 'fish_market', 'sushi_restaurant', 'reef']
senticnet['tidal_wave'] = [0.02, 0.076, 0, 0, '#joyful', '#interesting', 0.032, 'land_earth', 'brine', 'puddle', 'hot_water_heater', 'spurt']
senticnet['tidbit'] = [0.92, 0.7, 0, 0, '#joyful', '#interesting', 0.54, 'sting', 'nip', 'bite', 'flea', 'least']
senticnet['tidiness'] = [-0.097, -0.049, -0.048, -0.158, '#sad', '#disgusting', -0.085, 'spider', 'back_pain', 'house_look_better', 'asthma', 'barf']
senticnet['tidy'] = [0.862, 0, 0, 0.99, '#joyful', '#admirable', 0.617, 'neat', 'tidy_up', 'cleanness', 'personal_cleanliness', 'cleanliness']
senticnet['tidy_room'] = [0.72, 0.799, 0, 0.753, '#interesting', '#admirable', 0.757, 'check_oneself_mirror', 'check_breathe', 'feel_emotion', 'stop_bleed', 'think_future']
senticnet['tidy_up'] = [0.981, 0.732, 0, 0.846, '#joyful', '#admirable', 0.853, 'neat', 'tidy', 'expect_guest', 'use_vacuum_cleaner', 'vacuum_floor']
senticnet['tie_bow'] = [0, 0.087, -0.07, 0.1, '#interesting', '#admirable', 0.039, 'cover_body', 'knit_sweater', 'weave', 'make_drape', 'organize_clothes']
senticnet['tie_down'] = [0.624, -0.65, 0, 0.521, '#joyful', '#surprising', 0.598, 'hold', 'faggot', 'fagot', 'chain_up', 'faggot_up']
senticnet['tie_game'] = [-0.035, 0, 0, -0.039, '#sad', '#disgusting', -0.025, 'use_crayon', 'sketch', 'create_image', 'pencil_art', 'like_paint']
senticnet['tie_knot'] = [0.726, 0.808, 0, 0.861, '#interesting', '#admirable', 0.798, 'need_companionship', 'ease_pain', 'cup_hand', 'gather_berry', 'hang_picture_on_wall']
senticnet['tie_score'] = [0.797, 0, 0, 0.775, '#joyful', '#admirable', 0.524, 'competitiveness', 'even_out', 'win_money', 'keep_score', 'funny_friend']
senticnet['tie_shoelace'] = [-0.028, -0.021, 0.062, -0.105, '#angry', '#disgusting', -0.058, 'jump_up_down', 'stand_up', 'jump_rope', 'hike', 'skate']
senticnet['tie_shoes'] = [-0.1, -0.03, 0.065, -0.082, '#sad', '#disgusting', -0.072, 'put_sneaker', 'bring_dog', 'go_park', 'move_leg', 'put_jogging_shoes']
senticnet['tie_together'] = [0, 0.123, -0.069, 0.176, '#interesting', '#admirable', 0.077, 'bring_together', 'inclusion', 'fuse', 'commence', 'merge']
senticnet['tie_up'] = [-0.206, -0.049, 0, -0.181, '#sad', '#disgusting', -0.113, 'reach_high_shelf', 'lift_foot', 'step_up', 'go_up_down', 'go_upstairs']
senticnet['tier'] = [-0.088, -0.046, 0.023, -0.076, '#sad', '#disgusting', -0.047, 'spoilage', 'make_toast', 'house_smell_good', 'get_hot', 'bread_crumb']
senticnet['tiff'] = [-0.551, 0, 0.912, -0.507, '#sad', '#angry', -0.657, 'wrangle', 'dustup', 'quarrel', 'row', 'word']
senticnet['tight'] = [-0.206, -0.049, 0, -0.181, '#sad', '#disgusting', -0.113, 'tight_shoe', 'cramped', 'narrow', 'strict', 'tight_pants']
senticnet['tight_pants'] = [-0.206, -0.049, 0, -0.181, '#sad', '#disgusting', -0.113, 'tight_shoe', 'cramped', 'narrow', 'strict', 'tight']
senticnet['tight_shoe'] = [-0.206, -0.049, 0, -0.181, '#sad', '#disgusting', -0.113, 'tight', 'cramped', 'narrow', 'strict', 'tight_pants']
senticnet['tighten'] = [0, 0.096, 0, 0.112, '#interesting', '#admirable', 0.069, 'make_bow', 'visit_zoo', 'safe_sex', 'sex', 'contraception']
senticnet['tile_floor'] = [0, 0.096, 0, 0.112, '#interesting', '#admirable', 0.069, 'renovation', 'tile', 'floor', 'tile_roof', 'tile_wall']
senticnet['tile_roof'] = [0, 0.096, 0, 0.112, '#interesting', '#admirable', 0.069, 'renovation', 'tile', 'floor', 'tile_floor', 'tile_wall']
senticnet['tile_wall'] = [0, 0.096, 0, 0.112, '#interesting', '#admirable', 0.069, 'renovation', 'tile', 'floor', 'tile_roof', 'tile_floor']
senticnet['tilled_land'] = [-0.769, 0, 0.695, -0.785, '#sad', '#disgusting', -0.75, 'cultivated_land', 'farmland', 'plowland', 'ploughland', 'fallow']
senticnet['timberland'] = [-0.739, 0, 0.59, -0.893, '#sad', '#disgusting', -0.741, 'desert', 'grassland', 'forest', 'woodland', 'biome']
senticnet['time'] = [0.86, -0.794, 0, 0.93, '#joyful', '#admirable', 0.861, 'modern_times', 'present_times', 'modern_world', 'contemporary_world', 'period']
senticnet['time_amount'] = [0.03, -0.05, 0, 0.059, '#surprising', '#admirable', 0.046, 'amount', 'time', 'past_present', 'theoretical', 'constant']
senticnet['time_consume'] = [-0.113, -0.081, 0.037, -0.261, '#sad', '#disgusting', -0.11, 'tedious', 'eye_strain', 'time_waste', 'stiff', 'backward']
senticnet['time_day'] = [-0.048, 0.088, 0.013, 0.069, '#interesting', '#admirable', 0.032, 'nightfall', 'sunrise', 'day_part', 'day_end', 'late_time']
senticnet['time_description'] = [0.043, 0.067, 0.012, 0, '#joyful', '#interesting', 0.033, 'accurate', 'time', 'time_loop', 'period', 'accuracy']
senticnet['time_designation'] = [0, 0.104, 0, 0.124, '#interesting', '#admirable', 0.076, 'era', 'constant', 'time_increment', 'good_trait', 'time_length']
senticnet['time_effort'] = [0.844, 0.715, 0, 0, '#joyful', '#interesting', 0.52, 'persistence', 'open_mind', 'study_animal', 'diligent', 'use_telescope']
senticnet['time_event'] = [0.154, 0.086, 0.03, 0.153, '#joyful', '#admirable', 0.121, 'keep_track_time', 'measure_passage_time', 'know_time', 'time_runner', 'time']
senticnet['time_frame'] = [0, 0.069, 0, 0.092, '#interesting', '#admirable', 0.054, 'calendar_event', 'time_period', 'short_time', 'event', 'time_length']
senticnet['time_increment'] = [0, 0.104, 0, 0.124, '#interesting', '#admirable', 0.076, 'era', 'constant', 'good_trait', 'time_designation', 'time_length']
senticnet['time_interval'] = [0.861, -0.788, 0, 0.911, '#joyful', '#admirable', 0.853, 'round', 'pause', 'space', 'lunitidal_interval', 'break']
senticnet['time_lag'] = [0.976, -0.719, 0, 0.863, '#joyful', '#admirable', 0.853, 'hold', 'delay', 'wait', 'moratorium', 'postponement']
senticnet['time_length'] = [0, 0.069, 0, 0.092, '#interesting', '#admirable', 0.054, 'time_frame', 'time_period', 'short_time', 'event', 'calendar_event']
senticnet['time_limit'] = [0, 0.149, 0, 0, '#interesting', '#interesting', 0.05, 'home', 'most_homes', 'fourth', 'monthly', 'modern_home']
senticnet['time_loop'] = [-0.027, 0.106, 0, 0.088, '#interesting', '#admirable', 0.056, 'time', 'time_description', 'time_reference', 'time_event', 'short_time']
senticnet['time_measure'] = [0, 0.138, 0.077, 0.186, '#interesting', '#admirable', 0.082, 'show_time', 'timekeeper', 'measure', 'keep_time', 'measure_time']
senticnet['time_measurement'] = [0, -0.003, 0.063, -0.037, '#angry', '#disgusting', -0.032, 'thirty', 'date', 'calendar', 'day', 'day_month']
senticnet['time_off'] = [0.787, 0.949, 0, 0.99, '#interesting', '#admirable', 0.909, 'holiday', 'day_off', 'vacation', 'sabbatical', 'time']
senticnet['time_out'] = [-0.102, 0.077, -0.117, 0, '#sad', '#scared', -0.047, 'rest_time', 'end', 'leave_behind', 'break_apart', 'break_glass']
senticnet['time_pass'] = [0, -0.026, 0.085, -0.094, '#angry', '#disgusting', -0.051, 'day_period', 'watch_clock', 'tie_score', 'keep_track_time', 'even_out']
senticnet['time_period'] = [0, 0.069, 0, 0.092, '#interesting', '#admirable', 0.054, 'time_frame', 'calendar_event', 'short_time', 'event', 'time_length']
senticnet['time_race'] = [-0.045, 0, 0.042, 0, '#sad', '#angry', -0.029, 'measure_passage_time', 'time_event', 'measure_time', 'time_runner', 'time']
senticnet['time_reference'] = [0.066, 0.079, 0, 0.142, '#interesting', '#admirable', 0.096, 'never_end', 'metaphor', 'duration', 'calendar_event', 'general_time']
senticnet['time_relax'] = [0.855, 0.921, 0, 0, '#joyful', '#interesting', 0.592, 'happy_time', 'make_others_happy', 'make_gift', 'good_lover', 'good_mental_health']
senticnet['time_rest'] = [0.319, 0.216, 0, 0.39, '#joyful', '#admirable', 0.308, 'good_fortune', 'taken_seriously', 'complement', 'much_need', 'spice_life']
senticnet['time_runner'] = [-0.045, 0, 0.042, 0, '#sad', '#angry', -0.029, 'measure_passage_time', 'time_event', 'measure_time', 'time_race', 'time']
senticnet['time_test'] = [-0.126, -0.013, 0, -0.154, '#sad', '#disgusting', -0.089, 'listen_teacher', 'offer_opinion', 'educate_others', 'better_grade', 'learn_fact']
senticnet['time_think'] = [-0.97, 0, -0.978, -0.847, '#sad', '#scared', -0.932, 'intellectual_stimulation', 'enjoy_beauty', 'exercise_mind', 'leisure_time', 'mentally_challenged']
senticnet['time_tracker'] = [-0.022, -0.01, 0.058, 0, '#sad', '#angry', -0.023, 'device_measure_time', 'show_time', 'timekeeper', 'timekeep', 'tell_time']
senticnet['time_up'] = [0, 0.743, 0, 0.914, '#interesting', '#admirable', 0.552, 'inevitable', 'expire', 'desirable', 'good_quality', 'life_end']
senticnet['time_waste'] = [0.888, 0.743, 0, 0, '#joyful', '#interesting', 0.544, 'eye_strain', 'change_opinion', 'learn_current_event', 'see_ad', 'eye']
senticnet['time_waster'] = [0.718, 0.832, 0, 0, '#joyful', '#interesting', 0.517, 'school', 'school_system', 'class', 'college', 'college_class']
senticnet['timekeep'] = [-0.022, -0.01, 0.058, 0, '#sad', '#angry', -0.023, 'time_tracker', 'show_time', 'device_measure_timeer', 'device_measure_time', 'tell_time']
senticnet['timekeeper'] = [-0.027, 0.106, 0, 0.088, '#interesting', '#admirable', 0.056, 'check_time', 'timekeep', 'time', 'measure_time', 'time_measure']
senticnet['timely'] = [0, 0.812, 0, 0.959, '#interesting', '#admirable', 0.59, 'contemporary', 'serenity', 'currently', 'right_now', 'joy']
senticnet['timepiece'] = [0.988, 0.772, 0, 0, '#joyful', '#interesting', 0.587, 'watch', 'stopwatch', 'find_pawnshop', 'wristwatch', 'clock']
senticnet['timid'] = [0.717, 0.722, 0, 0, '#joyful', '#interesting', 0.48, 'shyly', 'timidness', 'bashfully', 'timidly', 'timorousness']
senticnet['timidity'] = [0.971, 0.723, 0, 0, '#joyful', '#interesting', 0.565, 'bashfully', 'timorousness', 'timidness', 'shyly', 'timidly']
senticnet['timidly'] = [0.864, 0.82, 0, 0, '#joyful', '#interesting', 0.561, 'bashfully', 'timorousness', 'timidness', 'timidity', 'shyly']
senticnet['timidness'] = [0.839, 0.735, 0, 0, '#joyful', '#interesting', 0.525, 'bashfully', 'timorousness', 'timidity', 'shyly', 'timidly']
senticnet['timorous'] = [1.0, 0.918, 0, 0, '#joyful', '#interesting', 0.639, 'timorously', 'trepid', 'trepidly', 'trepidation', 'presentiment']
senticnet['timorously'] = [0.822, 0.837, 0, 0, '#joyful', '#interesting', 0.553, 'trepid', 'trepidly', 'timorous', 'trepidation', 'presentiment']
senticnet['timorousness'] = [0.906, 0.758, 0, 0, '#joyful', '#interesting', 0.555, 'bashfully', 'timidness', 'timidity', 'shyly', 'timidly']
senticnet['tin'] = [0.026, 0, 0.011, 0.095, '#joyful', '#admirable', 0.037, 'magnetic', 'hard_plastic', 'tin_aluminium', 'heavy_element', 'solid_room_temperature']
senticnet['tin_aluminium'] = [0.028, 0, 0.026, 0.067, '#joyful', '#admirable', 0.023, 'silver', 'magnetic', 'heavy_element', 'tin', 'strong_material']
senticnet['tin_can'] = [-0.952, 0, 0, -0.73, '#sad', '#disgusting', -0.561, 'hold_pencil', 'food_scrap', 'paper_product', 'wrapper', 'waste_paper']
senticnet['tin_ear'] = [-0.794, 0, 0.636, -0.756, '#sad', '#disgusting', -0.729, 'insensibility', 'insensitiveness', 'hardness', 'unfitness', 'unfeelingness']
senticnet['tin_foil'] = [0.716, -0.791, 0, 0.543, '#joyful', '#surprising', 0.683, 'chaff', 'wrap', 'aluminium_foil', 'foil', 'gold_foil']
senticnet['tinea'] = [-0.572, 0, 0.873, -0.782, '#angry', '#disgusting', -0.742, 'fungal_infection', 'mycosis', 'kerion', 'tinea_pedis', 'athlete_foot']
senticnet['tinea_pedis'] = [-0.964, 0, 0.694, -0.623, '#sad', '#angry', -0.76, 'fungal_infection', 'mycosis', 'kerion', 'ringworm', 'athlete_foot']
senticnet['tingle'] = [0, 0, 0.771, -0.807, '#angry', '#disgusting', -0.526, 'prickle', 'sting', 'smart', 'prick', 'itch']
senticnet['tingling'] = [-0.78, 0, 0.669, -0.894, '#sad', '#disgusting', -0.781, 'pain_sensation', 'painful_sensation', 'prickling', 'somatic_sensation', 'pain']
senticnet['tinnitus'] = [0.215, -0.139, 0.116, -0.124, '#joyful', '#surprising', 0.038, 'hear_loss', 'earring', 'damage_ear', 'hear_song', 'like']
senticnet['tiny'] = [-0.05, 0, -0.12, -0.168, '#scared', '#disgusting', -0.113, 'reduced', 'small', 'small_size', 'narrow', 'poor']
senticnet['tiny_amount'] = [0.956, 0.974, 0, 0, '#joyful', '#interesting', 0.643, 'sting', 'tidbit', 'nip', 'bite', 'piece']
senticnet['tiny_animal'] = [0, 0, 0.091, 0, '#angry', '#angry', -0.03, 'tiny_insect', 'small_insect', 'critter', 'furry_creature', 'fly']
senticnet['tiny_insect'] = [-0.03, 0, 0.107, -0.035, '#angry', '#disgusting', -0.057, 'small_insect', 'parasite', 'nuisance_insect', 'tiny_animal', 'annoy_bug']
senticnet['tiny_organism'] = [0, 0.065, 0.021, 0.052, '#interesting', '#admirable', 0.032, 'microscopic', 'basic_unit', 'small_unit', 'amoeba', 'body_type']
senticnet['tiny_particle'] = [0, 0.081, 0.044, 0.106, '#interesting', '#admirable', 0.048, 'particle', 'small_particle', 'small_object', 'tiny', 'small']
senticnet['tiny_person'] = [0.044, -0.033, 0.037, 0.089, '#joyful', '#admirable', 0.043, 'kid_toy', 'life_like', 'mannequin', 'build_block', 'plaything']
senticnet['tiny_speck'] = [0.888, 0, 0, 0.813, '#joyful', '#admirable', 0.567, 'small_fly', 'tiny_insect', 'small_bug', 'tiny', 'small_insect']
senticnet['tip'] = [0, 0.238, 0.014, 0.104, '#interesting', '#admirable', 0.109, 'sharpness', 'margin', 'sharp_end', 'sharp_corner', 'bottom_line']
senticnet['tip_waiter'] = [0.885, 0.838, 0, 0, '#joyful', '#interesting', 0.574, 'finish_job', 'put_food_table', 'become_little_hungry', 'desire_money', 'read_menu']
senticnet['tip_waitress'] = [0.712, 0.881, 0, 0, '#joyful', '#interesting', 0.531, 'read_label', 'bring_home', 'carry_home', 'salivation', 'buy_steak']
senticnet['tipsiness'] = [-0.529, 0, 0.542, -0.938, '#angry', '#disgusting', -0.67, 'intoxication', 'drunkenness', 'inebriation', 'inebriety', 'sottishness']
senticnet['tirade'] = [-0.912, 0, 0.704, -0.702, '#sad', '#angry', -0.773, 'rant', 'raving', 'harangue', 'ranting', 'declamation']
senticnet['tirant'] = [-0.837, 0, 0.858, -0.795, '#sad', '#angry', -0.83, 'dominance', 'ascendance', 'autocracy', 'ascendancy', 'absolutism']
senticnet['tire_out'] = [-0.983, 0, 0.047, -0.917, '#sad', '#disgusting', -0.649, 'exhaust', 'tire', 'bother', 'bore', 'annoy']
senticnet['tired'] = [0.986, 0.702, 0, 0, '#joyful', '#interesting', 0.563, 'hard_day_at_work', 'lack_of_sleep', 'sleepy', 'need_to_rest', 'sleepiness']
senticnet['tired_eye'] = [-0.165, 0, 0, -0.236, '#sad', '#disgusting', -0.134, 'lifestyle_change', 'headache', 'mind_boggle', 'relieve_pain', 'head_hurt']
senticnet['tired_foot'] = [0.737, 0.872, 0, 0, '#joyful', '#interesting', 0.536, 'lack_of_sleep', 'gyroscope', 'get_tired', 'exhaustion', 'sedative']
senticnet['tired_iron'] = [0, -0.066, 0.077, -0.109, '#angry', '#disgusting', -0.04, 'lose_ball', 'increase_price', 'ball_bounce', 'punch_bag', 'buy_ball']
senticnet['tired_leg'] = [-0.837, 0, 0, -0.85, '#sad', '#disgusting', -0.562, 'dehydration', 'heavy_breathe', 'sweat', 'shin_splint', 'get_sweaty']
senticnet['tired_of'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['tired_person'] = [-0.906, 0, 0.877, -0.911, '#sad', '#disgusting', -0.898, 'talk_too_much', 'bored_person', 'annoy_person', 'boring_movie', 'boring_show']
senticnet['tiredness'] = [0.974, 0.883, 0, 0, '#joyful', '#interesting', 0.619, 'fatigue', 'exhaustion', 'become_tired', 'get_tired', 'feel_tired']
senticnet['tiresome'] = [-0.661, 0, 0.594, -0.675, '#sad', '#disgusting', -0.643, 'boring', 'deadening', 'irksome', 'uninteresting', 'wearisome']
senticnet['tiring'] = [-0.825, 0, 0.58, -0.539, '#sad', '#angry', -0.648, 'effortful', 'wearing', 'wearying', 'hard', 'arduous']
senticnet['tiro'] = [-0.954, 0, 0.735, -0.842, '#sad', '#disgusting', -0.844, 'novice', 'beginner', 'tyro', 'cub', 'initiate']
senticnet['tissue'] = [0.051, 0.066, 0.024, 0, '#joyful', '#interesting', 0.031, 'skeleton', 'skin', 'skin_cover', 'internal_organ', 'flesh']
senticnet['titanic'] = [0, 0, 0, -0.072, '#disgusting', '#disgusting', -0.024, 'submarine', 'lifeboat', 'battleship', 'large_ship', 'canoe']
senticnet['titanium'] = [0.87, 0.822, 0, 0.717, '#joyful', '#interesting', 0.803, 'gold', 'bronze', 'alloy', 'medal', 'copper']
senticnet['tithe'] = [-0.046, 0.418, -0.233, 0.35, '#interesting', '#admirable', 0.163, 'charity', 'excise', 'given', 'extortion', 'return']
senticnet['titillate'] = [0.676, 0.63, -0.237, 0.314, '#joyful', '#interesting', 0.461, 'titillated', 'teased', 'titillating', 'titillation', 'perkiness']
senticnet['titillated'] = [0.676, 0.63, -0.237, 0.314, '#joyful', '#interesting', 0.461, 'titillate', 'teased', 'titillating', 'titillation', 'perkiness']
senticnet['titillating'] = [0.676, 0.63, -0.237, 0.314, '#joyful', '#interesting', 0.461, 'titillate', 'titillated', 'teased', 'titillation', 'perkiness']
senticnet['titillation'] = [0.676, 0.63, -0.237, 0.314, '#joyful', '#interesting', 0.461, 'titillate', 'titillated', 'teased', 'titillating', 'perkiness']
senticnet['title'] = [0.07, 0.134, -0.071, 0.155, '#interesting', '#admirable', 0.096, 'royal_person', 'blue_blood', 'royal_title', 'kingly', 'leader']
senticnet['title_page'] = [0.044, 0, 0, 0.206, '#joyful', '#admirable', 0.083, 'begin_end', 'book', 'book_content', 'book_end', 'frontspiece']
senticnet['to_go'] = [0, 0.152, -0.088, 0.208, '#interesting', '#admirable', 0.091, 'colored_green', 'plant', 'depart', 'green_color', 'tree']
senticnet['toady'] = [-0.821, 0, 0.612, -0.51, '#sad', '#angry', -0.648, 'apple_polisher', 'bootlicker', 'fawner', 'servant', 'groveler']
senticnet['toast'] = [0.022, -0.054, 0, 0, '#joyful', '#surprising', 0.025, 'bread', 'muffin', 'cookie', 'loaf', 'bagel']
senticnet['toaster'] = [0.868, -0.752, 0, 0.795, '#joyful', '#admirable', 0.805, 'friend', 'champion', 'supporter', 'protagonist', 'admirer']
senticnet['tobacco'] = [-0.999, 0, 0.056, -0.982, '#sad', '#disgusting', -0.679, 'smoke', 'cigarette', 'bad_air', 'pollution', 'cigar']
senticnet['tobacco_product'] = [0.047, 0, -0.102, -0.06, '#scared', '#disgusting', -0.038, 'smoke', 'cigarette_smoke', 'smoke_tobacco', 'lung_cancer', 'cigar']
senticnet['tobacco_wilt'] = [-0.833, 0, 0.754, -0.979, '#sad', '#disgusting', -0.855, 'brown_rot_gummosis', 'ring_rot', 'ring_disease', 'brown_rot', 'gummosis']
senticnet['toccata'] = [0.62, -0.731, 0, 0.511, '#joyful', '#surprising', 0.621, 'musical_composition', 'opus', 'composition', 'piece', 'piece_of_music']
senticnet['todd'] = [0, 0, -0.064, -0.099, '#scared', '#disgusting', -0.054, 'fire', 'combustible_material', 'wood_pulp', 'steel_wool', 'campfire']
senticnet['toddler'] = [-0.06, 0, 0.01, 0, '#sad', '#angry', -0.023, 'youth', 'young_child', 'small_child', 'lad', 'most_children']
senticnet['toe'] = [-0.037, -0.027, 0.065, -0.029, '#sad', '#angry', -0.035, 'leg', 'ankle', 'hold_canvas', 'foot', 'heel']
senticnet['toe_line'] = [0.731, -0.592, 0, 0.634, '#joyful', '#admirable', 0.652, 'accommodate', 'obey', 'conform_to', 'abide_by', 'oblige']
senticnet['toe_nail'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'make_up', 'bathroom_wall', 'fallen_tree', 'old_food', 'moldy_bread']
senticnet['tofu'] = [0, -0.031, 0.046, -0.088, '#angry', '#disgusting', -0.034, 'pasta', 'green_bean', 'mayonnaise', 'frozen_food', 'sour_milk']
senticnet['together'] = [0.211, 0.103, -0.082, 0.256, '#joyful', '#admirable', 0.163, 'come_together', 'group_of_people', 'bring_together', 'part_of_group', 'team_up']
senticnet['togetherness'] = [0.676, 0.695, -0.264, 0.402, '#joyful', '#interesting', 0.503, 'nigh', 'capture', 'comfortableness', 'comfortably', 'solace']
senticnet['toil'] = [-0.228, 0.182, -0.279, 0.162, '#sad', '#scared', -0.054, 'labor', 'employment', 'task', 'employ', 'obligation']
senticnet['toilet_brush'] = [0.83, 0.93, 0, 0, '#joyful', '#interesting', 0.587, 'shampoo_conditioner', 'toothpaste', 'electric_razor', 'gel_toothpaste', 'tartar_control_toothpaste']
senticnet['toilet_paper'] = [0.876, 0, 0, 0.748, '#joyful', '#admirable', 0.541, 'towel', 'wax_dental_floss', 'disposable_razor', 'fluoride_toothpaste', 'hair_brush']
senticnet['toilet_seat'] = [0.968, 0.775, 0, 0, '#joyful', '#interesting', 0.581, 'electric_toothbrush', 'towel', 't_shirt', 'heat_towel_rack', 'hair_brush']
senticnet['toilet_tank'] = [0.837, 0.757, 0, 0, '#joyful', '#interesting', 0.531, 'puddle', 'sop', 'liquid_water', 'finger_paint', 'bread']
senticnet['token'] = [0.02, 0.079, 0, 0.069, '#interesting', '#admirable', 0.056, 'paper_bill', 'metal_coin', 'cash_bill', 'cash_coin', 'penny']
senticnet['token_slot'] = [0.035, 0.078, 0.025, 0, '#joyful', '#interesting', 0.029, 'coin_slot', 'transit_ticket', 'passenger_ticket', 'train_ticket', 'museum_ticket']
senticnet['token_turnstile'] = [0.096, -0.017, 0, 0, '#joyful', '#surprising', 0.038, 'chain', 'platform_rail', 'catwalk', 'column', 'rail']
senticnet['tolerable'] = [0.525, -0.799, 0, 0.593, '#surprising', '#admirable', 0.639, 'tolerant', 'resistant', 'bearable', 'endurable', 'sufferable']
senticnet['tolerance'] = [-0.783, 0, 0, -0.922, '#sad', '#disgusting', -0.568, 'difference', 'discrepancy', 'allowance', 'leeway', 'margin']
senticnet['tolerant'] = [0.031, 0.146, -0.141, 0.191, '#interesting', '#admirable', 0.076, 'let_someone_do', 'leave_alone', 'group_star', 'orbit', 'outer_space']
senticnet['tolerate'] = [0, 0, 0.705, -0.91, '#angry', '#disgusting', -0.538, 'bear_up', 'take_lying_down', 'swallow', 'live_with', 'sit_out']
senticnet['toll'] = [-0.285, 0, -0.238, -0.126, '#sad', '#scared', -0.216, 'tax', 'rend', 'bill', 'owe', 'reward']
senticnet['toll_highway'] = [0, 0, 0.024, -0.051, '#angry', '#disgusting', -0.025, 'toll_road', 'national_highway', 'superhighway', 'international_highway', 'motorway']
senticnet['toll_road'] = [0.579, -0.891, 0, 0.878, '#surprising', '#admirable', 0.783, 'autobahn', 'autostrada', 'turnpike', 'expressway', 'highway']
senticnet['tomb'] = [0, 0.73, 0, 0.847, '#interesting', '#admirable', 0.526, 'bury_body', 'coffin', 'headstone', 'morgue', 'tombstone']
senticnet['tomboy'] = [0.619, -0.568, 0, 0.523, '#joyful', '#surprising', 0.57, 'girl', 'miss', 'missy', 'young_lady', 'young_woman']
senticnet['tomfool'] = [0.512, -0.926, 0, 0.688, '#surprising', '#admirable', 0.709, 'morosoph', 'simpleton', 'flibbertigibbet', 'foolish_woman', 'simple']
senticnet['tone'] = [0, 0.762, 0, 0.919, '#interesting', '#admirable', 0.56, 'melodic_noise', 'universal_language', 'instrumental', 'musical_note', 'audio']
senticnet['tone_of_voice'] = [-0.943, 0, 0.65, -0.578, '#sad', '#angry', -0.724, 'manner_of_speaking', 'undertone', 'note', 'roundness', 'rotundity']
senticnet['tonicity'] = [-0.748, 0, 0.723, -0.594, '#sad', '#angry', -0.688, 'tone', 'tautness', 'tonus', 'condition', 'status']
senticnet['tons'] = [-0.64, 0, 0.87, -0.745, '#angry', '#disgusting', -0.752, 'infinitude', 'piles', 'mess', 'large_number', 'large_indefinite_amount']
senticnet['tonus'] = [-0.748, 0, 0.723, -0.594, '#sad', '#angry', -0.688, 'tone', 'tonicity', 'tautness', 'condition', 'status']
senticnet['too_bad'] = [-0.905, 0, 0.827, -0.941, '#sad', '#disgusting', -0.891, 'regret', 'sorrow', 'grief', 'sadness', 'trouble']
senticnet['tool'] = [0.783, 0.938, 0, 0, '#joyful', '#interesting', 0.574, 'nut_bolt', 'power_drill', 'wrench', 'c_clamp', 'clamp']
senticnet['tool_belt'] = [0.959, 0.9, 0, 0, '#joyful', '#interesting', 0.62, 'tool_shed', 'tool', 'garage', 'hardware_store', 'toolbox']
senticnet['tool_box'] = [0.053, -0.067, 0, 0, '#joyful', '#surprising', 0.04, 'pair_of_scissors', 'c_clamp', 'pliers', 'salad_shaker', 'ladle']
senticnet['tool_shed'] = [0.948, 0.983, 0, 0, '#joyful', '#interesting', 0.644, 'tool', 'garage', 'hardware_store', 'tool_belt', 'utility_room']
senticnet['tool_war'] = [-0.08, -0.027, 0, -0.152, '#sad', '#disgusting', -0.068, 'weapon_war', 'gun', 'weapon', 'firearm', 'big_gun']
senticnet['toolbox'] = [0.747, 0.774, 0, 0, '#joyful', '#interesting', 0.507, 'tool_shed', 'tool', 'garage', 'tool_belt', 'hardware_store']
senticnet['tooth'] = [-0.03, 0.079, 0.024, 0.091, '#interesting', '#admirable', 0.039, 'toothpaste', 'toothbrush', 'mouth', 'gel_toothpaste', 'dental']
senticnet['tooth_brush'] = [0.043, -0.05, 0.043, 0.204, '#surprising', '#admirable', 0.085, 'flour_water', 'sticky_substance', 'adhesive', 'computer_command', 'insert']
senticnet['tooth_decay'] = [0, 0, 0.813, -0.951, '#angry', '#disgusting', -0.588, 'ice_cream_melt', 'allergy', 'toothache', 'gonorrhea', 'tastebud']
senticnet['tooth_hurt'] = [0.038, -0.04, -0.066, -0.121, '#scared', '#disgusting', -0.036, 'digestion', 'enjoy_taste', 'become_little_hungry', 'no_long_hungry', 'feel_full']
senticnet['tooth_pain'] = [-0.92, 0, 0.794, -0.935, '#sad', '#disgusting', -0.883, 'loose_tooth', 'pain', 'feel_terrible', 'scared', 'painful']
senticnet['tooth_socket'] = [0.681, -0.632, 0, 0.647, '#joyful', '#admirable', 0.653, 'hip_socket', 'socket', 'alveolus', 'acetabulum', 'cotyloid_cavity']
senticnet['toothache'] = [0, 0, 0.819, -0.984, '#angry', '#disgusting', -0.601, 'diabetes', 'ice_cream_melt', 'bad_hair_day', 'diarrhoea', 'flab']
senticnet['toothbrush'] = [0.036, 0.129, 0, 0.06, '#interesting', '#admirable', 0.075, 'toothpaste', 'tartar_control_toothpaste', 'wax_dental_floss', 'gel_toothpaste', 'dental_floss']
senticnet['toothbrush_bristle'] = [0.921, 0.772, 0, 0, '#joyful', '#interesting', 0.564, 'tartar_control_toothpaste', 'toothpaste', 'gel_toothpaste', 'toothbrush_head', 'dental_floss']
senticnet['toothbrush_head'] = [0.783, 0.721, 0, 0, '#joyful', '#interesting', 0.501, 'tartar_control_toothpaste', 'gel_toothpaste', 'dental_floss', 'toothpaste', 'toothbrush']
senticnet['toothed'] = [0.845, -0.716, 0, 0.775, '#joyful', '#admirable', 0.779, 'toothy', 'cogged', 'sabertoothed', 'toothlike', 'tusked']
senticnet['toothpaste'] = [0.036, 0.129, 0, 0.06, '#interesting', '#admirable', 0.075, 'tartar_control_toothpaste', 'gel_toothpaste', 'dental', 'toothbrush', 'tooth']
senticnet['top'] = [0.045, 0, 0, 0.125, '#joyful', '#admirable', 0.057, 'zenith', 'tall', 'high', 'pinnacle', 'apex']
senticnet['top_class'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'top', 'top_notch', 'first_rate', 'premium', 'high_class']
senticnet['top_dog'] = [0.163, 0.121, 0, 0.131, '#joyful', '#admirable', 0.138, 'head_guy', 'head_person', 'police_rank', 'chief', 'commander']
senticnet['top_face'] = [0, 0.076, 0, 0.052, '#interesting', '#admirable', 0.043, 'hold_brain', 'face', 'skull', 'eye_nose', 'nose_mouth']
senticnet['top_fermentation'] = [0.833, -0.507, 0, 0.519, '#joyful', '#admirable', 0.62, 'bottom_fermentation', 'zymosis', 'vinification', 'chemical_process', 'chemical_change']
senticnet['top_floor'] = [0.064, 0.07, 0, 0, '#joyful', '#interesting', 0.045, 'elevator', 'front_desk', 'concierge', 'exit', 'ground_floor']
senticnet['top_head'] = [0.049, 0.089, 0, 0.102, '#interesting', '#admirable', 0.08, 'head_wear', 'head_gear', 'worn_head', 'blue_blood', 'headdress']
senticnet['top_model'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'work_out', 'exercise', 'eat_properly', 'fitness', 'go_gym']
senticnet['top_notch'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'top', 'top_class', 'first_rate', 'premium', 'high_class']
senticnet['top_tree'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'tunnel', 'dark_place', 'ski_resort', 'cave', 'compost_pile']
senticnet['topple'] = [-0.536, 0, 0.752, -0.898, '#angry', '#disgusting', -0.729, 'fall', 'keel_over', 'descend', 'go_down', 'come_down']
senticnet['torah'] = [0.071, 0.171, 0, 0.154, '#interesting', '#admirable', 0.132, 'biography', 'chapter', 'text', 'scripture', 'essay']
senticnet['torch'] = [-0.034, -0.022, -0.113, -0.083, '#scared', '#disgusting', -0.069, 'firebomb', 'fire_light', 'master_control', 'flare', 'flash_light']
senticnet['torment'] = [-0.172, 0.07, 0.675, -0.673, '#angry', '#disgusting', -0.483, 'pique', 'harassment', 'bedevil', 'frustrating', 'crucify']
senticnet['tormented'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'mocked', 'teased', 'bothered', 'annoyed', 'ridiculed']
senticnet['torn'] = [-0.066, -0.018, 0.05, -0.071, '#sad', '#disgusting', -0.056, 'embroidery', 'woven', 'cover_wind', 'braid', 'use_needle']
senticnet['tornado'] = [0, -0.016, -0.082, -0.136, '#scared', '#disgusting', -0.067, 'lightning', 'lighten', 'bright_flash', 'flood', 'natural_disaster']
senticnet['torpid'] = [-0.963, 0, -0.848, 0, '#sad', '#scared', -0.604, 'soggy', 'dormant', 'inert', 'sluggish', 'hibernating']
senticnet['torpidity'] = [-0.975, 0, 0.992, -0.866, '#sad', '#angry', -0.944, 'lassitude', 'hibernation', 'lethargy', 'sluggishness', 'physical_condition']
senticnet['torpor'] = [-0.793, 0, 0.837, -0.82, '#angry', '#disgusting', -0.817, 'lassitude', 'hibernation', 'lethargy', 'sluggishness', 'physical_condition']
senticnet['torrid'] = [0, 0, 0.787, -0.941, '#angry', '#disgusting', -0.576, 'fervid', 'ardent', 'impassioned', 'fervent', 'fiery']
senticnet['tortuous'] = [0, 0, 0.968, -0.83, '#angry', '#disgusting', -0.599, 'convoluted', 'knotty', 'tangled', 'involved', 'byzantine']
senticnet['torture'] = [0, 0, -0.792, -0.903, '#scared', '#disgusting', -0.565, 'destruction', 'seek_revenge', 'suffer', 'stab_knife', 'feel_anger']
senticnet['torture_and_interrogate'] = [-0.973, 0, 0.676, -0.963, '#sad', '#disgusting', -0.871, 'commit_crime', 'criminal', 'police', 'deceive', 'beat_to_bleeding']
senticnet['toss_ball'] = [0.885, 0, 0, 0, '#joyful', '#joyful', 0.295, 'catch_ball', 'swim_lake', 'experience_fear', 'field_ball', 'bird_watch']
senticnet['toss_turn'] = [-0.022, 0, 0, -0.048, '#sad', '#disgusting', -0.023, 'sleep_day', 'take_afternoon_nap', 'pull_up_cover', 'take_nap', 'nap']
senticnet['tot'] = [-0.933, 0, 0.8, -0.501, '#sad', '#angry', -0.745, 'miscount', 'numerate', 'tally', 'find', 'add']
senticnet['total'] = [0, 0.26, 0.019, 0.204, '#interesting', '#admirable', 0.148, 'all_of_it', 'amount', 'sum', 'quantity', 'total_number']
senticnet['total_amount'] = [-0.045, 0.268, 0, 0.159, '#interesting', '#admirable', 0.127, 'total', 'amount', 'a_lot', 'all_of_it', 'like_price']
senticnet['total_number'] = [0.027, 0.158, 0.082, 0.182, '#interesting', '#admirable', 0.095, 'count', 'list_number', 'measure_unit', 'tally', 'numeral']
senticnet['totalitarian'] = [-0.551, 0, 0.931, -0.74, '#angry', '#disgusting', -0.741, 'undemocratic', 'authoritarian', 'dictatorial', 'despotic', 'monarchal']
senticnet['totality'] = [0.044, 0.256, -0.093, 0.274, '#interesting', '#admirable', 0.16, 'complete', 'impermanent', 'entire', 'full', 'all_of_it']
senticnet['tote'] = [0.048, 0.169, -0.145, 0.403, '#interesting', '#admirable', 0.158, 'hold_stuff', 'spring_leak', 'carry', 'carry_item', 'bring']
senticnet['tote_bag'] = [0, -0.026, 0.027, -0.092, '#angry', '#disgusting', -0.031, 'shoulder_bag', 'satchel', 'satchel_bag', 'water_bottle', 'vanity_case']
senticnet['totter'] = [-0.8, 0, -0.804, 0, '#sad', '#scared', -0.535, 'coggle', 'paddle', 'dodder', 'toddle', 'waddle']
senticnet['touch'] = [0, 0.959, 0, 0.752, '#interesting', '#admirable', 0.57, 'rub', 'sensual', 'gesture', 'grasp', 'grab']
senticnet['touch_ball'] = [-0.768, 0, 0.85, -0.778, '#angry', '#disgusting', -0.799, 'fussy', 'pester', 'fastidious', 'contrary', 'inquisitive']
senticnet['touch_chord'] = [0.636, -0.92, 0, 0.683, '#surprising', '#admirable', 0.746, 'arouse', 'elicit', 'enkindle', 'kindle', 'evoke']
senticnet['touch_fire'] = [0, 0, -0.849, -0.732, '#scared', '#disgusting', -0.527, 'blow_out_match', 'burn_paper', 'blow_out', 'create_light', 'burn_wood']
senticnet['touch_ground'] = [0, -0.024, 0.074, -0.098, '#angry', '#disgusting', -0.049, 'silent', 'mute', 'antiquate', 'absorb_water', 'tangent']
senticnet['touch_heart'] = [0.829, 0, 0, 0.729, '#joyful', '#admirable', 0.519, 'spread_word', 'able_read', 'clever', 'develop_talent', 'others_understand']
senticnet['touch_other'] = [0.308, 0.067, 0.053, 0.161, '#joyful', '#admirable', 0.161, 'happiness', 'stimulation', 'orgasm', 'sexual_pleasure', 'kiss_partner']
senticnet['touch_toe'] = [0, 0.801, 0, 0.983, '#interesting', '#admirable', 0.595, 'elasticity', 'elastic', 'stretch', 'flexibility', 'elongate']
senticnet['touchiness'] = [-0.892, 0, 0.943, -0.561, '#sad', '#angry', -0.799, 'ill_humor', 'distemper', 'pet', 'testiness', 'crossness']
senticnet['touchy'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'pervert', 'horny', 'uncomfortable', 'uneasy', 'short_tempered']
senticnet['tough'] = [0, 0.863, 0, 0.822, '#interesting', '#admirable', 0.562, 'combatant', 'battler', 'fighter', 'scrapper', 'durable']
senticnet['tough_luck'] = [-0.618, 0, 0.961, -0.827, '#angry', '#disgusting', -0.802, 'hard_cheese', 'weakness', 'gutter', 'adversity', 'hardship']
senticnet['toughened'] = [0.641, -0.577, 0, 0.707, '#joyful', '#admirable', 0.642, 'enured', 'inured', 'thickened', 'calloused', 'callous']
senticnet['toughie'] = [-0.765, 0, 0.527, -0.826, '#sad', '#disgusting', -0.706, 'criminal', 'bully', 'outlaw', 'malefactor', 'felon']
senticnet['tourer'] = [-0.569, 0, 0.811, -0.769, '#angry', '#disgusting', -0.716, 'rubberneck', 'sightseer', 'excursionist', 'tripper', 'traveler']
senticnet['tourism'] = [0, 0.863, 0, 0.927, '#interesting', '#admirable', 0.597, 'travel', 'infect', 'live', 'apologize', 'life_end']
senticnet['tourist'] = [-0.871, 0, 0.938, -0.575, '#sad', '#angry', -0.795, 'rubberneck', 'sightseer', 'excursionist', 'tripper', 'traveler']
senticnet['tourist_attraction'] = [0.034, 0.13, -0.083, 0.258, '#interesting', '#admirable', 0.113, 'tourism', 'nice_view', 'big_monument', 'temple', 'sightsee']
senticnet['tourist_site'] = [0, 0.784, 0, 0.791, '#interesting', '#admirable', 0.525, 'bad_situation', 'political_rally', 'predicament', 'dilemma', 'situation']
senticnet['tourniquet'] = [-0.036, 0, -0.12, -0.217, '#scared', '#disgusting', -0.124, 'medicine', 'scalpel', 'stethoscope', 'hospital', 'treatment']
senticnet['touting'] = [0, 0, 0.807, -0.721, '#angry', '#disgusting', -0.509, 'shoot_line', 'boast', 'swash', 'gas', 'brag']
senticnet['tow'] = [0, 0.21, -0.113, 0.345, '#interesting', '#admirable', 0.147, 'come', 'continue', 'go_on', 'push', 'drag']
senticnet['tow_truck'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'trailer', 'trail_car', 'camion', 'wagon', 'towboat']
senticnet['toward'] = [0, 0.21, -0.113, 0.345, '#interesting', '#admirable', 0.147, 'direction', 'unto', 'forehead', 'upon', 'go_toward']
senticnet['towel'] = [0.024, 0.157, 0.018, 0.145, '#interesting', '#admirable', 0.103, 'toilet_paper', 'beach_towel', 'face_towel', 'hand_towel', 'tissue']
senticnet['towel_bar'] = [0, -0.029, 0.041, -0.102, '#angry', '#disgusting', -0.038, 'separate_shower', 'shampoo_conditioner', 'shower_curtain', 'shower_head', 'toilet_brush']
senticnet['towel_off'] = [0, 0.078, 0, 0.065, '#interesting', '#admirable', 0.048, 'dry_off', 'dry_oneself', 'hang_up_towel', 'make_bow', 'dry_off_towel']
senticnet['tower'] = [0.024, 0.157, 0.018, 0.145, '#interesting', '#admirable', 0.103, 'castle', 'bell_tower', 'spire', 'steeple', 'religious_place']
senticnet['tower_cress'] = [0.598, -0.721, 0, 0.941, '#surprising', '#admirable', 0.753, 'sicklepod', 'rock_cress', 'tower_mustard', 'cress', 'cress_plant']
senticnet['tower_mustard'] = [0.598, -0.721, 0, 0.941, '#surprising', '#admirable', 0.753, 'sicklepod', 'tower_cress', 'rock_cress', 'cress', 'cress_plant']
senticnet['town_center'] = [-0.033, 0.099, 0.017, 0.102, '#interesting', '#admirable', 0.05, 'every_town', 'downtown', 'monument', 'cathedral', 'city_center']
senticnet['town_hall'] = [0.025, 0.136, 0, 0, '#joyful', '#interesting', 0.054, 'city_hall', 'courthouse', 'subway_station', 'public_place', 'bus_station']
senticnet['toxic'] = [-0.188, 0, -0.141, 0, '#sad', '#scared', -0.11, 'hazardous_health', 'dangerous_health', 'bad_health', 'gross', 'harmful']
senticnet['toxic_condition'] = [-0.74, 0, 0.981, -0.603, '#sad', '#angry', -0.775, 'ergotism', 'paraquat_poisoning', 'alkali_poisoning', 'caffeinism', 'caffeine_intoxication']
senticnet['toxic_dumpsite'] = [0.835, -0.854, 0, 0.99, '#surprising', '#admirable', 0.893, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'wasteyard']
senticnet['toxic_metal'] = [0.046, -0.15, 0.016, 0.167, '#surprising', '#admirable', 0.116, 'dense_air', 'north_south', 'heavy_metal', 'heavy_element', 'tin_foil']
senticnet['toxic_waste'] = [-0.058, -0.049, 0.01, -0.113, '#sad', '#disgusting', -0.044, 'potato', 'break', 'kill_bug', 'tear_apart', 'destroy']
senticnet['toxic_waste_dump'] = [0.744, -0.963, 0, 0.864, '#surprising', '#admirable', 0.857, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'wasteyard']
senticnet['toxic_waste_site'] = [0.889, -0.518, 0, 0.757, '#joyful', '#admirable', 0.721, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'wasteyard']
senticnet['toxicity'] = [-0.721, 0, 0.71, -0.9, '#sad', '#disgusting', -0.777, 'perniciousness', 'harmfulness', 'unwholesomeness', 'noisomeness', 'noxiousness']
senticnet['toy'] = [0, -0.105, 0, 0, '#surprising', '#surprising', 0.035, 'bath_toy', 'stuff_animal', 'toy_soldier', 'action_figure', 'yo-yo']
senticnet['toy_ball'] = [0.945, 0.943, 0, 0, '#joyful', '#interesting', 0.629, 'toy_marble', 'toy_car', 'toy_soldier', 'beanie_baby', 'action_figure']
senticnet['toy_balloon'] = [0.801, 0.752, 0, 0, '#joyful', '#interesting', 0.518, 'helium_balloon', 'toy_car', 'toy_soldier', 'slinky', 'beanie_baby']
senticnet['toy_box'] = [0.84, 0.817, 0, 0, '#joyful', '#interesting', 0.552, 'fancy_dress', 'shoe_shop', 'kid_room', 'furniture_store', 'girl_room']
senticnet['toy_car'] = [0.883, 0.9, 0, 0, '#joyful', '#interesting', 0.594, 'toy_ball', 'action_figure', 'toy_soldier', 'toy_marble', 'beanie_baby']
senticnet['toy_marble'] = [0.817, 0.998, 0, 0, '#joyful', '#interesting', 0.605, 'toy_ball', 'toy_car', 'action_figure', 'toy_soldier', 'beanie_baby']
senticnet['toy_soldier'] = [0.809, 0.712, 0, 0, '#joyful', '#interesting', 0.507, 'toy_car', 'toy_ball', 'action_figure', 'toy_marble', 'beanie_baby']
senticnet['toy_store'] = [0, 0.306, -0.053, 0.287, '#interesting', '#admirable', 0.18, 'luggage_compartment', 'toy_box', 'sport_goods_store', 'girl_room', 'gym']
senticnet['toying'] = [0.663, -0.605, 0, 0.862, '#joyful', '#admirable', 0.71, 'frolic', 'gambol', 'romp', 'play', 'caper']
senticnet['trace'] = [-0.042, 0.114, 0, 0.086, '#interesting', '#admirable', 0.053, 'pencil_art', 'sketch', 'like_paint', 'representation', 'illustration']
senticnet['track'] = [-0.042, 0.114, 0, 0.086, '#interesting', '#admirable', 0.053, 'street', 'road', 'railway', 'racetrack', 'pathway']
senticnet['tract'] = [-0.55, 0, 0.996, -0.506, '#sad', '#angry', -0.684, 'pesthole', 'rookery', 'breeding_ground', 'piece_of_land', 'piece_of_ground']
senticnet['tractability'] = [0.637, -0.911, 0, 0.757, '#surprising', '#admirable', 0.768, 'manageability', 'manageableness', 'docility', 'obedience', 'amenability']
senticnet['tractable'] = [0.604, -0.612, 0, 0.536, '#joyful', '#surprising', 0.584, 'tamable', 'tameable', 'ductile', 'malleable', 'docile']
senticnet['tractableness'] = [0.518, -0.924, 0, 0.527, '#surprising', '#admirable', 0.656, 'manageability', 'manageableness', 'docility', 'obedience', 'amenability']
senticnet['trade'] = [-0.047, 0.278, -0.085, 0.202, '#interesting', '#admirable', 0.116, 'exchange', 'bargain', 'business_deal', 'sale', 'deal']
senticnet['trade_baseball_card'] = [-0.183, 0, -0.082, -0.05, '#sad', '#scared', -0.105, 'roll_ball', 'ring_doorbell', 'wear_silly_hat', 'bicycle_school', 'promise_good']
senticnet['trade_card'] = [-0.047, 0.278, -0.085, 0.202, '#interesting', '#admirable', 0.116, 'trade', 'card', 'collection', 'collect_item', 'business_card']
senticnet['trade_protection'] = [-0.706, 0, 0.552, -0.681, '#sad', '#disgusting', -0.646, 'protection', 'regimentation', 'taxation', 'imposition', 'reimposition']
senticnet['trade_stock'] = [0.022, 0.08, 0, 0.076, '#interesting', '#admirable', 0.059, 'trade', 'stock', 'wall_street', 'earn_money', 'business']
senticnet['tradesman'] = [0.022, 0.08, 0, 0.076, '#interesting', '#admirable', 0.059, 'profession', 'occupation', 'job', 'important_job', 'hire_help']
senticnet['tradition'] = [0, 0.853, 0, 0.715, '#interesting', '#admirable', 0.523, 'culture', 'special_day', 'holiday', 'party_time', 'yearly_celebration']
senticnet['traditional_knowledge'] = [0.634, -0.97, 0, 0.523, '#joyful', '#surprising', 0.709, 'content', 'old_wives_tale', 'folklore', 'cognitive_content', 'mental_object']
senticnet['traducement'] = [-0.612, 0, 0.749, -0.546, '#sad', '#angry', -0.636, 'malignment', 'vilification', 'smear', 'character_assassination', 'libel']
senticnet['traffic'] = [-0.987, 0, 0.989, -0.933, '#sad', '#angry', -0.97, 'flight_accident', 'dangerous', 'danger', 'air_traffic', 'air_traffic_jam']
senticnet['traffic_accident'] = [-0.085, -0.059, 0, -0.083, '#sad', '#disgusting', -0.036, 'press_accelerator', 'get_lose', 'use_gas', 'arrive_late', 'shift_gear']
senticnet['traffic_artery'] = [0.04, 0.07, 0, 0, '#joyful', '#interesting', 0.037, 'intersection', 'interstate', 'parking_lot', 'expressway', 'crossroad']
senticnet['traffic_congestion'] = [0.954, 0.891, 0, 0, '#joyful', '#interesting', 0.615, 'traffic', 'congestion', 'block_road', 'road_block', 'stop']
senticnet['traffic_control'] = [0.032, -0.009, 0, 0.09, '#joyful', '#admirable', 0.044, 'umpire', 'referee', 'equestrian_sport', 'backgammon', 'croquet']
senticnet['traffic_cop'] = [0, 0.066, -0.058, 0.095, '#interesting', '#admirable', 0.034, 'interjection', 'like_car', 'red_cross', 'another_name', 'gas_electric']
senticnet['traffic_jam'] = [-0.157, -0.136, 0, -0.255, '#sad', '#disgusting', -0.092, 'road_rage', 'car_crash', 'skid_mark', 'pollution', 'stop_red_light']
senticnet['traffic_light'] = [0.722, 0.865, 0, 0.748, '#interesting', '#admirable', 0.778, 'safety', 'avoid_crash', 'drive_safe', 'safety_belt', 'respect_rule']
senticnet['traffic_police'] = [0, 0.769, 0, 0, '#interesting', '#interesting', 0.256, 'stop_suspect', 'direct_traffic', 'traffic_jam', 'stop_crime', 'fine_violator']
senticnet['traffic_rule'] = [0.038, 0, 0.01, 0.059, '#joyful', '#admirable', 0.029, 'control_road', 'develop_city', 'bicycle_area', 'red_light', 'yellow_line']
senticnet['traffic_sign'] = [0, 0.119, 0, 0.123, '#interesting', '#admirable', 0.081, 'street_sign', 'road_sign', 'red_light', 'paint_line', 'halt']
senticnet['traffic_signal'] = [0.06, 0, 0, 0.059, '#joyful', '#admirable', 0.04, 'electrical_circuit', 'mailbox', 'parking_lot', 'hand_luggage', 'message_board']
senticnet['tragedy'] = [-0.232, -0.049, -0.183, -0.039, '#sad', '#scared', -0.135, 'terrible_event', 'perpetrator', 'drama', 'broken_arm', 'deception']
senticnet['trail'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'path', 'roadside', 'car_path', 'intersection', 'under_bridge']
senticnet['trail_car'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'tow_truck', 'trailer', 'camion', 'wagon', 'towboat']
senticnet['trailer'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'tow_truck', 'trail_car', 'camion', 'wagon', 'towboat']
senticnet['train_daily'] = [0, 0.992, 0, 0.867, '#interesting', '#admirable', 0.62, 'sporty_guy', 'run_fast', 'run_lot', 'train_muscle', 'exercise']
senticnet['train_depot'] = [0, 0.106, 0, 0, '#interesting', '#interesting', 0.035, 'train_station', 'park_meter', 'bus_station', 'factory', 'baggage_compartment']
senticnet['train_dog'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'teach', 'restless', 'train_pet', 'feel_energetic', 'need_fresh_air']
senticnet['train_hard'] = [0, 0.949, 0, 0.726, '#interesting', '#admirable', 0.558, 'olympic_event', 'athletics', 'shape', 'form_of_exercise', 'good_shape']
senticnet['train_marathon'] = [-0.857, 0, -0.719, -0.865, '#sad', '#disgusting', -0.814, 'get_exercise', 'high_blood_pressure', 'run_marathon', 'run_long_distance', 'go_gym']
senticnet['train_muscle'] = [0, 0.971, 0, 0.929, '#interesting', '#admirable', 0.633, 'sporty_guy', 'train_daily', 'run_lot', 'run_fast', 'exercise']
senticnet['train_open_mind'] = [0, 0.951, 0, 0, '#interesting', '#interesting', 0.317, 'enter_data_computer', 'add_number', 'write_computer_program', 'add_two_numbers_together', 'calculation']
senticnet['train_pet'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'teach', 'restless', 'train_dog', 'feel_energetic', 'need_fresh_air']
senticnet['train_seat'] = [0.716, 0.836, 0, 0, '#joyful', '#interesting', 0.517, 'coach_seat', 'snack_bar', 'airplane_seat', 'sofa_bed', 'first_class_airplane_seat']
senticnet['train_station'] = [0, 0.147, 0, 0.099, '#interesting', '#admirable', 0.082, 'airport', 'railway_station', 'subway', 'airport_terminal', 'depot']
senticnet['train_ticket'] = [0, 0.093, 0, 0, '#interesting', '#interesting', 0.031, 'subway_pass', 'bus_pass', 'transit_ticket', 'passenger_ticket', 'transit_card']
senticnet['train_track'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'railway', 'track', 'train', 'rail', 'pathway']
senticnet['train_window'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'unix', 'window', 'many_windows', 'solaris', 'doorway']
senticnet['trainband'] = [-0.636, 0, 0.575, -0.598, '#sad', '#disgusting', -0.603, 'force', 'militia', 'military_unit', 'military_force', 'military_group']
senticnet['trained'] = [0, -0.927, 0, 0.771, '#surprising', '#admirable', 0.566, 'prepare', 'develop', 'check', 'discipline', 'educate']
senticnet['trainer'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'coach', 'instructor', 'personal_trainer', 'fit_person', 'train']
senticnet['training'] = [0.908, -0.837, 0, 0.822, '#joyful', '#surprising', 0.856, 'practice', 'activity', 'discipline', 'athletic_training', 'drill']
senticnet['training_body'] = [0.877, 0.832, 0, 0.791, '#joyful', '#interesting', 0.833, 'enjoy_challenge', 'win_competition', 'enjoy_game', 'leader', 'engage_sport']
senticnet['trait'] = [0, 0.999, 0, 0.828, '#interesting', '#admirable', 0.609, 'peculiar', 'good_character', 'personality_trait', 'character_trait', 'behavior']
senticnet['traitor'] = [0, 0, 0.85, -0.88, '#angry', '#disgusting', -0.577, 'rogue', 'seaman', 'lieutenant', 'officer', 'captain']
senticnet['tram'] = [0, 0.804, 0, 0.957, '#interesting', '#admirable', 0.587, 'bus', 'metro', 'train', 'transport', 'transportation']
senticnet['trammel'] = [-0.519, 0, 0.946, -0.995, '#angry', '#disgusting', -0.82, 'clamp_down', 'limit', 'restrict', 'bound', 'confine']
senticnet['tramp'] = [-0.647, 0, 0.712, -0.785, '#angry', '#disgusting', -0.715, 'vagrant', 'drifter', 'floater', 'vagabond', 'dosser']
senticnet['trance'] = [0.636, 0.631, -0.28, 0.36, '#joyful', '#interesting', 0.449, 'enchant', 'comfortableness', 'comfortably', 'solace', 'capture']
senticnet['tranquil'] = [0.549, 0.656, -0.249, 0.264, '#joyful', '#interesting', 0.407, 'unagitated', 'unruffled', 'placidly', 'placid', 'placidness']
senticnet['tranquility'] = [0.634, 0.649, -0.248, 0.3, '#joyful', '#interesting', 0.445, 'serene', 'repose', 'ataraxis', 'pacifically', 'peaceably']
senticnet['tranquilize'] = [0.506, 0.659, -0.246, 0.242, '#joyful', '#interesting', 0.387, 'calmly', 'quieten', 'soothing', 'assuasive', 'tranquility']
senticnet['tranquilizer'] = [-0.866, 0, 0.646, -0.888, '#sad', '#disgusting', -0.8, 'minor_tranquilizer', 'put_to_sleep', 'antianxiety_drug', 'anxiolytic', 'anxiolytic_drug']
senticnet['tranquillize'] = [0.962, -0.739, 0, 0.995, '#joyful', '#admirable', 0.899, 'lenify', 'placate', 'gruntle', 'pacify', 'conciliate']
senticnet['tranquilly'] = [0.579, 0.652, -0.249, 0.276, '#joyful', '#interesting', 0.419, 'tranquility', 'quietness', 'quietude', 'tranquil', 'unagitated']
senticnet['transact_business'] = [0.84, 0.813, 0, 0.915, '#joyful', '#admirable', 0.856, 'increase_income', 'able_use', 'resolve_dispute', 'time_consume', 'promote_business']
senticnet['transactinide'] = [-0.575, 0, 0.954, -0.806, '#angry', '#disgusting', -0.778, 'nonmetal', 'chemical_element', 'hydrogen', 'atomic_number_1', 'xenon']
senticnet['transaction'] = [-0.059, 0.265, -0.067, 0.233, '#interesting', '#admirable', 0.124, 'business_transaction', 'money_exchange', 'financial_transaction', 'purchase', 'lower_price']
senticnet['transfer'] = [-0.1, 0.273, -0.098, 0.219, '#interesting', '#admirable', 0.098, 'money_exchange', 'money_transfer', 'financial_transaction', 'owe_money', 'money']
senticnet['transfer_information'] = [0.574, 0.561, 0, 0.795, '#joyful', '#admirable', 0.643, 'take_note', 'collect_information', 'take_note_class', 'search_information', 'listen_lecture']
senticnet['transfer_knowledge'] = [-0.1, 0.273, -0.098, 0.219, '#interesting', '#admirable', 0.098, 'share_idea', 'knowledge', 'exchange_knowledge', 'exchange_idea', 'share_knowledge']
senticnet['transformation'] = [0.556, -0.923, 0, 0.762, '#surprising', '#admirable', 0.747, 'degeneration', 'improvement', 'betterment', 'sea_change', 'strengthening']
senticnet['transformer'] = [0.96, 0.81, 0, 0, '#joyful', '#interesting', 0.59, 'yo-yo', 'action_figure', 'toy_marble', 'kite', 'toy_car']
senticnet['transfuse'] = [0.79, -0.62, 0, 0.674, '#joyful', '#admirable', 0.695, 'add', 'contribute', 'lend', 'breathe', 'impart']
senticnet['transgress'] = [-0.933, 0, 0.669, -0.931, '#sad', '#disgusting', -0.844, 'offend', 'violate', 'go_against', 'break', 'contravene']
senticnet['transience'] = [-0.877, 0, 0.744, -0.54, '#sad', '#angry', -0.72, 'temporariness', 'impermanence', 'transiency', 'transitoriness', 'mortality']
senticnet['transiency'] = [-0.877, 0, 0.744, -0.54, '#sad', '#angry', -0.72, 'temporariness', 'transience', 'impermanence', 'transitoriness', 'mortality']
senticnet['transient'] = [0, 0, -0.849, -0.705, '#scared', '#disgusting', -0.518, 'transitory', 'transeunt', 'ephemeral', 'passing', 'short-lived']
senticnet['transit'] = [0.04, 0.144, -0.074, 0.122, '#interesting', '#admirable', 0.077, 'taxi_cab', 'rut', 'foreign_country', 'another_place', 'move_another_place']
senticnet['transit_card'] = [0.04, 0.144, -0.074, 0.122, '#interesting', '#admirable', 0.077, 'transit', 'bus_pass', 'travel_card', 'transit_ticket', 'transport_card']
senticnet['transit_ticket'] = [0, 0.093, 0, 0, '#interesting', '#interesting', 0.031, 'subway_pass', 'train_ticket', 'bus_pass', 'passenger_ticket', 'transit_card']
senticnet['transition'] = [0, 0.202, -0.067, 0.291, '#interesting', '#admirable', 0.142, 'change_life', 'pocket_money', 'go_forward', 'evolve', 'rotate_movement']
senticnet['transitoriness'] = [-0.877, 0, 0.744, -0.54, '#sad', '#angry', -0.72, 'temporariness', 'transience', 'transiency', 'impermanence', 'mortality']
senticnet['translation'] = [0, 0.202, -0.067, 0.291, '#interesting', '#admirable', 0.142, 'vocabulary', 'translate', 'dictionary', 'interpreter', 'thesaurus']
senticnet['translucent'] = [0, 0.075, 0, 0.119, '#interesting', '#admirable', 0.065, 'transparent', 'see_thru', 'clear_solid', 'transparency', 'see_through']
senticnet['transmission'] = [-0.536, 0, 0.8, -0.642, '#angry', '#disgusting', -0.659, 'causing', 'causation', 'sending', 'transmittal', 'transmitting']
senticnet['transmit_disease'] = [-0.076, 0, -0.171, -0.095, '#scared', '#disgusting', -0.114, 'get_trouble', 'end_war', 'feel_love', 'go_scuba_dive', 'sense_environment']
senticnet['transmit_information'] = [0.504, 0.617, 0, 0.753, '#interesting', '#admirable', 0.625, 'convey_information', 'body_language', 'express_idea', 'give_comfort', 'write_novel']
senticnet['transmit_signal'] = [0, 0.711, 0, 0.984, '#interesting', '#admirable', 0.565, 'lean', 'bury_dead', 'wooden_box', 'inside_body', 'body']
senticnet['transmittal'] = [-0.536, 0, 0.8, -0.642, '#angry', '#disgusting', -0.659, 'causing', 'causation', 'transmission', 'sending', 'transmitting']
senticnet['transmitting'] = [-0.536, 0, 0.8, -0.642, '#angry', '#disgusting', -0.659, 'causing', 'causation', 'transmission', 'transmittal', 'sending']
senticnet['transparency'] = [-0.026, 0.095, 0.009, 0.107, '#interesting', '#admirable', 0.056, 'see_thru', 'translucent', 'transparent', 'clear_solid', 'sunny_weather']
senticnet['transparent'] = [-0.031, 0.066, 0, 0.08, '#interesting', '#admirable', 0.038, 'translucent', 'see_thru', 'clear_solid', 'see_through', 'clear']
senticnet['transparentness'] = [0.617, -0.848, 0, 0.868, '#surprising', '#admirable', 0.778, 'clearness', 'clarity', 'uncloudedness', 'pellucidity', 'limpidity']
senticnet['transplant'] = [-0.883, 0.174, -0.597, 0, '#sad', '#scared', -0.435, 'displace', 'move', 'move_away', 'bump', 'dislocate']
senticnet['transport'] = [0.045, 0.075, -0.053, 0.19, '#interesting', '#admirable', 0.086, 'ride', 'trucking', 'haul', 'car_action', 'move_object']
senticnet['transport_card'] = [0.04, 0.144, -0.074, 0.122, '#interesting', '#admirable', 0.077, 'transit', 'bus_pass', 'travel_card', 'transit_ticket', 'transit_card']
senticnet['transport_food'] = [0.823, 0, 0, 0, '#joyful', '#joyful', 0.274, 'serve_meal', 'eat_food_off_plate', 'munch', 'eat_pudding', 'eat_food']
senticnet['transport_goods'] = [-0.036, 0.111, -0.061, 0.084, '#interesting', '#admirable', 0.033, 'sailing', 'travel_over_water', 'cross_ocean', 'vacation', 'sail_ocean']
senticnet['transport_person'] = [0.028, 0, 0, 0.099, '#joyful', '#admirable', 0.042, 'go_from_place_to_place', 'get_to_another_place', 'travel_long_distance', 'go_some_place', 'travel']
senticnet['transportation'] = [0.02, -0.007, 0, 0.096, '#joyful', '#admirable', 0.041, 'car_travel', 'trucking', 'travel_long_distance', 'get_around', 'travel_to_another_place']
senticnet['transportation_device'] = [-0.029, 0.075, 0, 0.059, '#interesting', '#admirable', 0.035, 'human_memory', 'courthouse_look_public_record', 'new_caledonia', 'minor_planet', 'poo']
senticnet['transportation_vehicle'] = [0, -0.019, 0, 0.058, '#surprising', '#admirable', 0.026, 'long_car', 'motor_vehicle', 'large_automobile', 'machine_transportation', 'form_of_public_transportation']
senticnet['trap_mouse'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'kill_mouse', 'trap', 'pest', 'catch_mouse', 'bait']
senticnet['trapeze'] = [0.72, 0.845, 0, 0, '#joyful', '#interesting', 0.522, 'polka', 'jitterbug', 'twist', 'flea', 'mosquito']
senticnet['trapezoid'] = [0, 0.862, 0, 0.941, '#interesting', '#admirable', 0.601, 'hexagon', 'parallelogram', 'rhombus', 'polygon', 'geometric_figure']
senticnet['trapping'] = [-0.741, 0, 0.722, -0.562, '#sad', '#angry', -0.675, 'accouterment', 'furnishing', 'wear', 'wearable', 'belt']
senticnet['trash'] = [0.976, 0.726, 0, 0, '#joyful', '#interesting', 0.567, 'garbage', 'store_trash', 'dustbin', 'garbage_can', 'wastebasket']
senticnet['trash_bag'] = [0.291, 0.17, -0.146, 0.08, '#joyful', '#interesting', 0.132, 'rubbish', 'garbage', 'waste_paper', 'store_trash', 'hold_trash']
senticnet['trash_bin'] = [0, 0, 0, -0.117, '#disgusting', '#disgusting', -0.039, 'garbage_dump', 'dumpster', 'dump', 'garage', 'repair_shop']
senticnet['trash_can'] = [0.996, 0.973, 0, 0, '#joyful', '#interesting', 0.656, 'trash', 'trash_container', 'dustbin', 'coffee_cup', 'trash_receptacle']
senticnet['trash_container'] = [0.782, 0.934, 0, 0, '#joyful', '#interesting', 0.572, 'trash', 'dustbin', 'trash_can', 'coffee_cup', 'trash_receptacle']
senticnet['trash_dump'] = [-0.707, 0, 0.611, -0.695, '#sad', '#disgusting', -0.671, 'dump', 'garbage_dump', 'garbage_heap', 'rubbish_dump', 'wasteyard']
senticnet['trash_heap'] = [-0.918, 0, 0.615, -0.569, '#sad', '#angry', -0.701, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'wasteyard']
senticnet['trash_pile'] = [-0.52, 0, 0.978, -0.558, '#angry', '#disgusting', -0.685, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'wasteyard']
senticnet['trash_receptacle'] = [0.835, 0.892, 0, 0, '#joyful', '#interesting', 0.576, 'trash', 'trash_container', 'trash_can', 'coffee_cup', 'dustbin']
senticnet['trashcan'] = [0, 0, 0, -0.082, '#disgusting', '#disgusting', -0.027, 'dump', 'dumpster', 'trash_bin', 'incinerator', 'garbage_dump']
senticnet['trashiness'] = [-0.771, 0, 0.599, -0.528, '#sad', '#angry', -0.633, 'vanity', 'worthlessness', 'damn', 'shoddiness', 'shit']
senticnet['trashy'] = [-0.784, 0, 0.651, -0.564, '#sad', '#angry', -0.666, 'rubbishy', 'sorry', 'worthless', 'otiose', 'superfluous']
senticnet['trauma'] = [-0.886, 0, -0.795, -0.857, '#sad', '#disgusting', -0.846, 'pain', 'severe_pain', 'agony', 'physical_pain', 'suffer']
senticnet['travail'] = [-0.687, 0, 0.635, -0.547, '#sad', '#angry', -0.623, 'sweat', 'effort', 'elbow_grease', 'exertion', 'least_effort']
senticnet['travel'] = [0, 0, 0, 0.097, '#admirable', '#admirable', 0.032, 'transport_person', 'travel_long_distance', 'get_plane', 'get_bus', 'get_to_another_place']
senticnet['travel_abroad'] = [0.838, 0.936, 0, 0, '#joyful', '#interesting', 0.591, 'travel_by_airplane', 'board_plane', 'board_airplane', 'board_boat', 'board_bus']
senticnet['travel_across_world'] = [0.978, 0.843, 0, 0, '#joyful', '#interesting', 0.607, 'seat_passenger', 'land_runway', 'cost_money', 'government_agreement', 'run_out_fuel']
senticnet['travel_by_airplane'] = [0.729, 0.974, 0, 0, '#joyful', '#interesting', 0.568, 'board_boat', 'travel_abroad', 'near_destination', 'drive_destination', 'board_plane']
senticnet['travel_car'] = [0, -0.009, 0, 0.081, '#surprising', '#admirable', 0.03, 'drive_upon', 'divide_property', 'get_fast', 'pay_toll', 'drive_quickly']
senticnet['travel_card'] = [0.04, 0.144, -0.074, 0.122, '#interesting', '#admirable', 0.077, 'transit', 'bus_pass', 'transit_card', 'transit_ticket', 'transport_card']
senticnet['travel_comfortable'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'seat', 'few_people', 'free_seat', 'good_service', 'free']
senticnet['travel_fast'] = [0.729, 0.974, 0, 0, '#joyful', '#interesting', 0.568, 'travel', 'fast', 'faster', 'take_airplane', 'drive_fast']
senticnet['travel_fast_light'] = [0, 0, 0, 0.717, '#admirable', '#admirable', 0.239, 'travel', 'live_ocean', 'like_play', 'drink_sea_water', 'breaunderwater']
senticnet['travel_kit'] = [0.876, 0.806, 0, 0, '#joyful', '#interesting', 0.561, 'shave_kit', 'own_bathroom', 'hotel_bathroom', 'carton', 'beauty_parlor']
senticnet['travel_long_distance'] = [0.051, -0.034, 0.012, 0.049, '#joyful', '#admirable', 0.041, 'travel_to_another_place', 'go_from_place_to_place', 'transport_person', 'get_to_another_place', 'transportation']
senticnet['travel_map'] = [0.946, 0, 0, 0.77, '#joyful', '#admirable', 0.572, 'game', 'travel_world', 'fun', 'fast_travel', 'location']
senticnet['travel_moon'] = [0.754, 0.903, 0, 0, '#joyful', '#interesting', 0.552, 'hand', 'two_hands', 'forearm', 'five_fingers', 'elbow']
senticnet['travel_over_water'] = [0, 0.091, 0, 0.141, '#interesting', '#admirable', 0.077, 'cross_river', 'bridge_stream', 'sail_ocean', 'connect_city', 'bridge']
senticnet['travel_place'] = [0, 0, 0, 0.077, '#admirable', '#admirable', 0.026, 'transport_person', 'corner_well', 'travel_road', 'move_person', 'carry_person']
senticnet['travel_quick'] = [0.946, 0, 0, 0.77, '#joyful', '#admirable', 0.572, 'shade', 'drive_quickly', 'travel', 'drive_somewhere', 'aviator']
senticnet['travel_quickly'] = [-0.041, 0, -0.047, 0, '#sad', '#scared', -0.029, 'get_plane', 'get_to_another_place', 'get_bus', 'get_fast', 'arrive_late']
senticnet['travel_road'] = [-0.105, 0, -0.098, 0.067, '#sad', '#scared', -0.045, 'corner_well', 'gain_speed', 'appear_suddenly', 'go_fast', 'drive_down_street']
senticnet['travel_space'] = [0.995, 0.784, 0, 0, '#joyful', '#interesting', 0.593, 'marry_man', 'service_car', 'dig_grave', 'bicycle_across_town', 'date_woman']
senticnet['travel_through_space'] = [-0.062, 0, -0.072, -0.035, '#sad', '#scared', -0.056, 'hold_two_together', 'deteriorate', 'burn_up', 'corrode', 'float_through_air']
senticnet['travel_to_another_place'] = [0.924, 0.992, 0, 0, '#joyful', '#interesting', 0.639, 'travel_long_distance', 'wander_around', 'go_from_place_to_place', 'get_to_another_place', 'get_around_town']
senticnet['travel_work'] = [-0.072, -0.026, 0, -0.077, '#sad', '#disgusting', -0.041, 'push_limit', 'fly_plane', 'rush_work', 'get_stick_traffic', 'plan_day']
senticnet['travel_world'] = [0.946, 0, 0, 0.77, '#joyful', '#admirable', 0.572, 'game', 'fast_travel', 'fun', 'travel_map', 'location']
senticnet['traveler'] = [-0.653, 0, 0.943, -0.756, '#angry', '#disgusting', -0.784, 'rubberneck', 'sightseer', 'excursionist', 'tripper', 'holidaymaker']
senticnet['traveling_destination'] = [0.924, 0.992, 0, 0, '#joyful', '#interesting', 0.639, 'travel', 'destination', 'holiday', 'traveling_person', 'traveller']
senticnet['traveling_long_distance'] = [0.054, -0.046, 0.01, 0.059, '#joyful', '#admirable', 0.05, 'travel_long_distance', 'drive_upon', 'get_fast', 'commute', 'travel_car']
senticnet['traveling_person'] = [0.069, 0.07, 0, 0.116, '#interesting', '#admirable', 0.085, 'person', 'stockholder', 'move_around', 'move_person', 'guilty_person']
senticnet['traveling_water'] = [0.821, 0, 0, 0.724, '#joyful', '#admirable', 0.515, 'compete_others', 'recreation', 'fun_exercise', 'competition', 'get_physically_fit']
senticnet['traveller'] = [0.069, 0.07, 0, 0.116, '#interesting', '#admirable', 0.085, 'passenger', 'tourist', 'travel', 'explorer', 'adventurer']
senticnet['traversable'] = [-0.996, 0, 0.641, -0.765, '#sad', '#disgusting', -0.801, 'navigable', 'negotiable', 'surmountable', 'climbable', 'passable']
senticnet['traverse'] = [0, 0, -0.778, -0.778, '#scared', '#disgusting', -0.519, 'transom', 'track', 'crosspiece', 'crossbeam', 'traversal']
senticnet['travesty'] = [0, 0, -0.905, -0.973, '#scared', '#disgusting', -0.626, 'parody', 'farce', 'lampoon', 'farce_comedy', 'spoof']
senticnet['treacherous'] = [-0.669, 0, 0.709, -0.881, '#angry', '#disgusting', -0.753, 'untrue', 'apostate', 'unfaithful', 'perfidious', 'punic']
senticnet['treachery'] = [-0.28, -0.023, -0.142, -0.293, '#sad', '#disgusting', -0.231, 'bloodshed', 'casualty', 'mean_person', 'imprisonment', 'attack_enemy']
senticnet['treadle'] = [-0.993, 0, 0.66, -0.508, '#sad', '#angry', -0.72, 'bar', 'lever', 'pry', 'key', 'peavey']
senticnet['treadmill'] = [0.094, 0, 0, 0, '#joyful', '#joyful', 0.031, 'hooker', 'registry_office', 'restaurant_entrance', 'elevator', 'exit']
senticnet['treasure'] = [0.914, 0.732, 0, 0, '#joyful', '#interesting', 0.549, 'old_coin', 'precious', 'alter', 'paper_money', 'monetary_unit']
senticnet['treasure_chest'] = [0, 0.177, 0, 0.126, '#interesting', '#admirable', 0.101, 'treasure', 'storage_facility', 'shrine', 'lock_box', 'jewelry_box']
senticnet['treasured'] = [0.732, 0, 0, 0.907, '#joyful', '#admirable', 0.546, 'cherish', 'prize', 'appreciate', 'value', 'care_for']
senticnet['treasurer'] = [0.03, 0.222, 0, 0, '#joyful', '#interesting', 0.084, 'safe', 'bank', 'government_agreement', 'wallet', 'coffer']
senticnet['treat'] = [0, 0.996, 0, 0.714, '#interesting', '#admirable', 0.57, 'pay_for_meal', 'birthday_surprise', 'birthday_treat', 'dessert', 'chocolate_dessert']
senticnet['treat_illness'] = [0, 0.068, -0.126, -0.103, '#scared', '#disgusting', -0.054, 'cure_disease', 'heal', 'cure_illness', 'get_well', 'heal_disease']
senticnet['treatable'] = [-0.589, 0.11, -0.505, 0, '#sad', '#scared', -0.328, 'harmful_human', 'bad', 'inherit', 'bad_choice', 'hard_to_define']
senticnet['treated'] = [-0.739, 0, 0.641, -0.748, '#sad', '#disgusting', -0.709, 'burnt', 'burned', 'proofed', 'doped', 'activated']
senticnet['treatment'] = [-0.057, 0, -0.226, -0.065, '#scared', '#disgusting', -0.116, 'medicine', 'cure', 'medical_procedure', 'sleep_drug', 'nurse']
senticnet['treaty'] = [0.133, 0.266, -0.129, 0.163, '#interesting', '#admirable', 0.144, 'truce', 'pact', 'cease_fire', 'agreement', 'hesitation']
senticnet['tree'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'christmas_tree', 'evergreen_christmas_tree', 'big_christmas_tree', 'christmas_tree_item', 'christmas']
senticnet['tree_animal'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'flora', 'eukaryote', 'endangered_species', 'rodent', 'carbon_monoxide']
senticnet['tree_arm'] = [0.027, -0.057, 0.055, 0.058, '#surprising', '#admirable', 0.029, 'tree_part', 'tree_limb', 'part_of_tree', 'tree_piece', 'twig']
senticnet['tree_branch'] = [0.042, -0.134, 0.029, 0, '#joyful', '#surprising', 0.049, 'twig', 'leaf', 'tree_arm', 'branch', 'tree_limb']
senticnet['tree_cover'] = [0.02, 0, 0.009, 0.132, '#joyful', '#admirable', 0.048, 'green', 'tree_make', 'colored_green', 'fragrant', 'sexual']
senticnet['tree_flower'] = [0, 0.071, 0, 0, '#interesting', '#interesting', 0.024, 'vegetation', 'greenery', 'green_growth', 'flower_plant', 'many_plants']
senticnet['tree_fruit'] = [0.058, 0, 0.041, 0.086, '#joyful', '#admirable', 0.034, 'delicious_fruit', 'yellow_fruit', 'small_fruit', 'crunchy', 'popular_food']
senticnet['tree_house'] = [0, 0.095, 0, 0.127, '#interesting', '#admirable', 0.074, 'upside_down', 'up_mountain', 'graceful', 'nocturnal', 'climb_tree']
senticnet['tree_item'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'tree', 'evergreen_tree', 'christmas_tree', 'big_tree', 'christmas']
senticnet['tree_limb'] = [0, 0.902, 0, 0.771, '#interesting', '#admirable', 0.558, 'tree_part', 'tree_arm', 'part_of_tree', 'tree_piece', 'twig']
senticnet['tree_make'] = [0, 0, 0, 0.089, '#admirable', '#admirable', 0.03, 'tree_product', 'tree_cover', 'solid_fuel', 'parasol', 'make_wood']
senticnet['tree_part'] = [0.134, -0.112, 0.066, 0.054, '#joyful', '#surprising', 0.078, 'wooden_stick', 'long_stick', 'tree_limb', 'big_stick', 'twig']
senticnet['tree_piece'] = [0, 0.836, 0, 0.994, '#interesting', '#admirable', 0.61, 'part_of_tree', 'tree_part', 'tree_limb', 'tree_arm', 'tree_branch']
senticnet['tree_product'] = [0, 0, 0, 0.073, '#admirable', '#admirable', 0.024, 'solid_fuel', 'organic_substance', 'renewable_resource', 'use_fuel', 'fire_starter']
senticnet['tree_trunk'] = [-0.189, -0.121, 0.049, -0.247, '#sad', '#disgusting', -0.121, 'wooden_leg', 'plank', 'artificial_leg', 'hardwood', 'tree_wood']
senticnet['tree_type'] = [0, 0, 0.029, -0.043, '#angry', '#disgusting', -0.024, 'franchise', 'soft_wood', 'tree_wood', 'wood', 'cellulose']
senticnet['tree_wood'] = [0, -0.026, 0.085, -0.094, '#angry', '#disgusting', -0.051, 'dead_tree', 'forest', 'sideways', 'deforestation', 'wood']
senticnet['trefoil_arch'] = [0.641, -0.569, 0, 0.748, '#joyful', '#admirable', 0.653, 'pointed_arch', 'ogee_arch', 'keel_arch', 'drop_arch', 'arch']
senticnet['trekking'] = [0.993, 0, 0, 0.896, '#joyful', '#admirable', 0.63, 'popular_recreation', 'exercise', 'exercise_regularly', 'moderation', 'nice_weather']
senticnet['trematode'] = [0.688, -0.942, 0, 0.925, '#surprising', '#admirable', 0.852, 'flatworm', 'platyhelminth', 'liver_fluke', 'schistosome', 'blood_fluke']
senticnet['trematode_worm'] = [0.938, -0.601, 0, 0.691, '#joyful', '#admirable', 0.743, 'flatworm', 'platyhelminth', 'liver_fluke', 'schistosome', 'blood_fluke']
senticnet['tremble'] = [-0.879, 0, 0.882, -0.564, '#sad', '#angry', -0.775, 'reflex', 'reflex_response', 'reflex_action', 'instinctive_reflex', 'innate_reflex']
senticnet['tremendous'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'terrific', 'wondrously', 'marvelous', 'wondrous', 'amazing']
senticnet['tremolo'] = [0.748, -0.907, 0, 0.99, '#surprising', '#admirable', 0.882, 'shakiness', 'quivering', 'shaking', 'vibration', 'quiver']
senticnet['tremor'] = [0, 0.866, 0, 0.959, '#interesting', '#admirable', 0.608, 'earth_movement', 'vibration', 'animal_sound', 'loud_yell', 'sound']
senticnet['trench_fever'] = [-0.738, 0, 0.599, -0.96, '#sad', '#disgusting', -0.766, 'spotted_fever', 'rickettsial_disease', 'rickettsialpox', 'typhus', 'typhus_fever']
senticnet['trench_foot'] = [-0.503, 0, 0.737, -0.741, '#angry', '#disgusting', -0.66, 'injury', 'harm', 'hurt', 'cryopathy', 'immersion_foot']
senticnet['trend'] = [0.05, 0.151, 0, 0.159, '#interesting', '#admirable', 0.12, 'glamour', 'stylish', 'style', 'clothes_style', 'fancy_clothes']
senticnet['trendy'] = [0.039, -0.022, 0.032, 0.059, '#joyful', '#admirable', 0.029, 'glamour', 'fancy_clothes', 'frilly', 'woman_clothes', 'girl_clothes']
senticnet['trepid'] = [0.992, 0.719, 0, 0, '#joyful', '#interesting', 0.57, 'timorously', 'timorous', 'fear', 'timorousation', 'presentiment']
senticnet['trepidation'] = [0, 0, 0.967, -0.729, '#angry', '#disgusting', -0.565, 'timorously', 'trepid', 'trepidly', 'timorous', 'fear']
senticnet['trepidly'] = [0.887, 0.85, 0, 0, '#joyful', '#interesting', 0.579, 'boding', 'premonition', 'presentiment', 'foreboding', 'presage']
senticnet['trespass'] = [-0.961, 0, 0.589, -0.572, '#sad', '#angry', -0.707, 'continuing_trespass', 'trespass_de_bonis_asportatis', 'trespass_on_case', 'trespass_quare_clausum_fregit', 'trespass_viet_armis']
senticnet['trespass_de_bonis_asportatis'] = [-0.961, 0, 0.589, -0.572, '#sad', '#angry', -0.707, 'continuing_trespass', 'trespass', 'trespass_on_case', 'trespass_quare_clausum_fregit', 'trespass_viet_armis']
senticnet['trespass_on_case'] = [-0.961, 0, 0.589, -0.572, '#sad', '#angry', -0.707, 'continuing_trespass', 'trespass_de_bonis_asportatis', 'trespass', 'trespass_quare_clausum_fregit', 'trespass_viet_armis']
senticnet['trespass_quare_clausum_fregit'] = [-0.961, 0, 0.589, -0.572, '#sad', '#angry', -0.707, 'continuing_trespass', 'trespass_de_bonis_asportatis', 'trespass_on_case', 'trespass', 'trespass_viet_armis']
senticnet['trespass_viet_armis'] = [-0.961, 0, 0.589, -0.572, '#sad', '#angry', -0.707, 'continuing_trespass', 'trespass_de_bonis_asportatis', 'trespass_on_case', 'trespass_quare_clausum_fregit', 'trespass']
senticnet['trespasser'] = [-0.978, 0, 0.783, -0.601, '#sad', '#angry', -0.787, 'outsider', 'foreigner', 'intruder', 'interloper', 'stranger']
senticnet['trial'] = [0, 0.126, 0, 0.084, '#interesting', '#admirable', 0.07, 'punish_criminal', 'negotiator', 'judge_jury', 'juror', 'judicial_system']
senticnet['trial_run'] = [0.736, -0.808, 0, 0.69, '#joyful', '#surprising', 0.745, 'field_trial', 'field_test', 'alpha_test', 'beta_test', 'road_test']
senticnet['triangle'] = [0.763, -0.612, 0, 0.777, '#joyful', '#admirable', 0.717, 'acute_triangle', 'wedge_shape', 'cuneus', 'wedge', 'oblique_triangle']
senticnet['tribe'] = [0, 0.867, 0, 0.921, '#interesting', '#admirable', 0.596, 'committee', 'council', 'caste', 'association', 'organization']
senticnet['tribulate'] = [-0.743, 0, 0.622, -0.867, '#sad', '#disgusting', -0.744, 'afflict', 'upset', 'grieve', 'disconcert', 'aggrieve']
senticnet['tribute'] = [0, 0, 0, 0.78, '#admirable', '#admirable', 0.26, 'tradition', 'commencement', 'invitation', 'festivity', 'occasion']
senticnet['trick'] = [0, 0, 0.746, -0.984, '#angry', '#disgusting', -0.577, 'deception', 'fraud', 'dare', 'fool', 'deceive']
senticnet['trick_someone'] = [-0.96, 0, 0.65, -0.929, '#sad', '#disgusting', -0.846, 'lie', 'fraud', 'commit_perjury', 'deceit', 'dishonesty']
senticnet['trickery'] = [-0.86, 0, 0.675, -0.841, '#sad', '#disgusting', -0.792, 'shenanigan', 'chicanery', 'wile', 'goldbrick', 'dupery']
senticnet['tricky'] = [-0.384, 0.165, -0.32, 0.243, '#sad', '#scared', -0.099, 'hard_to_define', 'inherit', 'harmful_human', 'bad_choice', 'badness']
senticnet['tried_and_true'] = [0.947, -0.793, 0, 0.7, '#joyful', '#surprising', 0.813, 'tested', 'tried', 'dependable', 'sure', 'undeviating']
senticnet['trifling'] = [0, 0, -0.846, -0.822, '#scared', '#disgusting', -0.556, 'dalliance', 'piddle', 'wanton_away', 'wanton', 'dawdling']
senticnet['trigeminal_neuralgia'] = [-0.547, 0, 0.543, -0.63, '#sad', '#disgusting', -0.573, 'hurting', 'pain', 'neuralgia', 'tic_douloureux', 'sciatica']
senticnet['trigger'] = [-0.997, 0, 0.651, -0.513, '#sad', '#angry', -0.72, 'sending', 'compulsion', 'influence', 'inducement', 'causation']
senticnet['triggerfish'] = [-0.545, 0, 0.829, -0.725, '#angry', '#disgusting', -0.7, 'puffer', 'pufferfish', 'blowfish', 'plectognath', 'filefish']
senticnet['trilby'] = [-0.588, 0, 0.632, -0.638, '#angry', '#disgusting', -0.619, 'skimmer', 'chapeau', 'bearskin', 'busby', 'shako']
senticnet['trim'] = [-0.069, 0, 0.034, -0.071, '#sad', '#disgusting', -0.058, 'sever', 'slit', 'slash', 'open_wind', 'lacerate']
senticnet['trim_back'] = [0.887, -0.737, 0, 0.603, '#joyful', '#surprising', 0.742, 'inflate', 'thin', 'downsize', 'subtract', 'knock_off']
senticnet['trim_down'] = [0.964, -0.709, 0, 0.62, '#joyful', '#surprising', 0.764, 'inflate', 'thin', 'downsize', 'subtract', 'knock_off']
senticnet['trim_hair'] = [-0.062, -0.033, 0.044, -0.084, '#sad', '#disgusting', -0.052, 'shave_beard', 'shorten_hair', 'shave_leg', 'shave', 'cut_paper']
senticnet['trinket'] = [0, 0, -0.955, -0.711, '#scared', '#disgusting', -0.555, 'gaud', 'novelty', 'gewgaw', 'bangle', 'bauble']
senticnet['triose'] = [-0.528, 0, 0.681, -0.768, '#angry', '#disgusting', -0.659, 'simple_sugar', 'tetrose', 'pentose', 'hexose', 'aldose']
senticnet['trip'] = [0, 0, -0.903, 0, '#scared', '#scared', -0.301, 'lose_foot', 'skid', 'stumble', 'reach_high_shelf', 'almost_fall']
senticnet['trip_acid'] = [-0.034, -0.082, -0.154, -0.163, '#scared', '#disgusting', -0.09, 'drug', 'analgesic', 'sleep_drug', 'ibuprofen', 'palliative']
senticnet['trip_fall'] = [0.948, 0.837, 0, 0, '#joyful', '#interesting', 0.595, 'blister_foot', 'breahard', 'twist_ankle', 'breafast', 'out_breath']
senticnet['trip_fall_down'] = [-0.88, 0, 0, -0.95, '#sad', '#disgusting', -0.61, 'get_hit_by_car', 'move_leg', 'hurt_toe', 'swing_arm', 'trip_fall']
senticnet['trip_over'] = [-0.112, 0, 0.012, -0.099, '#sad', '#disgusting', -0.074, 'lose_balance', 'fall_off', 'shift_gear', 'wear_helmet', 'peddle']
senticnet['trip_person'] = [0, 0.788, 0, 0.905, '#interesting', '#admirable', 0.564, 'sense_environment', 'fight_other', 'battle_cancer', 'eat_live', 'die_only_once']
senticnet['trip_up'] = [-0.988, 0, 0.618, -0.507, '#sad', '#angry', -0.704, 'learn', 'hear', 'get_word', 'get_wind', 'pick_up']
senticnet['tripod_dolly'] = [0.128, -0.111, 0, -0.057, '#joyful', '#surprising', 0.061, 'chesterfield', 'stool', 'tape_machine_room', 'chair', 'bicyle']
senticnet['tripped_over'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'come_across', 'stumble', 'lose_balance', 'stammer', 'stutter']
senticnet['tripper'] = [-0.653, 0, 0.943, -0.756, '#angry', '#disgusting', -0.784, 'rubberneck', 'sightseer', 'excursionist', 'holidaymaker', 'traveler']
senticnet['triquetral'] = [-0.744, 0, 0.598, -0.756, '#sad', '#disgusting', -0.699, 'lunate_bone', 'semilunar_bone', 'carpal_bone', 'carpal', 'bone']
senticnet['triquetral_bone'] = [-0.744, 0, 0.598, -0.756, '#sad', '#disgusting', -0.699, 'lunate_bone', 'semilunar_bone', 'carpal_bone', 'triquetral', 'carpal']
senticnet['trisomy'] = [-0.827, 0, 0.582, -0.741, '#sad', '#disgusting', -0.717, 'down_syndrome', 'birth_defect', 'congenital_anomaly', 'congenital_defect', 'congenital_disorder']
senticnet['trite'] = [0, 0, -0.867, -0.806, '#scared', '#disgusting', -0.558, 'banal', 'commonplace', 'old-hat', 'hackneyed', 'shopworn']
senticnet['triumph'] = [0.721, 0.805, 0, 0.738, '#interesting', '#admirable', 0.755, 'triumphal', 'prideful', 'exulting', 'exultant', 'triumphant']
senticnet['triumphal'] = [0.732, 0.614, -0.224, 0.329, '#joyful', '#interesting', 0.484, 'exulting', 'prideful', 'exultant', 'triumphant', 'rejoicing']
senticnet['triumphant'] = [0.732, 0.614, -0.224, 0.329, '#joyful', '#interesting', 0.484, 'exulting', 'prideful', 'triumphal', 'exultant', 'rejoicing']
senticnet['triumphantly'] = [0.724, 0.617, -0.228, 0.331, '#joyful', '#interesting', 0.481, 'rejoicing', 'triumphal', 'prideful', 'exulting', 'triumphant']
senticnet['trivia'] = [0.098, 0.165, -0.134, 0.284, '#interesting', '#admirable', 0.138, 'understand', 'gain_insight', 'knowledge', 'know', 'solution_to_problem']
senticnet['trivial'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'minor', 'unimportant', 'inessential', 'negligible', 'petty']
senticnet['trojan'] = [-0.867, 0, 0.769, -0.888, '#sad', '#disgusting', -0.841, 'malevolent_program', 'malevolent_program_horse', 'virus', 'worm', 'computer_virus']
senticnet['trojan_horse'] = [-0.867, 0, 0.769, -0.888, '#sad', '#disgusting', -0.841, 'trojan', 'malevolent_program', 'virus', 'worm', 'computer_virus']
senticnet['trolley'] = [0.038, 0.155, 0, 0.074, '#interesting', '#admirable', 0.089, 'merchandise', 'cashier', 'goods', 'shopper', 'grocery']
senticnet['trollop'] = [-0.544, 0, 0.691, -0.966, '#angry', '#disgusting', -0.734, 'slut', 'adulterer', 'libertine', 'adulteress', 'fornicatress']
senticnet['troop'] = [0, 0, -0.064, -0.129, '#scared', '#disgusting', -0.064, 'army', 'attacker', 'military', 'soldier', 'infantry']
senticnet['trophy'] = [0.041, 0.116, -0.057, 0.089, '#interesting', '#admirable', 0.063, 'medal', 'medallion', 'gold', 'titanium', 'carat']
senticnet['tropical_cyclone'] = [-0.961, 0, 0.014, -0.956, '#sad', '#disgusting', -0.644, 'storm', 'gale', 'bad_weather', 'hurricane', 'rain']
senticnet['tropical_fish'] = [-0.899, 0, 0, -0.985, '#sad', '#disgusting', -0.628, 'autumn_leaf', 'wood_duck', 'disney', 'pink_flower', 'beau']
senticnet['tropical_forest'] = [0, 0.762, 0, 0, '#interesting', '#interesting', 0.254, 'encyclopaedia', 'tropical_rainforest', 'learn_new_information', 'documentary', 'children_story']
senticnet['tropical_rainforest'] = [0, 0.762, 0, 0, '#interesting', '#interesting', 0.254, 'encyclopaedia', 'documentary', 'learn_new_information', 'tropical_forest', 'children_story']
senticnet['tropical_storm'] = [-0.028, 0, 0, -0.081, '#sad', '#disgusting', -0.036, 'hurricane', 'mild', 'breeze', 'weather_element', 'atmospheric_phenomenon']
senticnet['trot'] = [0, 0, 0.752, -0.843, '#angry', '#disgusting', -0.532, 'get_hit_by_car', 'meander', 'full_moon', 'step_dog_poop', 'kick_ass']
senticnet['trot_out'] = [0.58, -0.821, 0, 0.77, '#surprising', '#admirable', 0.724, 'show', 'expose', 'bring_out', 'unfold', 'disclose']
senticnet['trouble'] = [-0.378, 0.184, -0.346, -0.067, '#sad', '#scared', -0.202, 'cause_problem', 'caution', 'unsafe', 'big_monster', 'intolerance']
senticnet['trouble_breathe'] = [0, 0, -0.748, -0.871, '#scared', '#disgusting', -0.54, 'go_hospital', 'chest_pain', 'brain_damage', 'kill_oneself', 'health_problem']
senticnet['trouble_maker'] = [-0.849, 0, 0.506, -0.628, '#sad', '#disgusting', -0.661, 'disturber', 'provoker', 'inciter', 'instigant', 'hellhound']
senticnet['troubled'] = [-0.723, 0, 0.671, -0.635, '#sad', '#angry', -0.676, 'disquieted', 'worried', 'upset', 'unquiet', 'distressed']
senticnet['troublemaker'] = [-0.983, 0, 0.693, -0.768, '#sad', '#disgusting', -0.815, 'disturber', 'provoker', 'inciter', 'instigant', 'hellhound']
senticnet['troubler'] = [-0.523, 0, 0.701, -0.503, '#sad', '#angry', -0.576, 'disturber', 'provoker', 'inciter', 'instigant', 'hellhound']
senticnet['troubleshoot'] = [-0.886, 0, 0.688, -0.936, '#sad', '#disgusting', -0.837, 'fix', 'bushel', 'doctor', 'furbish_up', 'repair']
senticnet['troublesome'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'nuisance', 'annoyance', 'irritant', 'pain_in_ass', 'pest']
senticnet['troublesomeness'] = [-0.647, 0, 0.625, -0.882, '#sad', '#disgusting', -0.718, 'difficulty', 'awkwardness', 'flea_bite', 'difficultness', 'cumbersomeness']
senticnet['troubling'] = [0.845, 0.708, 0, 0, '#joyful', '#interesting', 0.518, 'disquieted', 'distressing', 'disturbing', 'perturbing', 'worrisome']
senticnet['trounce'] = [0.946, -0.638, 0, 0.889, '#joyful', '#admirable', 0.824, 'flagellate', 'leather', 'birch', 'beat', 'scourge']
senticnet['trousers'] = [0, -0.052, 0.092, -0.072, '#angry', '#disgusting', -0.037, 'pant', 'man_clothes', 'slack', 'shirt', 'scarf']
senticnet['trout'] = [-0.861, 0, 0.941, -0.713, '#sad', '#angry', -0.838, 'salmon', 'salmonid', 'go_fishing', 'fish', 'catch_fish']
senticnet['truant'] = [-0.514, 0, 0.63, -0.842, '#angry', '#disgusting', -0.662, 'hooky_player', 'absentee', 'defaulter', 'exile', 'expatriate']
senticnet['truce'] = [0.268, 0.199, -0.123, 0, '#joyful', '#interesting', 0.115, 'peace', 'no_war', 'no_noise', 'treaty', 'civil_war']
senticnet['truck'] = [0.903, -0.893, 0, 0.919, '#joyful', '#admirable', 0.905, 'camion', 'rig', 'wrecker', 'dump_truck', 'dumper']
senticnet['truck_driver'] = [0, 0.763, 0, 0.884, '#interesting', '#admirable', 0.549, 'attendant', 'manager', 'public_servant', 'specialist', 'accomplice']
senticnet['truck_stop'] = [0, 0, 0, -0.077, '#disgusting', '#disgusting', -0.026, 'sell_car', 'car_dealership', 'vehicle', 'insurance', 'car']
senticnet['trucking'] = [0, 0.082, -0.057, 0.201, '#interesting', '#admirable', 0.075, 'car_travel', 'transportation', 'go_elsewhere', 'transport_person', 'steer_car']
senticnet['truculence'] = [-0.507, 0, 0.817, -0.593, '#angry', '#disgusting', -0.639, 'disagreeableness', 'pugnacity', 'truculency', 'bellicosity', 'bellicoseness']
senticnet['truculency'] = [-0.507, 0, 0.817, -0.593, '#angry', '#disgusting', -0.639, 'disagreeableness', 'truculence', 'pugnacity', 'bellicosity', 'bellicoseness']
senticnet['true'] = [0.117, 0.266, 0, 0.215, '#interesting', '#admirable', 0.199, 'genuine', 'truthful', 'smartness', 'honesty', 'truth']
senticnet['true_bacteria'] = [-0.908, 0, 0.908, -0.538, '#sad', '#angry', -0.785, 'tubercle_bacillus', 'leprosy_bacillus', 'eubacteria', 'eubacterium', 'mycobacteria']
senticnet['true_believer'] = [0, 0.211, -0.088, 0.183, '#interesting', '#admirable', 0.102, 'believer', 'cleric', 'worshiper', 'religious_person', 'religious_leader']
senticnet['true_bill'] = [0.654, -0.592, 0, 0.774, '#joyful', '#admirable', 0.673, 'instrument', 'murder_charge', 'murder_indictment', 'indictment', 'legal_document']
senticnet['true_blackberry'] = [-0.922, 0, 0.912, -0.942, '#sad', '#disgusting', -0.925, 'blackberry_bush', 'sand_blackberry', 'dewberry', 'dewberry_bush', 'running_blackberry']
senticnet['true_love'] = [0.801, 0, 0, 0.912, '#joyful', '#admirable', 0.571, 'cherish', 'love_parent', 'run_business', 'express_gratitude', 'world_peace']
senticnet['truffle'] = [0.995, 0.969, 0, 0, '#joyful', '#interesting', 0.655, 'fallen_leaf', 'pine_cone', 'detritus', 'dead_leaf', 'sleep_dog']
senticnet['truffle_dog'] = [0.059, 0.073, 0, 0, '#joyful', '#interesting', 0.044, 'chihuahua', 'dog', 'domesticate_dog', 'domesticate_animal', 'bloodhound']
senticnet['truism'] = [0.524, -0.641, 0, 0.675, '#surprising', '#admirable', 0.613, 'truth', 'platitude', 'cliche', 'banality', 'commonplace']
senticnet['trunk_hose'] = [-0.589, 0, 0.757, -0.679, '#angry', '#disgusting', -0.675, 'breeches', 'knee_breeches', 'knee_pants', 'knickerbockers', 'knickers']
senticnet['trust'] = [0, 0, 0, 0.6, '#admirable', '#admirable', 0.2, 'hope', 'worship', 'trust_god', 'enter_contract', 'believe']
senticnet['trust_friend'] = [0.852, 0.955, 0, 0, '#joyful', '#interesting', 0.602, 'think_food', 'fight_other', 'die_only_once', 'wear_skirt', 'dig_grave']
senticnet['trust_god'] = [0.782, 0, 0, 0.752, '#joyful', '#admirable', 0.511, 'plan_wedding', 'believe_god', 'belief_god', 'believe', 'kneel']
senticnet['trusting'] = [0, 0, -0.831, -0.904, '#scared', '#disgusting', -0.578, 'hope', 'swear', 'rely', 'bank', 'believe']
senticnet['trustworthy'] = [0, 0.834, 0, 0.814, '#interesting', '#admirable', 0.549, 'medical_person', 'medical', 'diagnose', 'medical_professional', 'doctor_patient']
senticnet['truth'] = [0.768, 0.935, 0, 0.996, '#interesting', '#admirable', 0.9, 'integrity', 'ethic', 'certain', 'impact', 'investigation']
senticnet['truthful'] = [0.76, 0.998, 0, 0.75, '#joyful', '#interesting', 0.836, 'honesty', 'honest', 'integrity', 'virtue', 'good_character']
senticnet['truthfulness'] = [0.76, -0.593, 0, 0.713, '#joyful', '#admirable', 0.689, 'sooth', 'sincerity', 'honestness', 'honesty', 'veracity']
senticnet['try'] = [-0.107, 0.171, -0.1, 0.17, '#interesting', '#admirable', 0.045, 'ask_nicely', 'ask_politely', 'attempt', 'make_effort', 'question_ask']
senticnet['try_again'] = [-0.122, 0, -0.074, 0, '#sad', '#scared', -0.065, 'smoke_cigar', 'cross_bridge', 'hope_peace', 'deal_card', 'sell_car']
senticnet['try_best'] = [-0.078, -0.006, 0, -0.052, '#sad', '#disgusting', -0.041, 'strategize', 'loose', 'win', 'stand_around', 'lose_game']
senticnet['try_calm_down'] = [-0.077, 0, 0.073, -0.262, '#sad', '#disgusting', -0.137, 'find_victim', 'buy_gun', 'buy_weapon', 'plan_attack', 'short_circuit']
senticnet['try_case'] = [0, 0.133, 0, 0.086, '#interesting', '#admirable', 0.073, 'negotiator', 'juror', 'decide_guilt', 'arbiter', 'become_judge']
senticnet['try_clothes'] = [0.999, 0.923, 0, 0, '#joyful', '#interesting', 0.641, 'dress_room', 'fitting_room', 'changing_room', 'jeans', 'clothes_shelf']
senticnet['try_clothes_before_buy'] = [0.151, 0, 0, 0.055, '#joyful', '#admirable', 0.069, 'dry_off_towel', 'lock_front_door', 'dry_towel', 'protect_body', 'put_clothes']
senticnet['try_forget'] = [0.993, 0, 0, 0, '#joyful', '#joyful', 0.331, 'experience_pleasure', 'listen_rock_music', 'trade_stock', 'think_funny', 'experience_joy']
senticnet['try_hard'] = [-0.102, 0, 0.02, 0, '#sad', '#angry', -0.041, 'try_best', 'win', 'strategize', 'get_back', 'loose']
senticnet['try_new'] = [0, 0.069, 0, 0.108, '#interesting', '#admirable', 0.059, 'appreciate', 'curious', 'new_insight', 'desire_travel', 'become_distracted']
senticnet['try_new_clothes'] = [0.707, 0.988, 0, 0, '#joyful', '#interesting', 0.565, 'try_clothes_before_buy', 'lock_front_door', 'dry_off_towel', 'put_clothes', 'dress_occasion']
senticnet['try_on'] = [0.745, -0.713, 0, 0.709, '#joyful', '#surprising', 0.722, 'don', 'put_on', 'wear', 'assume', 'get_into']
senticnet['try_out'] = [0.777, -0.889, 0, 0.79, '#surprising', '#admirable', 0.819, 'verify', 'control', 'float', 'evaluate', 'pass_judgment']
senticnet['try_to_find'] = [0.43, 0.657, -0.285, 0.244, '#joyful', '#interesting', 0.349, 'look_for', 'expectancy', 'amour_propre', 'self-love', 'conceit']
senticnet['try_understand'] = [0, 0.758, 0, 0.78, '#interesting', '#admirable', 0.513, 'take_picture', 'point_out', 'help_another_person', 'complete_sentence', 'read_bible']
senticnet['try_win'] = [0, 0.95, 0, 0, '#interesting', '#interesting', 0.317, 'loose', 'roll_dice', 'win', 'try_hard', 'minor_injury']
senticnet['try_win_game'] = [0.807, 0, 0, 0, '#joyful', '#joyful', 0.269, 'buy_stock', 'play_video_game', 'double_money', 'lose_money', 'desire_win']
senticnet['trying'] = [-0.861, 0, 0.547, -0.671, '#sad', '#disgusting', -0.693, 'dreadful', 'vexing', 'harsh', 'stressful', 'disagreeable']
senticnet['trying_luck'] = [-0.081, 0.179, -0.06, 0.096, '#interesting', '#admirable', 0.045, 'gamble', 'buy_lottery_ticket', 'spend_money', 'hope', 'finger_crossed']
senticnet['tryout'] = [0.615, -0.511, 0, 0.573, '#joyful', '#admirable', 0.566, 'field_trial', 'field_test', 'alpha_test', 'beta_test', 'road_test']
senticnet['tsatske'] = [-0.777, 0, 0.737, -0.563, '#sad', '#angry', -0.692, 'miss', 'girl', 'missy', 'young_lady', 'young_woman']
senticnet['tshatshke'] = [-0.928, 0, 0.994, -0.642, '#sad', '#angry', -0.855, 'miss', 'girl', 'missy', 'young_lady', 'young_woman']
senticnet['tsunami'] = [-0.077, 0, 0.073, -0.262, '#sad', '#disgusting', -0.137, 'disaster', 'catastrophe', 'earthquake', 'hurricane', 'flood']
senticnet['tubal_pregnancy'] = [-0.752, 0, 0.715, -0.725, '#sad', '#disgusting', -0.731, 'abdominal_pregnancy', 'ovarian_pregnancy', 'ectopic_gestation', 'pregnancy', 'gestation']
senticnet['tube'] = [0.05, -0.085, 0, -0.038, '#joyful', '#surprising', 0.032, 'plastic_bag', 'refrigerator', 'storage_furniture', 'water_bottle', 'electric_fan']
senticnet['tubercle_bacillus'] = [-0.908, 0, 0.908, -0.538, '#sad', '#angry', -0.785, 'mycobacteria', 'leprosy_bacillus', 'eubacteria', 'eubacterium', 'true_bacteria']
senticnet['tuberculosis'] = [-0.085, -0.043, 0, -0.128, '#sad', '#disgusting', -0.057, 'wipe_mouth_napkin', 'stomach_full', 'use_fork', 'swallow', 'eat']
senticnet['tubular_cavity'] = [0.718, -0.882, 0, 0.83, '#surprising', '#admirable', 0.81, 'throat', 'pharynx', 'cavity', 'bodily_cavity', 'cavum']
senticnet['tucker_out'] = [0.828, -0.968, 0, 0.555, '#joyful', '#surprising', 0.784, 'wear_upon', 'tire_out', 'outwear', 'fag_out', 'weary']
senticnet['tuft'] = [-0.635, 0, 0.862, -0.523, '#sad', '#angry', -0.673, 'knot', 'swad', 'bunch', 'tussock', 'agglomeration']
senticnet['tufted_centaury'] = [-0.902, 0, 0.726, -0.534, '#sad', '#angry', -0.721, 'broad_leaved_centaury', 'rosita', 'lesser_centaury', 'centaury', 'seaside_centaury']
senticnet['tug'] = [0, 0.179, -0.099, 0.279, '#interesting', '#admirable', 0.12, 'drag', 'go_build', 'enter', 'hang_door', 'enter_area']
senticnet['tuition'] = [-0.077, 0, 0.073, -0.262, '#sad', '#disgusting', -0.137, 'college_tuition', 'private_tuition', 'pay_tuition', 'enroll_class', 'enroll_school']
senticnet['tulip'] = [0, 0.067, 0, 0.05, '#interesting', '#admirable', 0.039, 'bloom', 'daisy', 'clover', 'rose', 'daffodil']
senticnet['tulle'] = [0.735, -0.549, 0, 0.897, '#joyful', '#admirable', 0.727, 'net', 'network', 'mesh', 'meshing', 'meshwork']
senticnet['tumble'] = [-0.502, 0, 0.73, -0.686, '#angry', '#disgusting', -0.639, 'flip', 'acrobatic_stunt', 'acrobatic_feat', 'somersault', 'somerset']
senticnet['tumefy'] = [-0.763, 0, 0.656, -0.726, '#sad', '#disgusting', -0.715, 'belly_out', 'swell_up', 'tumesce', 'intumesce', 'swell']
senticnet['tumesce'] = [-0.63, 0, 0.737, -0.752, '#angry', '#disgusting', -0.706, 'bloat', 'blister', 'vesicate', 'belly', 'belly_out']
senticnet['tummy_tuck'] = [0.96, -0.839, 0, 0.566, '#joyful', '#surprising', 0.788, 'lift', 'phalloplasty', 'abdominoplasty', 'plastic_surgery', 'autoplasty']
senticnet['tumor'] = [-0.913, 0, 0, -0.844, '#sad', '#disgusting', -0.586, 'loss_oflife', 'chest_pain', 'die', 'death', 'end_life']
senticnet['tumult'] = [-0.848, -0.741, -0.948, 0, '#sad', '#scared', -0.352, 'foment', 'agitated', 'agitate', 'stir_up', 'fire_up']
senticnet['tumultuousness'] = [-0.836, 0, 0.703, -0.854, '#sad', '#disgusting', -0.798, 'hurly_burly', 'kerfuffle', 'commotion', 'disruption', 'disturbance']
senticnet['tundra'] = [-0.04, 0, 0, -0.05, '#sad', '#disgusting', -0.03, 'bad_luck', 'damn', 'artic', 'mammal_family', 'bad_mood']
senticnet['tune'] = [0.802, 0, 0, 0, '#joyful', '#joyful', 0.267, 'classical_music', 'melody', 'harmony', 'type_of_music', 'lyric']
senticnet['tune_instrument'] = [-0.045, 0, 0.058, -0.055, '#angry', '#disgusting', -0.053, 'make_a_lot_of_noise', 'sound_alarm', 'strum', 'perform_on_stage', 'pluck_string']
senticnet['tune_up'] = [0.71, -0.577, 0, 0.721, '#joyful', '#admirable', 0.669, 'tweak', 'correct', 'adjust', 'set', 'service']
senticnet['tuner'] = [0.036, -0.04, 0.027, 0.063, '#surprising', '#admirable', 0.037, 'radio', 'speaker', 'channel_selector', 'power_switch', 'female_television_connector']
senticnet['tunnel'] = [-0.045, 0, 0, -0.047, '#sad', '#disgusting', -0.031, 'underground_passage', 'rut', 'cave', 'golf_course', 'room_temperature']
senticnet['tupperware'] = [0.348, 0.23, -0.153, 0.294, '#joyful', '#admirable', 0.24, 'happy_emotion', 'niceness', 'contagious', 'good_emotion', 'savor']
senticnet['turban_squash'] = [-0.562, 0, 0.696, -0.964, '#angry', '#disgusting', -0.741, 'squash', 'acorn_squash', 'hubbard_squash', 'winter_squash', 'butternut_squash']
senticnet['turbine'] = [-0.976, 0, 0.658, -0.606, '#sad', '#angry', -0.747, 'gas_turbine', 'hydroelectric_turbine', 'impulse_turbine', 'reaction_turbine', 'steam_turbine']
senticnet['turbulent'] = [0, 0, -0.727, -0.853, '#scared', '#disgusting', -0.527, 'disruptive', 'troubled', 'tumultuous', 'riotous', 'churning']
senticnet['turd'] = [-0.827, 0, 0.89, -0.764, '#sad', '#angry', -0.827, 'stool', 'dejection', 'fecal_matter', 'shit', 'feces']
senticnet['turf_out'] = [-0.711, 0, 0.954, -0.563, '#sad', '#angry', -0.743, 'eject', 'chuck_out', 'exclude', 'evict', 'boot_out']
senticnet['turgidity'] = [-0.575, 0, 0.767, -0.617, '#angry', '#disgusting', -0.653, 'verboseness', 'verbosity', 'prolixity', 'turgidness', 'flatulence']
senticnet['turgidness'] = [-0.575, 0, 0.767, -0.617, '#angry', '#disgusting', -0.653, 'verboseness', 'verbosity', 'turgidity', 'prolixity', 'flatulence']
senticnet['turkey_oak'] = [0.672, -0.696, 0, 0.831, '#surprising', '#admirable', 0.733, 'southern_red_oak', 'swamp_red_oak', 'red_oak', 'northern_red_oak', 'oak']
senticnet['turmoil'] = [0, 0, 0.846, -0.956, '#angry', '#disgusting', -0.601, 'tumult', 'agitate', 'foment', 'agitated', 'unrest']
senticnet['turn'] = [0.061, 0, 0, 0.174, '#joyful', '#admirable', 0.078, 'twist', 'read_instruction_manual', 'rotate', 'revolve', 'rotation']
senticnet['turn_aircon_on'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'sit_in_shade', 'chill_out', 'enjoy_cold', 'fresh', 'cool']
senticnet['turn_around'] = [0, 0, 0, 0.078, '#admirable', '#admirable', 0.026, 'rotate', 'bend', 'change_direction', 'revolve', 'rotate_movement']
senticnet['turn_away'] = [-0.118, 0.109, -0.117, 0, '#sad', '#scared', -0.042, 'form_sentence', 'eat_animal', 'die_only_once', 'hurt_animal', 'kill_specific_group']
senticnet['turn_back'] = [-0.9, 0, 0.837, -0.809, '#sad', '#angry', -0.849, 'revert', 'return', 'retrovert', 'regress', 'recidivate']
senticnet['turn_blind_eye'] = [-0.58, 0, 0.657, -0.94, '#angry', '#disgusting', -0.726, 'disregard', 'ignore', 'brush_off', 'push_aside', 'dismiss']
senticnet['turn_calculator'] = [-0.048, 0.146, 0.063, 0.126, '#interesting', '#admirable', 0.054, 'learn_add', 'add_number_together', 'learn_math', 'add_two_numbers_together', 'count_number']
senticnet['turn_car'] = [0, 0, 0, 0.177, '#admirable', '#admirable', 0.059, 'car_movement', 'make_go', 'car_bus', 'run_car', 'car_steer']
senticnet['turn_car_off'] = [-0.123, 0, 0, -0.049, '#sad', '#disgusting', -0.057, 'turn_key', 'free_prisoner', 'start_engine', 'open_lock', 'open_car_door']
senticnet['turn_channel'] = [-0.085, -0.019, 0, -0.191, '#sad', '#disgusting', -0.086, 'insert_dvd_in_player', 'watch_commercial', 'read_credit', 'change_channel', 'turn_television']
senticnet['turn_computer_on'] = [0, 0.85, 0, 0.847, '#interesting', '#admirable', 0.566, 'learn_program_language', 'learn_computer_language', 'access_computer', 'write_code', 'a_lot_of_time']
senticnet['turn_down'] = [-0.926, 0, 0, -0.956, '#sad', '#disgusting', -0.627, 'forget_name', 'say_no', 'sexual_attraction', 'rejection', 'tell_others']
senticnet['turn_engine'] = [0, 0.098, 0, 0.107, '#interesting', '#admirable', 0.068, 'check_mirror', 'fasten_seatbelt', 'adjust_seat', 'change_gear', 'put_key_ignition']
senticnet['turn_exam'] = [0.045, 0.081, -0.066, 0.122, '#interesting', '#admirable', 0.061, 'turn', 'land_ground', 'put_liquid', 'exam', 'read_instruction_manual']
senticnet['turn_faucet'] = [0, 0.095, 0, 0.074, '#interesting', '#admirable', 0.056, 'buy_wash_powder', 'water_soap', 'laundry_detergent', 'take_off', 'fill_bathtub_water']
senticnet['turn_head_cough'] = [-0.104, 0, -0.138, -0.136, '#scared', '#disgusting', -0.126, 'make_doctor_appointment', 'call_doctor', 'schedule_appointment_doctor', 'find_doctor', 'make_appointment_with_doctor']
senticnet['turn_heat'] = [0.732, 0.79, 0, 0, '#joyful', '#interesting', 0.507, 'go_pee', 'defecate', 'go_bathroom', 'brush_tooth', 'go_toilet']
senticnet['turn_heating_on'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'warm_up', 'warm_room', 'read_bedtime_story', 'drink_espresso', 'appear_beautiful']
senticnet['turn_ignition'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'use_car', 'start_engine', 'steer_car', 'burn_gasoline', 'put_gear']
senticnet['turn_key'] = [-0.092, 0, 0, 0, '#sad', '#sad', -0.031, 'start_engine', 'open_car_door', 'put_key_ignition', 'turn_car_off', 'free_prisoner']
senticnet['turn_knob'] = [-0.054, 0.081, 0, 0.12, '#interesting', '#admirable', 0.049, 'shut_door', 'switch_button', 'enter_door', 'wave_hello', 'open_mailbox']
senticnet['turn_leave'] = [-0.084, 0.092, -0.073, 0.15, '#interesting', '#admirable', 0.028, 'leave_place', 'push_limit', 'steer_car', 'drive_highway', 'break_down']
senticnet['turn_light'] = [-0.118, -0.003, 0, -0.096, '#sad', '#disgusting', -0.07, 'learn_read', 'look_out_window', 'check_mail', 'page_through_book', 'open_letter']
senticnet['turn_music'] = [0.954, 0, 0, 0.891, '#joyful', '#admirable', 0.615, 'sense_rhythm', 'free_ticket', 'put_music', 'stressful_situation', 'type_of_music']
senticnet['turn_off'] = [-0.049, -0.028, 0.021, -0.17, '#sad', '#disgusting', -0.071, 'drink_soda', 'sleep_through', 'tell_friend', 'laugh_out_loud', 'drink_coke']
senticnet['turn_off_alarm'] = [-0.024, 0.093, -0.068, 0.079, '#interesting', '#admirable', 0.027, 'alarm_clock_ring', 'start_new_day', 'get_out_of_bed', 'work_oneself', 'hard_work']
senticnet['turn_off_alarm_clock'] = [-0.057, -0.043, 0.054, -0.077, '#sad', '#disgusting', -0.048, 'no_effort', 'take_sleep_pill', 'lie_down_close_eye', 'lie_down_bed', 'count_sheep']
senticnet['turn_off_computer'] = [-0.026, -0.025, 0.069, -0.086, '#angry', '#disgusting', -0.052, 'wind_down', 'miss_appointment', 'sit_rock_chair', 'breadeeply', 'lie_around']
senticnet['turn_off_engine'] = [-0.107, -0.025, 0.013, -0.156, '#sad', '#disgusting', -0.084, 'check_oneself_mirror', 'look_out_window', 'stop_bleed', 'drink_soda', 'turn_off']
senticnet['turn_off_light'] = [-0.027, -0.012, 0.019, -0.064, '#sad', '#disgusting', -0.033, 'take_off_glass', 'put_pyjamas', 'wear_pyjamas', 'close_eye', 'lay_down']
senticnet['turn_off_television'] = [0.89, 0.758, 0, 0, '#joyful', '#interesting', 0.549, 'fall_asleep', 'doze_off', 'go_to_bed', 'bed_time', 'drowsiness']
senticnet['turn_off_tv'] = [-0.094, 0, 0, -0.068, '#sad', '#disgusting', -0.054, 'turn_light', 'look_out_window', 'turn_off_television', 'take_off_glass', 'close_eye']
senticnet['turn_on'] = [-0.939, 0, 0.595, -0.835, '#sad', '#disgusting', -0.79, 'ride', 'owe', 'depend_on', 'depend_upon', 'build_on']
senticnet['turn_on_air_conditioner'] = [0.899, 0.726, 0, 0, '#joyful', '#interesting', 0.542, 'air', 'fresh_air', 'turn_on_fan', 'enjoy_fresh_air', 'cool_air']
senticnet['turn_on_dvd_player'] = [-0.086, -0.061, 0.043, -0.185, '#sad', '#disgusting', -0.084, 'press_play', 'insert_dvd_in_player', 'turn_channel', 'buy_popcorn', 'turn_television']
senticnet['turn_on_fan'] = [0.899, 0.726, 0, 0, '#joyful', '#interesting', 0.542, 'air', 'fresh_air', 'enjoy_fresh_air', 'turn_on_air_conditioner', 'cool_air']
senticnet['turn_on_radio'] = [0, 0.946, 0, 0.766, '#interesting', '#admirable', 0.571, 'listen_cd', 'play_cd', 'play_music', 'play_tune', 'music_album']
senticnet['turn_on_torch'] = [0.937, 0, 0, 0.828, '#joyful', '#admirable', 0.588, 'switch_on_light', 'light_candle', 'light_match', 'create_light', 'create_flame']
senticnet['turn_on_tv'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'wear_glass', 'near_tv', 'open_eye', 'ability_see', 'eyesight']
senticnet['turn_out_light'] = [-0.983, 0, 0, 0, '#sad', '#sad', -0.328, 'put_pyjamas', 'count_sheep', 'go_room', 'sleepwalk', 'call_sick']
senticnet['turn_page'] = [-0.106, -0.052, 0.038, -0.242, '#sad', '#disgusting', -0.111, 'move_eye', 'eye', 'use_dictionary', 'learn_much', 'eye_strain']
senticnet['turn_profit'] = [0.96, -0.786, 0, 0.583, '#joyful', '#surprising', 0.776, 'clear', 'make', 'realize', 'gain', 'take_in']
senticnet['turn_radio'] = [0.931, 0.739, 0, 0, '#joyful', '#interesting', 0.557, 'go_rock_concert', 'attend_concert', 'sensibility', 'audible', 'able_hear']
senticnet['turn_screw'] = [-0.083, -0.06, 0.024, -0.177, '#sad', '#disgusting', -0.075, 'use_knife', 'wound', 'lacerate', 'cut_tool', 'cut_food']
senticnet['turn_steer_wheel'] = [-0.073, -0.034, 0.01, -0.134, '#sad', '#disgusting', -0.061, 'honk_horn', 'discover_new_place', 'stop_red_light', 'shift_gear', 'stop_stop_sign']
senticnet['turn_stereo'] = [0, 0, 0, -0.072, '#disgusting', '#disgusting', -0.024, 'go_movie', 'watch_musician_perform', 'go_concert', 'go_opus', 'attend_opus']
senticnet['turn_stomach'] = [-0.062, 0.128, 0.707, -0.677, '#angry', '#disgusting', -0.439, 'sickish', 'vile', 'sickening', 'noisome', 'nauseous']
senticnet['turn_television'] = [0.787, -0.55, 0, 0.784, '#joyful', '#admirable', 0.707, 'find_tv_set', 'find_tv', 'switch_tv', 'near_tv', 'buy_tv']
senticnet['turn_television_set'] = [0, 0.108, 0, 0.202, '#interesting', '#admirable', 0.103, 'source_electricity', 'read_instruction_manual', 'switch', 'find_tape', 'recording']
senticnet['turn_tv'] = [0, 0, -0.059, -0.044, '#scared', '#disgusting', -0.034, 'turn_television', 'switch_television', 'turn_television_set', 'switch_tv', 'find_tv']
senticnet['turn_tv_set'] = [-0.049, 0, 0, -0.035, '#sad', '#disgusting', -0.028, 'turn_television', 'near_tv', 'switch_tv', 'turn_television_set', 'turn_on_tv']
senticnet['turn_up_heat'] = [0.951, -0.98, 0, 0.789, '#joyful', '#surprising', 0.907, 'coerce', 'hale', 'pressure', 'force', 'squeeze']
senticnet['turn_up_pressure'] = [0.564, -0.52, 0, 0.648, '#joyful', '#admirable', 0.577, 'coerce', 'hale', 'pressure', 'force', 'squeeze']
senticnet['turn_water'] = [-0.074, 0, 0.026, 0, '#sad', '#angry', -0.033, 'soap_up', 'dispense_water', 'fill_bathtub', 'run_bath', 'launder']
senticnet['turned'] = [-0.652, 0, 0.935, -0.846, '#angry', '#disgusting', -0.811, 'upset', 'inverted', 'overturned', 'upturned', 'reversed']
senticnet['turning_away'] = [0.916, -0.929, 0, 0.502, '#joyful', '#surprising', 0.782, 'rejection', 'escape', 'near_thing', 'aversion', 'averting']
senticnet['turnip'] = [0.065, 0, 0.011, 0.051, '#joyful', '#admirable', 0.035, 'fruit_vegetable', 'fruit', 'fresh_fruit', 'fresh_vegetable', 'radish']
senticnet['turquoise'] = [-0.065, 0, 0.011, 0, '#sad', '#angry', -0.025, 'sapphire', 'birth_stone', 'amethyst', 'gemstone', 'precious_stone']
senticnet['tussock'] = [-0.635, 0, 0.862, -0.523, '#sad', '#angry', -0.673, 'knot', 'swad', 'tuft', 'bunch', 'agglomeration']
senticnet['tv_channel'] = [0, 0.142, -0.049, 0.116, '#interesting', '#admirable', 0.07, 'scientific', 'criterion', 'method', 'subject', 'hypothesis']
senticnet['tv_drama'] = [0.078, 0, 0, 0.06, '#joyful', '#admirable', 0.046, 'clean_agent', 'cleanser', 'hand_wash', 'use_clean', 'clean_product']
senticnet['tv_program'] = [0, 0.855, 0, 0.819, '#interesting', '#admirable', 0.558, 'cnn', 'weather_prediction', 'daily', 'journalism', 'journalist']
senticnet['tv_series'] = [-0.269, 0.166, -0.331, 0.171, '#sad', '#scared', -0.088, 'misplace', 'rid', 'tv_show', 'circus_performer', 'against_law']
senticnet['tv_set'] = [0.09, -0.032, 0.015, 0, '#joyful', '#surprising', 0.036, 'tape_player', 'light_fixture', 'dvd_player', 'sit_at_theater', 'technician']
senticnet['tv_show'] = [-0.09, 0.166, -0.146, 0.198, '#interesting', '#admirable', 0.043, 'presentation', 'tv_series', 'circus_performer', 'cant', 'movie_star']
senticnet['tv_station'] = [-0.09, 0.166, -0.146, 0.198, '#interesting', '#admirable', 0.043, 'television_station', 'tv_studio', 'watch_tv', 'radio_station', 'television_channel']
senticnet['tv_studio'] = [0, 0.07, 0, 0.071, '#interesting', '#admirable', 0.047, 'theater', 'cinema', 'opus', 'film_studio', 'opus_house']
senticnet['twang'] = [-0.719, 0, 0.998, -0.647, '#sad', '#angry', -0.788, 'tone', 'quality', 'nasality', 'nasal_nasality', 'timber']
senticnet['twat'] = [-0.723, 0, 0.728, -0.689, '#sad', '#angry', -0.713, 'sap', 'fool', 'saphead', 'muggins', 'tomfool']
senticnet['tweediness'] = [-0.9, 0, 0.841, -0.731, '#sad', '#angry', -0.824, 'nubbiness', 'raggedness', 'harshness', 'graininess', 'granularity']
senticnet['tweezer'] = [0.817, 0.949, 0, 0, '#joyful', '#interesting', 0.589, 'chisel', 'power_drill', 'razor_blade', 'knife', 'vise']
senticnet['twelve'] = [0, -0.003, 0.063, -0.037, '#angry', '#disgusting', -0.032, 'thirty', 'hundred_year', 'dozen', 'day_month', 'time_measurement']
senticnet['twelve_inch'] = [0.847, 0.937, 0, 0, '#joyful', '#interesting', 0.595, 'sole', 'type_of_shoes', 'foot', 'foot_part', 'heel']
senticnet['twelve_months'] = [0, 0, 0, 0.7, '#admirable', '#admirable', 0.233, 'yearly_celebration', 'year', 'annual', 'age', 'centennial']
senticnet['twentieth_century'] = [0.978, -0.601, 0, 0.895, '#joyful', '#admirable', 0.825, 'period', 'quattrocento', 'century', 'time_period', 'period_of_time']
senticnet['twice'] = [0, 0.144, 0.046, 0.239, '#interesting', '#admirable', 0.112, 'one_more', 'enumeration', 'numerical', 'plus', 'repeat']
senticnet['twiddle_thumb'] = [0.923, 0.972, 0, 0, '#joyful', '#interesting', 0.632, 'learn_patience', 'collect_data', 'wait_patiently', 'take_number', 'wait_service']
senticnet['twig'] = [0.986, 0.901, 0, 0, '#joyful', '#interesting', 0.629, 'tree_limb', 'tree_part', 'tree_arm', 'part_of_tree', 'tree_branch']
senticnet['twilight'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'dusk', 'nightfall', 'sundown', 'sunset', 'day_end']
senticnet['twilight_zone'] = [0.979, -0.75, 0, 0.764, '#joyful', '#admirable', 0.831, 'ocean_floor', 'sea_floor', 'ocean_bottom', 'seabed', 'sea_bottom']
senticnet['twin'] = [0, 0.142, 0.057, 0.168, '#interesting', '#admirable', 0.084, 'duplicate', 'twice', 'multiply', 'two_halves', 'equal']
senticnet['twirl'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'turn_around', 'float_through_air', 'pull_car', 'revolve', 'spring_up']
senticnet['twirl_around'] = [0.075, 0, 0, 0.158, '#joyful', '#admirable', 0.078, 'sway', 'swirl', 'body_movement', 'move_around', 'dance_move']
senticnet['twirler'] = [-0.922, 0, 0.767, -0.85, '#sad', '#disgusting', -0.846, 'closer', 'finisher', 'pitcher', 'hurler', 'relief_pitcher']
senticnet['twist'] = [0.06, 0, 0, 0.182, '#joyful', '#admirable', 0.081, 'turn', 'wrap_around', 'revolve', 'salsa', 'rotation']
senticnet['twist_ankle'] = [0, 0, -0.947, -0.858, '#scared', '#disgusting', -0.602, 'trip_fall', 'out_breath', 'blister_foot', 'breahard', 'tire']
senticnet['twister'] = [-0.039, 0, 0, -0.125, '#sad', '#disgusting', -0.055, 'abrasion', 'wind', 'welt', 'gash', 'cut_skin']
senticnet['twit'] = [-0.555, 0, 0.947, -0.775, '#angry', '#disgusting', -0.759, 'blackguard', 'deride', 'bemock', 'tease', 'razz']
senticnet['twitch'] = [-0.691, 0, 0.849, -0.717, '#angry', '#disgusting', -0.752, 'muscle_spasm', 'spasm', 'cramp', 'tic', 'blepharism']
senticnet['twitching'] = [-0.658, 0, 0.713, -0.665, '#angry', '#disgusting', -0.679, 'muscle_spasm', 'spasm', 'cramp', 'tic', 'blepharism']
senticnet['two-dimensional'] = [-0.025, 0.091, 0, 0.152, '#interesting', '#admirable', 0.073, 'latex', 'wall_cover', 'dimensional', 'thick_liquid', 'cover_wall']
senticnet['two_arms'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'two_ears', 'two_eyes', 'adam_apple', 'hormone', 'liver']
senticnet['two_children'] = [0.029, 0.076, 0, 0, '#joyful', '#interesting', 0.035, 'youngster', 'adolescent', 'grandchild', 'lad', 'children']
senticnet['two_ears'] = [0.902, 0.772, 0, 0, '#joyful', '#interesting', 0.558, 'body', 'abdomen', 'dog_pet', 'living_thing', 'fur']
senticnet['two_eyes'] = [0, -0.011, 0.044, -0.069, '#angry', '#disgusting', -0.034, 'no_hair', 'hair', 'fur_keep_warm', 'hold_hair', 'facial_hair']
senticnet['two_feet'] = [-0.04, 0, 0.059, 0, '#sad', '#angry', -0.033, 'human_limb', 'lower_body', 'thigh', 'ten_toes', 'body_limb']
senticnet['two_halves'] = [-0.028, 0.103, 0.069, 0.151, '#interesting', '#admirable', 0.052, 'single', 'unit_of_measurement', 'do_it_yourself', 'enumeration', 'alone']
senticnet['two_hands'] = [0.754, 0.903, 0, 0, '#joyful', '#interesting', 0.552, 'hand', 'five_fingers', 'forearm', 'ten_fingers', 'wrist']
senticnet['two_horses'] = [0, 0, 0, 0.071, '#admirable', '#admirable', 0.024, 'barb', 'horse', 'mule', 'buddhist', 'ride_horse']
senticnet['two_lines'] = [0.065, 0.239, 0.06, 0.177, '#interesting', '#admirable', 0.14, 'religious_icon', 'line', 'wood_structure', 'two_parts', 'crucifix']
senticnet['two_parts'] = [0.813, 0.957, 0, 0, '#joyful', '#interesting', 0.59, 'double', 'single', 'two_lines', 'split', 'enumeration']
senticnet['two_people'] = [0.164, 0.145, -0.105, 0.188, '#joyful', '#admirable', 0.131, 'man_and_woman', 'partner', 'group_of_people', 'husband_wife', 'sing_microphone']
senticnet['two_sides'] = [0, 0.072, 0.068, 0.074, '#interesting', '#admirable', 0.026, 'part_of_book', 'book_part', 'both_sides', 'book_content', 'book_paper']
senticnet['two_syllables'] = [0.03, 0.113, 0.073, 0.131, '#interesting', '#admirable', 0.067, 'advance_career', 'two_together', 'root_evil', 'monetary_unit', 'sum_total']
senticnet['two_together'] = [0.024, 0.124, 0.015, 0.229, '#interesting', '#admirable', 0.121, 'two_syllables', 'slogan', 'consistency', 'bottom_line', 'together']
senticnet['two_wheels'] = [0.041, -0.087, 0, 0.056, '#surprising', '#admirable', 0.061, 'engine', 'wheel', 'motor', 'steer_wheel', 'axle']
senticnet['type_of_animal'] = [0, -0.101, 0, 0, '#surprising', '#surprising', 0.034, 'mammal', 'baby_deer', 'animal', 'sea_mammal', 'water_mammal']
senticnet['type_of_architecture'] = [0.578, -0.957, 0, 0.979, '#surprising', '#admirable', 0.838, 'perpendicular', 'perpendicular_style', 'architectural_style', 'style_of_architecture', 'gothic_architecture']
senticnet['type_of_art'] = [0, 0.112, -0.047, 0.163, '#interesting', '#admirable', 0.076, 'wall_decoration', 'two-dimensional', 'artwork', 'cover_wall', 'image']
senticnet['type_of_bear'] = [0, 0.932, 0, 0.794, '#interesting', '#admirable', 0.575, 'look_after', 'care', 'kindness', 'want_badly', 'yearn']
senticnet['type_of_bow'] = [0.033, 0, 0.009, 0.057, '#joyful', '#admirable', 0.027, 'triangle', 'baton', 'bugle', 'clavichord', 'horn']
senticnet['type_of_bread'] = [-0.026, 0.086, 0.026, 0.157, '#interesting', '#admirable', 0.064, 'rye', 'wheat', 'corn', 'grain', 'sushi']
senticnet['type_of_car'] = [0, 0.281, 0, 0.206, '#interesting', '#admirable', 0.162, 'plane', 'airplane', 'back_airplane', 'bus', 'airliner']
senticnet['type_of_cloth'] = [0.085, 0, 0.035, 0.147, '#joyful', '#admirable', 0.066, 'soft', 'material_type', 'fabric_type', 'biodegradable', 'cloth_fabric']
senticnet['type_of_container'] = [0.031, 0.089, 0, 0.116, '#interesting', '#admirable', 0.079, 'storage_container', 'drink_container', 'drink_holder', 'metal_cylinder', 'cylinder']
senticnet['type_of_credit_card'] = [0.758, 0.769, 0, 0, '#joyful', '#interesting', 0.509, 'look_scary', 'make_assumption', 'travel_fast_light', 'sing_well', 'endanger']
senticnet['type_of_criminal'] = [0, 0.812, 0, 0.775, '#interesting', '#admirable', 0.529, 'policeman', 'police', 'authority', 'officer', 'rogue']
senticnet['type_of_document'] = [0, 0.723, 0, 0.824, '#interesting', '#admirable', 0.516, 'create_document', 'write_text', 'enter_data', 'type', 'send_email']
senticnet['type_of_dog'] = [0, 0, -0.807, -0.882, '#scared', '#disgusting', -0.563, 'future_robot', 'drive_recklessly', 'dog', 'dangerous', 'drive']
senticnet['type_of_engine'] = [0.039, 0, 0, 0.052, '#joyful', '#admirable', 0.03, 'hot_air', 'liquid_gas', 'fire_hazard', 'warm_air', 'fire_starter']
senticnet['type_of_food'] = [0.052, 0, 0.035, 0.065, '#joyful', '#admirable', 0.027, 'food_item', 'morning_food', 'yummy', 'sweet_treat', 'eatable']
senticnet['type_of_fruit'] = [0, 0.745, 0, 0.702, '#interesting', '#admirable', 0.482, 'cobol', 'woodworking_tool', 'helpful', 'helpful_tool', 'hand_tool']
senticnet['type_of_game'] = [0, -0.064, 0, 0.122, '#surprising', '#admirable', 0.062, 'violent_sport', 'type_of_sport', 'rough_sport', 'rough_game', 'game_skill']
senticnet['type_of_government'] = [0.075, 0.166, -0.078, 0.138, '#interesting', '#admirable', 0.1, 'form_government', 'political_system', 'united_country', 'democracy', 'unite']
senticnet['type_of_gun'] = [0.791, 0.911, 0, 0, '#joyful', '#interesting', 0.567, 'gun', 'rifle', 'revolver', 'pistol', 'firearm']
senticnet['type_of_keyboard'] = [0, 0.951, 0, 0, '#interesting', '#interesting', 0.317, 'enter_data_computer', 'train_open_mind', 'write_computer_program', 'move_mouse', 'add_number']
senticnet['type_of_letter'] = [-0.071, 0, 0.031, 0, '#sad', '#angry', -0.034, 'write_novel', 'enter_data_computer', 'wedge_door_open', 'draw_picture', 'fill_out_form']
senticnet['type_of_machine'] = [0, 0.098, 0, 0.107, '#interesting', '#admirable', 0.068, 'power_drill', 'air_pump', 'drill_bite', 'adjustable_wrench', 'drill']
senticnet['type_of_material'] = [0, 0.711, 0, 0.979, '#interesting', '#admirable', 0.563, 'material_type', 'soft_white', 'fabric_type', 'cloth_material', 'cloth_fabric']
senticnet['type_of_metal'] = [0, 0.755, 0, 0.808, '#interesting', '#admirable', 0.521, 'use_jewelry', 'magnetic', 'shinny', 'hard_plastic', 'both_functional_decorative']
senticnet['type_of_music'] = [0.802, 0, 0, 0, '#joyful', '#joyful', 0.267, 'tune', 'melody', 'harmony', 'classical_music', 'lyric']
senticnet['type_of_paper'] = [0, 0.955, 0, 0.85, '#interesting', '#admirable', 0.602, 'grade_paper', 'use_ink', 'pencil_mark', 'make_newspaper', 'readable']
senticnet['type_of_party'] = [0.856, 0.813, 0, 0, '#joyful', '#interesting', 0.556, 'special_time', 'special_moment', 'special_happen', 'special_event', 'celebration']
senticnet['type_of_shoes'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'shoe_type', 'foot_part', 'sole', 'heel', 'foot']
senticnet['type_of_sport'] = [0, -0.081, 0, 0.09, '#surprising', '#admirable', 0.057, 'rough_sport', 'violent_sport', 'rough_game', 'ball_sport', 'team_sport']
senticnet['type_of_store'] = [0, 0, 0.069, 0, '#angry', '#angry', -0.023, 'many_shops', 'many_stores', 'corner_store', 'item_sell', 'bazaar']
senticnet['type_of_valley'] = [0.823, 0.857, 0, 0, '#joyful', '#interesting', 0.56, 'hot', 'suppose_impartial', 'opposite_cold', 'heat', 'warm']
senticnet['type_url'] = [0, 0.201, 0.018, 0.077, '#interesting', '#admirable', 0.087, 'connect_internet', 'boot_up_computer', 'go_online', 'buy_computer', 'find_address']
senticnet['typeface'] = [0, 0, -0.074, 0, '#scared', '#scared', -0.025, 'dissertation', 'print_word', 'grammatical_term', 'hold_information', 'continue_story']
senticnet['typewriter'] = [0, 0, 0.128, 0, '#angry', '#angry', -0.043, 'grid', 'efficient', 'calculator', 'computer', 'personal_computer']
senticnet['typewriter_font'] = [-0.931, 0, 0.845, -0.867, '#sad', '#disgusting', -0.881, 'face', 'font', 'fount', 'typeface', 'case']
senticnet['typewriter_key'] = [0, -0.026, 0, 0.056, '#surprising', '#admirable', 0.027, 'typewriter_keyboard', 'grasper', 'tong', 'c_clamp', 'utility_case']
senticnet['typewriter_keyboard'] = [0, -0.026, 0, 0.056, '#surprising', '#admirable', 0.027, 'typewriter_key', 'grasper', 'tong', 'c_clamp', 'utility_case']
senticnet['typewriter_ribbon'] = [0.756, 0.886, 0, 0, '#joyful', '#interesting', 0.547, 'remote_control', 'air_pump', 'safety_pin', 'slinky', 'chatter_tooth']
senticnet['typhus'] = [0.579, -0.81, 0, 0.833, '#surprising', '#admirable', 0.741, 'murine_typhus', 'rat_typhus', 'urban_typhus', 'endemic_typhus', 'rickettsial_disease']
senticnet['typhus_fever'] = [0.709, -0.675, 0, 0.969, '#joyful', '#admirable', 0.784, 'murine_typhus', 'rat_typhus', 'urban_typhus', 'endemic_typhus', 'rickettsial_disease']
senticnet['typical'] = [0, 0.193, 0, 0.194, '#interesting', '#admirable', 0.129, 'usual_ordinary', 'normal', 'usual', 'frequent', 'sameness']
senticnet['typically'] = [0, 0.131, 0, 0, '#interesting', '#interesting', 0.044, 'money_clip', 'keep_fresh', 'secure', 'broth', 'metal_box']
senticnet['tyrannical'] = [-0.834, 0.214, -0.391, -0.108, '#sad', '#scared', -0.373, 'oppressiveness', 'downtrodden', 'oppressive', 'tyrannous', 'laden']
senticnet['tyrannous'] = [-0.834, 0.214, -0.391, -0.108, '#sad', '#scared', -0.373, 'oppressiveness', 'tyrannical', 'downtrodden', 'oppressive', 'laden']
senticnet['tyranny'] = [-0.856, 0, 0.75, -0.953, '#sad', '#disgusting', -0.853, 'reign', 'legislation', 'rebel', 'legislature', 'decree']
senticnet['tyrant'] = [0, 0, 0.97, 0, '#angry', '#angry', -0.323, 'dictator', 'despot', 'administration', 'measure_inch', 'ruler']
senticnet['tyro'] = [-0.954, 0, 0.735, -0.842, '#sad', '#disgusting', -0.844, 'novice', 'beginner', 'cub', 'tiro', 'initiate']
senticnet['udder'] = [0, 0, 0, 0.085, '#admirable', '#admirable', 0.028, 'moo', 'baby_cow', 'bovine', 'hoof_animal', 'male_cow']
senticnet['ufo'] = [0.863, 0.965, 0, 0, '#joyful', '#interesting', 0.609, 'martian', 'milky', 'space_junk', 'galaxy', 'solar_system']
senticnet['ugliness'] = [-0.874, 0, 0.584, -0.711, '#sad', '#disgusting', -0.723, 'unsightliness', 'eyesore', 'hideousness', 'unattractiveness', 'garishness']
senticnet['ugly'] = [-0.964, 0, 0, -0.778, '#sad', '#disgusting', -0.581, 'dreadful', 'terrible', 'fearful', 'scary', 'humiliate']
senticnet['ugly_duckling'] = [0.866, -0.795, 0, 0.894, '#joyful', '#admirable', 0.852, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['ulcer'] = [-0.718, 0, -0.742, 0, '#sad', '#scared', -0.487, 'pain', 'gape', 'sunburn', 'ouch', 'cut_skin']
senticnet['ulcer_diet'] = [-0.637, 0, 0.819, -0.997, '#angry', '#disgusting', -0.818, 'light_diet', 'soft_diet', 'spoon_food', 'bland_diet', 'diet']
senticnet['ulcerative_colitis'] = [-0.755, 0, 0.868, -0.992, '#angry', '#disgusting', -0.872, 'regional_enteritis', 'regional_ileitis', 'colitis', 'rubor', 'redness']
senticnet['ultimate'] = [0.106, 0.162, 0.037, 0.32, '#interesting', '#admirable', 0.184, 'superlative', 'best', 'mass_measure', 'a_lot', 'plenty']
senticnet['ultraviolet'] = [0, -0.016, -0.078, -0.064, '#scared', '#disgusting', -0.042, 'sun', 'lantern', 'illumination', 'light', 'ray']
senticnet['ululate'] = [-0.502, 0, 0.611, -0.752, '#angry', '#disgusting', -0.622, 'howl', 'wail', 'waul', 'roar', 'yawl']
senticnet['umbrage'] = [-0.14, 0.148, 0.62, -0.636, '#angry', '#disgusting', -0.416, 'offense', 'incensed', 'indignant', 'umbrageous', 'outraged']
senticnet['umbrageous'] = [-0.139, 0.146, 0.623, -0.637, '#angry', '#disgusting', -0.418, 'outraged', 'incensed', 'indignant', 'outrage', 'indignation']
senticnet['umbrella'] = [0.106, 0.162, 0.037, 0.32, '#interesting', '#admirable', 0.184, 'block_sun', 'waterproof_jacket', 'waterproof_boot', 'rain_equipment', 'block_rain']
senticnet['unable'] = [-0.808, 0, -0.803, -0.961, '#sad', '#disgusting', -0.857, 'impossible', 'absurd', 'difficult', 'impratical', 'unimaginable']
senticnet['unaccented'] = [-0.9, 0, 0.972, -0.794, '#sad', '#angry', -0.889, 'feminine', 'weak', 'light', 'unemphatic', 'unstressed']
senticnet['unacceptable'] = [-0.889, 0, 0.907, -0.847, '#sad', '#angry', -0.881, 'unsupportable', 'intolerable', 'bitter', 'impossible', 'insufferable']
senticnet['unaccessible'] = [0.743, -0.668, 0, 0.535, '#joyful', '#surprising', 0.649, 'outback', 'trackless', 'pathless', 'roadless', 'untracked']
senticnet['unaccompanied'] = [-0.877, 0, 0.773, -0.806, '#sad', '#disgusting', -0.819, 'isolated', 'lonely', 'unattended', 'solitary', 'alone']
senticnet['unaccountable'] = [-0.624, 0, 0.825, -0.738, '#angry', '#disgusting', -0.729, 'unexplainable', 'incomprehensible', 'unexplained', 'inscrutable', 'mystifying']
senticnet['unaccustomed'] = [-0.221, -0.206, 0.134, -0.329, '#sad', '#disgusting', -0.159, 'uncommon', 'strange', 'unpleasant', 'unfamiliar', 'unusual']
senticnet['unacknowledged'] = [-0.751, 0, 0.563, -0.986, '#sad', '#disgusting', -0.767, 'unsung', 'unrecognized', 'unappreciated', 'unvalued', 'unconfessed']
senticnet['unacquainted'] = [-0.509, 0, 0.737, -0.552, '#angry', '#disgusting', -0.599, 'unfamiliar_with', 'stranger', 'unknown', 'unfamiliar', 'strange']
senticnet['unacquainted_with'] = [-0.509, 0, 0.737, -0.552, '#angry', '#disgusting', -0.599, 'unfamiliar', 'unfamiliar_with', 'unknown', 'unacquainted', 'strange']
senticnet['unadaptability'] = [-0.701, 0, 0.914, -0.727, '#angry', '#disgusting', -0.781, 'inflexibility', 'rigidity', 'rigidness', 'unfitness', 'inability']
senticnet['unadorned'] = [-0.752, 0, 0.869, -0.737, '#sad', '#angry', -0.786, 'spare', 'unembellished', 'unornamented', 'bare', 'plain']
senticnet['unadulterated'] = [-0.657, 0, 0.799, -0.751, '#angry', '#disgusting', -0.736, 'undiminished', 'unrelieved', 'everlasting', 'unmitigated', 'bloody']
senticnet['unaerated'] = [-0.586, 0, 0.593, -0.979, '#angry', '#disgusting', -0.719, 'unvented', 'fuggy', 'unventilated', 'unoxygenated', 'stuffy']
senticnet['unaesthetic'] = [0.036, 0, 0.094, -0.055, '#angry', '#disgusting', -0.038, 'facial_hair', 'need_shave', 'need_beauty_center', 'long_beard', 'carelessness']
senticnet['unaffected'] = [0.808, 0, 0, 0.702, '#joyful', '#admirable', 0.503, 'untouched', 'uninfluenced', 'unswayed', 'immune', 'ingenuous']
senticnet['unaffectionate'] = [-0.565, 0, 0.578, -0.744, '#angry', '#disgusting', -0.629, 'cold', 'frigid', 'loveless', 'detached', 'unloving']
senticnet['unaffordable'] = [-0.785, 0, -0.945, 0, '#sad', '#scared', -0.577, 'high_cost', 'spend_money', 'waste_money', 'high_price', 'expensive']
senticnet['unafraid'] = [0.481, 0.663, -0.252, 0.24, '#joyful', '#interesting', 0.377, 'intrepidly', 'hardy', 'fearlessness', 'fearlessly', 'unfearing']
senticnet['unagitated'] = [0.546, 0.656, -0.248, 0.261, '#joyful', '#interesting', 0.405, 'tranquil', 'placidly', 'unruffled', 'placidity', 'placidness']
senticnet['unalienable'] = [-0.548, 0, 0.812, -0.865, '#angry', '#disgusting', -0.742, 'infrangible', 'nontransferable', 'unassignable', 'untransferable', 'inviolable']
senticnet['unalterability'] = [-0.834, 0, 0.696, -0.989, '#sad', '#disgusting', -0.84, 'immutability', 'agelessness', 'changelessness', 'unchangeability', 'unchangeableness']
senticnet['unalterable'] = [-0.905, 0, 0.653, -0.998, '#sad', '#disgusting', -0.852, 'unchangeable', 'static', 'changeless', 'confirmed', 'fixed']
senticnet['unambiguity'] = [0.777, -0.681, 0, 0.601, '#joyful', '#surprising', 0.686, 'lucidness', 'clarity', 'clearness', 'lucidity', 'pellucidity']
senticnet['unanswerable'] = [-0.633, 0, 0.745, -0.527, '#sad', '#angry', -0.635, 'watertight', 'incontrovertible', 'incontestable', 'bulletproof', 'unassailable']
senticnet['unappreciated'] = [-0.751, 0, 0.563, -0.986, '#sad', '#disgusting', -0.767, 'unsung', 'unrecognized', 'unacknowledged', 'unvalued', 'unconfessed']
senticnet['unarmed'] = [-0.574, 0, 0.654, -0.986, '#angry', '#disgusting', -0.738, 'defenseless', 'defenceless', 'barehanded', 'clean', 'weaponless']
senticnet['unarticulate'] = [-0.668, 0, 0.989, -0.686, '#angry', '#disgusting', -0.781, 'aphasic', 'aphonic', 'speechless', 'unarticulated', 'dumb']
senticnet['unarticulated'] = [-0.567, 0, 0.509, -0.832, '#sad', '#disgusting', -0.636, 'aphasic', 'aphonic', 'speechless', 'inarticulate', 'dumb']
senticnet['unassailable'] = [0.893, 0.908, 0, 0, '#joyful', '#interesting', 0.6, 'incontrovertible', 'bulletproof', 'incontestable', 'armored', 'unshakable']
senticnet['unassertive'] = [0.743, 0.891, 0, 0, '#joyful', '#interesting', 0.545, 'unassertively', 'unassertiveness', 'hesitantly', 'hesitatingly', 'hesitancy']
senticnet['unassertively'] = [0.883, 0.973, 0, 0, '#joyful', '#interesting', 0.619, 'unassertiveness', 'unassertive', 'hesitantly', 'hesitatingly', 'hesitancy']
senticnet['unassertiveness'] = [0.816, 0.792, 0, 0, '#joyful', '#interesting', 0.536, 'unassertively', 'unassertive', 'hesitantly', 'hesitatingly', 'hesitancy']
senticnet['unassignable'] = [-0.805, 0, 0.815, -0.984, '#angry', '#disgusting', -0.868, 'infrangible', 'nontransferable', 'inalienable', 'untransferable', 'inviolable']
senticnet['unattached'] = [-0.653, 0, 0.944, -0.87, '#angry', '#disgusting', -0.822, 'asternal', 'isolated', 'separate', 'unconnected', 'separated']
senticnet['unattainableness'] = [-0.661, 0, 0.984, -0.554, '#sad', '#angry', -0.733, 'inconceivability', 'inconceivableness', 'nonexistence', 'nonentity', 'impossibility']
senticnet['unattended'] = [-0.877, 0, 0.773, -0.806, '#sad', '#disgusting', -0.819, 'isolated', 'lonely', 'unaccompanied', 'solitary', 'alone']
senticnet['unattractive'] = [0, 0, 0, -0.705, '#disgusting', '#disgusting', -0.235, 'leave_out', 'loathing', 'cause_suffer', 'lose_team', 'disrespect']
senticnet['unattractiveness'] = [-0.874, 0, 0.584, -0.711, '#sad', '#disgusting', -0.723, 'unsightliness', 'eyesore', 'hideousness', 'ugliness', 'garishness']
senticnet['unauthorized'] = [-0.904, 0, 0.569, -0.967, '#sad', '#disgusting', -0.813, 'unofficial', 'wildcat', 'informal', 'loose', 'drumhead']
senticnet['unavailable'] = [-0.777, 0, 0.644, -0.687, '#sad', '#disgusting', -0.703, 'unobtainable', 'unprocurable', 'out_of_stock', 'gone', 'untouchable']
senticnet['unavoidability'] = [-0.91, 0, 0.795, -0.94, '#sad', '#disgusting', -0.882, 'ineluctability', 'sure_thing', 'predictability', 'slam_dunk', 'inevitability']
senticnet['unbalance'] = [-0.045, 0, -0.163, -0.123, '#scared', '#disgusting', -0.11, 'uncommon', 'good', 'like_candy', 'make_fruit', 'niceness']
senticnet['unbalanced'] = [-0.868, 0, 0.63, -0.697, '#sad', '#disgusting', -0.732, 'unequalized', 'mismatched', 'nonequivalent', 'uneven', 'unequal']
senticnet['unbarred'] = [-0.759, 0, 0.892, -0.684, '#sad', '#angry', -0.778, 'unfastened', 'unbolted', 'unlatched', 'unlocked', 'unsecured']
senticnet['unbearable'] = [-0.177, 0.079, -0.18, 0, '#sad', '#scared', -0.093, 'terminate', 'bloody', 'maim', 'hurtful', 'severe']
senticnet['unbecoming'] = [-0.648, 0, 0.52, -0.532, '#sad', '#disgusting', -0.567, 'wrong', 'incorrect', 'improper', 'uncomely', 'unseemly']
senticnet['unbelief'] = [-0.553, -0.1, -0.416, -0.159, '#sad', '#scared', -0.343, 'angry_mob', 'protest', 'denial', 'against', 'rebellion']
senticnet['unbelievable'] = [-0.542, 0, 0.646, -0.62, '#angry', '#disgusting', -0.603, 'improbable', 'undreamed', 'undreamed_of', 'undreamt', 'undreamt_of']
senticnet['unbeliever'] = [0, 0.325, -0.098, 0.21, '#interesting', '#admirable', 0.146, 'saint', 'priest', 'christian', 'holy_man', 'friar']
senticnet['unbeloved'] = [-0.859, 0, 0.655, -0.672, '#sad', '#disgusting', -0.729, 'lovelorn', 'unloved', 'bereft', 'estranged', 'disinherited']
senticnet['unbend'] = [-0.519, 0, 0.738, -0.834, '#angry', '#disgusting', -0.697, 'relax', 'loosen_up', 'sit_back', 'unwind', 'decompress']
senticnet['unblemished'] = [0.513, -0.585, 0, 0.919, '#surprising', '#admirable', 0.672, 'stainless', 'untainted', 'untarnished', 'unsullied', 'unstained']
senticnet['unbodied'] = [-0.53, 0, 0.637, -0.925, '#angry', '#disgusting', -0.697, 'discorporate', 'unembodied', 'disembodied', 'bodiless', 'incorporeal']
senticnet['unbolted'] = [-0.759, 0, 0.892, -0.684, '#sad', '#angry', -0.778, 'unbarred', 'unfastened', 'unlatched', 'unlocked', 'unsecured']
senticnet['unbridled'] = [-0.971, 0, 0.569, -0.721, '#sad', '#disgusting', -0.754, 'unrestrained', 'unchecked', 'uncurbed', 'unhampered', 'unhindered']
senticnet['unbroken'] = [-0.632, 0, 0.991, -0.734, '#angry', '#disgusting', -0.786, 'undomesticated', 'feral', 'ferine', 'savage', 'untamed']
senticnet['uncanny'] = [0, 0, 0, -0.801, '#disgusting', '#disgusting', -0.267, 'uneducated', 'homophobic', 'guilty_crime', 'weird', 'strange']
senticnet['uncertain'] = [-0.875, 0.184, -0.587, 0, '#sad', '#scared', -0.426, 'unclear', 'unsure', 'unpredictable', 'random', 'vague']
senticnet['uncertain_environment'] = [0, 0, 0, -0.706, '#disgusting', '#disgusting', -0.235, 'uncertain_future', 'uncertainty', 'insecure', 'blur', 'anxiety']
senticnet['uncertain_future'] = [0, 0, 0, -0.706, '#disgusting', '#disgusting', -0.235, 'uncertainty', 'uncertain_environment', 'insecure', 'blur', 'anxiety']
senticnet['uncertainty'] = [0, 0, 0, -0.706, '#disgusting', '#disgusting', -0.235, 'uncertain_future', 'uncertain_environment', 'insecure', 'blur', 'anxiety']
senticnet['unchallengeable'] = [-0.957, 0, 0.783, -0.654, '#sad', '#angry', -0.798, 'noncontroversial', 'undisputed', 'unchallenged', 'unquestioned', 'agreed_upon']
senticnet['unchallenged'] = [-0.957, 0, 0.783, -0.654, '#sad', '#angry', -0.798, 'unchallengeable', 'undisputed', 'noncontroversial', 'unquestioned', 'agreed_upon']
senticnet['unchangeable'] = [-0.905, 0, 0.653, -0.998, '#sad', '#disgusting', -0.852, 'unalterable', 'static', 'changeless', 'confirmed', 'fixed']
senticnet['unchangeableness'] = [-0.834, 0, 0.696, -0.989, '#sad', '#disgusting', -0.84, 'unalterability', 'agelessness', 'changelessness', 'unchangeability', 'immutability']
senticnet['unchanging'] = [-0.819, 0, 0.921, -0.803, '#sad', '#angry', -0.848, 'immovability', 'fixity', 'lodgment', 'permanent', 'lodging']
senticnet['unchangingness'] = [-0.938, 0, 0.749, -0.684, '#sad', '#angry', -0.79, 'unvariedness', 'changelessness', 'unchangeability', 'unchangeableness', 'invariableness']
senticnet['unchecked'] = [-0.971, 0, 0.569, -0.721, '#sad', '#disgusting', -0.754, 'unbridled', 'unrestrained', 'uncurbed', 'unhampered', 'unhindered']
senticnet['uncheerful'] = [-0.759, 0.282, -0.429, -0.066, '#sad', '#scared', -0.324, 'depressing', 'cheerless', 'low-spiritedness', 'lowness', 'dispiritedness']
senticnet['uncheerfulness'] = [-0.718, 0.307, -0.407, -0.076, '#sad', '#scared', -0.298, 'cheerlessness', 'cheerlessly', 'lachrymose', 'weeping', 'dolorous']
senticnet['unclaimed'] = [-0.828, 0, 0.85, -0.709, '#sad', '#angry', -0.796, 'outcaste', 'casteless', 'unwanted', 'unwelcome', 'undesired']
senticnet['unclassifiable'] = [-0.826, 0, 0.758, -0.703, '#sad', '#angry', -0.762, 'unidentifiable', 'unrecognizable', 'unrecognisable', 'intangible', 'undiagnosable']
senticnet['unclean'] = [-0.691, 0, 0.858, -0.837, '#angry', '#disgusting', -0.795, 'draggled', 'befouled', 'filthy', 'nasty', 'scummy']
senticnet['uncleanness'] = [0.732, -0.957, 0, 0.856, '#surprising', '#admirable', 0.848, 'feculence', 'befoulment', 'defilement', 'dinginess', 'dinge']
senticnet['unclear'] = [-0.794, 0.241, -0.524, -0.118, '#sad', '#scared', -0.398, 'disoriented', 'obscure', 'unsure', 'uncertain', 'unfair']
senticnet['unclearness'] = [-0.587, 0, 0.871, -0.705, '#angry', '#disgusting', -0.721, 'elusiveness', 'inexplicitness', 'ambiguity', 'equivocalness', 'vagueness']
senticnet['unclothe'] = [-0.986, 0, 0.654, -0.847, '#sad', '#disgusting', -0.829, 'bereave', 'expropriate', 'disarm', 'deprive', 'take']
senticnet['uncloudedness'] = [0.818, -0.672, 0, 0.906, '#joyful', '#admirable', 0.799, 'quality', 'transparentness', 'distinctness', 'transparency', 'transparence']
senticnet['uncomely'] = [-0.648, 0, 0.52, -0.532, '#sad', '#disgusting', -0.567, 'wrong', 'incorrect', 'unbecoming', 'improper', 'unseemly']
senticnet['uncomfortable'] = [0, 0, 0.898, -0.908, '#angry', '#disgusting', -0.602, 'painful', 'ignorant', 'unpleasant', 'smelly', 'physical_reaction']
senticnet['uncomfortable_chair'] = [-0.974, 0, 0.135, -0.928, '#sad', '#disgusting', -0.679, 'tight_shoe', 'uncomfortable', 'very_uncomfortable', 'uncomfortable_seat', 'uncomfortable_shoe']
senticnet['uncomfortable_seat'] = [-0.974, 0, 0.135, -0.928, '#sad', '#disgusting', -0.679, 'tight_shoe', 'uncomfortable', 'uncomfortable_chair', 'very_uncomfortable', 'uncomfortable_shoe']
senticnet['uncomfortable_shoe'] = [-0.974, 0, 0.135, -0.928, '#sad', '#disgusting', -0.679, 'tight_shoe', 'uncomfortable', 'uncomfortable_chair', 'uncomfortable_seat', 'very_uncomfortable']
senticnet['uncomfortable_situation'] = [-0.964, 0, 0, -0.715, '#sad', '#disgusting', -0.56, 'embarrass_oneself', 'become_red', 'bad_experience', 'shy', 'provocative_discussion']
senticnet['uncomfortableness'] = [0.988, 0.974, 0, 0, '#joyful', '#interesting', 0.654, 'self-conscious', 'self-consciousness', 'pride', 'bashfulness', 'mortification']
senticnet['uncommon'] = [0, 0.937, 0, 0.824, '#interesting', '#admirable', 0.587, 'good', 'like_candy', 'tasty_good', 'special', 'niceness']
senticnet['uncommunicative'] = [-0.964, 0, 0.861, -0.901, '#sad', '#disgusting', -0.909, 'incommunicado', 'unpronounceable', 'impassive', 'inexpressive', 'silent']
senticnet['uncommunicativeness'] = [0.609, -0.824, 0, 0.756, '#surprising', '#admirable', 0.73, 'secretiveness', 'trait', 'secrecy', 'reserve', 'silence']
senticnet['uncomparable'] = [0.603, -0.804, 0, 0.555, '#joyful', '#surprising', 0.654, 'matchless', 'nonpareil', 'one_and_only', 'peerless', 'unmatchable']
senticnet['uncompensated'] = [-0.972, 0, 0.53, -0.666, '#sad', '#disgusting', -0.723, 'unpaid', 'unsalaried', 'buckshee', 'undischarged', 'complimentary']
senticnet['uncomplete'] = [0.538, -0.721, 0, 0.606, '#surprising', '#admirable', 0.622, 'sketchy', 'unelaborated', 'partial', 'uncompleted', 'broken']
senticnet['uncomprehensible'] = [-0.991, 0, 0.797, -0.569, '#sad', '#angry', -0.786, 'dark', 'impenetrable', 'lost', 'missed', 'unfathomable']
senticnet['unconcern'] = [0, 0, 0.898, -0.908, '#angry', '#disgusting', -0.602, 'unconcerned', 'unconcernedly', 'apathy', 'indifference', 'carelessness']
senticnet['unconcerned'] = [0, 0, 0.898, -0.908, '#angry', '#disgusting', -0.602, 'unconcern', 'unconcernedly', 'apathy', 'indifference', 'carelessness']
senticnet['unconcernedly'] = [0, 0, 0.898, -0.908, '#angry', '#disgusting', -0.602, 'unconcern', 'unconcerned', 'apathy', 'indifference', 'carelessness']
senticnet['unconditional'] = [0.813, 0, 0, 0.7, '#joyful', '#admirable', 0.504, 'unlimited', 'unqualified', 'categoric', 'categorical', 'entire']
senticnet['unconfessed'] = [-0.751, 0, 0.563, -0.986, '#sad', '#disgusting', -0.767, 'unsung', 'unrecognized', 'unappreciated', 'unvalued', 'unacknowledged']
senticnet['unconnected'] = [-0.653, 0, 0.944, -0.87, '#angry', '#disgusting', -0.822, 'asternal', 'isolated', 'separate', 'unattached', 'separated']
senticnet['unconquerable'] = [-0.738, 0, 0.732, -0.535, '#sad', '#angry', -0.668, 'insurmountable', 'insuperable', 'inexpugnable', 'indomitable', 'unsubduable']
senticnet['unconscientiousness'] = [-0.933, 0, 0.689, -0.851, '#sad', '#disgusting', -0.824, 'neglectfulness', 'inattentiveness', 'negligence', 'neglect', 'carelessness']
senticnet['unconscious'] = [-0.969, 0, 0.907, -0.959, '#sad', '#disgusting', -0.945, 'brain_damage', 'loss_ofawareness', 'concussion', 'amnesia', 'death']
senticnet['unconscious_process'] = [-0.531, 0, 0.762, -0.668, '#angry', '#disgusting', -0.654, 'defense', 'sleep_talking', 'somniloquy', 'somniloquism', 'condensation']
senticnet['unconsciousness'] = [-0.1, 0, -0.131, -0.158, '#scared', '#disgusting', -0.13, 'hit_oneself_head', 'unconscious', 'stop_move', 'serious_accident', 'become_unconscious']
senticnet['unconstipated'] = [-0.994, 0, 0.859, -0.626, '#sad', '#angry', -0.826, 'lax', 'loose', 'diarrheal', 'diarrhoeal', 'diarrhetic']
senticnet['uncontrollable'] = [-0.216, 0.147, -0.275, 0.131, '#sad', '#scared', -0.071, 'hazardous_health', 'bad_health', 'dangerous_health', 'unhealthy', 'destructive']
senticnet['uncontrolled'] = [-0.891, 0, 0.678, -0.62, '#sad', '#angry', -0.73, 'undisciplined', 'anarchic', 'anarchical', 'irrepressible', 'uncontrollable']
senticnet['uncontroversial'] = [-0.819, 0, 0.899, -0.709, '#sad', '#angry', -0.809, 'unchallengeable', 'undisputed', 'unchallenged', 'unquestioned', 'agreed_upon']
senticnet['unconventionality'] = [-0.502, 0, 0.733, -0.558, '#angry', '#disgusting', -0.598, 'originality', 'novelty', 'innovativeness', 'freshness', 'ability']
senticnet['unconverted'] = [-0.677, 0, 0.715, -0.89, '#angry', '#disgusting', -0.761, 'obstinate', 'unrepentant', 'impenitent', 'unregenerated', 'unpersuaded']
senticnet['uncorrectable'] = [-0.836, 0, 0.855, -0.893, '#angry', '#disgusting', -0.861, 'incorrigible', 'unreformable', 'unregenerate', 'uncontrollable', 'unmanageable']
senticnet['uncreativeness'] = [-0.784, 0, 0.707, -0.868, '#sad', '#disgusting', -0.786, 'mental_block', 'inability', 'stupidity', 'illiteracy', 'analphabetism']
senticnet['unction'] = [-0.644, 0, 0.941, -0.923, '#angry', '#disgusting', -0.836, 'carron_oil', 'salve', 'ointment', 'unguent', 'balm']
senticnet['unctuous'] = [0, 0, -0.746, -0.795, '#scared', '#disgusting', -0.514, 'buttery', 'oleaginous', 'fulsome', 'smarmy', 'oily']
senticnet['uncurbed'] = [-0.971, 0, 0.569, -0.721, '#sad', '#disgusting', -0.754, 'unbridled', 'unchecked', 'unrestrained', 'unhampered', 'unhindered']
senticnet['uncut'] = [-0.958, 0, 0.712, -0.528, '#sad', '#angry', -0.733, 'uninjured', 'unharmed', 'unscathed', 'unwounded', 'unhurt']
senticnet['undead'] = [0, 0, -0.753, -0.749, '#scared', '#disgusting', -0.501, 'storage_box', 'cobweb', 'dust', 'wine_bottle', 'read']
senticnet['undecorated'] = [-0.811, 0, 0.576, -0.906, '#sad', '#disgusting', -0.764, 'spare', 'unembellished', 'unornamented', 'bare', 'plain']
senticnet['undefeated'] = [0.914, -0.547, 0, 0.803, '#joyful', '#admirable', 0.755, 'victorious', 'triumphant', 'unbowed', 'unbeaten', 'unconquered']
senticnet['undemocratic'] = [-0.551, 0, 0.931, -0.74, '#angry', '#disgusting', -0.741, 'totalitarian', 'authoritarian', 'dictatorial', 'despotic', 'monarchal']
senticnet['undeniable'] = [-0.901, 0, 0.973, -0.767, '#sad', '#angry', -0.88, 'irrefutable', 'incontestable', 'incontrovertible', 'indisputable', 'questionable']
senticnet['undependability'] = [-0.922, 0, 0.546, -0.523, '#sad', '#angry', -0.664, 'irresponsibility', 'irresponsibleness', 'instability', 'irreproducibility', 'fallibility']
senticnet['undependable'] = [-0.831, 0, 0.962, -0.627, '#sad', '#angry', -0.807, 'unreliable', 'fallible', 'weak', 'errant', 'erring']
senticnet['undependableness'] = [-0.594, 0, 0.8, -0.514, '#sad', '#angry', -0.636, 'irresponsibility', 'irresponsibleness', 'instability', 'irreproducibility', 'fallibility']
senticnet['under_bed'] = [-0.023, 0, 0, -0.058, '#sad', '#disgusting', -0.027, 'sock_drawer', 'under_carpet', 'closet', 'under_closet', 'back_sofa']
senticnet['under_bridge'] = [0.025, 0, 0.044, -0.083, '#angry', '#disgusting', -0.034, 'bridge', 'suspension_bridge', 'side_road', 'roadside', 'interstate']
senticnet['under_car'] = [-0.041, -0.163, 0, 0.056, '#surprising', '#admirable', 0.059, 'car_part', 'car_wheel', 'automobile', 'wheel', 'car']
senticnet['under_carpet'] = [-0.043, 0, 0.041, -0.045, '#sad', '#disgusting', -0.043, 'back_sofa', 'home_improvement_store', 'closet', 'waste_bin', 'shoe_shop']
senticnet['under_closet'] = [-0.023, 0, 0, -0.058, '#sad', '#disgusting', -0.027, 'sock_drawer', 'under_carpet', 'closet', 'back_sofa', 'under_bed']
senticnet['under_cover'] = [-0.028, 0.08, 0, 0.073, '#interesting', '#admirable', 0.042, 'good_sleep', 'shut_eye', 'no_light', 'block_light', 'doze']
senticnet['under_garment'] = [0.924, 0.946, 0, 0, '#joyful', '#interesting', 0.623, 'undergarment', 'lady_underwear', 'underwear', 'woman_clothes', 'bra']
senticnet['under_ground'] = [-0.062, 0, 0, -0.032, '#sad', '#disgusting', -0.031, 'underground', 'tunnel', 'yard', 'skin_cancer', 'golf_course']
senticnet['under_head'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'head_shoulder', 'nervous_system', 'crotch', 'nape', 'stub']
senticnet['under_house'] = [-0.093, -0.005, 0.018, 0, '#sad', '#angry', -0.035, 'build_ground', 'real_estate', 'part_of_building', 'underfoot', 'house_land']
senticnet['under_rock'] = [-0.068, 0, 0, 0, '#sad', '#sad', -0.023, 'bathroom_wall', 'fallen_tree', 'relax', 'wet_towel', 'compost_pile']
senticnet['under_umbrella'] = [0, 0.094, 0, 0, '#interesting', '#interesting', 0.031, 'dark_area', 'cavern', 'cooler', 'parasol', 'stick_wall']
senticnet['under_water'] = [-0.036, -0.009, 0.024, -0.052, '#sad', '#disgusting', -0.034, 'bottom_sea', 'underwater', 'water_sea', 'ocean', 'sea']
senticnet['underbelly'] = [-0.549, 0, 0.845, -0.955, '#angry', '#disgusting', -0.783, 'face', 'base', 'underside', 'sole', 'bilge']
senticnet['underclassman'] = [-0.648, 0, 0.88, -0.807, '#angry', '#disgusting', -0.778, 'junior', 'undergraduate', 'undergrad', 'freshman', 'fresher']
senticnet['undercover'] = [-0.381, 0.108, -0.389, 0.072, '#sad', '#scared', -0.197, 'hide_identity', 'hide', 'fake', 'hacker', 'internet']
senticnet['underdog'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'nerd', 'computer_lover', 'loser', 'book_worm', 'geek']
senticnet['underdress'] = [-0.75, 0, 0.586, -0.989, '#sad', '#disgusting', -0.775, 'raiment', 'garb', 'dress', 'clothe', 'enclothe']
senticnet['underestimate'] = [-0.53, 0, 0.543, -0.992, '#angry', '#disgusting', -0.688, 'underestimation', 'underrating', 'underreckoning', 'dead_reckoning', 'approximation']
senticnet['underestimation'] = [-0.53, 0, 0.543, -0.992, '#angry', '#disgusting', -0.688, 'approximation', 'underrating', 'underreckoning', 'dead_reckoning', 'underestimate']
senticnet['underfed'] = [-0.604, 0, 0.766, -0.746, '#angry', '#disgusting', -0.705, 'unfed', 'malnourished', 'undernourished', 'starved', 'starving']
senticnet['underfoot'] = [-0.063, -0.017, 0.031, -0.037, '#sad', '#disgusting', -0.038, 'low', 'ground', 'look_down', 'ground_level', 'under_house']
senticnet['undergarment'] = [0.965, 0.913, 0, 0, '#joyful', '#interesting', 0.626, 'under_garment', 'lady_underwear', 'underwear', 'woman_clothes', 'pantie']
senticnet['undergrad'] = [-0.519, 0, 0.762, -0.861, '#angry', '#disgusting', -0.714, 'lowerclassman', 'underclassman', 'senior', 'college_girl', 'collegian']
senticnet['undergraduate'] = [-0.863, 0, 0.825, -0.948, '#sad', '#disgusting', -0.879, 'lowerclassman', 'underclassman', 'senior', 'college_girl', 'collegian']
senticnet['underground'] = [-0.048, 0, 0, -0.047, '#sad', '#disgusting', -0.032, 'golf_course', 'surface_earth', 'ground', 'under_ground', 'tunnel']
senticnet['underground_animal'] = [-0.139, 0, 0.013, -0.081, '#sad', '#disgusting', -0.078, 'blind', 'dig_tunnel', 'bad_eyesight', 'big_mouse', 'small_rodent']
senticnet['underground_area'] = [0, 0, -0.051, -0.096, '#scared', '#disgusting', -0.049, 'basement', 'master_control', 'hold_point', 'tunnel', 'metal_detector']
senticnet['underground_map'] = [0.087, 0.08, 0.013, 0, '#joyful', '#interesting', 0.051, 'advertise_company', 'billboard', 'advertise_panel', 'neighborhood_map', 'restaurant_entrance']
senticnet['underground_passage'] = [-0.045, 0, 0, -0.047, '#sad', '#disgusting', -0.031, 'tunnel', 'rut', 'cave', 'golf_course', 'room_temperature']
senticnet['undermanned'] = [-0.587, 0, 0.996, -0.848, '#angry', '#disgusting', -0.81, 'inadequate', 'understaffed', 'deficient', 'lacking', 'wanting']
senticnet['undermentioned'] = [-0.643, 0, 0.684, -0.717, '#angry', '#disgusting', -0.681, 'consecutive', 'postmortem', 'ensuing', 'following', 'succeeding']
senticnet['undermine'] = [0, 0, 0.773, -0.95, '#angry', '#disgusting', -0.574, 'counteract', 'cave', 'sabotage', 'subvert', 'weaken']
senticnet['undermined'] = [0, 0, -0.913, -0.715, '#scared', '#disgusting', -0.543, 'countermine', 'counteract', 'sabotage', 'weaken', 'subvert']
senticnet['undernourished'] = [-0.604, 0, 0.766, -0.746, '#angry', '#disgusting', -0.705, 'unfed', 'underfed', 'malnourished', 'starved', 'starving']
senticnet['underpants'] = [-0.736, 0, 0.997, -0.862, '#angry', '#disgusting', -0.865, 'scanty', 'unmentionable', 'bikini_pants', 'bloomers', 'pants']
senticnet['underrating'] = [-0.53, 0, 0.543, -0.992, '#angry', '#disgusting', -0.688, 'underestimation', 'approximation', 'underreckoning', 'dead_reckoning', 'underestimate']
senticnet['underreckoning'] = [-0.53, 0, 0.543, -0.992, '#angry', '#disgusting', -0.688, 'underestimation', 'underrating', 'approximation', 'dead_reckoning', 'underestimate']
senticnet['underseller'] = [-0.773, 0, 0.528, -0.516, '#sad', '#angry', -0.606, 'seller', 'marketer', 'vender', 'vendor', 'trafficker']
senticnet['underside'] = [-0.549, 0, 0.845, -0.955, '#angry', '#disgusting', -0.783, 'face', 'base', 'underbelly', 'sole', 'bilge']
senticnet['undersized'] = [0, -0.032, -0.057, -0.121, '#scared', '#disgusting', -0.049, 'gnome', 'elf', 'goblin', 'dwarf', 'small_person']
senticnet['understaffed'] = [-0.587, 0, 0.996, -0.848, '#angry', '#disgusting', -0.81, 'undermanned', 'inadequate', 'deficient', 'lacking', 'wanting']
senticnet['understand'] = [0.098, 0.165, -0.134, 0.284, '#interesting', '#admirable', 0.138, 'know', 'know_fact', 'great_understand', 'trivia', 'gain_insight']
senticnet['understand_better'] = [0.929, 0.861, 0, 0.862, '#joyful', '#admirable', 0.884, 'communicate_other_person', 'transfer_knowledge', 'answer_question', 'supply_answer', 'commit_to_memory']
senticnet['understand_culture'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'get_informed', 'get_news', 'stimulate_mind', 'expand_horizon', 'appreciate_art']
senticnet['understand_current_event'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'keep_up_current_event', 'learn_entertainment', 'take_up_time', 'know_happen_world', 'expand_knowledge']
senticnet['understand_each_other'] = [0.932, 0.787, 0, 0, '#joyful', '#interesting', 0.573, 'learn_patience', 'discuss', 'avoid_conflict', 'conformist_attitude', 'seek_clarification']
senticnet['understand_fact'] = [-0.167, -0.019, -0.177, 0.062, '#sad', '#scared', -0.088, 'heart_attack', 'sign_paper', 'criminal_activity', 'freedom', 'sign_document']
senticnet['understand_idea'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'educate_others', 'listen_teacher', 'share_opinion', 'help_another_person', 'seek_understanding']
senticnet['understand_new_culture'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'find_out', 'find_out_world', 'discover', 'explore', 'learn']
senticnet['understand_plot'] = [0.759, 0.829, 0, 0, '#joyful', '#interesting', 0.529, 'watch_commercial', 'eat_popcorn', 'laugh', 'neglect_chore', 'see_advertisement']
senticnet['understand_problem'] = [0.945, 0.784, 0, 0, '#joyful', '#interesting', 0.576, 'trivia', 'understand', 'find_answer', 'intelligence', 'gain_insight']
senticnet['understand_rule'] = [0.928, 0.754, 0, 0, '#joyful', '#interesting', 0.561, 'resolve_conflict', 'look_truth', 'learn_world', 'logic', 'look_evidence']
senticnet['understand_topic'] = [-0.065, 0, 0.042, -0.087, '#sad', '#disgusting', -0.065, 'learn_oneself', 'understand', 'get_answer', 'start_talk', 'help_understand']
senticnet['understand_world'] = [0.041, 0, 0, 0.109, '#joyful', '#admirable', 0.05, 'good_idea', 'party', 'use_party', 'hold_beer', 'relax_friend']
senticnet['understated'] = [0, 0, -0.868, -0.782, '#scared', '#disgusting', -0.55, 'minimize', 'minimise', 'unpretentious', 'unostentatious', 'downplay']
senticnet['understood'] = [0.632, -0.612, 0, 0.732, '#joyful', '#admirable', 0.659, 'appreciated', 'apprehended', 'comprehended', 'interpreted', 'taken']
senticnet['undersurface'] = [-0.666, 0, 0.809, -0.614, '#sad', '#angry', -0.696, 'face', 'base', 'underbelly', 'sole', 'bilge']
senticnet['undertake'] = [-0.046, 0.194, -0.106, 0.124, '#interesting', '#admirable', 0.055, 'no_doubt', 'recruit', 'consideration', 'review', 'business_person']
senticnet['undertone'] = [-0.943, 0, 0.65, -0.578, '#sad', '#angry', -0.724, 'manner_of_speaking', 'tone_of_voice', 'note', 'roundness', 'rotundity']
senticnet['underwater'] = [-0.036, -0.009, 0.024, -0.052, '#sad', '#disgusting', -0.034, 'under_water', 'bottom_sea', 'water_sea', 'ocean', 'sea']
senticnet['underwear'] = [0.727, 0.821, 0, 0, '#joyful', '#interesting', 0.516, 'robe', 'clothes', 'garment', 'piece_of_clothing', 'slack']
senticnet['underwing'] = [-0.534, 0, 0.8, -0.619, '#angry', '#disgusting', -0.651, 'armyworm', 'noctuid', 'antler_moth', 'heliothis_moth', 'moth']
senticnet['underworld'] = [0, 0, -0.978, -0.864, '#scared', '#disgusting', -0.614, 'war', 'arsenal', 'gun_store', 'war_museum', 'war_zone']
senticnet['undesirable'] = [-0.557, 0, -0.405, -0.087, '#sad', '#scared', -0.35, 'death_love', 'negative_feeling', 'bad_feeling', 'lament', 'deep_sadness']
senticnet['undesired'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'short_circuit', 'error', 'mistake', 'crosstalk', 'trouble']
senticnet['undestroyable'] = [-0.957, 0, 0.799, -0.673, '#sad', '#angry', -0.81, 'imputrescible', 'imperishable', 'indestructible', 'durable', 'perdurable']
senticnet['undetermined'] = [-0.604, 0, 0.722, -0.843, '#angry', '#disgusting', -0.723, 'unsettled', 'undecided', 'tentative', 'unresolved', 'open']
senticnet['undiagnosable'] = [-0.826, 0, 0.758, -0.703, '#sad', '#angry', -0.762, 'unclassifiable', 'unrecognizable', 'unrecognisable', 'intangible', 'unidentifiable']
senticnet['undigested'] = [-0.774, 0, 0.671, -0.807, '#sad', '#disgusting', -0.751, 'flatulent', 'nondigestible', 'indigestible', 'stodgy', 'heavy']
senticnet['undignified'] = [-0.896, 0, 0.647, -0.598, '#sad', '#angry', -0.714, 'mortifying', 'demeaning', 'humbling', 'humiliating', 'pathetic']
senticnet['undiminished'] = [-0.657, 0, 0.799, -0.751, '#angry', '#disgusting', -0.736, 'unmitigated', 'unrelieved', 'everlasting', 'unadulterated', 'bloody']
senticnet['undischarged'] = [-0.972, 0, 0.53, -0.666, '#sad', '#disgusting', -0.723, 'uncompensated', 'unsalaried', 'buckshee', 'unpaid', 'complimentary']
senticnet['undiscipline'] = [-0.964, 0, 0.942, -0.858, '#sad', '#angry', -0.921, 'indulgence', 'incontinence', 'trait', 'dissoluteness', 'unrestraint']
senticnet['undisciplined'] = [-0.891, 0, 0.678, -0.62, '#sad', '#angry', -0.73, 'uncontrolled', 'anarchic', 'anarchical', 'irrepressible', 'uncontrollable']
senticnet['undisputed'] = [0, 0.845, 0, 0.952, '#interesting', '#admirable', 0.599, 'unchallengeable', 'unchallenged', 'unquestioned', 'agreed_upon', 'agree']
senticnet['undistributed'] = [-0.929, 0, 0.859, -0.64, '#sad', '#angry', -0.809, 'undiversified', 'monolithic', 'unanimous', 'whole', 'solid']
senticnet['undisturbed'] = [-0.591, 0, 0.799, -0.698, '#angry', '#disgusting', -0.696, 'dreamless', 'untroubled', 'unmolested', 'unworried', 'unconcerned']
senticnet['undiversified'] = [-0.929, 0, 0.859, -0.64, '#sad', '#angry', -0.809, 'undistributed', 'monolithic', 'unanimous', 'whole', 'solid']
senticnet['undivided'] = [-0.77, 0, 0.577, -0.782, '#sad', '#disgusting', -0.71, 'unshared', 'exclusive', 'sole', 'individual', 'single']
senticnet['undo'] = [0.507, -0.507, 0, 0.676, '#joyful', '#surprising', 0.563, 'unlace', 'unfold', 'untie', 'unbrace', 'spread']
senticnet['undoer'] = [-0.583, 0, 0.714, -0.612, '#angry', '#disgusting', -0.636, 'waster', 'sleeper', 'destroyer', 'ruiner', 'diversionist']
senticnet['undomesticated'] = [-0.632, 0, 0.991, -0.734, '#angry', '#disgusting', -0.786, 'untamed', 'feral', 'ferine', 'savage', 'unbroken']
senticnet['undone'] = [-0.988, 0, 0.811, -0.958, '#sad', '#disgusting', -0.919, 'unmethodical', 'upset', 'confused', 'scrambled', 'disorganized']
senticnet['undreamed'] = [-0.542, 0, 0.646, -0.62, '#angry', '#disgusting', -0.603, 'improbable', 'unbelievable', 'unbelievable_of', 'undreamt', 'undreamt_of']
senticnet['undreamed_of'] = [-0.542, 0, 0.646, -0.62, '#angry', '#disgusting', -0.603, 'improbable', 'undreamed', 'unbelievable', 'undreamt', 'undreamt_of']
senticnet['undreamt'] = [-0.542, 0, 0.646, -0.62, '#angry', '#disgusting', -0.603, 'improbable', 'undreamed', 'undreamed_of', 'unbelievable', 'unbelievable_of']
senticnet['undreamt_of'] = [-0.542, 0, 0.646, -0.62, '#angry', '#disgusting', -0.603, 'improbable', 'undreamed', 'undreamed_of', 'undreamt', 'unbelievable']
senticnet['undress'] = [1.0, 0.882, 0, 0, '#joyful', '#interesting', 0.627, 'disorder', 'messy', 'worst', 'mess_up', 'disarray']
senticnet['undressed'] = [-0.805, 0, 0.677, -0.809, '#sad', '#disgusting', -0.764, 'unhewn', 'unfattened', 'unfinished', 'roughhewn', 'raw']
senticnet['unearth'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'find_out', 'unmask', 'dig_out', 'become_aware', 'dish_out']
senticnet['uneasily'] = [-0.834, 0, 0, -0.784, '#sad', '#disgusting', -0.539, 'anxiously', 'apprehensively', 'apprehensive', 'worried', 'solicitousness']
senticnet['uneasiness'] = [-0.765, 0, 0, -0.772, '#sad', '#disgusting', -0.512, 'hysteria', 'dreadful', 'dread', 'scary', 'anxious']
senticnet['uneasy'] = [-0.974, 0, 0, -0.725, '#sad', '#disgusting', -0.566, 'unquiet', 'sinking_feeling', 'sinking', 'scruple', 'misgiving']
senticnet['uneducated'] = [-0.956, 0, 0, -0.97, '#sad', '#disgusting', -0.642, 'homophobic', 'guilty_crime', 'precise', 'strange', 'lovely']
senticnet['unembellished'] = [-0.752, 0, 0.869, -0.737, '#sad', '#angry', -0.786, 'spare', 'unadorned', 'unornamented', 'bare', 'plain']
senticnet['unembodied'] = [-0.53, 0, 0.637, -0.925, '#angry', '#disgusting', -0.697, 'discorporate', 'incorporeal', 'disembodied', 'bodiless', 'unbodied']
senticnet['unemotional'] = [0.716, -0.636, 0, 0.848, '#joyful', '#admirable', 0.733, 'phlegmatic', 'phlegmatical', 'unblinking', 'stoic', 'chilly']
senticnet['unemphatic'] = [-0.9, 0, 0.972, -0.794, '#sad', '#angry', -0.889, 'feminine', 'weak', 'light', 'unstressed', 'unaccented']
senticnet['unemployed'] = [-0.89, 0, 0.904, -0.782, '#sad', '#angry', -0.859, 'acne', 'health_problem', 'varicose_vein', 'ill_health', 'terminal_illness']
senticnet['unemployment'] = [0, 0, 0.948, -0.963, '#angry', '#disgusting', -0.637, 'work_much', 'lack_money', 'wage_slavery', 'buy_tool', 'get_paycheck']
senticnet['unending'] = [0, 0.093, 0, 0.146, '#interesting', '#admirable', 0.08, 'constant', 'past_present', 'eternity', 'irrelevant', 'never_end']
senticnet['unendurable'] = [-0.859, 0, 0.898, -0.929, '#angry', '#disgusting', -0.895, 'unsupportable', 'unacceptable', 'bitter', 'impossible', 'insufferable']
senticnet['unenergetic'] = [-0.749, 0, 0.994, -0.856, '#angry', '#disgusting', -0.866, 'foggy', 'groggy', 'logy', 'stuporous', 'dazed']
senticnet['unentitled'] = [-0.608, 0, 0.832, -0.537, '#sad', '#angry', -0.659, 'unsuitable', 'undesirable', 'unqualified', 'disqualified', 'ineligible']
senticnet['unenviable'] = [-0.753, 0, 0, -0.799, '#sad', '#disgusting', -0.517, 'awkward', 'abash', 'embarrassingly', 'embarrassing', 'sheepish']
senticnet['unequal'] = [-0.868, 0, 0.63, -0.697, '#sad', '#disgusting', -0.732, 'unequalized', 'mismatched', 'nonequivalent', 'uneven', 'unbalanced']
senticnet['unequalized'] = [-0.868, 0, 0.63, -0.697, '#sad', '#disgusting', -0.732, 'unequal', 'mismatched', 'nonequivalent', 'uneven', 'unbalanced']
senticnet['unequivocalness'] = [0.823, -0.532, 0, 0.583, '#joyful', '#admirable', 0.646, 'lucidness', 'clarity', 'clearness', 'lucidity', 'pellucidity']
senticnet['unerect'] = [-0.783, 0, 0.95, -0.731, '#sad', '#angry', -0.821, 'drooping', 'crooked', 'weeping', 'prone', 'supine']
senticnet['unerring'] = [-0.693, 0, 0.679, -0.898, '#sad', '#disgusting', -0.757, 'inerrable', 'inerrant', 'infallible', 'unfailing', 'foolproof']
senticnet['unessential'] = [-0.819, 0, 0.987, -0.641, '#sad', '#angry', -0.816, 'nonessential', 'accidental', 'incidental', 'accessorial', 'adscititious']
senticnet['unethical'] = [0, 0, 0, -0.959, '#disgusting', '#disgusting', -0.32, 'immoral', 'bad', 'obscene', 'indecent', 'shameless']
senticnet['uneven'] = [0, 0, 0.726, -0.941, '#angry', '#disgusting', -0.556, 'seldom', 'alpha', 'capoeira', 'convert_energy', 'animal_sound']
senticnet['unevenness'] = [-0.535, 0, 0.765, -0.942, '#angry', '#disgusting', -0.747, 'jaggedness', 'unregularity', 'ruggedness', 'irregularity', 'patchiness']
senticnet['unexchangeability'] = [-0.568, 0, 0.574, -0.695, '#angry', '#disgusting', -0.612, 'incommutability', 'irreplaceableness', 'changelessness', 'unchangeability', 'unchangeableness']
senticnet['unexhausted'] = [0.921, -0.825, 0, 0.868, '#joyful', '#admirable', 0.871, 'odd', 'left', 'unspent', 'unexpended', 'leftover']
senticnet['unexpected'] = [0, -1, 0, 0, '#surprising', '#surprising', 0.333, 'surprise', 'amazement', 'astonishment', 'unforeseen', 'unanticipated']
senticnet['unexplainable'] = [-0.624, 0, 0.825, -0.738, '#angry', '#disgusting', -0.729, 'incomprehensible', 'unaccountable', 'unexplained', 'inscrutable', 'mystifying']
senticnet['unexplained'] = [-0.624, 0, 0.825, -0.738, '#angry', '#disgusting', -0.729, 'unexplainable', 'unaccountable', 'incomprehensible', 'inscrutable', 'mystifying']
senticnet['unfailing'] = [-0.693, 0, 0.679, -0.898, '#sad', '#disgusting', -0.757, 'inerrable', 'inerrant', 'unerring', 'infallible', 'foolproof']
senticnet['unfair'] = [-0.972, 0, 0.7, -0.964, '#sad', '#disgusting', -0.879, 'rude', 'uneducated', 'fragile', 'mean', 'cheat_on']
senticnet['unfaithful'] = [-0.669, 0, 0.709, -0.881, '#angry', '#disgusting', -0.753, 'untrue', 'apostate', 'treacherous', 'perfidious', 'punic']
senticnet['unfaithfulness'] = [0.667, -0.719, 0, 0.775, '#surprising', '#admirable', 0.72, 'quality', 'disloyalty', 'inconstancy', 'falseness', 'faithlessness']
senticnet['unfamiliar'] = [-0.509, 0, 0.737, -0.552, '#angry', '#disgusting', -0.599, 'unacquainted_with', 'unfamiliar_with', 'unknown', 'unacquainted', 'strange']
senticnet['unfamiliar_with'] = [-0.509, 0, 0.737, -0.552, '#angry', '#disgusting', -0.599, 'unacquainted_with', 'unfamiliar', 'unknown', 'unacquainted', 'strange']
senticnet['unfamiliarity'] = [-0.652, 0, 0.98, -0.682, '#angry', '#disgusting', -0.771, 'freakishness', 'quaintness', 'abnormality', 'queerness', 'crotchet']
senticnet['unfashionable'] = [-0.874, 0, 0.83, -0.611, '#sad', '#angry', -0.772, 'out', 'dated', 'stodgy', 'prehistoric', 'antique']
senticnet['unfastened'] = [-0.759, 0, 0.892, -0.684, '#sad', '#angry', -0.778, 'unbarred', 'unbolted', 'unlatched', 'unlocked', 'unsecured']
senticnet['unfathomable'] = [-0.991, 0, 0.797, -0.569, '#sad', '#angry', -0.786, 'dark', 'impenetrable', 'lost', 'missed', 'uncomprehensible']
senticnet['unfattened'] = [-0.805, 0, 0.677, -0.809, '#sad', '#disgusting', -0.764, 'unhewn', 'unfinished', 'undressed', 'roughhewn', 'raw']
senticnet['unfavorable'] = [-0.74, 0, 0.982, -0.819, '#angry', '#disgusting', -0.847, 'inauspicious', 'admonishing', 'reproachful', 'reproving', 'untoward']
senticnet['unfavorable_judgment'] = [-0.543, 0, 0.884, -0.714, '#angry', '#disgusting', -0.714, 'reprimand', 'static', 'stricture', 'disapproval', 'faultfinding']
senticnet['unfavorable_position'] = [-0.621, 0, 0.708, -0.619, '#sad', '#angry', -0.649, 'unfavorableness', 'unfavourableness', 'disadvantage', 'unprofitableness', 'unprofitability']
senticnet['unfavorableness'] = [-0.621, 0, 0.708, -0.619, '#sad', '#angry', -0.649, 'disadvantage', 'unfavourableness', 'unfavorable_position', 'unprofitableness', 'unprofitability']
senticnet['unfavourable'] = [-0.941, 0, 0.777, -0.707, '#sad', '#angry', -0.808, 'inauspicious', 'admonishing', 'reproachful', 'reproving', 'untoward']
senticnet['unfavourableness'] = [-0.621, 0, 0.708, -0.619, '#sad', '#angry', -0.649, 'unfavorableness', 'disadvantage', 'unfavorable_position', 'unprofitableness', 'unprofitability']
senticnet['unfeasibility'] = [-0.978, 0, 0.675, -0.937, '#sad', '#disgusting', -0.863, 'infeasibility', 'impracticability', 'inutility', 'uselessness', 'unusefulness']
senticnet['unfed'] = [-0.604, 0, 0.766, -0.746, '#angry', '#disgusting', -0.705, 'malnourished', 'underfed', 'undernourished', 'starved', 'starving']
senticnet['unfeelingness'] = [-0.794, 0, 0.636, -0.756, '#sad', '#disgusting', -0.729, 'insensibility', 'tin_ear', 'hardness', 'unfitness', 'insensitiveness']
senticnet['unfinished'] = [-0.805, 0, 0.677, -0.809, '#sad', '#disgusting', -0.764, 'unhewn', 'unfattened', 'undressed', 'roughhewn', 'raw']
senticnet['unfirm'] = [-0.699, 0, 0.695, -0.716, '#sad', '#disgusting', -0.703, 'unfixed', 'unsteady', 'detached', 'free', 'floating']
senticnet['unfit'] = [-0.823, 0, 0, -0.953, '#sad', '#disgusting', -0.592, 'blister_foot', 'trip_fall', 'breafast', 'run_out_breath', 'breahard']
senticnet['unfitness'] = [-0.829, 0, 0.698, -0.943, '#sad', '#disgusting', -0.823, 'disability', 'disablement', 'ill_health', 'unhealthiness', 'health_problem']
senticnet['unfixed'] = [-0.699, 0, 0.695, -0.716, '#sad', '#disgusting', -0.703, 'unfirm', 'unsteady', 'detached', 'free', 'floating']
senticnet['unfolded'] = [0, 0, -0.754, -0.853, '#scared', '#disgusting', -0.536, 'blossom', 'stretch', 'open', 'stretch_out', 'spread']
senticnet['unforesightful'] = [-0.638, 0, 0.867, -0.57, '#sad', '#angry', -0.692, 'myopic', 'short', 'shortsighted', 'improvident', 'thriftless']
senticnet['unforgivable'] = [-0.53, 0, 0.901, -0.511, '#sad', '#angry', -0.647, 'inexpiable', 'inexcusable', 'deadly', 'unpardonable', 'mortal']
senticnet['unformed'] = [-0.646, 0, 0.557, -0.739, '#sad', '#disgusting', -0.647, 'formless', 'amorphous', 'shapeless', 'unshaped', 'unshapen']
senticnet['unfortunate'] = [-0.676, 0, 0.838, -0.86, '#angry', '#disgusting', -0.791, 'unsuccessful_person', 'loser', 'abandoned_person', 'desperate', 'jonah']
senticnet['unfortunate_person'] = [-0.804, 0, 0.603, -0.714, '#sad', '#disgusting', -0.707, 'unsuccessful_person', 'loser', 'abandoned_person', 'desperate', 'jonah']
senticnet['unfounded'] = [-0.974, 0, 0.59, -0.93, '#sad', '#disgusting', -0.831, 'idle', 'baseless', 'groundless', 'unsupported', 'unwarranted']
senticnet['unfriendliness'] = [-0.122, 0.193, 0.597, -0.627, '#angry', '#disgusting', -0.384, 'unfriendly', 'inimical', 'disapproval', 'disapprove', 'disapproving']
senticnet['unfriendly'] = [-0.122, 0.193, 0.597, -0.627, '#angry', '#disgusting', -0.384, 'inimical', 'unfriendliness', 'disapproval', 'disapprove', 'disapproving']
senticnet['unfriendly_staff'] = [-0.983, 0, 0.058, -0.921, '#sad', '#disgusting', -0.654, 'bad_staff', 'cheap_hotel', 'cheap_restaurant', 'bad_service', 'long_waiting_time']
senticnet['unfrock'] = [-0.956, 0, 0.673, -0.855, '#sad', '#disgusting', -0.828, 'discharge', 'free', 'dethrone', 'defrock', 'disinvest']
senticnet['unfruitful'] = [-0.705, 0, 0.919, -0.732, '#angry', '#disgusting', -0.785, 'childless', 'unsuccessful', 'acarpous', 'abortive', 'stillborn']
senticnet['unfunctional'] = [-0.755, 0, 0.832, -0.695, '#sad', '#angry', -0.761, 'impractical', 'useless', 'stupid', 'difficult', 'hard']
senticnet['ungainly'] = [-0.965, 0, 0.636, -0.85, '#sad', '#disgusting', -0.817, 'awkward', 'bunglesome', 'clumsy', 'cumbersome', 'unmanageable']
senticnet['unglam'] = [0, 0, 0.894, -0.825, '#angry', '#disgusting', -0.573, 'get_old', 'old_software', 'become_obsolete', 'old_technology', 'overrated']
senticnet['unglamorous'] = [-0.121, -0.06, -0.089, -0.036, '#sad', '#scared', -0.062, 'old_fashioned', 'passe', 'special_person', 'bloke', 'male']
senticnet['ungratefulness'] = [-0.739, 0, 0, -0.74, '#sad', '#disgusting', -0.493, 'ingratitude', 'feel_for', 'condole_with', 'compassionateness', 'sympathize_with']
senticnet['ungratified'] = [-0.88, 0, 0.718, -0.923, '#sad', '#disgusting', -0.84, 'discontented', 'disaffected', 'malcontent', 'unsatisfied', 'restless']
senticnet['unguent'] = [-0.644, 0, 0.941, -0.923, '#angry', '#disgusting', -0.836, 'unction', 'salve', 'ointment', 'carron_oil', 'balm']
senticnet['ungummed'] = [-0.735, 0, 0.957, -0.609, '#sad', '#angry', -0.767, 'nonadhesive', 'nonglutinous', 'nonviscid', 'nonresinous', 'nonresiny']
senticnet['unhampered'] = [-0.971, 0, 0.569, -0.721, '#sad', '#disgusting', -0.754, 'unbridled', 'unchecked', 'uncurbed', 'unrestrained', 'unhindered']
senticnet['unhappiness'] = [-0.794, 0.241, -0.524, -0.118, '#sad', '#scared', -0.398, 'misery', 'melancholy', 'sad', 'unhappy', 'sorrow']
senticnet['unhappy'] = [-0.713, 0, 0.944, -0.997, '#angry', '#disgusting', -0.885, 'hangdog', 'melancholy', 'shamed', 'miserably', 'piteous']
senticnet['unharmed'] = [-0.958, 0, 0.712, -0.528, '#sad', '#angry', -0.733, 'uncut', 'uninjured', 'unscathed', 'unwounded', 'unhurt']
senticnet['unharmonious'] = [-0.774, 0, 0.527, -0.749, '#sad', '#disgusting', -0.683, 'discordant', 'dissonant', 'unresolved', 'false', 'disharmonious']
senticnet['unhealthfulness'] = [-0.754, 0, 0.893, -0.618, '#sad', '#angry', -0.755, 'unwholesomeness', 'morbidness', 'morbidity', 'insalubrity', 'insalubriousness']
senticnet['unhealthiness'] = [-0.932, 0, 0.75, -0.845, '#sad', '#disgusting', -0.842, 'invalidism', 'injury', 'affliction', 'biliousness', 'harm']
senticnet['unhealthy'] = [-0.241, 0.084, -0.264, -0.06, '#sad', '#scared', -0.16, 'bad_health', 'dangerous_health', 'hazardous', 'hazardous_health', 'unsafe']
senticnet['unhealthy_food'] = [-0.981, 0, 0.802, -0.902, '#sad', '#disgusting', -0.895, 'unhealthy', 'expired_egg', 'expired_food', 'expired_beef', 'expired_milk']
senticnet['unhearable'] = [-0.964, 0, 0.613, -0.82, '#sad', '#disgusting', -0.799, 'silent', 'voiceless', 'unsounded', 'breathed', 'supersonic']
senticnet['unheeded'] = [-0.603, 0, 0.564, -0.85, '#sad', '#disgusting', -0.672, 'unmarked', 'ignored', 'unnoticed', 'overlooked', 'unnoted']
senticnet['unhewn'] = [-0.805, 0, 0.677, -0.809, '#sad', '#disgusting', -0.764, 'unfinished', 'unfattened', 'undressed', 'roughhewn', 'raw']
senticnet['unhindered'] = [-0.971, 0, 0.569, -0.721, '#sad', '#disgusting', -0.754, 'unbridled', 'unchecked', 'uncurbed', 'unhampered', 'unrestrained']
senticnet['unhinge'] = [-0.993, 0, 0.968, -0.963, '#sad', '#angry', -0.975, 'upset', 'trouble', 'worry', 'disturb', 'vex']
senticnet['unhopeful'] = [-0.93, 0, 0, -0.93, '#sad', '#disgusting', -0.62, 'resignedly', 'abject', 'abjectly', 'resignation', 'reconcile']
senticnet['unhurried'] = [-0.771, 0, 0.855, -0.576, '#sad', '#angry', -0.734, 'leisurely', 'easygoing', 'deliberate', 'easy', 'careful']
senticnet['unhurriedness'] = [-0.652, 0, 0.681, -0.623, '#sad', '#angry', -0.652, 'dilatoriness', 'leisureliness', 'procrastination', 'rate', 'pace']
senticnet['unhurt'] = [-0.958, 0, 0.712, -0.528, '#sad', '#angry', -0.733, 'uncut', 'unharmed', 'unscathed', 'unwounded', 'uninjured']
senticnet['unicycle'] = [-0.094, 0, 0, 0, '#sad', '#sad', -0.031, 'mope', 'truck', 'lorry', 'vehicle', 'vehicle_type']
senticnet['unidentifiable'] = [-0.826, 0, 0.758, -0.703, '#sad', '#angry', -0.762, 'unclassifiable', 'unrecognizable', 'unrecognisable', 'intangible', 'undiagnosable']
senticnet['unifoliate'] = [-0.508, 0, 0.573, -0.893, '#angry', '#disgusting', -0.658, 'petallike', 'bowery', 'foliolate', 'leafy', 'bifoliate']
senticnet['uniform'] = [0.075, 0.216, -0.165, 0.211, '#interesting', '#admirable', 0.112, 'suit', 'cape', 'outfit', 'robe', 'jacket']
senticnet['uniformness'] = [-0.638, 0, 0.822, -0.953, '#angry', '#disgusting', -0.804, 'homogeneity', 'homogeneousness', 'consistency', 'consistence', 'similarity']
senticnet['unifying'] = [-0.938, 0, 0.944, -0.922, '#sad', '#angry', -0.935, 'combinative', 'combinatory', 'consolidative', 'integrative', 'combinatorial']
senticnet['unilateralism'] = [-0.506, 0, 0.734, -0.994, '#angry', '#disgusting', -0.745, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['unimaginable'] = [-0.808, 0, -0.803, -0.961, '#sad', '#disgusting', -0.857, 'unable', 'absurd', 'difficult', 'impratical', 'impossible']
senticnet['unimpeachable'] = [-0.718, 0, 0.785, -0.558, '#sad', '#angry', -0.687, 'unquestionable', 'acknowledged', 'for_sure', 'mathematical', 'beyond_doubt']
senticnet['unimportant'] = [-0.792, 0, 0.752, 0, '#sad', '#angry', -0.515, 'inconsequent', 'inconsequential', 'trivial', 'lightweight', 'insignificant']
senticnet['unimpressed'] = [-0.921, 0, 0.731, -0.852, '#sad', '#disgusting', -0.835, 'unaffected', 'untouched', 'uninfluenced', 'unswayed', 'immune']
senticnet['uninfluenced'] = [-0.921, 0, 0.731, -0.852, '#sad', '#disgusting', -0.835, 'unimpressed', 'untouched', 'unaffected', 'unswayed', 'immune']
senticnet['uninformed'] = [-0.981, 0, 0, -0.966, '#sad', '#disgusting', -0.649, 'naive', 'unenlightened', 'unread', 'unknowing', 'clueless']
senticnet['uninhabited'] = [-0.792, 0, 0.621, -0.502, '#sad', '#angry', -0.638, 'untenanted', 'unoccupied', 'derelict', 'deserted', 'depopulated']
senticnet['uninjured'] = [-0.958, 0, 0.712, -0.528, '#sad', '#angry', -0.733, 'uncut', 'unharmed', 'unscathed', 'unwounded', 'unhurt']
senticnet['unintelligibility'] = [0.813, -0.66, 0, 0.65, '#joyful', '#surprising', 0.708, 'nonsense', 'meaninglessness', 'word_salad', 'bunk', 'nonsensicality']
senticnet['unintended'] = [-0.833, 0, 0.508, -0.796, '#sad', '#disgusting', -0.712, 'unwitting', 'unplanned', 'unintentional', 'accidental', 'inadvertent']
senticnet['unintentional'] = [-0.833, 0, 0.508, -0.796, '#sad', '#disgusting', -0.712, 'unwitting', 'unplanned', 'unintended', 'accidental', 'inadvertent']
senticnet['uninterested'] = [-0.612, 0, 0.764, -0.97, '#angry', '#disgusting', -0.782, 'apathetic', 'benumbed', 'indifferent', 'dismissive', 'dulled']
senticnet['uninteresting'] = [-0.661, 0, 0.594, -0.675, '#sad', '#disgusting', -0.643, 'boring', 'deadening', 'irksome', 'tiresome', 'wearisome']
senticnet['uninterestingness'] = [-0.685, 0, 0.93, -0.852, '#angry', '#disgusting', -0.822, 'powerlessness', 'ponderousness', 'impotence', 'impotency', 'dullness']
senticnet['union'] = [0.075, 0.216, -0.165, 0.211, '#interesting', '#admirable', 0.112, 'association', 'agency', 'team_up', 'join', 'egalitarian_society']
senticnet['unipolar_depression'] = [-0.786, 0, 0.918, -0.963, '#angry', '#disgusting', -0.889, 'major_depressive_episode', 'depression', 'depressive_disorder', 'clinical_depression', 'involutional_depression']
senticnet['unique'] = [0.957, 0, 0, 0.759, '#joyful', '#admirable', 0.572, 'hard_find', 'nice', 'compliment', 'lovely', 'fair']
senticnet['unique_animal'] = [0.816, 0.756, 0, 0.747, '#joyful', '#interesting', 0.773, 'attractive', 'become_extinct', 'exotic', 'nocturnal', 'beautiful_creature']
senticnet['unit'] = [0.052, 0.109, 0.086, 0.116, '#interesting', '#admirable', 0.064, 'size', 'magnitude', 'ounce', 'measure', 'measurement']
senticnet['unit_language'] = [-0.031, 0.119, -0.11, 0.216, '#interesting', '#admirable', 0.065, 'snail_mail', 'message', 'grammar_part', 'speech_part', 'word']
senticnet['unit_of_measure'] = [0, 0.126, 0.104, 0.172, '#interesting', '#admirable', 0.065, 'mass_measure', 'measurement_unit', 'imperial_measurement', 'liquid_measurement', 'measure_unit']
senticnet['unit_of_measurement'] = [0, 0.975, 0, 0.921, '#interesting', '#admirable', 0.632, 'measurement_unit', 'length_measurement', 'imperial_measurement', 'length', 'single']
senticnet['unite'] = [0.084, 0.122, -0.086, 0.137, '#interesting', '#admirable', 0.086, 'democratic_country', 'pledge_allegiance', 'political_unit', 'state', 'free_country']
senticnet['united'] = [0, 0, -0.708, -0.977, '#scared', '#disgusting', -0.562, 'unify', 'merge', 'connect', 'combine', 'link']
senticnet['united_country'] = [0.041, 0.104, 0, 0.072, '#interesting', '#admirable', 0.072, 'political_entity', 'political_unit', 'political_state', 'pledge_allegiance', 'democratic_country']
senticnet['united_nations'] = [0, 0.707, 0, 0.935, '#interesting', '#admirable', 0.547, 'congress', 'meeting', 'government_job', 'discussion', 'world_hunger']
senticnet['united_states'] = [0, 0.797, 0, 0.96, '#interesting', '#admirable', 0.586, 'state_america', 'state', 'usa', 'name_state', 'large_state']
senticnet['unity'] = [0.099, 0.073, 0, 0.19, '#joyful', '#admirable', 0.121, 'country_person', 'political_state', 'large_state', 'political_division', 'political_unit']
senticnet['universal'] = [0.196, 0.129, -0.065, 0.184, '#joyful', '#admirable', 0.148, 'pleasant', 'pleasurable', 'bourgeois', 'important_human', 'good']
senticnet['universal_language'] = [0.08, 0, 0.048, 0.108, '#joyful', '#admirable', 0.047, 'instrumental', 'melodic_noise', 'common_language', 'vocal_music', 'form_expression']
senticnet['unix'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'solaris', 'window', 'many_windows', 'train_window', 'doorway']
senticnet['unjust'] = [-0.745, 0, 0.934, -0.859, '#angry', '#disgusting', -0.846, 'dirty', 'below_belt', 'foul', 'cheating', 'raw']
senticnet['unjustifiable'] = [-0.736, 0, 0.846, -0.687, '#sad', '#angry', -0.756, 'indefensible', 'unwarranted', 'insupportable', 'inexcusable', 'unwarrantable']
senticnet['unjustness'] = [0.871, -0.748, 0, 0.981, '#joyful', '#admirable', 0.867, 'unrighteousness', 'inequity', 'unfairness', 'wrong', 'wrongfulness']
senticnet['unkemptness'] = [-0.562, 0, 0.909, -0.626, '#angry', '#disgusting', -0.699, 'untidiness', 'disorder', 'slovenliness', 'sloppiness', 'disorderliness']
senticnet['unkind'] = [-0.728, 0, 0, -0.813, '#sad', '#disgusting', -0.514, 'mercilessness', 'ruthlessness', 'cruelly', 'pitilessness', 'unassertively']
senticnet['unkindness'] = [0.814, -0.95, 0, 0.918, '#surprising', '#admirable', 0.894, 'inconsideration', 'inconsiderateness', 'thoughtlessness', 'unhelpfulness', 'insensitivity']
senticnet['unknown'] = [-0.094, 0, 0, -0.199, '#sad', '#disgusting', -0.098, 'add_knowledge', 'learn', 'become_smart', 'discover', 'make_out_atom']
senticnet['unlatched'] = [-0.759, 0, 0.892, -0.684, '#sad', '#angry', -0.778, 'unbarred', 'unbolted', 'unfastened', 'unlocked', 'unsecured']
senticnet['unlawful'] = [0, 0, -0.948, -0.78, '#scared', '#disgusting', -0.576, 'illegitimate', 'unconventional', 'illicit', 'wrongful', 'improper']
senticnet['unlawful_carnal_knowledge'] = [0.542, -0.839, 0, 0.927, '#surprising', '#admirable', 0.769, 'incest', 'extramarital_sex', 'free_love', 'sexual_intercourse', 'intercourse']
senticnet['unlawfulness'] = [-0.722, 0, 0.742, -0.802, '#angry', '#disgusting', -0.755, 'illicitness', 'illegality', 'illegitimacy', 'shadiness', 'quality']
senticnet['unless'] = [-0.25, 0, -0.174, -0.082, '#sad', '#scared', -0.169, 'social_exclusion', 'exclusion_zone', 'isolation', 'exclusion', 'except']
senticnet['unlikeness'] = [-0.545, 0, 0.979, -0.858, '#angry', '#disgusting', -0.794, 'dissimilarity', 'dissimilitude', 'difference', 'heterology', 'disparateness']
senticnet['unlimited'] = [-0.031, 0.095, 0, 0.099, '#interesting', '#admirable', 0.054, 'infinite', 'around_earth', 'endless', 'radiant', 'limitless']
senticnet['unloading'] = [0.881, 0.879, 0, 0, '#joyful', '#interesting', 0.587, 'exhaust', 'discharge', 'drainage', 'waste', 'refuse']
senticnet['unlock'] = [-0.024, 0.122, 0, 0.137, '#interesting', '#admirable', 0.078, 'open_lock_door', 'hang_door', 'enter_room', 'control_access', 'separate_room']
senticnet['unlock_door'] = [-0.102, 0, 0, 0, '#sad', '#sad', -0.034, 'sell_car', 'door_open', 'own_car', 'shine_car', 'shoulder_burden']
senticnet['unlocked'] = [-0.759, 0, 0.892, -0.684, '#sad', '#angry', -0.778, 'unbarred', 'unbolted', 'unlatched', 'unfastened', 'unsecured']
senticnet['unlogical'] = [0.792, -0.867, 0, 0.888, '#surprising', '#admirable', 0.849, 'absurd', 'inconsequential', 'intuitive', 'visceral', 'nonrational']
senticnet['unloose'] = [0.714, -0.571, 0, 0.873, '#joyful', '#admirable', 0.719, 'bail_out', 'unspell', 'bail', 'unchain', 'run']
senticnet['unloosen'] = [0.92, -0.576, 0, 0.758, '#joyful', '#admirable', 0.751, 'bail_out', 'unspell', 'bail', 'unchain', 'run']
senticnet['unlove'] = [-0.732, 0, 0, -0.803, '#sad', '#disgusting', -0.512, 'betray', 'hear_bad_news', 'cause_suffer', 'lose_team', 'hate']
senticnet['unloved'] = [-0.859, 0, 0.655, -0.672, '#sad', '#disgusting', -0.729, 'lovelorn', 'unbeloved', 'bereft', 'estranged', 'disinherited']
senticnet['unloving'] = [-0.565, 0, 0.578, -0.744, '#angry', '#disgusting', -0.629, 'cold', 'frigid', 'loveless', 'detached', 'unaffectionate']
senticnet['unlucky'] = [0, 0, -0.909, -0.938, '#scared', '#disgusting', -0.616, 'luckless', 'ill-omened', 'ill-starred', 'doomed', 'ill-fated']
senticnet['unmalleable'] = [-0.998, 0, 0.754, -0.503, '#sad', '#angry', -0.752, 'intractable', 'stubborn', 'refractory', 'uncontrollable', 'balking']
senticnet['unmanageable'] = [-0.965, 0, 0.636, -0.85, '#sad', '#disgusting', -0.817, 'awkward', 'bunglesome', 'clumsy', 'cumbersome', 'ungainly']
senticnet['unmanful'] = [-0.63, 0, 0.986, -0.946, '#angry', '#disgusting', -0.854, 'womanish', 'effeminate', 'emasculate', 'cissy', 'sissified']
senticnet['unmanlike'] = [-0.776, 0, 0.566, -0.632, '#sad', '#disgusting', -0.658, 'womanish', 'effeminate', 'emasculate', 'cissy', 'sissified']
senticnet['unmanly'] = [-0.956, 0, 0.682, -0.89, '#sad', '#disgusting', -0.843, 'womanish', 'effeminate', 'emasculate', 'cissy', 'sissified']
senticnet['unmarked'] = [-0.603, 0, 0.564, -0.85, '#sad', '#disgusting', -0.672, 'unnoticed', 'ignored', 'unheeded', 'overlooked', 'unnoted']
senticnet['unmarred'] = [0.566, -0.588, 0, 0.597, '#surprising', '#admirable', 0.584, 'stainless', 'untainted', 'untarnished', 'unsullied', 'unstained']
senticnet['unmarried'] = [-0.73, 0, 0.729, -0.981, '#sad', '#disgusting', -0.813, 'unwed', 'unwedded', 'divorced', 'mateless', 'widowed']
senticnet['unmask'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'find_out', 'dig_out', 'unearth', 'become_aware', 'dish_out']
senticnet['unmatched'] = [0, 0, 0.778, -0.76, '#angry', '#disgusting', -0.513, 'mismated', 'unsuited', 'mismatched', 'odd', 'incompatible']
senticnet['unmeasurable'] = [-0.978, 0, 0.66, -0.885, '#sad', '#disgusting', -0.841, 'illimitable', 'limitless', 'measureless', 'unmeasured', 'abysmal']
senticnet['unmeasured'] = [-0.808, 0, 0.761, -0.705, '#sad', '#angry', -0.758, 'illimitable', 'limitless', 'measureless', 'immeasurable', 'abysmal']
senticnet['unmentionable'] = [-0.75, 0, 0.614, -0.743, '#sad', '#disgusting', -0.702, 'out', 'impermissible', 'untouchable', 'taboo', 'tabu']
senticnet['unmerciful'] = [0.563, -0.56, 0, 0.722, '#joyful', '#admirable', 0.615, 'mortal', 'cutthroat', 'bowelless', 'tigerish', 'pitiless']
senticnet['unmethodical'] = [-0.988, 0, 0.811, -0.958, '#sad', '#disgusting', -0.919, 'disorganized', 'upset', 'confused', 'scrambled', 'undone']
senticnet['unmitigated'] = [-0.657, 0, 0.799, -0.751, '#angry', '#disgusting', -0.736, 'undiminished', 'unrelieved', 'everlasting', 'unadulterated', 'bloody']
senticnet['unmolested'] = [-0.591, 0, 0.799, -0.698, '#angry', '#disgusting', -0.696, 'dreamless', 'undisturbed', 'untroubled', 'unworried', 'unconcerned']
senticnet['unmovable'] = [-0.576, 0, 0.97, -0.761, '#angry', '#disgusting', -0.769, 'immovable', 'immoveable', 'immobile', 'nonmotile', 'immotile']
senticnet['unmoving'] = [-0.802, 0, 0.547, -0.865, '#sad', '#disgusting', -0.738, 'motionless', 'rigid', 'inactive', 'still', 'static']
senticnet['unmutilated'] = [0.606, -0.887, 0, 0.962, '#surprising', '#admirable', 0.818, 'stainless', 'untainted', 'untarnished', 'unsullied', 'unstained']
senticnet['unnatural'] = [-0.7, 0, 0.77, -0.754, '#angry', '#disgusting', -0.741, 'fake', 'artificial', 'man_made', 'artificial_sea', 'artificial_taste']
senticnet['unnaturalness'] = [-0.685, 0, 0.863, -0.694, '#angry', '#disgusting', -0.747, 'pretension', 'artificiality', 'affectedness', 'supernaturalness', 'largeness']
senticnet['unnecessary'] = [-0.718, 0, 0.711, 0, '#sad', '#angry', -0.476, 'needless', 'vain', 'idle', 'useless', 'pointless']
senticnet['unnerve'] = [0, 0, 0.956, -0.913, '#angry', '#disgusting', -0.623, 'upset', 'faze', 'discompose', 'discomfit', 'disconcert']
senticnet['unnoted'] = [-0.603, 0, 0.564, -0.85, '#sad', '#disgusting', -0.672, 'unmarked', 'ignored', 'unheeded', 'overlooked', 'unnoticed']
senticnet['unnoticed'] = [-0.603, 0, 0.564, -0.85, '#sad', '#disgusting', -0.672, 'unmarked', 'ignored', 'unheeded', 'overlooked', 'unnoted']
senticnet['unobservable'] = [-0.781, 0, 0.792, -0.616, '#sad', '#angry', -0.73, 'incognizable', 'incognoscible', 'insensible', 'imperceptible', 'indiscernible']
senticnet['unobstructed'] = [0.924, -0.834, 0, 0.807, '#joyful', '#surprising', 0.855, 'unclogged', 'clear', 'patent', 'open', 'unimpeded']
senticnet['unobtainable'] = [-0.777, 0, 0.644, -0.687, '#sad', '#disgusting', -0.703, 'unavailable', 'unprocurable', 'out_of_stock', 'gone', 'untouchable']
senticnet['unoccupied'] = [-0.792, 0, 0.621, -0.502, '#sad', '#angry', -0.638, 'untenanted', 'uninhabited', 'derelict', 'deserted', 'depopulated']
senticnet['unofficial'] = [-0.904, 0, 0.569, -0.967, '#sad', '#disgusting', -0.813, 'unauthorized', 'wildcat', 'informal', 'loose', 'drumhead']
senticnet['unoriented'] = [-0.89, 0, 0.584, -0.619, '#sad', '#disgusting', -0.698, 'lost', 'confused', 'alienated', 'disoriented', 'anomic']
senticnet['unoriginal'] = [-0.655, 0, 0.804, -0.945, '#angry', '#disgusting', -0.801, 'cold', 'cliched', 'dusty', 'slavish', 'banal']
senticnet['unornamented'] = [-0.752, 0, 0.869, -0.737, '#sad', '#angry', -0.786, 'spare', 'unembellished', 'unadorned', 'bare', 'plain']
senticnet['unoxygenated'] = [-0.586, 0, 0.593, -0.979, '#angry', '#disgusting', -0.719, 'unvented', 'fuggy', 'unaerated', 'unventilated', 'stuffy']
senticnet['unpaid'] = [-0.972, 0, 0.53, -0.666, '#sad', '#disgusting', -0.723, 'uncompensated', 'unsalaried', 'buckshee', 'undischarged', 'complimentary']
senticnet['unpalatability'] = [-0.522, 0, 0.703, -0.718, '#angry', '#disgusting', -0.648, 'distastefulness', 'taste_property', 'disgustingness', 'unsavoriness', 'nauseatingness']
senticnet['unpalatableness'] = [-0.779, 0, 0.717, -0.544, '#sad', '#angry', -0.68, 'distastefulness', 'taste_property', 'disgustingness', 'unsavoriness', 'nauseatingness']
senticnet['unpardonable'] = [-0.53, 0, 0.901, -0.511, '#sad', '#angry', -0.647, 'inexpiable', 'inexcusable', 'deadly', 'unforgivable', 'mortal']
senticnet['unpeaceable'] = [-0.5, 0, 0.982, -0.85, '#angry', '#disgusting', -0.777, 'unpeaceful', 'stormy', 'tempestuous', 'militant', 'belligerent']
senticnet['unpeaceful'] = [-0.5, 0, 0.982, -0.85, '#angry', '#disgusting', -0.777, 'unpeaceable', 'stormy', 'tempestuous', 'militant', 'belligerent']
senticnet['unperceivable'] = [-0.535, 0, 0.661, -0.834, '#angry', '#disgusting', -0.677, 'incognizable', 'incognoscible', 'insensible', 'unobservable', 'indiscernible']
senticnet['unpersuadable'] = [-0.77, 0, 0.639, -0.798, '#sad', '#disgusting', -0.736, 'insusceptible', 'unsuasible', 'unresponsive', 'resistant', 'incapable']
senticnet['unpersuaded'] = [-0.677, 0, 0.715, -0.89, '#angry', '#disgusting', -0.761, 'obstinate', 'unrepentant', 'impenitent', 'unconverted', 'unregenerated']
senticnet['unpersuasiveness'] = [-0.962, 0, 0.531, -0.518, '#sad', '#angry', -0.67, 'impuissance', 'weakness', 'impotence', 'uninterestingness', 'helplessness']
senticnet['unplaced'] = [-0.747, 0, 0.792, -0.577, '#sad', '#angry', -0.705, 'sunk', 'unsuccessful', 'out', 'pointless', 'defeated']
senticnet['unplanned'] = [-0.833, 0, 0.508, -0.796, '#sad', '#disgusting', -0.712, 'unwitting', 'unintended', 'unintentional', 'accidental', 'inadvertent']
senticnet['unpleasant'] = [-0.704, 0, 0.986, -0.956, '#angry', '#disgusting', -0.882, 'body_reaction', 'symptom', 'sometimes_painful', 'mock', 'sign_sickness']
senticnet['unpleasant_person'] = [-0.854, 0, 0.644, -0.983, '#sad', '#disgusting', -0.827, 'bastard', 'dickhead', 'mother_fucker', 'motherfucker', 'son_of_bitch']
senticnet['unpleasant_woman'] = [-0.558, 0, 0.956, -0.541, '#sad', '#angry', -0.685, 'termagant', 'old_bag', 'shrew', 'frump', 'hellcat']
senticnet['unpleasantness'] = [-0.841, 0, 0, -0.77, '#sad', '#disgusting', -0.537, 'repetitive_task', 'monotony', 'screw_up', 'wrongdoing', 'reprimand']
senticnet['unplug'] = [-0.072, -0.017, 0, -0.151, '#sad', '#disgusting', -0.069, 'stop_move', 'hit_oneself_head', 'become_unconscious', 'lose_consciousness', 'stop_think']
senticnet['unpredictability'] = [-0.526, 0, 0.959, -0.701, '#angry', '#disgusting', -0.729, 'irresoluteness', 'indecisiveness', 'indecision', 'trait', 'volatility']
senticnet['unpredictable'] = [-0.732, 0, 0, -0.803, '#sad', '#disgusting', -0.512, 'uncontrollable', 'unstable', 'incalculable', 'uncertain', 'unreliable']
senticnet['unprepared'] = [-0.674, 0, 0.936, -0.555, '#sad', '#angry', -0.722, 'extemporaneous', 'extemporary', 'extempore', 'impromptu', 'unrehearsed']
senticnet['unprocurable'] = [-0.777, 0, 0.644, -0.687, '#sad', '#disgusting', -0.703, 'unobtainable', 'unavailable', 'out_of_stock', 'gone', 'untouchable']
senticnet['unproductive'] = [-0.608, 0, 0.761, -0.849, '#angry', '#disgusting', -0.739, 'vain', 'bootless', 'fruitless', 'futile', 'sleeveless']
senticnet['unprofitability'] = [-0.621, 0, 0.708, -0.619, '#sad', '#angry', -0.649, 'unfavorableness', 'unfavourableness', 'unfavorable_position', 'unprofitableness', 'disadvantage']
senticnet['unprofitable'] = [-0.546, 0, 0.739, -0.643, '#angry', '#disgusting', -0.643, 'unremunerative', 'idle', 'lean', 'dead', 'marginal']
senticnet['unprofitableness'] = [-0.621, 0, 0.708, -0.619, '#sad', '#angry', -0.649, 'unfavorableness', 'unfavourableness', 'unfavorable_position', 'disadvantage', 'unprofitability']
senticnet['unprompted'] = [-0.838, 0, 0.812, -0.92, '#sad', '#disgusting', -0.857, 'natural', 'impulsive', 'intuitive', 'instinctive', 'spontaneous']
senticnet['unpronounceable'] = [-0.947, 0, 0.636, -0.745, '#sad', '#disgusting', -0.776, 'incommunicado', 'incommunicative', 'impassive', 'inexpressive', 'silent']
senticnet['unprotect_sex'] = [0.049, 0.098, -0.079, 0.121, '#interesting', '#admirable', 0.063, 'procreate', 'reproduce', 'start_family', 'cause_cold', 'copulate']
senticnet['unprotected'] = [-0.924, 0, 0.969, -0.911, '#sad', '#angry', -0.935, 'exposed', 'defenseless', 'open', 'naked', 'unshielded']
senticnet['unqualified'] = [-0.669, 0, 0.721, -0.539, '#sad', '#angry', -0.643, 'unlimited', 'outright', 'unconditional', 'categoric', 'categorical']
senticnet['unquenchable'] = [-0.728, 0, 0.933, -0.505, '#sad', '#angry', -0.722, 'unsatisfied', 'quenchless', 'insatiable', 'unsated', 'unsatiated']
senticnet['unquestionability'] = [0.904, -0.804, 0, 0.611, '#joyful', '#surprising', 0.773, 'demonstrability', 'provability', 'positivity', 'positiveness', 'certainty']
senticnet['unquestionable'] = [0, 0.746, 0, 0.798, '#interesting', '#admirable', 0.515, 'unimpeachable', 'for_sure', 'mathematical', 'beyond_doubt', 'sure']
senticnet['unquestionableness'] = [0.946, -0.895, 0, 0.942, '#joyful', '#admirable', 0.928, 'demonstrability', 'provability', 'positivity', 'positiveness', 'certainty']
senticnet['unquestioned'] = [-0.957, 0, 0.783, -0.654, '#sad', '#angry', -0.798, 'unchallengeable', 'undisputed', 'unchallenged', 'noncontroversial', 'agreed_upon']
senticnet['unquiet'] = [-0.786, 0, 0, -0.927, '#sad', '#disgusting', -0.571, 'uneasy', 'sinking_feeling', 'sinking', 'scruple', 'misgiving']
senticnet['unreactive'] = [-0.541, 0, 0.868, -0.968, '#angry', '#disgusting', -0.792, 'inactive', 'inert', 'indifferent', 'stable', 'neutral']
senticnet['unready'] = [-0.926, 0, 0.659, -0.814, '#sad', '#disgusting', -0.8, 'unripe', 'napping', 'off_guard', 'off_one_guard', 'off_his_guard']
senticnet['unreal'] = [-0.757, 0, 0, -0.754, '#sad', '#disgusting', -0.504, 'fabled', 'fictitious', 'pretend', 'make_believe', 'made_up']
senticnet['unrealistic'] = [-0.93, 0, 0.94, -0.772, '#sad', '#angry', -0.881, 'delusive', 'phantasmagoric', 'phantasmagorical', 'surrealistic', 'wild']
senticnet['unreality'] = [-0.953, 0, 0.909, -0.974, '#sad', '#disgusting', -0.945, 'incorporeality', 'insubstantiality', 'quality', 'intangibility', 'intangibleness']
senticnet['unreasonable'] = [-0.982, 0, 0.646, -0.982, '#sad', '#disgusting', -0.87, 'indefensible', 'reasonless', 'untenable', 'senseless', 'unwarranted']
senticnet['unrecognisable'] = [-0.826, 0, 0.758, -0.703, '#sad', '#angry', -0.762, 'unclassifiable', 'unrecognizable', 'unidentifiable', 'intangible', 'undiagnosable']
senticnet['unrecognizable'] = [-0.826, 0, 0.758, -0.703, '#sad', '#angry', -0.762, 'unclassifiable', 'unidentifiable', 'unrecognisable', 'intangible', 'undiagnosable']
senticnet['unrecognized'] = [-0.751, 0, 0.563, -0.986, '#sad', '#disgusting', -0.767, 'unsung', 'unacknowledged', 'unappreciated', 'unvalued', 'unconfessed']
senticnet['unreconciled'] = [-0.971, 0, 0.712, -0.786, '#sad', '#disgusting', -0.823, 'discrepant', 'inconsistent', 'scratchy', 'uneven', 'contradictory']
senticnet['unreformable'] = [-0.836, 0, 0.855, -0.893, '#angry', '#disgusting', -0.861, 'uncorrectable', 'incorrigible', 'unregenerate', 'uncontrollable', 'unmanageable']
senticnet['unregenerate'] = [-0.964, 0, 0.858, -0.876, '#sad', '#disgusting', -0.899, 'contrarious', 'dogged', 'pertinacious', 'cantankerous', 'bolshy']
senticnet['unregenerated'] = [-0.677, 0, 0.715, -0.89, '#angry', '#disgusting', -0.761, 'obstinate', 'unrepentant', 'impenitent', 'unconverted', 'unpersuaded']
senticnet['unregularity'] = [-0.897, 0, 0.972, -0.502, '#sad', '#angry', -0.79, 'unsteadiness', 'haphazardness', 'stochasticity', 'variability', 'fitfulness']
senticnet['unrehearsed'] = [-0.674, 0, 0.936, -0.555, '#sad', '#angry', -0.722, 'extemporaneous', 'extemporary', 'extempore', 'impromptu', 'unprepared']
senticnet['unreleased'] = [-0.725, 0, 0.728, -0.5, '#sad', '#angry', -0.651, 'quelled', 'squelched', 'burked', 'quenched', 'suppressed']
senticnet['unreliability'] = [-0.878, 0, 0.508, -0.946, '#sad', '#disgusting', -0.777, 'irresponsibility', 'irresponsibleness', 'instability', 'irreproducibility', 'fallibility']
senticnet['unreliable'] = [-0.732, 0, 0, -0.803, '#sad', '#disgusting', -0.512, 'uncontrollable', 'unpredictable', 'unstable', 'incalculable', 'uncertain']
senticnet['unreliableness'] = [-0.91, 0, 0.795, -0.662, '#sad', '#angry', -0.789, 'irresponsibility', 'irresponsibleness', 'instability', 'irreproducibility', 'fallibility']
senticnet['unrelieved'] = [-0.657, 0, 0.799, -0.751, '#angry', '#disgusting', -0.736, 'undiminished', 'unmitigated', 'everlasting', 'unadulterated', 'bloody']
senticnet['unremunerative'] = [-0.546, 0, 0.739, -0.643, '#angry', '#disgusting', -0.643, 'unprofitable', 'idle', 'lean', 'dead', 'marginal']
senticnet['unrepentant'] = [-0.677, 0, 0.715, -0.89, '#angry', '#disgusting', -0.761, 'obstinate', 'unregenerated', 'impenitent', 'unconverted', 'unpersuaded']
senticnet['unresolved'] = [-0.527, 0, 0.902, -0.735, '#angry', '#disgusting', -0.721, 'discordant', 'dissonant', 'inharmonious', 'false', 'disharmonious']
senticnet['unrespectability'] = [-0.774, 0, 0.748, -0.606, '#sad', '#angry', -0.709, 'ignobleness', 'ignobility', 'sleaziness', 'dishonorableness', 'disreputability']
senticnet['unresponsive'] = [-0.77, 0, 0.639, -0.798, '#sad', '#disgusting', -0.736, 'unpersuadable', 'unsuasible', 'insusceptible', 'resistant', 'incapable']
senticnet['unrest'] = [-0.786, 0, 0.994, -0.768, '#sad', '#angry', -0.849, 'turmoil', 'tumult', 'foment', 'agitate', 'agitated']
senticnet['unrestrained'] = [-0.971, 0, 0.569, -0.721, '#sad', '#disgusting', -0.754, 'unbridled', 'unchecked', 'uncurbed', 'unhampered', 'unhindered']
senticnet['unrestraint'] = [-0.832, 0, 0.531, -0.595, '#sad', '#disgusting', -0.653, 'indulgence', 'incontinence', 'trait', 'dissoluteness', 'indiscipline']
senticnet['unrighteousness'] = [0.673, -0.663, 0, 0.566, '#joyful', '#surprising', 0.634, 'wickedness', 'impiety', 'impiousness', 'unjustness', 'dishonor']
senticnet['unripe'] = [-0.926, 0, 0.659, -0.814, '#sad', '#disgusting', -0.8, 'unready', 'napping', 'off_guard', 'off_one_guard', 'off_his_guard']
senticnet['unruffled'] = [0.553, 0.658, -0.251, 0.271, '#joyful', '#interesting', 0.41, 'placid', 'placidly', 'placidity', 'placidness', 'tranquil']
senticnet['unruliness'] = [-0.664, 0, 0.649, -0.764, '#sad', '#disgusting', -0.692, 'contrariness', 'wildness', 'intractability', 'intractableness', 'perversity']
senticnet['unruly'] = [-0.642, 0, 0.941, -0.664, '#angry', '#disgusting', -0.749, 'rowdy', 'boisterous', 'disorderly', 'rambunctious', 'robustious']
senticnet['unsafe'] = [-0.742, 0, 0.781, -0.98, '#angry', '#disgusting', -0.834, 'reprimand', 'caution', 'big_monster', 'kidnap', 'mock']
senticnet['unsafe_sex'] = [-0.909, 0, 0.202, -1.0, '#sad', '#disgusting', -0.704, 'sickness', 'sexually_transmitted_disease', 'social_disease', 'std', 'sex_without_condom']
senticnet['unsalaried'] = [-0.972, 0, 0.53, -0.666, '#sad', '#disgusting', -0.723, 'uncompensated', 'unpaid', 'buckshee', 'undischarged', 'complimentary']
senticnet['unsalted'] = [-0.717, 0, 0.559, -0.957, '#sad', '#disgusting', -0.744, 'unseasoned', 'tasteless', 'flavorless', 'flavourless', 'savorless']
senticnet['unsanitariness'] = [-0.687, 0, 0.529, -0.694, '#sad', '#disgusting', -0.637, 'nastiness', 'filth', 'filthiness', 'dunghill', 'sanitary_condition']
senticnet['unsated'] = [-0.728, 0, 0.933, -0.505, '#sad', '#angry', -0.722, 'unsatisfied', 'quenchless', 'unquenchable', 'insatiable', 'unsatiated']
senticnet['unsatiable'] = [-0.676, 0, 0.931, -0.693, '#angry', '#disgusting', -0.767, 'unsatisfied', 'quenchless', 'unquenchable', 'unsated', 'unsatiated']
senticnet['unsatiated'] = [-0.728, 0, 0.933, -0.505, '#sad', '#angry', -0.722, 'unsatisfied', 'quenchless', 'unquenchable', 'unsated', 'insatiable']
senticnet['unsatisfactoriness'] = [0.774, -0.827, 0, 0.63, '#joyful', '#surprising', 0.744, 'quality', 'perishability', 'perishableness', 'inadequateness', 'inadequacy']
senticnet['unsatisfactory'] = [-0.751, 0, 0.785, -0.7, '#sad', '#angry', -0.745, 'disappointing', 'dissatisfactory', 'unsatisfying', 'off', 'unacceptable']
senticnet['unsatisfied'] = [-0.88, 0, 0.718, -0.923, '#sad', '#disgusting', -0.84, 'ungratified', 'disaffected', 'malcontent', 'discontented', 'restless']
senticnet['unsatisfying'] = [-0.751, 0, 0.785, -0.7, '#sad', '#angry', -0.745, 'disappointing', 'dissatisfactory', 'unsatisfactory', 'off', 'unacceptable']
senticnet['unsavoriness'] = [-0.522, 0, 0.703, -0.718, '#angry', '#disgusting', -0.648, 'distastefulness', 'taste_property', 'disgustingness', 'unpalatability', 'nauseatingness']
senticnet['unscathed'] = [0.757, 0, 0, 0.775, '#joyful', '#admirable', 0.511, 'uncut', 'unharmed', 'uninjured', 'unwounded', 'unhurt']
senticnet['unscrew'] = [0.062, -0.03, 0, 0, '#joyful', '#surprising', 0.031, 'twirl_around', 'dance_well', 'upgrade', 'turn_around', 'adjust_volume']
senticnet['unseasoned'] = [-0.717, 0, 0.559, -0.957, '#sad', '#disgusting', -0.744, 'tasteless', 'unsalted', 'flavorless', 'flavourless', 'savorless']
senticnet['unsecured'] = [-0.759, 0, 0.892, -0.684, '#sad', '#angry', -0.778, 'unbarred', 'unbolted', 'unlatched', 'unlocked', 'unfastened']
senticnet['unseeable'] = [-0.811, 0, 0.945, -0.514, '#sad', '#angry', -0.757, 'occult', 'concealed', 'nonvisual', 'hidden', 'out_of_sight']
senticnet['unseemly'] = [-0.648, 0, 0.52, -0.532, '#sad', '#disgusting', -0.567, 'wrong', 'incorrect', 'unbecoming', 'uncomely', 'improper']
senticnet['unsettle'] = [-0.142, 0, -0.152, -0.144, '#scared', '#disgusting', -0.146, 'nightmare', 'sleepwalk', 'reflect', 'pleasant_thought', 'doze_off']
senticnet['unsettled'] = [-0.604, 0, 0.722, -0.843, '#angry', '#disgusting', -0.723, 'undetermined', 'undecided', 'tentative', 'unresolved', 'open']
senticnet['unsexed'] = [0.976, -0.958, 0, 0.876, '#joyful', '#surprising', 0.937, 'cut', 'altered', 'neutered', 'emasculated', 'gelded']
senticnet['unshaped'] = [-0.646, 0, 0.557, -0.739, '#sad', '#disgusting', -0.647, 'formless', 'amorphous', 'shapeless', 'unformed', 'unshapen']
senticnet['unshapely'] = [-0.737, 0, 0.904, -0.531, '#sad', '#angry', -0.724, 'acromegalic', 'shapeless', 'lumpy', 'deformed', 'malformed']
senticnet['unshapen'] = [-0.646, 0, 0.557, -0.739, '#sad', '#disgusting', -0.647, 'formless', 'amorphous', 'shapeless', 'unshaped', 'unformed']
senticnet['unshared'] = [-0.77, 0, 0.577, -0.782, '#sad', '#disgusting', -0.71, 'undivided', 'exclusive', 'sole', 'individual', 'single']
senticnet['unsharpened'] = [-0.043, -0.04, -0.049, -0.046, '#scared', '#disgusting', -0.033, 'blunted', 'dull', 'blunt', 'insensitive', 'edgeless']
senticnet['unshaved'] = [-0.945, 0, 0.84, -0.917, '#sad', '#disgusting', -0.901, 'bearded', 'barbate', 'bewhiskered', 'whiskered', 'whiskery']
senticnet['unshaven'] = [-0.644, 0, 0.632, -0.612, '#sad', '#angry', -0.629, 'bearded', 'barbate', 'bewhiskered', 'whiskered', 'whiskery']
senticnet['unshielded'] = [-0.924, 0, 0.969, -0.911, '#sad', '#angry', -0.935, 'exposed', 'defenseless', 'open', 'naked', 'unprotected']
senticnet['unsightliness'] = [-0.874, 0, 0.584, -0.711, '#sad', '#disgusting', -0.723, 'ugliness', 'eyesore', 'hideousness', 'unattractiveness', 'garishness']
senticnet['unsimilarity'] = [-0.757, 0, 0.69, -0.695, '#sad', '#disgusting', -0.714, 'unlikeness', 'dissimilitude', 'difference', 'heterology', 'disparateness']
senticnet['unskilled'] = [-0.983, 0, 0.505, -0.832, '#sad', '#disgusting', -0.773, 'lowly', 'bungled', 'botched', 'fumbling', 'bungling']
senticnet['unskillfulness'] = [0.983, -0.637, 0, 0.697, '#joyful', '#admirable', 0.772, 'amateurishness', 'inability', 'ineptness', 'clumsiness', 'awkwardness']
senticnet['unsmooth'] = [-0.774, 0, 0.626, -0.786, '#sad', '#disgusting', -0.729, 'bumpy', 'scabrous', 'lepidote', 'leprose', 'roughish']
senticnet['unsociability'] = [0.72, -0.727, 0, 0.506, '#joyful', '#surprising', 0.651, 'standoffishness', 'withdrawnness', 'closeness', 'secretiveness', 'remoteness']
senticnet['unsociableness'] = [0.831, -0.984, 0, 0.868, '#surprising', '#admirable', 0.894, 'standoffishness', 'withdrawnness', 'closeness', 'secretiveness', 'remoteness']
senticnet['unsocial'] = [-0.981, 0, 0.582, -0.561, '#sad', '#angry', -0.708, 'asocial', 'antisocial', 'lonely', 'withdrawn', 'solitary']
senticnet['unsounded'] = [-0.998, 0, 0.798, -0.716, '#sad', '#angry', -0.837, 'silent', 'voiceless', 'inaudible', 'breathed', 'supersonic']
senticnet['unspell'] = [0.915, -0.897, 0, 0.936, '#joyful', '#admirable', 0.916, 'free', 'unloose', 'unloosen', 'liberate', 'release']
senticnet['unstable'] = [-0.221, -0.206, 0.134, -0.329, '#sad', '#disgusting', -0.159, 'eaten_shark', 'foolish', 'naughty', 'small_boat', 'big_boat']
senticnet['unsteady'] = [-0.569, 0, 0.849, -0.618, '#angry', '#disgusting', -0.679, 'convulsive', 'arrhythmic', 'jerky', 'spasmodic', 'spastic']
senticnet['unstressed'] = [-0.9, 0, 0.972, -0.794, '#sad', '#angry', -0.889, 'feminine', 'weak', 'light', 'unemphatic', 'unaccented']
senticnet['unsuasible'] = [-0.77, 0, 0.639, -0.798, '#sad', '#disgusting', -0.736, 'unpersuadable', 'insusceptible', 'unresponsive', 'resistant', 'incapable']
senticnet['unsubduable'] = [-0.738, 0, 0.732, -0.535, '#sad', '#angry', -0.668, 'insurmountable', 'insuperable', 'inexpugnable', 'indomitable', 'unconquerable']
senticnet['unsubstantial'] = [-0.86, 0, 0.632, -0.66, '#sad', '#disgusting', -0.717, 'airy', 'shadowy', 'stringy', 'wraithlike', 'ethereal']
senticnet['unsuccessful'] = [-0.747, 0, 0.792, -0.577, '#sad', '#angry', -0.705, 'sunk', 'unplaced', 'out', 'pointless', 'defeated']
senticnet['unsuccessful_person'] = [-0.577, 0, 0.57, -0.949, '#sad', '#disgusting', -0.699, 'unfortunate', 'insolvent', 'underdog', 'bankrupt', 'dud']
senticnet['unsuitability'] = [0.605, -0.836, 0, 0.935, '#surprising', '#admirable', 0.792, 'quality', 'unfitness', 'inappropriateness', 'inconvenience', 'unworthiness']
senticnet['unsuitable'] = [-0.608, 0, 0.832, -0.537, '#sad', '#angry', -0.659, 'ineligible', 'undesirable', 'unqualified', 'disqualified', 'unentitled']
senticnet['unsuitableness'] = [0.93, -0.504, 0, 0.694, '#joyful', '#admirable', 0.709, 'quality', 'unfitness', 'inappropriateness', 'inconvenience', 'unworthiness']
senticnet['unsuited'] = [-0.841, 0, 0.722, -0.767, '#sad', '#disgusting', -0.777, 'mismated', 'mismatched', 'unmatched', 'odd', 'incompatible']
senticnet['unsung'] = [-0.751, 0, 0.563, -0.986, '#sad', '#disgusting', -0.767, 'unacknowledged', 'unrecognized', 'unappreciated', 'unvalued', 'unconfessed']
senticnet['unsupportable'] = [-0.889, 0, 0.907, -0.847, '#sad', '#angry', -0.881, 'intolerable', 'unacceptable', 'bitter', 'impossible', 'insufferable']
senticnet['unsupported'] = [-0.974, 0, 0.59, -0.93, '#sad', '#disgusting', -0.831, 'idle', 'baseless', 'groundless', 'unfounded', 'unwarranted']
senticnet['unsure'] = [-0.734, 0, 0.786, -0.755, '#angry', '#disgusting', -0.758, 'diffidence', 'self-distrust', 'self-doubt', 'diffidently', 'unassertive']
senticnet['unsusceptible'] = [-0.96, 0, 0.91, -0.618, '#sad', '#angry', -0.829, 'unpersuadable', 'unsuasible', 'unresponsive', 'resistant', 'incapable']
senticnet['unswayed'] = [-0.921, 0, 0.731, -0.852, '#sad', '#disgusting', -0.835, 'unimpressed', 'untouched', 'uninfluenced', 'unaffected', 'immune']
senticnet['untamed'] = [-0.632, 0, 0.991, -0.734, '#angry', '#disgusting', -0.786, 'undomesticated', 'feral', 'ferine', 'savage', 'unbroken']
senticnet['untenable'] = [-0.982, 0, 0.646, -0.982, '#sad', '#disgusting', -0.87, 'indefensible', 'reasonless', 'unreasonable', 'senseless', 'unwarranted']
senticnet['untenanted'] = [-0.792, 0, 0.621, -0.502, '#sad', '#angry', -0.638, 'uninhabited', 'unoccupied', 'derelict', 'deserted', 'depopulated']
senticnet['unthoughtfulness'] = [-0.938, 0, 0.672, -0.946, '#sad', '#disgusting', -0.852, 'recklessness', 'foolhardiness', 'rashness', 'trait', 'impulsiveness']
senticnet['untidiness'] = [-0.562, 0, 0.909, -0.626, '#angry', '#disgusting', -0.699, 'unkemptness', 'disorder', 'slovenliness', 'sloppiness', 'disorderliness']
senticnet['untidy'] = [-0.852, 0, 0.985, -0.71, '#sad', '#angry', -0.849, 'messy', 'mussy', 'disheveled', 'dirty', 'frowzled']
senticnet['untimely'] = [0, 0, -0.906, -0.995, '#scared', '#disgusting', -0.634, 'wrong', 'prematurely', 'unseasonable', 'premature', 'ill-timed']
senticnet['untouched'] = [0, 0, 0.833, -0.861, '#angry', '#disgusting', -0.565, 'unimpressed', 'unaffected', 'uninfluenced', 'unswayed', 'immune']
senticnet['untoward'] = [-0.74, 0, 0.982, -0.819, '#angry', '#disgusting', -0.847, 'inauspicious', 'admonishing', 'reproachful', 'reproving', 'unfavorable']
senticnet['untransferable'] = [-0.805, 0, 0.815, -0.984, '#angry', '#disgusting', -0.868, 'infrangible', 'nontransferable', 'unassignable', 'inalienable', 'inviolable']
senticnet['untroubled'] = [-0.591, 0, 0.799, -0.698, '#angry', '#disgusting', -0.696, 'dreamless', 'undisturbed', 'unmolested', 'unworried', 'unconcerned']
senticnet['untrustiness'] = [-0.613, 0, 0.516, -0.965, '#sad', '#disgusting', -0.698, 'untrustworthiness', 'irresponsibility', 'undependability', 'undependableness', 'unreliability']
senticnet['untrustworthiness'] = [-0.613, 0, 0.516, -0.965, '#sad', '#disgusting', -0.698, 'irresponsibility', 'untrustiness', 'undependability', 'undependableness', 'unreliability']
senticnet['untruth'] = [-0.155, -0.011, -0.146, 0.066, '#sad', '#scared', -0.075, 'dishonesty', 'falsehood', 'deceit', 'fallacy', 'slumber']
senticnet['untune'] = [0.591, -0.591, 0, 0.751, '#joyful', '#surprising', 0.644, 'enervate', 'faze', 'unnerve', 'unsettle', 'dissolve']
senticnet['unusefulness'] = [0.526, -0.739, 0, 0.951, '#surprising', '#admirable', 0.739, 'quality', 'futility', 'impracticality', 'worthlessness', 'impracticability']
senticnet['unusual'] = [-0.221, -0.206, 0.134, -0.329, '#sad', '#disgusting', -0.159, 'uncommon', 'strange', 'unpleasant', 'unfamiliar', 'unaccustomed']
senticnet['unusual_face'] = [-0.085, 0, 0.015, 0, '#sad', '#angry', -0.033, 'use_hand_gesture', 'make_unusual_face', 'move_tongue', 'make_gesture', 'share_idea']
senticnet['unusual_language'] = [-0.043, -0.021, 0.041, -0.039, '#sad', '#angry', -0.034, 'jargon', 'lingo', 'cant', 'chatspeak', 'slang']
senticnet['unusual_person'] = [-0.881, 0, 0.882, -0.586, '#sad', '#angry', -0.783, 'mortal', 'behemoth', 'colossus', 'aberrant', 'giant']
senticnet['unvalued'] = [-0.751, 0, 0.563, -0.986, '#sad', '#disgusting', -0.767, 'unsung', 'unrecognized', 'unappreciated', 'unacknowledged', 'unconfessed']
senticnet['unvariedness'] = [-0.833, 0, 0.757, -0.655, '#sad', '#angry', -0.748, 'invariability', 'invariableness', 'invariance', 'sameness', 'monotony']
senticnet['unveil_truth'] = [0.781, 0.942, 0, 0, '#joyful', '#interesting', 0.574, 'add_knowledge', 'desire_education', 'learn_much', 'gain_knowledge', 'become_smart']
senticnet['unvented'] = [-0.586, 0, 0.593, -0.979, '#angry', '#disgusting', -0.719, 'unventilated', 'fuggy', 'unaerated', 'unoxygenated', 'stuffy']
senticnet['unventilated'] = [-0.586, 0, 0.593, -0.979, '#angry', '#disgusting', -0.719, 'unvented', 'fuggy', 'unaerated', 'unoxygenated', 'stuffy']
senticnet['unvoluntary'] = [-0.648, 0, 0.911, -0.852, '#angry', '#disgusting', -0.804, 'unwilling', 'unconscious', 'unwilled', 'driven', 'forced']
senticnet['unwanted'] = [-0.828, 0, 0.85, -0.709, '#sad', '#angry', -0.796, 'outcaste', 'casteless', 'unclaimed', 'unwelcome', 'undesired']
senticnet['unwanted_outcome'] = [-0.939, 0, 0.812, -0.964, '#sad', '#disgusting', -0.905, 'problem', 'trouble', 'punishment', 'exam_failed', 'job_interview_failed']
senticnet['unwarrantable'] = [-0.736, 0, 0.846, -0.687, '#sad', '#angry', -0.756, 'indefensible', 'unwarranted', 'insupportable', 'unjustifiable', 'inexcusable']
senticnet['unwarranted'] = [-0.736, 0, 0.846, -0.687, '#sad', '#angry', -0.756, 'indefensible', 'inexcusable', 'insupportable', 'unjustifiable', 'unwarrantable']
senticnet['unwed'] = [-0.73, 0, 0.729, -0.981, '#sad', '#disgusting', -0.813, 'unmarried', 'unmarriedded', 'divorced', 'mateless', 'widowed']
senticnet['unwedded'] = [-0.73, 0, 0.729, -0.981, '#sad', '#disgusting', -0.813, 'unwed', 'unmarried', 'divorced', 'mateless', 'widowed']
senticnet['unwelcome'] = [-0.828, 0, 0.85, -0.709, '#sad', '#angry', -0.796, 'outcaste', 'casteless', 'unclaimed', 'unwanted', 'undesired']
senticnet['unwelcome_person'] = [-0.874, 0, 0.693, -0.645, '#sad', '#angry', -0.737, 'sourpuss', 'picklepuss', 'troublemaker', 'trouble_maker', 'troubler']
senticnet['unwell'] = [-0.711, 0, -0.96, -0.943, '#scared', '#disgusting', -0.871, 'ill', 'unconscious', 'sick', 'feel_sick', 'sleep_apnea']
senticnet['unwholesome'] = [-0.754, 0, 0.909, -0.968, '#angry', '#disgusting', -0.877, 'noisome', 'unhealthy', 'morbid', 'nauseating', 'nauseous']
senticnet['unwholesomeness'] = [-0.721, 0, 0.71, -0.9, '#sad', '#disgusting', -0.777, 'perniciousness', 'harmfulness', 'toxicity', 'noisomeness', 'noxiousness']
senticnet['unwieldy'] = [0, 0, 0.721, -0.921, '#angry', '#disgusting', -0.547, 'cumbrous', 'ungainly', 'clumsy', 'cumbersome', 'awkward']
senticnet['unwilled'] = [-0.526, 0, 0.857, -0.754, '#angry', '#disgusting', -0.712, 'unwilling', 'unconscious', 'nonvoluntary', 'driven', 'forced']
senticnet['unwilling'] = [-0.526, 0, 0.857, -0.754, '#angry', '#disgusting', -0.712, 'nonvoluntary', 'unconscious', 'unwilled', 'driven', 'forced']
senticnet['unwillingness'] = [-0.991, 0, 0.907, -0.612, '#sad', '#angry', -0.837, 'resistance', 'disinclination', 'indisposition', 'temperament', 'hesitancy']
senticnet['unwind'] = [0.898, 0.757, 0, 0, '#joyful', '#interesting', 0.552, 'relaxation', 'stress_reduction', 'waste_time', 'enjoy_down_time', 'distraction']
senticnet['unwiseness'] = [0.661, -0.63, 0, 0.873, '#joyful', '#admirable', 0.721, 'injudiciousness', 'asininity', 'silliness', 'fatuity', 'fatuousness']
senticnet['unwitting'] = [-0.833, 0, 0.508, -0.796, '#sad', '#disgusting', -0.712, 'unintended', 'unplanned', 'unintentional', 'accidental', 'inadvertent']
senticnet['unworldly'] = [-0.948, 0, 0.779, -0.858, '#sad', '#disgusting', -0.862, 'eremitic', 'eremitical', 'cloistered', 'anchoritic', 'hermitic']
senticnet['unworried'] = [0.69, 0.626, -0.234, 0.317, '#joyful', '#interesting', 0.466, 'lightheartedness', 'insouciance', 'carefree', 'lightsomeness', 'carefreeness']
senticnet['unwounded'] = [-0.958, 0, 0.712, -0.528, '#sad', '#angry', -0.733, 'uncut', 'unharmed', 'unscathed', 'uninjured', 'unhurt']
senticnet['unwrap'] = [-0.962, 0, 0.69, -0.844, '#sad', '#disgusting', -0.832, 'bring_out', 'break', 'let_out', 'expose', 'bewray']
senticnet['unyieldingness'] = [-0.877, 0, 0.814, -0.978, '#sad', '#disgusting', -0.89, 'firmness', 'resolve', 'resoluteness', 'firmness_of_purpose', 'resolution']
senticnet['unzip_pant'] = [0, 0.071, -0.077, -0.081, '#scared', '#disgusting', -0.029, 'find_restroom', 'pull_down_pant', 'find_toilet', 'full_bladder', 'serve_beer']
senticnet['up_and_coming'] = [0.884, 0, 0, 0, '#joyful', '#joyful', 0.295, 'feel_good', 'active', 'feel_energetic', 'full_of_energy', 'power']
senticnet['up_date'] = [0.032, 0.205, -0.118, 0.294, '#interesting', '#admirable', 0.138, 'electrical_unit', 'relevant', 'contemporary', 'particular', 'actual']
senticnet['up_down'] = [0.03, 0.12, -0.046, 0.26, '#interesting', '#admirable', 0.121, 'hand_gesture', 'crest', 'goodbye', 'hand_motion', 'hand_movement']
senticnet['up_early'] = [0, 0.08, 0, 0.179, '#interesting', '#admirable', 0.086, 'wake_up_morning', 'awake', 'get_awake', 'gather_energy_tomorrow', 'sit_chair']
senticnet['up_front'] = [0, 0.09, -0.078, 0.148, '#interesting', '#admirable', 0.053, 'no_sight', 'clear', 'front', 'body_area', 'part_of_face']
senticnet['up_high'] = [-0.046, 0.078, 0, 0.174, '#interesting', '#admirable', 0.069, 'high_up', 'block_sun', 'crystal_clear', 'sun_cover', 'water_particle']
senticnet['up_hill'] = [0, 0.1, 0, 0.113, '#interesting', '#admirable', 0.071, 'steep', 'incline', 'slant', 'elevation', 'incline_plane']
senticnet['up_morning'] = [-0.03, 0, 0, -0.057, '#sad', '#disgusting', -0.029, 'up_early', 'get_out_of_bed', 'start_new_day', 'out_bed', 'wake_up_morning']
senticnet['up_mountain'] = [0, 0.137, -0.045, 0.125, '#interesting', '#admirable', 0.072, 'elevation', 'mountaineer', 'move_upward', 'up_hill', 'ascend']
senticnet['up_roar'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'agitation', 'fuss_about', 'commotion', 'disturbance', 'upset']
senticnet['up_to'] = [0.889, -0.904, 0, 0.559, '#joyful', '#surprising', 0.784, 'competent', 'adequate', 'adequate_to', 'equal_to', 'capable']
senticnet['upbraid'] = [-0.708, 0, 0.905, -0.84, '#angry', '#disgusting', -0.818, 'reproach', 'criminate', 'arraign', 'charge', 'accuse']
senticnet['upbraiding'] = [-0.554, 0, 0.95, -0.686, '#angry', '#disgusting', -0.73, 'reprimand', 'rebuke', 'reproof', 'reproval', 'reprehension']
senticnet['upbringing'] = [0.858, -0.778, 0, 0.735, '#joyful', '#surprising', 0.79, 'breeding', 'training', 'education', 'raising', 'nurture']
senticnet['update'] = [-0.078, -0.01, -0.097, 0, '#sad', '#scared', -0.055, 'up_date', 'happen_now', 'latest', 'relevant', 'timely']
senticnet['upgrade'] = [-0.066, 0.113, -0.099, 0.131, '#interesting', '#admirable', 0.026, 'deflate', 'spread_out', 'read_cover', 'scan', 'look_behind']
senticnet['upheaval'] = [-0.596, 0, 0.978, -0.977, '#angry', '#disgusting', -0.85, 'disorder', 'agitation', 'unrest', 'violence', 'roller_coaster']
senticnet['uphold'] = [0.594, -0.815, 0, 0.93, '#surprising', '#admirable', 0.78, 'hold', 'hold_on', 'persist', 'hang_on', 'maintain']
senticnet['upkeep'] = [0, 0.235, -0.129, 0.274, '#interesting', '#admirable', 0.127, 'preserve', 'keep', 'hold_onto', 'prevent', 'hold']
senticnet['uplift'] = [0.654, 0.617, -0.258, 0.328, '#joyful', '#interesting', 0.447, 'joyful', 'euphoric', 'euphoria', 'euphoriant', 'elating']
senticnet['upper'] = [0.022, 0.075, 0, 0.117, '#interesting', '#admirable', 0.071, 'status', 'taken', 'designation', 'upper_lower', 'social_status']
senticnet['upper_deck'] = [0.831, -0.821, 0, 0.826, '#joyful', '#admirable', 0.826, 'deck', 'freeboard_deck', 'weather_deck', 'shelter_deck', 'boat_deck']
senticnet['upper_hand'] = [0.11, 0.209, 0, 0.238, '#interesting', '#admirable', 0.186, 'extremity', 'hand', 'human_appendage', 'arm_part', 'body_limb']
senticnet['upper_lower'] = [0, 0.104, 0.05, 0.117, '#interesting', '#admirable', 0.057, 'upper', 'singular', 'lower', 'crate', 'lid']
senticnet['uppercase_bug'] = [-0.046, 0.121, 0, 0.178, '#interesting', '#admirable', 0.084, 'programming_bug', 'bug', 'code', 'developer', 'bad']
senticnet['upright'] = [0, 0.193, -0.095, 0.214, '#interesting', '#admirable', 0.104, 'vertical', 'standing', 'position', 'trust', 'support']
senticnet['uprise'] = [0, 0.707, 0, 0.924, '#interesting', '#admirable', 0.544, 'disagreement', 'fight_against', 'opposition', 'against', 'go_against']
senticnet['uproar'] = [-0.501, 0, 0.863, -0.578, '#angry', '#disgusting', -0.647, 'hurly_burly', 'kerfuffle', 'commotion', 'disruption', 'disturbance']
senticnet['uproarious'] = [0.893, 0.881, 0, 0, '#joyful', '#interesting', 0.591, 'screaming', 'hilariously', 'uproariously', 'hilarious', 'hilarity']
senticnet['uproariously'] = [0.695, 0.623, -0.231, 0.319, '#joyful', '#interesting', 0.469, 'uproarious', 'screaming', 'hilariously', 'hilarious', 'hilarity']
senticnet['upset'] = [-0.872, 0, -0.74, -0.727, '#sad', '#scared', -0.78, 'shame', 'humiliation', 'embarrassment', 'fright', 'dread']
senticnet['upset_person'] = [-0.758, 0, -0.751, -0.998, '#sad', '#disgusting', -0.836, 'tease', 'upset', 'lubricant', 'vaseline', 'piston']
senticnet['upset_stomach'] = [-0.867, 0, 0, -0.976, '#sad', '#disgusting', -0.614, 'decrease_hunger', 'feel_full', 'stomach_problem', 'get_fat', 'a_little_hungry']
senticnet['upshot'] = [0, 0, -0.888, -0.776, '#scared', '#disgusting', -0.555, 'consequence', 'result', 'outcome', 'effect', 'event']
senticnet['upside_down'] = [0, 0.769, 0, 0.866, '#interesting', '#admirable', 0.545, 'tree_house', 'same_again', 'reverse', 'spot', 'clothes_accessory']
senticnet['upstart'] = [-0.955, 0, 0.772, -0.894, '#sad', '#disgusting', -0.874, 'smart_aleck', 'wiseacre', 'snob', 'snooty', 'unpleasant_person']
senticnet['upsurge'] = [-0.529, 0, 0.884, -0.942, '#angry', '#disgusting', -0.785, 'debris_surge', 'debris_storm', 'flowing', 'onrush', 'flow']
senticnet['uptight'] = [0.72, 0.8, 0, 0, '#joyful', '#interesting', 0.507, 'high-strung', 'restive', 'overstrung', 'nervy', 'jumpy']
senticnet['upturned'] = [-0.652, 0, 0.935, -0.846, '#angry', '#disgusting', -0.811, 'upset', 'inverted', 'overturned', 'turned', 'reversed']
senticnet['upvalue'] = [-0.122, 0.193, 0.597, -0.627, '#angry', '#disgusting', -0.384, 'overrate', 'overvalue', 'overprize', 'overstimate', 'overprice']
senticnet['upward'] = [0, 0.21, -0.123, 0.224, '#interesting', '#admirable', 0.104, 'upwards', 'move_upward', 'raise_up', 'go_up', 'go_high']
senticnet['upward_movement'] = [0, 0.22, -0.11, 0.282, '#interesting', '#admirable', 0.131, 'move_upward', 'raise_up', 'go_up', 'levitate', 'rise_up']
senticnet['upwards'] = [-0.084, 0.127, -0.066, 0.149, '#interesting', '#admirable', 0.042, 'high', 'high_land', 'upward', 'mountaineer', 'cover_snow']
senticnet['uranium'] = [0, 0, -0.973, 0, '#scared', '#scared', -0.324, 'iodine', 'lithium', 'arsenic', 'element', 'manganese']
senticnet['uranoplasty'] = [0.703, -0.559, 0, 0.605, '#joyful', '#admirable', 0.622, 'operation', 'surgery', 'surgical_operation', 'surgical_procedure', 'surgical_process']
senticnet['urban'] = [0.077, 0.125, 0, 0.076, '#joyful', '#interesting', 0.093, 'many_cities', 'group_of_people', 'community', 'big_city_life', 'metropolis']
senticnet['urban_typhus'] = [0.579, -0.81, 0, 0.833, '#surprising', '#admirable', 0.741, 'murine_typhus', 'rat_typhus', 'typhus', 'endemic_typhus', 'rickettsial_disease']
senticnet['urchin'] = [0, 0, -0.069, 0, '#scared', '#scared', -0.023, 'mussel', 'fish', 'barnacle', 'scuba_diver', 'seal']
senticnet['urge'] = [0.655, 0.681, -0.3, 0.39, '#joyful', '#interesting', 0.475, 'favor', 'exhilarate', 'joyful', 'nigh', 'comfortableness']
senticnet['urge_incontinence'] = [-0.776, 0, 0.966, -0.518, '#sad', '#angry', -0.753, 'overflow_incontinence', 'incontinency', 'incontinence', 'stress_incontinence', 'enuresis']
senticnet['urge_on'] = [0.655, 0.635, -0.237, 0.3, '#joyful', '#interesting', 0.451, 'cheerfully', 'cheerful', 'jolly_up', 'hearten', 'chirk_up']
senticnet['urgency'] = [-0.891, 0.168, -0.609, 0.05, '#sad', '#scared', -0.427, 'emergency', 'emergency_situation', 'urgent', 'needful', 'alarm']
senticnet['urial'] = [-0.799, 0, 0.667, -0.668, '#sad', '#disgusting', -0.711, 'argali', 'argal', 'wild_sheep', 'white_sheep', 'mountain_sheep']
senticnet['urinary_incontinence'] = [-0.889, 0, 0.525, -0.92, '#sad', '#disgusting', -0.778, 'overflow_incontinence', 'incontinency', 'incontinence', 'stress_incontinence', 'urge_incontinence']
senticnet['urinate'] = [-0.059, 0, -0.055, -0.049, '#sad', '#scared', -0.054, 'empty_bladder', 'pee', 'go_potty', 'go_pee', 'go_toilet']
senticnet['urine'] = [-0.053, 0, 0, -0.117, '#sad', '#disgusting', -0.057, 'piss', 'pee', 'sour_milk', 'lemon', 'lifeguard']
senticnet['urn'] = [0, 0.082, -0.093, -0.122, '#scared', '#disgusting', -0.044, 'coffin', 'headstone', 'morgue', 'bury_body', 'casket']
senticnet['uropathy'] = [0.762, -0.842, 0, 0.831, '#surprising', '#admirable', 0.812, 'kidney_disease', 'renal_disorder', 'nephropathy', 'pathology', 'nephrosis']
senticnet['urticaria'] = [-0.556, 0, 0.536, -0.72, '#sad', '#disgusting', -0.604, 'hypersensitivity_reaction', 'rash', 'efflorescence', 'roseola', 'skin_rash']
senticnet['urtication'] = [-0.786, 0, 0.872, -0.505, '#sad', '#angry', -0.721, 'hypersensitivity_reaction', 'rash', 'efflorescence', 'roseola', 'skin_rash']
senticnet['usable'] = [0.834, -0.764, 0, 0, '#joyful', '#surprising', 0.533, 'operational', 'functional', 'operable', 'available', 'useable']
senticnet['usage'] = [0.917, -0.982, 0, 0.613, '#joyful', '#surprising', 0.837, 'practice', 'activity', 'play', 'misuse', 'abuse']
senticnet['use'] = [-0.044, 0.141, -0.094, 0.21, '#interesting', '#admirable', 0.071, 'make_use', 'exploit', 'creation', 'make_stuff', 'employ']
senticnet['use_army'] = [0, 0, -0.062, -0.154, '#scared', '#disgusting', -0.072, 'battle', 'soldier', 'declare_war', 'warrior', 'siege']
senticnet['use_atm'] = [-0.078, 0, 0, 0, '#sad', '#sad', -0.026, 'carry_credit_card', 'carry_wallet', 'window_shop', 'buy_coffee', 'out_money']
senticnet['use_bathroom'] = [0.868, 0.805, 0, 0, '#joyful', '#interesting', 0.558, 'go_restroom', 'leave_tip', 'charge_credit_card', 'spill_food_clothes', 'ask_menu']
senticnet['use_bed'] = [0.165, 0, 0.032, 0.114, '#joyful', '#admirable', 0.082, 'good_sleep', 'shut_eye', 'place_sleep', 'comfortable_place_sleep', 'lie_down_bed']
senticnet['use_binoculars'] = [0.021, 0.206, -0.11, 0.148, '#interesting', '#admirable', 0.088, 'classy', 'female_person', 'female_human', 'elegant', 'relate']
senticnet['use_blade'] = [-0.949, 0, 0.655, -0.959, '#sad', '#disgusting', -0.854, 'use_knife', 'cut_thing', 'cut', 'sharp_tool', 'dangerous']
senticnet['use_board_game'] = [0, 0.764, 0, 0.777, '#interesting', '#admirable', 0.514, 'life_end', 'expire', 'terminate', 'kill_self', 'end_life']
senticnet['use_body'] = [-0.058, 0, 0.036, 0, '#sad', '#angry', -0.031, 'exercise_much', 'exercise_regularly', 'exercise', 'great_exercise', 'eat_properly']
senticnet['use_book'] = [0.762, 0.746, 0, 0, '#joyful', '#interesting', 0.503, 'open_book', 'librarian', 'contestant', 'book_relate', 'bookmark']
senticnet['use_brain'] = [0.995, 0.879, 0, 0, '#joyful', '#interesting', 0.625, 'focus_attention', 'think_hard', 'ponder', 'figure_out', 'reach_conclusion']
senticnet['use_brake'] = [-0.083, -0.059, 0.026, -0.124, '#sad', '#disgusting', -0.058, 'fall_over', 'fall_off', 'press_brake', 'lose_balance', 'fall_down']
senticnet['use_brush'] = [0.031, 0.07, 0.025, 0.07, '#interesting', '#admirable', 0.049, 'wall_cover', 'brush', 'art_supply', 'cover_wall', 'latex']
senticnet['use_brush_air'] = [0.86, 0.96, 0, 0, '#joyful', '#interesting', 0.607, 'use_brush', 'hair', 'brush_hair', 'brush', 'brush_tooth']
senticnet['use_calculator'] = [0.031, 0.07, 0.025, 0.07, '#interesting', '#admirable', 0.049, 'use_computer', 'use_technology', 'calculator', 'study_math', 'math_exercises']
senticnet['use_camera'] = [0, 0.333, -0.219, 0.384, '#interesting', '#admirable', 0.166, 'take_picture', 'picture', 'video', 'take_photograph', 'photograph']
senticnet['use_car'] = [0, 0.993, 0, 0.778, '#interesting', '#admirable', 0.59, 'decide_to_go', 'turn_ignition', 'burn_gasoline', 'start_engine', 'know_go']
senticnet['use_cash'] = [0.339, 0.302, 0, 0.387, '#joyful', '#admirable', 0.343, 'good_citizen', 'pay_bill', 'use_credit_card', 'purchase_gift', 'pay_off_debt']
senticnet['use_chair'] = [0.059, -0.022, 0, 0, '#joyful', '#surprising', 0.027, 'rest', 'want_sleep', 'sleep_night', 'take_break', 'residue']
senticnet['use_clean'] = [0.048, 0, 0, 0.104, '#joyful', '#admirable', 0.051, 'find_home', 'clean_agent', 'clean_product', 'clean_cloth', 'tv_drama']
senticnet['use_compass'] = [0, 0.943, 0, 0.925, '#interesting', '#admirable', 0.623, 'travel', 'find_way', 'help_travelling', 'compass_direction', 'compass']
senticnet['use_computer'] = [0.909, 0.858, 0, 0, '#joyful', '#interesting', 0.589, 'post_message', 'send_mail', 'print_printer', 'enter_data', 'send_email']
senticnet['use_condom'] = [0.06, 0.422, -0.177, 0.41, '#interesting', '#admirable', 0.238, 'safe_sex', 'meet_girl', 'prevention', 'playboy', 'dirty_magazine']
senticnet['use_construction'] = [0.04, 0, 0, 0.064, '#joyful', '#admirable', 0.035, 'use_jewelry', 'metallic_element', 'hard_plastic', 'hard_substance', 'tin']
senticnet['use_cook'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'essential_life', 'slippery', 'spicy', 'liquid_substance', 'fluid']
senticnet['use_crayon'] = [-0.037, 0.077, 0, 0.077, '#interesting', '#admirable', 0.039, 'sketch', 'draw', 'pencil_art', 'make_sketch', 'create_image']
senticnet['use_credit_card'] = [0, 0.937, 0, 0.774, '#interesting', '#admirable', 0.57, 'run_out_money', 'pay_money', 'compare_price', 'make_profit', 'spend_much_money']
senticnet['use_decoration'] = [0, 0.106, 0, 0.165, '#interesting', '#admirable', 0.09, 'fragrant', 'sexual', 'cultivate_yard', 'garden_plant', 'green']
senticnet['use_dictionary'] = [-0.103, -0.033, 0.068, -0.227, '#sad', '#disgusting', -0.122, 'turn_page', 'remember_fact', 'move_eye', 'gain_insight', 'better_understand']
senticnet['use_drink'] = [-0.053, -0.01, 0.051, -0.065, '#sad', '#disgusting', -0.053, 'ground', 'dirt', 'use_recipe', 'underground', 'soil']
senticnet['use_drug'] = [0, 0, 0, -0.87, '#disgusting', '#disgusting', -0.29, 'deal_card_player', 'stand_alone', 'forward_email', 'explain_everything', 'bridge_difference']
senticnet['use_ear'] = [0.022, 0.107, 0, 0.192, '#interesting', '#admirable', 0.107, 'ear_activity', 'ear_work', 'audible', 'hear', 'audio']
senticnet['use_electricity'] = [0.897, 0.929, 0, 0, '#joyful', '#interesting', 0.609, 'change_channel', 'see_commercial', 'tell_friend', 'kill_brain_cell', 'drink_soda']
senticnet['use_energy'] = [0.721, 0.787, 0, 0, '#joyful', '#interesting', 0.503, 'exercise', 'enjoy_outdoors', 'fit_person', 'relieve_stress', 'learn_teamwork']
senticnet['use_eye'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'vision', 'eyes', 'contact_lens', 'correct_vision', 'improve_vision']
senticnet['use_farm'] = [0, 0, 0, 0.128, '#admirable', '#admirable', 0.043, 'door', 'glass_front', 'gate', 'corridor', 'build_open']
senticnet['use_finger'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'dexterity', 'manual_dexterity', 'use_hand', 'coordination', 'bend_over']
senticnet['use_foot'] = [-0.086, 0.102, 0, 0.153, '#interesting', '#admirable', 0.056, 'move_foot', 'move_forward', 'foot_motion', 'move_ahead', 'like_run']
senticnet['use_fork'] = [-0.047, -0.013, 0, -0.045, '#sad', '#disgusting', -0.026, 'burp', 'drink_much_beer', 'acid_indigestion', 'add_spice', 'wipe_mouth_napkin']
senticnet['use_fuel'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'energy', 'energy_use', 'switch_on', 'use_electricity', 'use_transport']
senticnet['use_game_chess'] = [-0.041, 0.141, -0.077, 0.107, '#interesting', '#admirable', 0.043, 'use_garden', 'chess', 'make_up_person', 'find_airplane', 'overrate']
senticnet['use_game_golf'] = [0, 0.705, 0, 0.868, '#interesting', '#admirable', 0.524, 'find_pantry', 'play_game', 'charge_money', 'sell_stuff', 'multiplication']
senticnet['use_garden'] = [-0.04, 0.139, -0.078, 0.106, '#interesting', '#admirable', 0.042, 'garden', 'relax', 'chillax', 'chill_out', 'outdoor']
senticnet['use_gas'] = [0.032, 0.261, -0.157, 0.198, '#interesting', '#admirable', 0.111, 'stop_red_light', 'get_to_destination', 'run_out_gas', 'arrive_destination', 'control_car']
senticnet['use_gun'] = [-0.145, -0.019, -0.125, -0.18, '#sad', '#disgusting', -0.144, 'fire_weapon', 'use_weapon', 'shoot_gun', 'fire_gun', 'take_life']
senticnet['use_hand'] = [0, 0.128, -0.052, 0.098, '#interesting', '#admirable', 0.058, 'use_finger', 'good_reason', 'grab', 'sensual', 'dexterity']
senticnet['use_hand_gesture'] = [-0.085, 0, 0.015, 0, '#sad', '#angry', -0.033, 'make_unusual_face', 'unusual_face', 'move_tongue', 'make_gesture', 'share_idea']
senticnet['use_hunt'] = [0.964, 0.709, 0, 0, '#joyful', '#interesting', 0.558, 'rifle', 'gun', 'revolver', 'pistol', 'firearm']
senticnet['use_illegal_drug'] = [-0.196, 0, -0.155, -0.1, '#sad', '#scared', -0.15, 'break_law', 'send_to_prison', 'revenge', 'rape', 'break_bad']
senticnet['use_imagination'] = [0, 0.128, -0.052, 0.098, '#interesting', '#admirable', 0.058, 'mental_activity', 'fantasize', 'use_brain', 'imagination', 'dream']
senticnet['use_ink'] = [-0.036, 0.093, 0, 0.083, '#interesting', '#admirable', 0.047, 'pencil_mark', 'script', 'use_pen', 'write_poem', 'pen_and_paper']
senticnet['use_internet'] = [-0.061, -0.056, 0.049, -0.067, '#sad', '#disgusting', -0.04, 'read_article', 'borrow_book', 'keep_open_mind', 'hack', 'use_system_abstract_think']
senticnet['use_jazz_music'] = [-0.036, -0.009, 0.018, -0.082, '#sad', '#disgusting', -0.042, 'reed_instrument', 'stringed_musical_instrument', 'instrument_music', 'musical_instrument', 'listen_music']
senticnet['use_jewelry'] = [0, 0.877, 0, 0.994, '#interesting', '#admirable', 0.624, 'both_functional_decorative', 'magnetic', 'shinny', 'hard_plastic', 'type_of_metal']
senticnet['use_keyboard'] = [-0.079, 0, 0.065, -0.052, '#sad', '#angry', -0.065, 'language_skill', 'learn_how', 'use_finger', 'debug', 'nimble_finger']
senticnet['use_knife'] = [-0.094, -0.016, 0, -0.232, '#sad', '#disgusting', -0.103, 'vaccination', 'knife', 'find_victim', 'dagger', 'cut_tool']
senticnet['use_language'] = [-0.057, 0.101, 0.015, 0.058, '#interesting', '#admirable', 0.029, 'ability_communicate', 'know_language', 'know_talk', 'make_unusual_face', 'fact_straight']
senticnet['use_leg'] = [-0.092, 0.104, 0, 0.099, '#interesting', '#admirable', 0.037, 'act_quickly', 'take_step', 'wear_running_shoes', 'wear_good_shoes', 'run_slowly']
senticnet['use_lighter'] = [0.087, 0.113, -0.087, 0, '#joyful', '#interesting', 0.038, 'matchbox', 'strike_against', 'cigarette_lighter', 'match', 'find_match']
senticnet['use_logic'] = [0, 0, 0, 0.878, '#admirable', '#admirable', 0.293, 'guess_answer', 'love_pet', 'state_fact', 'miss_bus', 'point_out']
senticnet['use_machine'] = [0, 0.08, 0, 0.179, '#interesting', '#admirable', 0.086, 'scrub', 'soap_up', 'launder', 'use_water_soap', 'use_soap']
senticnet['use_map'] = [0.853, -0.719, 0, 0.92, '#joyful', '#admirable', 0.831, 'point_out', 'use_compass', 'find', 'direction', 'find_direction']
senticnet['use_match'] = [0.215, 0.194, -0.204, 0.279, '#joyful', '#admirable', 0.161, 'diligence', 'gather_kindle', 'combustible_material', 'rub_two_stick_together', 'lighter']
senticnet['use_memory'] = [0.785, 0.836, 0, 0, '#joyful', '#interesting', 0.54, 'remember', 'cogitate', 'memorization', 'recite', 'recall']
senticnet['use_microphone'] = [0.028, -0.602, 0, 0.354, '#surprising', '#admirable', 0.328, 'perform_on_stage', 'listen', 'sing', 'compose_music', 'entertain_other_person']
senticnet['use_military'] = [-0.062, -0.025, -0.077, -0.193, '#scared', '#disgusting', -0.102, 'make_war', 'find_airport', 'conquer_enemy', 'invade', 'kill_soldier']
senticnet['use_mind'] = [-0.031, 0, 0.066, -0.107, '#angry', '#disgusting', -0.068, 'use_brain', 'learn_new_word', 'solve_mystery', 'come_conclusion', 'focus_attention']
senticnet['use_money'] = [0.719, 0.757, 0, 0, '#joyful', '#interesting', 0.492, 'out_wallet', 'money_credit', 'enough_money', 'good_credit', 'find_merchant']
senticnet['use_mouth'] = [0.029, 0.074, 0, 0.187, '#interesting', '#admirable', 0.097, 'mouth_movement', 'mouth_action', 'verbal_communication', 'mouth_noise', 'human_noise']
senticnet['use_muscle'] = [0, 0.069, 0, 0.1, '#interesting', '#admirable', 0.056, 'limber_up', 'move_body', 'expend_energy', 'fitness', 'stretch_muscle']
senticnet['use_musical_instrument'] = [0.902, 0.983, 0, 0, '#joyful', '#interesting', 0.628, 'annoy_mom', 'play_orchestra', 'make_musical_sound', 'perform_of_music', 'play_tune']
senticnet['use_needle'] = [-0.065, -0.018, 0.049, -0.124, '#sad', '#disgusting', -0.073, 'needle_thread', 'embroidery', 'sew_term', 'seam', 'thread_needle']
senticnet['use_oil_paint'] = [0.065, -0.015, 0, 0, '#joyful', '#surprising', 0.027, 'oil_painting', 'tapestry', 'wall_art', 'yellow_ribbon', 'artist_tool']
senticnet['use_outside'] = [0.864, 0, 0, 0.964, '#joyful', '#admirable', 0.609, 'cook_tool', 'use', 'water_bubble', 'roast_meat', 'outside']
senticnet['use_paint'] = [-0.023, 0.132, 0, 0.134, '#interesting', '#admirable', 0.081, 'pencil_art', 'wall_hang', 'artwork', 'create_image', 'wall_decoration']
senticnet['use_paper'] = [-0.13, -0.004, 0, -0.067, '#sad', '#disgusting', -0.064, 'sharpen_pencil', 'select_topic', 'look_newspaper', 'run_out_ink', 'use_pencil']
senticnet['use_party'] = [-0.799, 0, 0, -0.811, '#sad', '#disgusting', -0.537, 'become_intoxicated', 'alcoholism', 'party', 'bee_sting', 'lose_control']
senticnet['use_pen'] = [0.463, 0.561, -0.294, 0.281, '#joyful', '#interesting', 0.337, 'write_date', 'digitate_date', 'use_computer', 'impress_date', 'date']
senticnet['use_pencil'] = [0.078, 0.229, -0.115, 0.209, '#interesting', '#admirable', 0.134, 'misspell', 'record_information', 'definite', 'documentation', 'think_idea']
senticnet['use_phone'] = [0, -0.003, 0, 0.104, '#surprising', '#admirable', 0.036, 'phone_conversation', 'use_telephone', 'call', 'make_call', 'telephone_ring']
senticnet['use_recipe'] = [-0.053, -0.01, 0.051, -0.065, '#sad', '#disgusting', -0.053, 'ground', 'dirt', 'use_drink', 'underground', 'soil']
senticnet['use_remote_control'] = [0.908, 0.76, 0, 0, '#joyful', '#interesting', 0.556, 'view_movie', 'press_play', 'rewind', 'jitters', 'read_credit']
senticnet['use_restroom'] = [-0.062, -0.013, 0, -0.141, '#sad', '#disgusting', -0.063, 'eat_french_fries', 'ask_menu', 'order_dinner', 'read_menu', 'order_french_fries']
senticnet['use_salad'] = [0, 0.115, 0.02, 0.189, '#interesting', '#admirable', 0.095, 'leafy_green', 'cultivate_yard', 'rabbit_food', 'red_fruit', 'nutritious']
senticnet['use_school'] = [0, 0.071, 0.043, 0.067, '#interesting', '#admirable', 0.032, 'go_to_school', 'student', 'teacher', 'learn_somthing_new', 'hard_surface']
senticnet['use_scissor'] = [-0.102, -0.025, 0, -0.155, '#sad', '#disgusting', -0.077, 'draw_blood', 'copy_paste', 'cause_bleed', 'laceration', 'cut_finger']
senticnet['use_screwdriver'] = [-0.101, -0.051, 0.09, -0.209, '#sad', '#disgusting', -0.116, 'take_apart', 'medical_equipment', 'doctor_tool', 'reboot', 'make_error']
senticnet['use_search_engine'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'read_book_subject', 'use_telescope', 'review_note', 'buy_textbook', 'remember_information']
senticnet['use_shower'] = [-0.13, 0.098, -0.154, 0, '#sad', '#scared', -0.062, 'pour_water', 'remove_clothes', 'wear_bath_suit', 'malfunction', 'change_lifestyle']
senticnet['use_skill'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'skill', 'talent', 'ability', 'genius', 'earn_money']
senticnet['use_soap'] = [0, 0.133, 0, 0.206, '#interesting', '#admirable', 0.113, 'scrub', 'cleanse', 'body_clean', 'shower', 'clean_laundry']
senticnet['use_solar_oven'] = [0.034, 0, -0.053, -0.097, '#scared', '#disgusting', -0.039, 'fee_oneself', 'hungry', 'need_grocery', 'hunger', 'fee']
senticnet['use_sport'] = [0.067, -0.095, 0.087, 0.09, '#surprising', '#admirable', 0.055, 'spherical_shape', 'symmetrical', 'bouncy', 'round_object', 'orb']
senticnet['use_system_abstract_think'] = [-0.089, 0, 0, 0, '#sad', '#sad', -0.03, 'read_article', 'borrow_book', 'read_book', 'discover_fact', 'study_history']
senticnet['use_talent'] = [0.981, 0.791, 0, 0, '#joyful', '#interesting', 0.591, 'entertain_audience', 'sound_good', 'give_pleasure', 'entertainment', 'entertain_crowd']
senticnet['use_technology'] = [0.132, 0.1, 0.063, 0.159, '#joyful', '#admirable', 0.109, 'technology', 'phone', 'pad', 'tablet', 'computer']
senticnet['use_telephone'] = [0.024, -0.018, 0.011, 0.085, '#joyful', '#admirable', 0.039, 'use_phone', 'phone_conversation', 'make_call', 'speak_loudly', 'call']
senticnet['use_telescope'] = [0.024, -0.018, 0.011, 0.085, '#joyful', '#admirable', 0.039, 'observe_nature', 'telescope', 'use_technology', 'study', 'read_science_book']
senticnet['use_television'] = [0, 0.954, 0, 0.722, '#interesting', '#admirable', 0.559, 'record_film', 'proof_of_purchase', 'watch_television', 'store_film', 'view_video']
senticnet['use_thermometer'] = [-0.078, 0, -0.144, 0, '#sad', '#scared', -0.074, 'catch_fire', 'age_prematurely', 'light_cigar', 'light_pipe', 'cause_mental_illness']
senticnet['use_ticket'] = [-0.069, 0, 0, 0, '#sad', '#sad', -0.023, 'purchase_ticket', 'buy_ticket_theater', 'buy_ticket', 'money_ticket', 'book_ticket']
senticnet['use_tissue'] = [0, 0.101, 0.039, 0.054, '#interesting', '#admirable', 0.039, 'smear', 'cheer_up', 'wipe_tear', 'push_button', 'scratch_back']
senticnet['use_toilet'] = [-0.047, 0, 0.023, -0.04, '#sad', '#disgusting', -0.037, 'wash_up', 'go_potty', 'go_pee', 'change_clothes', 'take_shower']
senticnet['use_tool'] = [-0.073, 0, 0, -0.074, '#sad', '#disgusting', -0.049, 'paint', 'cartoon_character', 'mould', 'use_oil_paint', 'buy_paint']
senticnet['use_tooth'] = [0.808, 0, 0, 0, '#joyful', '#joyful', 0.269, 'wash_first', 'take_bite', 'buy_market', 'chew', 'put_napkin_lap']
senticnet['use_transport'] = [-0.12, -0.056, -0.05, -0.194, '#sad', '#disgusting', -0.103, 'energy', 'use_fuel', 'switch_on', 'use_electricity', 'energy_use']
senticnet['use_up'] = [0.547, -0.947, 0, 0.74, '#surprising', '#admirable', 0.745, 'sap', 'expend', 'indulge', 'luxuriate', 'spend']
senticnet['use_vacuum_cleaner'] = [-0.027, 0.165, -0.08, 0.14, '#interesting', '#admirable', 0.066, 'maintenance', 'vacuum_carpet', 'clean_often', 'tidy_up', 'vacuum_floor']
senticnet['use_vehicle'] = [0, 0, 0, 0.165, '#admirable', '#admirable', 0.055, 'get_around', 'passenger_car', 'transportation', 'car_travel', 'car_go']
senticnet['use_voice'] = [-0.046, 0, 0.032, 0, '#sad', '#angry', -0.026, 'clear_throat', 'whisper', 'hear_voice', 'mouth_move', 'move_tongue']
senticnet['use_war'] = [-0.064, 0, -0.113, -0.08, '#scared', '#disgusting', -0.086, 'lethal', 'explosive_device', 'firearm', 'ammunition', 'automatic']
senticnet['use_washcloth'] = [0.813, 0, 0, 0, '#joyful', '#joyful', 0.271, 'wash_body', 'wash_dog', 'lather', 'clean_object', 'clean_oneself']
senticnet['use_water'] = [0, 0.095, 0, 0.074, '#interesting', '#admirable', 0.056, 'laundry_detergent', 'water_soap', 'clothes_dirty', 'laundry', 'buy_wash_powder']
senticnet['use_water_soap'] = [0, 0.066, 0, 0.067, '#interesting', '#admirable', 0.044, 'wash_body', 'wash_oneself', 'soap_up', 'clean_oneself', 'scrub']
senticnet['use_weapon'] = [-0.185, 0, -0.122, -0.224, '#sad', '#disgusting', -0.177, 'use_gun', 'fire_weapon', 'attack_enemy', 'plan_attack', 'hide_evidence']
senticnet['use_word'] = [0.713, 0.786, 0, 0, '#joyful', '#interesting', 0.5, 'think_creatively', 'learn_spell', 'think_story', 'scratch_head', 'check_spelling']
senticnet['used'] = [0, 0, -0.888, -0.984, '#scared', '#disgusting', -0.624, 'apply', 'employ', 'expend', 'utilize', 'habituate']
senticnet['useful'] = [0, 0.081, 0, 0.112, '#interesting', '#admirable', 0.064, 'dead', 'versatile', 'hard', 'expensive', 'hard_material']
senticnet['useful_tool'] = [-0.063, 0, 0.026, 0, '#sad', '#angry', -0.03, 'woodworking', 'tool', 'garden_tool', 'garden_implement', 'woodworking_tool']
senticnet['usefulness'] = [0.513, -0.874, 0, 0.924, '#surprising', '#admirable', 0.77, 'quality', 'serviceability', 'serviceableness', 'usableness', 'user_friendly']
senticnet['useless'] = [0, 0, 0, -0.785, '#disgusting', '#disgusting', -0.262, 'hazardous', 'bad_choice', 'wrong', 'violent', 'serious']
senticnet['uselessness'] = [0.75, -0.876, 0, 0.603, '#joyful', '#surprising', 0.743, 'quality', 'futility', 'impracticality', 'worthlessness', 'impracticability']
senticnet['user_friendly'] = [0.986, -0.629, 0, 0.807, '#joyful', '#admirable', 0.807, 'operable', 'functional', 'serviceable', 'usable', 'operational']
senticnet['usual'] = [0.035, 0.236, -0.076, 0.218, '#interesting', '#admirable', 0.138, 'typical', 'usual_ordinary', 'normal', 'frequent', 'sameness']
senticnet['usual_green'] = [0, 0.08, 0.019, 0.076, '#interesting', '#admirable', 0.046, 'green', 'leafy', 'vegetation', 'green_growth', 'tree_flower']
senticnet['usual_ordinary'] = [0.071, 0.222, -0.061, 0.264, '#interesting', '#admirable', 0.165, 'typical', 'normal', 'usual', 'frequent', 'sameness']
senticnet['usurious'] = [-0.891, 0, 0.6, -0.925, '#sad', '#disgusting', -0.805, 'outrageous', 'exorbitant', 'extortionate', 'immoderate', 'abnormal']
senticnet['usurp'] = [-0.799, 0, 0.605, -0.766, '#sad', '#disgusting', -0.723, 'raid', 'take', 'appropriate', 'capture', 'annex']
senticnet['usurpation'] = [-0.635, 0, 0.728, -0.588, '#sad', '#angry', -0.65, 'misconduct', 'inroad', 'wrongdoing', 'wrongful_conduct', 'actus_reus']
senticnet['utilitarianism'] = [0.726, -0.807, 0, 0.73, '#surprising', '#admirable', 0.754, 'philosophy', 'doctrine', 'philosophical_system', 'school_of_thought', 'ism']
senticnet['utility'] = [-0.027, 0.186, -0.047, 0.098, '#interesting', '#admirable', 0.07, 'spend', 'give_money', 'owe_money', 'pay_debt', 'pay']
senticnet['utility_case'] = [0.087, -0.041, 0, 0, '#joyful', '#surprising', 0.043, 'hoist', 'control_room', 'forklift', 'platform_rail', 'torso']
senticnet['utility_room'] = [-0.031, -0.008, 0, -0.046, '#sad', '#disgusting', -0.023, 'tool_shed', 'garage', 'hardware_store', 'antique_store', 'service_station']
senticnet['utopia'] = [0.087, 0.151, 0, 0.112, '#interesting', '#admirable', 0.117, 'java', 'memorial', 'nowhere', 'mount_ever', 'international_space_station']
senticnet['utter'] = [0, 0.739, 0, 0.93, '#interesting', '#admirable', 0.556, 'say', 'verbal', 'beckon', 'talkative', 'orate']
senticnet['utterance'] = [0, 0.899, 0, 0.737, '#interesting', '#admirable', 0.545, 'call', 'speech', 'voice', 'verbal_communication', 'phone_conversation']
senticnet['vacate'] = [-0.783, 0, 0.801, -0.87, '#angry', '#disgusting', -0.818, 'resign', 'renounce', 'step_down', 'abdicate', 'leave_office']
senticnet['vacation'] = [0.722, 0.865, 0, 0.748, '#interesting', '#admirable', 0.778, 'avoid_crash', 'summer_vacation', 'reach_destination', 'go_holiday', 'temporary_home']
senticnet['vacation_time'] = [0.777, 0.994, 0, 0.964, '#interesting', '#admirable', 0.912, 'make_difference', 'save_world', 'make_good_decision', 'feel_important', 'enjoy_beauty']
senticnet['vaccination'] = [0.722, 0.865, 0, 0.748, '#interesting', '#admirable', 0.778, 'medical_therapy', 'vaccine', 'doctor', 'medicine', 'hospital']
senticnet['vaccine'] = [-0.07, 0, -0.053, -0.186, '#sad', '#disgusting', -0.103, 'medical_therapy', 'vaccination', 'doctor', 'medicine', 'hospital']
senticnet['vacillate'] = [0, 0, -0.834, -0.905, '#scared', '#disgusting', -0.58, 'vibrate', 'oscillate', 'hover', 'waver', 'fluctuate']
senticnet['vacuous'] = [-0.78, 0, 0.783, -0.621, '#sad', '#angry', -0.728, 'insignificant', 'mindless', 'empty', 'nonsense', 'meaningless']
senticnet['vacuum_carpet'] = [0, 0.083, 0, 0.148, '#interesting', '#admirable', 0.077, 'mission_accomplished', 'maintenance', 'clean_often', 'achieve_goal', 'achievement']
senticnet['vacuum_cleaner'] = [-0.046, -0.028, 0.089, -0.142, '#angry', '#disgusting', -0.083, 'steam_locomotive', 'loudspeaker', 'collector', 'siren', 'activist']
senticnet['vacuum_flask'] = [0.619, -0.834, 0, 0.912, '#surprising', '#admirable', 0.788, 'hipflask', 'pocket_flask', 'ampulla', 'canteen', 'flask']
senticnet['vacuum_floor'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'cleanness', 'dust_furniture', 'sweep', 'clean_floor', 'clean']
senticnet['vagrant'] = [-0.918, 0, 0.768, -0.959, '#sad', '#disgusting', -0.882, 'hobo', 'tramp', 'beachcomber', 'bum', 'sundowner']
senticnet['vague'] = [-0.818, 0, 0, 0, '#sad', '#sad', -0.273, 'obscure', 'unsure', 'uncertain', 'disoriented', 'unclear']
senticnet['vain'] = [-0.718, 0, 0.711, 0, '#sad', '#angry', -0.476, 'needless', 'unnecessary', 'idle', 'useless', 'pointless']
senticnet['vainglory'] = [-0.845, 0, 0.969, -0.685, '#sad', '#angry', -0.833, 'posturing', 'swelled_head', 'egotism', 'boastfulness', 'conceitedness']
senticnet['valentine_day'] = [0.158, 0.207, -0.205, 0.278, '#interesting', '#admirable', 0.146, 'go_kiss', 'know_other', 'infidelity', 'amiable', 'lust']
senticnet['valeric_acid'] = [-0.652, 0, 0.935, -0.968, '#angry', '#disgusting', -0.852, 'acid', 'hexanedioic_acid', 'adipic_acid', 'succinic_acid', 'carboxylic_acid']
senticnet['valetudinarianism'] = [-0.834, 0, 0.874, -0.716, '#sad', '#angry', -0.808, 'infirmity', 'frailty', 'debility', 'frailness', 'asthenia']
senticnet['valid'] = [0.622, -0.721, 0, 0.799, '#surprising', '#admirable', 0.714, 'sound', 'logical', 'validated', 'effectual', 'legitimate']
senticnet['valley_fever'] = [-0.859, 0, 0.549, -0.938, '#sad', '#disgusting', -0.782, 'coccidioidomycosis', 'coccidiomycosis', 'mycosis', 'desert_rheumatism', 'cryptococcosis']
senticnet['valor'] = [0.827, 0.85, 0, 0.743, '#joyful', '#interesting', 0.807, 'chivalry', 'honor', 'almighty', 'admire', 'respect']
senticnet['valuable'] = [0.027, 0.281, -0.075, 0.195, '#interesting', '#admirable', 0.143, 'dollar_change', 'currency', 'richness', 'small_change', 'wealth']
senticnet['valuable_gem'] = [0, 0.844, 0, 0.771, '#interesting', '#admirable', 0.538, 'music_type', 'type_of_music', 'small_boulder', 'music_genre', 'rock_music']
senticnet['valuable_metal'] = [-0.04, -0.021, 0.027, -0.031, '#sad', '#disgusting', -0.026, 'precious_metal', 'olympic_medal', 'shiny_metal', 'bloodstone', 'many_different_kinds']
senticnet['value'] = [0, 0.717, 0, 0.765, '#interesting', '#admirable', 0.494, 'like_price', 'item_worth', 'value_amount', 'like_cost', 'amount']
senticnet['value_amount'] = [-0.032, 0.249, 0.011, 0.146, '#interesting', '#admirable', 0.117, 'item_value', 'sticker', 'item_worth', 'dollar_sign', 'amount_money']
senticnet['vandalism'] = [-0.513, 0, 0.617, -0.699, '#angry', '#disgusting', -0.61, 'devilment', 'roguery', 'mischief', 'shenanigan', 'deviltry']
senticnet['vanilla'] = [0.047, 0.094, -0.064, 0.132, '#interesting', '#admirable', 0.07, 'flavor', 'twist', 'wrap_around', 'sand', 'appear']
senticnet['vanish'] = [-0.973, 0, 0.981, -0.83, '#sad', '#angry', -0.928, 'absent', 'fall_away', 'evanesce', 'blow_over', 'pass_off']
senticnet['vanisher'] = [-0.801, 0, 0.568, -0.912, '#sad', '#disgusting', -0.76, 'mortal', 'person', 'individual', 'someone', 'somebody']
senticnet['vanity'] = [0.494, 0.6, -0.251, 0.273, '#joyful', '#interesting', 0.372, 'self-esteem', 'levity', 'fondness', 'serene', 'imperturbability']
senticnet['vanity_case'] = [0, 0, 0.043, -0.096, '#angry', '#disgusting', -0.046, 'satchel', 'handbag', 'shoulder_bag', 'card_case', 'bag']
senticnet['vanquish'] = [0.586, -0.522, 0, 0.716, '#joyful', '#admirable', 0.608, 'master', 'walk_over', 'checkmate', 'outfight', 'screw']
senticnet['vapid'] = [0, 0, 0.77, -0.844, '#angry', '#disgusting', -0.538, 'bland', 'insipid', 'flat', 'flavorless', 'savorless']
senticnet['vapor'] = [0, 0, -0.073, 0, '#scared', '#scared', -0.024, 'bad_habit', 'gaseous', 'haze', 'smoke', 'smog']
senticnet['vapor_water'] = [0.736, 0.726, 0, 0, '#joyful', '#interesting', 0.487, 'movie', 'wet_air', 'condense_water', 'movie_title', 'hazy']
senticnet['vaporing'] = [-0.887, 0, 0.666, -0.901, '#sad', '#disgusting', -0.818, 'crow', 'crowing', 'bluster', 'bragging', 'jactitation']
senticnet['vaporization'] = [-0.982, 0, 0.516, -0.908, '#sad', '#disgusting', -0.802, 'devastation', 'atomization', 'pulverization', 'annihilation', 'destruction']
senticnet['vardenafil'] = [-0.595, 0, 0.537, -0.577, '#sad', '#disgusting', -0.57, 'phentolamine', 'sildenafil', 'sildenafil_citrate', 'tadalafil', 'virility_drug']
senticnet['variability'] = [-0.9, 0, 0.747, -0.63, '#sad', '#angry', -0.759, 'variedness', 'personal_equation', 'variegation', 'changeableness', 'changeability']
senticnet['variable'] = [0.064, 0.099, 0.063, 0.127, '#interesting', '#admirable', 0.076, 'computer_company', 'sometimes_green', 'grassy_area', 'computer_manufacturer', 'mysterious']
senticnet['variableness'] = [-0.938, 0, 0.732, -0.52, '#sad', '#angry', -0.73, 'variedness', 'personal_equation', 'variegation', 'changeableness', 'changeability']
senticnet['variant'] = [-0.76, 0, 0.969, -0.554, '#sad', '#angry', -0.761, 'deviation', 'flection', 'flexion', 'discrepancy', 'variation']
senticnet['variation'] = [-0.836, 0, 0.546, -0.88, '#sad', '#disgusting', -0.754, 'difference', 'allomerism', 'deviation', 'divergence', 'departure']
senticnet['varicose_vein'] = [-0.365, -0.082, 0, -0.327, '#sad', '#disgusting', -0.203, 'disease', 'body_disease', 'need_cure', 'need_doctor', 'leg_pain']
senticnet['varied'] = [-0.562, 0, 0.931, -0.665, '#angry', '#disgusting', -0.719, 'varying', 'various', 'variable', 'versatile', 'multifaceted']
senticnet['variedness'] = [-0.9, 0, 0.747, -0.63, '#sad', '#angry', -0.759, 'variability', 'personal_equation', 'variegation', 'changeableness', 'changeability']
senticnet['variegation'] = [-0.9, 0, 0.747, -0.63, '#sad', '#angry', -0.759, 'variedness', 'personal_equation', 'variability', 'changeableness', 'changeability']
senticnet['variety'] = [0.055, 0.292, -0.071, 0.345, '#interesting', '#admirable', 0.207, 'option', 'proposition', 'develop', 'combine_sound', 'get_rid']
senticnet['various'] = [-0.562, 0, 0.931, -0.665, '#angry', '#disgusting', -0.719, 'varying', 'varied', 'variable', 'versatile', 'multifaceted']
senticnet['varment'] = [-0.622, 0, 0.588, -0.806, '#sad', '#disgusting', -0.672, 'animal', 'animate_being', 'beast', 'creature', 'brute']
senticnet['varmint'] = [-0.975, 0, 0.677, -0.955, '#sad', '#disgusting', -0.869, 'stunt', 'game', 'mutant', 'invertebrate', 'animate_being']
senticnet['vary'] = [0.295, 0.072, 0, 0.136, '#joyful', '#admirable', 0.168, 'live_environment', 'beautiful', 'lovely', 'important_man', 'peaceful']
senticnet['varying'] = [-0.562, 0, 0.931, -0.665, '#angry', '#disgusting', -0.719, 'varied', 'various', 'variable', 'versatile', 'multifaceted']
senticnet['vaseline'] = [-0.758, 0, -0.751, -0.998, '#sad', '#disgusting', -0.836, 'tease', 'upset', 'lubricant', 'upset_person', 'piston']
senticnet['vast'] = [-0.045, 0.099, 0, 0.177, '#interesting', '#admirable', 0.077, 'wide', 'large', 'big', 'really_big', 'huge']
senticnet['vatican'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'jerusalem', 'jewish_community', 'large_city', 'big_city', 'major_city']
senticnet['vaticinate'] = [0.677, -0.551, 0, 0.831, '#joyful', '#admirable', 0.686, 'vaticination', 'call', 'enlighten', 'irradiate', 'predict']
senticnet['vault'] = [0.02, 0.205, 0, 0, '#joyful', '#interesting', 0.075, 'safe', 'bank_vault', 'bank', 'piggy_bank', 'bank_account']
senticnet['vector'] = [-0.04, 0.097, 0.06, 0.146, '#interesting', '#admirable', 0.048, 'maths', 'ratio', 'length_measurement', 'measurement_unit', 'unit_of_measurement']
senticnet['vege_out'] = [0.502, -0.783, 0, 0.73, '#surprising', '#admirable', 0.672, 'relax', 'loosen_up', 'unbend', 'unwind', 'decompress']
senticnet['vegetable_field'] = [0, 0.084, 0.02, 0.076, '#interesting', '#admirable', 0.047, 'plant_field', 'plant_ground', 'vegetable_grow', 'edible_plant', 'grow_place']
senticnet['vegetable_fruit'] = [0.035, 0.104, 0, 0.12, '#interesting', '#admirable', 0.086, 'fruit_vegetable', 'vegetable', 'leafy_vegetable', 'fresh_vegetable', 'vegetarian_food']
senticnet['vegetable_grow'] = [0, 0.09, 0.014, 0.085, '#interesting', '#admirable', 0.054, 'grow_place', 'plant_ground', 'grow_stuff', 'crop_place', 'grass_area']
senticnet['vegetarian_food'] = [0.175, 0.101, 0.035, 0.195, '#joyful', '#admirable', 0.145, 'leafy_green', 'rabbit_food', 'fruit_plant', 'lawn_green', 'green_vegetable']
senticnet['vegetate'] = [-0.039, -0.079, 0.152, -0.086, '#angry', '#disgusting', -0.066, 'lazy', 'immobile', 'motionless', 'stationary', 'inactive']
senticnet['vegetative_cell'] = [-0.892, 0, 0.506, -0.525, '#sad', '#disgusting', -0.641, 'mast_cell', 'mastocyte', 'labrocyte', 'target_cell', 'phagocyte']
senticnet['veggie'] = [0.04, 0.091, -0.065, 0.066, '#interesting', '#admirable', 0.044, 'cereal_grain', 'food_ingredient', 'vegetable', 'food_grain', 'whole_grain']
senticnet['vehemence'] = [0, 0, -0.925, -0.934, '#scared', '#disgusting', -0.62, 'fury', 'emphasis', 'fierceness', 'wildness', 'ferocity']
senticnet['vehicle'] = [0, 0, 0, -0.077, '#disgusting', '#disgusting', -0.026, 'sell_car', 'truck_stop', 'car_dealership', 'insurance', 'car']
senticnet['vehicle_type'] = [0, 0.981, 0, 0.793, '#interesting', '#admirable', 0.591, 'form_of_transportation', 'mode_of_transport', 'means_of_transportation', 'mode_transportation', 'machine_transportation']
senticnet['veil'] = [0.103, -0.095, 0.019, 0, '#joyful', '#surprising', 0.06, 'cake', 'mousse', 'wedding_cake', 'alcohol', 'doughnut']
senticnet['vein'] = [0.042, -0.069, 0, -0.037, '#joyful', '#surprising', 0.025, 'artery', 'skeletal_system', 'heart', 'human_body', 'main_artery']
senticnet['velcro'] = [0.04, 0.091, -0.065, 0.066, '#interesting', '#admirable', 0.044, 'nylon', 'nylon_product', 'clothes', 'shoe', 'pants']
senticnet['vellication'] = [-0.964, 0, 0.586, -0.556, '#sad', '#angry', -0.702, 'muscle_spasm', 'spasm', 'cramp', 'tic', 'blepharism']
senticnet['velocity'] = [-0.033, 0.178, 0, 0.168, '#interesting', '#admirable', 0.104, 'speed', 'fast', 'fast_and_furious', 'speedy', 'fleet']
senticnet['velvet'] = [-0.035, 0, 0, -0.045, '#sad', '#disgusting', -0.027, 'cotton', 'silk', 'wool', 'cotton_boll', 'asbestos']
senticnet['vend'] = [-0.086, 0.196, 0, 0.194, '#interesting', '#admirable', 0.101, 'business_transaction', 'good_price', 'trade', 'transaction', 'cheap_price']
senticnet['vend_stand'] = [0, 0, 0.016, -0.086, '#angry', '#disgusting', -0.034, 'dime_store', 'shop_arcade', 'deli_store', 'bookshop', 'store']
senticnet['veneer'] = [-0.944, 0, 0.569, -0.721, '#sad', '#disgusting', -0.745, 'bitumastic', 'coating', 'coatinging', 'lacquer', 'seal']
senticnet['veneering'] = [-0.944, 0, 0.569, -0.721, '#sad', '#disgusting', -0.745, 'bitumastic', 'veneer', 'coating', 'lacquer', 'seal']
senticnet['venerate'] = [0, 0.87, 0, 0.753, '#interesting', '#admirable', 0.541, 'reverently', 'hero-worship', 'idolize', 'veneration', 'reverentially']
senticnet['veneration'] = [0, 0.742, 0, 0.843, '#interesting', '#admirable', 0.528, 'reverently', 'hero-worship', 'venerate', 'idolize', 'reverentially']
senticnet['venereal_disease'] = [-0.836, 0, -0.81, -0.848, '#sad', '#disgusting', -0.831, 'herpes', 'overpopulation', 'large_family', 'loss_offreedom', 'youth']
senticnet['venereal_infection'] = [-0.974, 0, 0.135, -0.928, '#sad', '#disgusting', -0.679, 'contagious_disease', 'contagion', 'disease', 'granuloma_inguinale', 'die']
senticnet['vengeance'] = [-0.787, 0, 0, -0.925, '#sad', '#disgusting', -0.571, 'revenge', 'retribution', 'go_jail', 'sin', 'incarceration']
senticnet['vengeful'] = [0.936, 0.863, 0, 0, '#joyful', '#interesting', 0.6, 'revenge', 'experience_emotion', 'take_revenge', 'even_out', 'waste_time']
senticnet['vengefully'] = [-0.031, 0.157, 0.698, -0.661, '#angry', '#disgusting', -0.411, 'vengefulness', 'vindictively', 'revengefully', 'vindictive', 'spiteful']
senticnet['vengefulness'] = [-0.031, 0.157, 0.698, -0.661, '#angry', '#disgusting', -0.411, 'vindictively', 'vengefully', 'revengefully', 'vindictive', 'spiteful']
senticnet['venial'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'forgivable', 'excusable', 'mercifully', 'merciful', 'mercifulness']
senticnet['venom'] = [-0.939, 0, -0.998, -0.928, '#sad', '#scared', -0.955, 'offensive', 'malice', 'despise', 'disgust', 'scorn']
senticnet['venomous'] = [-0.257, 0.081, -0.199, 0, '#sad', '#scared', -0.125, 'hairy', 'kind_animal', 'poisonous', 'big_fish', 'graceful']
senticnet['vent'] = [-0.819, 0, 0.504, -0.966, '#sad', '#disgusting', -0.763, 'regenerate', 'air_out', 'air', 'renew', 'freshen']
senticnet['ventricular_fibrillation'] = [-0.83, 0, 0.987, -0.504, '#sad', '#angry', -0.774, 'heart_block', 'atrioventricular_block', 'bradycardia', 'arrhythmia', 'tachycardia']
senticnet['venture'] = [0.59, -0.757, 0, 0.543, '#joyful', '#surprising', 0.63, 'joint_venture', 'sally', 'labor', 'cause', 'risk']
senticnet['venturing'] = [0, 0, 0.82, -0.963, '#angry', '#disgusting', -0.594, 'embark', 'venture', 'guess', 'hazard', 'pretend']
senticnet['verbal'] = [-0.025, 0.067, -0.045, 0.192, '#interesting', '#admirable', 0.063, 'verbalize', 'orate', 'say', 'talkative', 'discourse']
senticnet['verbal_aggression'] = [-0.917, 0, 0.451, -0.987, '#sad', '#disgusting', -0.785, 'slave', 'psychological_aggression', 'physical_aggression', 'aggression', 'female_slave']
senticnet['verbal_communication'] = [0, 0, 0, 0.141, '#admirable', '#admirable', 0.047, 'orate', 'spoken', 'speech', 'mouth_move', 'verbalize']
senticnet['verbal_contract'] = [0, 0.936, 0, 0.732, '#interesting', '#admirable', 0.556, 'pacifism', 'forgiven', 'weak_acid', 'good_fortune', 'sincere']
senticnet['verbalization'] = [-0.611, 0, 0.73, -0.858, '#angry', '#disgusting', -0.733, 'diction', 'phrasing', 'verbiage', 'wording', 'phraseology']
senticnet['verbalize'] = [0, 0.983, 0, 0.724, '#interesting', '#admirable', 0.569, 'verbal', 'orate', 'converse', 'spoken', 'talkative']
senticnet['verbiage'] = [-0.611, 0, 0.73, -0.858, '#angry', '#disgusting', -0.733, 'diction', 'phrasing', 'verbalization', 'wording', 'phraseology']
senticnet['verboseness'] = [-0.565, 0, 0.617, -0.804, '#angry', '#disgusting', -0.662, 'prolixity', 'prolixness', 'wordiness', 'repetitiveness', 'repetitiousness']
senticnet['verbosity'] = [0.04, -0.036, 0, 0.115, '#joyful', '#admirable', 0.064, 'sport_play', 'scrabble', 'excite_game', 'fun_game', 'rough_game']
senticnet['verdict'] = [0.978, 0.992, 0, 0, '#joyful', '#interesting', 0.657, 'go_court', 'serve_jury', 'question_witness', 'call_police', 'make_judgment']
senticnet['verification'] = [0.626, -0.853, 0, 0.551, '#joyful', '#surprising', 0.677, 'proof', 'bed_check', 'crosscheck', 'parity_check', 'redundancy_check']
senticnet['verify'] = [0.547, -0.961, 0, 0.89, '#surprising', '#admirable', 0.799, 'check', 'support', 'assure', 'affirm', 'check_off']
senticnet['veritable'] = [0.93, 0, 0, 0.95, '#joyful', '#admirable', 0.627, 'documented', 'echt', 'attested', 'authenticated', 'genuine']
senticnet['vermicide'] = [0.98, -0.708, 0, 0.625, '#joyful', '#surprising', 0.771, 'agent', 'medicament', 'medicinal_drug', 'medication', 'medicine']
senticnet['vermifuge'] = [0.639, -0.797, 0, 0.562, '#joyful', '#surprising', 0.666, 'thiabendazole', 'medicament', 'medicinal_drug', 'medication', 'medicine']
senticnet['vermin'] = [0, 0, 0.862, -0.794, '#angry', '#disgusting', -0.552, 'social_insect', 'big_mouse', 'rodent', 'small_animal', 'dig_tunnel']
senticnet['verruca'] = [-0.585, 0, 0.727, -0.596, '#angry', '#disgusting', -0.636, 'blemish', 'keratosis', 'mar', 'defect', 'common_wart']
senticnet['versatile'] = [0.085, 0.218, -0.073, 0.308, '#interesting', '#admirable', 0.179, 'delicate', 'useful', 'good', 'light_colored', 'beautiful']
senticnet['verse'] = [0.075, -0.013, 0.019, 0.067, '#joyful', '#admirable', 0.045, 'rhyme', 'like_poetry', 'song_lyric', 'lyrics', 'stanza']
senticnet['vertical'] = [0, 0.958, 0, 0.706, '#interesting', '#admirable', 0.555, 'pillar', 'build_support', 'load_bear', 'build_part', 'empty_place']
senticnet['verve'] = [0.847, -0.659, 0, 0.955, '#joyful', '#admirable', 0.82, 'bright', 'sparkle', 'twinkle', 'spark', 'energy']
senticnet['very_loud_noise'] = [-0.905, 0, 0.357, -0.988, '#sad', '#disgusting', -0.75, 'sound', 'noise', 'rumble', 'shout', 'annoying']
senticnet['very_uncomfortable'] = [-0.974, 0, 0.135, -0.928, '#sad', '#disgusting', -0.679, 'tight_shoe', 'uncomfortable', 'uncomfortable_chair', 'uncomfortable_seat', 'uncomfortable_shoe']
senticnet['vesicant'] = [-0.864, 0, 0.891, -0.821, '#sad', '#angry', -0.859, 'baneful', 'pernicious', 'vesicatory', 'noxious', 'pestilent']
senticnet['vesicate'] = [-0.881, 0, 0.705, -0.731, '#sad', '#disgusting', -0.772, 'tumefy', 'swell_up', 'tumesce', 'intumesce', 'swell']
senticnet['vesicatory'] = [-0.864, 0, 0.891, -0.821, '#sad', '#angry', -0.859, 'baneful', 'pernicious', 'noxious', 'vesicant', 'pestilent']
senticnet['vesicle'] = [-0.784, 0, 0.855, -0.996, '#angry', '#disgusting', -0.878, 'blood_blister', 'pustule', 'water_blister', 'bleb', 'cyst']
senticnet['vespid'] = [-0.663, 0, 0.946, -0.554, '#sad', '#angry', -0.721, 'yellow_hornet', 'yellow_jacket', 'giant_hornet', 'hornet', 'hornet_wasp']
senticnet['vespid_wasp'] = [-0.663, 0, 0.946, -0.554, '#sad', '#angry', -0.721, 'yellow_hornet', 'yellow_jacket', 'giant_hornet', 'vespid', 'hornet']
senticnet['vessel'] = [0.085, 0.218, -0.073, 0.308, '#interesting', '#admirable', 0.179, 'boat', 'yacht', 'ship', 'cruiser', 'craft']
senticnet['vest'] = [0.734, 0.774, 0, 0, '#joyful', '#interesting', 0.503, 'outer_wear', 'garment', 'jacket', 'nightgown', 'robe']
senticnet['vestibule'] = [0, 0, 0, 0.128, '#admirable', '#admirable', 0.043, 'central_passage', 'door', 'doorway', 'gate', 'door_handle']
senticnet['vestment'] = [0.849, -0.503, 0, 0.845, '#joyful', '#admirable', 0.732, 'robe', 'gown', 'veil', 'vest', 'cassock']
senticnet['vesture'] = [-0.927, 0, 0.595, -0.678, '#sad', '#disgusting', -0.733, 'wear', 'wearable', 'clothing', 'article_of_clothing', 'leisure_wear']
senticnet['vet'] = [-0.024, 0, -0.067, -0.037, '#scared', '#disgusting', -0.043, 'alleyway', 'animal_shelter', 'vet_office', 'home', 'doghouse']
senticnet['vet_office'] = [-0.023, -0.018, -0.068, -0.048, '#scared', '#disgusting', -0.04, 'owner_house', 'take_care_of_pet', 'dog_show', 'vet', 'animal']
senticnet['veterinarian_office'] = [0.749, 0, 0, 0, '#joyful', '#joyful', 0.25, 'warm_bed', 'alleyway', 'doghouse', 'animal_shelter', 'cage']
senticnet['veto'] = [-0.811, 0, 0.513, -0.715, '#sad', '#disgusting', -0.68, 'ballot', 'vote', 'voting', 'balloting', 'pocket_veto']
senticnet['vex'] = [0, 0, 0.726, -0.941, '#angry', '#disgusting', -0.556, 'irritate', 'idiot', 'talk_shit', 'rude', 'awful']
senticnet['vexation'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['vexatious'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'teasing']
senticnet['vexatious_litigant'] = [0.071, -0.044, 0, 0, '#joyful', '#surprising', 0.038, 'carpenter', 'litigant', 'tape_player', 'copper_wire', 'several_types']
senticnet['vexed'] = [-0.141, 0.098, 0.662, -0.656, '#angry', '#disgusting', -0.454, 'pesky', 'miffed', 'galling', 'annoying', 'vexatious']
senticnet['vexing'] = [-0.132, 0.119, 0.652, -0.651, '#angry', '#disgusting', -0.439, 'infuriation', 'enragement', 'maddening', 'infuriate', 'furiously']
senticnet['vial'] = [0.026, 0.067, 0, 0, '#joyful', '#interesting', 0.031, 'beaker', 'glass_container', 'bottle', 'drink_holder', 'flask']
senticnet['vibrant'] = [-0.051, 0.096, 0, 0.066, '#interesting', '#admirable', 0.037, 'hue_tint', 'spectrum', 'red_blue', 'green_yellow', 'tint']
senticnet['vibrate'] = [0, 0.717, 0, 0.749, '#interesting', '#admirable', 0.489, 'jiggle', 'back_forth', 'pull_car', 'convulse', 'bail_water']
senticnet['vibration'] = [0.048, 0.084, 0, 0.209, '#interesting', '#admirable', 0.114, 'move', 'motion', 'motility', 'movement', 'flicker']
senticnet['vicar'] = [0.023, 0.244, -0.045, 0.212, '#interesting', '#admirable', 0.145, 'pastor', 'church_head', 'protestant', 'monk', 'prayer']
senticnet['vicarious'] = [-0.583, 0, 0.814, -0.54, '#sad', '#angry', -0.646, 'atypical', 'irregular', 'abnormal', 'supernormal', 'subnormal']
senticnet['vice'] = [-0.762, 0, 0, -0.79, '#sad', '#disgusting', -0.517, 'bad_habit', 'smoke_cigarette', 'drink_alcohol', 'gambling_addiction', 'gambling']
senticnet['vice_admiral'] = [0.688, -0.908, 0, 0.877, '#surprising', '#admirable', 0.824, 'fleet_admiral', 'rear_admiral', 'admiral', 'full_admiral', 'flag_officer']
senticnet['vicinity'] = [0.088, 0.161, 0, 0.22, '#interesting', '#admirable', 0.156, 'location', 'absent', 'nearby', 'small_place', 'proximity']
senticnet['vicious'] = [-0.159, 0, -0.122, -0.096, '#sad', '#scared', -0.126, 'feel_ashamed', 'hunt_animal', 'play_dead', 'feel_confident', 'crazy']
senticnet['vicious_circle'] = [0.886, -0.586, 0, 0.792, '#joyful', '#admirable', 0.755, 'argument', 'straw_man', 'strawman', 'specious_argument', 'special_pleading']
senticnet['victim'] = [-0.854, 0, 0.872, -0.946, '#angry', '#disgusting', -0.891, 'bloodshed', 'buy_gun', 'assault', 'enemy', 'siege']
senticnet['victim_crime'] = [-0.763, 0, 0.742, -0.85, '#sad', '#disgusting', -0.785, 'pass_judgment', 'see_justice_done', 'juror', 'judge', 'punish_criminal']
senticnet['victimize'] = [-0.897, 0, 0.826, -0.501, '#sad', '#angry', -0.741, 'wrong', 'delude', 'deceive', 'cozen', 'rip_off']
senticnet['victor'] = [0.556, -0.688, 0, 0.978, '#surprising', '#admirable', 0.741, 'conqueror', 'vanquisher', 'combatant', 'battler', 'belligerent']
senticnet['victory'] = [0.82, 0.792, 0, 0.757, '#joyful', '#interesting', 0.79, 'win_battle', 'test_mettle', 'life', 'win_war', 'win']
senticnet['victory_defeat'] = [-0.082, -0.045, -0.055, -0.256, '#sad', '#disgusting', -0.116, 'lose_battle', 'beaten', 'defeat', 'lose_war', 'win_battle']
senticnet['video_game'] = [0.082, -0.017, 0.011, 0, '#joyful', '#surprising', 0.029, 'yo-yo', 'action_figure', 'ball_game', 'playroom', 'board_game']
senticnet['video_recorder'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'live_human', 'terrier', 'vertebrate', 'elf', 'ice_skater']
senticnet['video_tape'] = [0, 0, 0, -0.17, '#disgusting', '#disgusting', -0.057, 'medicine', 'aspirin', 'blank_check', 'painkiller', 'gauze']
senticnet['view_art'] = [0.082, -0.017, 0.011, 0, '#joyful', '#surprising', 0.029, 'art', 'paint', 'painting', 'picture', 'opera']
senticnet['view_film'] = [0.826, 0.894, 0, 0, '#joyful', '#interesting', 0.573, 'press_play', 'rend_movie', 'insert_dvd_in_player', 'view_movie', 'hear_funny']
senticnet['view_film_home'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'view_video', 'watch_tv_show', 'watch_film', 'take_film', 'watch_movie']
senticnet['view_movie'] = [0.741, 0.868, 0, 0, '#joyful', '#interesting', 0.536, 'use_remote_control', 'rewind', 'see_film', 'jitters', 'view_film']
senticnet['view_nature'] = [0.711, 0.827, 0, 0, '#joyful', '#interesting', 0.513, 'great_exercise', 'enjoy_nature', 'wear_out_shoes', 'physical_exertion', 'exercise_dog']
senticnet['view_video'] = [0, 0.737, 0, 0.94, '#interesting', '#admirable', 0.559, 'record_film', 'proof_of_purchase', 'watch_television', 'use_television', 'store_film']
senticnet['viewer'] = [0, 0.075, 0.047, 0.101, '#interesting', '#admirable', 0.043, 'watcher', 'part_of_face', 'facial_organ', 'face_feature', 'head_organ']
senticnet['viewfinder'] = [0.021, 0.081, 0.017, 0.113, '#interesting', '#admirable', 0.066, 'aspect', 'perspective', 'look_round', 'scenic', 'look_through']
senticnet['viewpoint'] = [-0.024, 0.272, -0.082, 0.236, '#interesting', '#admirable', 0.134, 'polarize', 'imaginative', 'acknowledge', 'idea', 'brain_function']
senticnet['vigil'] = [-0.565, 0, 0.568, -0.718, '#angry', '#disgusting', -0.617, 'wakefulness', 'arousal', 'waking', 'physical_condition', 'physiological_state']
senticnet['vigilance'] = [0, 1, 0, 0, '#interesting', '#interesting', 0.333, 'interest', 'attention', 'mood', 'strong_emotion', 'emotion']
senticnet['vigor'] = [-0.709, 0, 0.703, -0.534, '#sad', '#angry', -0.649, 'athleticism', 'strenuosity', 'forcefulness', 'force', 'strength']
senticnet['vigorous_activity'] = [0, 0, 0, 0.202, '#admirable', '#admirable', 0.067, 'human_movement', 'human_action', 'fast_movement', 'like_run', 'body_movement']
senticnet['vigorous_exercise'] = [0, 0, 0, 0.968, '#admirable', '#admirable', 0.323, 'physical_exertion', 'wear_out_shoes', 'become_physically_fit', 'much_exercise', 'strain_muscle']
senticnet['vile'] = [-0.062, 0.128, 0.707, -0.677, '#angry', '#disgusting', -0.439, 'sickish', 'turn_stomach', 'sickening', 'noisome', 'nauseous']
senticnet['vileness'] = [-0.97, 0, 0.536, -0.583, '#sad', '#disgusting', -0.696, 'lousiness', 'odiousness', 'sliminess', 'unpleasantness', 'blatancy']
senticnet['vilification'] = [-0.684, 0, 0.637, -0.504, '#sad', '#angry', -0.608, 'calumniation', 'traducement', 'hatchet_job', 'defamation', 'calumny']
senticnet['vilipend'] = [-0.574, 0, 0.827, -0.706, '#angry', '#disgusting', -0.702, 'disparage', 'belittle', 'deflate', 'puncture', 'pick_at']
senticnet['village_green'] = [-0.726, 0, 0.978, -0.861, '#angry', '#disgusting', -0.855, 'amusement_park', 'funfair', 'pleasure_ground', 'commons', 'tract']
senticnet['villager'] = [0.9, -0.513, 0, 0.836, '#joyful', '#admirable', 0.75, 'indweller', 'inhabitant', 'habitant', 'dweller', 'denizen']
senticnet['villain'] = [-0.166, 0, 0, -0.198, '#sad', '#disgusting', -0.121, 'military', 'attacker', 'military_force', 'opposition', 'army']
senticnet['villein'] = [-0.088, 0, -0.145, 0, '#sad', '#scared', -0.078, 'farmer', 'peasant', 'servant', 'poor', 'serf']
senticnet['vindication'] = [-0.798, 0, 0.651, -0.757, '#sad', '#disgusting', -0.735, 'defense', 'exculpation', 'extenuation', 'mitigation', 'defence']
senticnet['vindictive'] = [-0.031, 0.157, 0.698, -0.661, '#angry', '#disgusting', -0.411, 'vengefulness', 'vindictively', 'vengefully', 'revengefully', 'spiteful']
senticnet['vindictively'] = [-0.031, 0.157, 0.698, -0.661, '#angry', '#disgusting', -0.411, 'vengefulness', 'vengefully', 'revengefully', 'vindictive', 'spiteful']
senticnet['vindictiveness'] = [-0.031, 0.157, 0.698, -0.661, '#angry', '#disgusting', -0.411, 'vengefulness', 'vindictively', 'vengefully', 'revengefully', 'vindictive']
senticnet['vine'] = [-0.055, 0, 0, -0.071, '#sad', '#disgusting', -0.042, 'ivy', 'green_color', 'green_leave', 'evergreen_tree', 'large_plant']
senticnet['vine_fruit'] = [0.05, 0, 0.047, 0.068, '#joyful', '#admirable', 0.024, 'tree_fruit', 'yellow_fruit', 'small_fruit', 'delicious_fruit', 'red_fruit']
senticnet['vinegariness'] = [-0.991, 0, 0.744, -0.74, '#sad', '#angry', -0.825, 'acerbity', 'acidity', 'vinegarishness', 'tartness', 'taste_property']
senticnet['vinegarishness'] = [-0.991, 0, 0.744, -0.74, '#sad', '#angry', -0.825, 'acerbity', 'vinegariness', 'acidity', 'tartness', 'taste_property']
senticnet['violate'] = [-0.632, 0, 0.796, -0.776, '#angry', '#disgusting', -0.735, 'blindside', 'profane', 'assault', 'savage', 'assail']
senticnet['violation'] = [-0.698, 0, 0.752, -0.82, '#angry', '#disgusting', -0.757, 'usurpation', 'trespass', 'encroachment', 'intrusion', 'inroad']
senticnet['violator'] = [-0.809, 0, 0, -0.702, '#sad', '#disgusting', -0.504, 'felon', 'crook', 'malefactor', 'outlaw', 'criminal']
senticnet['violence'] = [-0.971, 0, -0.98, -0.827, '#sad', '#scared', -0.926, 'siege', 'conflict', 'combat', 'big_fight', 'battle']
senticnet['violent'] = [0, 0, -0.753, -0.749, '#scared', '#disgusting', -0.501, 'threat', 'hazardous', 'deadly', 'funny_look', 'rival']
senticnet['violent_action'] = [-0.768, 0, 0.85, -0.778, '#angry', '#disgusting', -0.799, 'bad_action', 'bad_behavior', 'consequence', 'judge_decision', 'badness']
senticnet['violent_crime'] = [-0.474, 0.174, -0.447, 0.105, '#sad', '#scared', -0.214, 'wrong', 'wrongdoing', 'bad_choice', 'harmful_human', 'bad_behavior']
senticnet['violent_death'] = [-0.716, 0, 0.748, -0.55, '#sad', '#angry', -0.671, 'casualty', 'fatal_accident', 'killing', 'fatality', 'death']
senticnet['violent_person'] = [-0.832, 0, -0.7, -0.791, '#sad', '#disgusting', -0.774, 'death_destruction', 'defend_oneself', 'destroy_live', 'kill_enemy', 'murder']
senticnet['violent_sport'] = [0, -0.091, 0, 0.102, '#surprising', '#admirable', 0.064, 'type_of_sport', 'rough_sport', 'rough_game', 'team_sport', 'contact_sport']
senticnet['violet'] = [-0.089, 0, 0, 0, '#sad', '#sad', -0.03, 'cyan', 'yellow_blue', 'cold_color', 'color', 'cool_color']
senticnet['violin_bow'] = [0.109, 0.129, 0, 0.098, '#joyful', '#interesting', 0.112, 'take_lesson', 'take_music_lesson', 'a_lot_of_practice', 'tune_instrument', 'learn_read_music']
senticnet['violin_case'] = [0, 0.842, 0, 0.765, '#interesting', '#admirable', 0.536, 'string_quartet', 'drum_set', 'high_school_band', 'music_shop', 'band_room']
senticnet['viper'] = [-0.96, 0, 0.865, -0.753, '#sad', '#angry', -0.859, 'gaboon_viper', 'ophidian', 'serpent', 'snake', 'adder']
senticnet['viral_hepatitis'] = [-0.881, 0, 0.864, -0.795, '#sad', '#angry', -0.847, 'hepatitis', 'disease', 'feel_sick', 'liver_disease', 'infectious_disease']
senticnet['viral_pneumonia'] = [-0.926, 0, 0.824, -0.522, '#sad', '#angry', -0.757, 'bronchopneumonia', 'bronchial_pneumonia', 'pneumonia', 'pleuropneumonia', 'pneumococcal_pneumonia']
senticnet['virility_drug'] = [-0.595, 0, 0.537, -0.577, '#sad', '#disgusting', -0.57, 'phentolamine', 'sildenafil', 'sildenafil_citrate', 'tadalafil', 'vardenafil']
senticnet['virtue'] = [0.193, 0.298, -0.189, 0.369, '#interesting', '#admirable', 0.224, 'goodness', 'good_quality', 'honest', 'best', 'honor']
senticnet['virtuoso'] = [0.867, 0.726, 0, 0, '#joyful', '#interesting', 0.531, 'sensation', 'champion', 'adept', 'ace', 'maven']
senticnet['virulent'] = [0, 0, -0.795, -0.823, '#scared', '#disgusting', -0.539, 'deadly', 'acerbic', 'blistering', 'acid', 'venomous']
senticnet['virus'] = [0, 0, -0.985, -0.858, '#scared', '#disgusting', -0.614, 'contagious_disease', 'infectious_disease', 'sexually_transmit_disease', 'disease', 'malady']
senticnet['visa'] = [0.029, 0.177, -0.102, 0.188, '#interesting', '#admirable', 0.097, 'mastercard', 'invoice', 'american_express', 'bill', 'pay_debt']
senticnet['visa_card'] = [-0.028, 0.119, 0, 0.054, '#interesting', '#admirable', 0.048, 'credit_card_company', 'debit_card', 'check', 'credit_card', 'cash_coin']
senticnet['viscous'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'wet', 'sticky', 'gluey', 'tacky', 'gooey']
senticnet['viscous_substance'] = [0, 0, 0, -0.964, '#disgusting', '#disgusting', -0.321, 'thick_substance', 'phlegm', 'mucous_substance', 'disgusting', 'disgust']
senticnet['visible'] = [0, 0.895, 0, 0.919, '#interesting', '#admirable', 0.605, 'blue_green', 'red_green', 'hue_tint', 'colorful', 'yellow_green']
senticnet['visible_light'] = [-0.925, 0, 0.734, -0.51, '#sad', '#angry', -0.723, 'chemiluminescence', 'light', 'bioluminescence', 'luminescence', 'visible_radiation']
senticnet['visible_radiation'] = [-0.925, 0, 0.734, -0.51, '#sad', '#angry', -0.723, 'chemiluminescence', 'light', 'bioluminescence', 'visible_light', 'luminescence']
senticnet['vision'] = [-0.035, 0.081, 0, 0.095, '#interesting', '#admirable', 0.047, 'sight', 'eye_function', 'eye_sense', 'see_ability', 'like_see']
senticnet['vision_defect'] = [-0.793, 0, 0.927, -0.956, '#angry', '#disgusting', -0.892, 'disability', 'disablement', 'aphakia', 'color_blindness', 'color_vision_deficiency']
senticnet['vision_loss'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'walking_stick', 'sunglasses', 'disabled', 'poor_visual_perception', 'blind_person']
senticnet['visionary'] = [0.724, 0, 0, 0.783, '#joyful', '#admirable', 0.502, 'idealist', 'inspired', 'imaginative', 'creative', 'inventive']
senticnet['visit'] = [0.065, 0, -0.054, 0.085, '#joyful', '#admirable', 0.032, 'join_club', 'social_skill', 'go_abroad', 'drive_around', 'ride_train']
senticnet['visit_barber'] = [0.123, 0.29, -0.192, 0.278, '#interesting', '#admirable', 0.166, 'go_barber', 'haircut', 'go_hair_salon', 'makeover', 'get_hair_colored']
senticnet['visit_doctor'] = [0, 0, -0.882, 0, '#scared', '#scared', -0.294, 'blood_test', 'go_doctor', 'go_see_doctor', 'see_doctor', 'eat_balance_diet']
senticnet['visit_family'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'visit_parent', 'christmas_holiday', 'visit', 'visit_mother', 'visit_father']
senticnet['visit_father'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'visit_family', 'christmas_holiday', 'visit', 'visit_mother', 'visit_parent']
senticnet['visit_friend'] = [0.719, 0.988, 0, 0, '#joyful', '#interesting', 0.569, 'socialize', 'bring_gift', 'talk_friend', 'meet_new_person', 'surprise']
senticnet['visit_grandmother'] = [0.941, 0.929, 0, 0, '#joyful', '#interesting', 0.623, 'explain_everything', 'forward_email', 'deal_card_player', 'stand_alone', 'bridge_difference']
senticnet['visit_grandparent'] = [0.788, 0.592, -0.207, 0.342, '#joyful', '#interesting', 0.505, 'family_nest', 'thank_parent', 'home_sweet_home', 'family', 'head_home']
senticnet['visit_library'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'buy_book', 'study_history', 'open_book', 'go_to_library', 'buy_textbook']
senticnet['visit_mother'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'visit_family', 'christmas_holiday', 'visit', 'visit_parent', 'visit_father']
senticnet['visit_new_place'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'globe_trotter', 'travel', 'wanderlust', 'explore', 'discover']
senticnet['visit_other_country'] = [0.787, 0.833, 0, 0, '#joyful', '#interesting', 0.54, 'go_vacation', 'leave_country', 'go_somewhere', 'plan_vacation', 'go_pub']
senticnet['visit_parent'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'visit_family', 'christmas_holiday', 'visit', 'visit_mother', 'visit_father']
senticnet['visit_relative'] = [0.872, 0.772, 0, 0.837, '#joyful', '#admirable', 0.827, 'experience_emotion', 'see_oneself', 'experience_joy', 'win_contest', 'listen_rock_music']
senticnet['visit_web_site'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'internet', 'go_online', 'web_site', 'find_information', 'choose_book']
senticnet['visit_zoo'] = [0, 0, 0, 0.911, '#admirable', '#admirable', 0.304, 'find_computer', 'build_computer', 'start_computer', 'switch_computer', 'log_off']
senticnet['visitor'] = [0.921, 0.923, 0, 0, '#joyful', '#interesting', 0.615, 'business_man', 'no_doubt', 'company', 'dolt', 'partnership']
senticnet['vista'] = [0, 0.962, 0, 0.971, '#interesting', '#admirable', 0.644, 'spectacular', 'panorama', 'perspective', 'scenic', 'view']
senticnet['visual'] = [-0.033, 0.102, 0, 0.099, '#interesting', '#admirable', 0.056, 'drawn', 'please_eye', 'wall_hang', 'category', 'wall_decoration']
senticnet['visual_agnosia'] = [-0.738, 0, 0.955, -0.547, '#sad', '#angry', -0.747, 'agnosia', 'auditory_agnosia', 'brain_disorder', 'encephalopathy', 'brain_disease']
senticnet['visual_aid'] = [0, 0.108, 0.01, 0.121, '#interesting', '#admirable', 0.073, 'complex_organ', 'no_sight', 'face_feature', 'facial_organ', 'part_of_face']
senticnet['visual_communication'] = [-0.025, 0, -0.049, -0.031, '#scared', '#disgusting', -0.035, 'studio', 'art_piece', 'art_gallery', 'artist', 'museum']
senticnet['visual_defect'] = [-0.874, 0, 0.961, -0.667, '#sad', '#angry', -0.834, 'disability', 'disablement', 'aphakia', 'color_blindness', 'color_vision_deficiency']
senticnet['visual_disorder'] = [-0.862, 0, 0.913, -0.944, '#angry', '#disgusting', -0.906, 'disability', 'disablement', 'aphakia', 'color_blindness', 'color_vision_deficiency']
senticnet['visual_impairment'] = [-0.754, 0, 0.769, -0.685, '#sad', '#angry', -0.736, 'disability', 'disablement', 'aphakia', 'color_blindness', 'color_vision_deficiency']
senticnet['visual_information'] = [0.044, 0.08, 0, -0.03, '#joyful', '#interesting', 0.031, 'screen', 'pixel', 'computer_monitor', 'image', 'display']
senticnet['visual_representation'] = [0, 0.924, 0, 0.885, '#interesting', '#admirable', 0.603, 'priceless', 'universal', 'important_human', 'bourgeois', 'artistic_expression']
senticnet['visual_sense'] = [0.959, -0.976, 0, 0.633, '#joyful', '#surprising', 0.856, 'oxyopia', 'sight', 'top', 'vision', 'acuity']
senticnet['visual_space'] = [-0.739, 0, 0.814, -0.887, '#angry', '#disgusting', -0.813, 'contrast', 'perception', 'face_recognition', 'object_recognition', 'seeing']
senticnet['visualize'] = [-0.094, 0, 0, -0.125, '#sad', '#disgusting', -0.073, 'write_down_idea', 'finish_book', 'write_down', 'take_note_class', 'take_note']
senticnet['visually_impaired_person'] = [-0.638, 0, 0.625, -0.989, '#sad', '#disgusting', -0.751, 'aphakic', 'blind_person', 'myope', 'mortal', 'hyperope']
senticnet['vital'] = [0.062, 0.335, 0, 0.36, '#interesting', '#admirable', 0.252, 'religious', 'religious_ceremony', 'religious_service', 'church_service', 'sacred']
senticnet['vital_organ'] = [0, 0, 0, 0.092, '#admirable', '#admirable', 0.031, 'organ_body', 'body_organ', 'internal_organ', 'human_part', 'heart']
senticnet['vitality'] = [0, 0.997, 0, 0.735, '#interesting', '#admirable', 0.577, 'powerful', 'create_destroy', 'essential', 'important', 'hyper']
senticnet['vitiate'] = [-0.961, 0, 0.996, -0.997, '#angry', '#disgusting', -0.985, 'suborn', 'modify', 'poison', 'lead_astray', 'alter']
senticnet['vitiated'] = [-0.968, 0, 0.624, -0.99, '#sad', '#disgusting', -0.861, 'impaired', 'dicky', 'dickey', 'lessened', 'diminished']
senticnet['vitriolic'] = [-0.877, 0, -0.965, 0, '#sad', '#scared', -0.614, 'corrosive', 'sulfurous', 'acid', 'acerbic', 'bitter']
senticnet['vituperation'] = [-0.576, 0, 0.79, -0.899, '#angry', '#disgusting', -0.755, 'abuse', 'vilification', 'insult', 'revilement', 'contumely']
senticnet['vivid'] = [0.927, 0, 0, 0.855, '#joyful', '#admirable', 0.594, 'lifelike', 'graphic', 'pictorial', 'bright', 'brilliant']
senticnet['vivification'] = [0.668, -0.884, 0, 0.893, '#surprising', '#admirable', 0.815, 'chirpiness', 'spirit', 'sprightliness', 'liveliness', 'activity']
senticnet['vivify'] = [0.837, -0.923, 0, 0.8, '#joyful', '#surprising', 0.853, 'energize', 'perk_up', 'brace', 'stimulate', 'arouse']
senticnet['vixen'] = [-0.662, 0, 0.992, -0.726, '#angry', '#disgusting', -0.793, 'fox', 'red_fox', 'kit_fox', 'prairie_fox', 'white_fox']
senticnet['vixenish'] = [-0.887, 0, 0.864, -0.725, '#sad', '#angry', -0.825, 'malicious', 'venomous', 'bitchy', 'catty', 'cattish']
senticnet['vocal'] = [0.055, -0.003, 0.025, 0.114, '#joyful', '#admirable', 0.049, 'human_sound', 'loud_soft', 'vocalization', 'mouth_noise', 'audible']
senticnet['vocal_chord'] = [0, 0, 0, 0.095, '#admirable', '#admirable', 0.032, 'vocal_cord', 'mouth_noise', 'vocal_sound', 'human_sound', 'vocalization']
senticnet['vocal_cord'] = [0, 0, 0, 0.106, '#admirable', '#admirable', 0.035, 'vocal_chord', 'mouth_noise', 'vocal_sound', 'human_sound', 'vocalization']
senticnet['vocal_music'] = [0.915, 0, 0, 0.784, '#joyful', '#admirable', 0.566, 'instrumental', 'lyric', 'lyrics', 'sung', 'melody']
senticnet['vocal_sound'] = [0, -0.036, 0, 0.115, '#surprising', '#admirable', 0.05, 'mouth_noise', 'vocal_cord', 'vocalization', 'human_sound', 'vocal_chord']
senticnet['vocalization'] = [0.032, 0, 0, 0.149, '#joyful', '#admirable', 0.06, 'human_sound', 'mouth_noise', 'human_noise', 'audible', 'loud_soft']
senticnet['vocation'] = [0, 0.166, -0.1, 0.109, '#interesting', '#admirable', 0.058, 'police_work', 'career', 'occupation', 'profession', 'employ']
senticnet['vocational_rehabilitation'] = [0.641, -0.784, 0, 0.721, '#surprising', '#admirable', 0.715, 'correctional_rehabilitation', 'physical_rehabilitation', 'physical_restoration', 'therapeutic_rehabilitation', 'rehabilitation']
senticnet['vodka'] = [0.778, 0, 0, 0.801, '#joyful', '#admirable', 0.526, 'bourbon', 'gin', 'scotch', 'brandy', 'wine']
senticnet['voice'] = [0.033, -0.021, 0, 0.076, '#joyful', '#admirable', 0.043, 'vocal_chord', 'utterance', 'vocal_cord', 'mouth_noise', 'vocal_sound']
senticnet['voice_communication'] = [0, -0.047, 0.021, 0.07, '#surprising', '#admirable', 0.032, 'talk', 'oration', 'talkative', 'spoken_language', 'make_call']
senticnet['voice_concern'] = [0.822, 0.874, 0, 0, '#joyful', '#interesting', 0.565, 'sail_around_world', 'storm_out_room', 'age_gracefully', 'chair_committee', 'bicycle_across_town']
senticnet['voice_of_conscience'] = [0.714, -0.583, 0, 0.667, '#joyful', '#admirable', 0.655, 'morality', 'wee_small_voice', 'small_voice', 'moral_sense', 'sense_of_shame']
senticnet['voice_opinion'] = [-0.144, 0, 0, -0.041, '#sad', '#disgusting', -0.062, 'wrong_another_person', 'erase_blackboard', 'master_skill', 'laugh_oneself', 'lose_key']
senticnet['voiceless'] = [-0.998, 0, 0.798, -0.716, '#sad', '#angry', -0.837, 'silent', 'inaudible', 'unsounded', 'breathed', 'supersonic']
senticnet['voicemail_message'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'leave_message', 'write_note', 'leave_document', 'send_email', 'message']
senticnet['void'] = [-0.914, 0, -0.772, -0.757, '#sad', '#scared', -0.814, 'emptiness', 'star_planet', 'nothingness', 'outer', 'around_earth']
senticnet['voix_celeste'] = [0.939, -0.717, 0, 0.775, '#joyful', '#admirable', 0.81, 'vox_angelica', 'organ_stop', 'dulciana', 'pipe', 'diapason']
senticnet['volatility'] = [-0.526, 0, 0.959, -0.701, '#angry', '#disgusting', -0.729, 'unpredictability', 'indecisiveness', 'indecision', 'trait', 'irresoluteness']
senticnet['volcanic_eruption'] = [0, 0, -0.874, 0, '#scared', '#scared', -0.291, 'dynamite_explosion', 'kind_animal', 'detonation', 'wash_mouth_soap', 'fall_sky']
senticnet['volcano'] = [0, -0.031, -0.105, -0.073, '#scared', '#disgusting', -0.049, 'autumn', 'winter', 'skier', 'snow_fall', 'avalanche']
senticnet['volt'] = [0, 0, -1, -1, '#scared', '#disgusting', -0.667, 'moon_gravity', 'force', 'coercion', 'watt', 'power_source']
senticnet['voltage'] = [0, 0.823, 0, 0.743, '#interesting', '#admirable', 0.522, 'electrical_unit', 'ampere', 'up_date', 'fast_water', 'ocean_movement']
senticnet['voluble'] = [0.949, -0.694, 0, 0.992, '#joyful', '#admirable', 0.878, 'chatty', 'gabby', 'garrulous', 'loquacious', 'talky']
senticnet['volume'] = [0.025, 0.115, 0.06, 0.183, '#interesting', '#admirable', 0.088, 'volume_measurement', 'liquid_measurement', 'mass_measure', 'geometry', 'size']
senticnet['volume_control'] = [0.055, 0.107, 0, 0.052, '#joyful', '#interesting', 0.071, 'life-long_mate', '32_teeth', 'two_arms', 'two_ears', 'belly_button']
senticnet['volume_measurement'] = [0, 0.126, 0.114, 0.194, '#interesting', '#admirable', 0.069, 'liquid_measurement', 'size', 'mass_measure', 'volume', 'heavy_weight']
senticnet['voluminous'] = [0, 0, -0.795, -0.772, '#scared', '#disgusting', -0.522, 'winding', 'tortuous', 'copious', 'twisting', 'twisty']
senticnet['voluntary'] = [-0.023, 0.1, -0.076, 0.089, '#interesting', '#admirable', 0.03, 'functionary', 'employment', 'labor', 'employ', 'toil']
senticnet['voluntary_muscle'] = [0.934, -0.62, 0, 0.79, '#joyful', '#admirable', 0.781, 'skeletal_muscle', 'deltoid', 'pterygoid_muscle', 'abductor', 'abductor_muscle']
senticnet['volunteer'] = [0, 0.818, 0, 0.781, '#interesting', '#admirable', 0.533, 'lend_hand', 'find_out_need', 'raise_hand', 'help_person', 'help_others']
senticnet['vomit'] = [-0.083, 0, -0.07, -0.186, '#sad', '#disgusting', -0.113, 'stagger', 'miss_appointment', 'lower_standard', 'dream_with_eyes_open', 'die_young']
senticnet['vomitive'] = [-0.995, 0, 0.748, -0.968, '#sad', '#disgusting', -0.904, 'remedy', 'cure', 'therapeutic', 'curative', 'ipecac']
senticnet['voracious'] = [0, 0, -0.857, -0.734, '#scared', '#disgusting', -0.53, 'wolfish', 'rapacious', 'esurient', 'ravenous', 'edacious']
senticnet['vote'] = [0, 0.23, -0.124, 0.198, '#interesting', '#admirable', 0.101, 'elect', 'ballot', 'presidential', 'nominate', 'command']
senticnet['voter'] = [0, 0.769, 0, 0.76, '#interesting', '#admirable', 0.51, 'detective', 'politician', 'government', 'democrat', 'legal_person']
senticnet['voting'] = [0.989, -0.763, 0, 0.56, '#joyful', '#surprising', 0.771, 'choice', 'option', 'veto', 'multiple_voting', 'block_vote']
senticnet['vow'] = [0.088, 0.317, -0.297, 0.379, '#interesting', '#admirable', 0.162, 'oath', 'commitment', 'marriage', 'obedience', 'enter_contract']
senticnet['vowel'] = [0.033, 0.101, -0.059, 0.157, '#interesting', '#admirable', 0.077, 'alphabet', 'part_of_speech', 'snail_mail', 'unit_language', 'paper_write']
senticnet['vox_angelica'] = [0.939, -0.717, 0, 0.775, '#joyful', '#admirable', 0.81, 'organ_stop', 'voix_celeste', 'dulciana', 'pipe', 'diapason']
senticnet['voyeur'] = [0.904, 0.932, 0, 0.976, '#interesting', '#admirable', 0.937, 'reliability', 'husband_wife', 'good_teacher', 'smart_man', 'college_professor']
senticnet['vulgarism'] = [-0.9, 0, 0.987, -0.534, '#sad', '#angry', -0.807, 'filth', 'smut', 'scatology', 'dirty_word', 'obscenity']
senticnet['vulgarize'] = [0.666, -0.875, 0, 0.736, '#surprising', '#admirable', 0.759, 'spread', 'diffuse', 'circulate', 'circularize', 'distribute']
senticnet['vulnerable'] = [-0.222, -0.082, -0.258, 0.08, '#sad', '#scared', -0.106, 'ignorant', 'nostalgic', 'helpless', 'bald', 'unwanted']
senticnet['wading_bird'] = [0.797, -0.719, 0, 0.736, '#joyful', '#admirable', 0.751, 'wood_ibis', 'wood_stork', 'sacred_ibis', 'ibis', 'wader']
senticnet['waffle'] = [0.794, 0.98, 0, 0, '#joyful', '#interesting', 0.591, 'food', 'dessert', 'fresh_fruit', 'chocolate', 'jam']
senticnet['wage'] = [0, 0.923, 0, 0, '#interesting', '#interesting', 0.308, 'salary', 'remittance', 'owe', 'payment', 'severance']
senticnet['wage_scale'] = [0.687, -0.98, 0, 0.666, '#joyful', '#surprising', 0.778, 'scale', 'scale_of_measurement', 'graduated_table', 'ordered_series', 'sliding_scale']
senticnet['wage_schedule'] = [0.715, -0.977, 0, 0.945, '#surprising', '#admirable', 0.879, 'scale', 'scale_of_measurement', 'graduated_table', 'ordered_series', 'sliding_scale']
senticnet['wage_slave'] = [-0.036, -0.015, 0.043, -0.125, '#angry', '#disgusting', -0.063, 'employee', 'earn_paycheck', 'have_something_to_do', 'make_work', 'get_job_done']
senticnet['wage_slavery'] = [0, 0, -0.066, -0.037, '#scared', '#disgusting', -0.034, 'day_job', 'much_work', 'coworker', 'low_pay_work', 'pay_child_support']
senticnet['wage_war'] = [-0.995, 0, 0.695, -0.946, '#sad', '#disgusting', -0.879, 'war', 'fight_war', 'kill', 'battle', 'kill_person']
senticnet['wagon'] = [-0.539, 0, 0.905, -0.586, '#angry', '#disgusting', -0.677, 'beach_shooting_brake', 'station_shooting_brake', 'shooting_brake', 'estate_car', 'beach_waggon']
senticnet['waif'] = [-0.613, 0, 0.635, -0.994, '#angry', '#disgusting', -0.747, 'fry', 'kid', 'minor', 'tike', 'small_fry']
senticnet['wail'] = [-0.706, 0, -0.873, -0.817, '#scared', '#disgusting', -0.799, 'bawl', 'weep', 'sob', 'shed_tear', 'freak_out']
senticnet['waist'] = [0, 0, 0, -0.081, '#disgusting', '#disgusting', -0.027, 'bowel', 'scrotum', 'shoulder', 'liver', 'anus']
senticnet['waistband'] = [-0.534, 0, 0.682, -0.748, '#angry', '#disgusting', -0.655, 'girdle', 'cincture', 'sash', 'cummerbund', 'waistcloth']
senticnet['waistcloth'] = [-0.534, 0, 0.682, -0.748, '#angry', '#disgusting', -0.655, 'girdle', 'cincture', 'sash', 'waistband', 'cummerbund']
senticnet['wait'] = [-0.024, 0, 0, -0.083, '#sad', '#disgusting', -0.036, 'wait_turn', 'wait_line', 'stand_queue', 'get_line', 'carve_niche']
senticnet['wait_bus'] = [0, 0, 0, -0.935, '#disgusting', '#disgusting', -0.312, 'book_flight', 'book_hotel_room', 'check_time', 'wait_train', 'act_bored']
senticnet['wait_for'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'impatience', 'impatient', 'tap_foot', 'angry', 'anger']
senticnet['wait_forever'] = [-0.245, 0.086, -0.17, 0, '#sad', '#scared', -0.11, 'correct_mistake', 'face_music', 'bad_liar', 'keep_promise', 'state_obvious']
senticnet['wait_in_line'] = [0, 0.128, -0.049, 0.064, '#interesting', '#admirable', 0.048, 'line_up', 'civility', 'come_early', 'find_end_line', 'wait_patiently']
senticnet['wait_line'] = [-0.032, 0, 0, -0.101, '#sad', '#disgusting', -0.044, 'stand_queue', 'wait_turn', 'stand_in_line', 'carve_niche', 'get_line']
senticnet['wait_patiently'] = [0, 0.817, 0, 0, '#interesting', '#interesting', 0.272, 'find_end_line', 'see_how_long_line', 'take_number', 'learn_patience', 'come_early']
senticnet['wait_person'] = [0, 0.085, -0.05, 0.07, '#interesting', '#admirable', 0.035, 'greet_guest', 'use_party', 'party', 'pay_rend', 'alcoholism']
senticnet['wait_room'] = [-0.029, 0, -0.123, -0.227, '#scared', '#disgusting', -0.126, 'syringe', 'x-ray_machine', 'examination_table', 'doctor_examination_room', 'patient']
senticnet['wait_service'] = [0, 0, 0.735, -0.75, '#angry', '#disgusting', -0.495, 'wait_turn', 'wait_line', 'wait', 'stand_queue', 'carve_niche']
senticnet['wait_staff'] = [0, 0.879, 0, 0.984, '#interesting', '#admirable', 0.621, 'server', 'manager', 'waitress', 'public_servant', 'waiter']
senticnet['wait_table'] = [0.974, 0.789, 0, 0.828, '#joyful', '#admirable', 0.864, 'get_out_of_bed', 'start_new_day', 'buy_sandwich', 'eat_breakfast', 'get_coffee']
senticnet['wait_train'] = [-0.041, -0.016, 0, -0.092, '#sad', '#disgusting', -0.039, 'board_subway_train', 'wait_patiently', 'wait', 'find_end_line', 'conformist_attitude']
senticnet['wait_turn'] = [-0.029, 0, 0, -0.095, '#sad', '#disgusting', -0.041, 'wait_line', 'stand_queue', 'get_line', 'carve_niche', 'wait']
senticnet['wait_until_turn'] = [-0.068, -0.013, 0.016, -0.151, '#sad', '#disgusting', -0.074, 'take_number', 'come_early', 'learn_patience', 'wait_patiently', 'find_end_line']
senticnet['waiting_game'] = [0.681, -0.851, 0, 0.605, '#joyful', '#surprising', 0.712, 'contrivance', 'bubble', 'house_of_cards', 'stratagem', 'strategy']
senticnet['waiting_time'] = [-0.054, 0, 0, -0.092, '#sad', '#disgusting', -0.049, 'long_queue', 'go_post_office', 'queue', 'waste_time', 'stress']
senticnet['waive'] = [0, 0, -0.981, -0.82, '#scared', '#disgusting', -0.6, 'foreswear', 'relinquish', 'dispense_with', 'forgo', 'throw_overboard']
senticnet['wake'] = [0, 0.963, 0, 0.923, '#interesting', '#admirable', 0.629, 'set_off', 'shake_up', 'scandalmongering', 'sensationalistic', 'sensational']
senticnet['wake_morning'] = [0.858, 0.954, 0, 0, '#joyful', '#interesting', 0.604, 'make_music', 'produce_sound', 'communicator', 'clear_throat', 'mouth_noise']
senticnet['wake_up'] = [0, 0.774, 0, 0.816, '#interesting', '#admirable', 0.53, 'awake', 'get_up_early', 'drink_coffee', 'drink_milk', 'have_breakfast']
senticnet['wake_up_call'] = [-0.134, -0.085, 0.015, -0.215, '#sad', '#disgusting', -0.093, 'wake_up_early', 'set_alarm', 'lack_of_sleep', 'alarm', 'set_timer']
senticnet['wake_up_early'] = [-0.064, -0.041, 0.039, -0.063, '#sad', '#disgusting', -0.042, 'sleep_early', 'finish_sleep', 'go_bed_early', 'set_alarm_clock', 'shut_off_alarm_clock']
senticnet['wake_up_morning'] = [0, 0.08, 0, 0.179, '#interesting', '#admirable', 0.086, 'awake', 'up_early', 'get_up_early', 'gather_energy_tomorrow', 'sit_chair']
senticnet['wakefulness'] = [-0.565, 0, 0.568, -0.718, '#angry', '#disgusting', -0.617, 'vigil', 'arousal', 'waking', 'physical_condition', 'physiological_state']
senticnet['waken'] = [0.694, -0.839, 0, 0.772, '#surprising', '#admirable', 0.768, 'bring_around', 'call', 'change', 'alter', 'modify']
senticnet['waking'] = [-0.565, 0, 0.568, -0.718, '#angry', '#disgusting', -0.617, 'vigil', 'arousal', 'wakefulness', 'physical_condition', 'physiological_state']
senticnet['walk_across_street'] = [0.733, 0.928, 0, 0, '#joyful', '#interesting', 0.554, 'date_woman', 'marry_man', 'service_car', 'date_man', 'oil_hinge']
senticnet['walk_along'] = [0, 0, 0, 0.165, '#admirable', '#admirable', 0.055, 'get_around', 'passenger_car', 'fun_ride', 'car_go', 'go_elsewhere']
senticnet['walk_along_beach'] = [0.093, 0.087, -0.05, 0.136, '#joyful', '#admirable', 0.089, 'have_fun', 'wear_necklace', 'sing_microphone', 'eat_together', 'gain_respect']
senticnet['walk_around'] = [0.839, 0.926, 0, 0, '#joyful', '#interesting', 0.588, 'walk', 'find_garden', 'enter_place', 'walk_down', 'pass_through']
senticnet['walk_away'] = [-0.025, 0.087, 0, 0.107, '#interesting', '#admirable', 0.056, 'say_good_bye', 'step_aside', 'step_out', 'excuse_oneself', 'open_mailbox']
senticnet['walk_beach'] = [0.739, 0, 0, 0.969, '#joyful', '#admirable', 0.569, 'bible', 'popular_hobby', 'big_boat', 'song_lyric', 'bible_story']
senticnet['walk_closet'] = [0, 0.722, 0, 0.826, '#interesting', '#admirable', 0.516, 'rug', 'carpet', 'linoleum', 'pillow_case', 'floor']
senticnet['walk_device'] = [0, 0.069, 0.031, 0.149, '#interesting', '#admirable', 0.062, 'walk_part', 'extension', 'foot_action', 'limp', 'stand_upon']
senticnet['walk_dog'] = [-0.183, 0, -0.142, -0.111, '#sad', '#scared', -0.145, 'fly_kite', 'ride_roller_coaster', 'skateboard', 'rake_leave', 'jump_up_down']
senticnet['walk_down'] = [0, 0.947, 0, 0.799, '#interesting', '#admirable', 0.582, 'find_garden', 'enter_place', 'walk', 'walk_through', 'progress']
senticnet['walk_drive'] = [0, 0, 0, 0.104, '#admirable', '#admirable', 0.035, 'use_vehicle', 'turn_car', 'transportation', 'car_travel', 'car_go']
senticnet['walk_exercise'] = [0, 0, 0, 0.964, '#admirable', '#admirable', 0.321, 'push_cart', 'buy_new', 'lose_wallet', 'pay_dinner', 'buy_many']
senticnet['walk_fast'] = [0, 0.902, 0, 0.933, '#interesting', '#admirable', 0.612, 'fast_walk', 'like_run', 'walk_quickly', 'run_slowly', 'human_movement']
senticnet['walk_on_air'] = [0.673, 0.631, -0.233, 0.309, '#joyful', '#interesting', 0.46, 'exultingly', 'on_cloud_nine', 'exultation', 'jubilance', 'happiness']
senticnet['walk_out'] = [0.867, 0.714, 0, 0, '#joyful', '#interesting', 0.527, 'laugh_loudly', 'walk_out_dog', 'laugh_out_loud', 'entertain', 'feel_emotion']
senticnet['walk_out_dog'] = [0.867, 0.714, 0, 0, '#joyful', '#interesting', 0.527, 'laugh_loudly', 'walk_out', 'laugh_out_loud', 'entertain', 'feel_emotion']
senticnet['walk_over'] = [0.53, -0.657, 0, 0.652, '#surprising', '#admirable', 0.613, 'vanquish', 'beat', 'beat_out', 'trounce', 'crush']
senticnet['walk_part'] = [-0.043, 0.086, 0.036, 0.166, '#interesting', '#admirable', 0.058, 'limp', 'stand_upon', 'walk_device', 'wal', 'foot_action']
senticnet['walk_quickly'] = [-0.046, 0.109, -0.061, 0.121, '#interesting', '#admirable', 0.041, 'use_leg', 'agility', 'run_slowly', 'find_ball', 'take_step']
senticnet['walk_school'] = [-0.115, 0, -0.078, -0.04, '#sad', '#scared', -0.078, 'laugh_oneself', 'throw_fit', 'watch_d', 'shoulder_responsibility', 'sun_oneself']
senticnet['walk_slowly'] = [0, 0.781, 0, 0, '#interesting', '#interesting', 0.26, 'dirty_kitchen', 'comfortable_position', 'hot_dog_bun', 'get_tired', 'collapse']
senticnet['walk_stick'] = [0.071, -0.339, 0.01, 0.127, '#surprising', '#admirable', 0.176, 'stick', 'sharp_nail', 'wand', 'cue', 'long_stick']
senticnet['walk_style'] = [-0.137, 0, -0.051, 0, '#sad', '#scared', -0.063, 'walk', 'find_garden', 'walk_down', 'go_for_stroll', 'enter_place']
senticnet['walk_through'] = [-0.043, 0.072, 0, 0.145, '#interesting', '#admirable', 0.058, 'connect_two_rooms', 'connect_room', 'enter_place', 'go_through', 'entrance_room']
senticnet['walk_through_door'] = [-0.037, 0, 0.033, -0.065, '#sad', '#disgusting', -0.045, 'carry_luggage', 'pass_by', 'meet_friends', 'pay_dinner', 'increase_value']
senticnet['walk_through_wall'] = [-0.085, 0, -0.098, 0, '#sad', '#scared', -0.061, 'magic', 'travel_fast_light', 'live_forever', 'drink_sea_water', 'live_ocean']
senticnet['walk_up'] = [-0.045, 0.087, 0, 0.133, '#interesting', '#admirable', 0.058, 'get_floor_another', 'go_up_down', 'tread', 'go_up', 'step']
senticnet['walk_upon'] = [-0.075, 0, 0.026, 0, '#sad', '#angry', -0.034, 'stand_upon', 'keep_foot_warm', 'stand', 'walk', 'find_garden']
senticnet['walk_wood'] = [0.117, 0, 0.04, 0.147, '#joyful', '#admirable', 0.075, 'comfortable_place_sleep', 'sleep_furniture', 'use_bed', 'time_rest', 'cozy']
senticnet['walker'] = [0.822, 0.768, 0, 0, '#joyful', '#interesting', 0.53, 'footstep', 'foot', 'wander', 'heel', 'sneaker']
senticnet['walking_stick'] = [0, 0, 0.919, -0.786, '#angry', '#disgusting', -0.568, 'blind_person', 'sunglasses', 'disabled', 'poor_visual_perception', 'vision_loss']
senticnet['walkout'] = [-0.772, 0, 0.505, -0.503, '#sad', '#angry', -0.593, 'wildcat_strike', 'sympathy_strike', 'sympathetic_strike', 'work_stoppage', 'job_action']
senticnet['walkover'] = [-0.687, 0, 0.545, -0.688, '#sad', '#disgusting', -0.64, 'stunt', 'tumble', 'split', 'acrobatic_feat', 'backbend']
senticnet['wall_art'] = [0.165, 0.069, 0.028, 0.057, '#joyful', '#interesting', 0.088, 'make_paint', 'stir_paint_brush', 'buy_paint', 'stir_paint', 'pick_up_brush']
senticnet['wall_cover'] = [0, 0, 0, 0.094, '#admirable', '#admirable', 0.031, 'cover_wall', 'latex', 'two-dimensional', 'decorator', 'dye']
senticnet['wall_decoration'] = [-0.043, 0.135, -0.056, 0.162, '#interesting', '#admirable', 0.066, 'wall_hang', 'image', 'artwork', 'like_paint', 'illustration']
senticnet['wall_germander'] = [-0.565, 0, 0.91, -0.809, '#angry', '#disgusting', -0.761, 'subshrub', 'suffrutex', 'wood_sage', 'germander', 'cat_thyme']
senticnet['wall_hang'] = [0, 0.112, 0, 0.125, '#interesting', '#admirable', 0.079, 'like_paint', 'wall_decoration', 'representation', 'artwork', 'painting']
senticnet['wall_street'] = [0, 0.119, 0, 0.106, '#interesting', '#admirable', 0.075, 'stock_market', 'stock', 'market', 'retail_store', 'corner_store']
senticnet['wallet'] = [0, 0.142, 0, 0, '#interesting', '#interesting', 0.047, 'coffer', 'billfold', 'bank_vault', 'bank', 'piggy_bank']
senticnet['wallet_purse'] = [0, 0.115, 0, 0, '#interesting', '#interesting', 0.038, 'pocket', 'purse', 'coin_purse', 'bank_vault', 'bank_account']
senticnet['walleye'] = [-0.898, 0, 0.709, -0.641, '#sad', '#angry', -0.749, 'divergent_strabismus', 'exotropia', 'squint', 'abnormality', 'abnormalcy']
senticnet['wallop'] = [-0.854, 0, 0.758, -0.889, '#sad', '#disgusting', -0.834, 'effect', 'issue', 'consequence', 'outcome', 'result']
senticnet['wallow'] = [0.704, 0.623, -0.23, 0.321, '#joyful', '#interesting', 0.473, 'jubilant', 'exuberant', 'jubilate', 'exult', 'carefreeness']
senticnet['wally'] = [-0.73, 0, 0.601, -0.998, '#sad', '#disgusting', -0.776, 'sap', 'fool', 'saphead', 'muggins', 'tomfool']
senticnet['walrus'] = [0, 0, -0.071, 0, '#scared', '#scared', -0.024, 'seal', 'otter', 'mussel', 'alligator', 'whale']
senticnet['waltz'] = [0.702, 0, 0, 0.703, '#joyful', '#admirable', 0.468, 'swirl', 'relate_music', 'dance', 'dance_step', 'dance_move']
senticnet['wand'] = [0.105, -0.178, 0.057, 0.079, '#joyful', '#surprising', 0.102, 'cue', 'twig', 'long_stick', 'stick', 'adhere']
senticnet['wander'] = [-0.61, 0, 0.538, -0.677, '#sad', '#disgusting', -0.608, 'gad', 'move', 'gallivant', 'jazz_around', 'travel']
senticnet['wander_around'] = [0.047, -0.012, 0.033, 0.071, '#joyful', '#admirable', 0.032, 'get_place', 'get_somewhere', 'get_around_town', 'go_to_place', 'go_some_place']
senticnet['wanderlust'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'globe_trotter', 'travel', 'visit_new_place', 'explore', 'discover']
senticnet['wangle'] = [-0.891, 0, 0.783, -0.898, '#sad', '#disgusting', -0.857, 'dodge', 'plant', 'scheme', 'strategy', 'wangling']
senticnet['wangler'] = [-0.571, 0, 0.839, -0.87, '#angry', '#disgusting', -0.76, 'beguiler', 'slicker', 'deceiver', 'cheat', 'cheater']
senticnet['wangling'] = [-0.891, 0, 0.783, -0.898, '#sad', '#disgusting', -0.857, 'wangle', 'plant', 'scheme', 'strategy', 'dodge']
senticnet['wank'] = [-0.056, 0, -0.068, -0.042, '#sad', '#scared', -0.055, 'masturbate', 'jerk', 'jerk_off', 'die_only_once', 'fight_other']
senticnet['wanness'] = [-0.665, 0, 0.782, -0.529, '#sad', '#angry', -0.659, 'lividness', 'pallidness', 'pallor', 'complexion', 'achromasia']
senticnet['want'] = [0.753, 0, 0, 0.712, '#joyful', '#admirable', 0.488, 'need', 'requisite', 'must', 'desideratum', 'help']
senticnet['want_badly'] = [0, 0.899, 0, 0.976, '#interesting', '#admirable', 0.625, 'holy_matrimony', 'good_etiquette', 'behavior', 'niceness', 'good_behavior']
senticnet['want_buy'] = [-0.134, 0, 0, -0.035, '#sad', '#disgusting', -0.056, 'ask_a_lot_of_question', 'determine_need', 'search_item', 'discuss_friend', 'come_warranty']
senticnet['want_degree'] = [-0.06, 0, -0.061, 0, '#sad', '#scared', -0.04, 'prove_learn', 'get_qualification', 'want_pass_class', 'prove_knowledge', 'complete_course']
senticnet['want_drink'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'place_order', 'order_hamburger', 'use_restroom', 'order_meal', 'order_menu']
senticnet['want_eat'] = [-0.037, -0.007, 0.04, -0.038, '#angry', '#disgusting', -0.036, 'eat_rice', 'eat_food_off', 'munch', 'eat', 'full_stomach']
senticnet['want_entertain'] = [0.993, 0.727, 0, 0, '#joyful', '#interesting', 0.573, 'like_movie', 'enjoy_movie', 'watch_show', 'mindless_entertainment', 'go_date']
senticnet['want_everything'] = [-0.884, 0.175, -0.599, 0, '#sad', '#scared', -0.436, 'eagerness', 'eagerly', 'avidity', 'thirstily', 'avidness']
senticnet['want_exercise'] = [0, 0.08, 0, 0.117, '#interesting', '#admirable', 0.066, 'exercise', 'healthy_exercise', 'good_environment', 'make_strong', 'aerobic_exercise']
senticnet['want_join'] = [0.706, 0, 0, 0.869, '#joyful', '#admirable', 0.525, 'know_result', 'carpal_tunnel_syndrome', 'become_excited', 'informative', 'beauty_world']
senticnet['want_know'] = [0.975, 0.854, 0, 0, '#joyful', '#interesting', 0.61, 'see_far_away', 'see_star', 'take_beach', 'learn_history', 'learn_past']
senticnet['want_learn'] = [-0.097, -0.011, 0.051, -0.177, '#sad', '#disgusting', -0.105, 'knowledge_subject', 'choose_subject', 'review_material', 'better_grade', 'review_note']
senticnet['want_learn_new'] = [0.937, 0.865, 0, 0, '#joyful', '#interesting', 0.601, 'become_scientist', 'become_intelligent', 'learn_new', 'enroll_class', 'add_knowledge']
senticnet['want_marry'] = [0, 0.925, 0, 0.878, '#interesting', '#admirable', 0.601, 'buy_condom', 'drive_home', 'buy_flower', 'wear_protection', 'love_back']
senticnet['want_money'] = [-0.061, 0, 0, -0.072, '#sad', '#disgusting', -0.044, 'need_earn_money', 'earn_money', 'support_family', 'desire_money', 'make_money']
senticnet['want_pass_class'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'prove_learn', 'get_qualification', 'become_engineer', 'prove_knowledge', 'complete_course']
senticnet['want_sleep'] = [0.054, -0.04, 0, 0, '#joyful', '#surprising', 0.031, 'go_sleep', 'sleep_night', 'go_bed', 'sleep', 'sleep_sometimes']
senticnet['want_to_win'] = [0.827, 0.913, 0, 0.867, '#interesting', '#admirable', 0.869, 'good_habit', 'improve_oneself', 'competitive', 'fighting_spirit', 'competitive_nature']
senticnet['want_understand'] = [-0.094, 0, 0, -0.047, '#sad', '#disgusting', -0.047, 'discuss_friend', 'solution_to_problem', 'say_eureka', 'trivia', 'come_conclusion']
senticnet['wanting'] = [-0.587, 0, 0.996, -0.848, '#angry', '#disgusting', -0.81, 'undermanned', 'understaffed', 'deficient', 'lacking', 'inadequate']
senticnet['wantonness'] = [-0.693, 0, 0.89, -0.988, '#angry', '#disgusting', -0.857, 'evil', 'wrongness', 'putrefaction', 'immorality', 'corruptibility']
senticnet['war'] = [-0.054, 0, -0.115, -0.198, '#scared', '#disgusting', -0.122, 'arsenal', 'gun_store', 'battle', 'big_fight', 'combat']
senticnet['war_advocacy'] = [0.729, -0.561, 0, 0.785, '#joyful', '#admirable', 0.692, 'ideology', 'militarism', 'warmongering', 'hawkishness', 'political_orientation']
senticnet['war_crime'] = [-0.944, 0, 0.904, -0.944, '#sad', '#disgusting', -0.931, 'war', 'battle', 'fight', 'crime', 'fight_war']
senticnet['war_machine'] = [-0.596, 0, 0.665, -0.522, '#sad', '#angry', -0.594, 'military', 'armed_forces', 'armed_services', 'military_machine', 'military_reserve']
senticnet['war_memorial'] = [0.072, 0.126, 0, 0, '#joyful', '#interesting', 0.066, 'subway_station', 'memorial', 'utopia', 'mortuary', 'hero']
senticnet['war_museum'] = [-0.033, 0, -0.1, -0.19, '#scared', '#disgusting', -0.108, 'underworld', 'battlefield', 'prisoner_war_camp', 'shoot_range', 'war_zone']
senticnet['war_paint'] = [-0.979, 0, 0.51, -0.892, '#sad', '#disgusting', -0.794, 'wear', 'raiment', 'wearable', 'clothing', 'article_of_clothing']
senticnet['war_zone'] = [-0.036, 0, -0.08, -0.202, '#scared', '#disgusting', -0.106, 'gun_shop', 'arsenal', 'holster', 'armory', 'gun_store']
senticnet['ware'] = [0, 0.179, -0.054, 0.214, '#interesting', '#admirable', 0.113, 'product', 'goods', 'store_item', 'grocery', 'groceries']
senticnet['warehouse'] = [0, 0.07, 0, 0.067, '#interesting', '#admirable', 0.046, 'car_trunk', 'walmart', 'recycle_bin', 'store', 'storage_place']
senticnet['warfare'] = [-0.052, 0, -0.079, -0.179, '#scared', '#disgusting', -0.103, 'violence', 'combat', 'conflict', 'big_fight', 'join_military']
senticnet['warm'] = [0.218, 0.285, -0.145, 0.123, '#joyful', '#interesting', 0.16, 'warmth', 'hot', 'keep_warm_winter', 'really_hot', 'hot_weather']
senticnet['warm-blooded'] = [0.076, -0.024, 0, 0.115, '#joyful', '#admirable', 0.072, 'hairy', 'diverse', 'social_animal', 'animal_type', 'mammary_gland']
senticnet['warm_air'] = [0.039, 0, 0, 0.052, '#joyful', '#admirable', 0.03, 'hot_air', 'liquid_gas', 'type_of_engine', 'fire_hazard', 'fire_starter']
senticnet['warm_bed'] = [0.149, 0, 0, 0.153, '#joyful', '#admirable', 0.101, 'alleyway', 'comfortable_chair', 'home', 'animal_shelter', 'veterinarian_office']
senticnet['warm_blood'] = [0.059, 0, 0.042, 0.055, '#joyful', '#admirable', 0.024, 'mammary_gland', 'hairy', 'hairy_animal', 'nipple', 'woodland_creature']
senticnet['warm_clothes'] = [0, -0.062, 0.082, -0.067, '#angry', '#disgusting', -0.029, 'fabric_shop', 'sweater', 'garment', 'clothes', 'winter_clothes']
senticnet['warm_color'] = [-0.04, 0, 0.059, -0.033, '#sad', '#angry', -0.044, 'secondary_color', 'color', 'color_rainbow', 'happiness', 'primary_color']
senticnet['warm_down'] = [0.135, 0.073, 0, 0, '#joyful', '#interesting', 0.069, 'rest_relaxation', 'sex_with_stranger', 'go_bed', 'go_sleep', 'stay_overnight']
senticnet['warm_feeling'] = [0, 0.702, 0, 0.738, '#interesting', '#admirable', 0.48, 'show_love', 'love_another_person', 'lust', 'feel_love', 'demand']
senticnet['warm_food'] = [0.822, 0.86, 0, 0.751, '#joyful', '#interesting', 0.811, 'get_ready', 'quick_movement', 'speedy', 'quickly', 'fry_egg']
senticnet['warm_foot'] = [0, 0.861, 0, 0.896, '#interesting', '#admirable', 0.586, 'foot', 'winter_boot', 'footwear', 'winter_sock', 'warm']
senticnet['warm_fuzzy_feeling'] = [0.878, 0.772, 0, 0, '#joyful', '#interesting', 0.55, 'love_back', 'sexual_intercourse', 'find_mate', 'show_empathy', 'arousal']
senticnet['warm_hand'] = [-0.091, -0.017, -0.073, -0.102, '#sad', '#disgusting', -0.083, 'explode', 'even_odds', 'die_out', 'burn_house', 'dry_wet_clothes']
senticnet['warm_home'] = [0.24, 0.065, -0.054, 0.133, '#joyful', '#admirable', 0.128, 'light_dark', 'heat_home', 'heat_house', 'burn_house', 'produce_heat']
senticnet['warm_house'] = [0.608, 0.647, -0.266, 0.325, '#joyful', '#interesting', 0.438, 'heat_home', 'heat_house', 'produce_heat', 'warm_room', 'light_dark']
senticnet['warm_place'] = [0.608, 0.647, -0.266, 0.325, '#joyful', '#interesting', 0.438, 'warm_house', 'produce_heat', 'heat_house', 'warm_room', 'heat_home']
senticnet['warm_room'] = [0.608, 0.647, -0.266, 0.325, '#joyful', '#interesting', 0.438, 'heat_house', 'warm_house', 'light_dark', 'produce_heat', 'heat_home']
senticnet['warm_to'] = [0.777, -0.852, 0, 0.615, '#joyful', '#surprising', 0.748, 'think_about', 'play', 'trifle', 'abstract', 'look_at']
senticnet['warm_up'] = [0.095, 0.204, -0.123, 0.174, '#interesting', '#admirable', 0.117, 'go_outdoors', 'sleep_tent', 'keep_dry', 'pitch_tent', 'careful']
senticnet['warm_weather'] = [0, 0.789, 0, 0, '#interesting', '#interesting', 0.263, 'hot_weather', 'hot', 'hotness', 'heat', 'high_temperature']
senticnet['warmer'] = [0.734, 0, 0, 0.936, '#joyful', '#admirable', 0.557, 'caring', 'benevolent', 'benign', 'fatherly', 'motherly']
senticnet['warmhearted'] = [0.551, 0.67, -0.279, 0.285, '#joyful', '#interesting', 0.409, 'caring', 'lovingness', 'warmheartedness', 'benevolently', 'benevolence']
senticnet['warmheartedness'] = [0.512, 0.674, -0.272, 0.269, '#joyful', '#interesting', 0.394, 'caring', 'lovingness', 'infatuation', 'calf_love', 'puppy_love']
senticnet['warmness'] = [0.461, 0.674, -0.262, 0.247, '#joyful', '#interesting', 0.373, 'affectionateness', 'philia', 'affectional', 'affective', 'emotive']
senticnet['warmonger'] = [-0.024, 0, -0.137, -0.076, '#scared', '#disgusting', -0.079, 'settle_disagreement', 'defeat_enemy', 'gain_territory', 'overpower', 'conquer_enemy']
senticnet['warmth'] = [0.296, 0.278, -0.145, 0.128, '#joyful', '#interesting', 0.186, 'warm', 'keep_warm', 'keep_warm_winter', 'create_warmth', 'heat_house']
senticnet['warn'] = [-0.225, 0.107, -0.258, 0.054, '#sad', '#scared', -0.107, 'caution', 'catalyst', 'unsafe', 'signal', 'problem']
senticnet['warn_sign'] = [-0.251, 0, -0.191, -0.041, '#sad', '#scared', -0.161, 'warm_color', 'secondary_color', 'color', 'primary_color', 'cool_color']
senticnet['warning'] = [-0.115, -0.016, 0, -0.081, '#sad', '#disgusting', -0.06, 'beep', 'primary_color', 'color_rainbow', 'color', 'light_red']
senticnet['warning_coloration'] = [0.62, -0.598, 0, 0.967, '#joyful', '#admirable', 0.728, 'aposematic_coloration', 'protective_coloration', 'apatetic_coloration', 'cryptic_coloration', 'coloration']
senticnet['warp'] = [-0.859, 0, 0.936, -0.807, '#sad', '#angry', -0.867, 'abnormalcy', 'abnormality', 'deflection', 'aberrance', 'chromosomal_aberration']
senticnet['warpath'] = [0.02, 0.131, 0.749, -0.672, '#angry', '#disgusting', -0.423, 'belligerence', 'belligerency', 'belligerent', 'war', 'rancor']
senticnet['warped'] = [0, 0, -0.949, -0.865, '#scared', '#disgusting', -0.605, 'heave', 'falsify', 'buckle', 'distort', 'garble']
senticnet['warping'] = [-0.977, 0, 0.521, -0.913, '#sad', '#disgusting', -0.804, 'warp', 'harm', 'impairment', 'damage', 'deformation']
senticnet['warrior'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'soldier', 'samurai', 'army', 'fighter', 'infantry']
senticnet['wart'] = [-0.078, 0, 0, -0.058, '#sad', '#disgusting', -0.045, 'sharp_tooth', 'pointy_ear', 'tail', 'big_tooth', 'fang']
senticnet['wary'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'alert', 'watchful', 'guard', 'vigilant', 'on_alert']
senticnet['wash'] = [-0.604, 0, 0.992, -0.948, '#angry', '#disgusting', -0.848, 'cleanse', 'lather', 'floss', 'decontaminate', 'bathe']
senticnet['wash_away_dirt'] = [0.075, -0.004, 0, 0.076, '#joyful', '#admirable', 0.052, 'cleanliness', 'become_wet', 'run_out_soap', 'dry_skin', 'clean_skin']
senticnet['wash_behind_ear'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'remove_dirt', 'clean_hand', 'cleanse_body', 'clean_skin', 'cleaner']
senticnet['wash_body'] = [0.785, 0, 0, 0.841, '#joyful', '#admirable', 0.542, 'clean_oneself', 'wash_up', 'wash_oneself', 'clean_dish', 'clean_self']
senticnet['wash_clothes'] = [0, 0.716, 0, 0.741, '#interesting', '#admirable', 0.486, 'clean_clothes', 'get_clean', 'take_shower', 'clean_body', 'become_clean']
senticnet['wash_dish'] = [0.786, 0, 0, 0, '#joyful', '#joyful', 0.262, 'wash_dog', 'eat_dessert', 'clean_object', 'camp_out', 'mop_floor']
senticnet['wash_dog'] = [0.813, 0, 0, 0, '#joyful', '#joyful', 0.271, 'wash_body', 'clean_object', 'lather', 'use_washcloth', 'clean_oneself']
senticnet['wash_first'] = [-0.045, -0.011, 0.04, -0.029, '#sad', '#angry', -0.034, 'take_bite', 'use_tooth', 'buy_market', 'chew', 'put_napkin_lap']
senticnet['wash_hair'] = [0.855, 0.849, 0, 0.767, '#joyful', '#interesting', 0.824, 'keep_clothes_clean', 'smell_good', 'smell_nice', 'well_dress', 'smell_clean']
senticnet['wash_hand'] = [0.053, 0.078, 0, 0, '#joyful', '#interesting', 0.044, 'wash_clothes', 'wash_oneself', 'clean_clothes', 'get_clean', 'cologne']
senticnet['wash_mouth_soap'] = [0.029, 0, -0.093, -0.123, '#scared', '#disgusting', -0.062, 'cigarette_smoke', 'smoke_pipe', 'cigarette', 'smoke', 'cigar']
senticnet['wash_oneself'] = [0.785, 0, 0, 0.841, '#joyful', '#admirable', 0.542, 'clean_oneself', 'wash_up', 'clean_dish', 'wash_body', 'clean_self']
senticnet['wash_out'] = [0.847, -0.808, 0, 0.711, '#joyful', '#surprising', 0.789, 'mollify', 'enervate', 'stultify', 'weaken', 'cripple']
senticnet['wash_person'] = [0.095, -0.043, 0.04, 0, '#joyful', '#surprising', 0.033, 'cleanse_body', 'feel_clean', 'smell_clean', 'moisturize_skin', 'feel_fresh']
senticnet['wash_self'] = [0.94, 0, 0, 0.768, '#joyful', '#admirable', 0.569, 'clean_agent', 'foam', 'lather', 'bubbly', 'cleanser']
senticnet['wash_tooth'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'smart_technology', 'electric_shaver', 'hair_dryer', 'stay_healthy', 'electric_toothbrush']
senticnet['wash_up'] = [0.785, 0, 0, 0.841, '#joyful', '#admirable', 0.542, 'clean_oneself', 'clean_dish', 'wash_oneself', 'wash_body', 'clean_self']
senticnet['wash_window'] = [0, 0, 0, -0.97, '#disgusting', '#disgusting', -0.323, 'sit_on_beach', 'pet_cat', 'absorb_moisture', 'mow_grass', 'clean_sink']
senticnet['washcloth'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'faucet_overflow', 'hot_faucet', 'hot_tap', 'faucet', 'dirty_dish']
senticnet['washing_machine'] = [0.041, 0.086, 0.016, 0, '#joyful', '#interesting', 0.037, 'sort_clothes', 'laundry', 'clean_clothes', 'dirty_clothes', 'basket_laundry']
senticnet['washy'] = [-0.952, 0, 0.669, -0.978, '#sad', '#disgusting', -0.866, 'weakened', 'weak', 'white', 'diluted', 'cut']
senticnet['wasp'] = [0.867, 0.911, 0, 0, '#joyful', '#interesting', 0.593, 'butterfly', 'moth', 'parrot', 'beetle', 'falcon']
senticnet['waste'] = [0.778, 0.916, 0, 0, '#joyful', '#interesting', 0.565, 'refuse', 'hold_trash', 'put_trash', 'store_trash', 'put_garbage']
senticnet['waste_bin'] = [-0.043, 0, 0.041, -0.045, '#sad', '#disgusting', -0.043, 'back_sofa', 'home_improvement_store', 'closet', 'under_carpet', 'shoe_shop']
senticnet['waste_food'] = [-0.981, 0, 0.458, -0.947, '#sad', '#disgusting', -0.795, 'fire', 'ruined_meal', 'ruined_dinner', 'ruined_lunch', 'burn_food']
senticnet['waste_life'] = [-0.31, -0.093, 0, -0.322, '#sad', '#disgusting', -0.18, 'broken_window', 'varicose_vein', 'step_dog_shit', 'flab', 'back_pain']
senticnet['waste_material'] = [0.526, -0.78, 0, 0.869, '#surprising', '#admirable', 0.725, 'impurity', 'dross', 'exhaust', 'garbage', 'material']
senticnet['waste_matter'] = [0.555, -0.667, 0, 0.758, '#surprising', '#admirable', 0.66, 'impurity', 'dross', 'exhaust', 'garbage', 'material']
senticnet['waste_money'] = [-0.727, 0, 0.826, -0.833, '#angry', '#disgusting', -0.795, 'lose_control', 'step_dog_poop', 'relax_friend', 'become_intoxicated', 'bee_sting']
senticnet['waste_of_time'] = [-0.973, 0, 0.009, -0.929, '#sad', '#disgusting', -0.637, 'without_end_product', 'come_to_nothing', 'failure', 'unsuccessful', 'no_result']
senticnet['waste_paper'] = [-0.952, 0, 0, -0.73, '#sad', '#disgusting', -0.561, 'hold_pencil', 'food_scrap', 'paper_product', 'wrapper', 'tin_can']
senticnet['waste_product'] = [0.64, -0.861, 0, 0.778, '#surprising', '#admirable', 0.76, 'impurity', 'dross', 'exhaust', 'garbage', 'material']
senticnet['waste_time'] = [0.999, 0.994, 0, 0, '#joyful', '#interesting', 0.664, 'pastime', 'escape_reality', 'entertainment_learn', 'stimulate_mind', 'kill_time']
senticnet['waste_water'] = [0.092, -0.197, 0.053, 0.089, '#joyful', '#surprising', 0.108, 'hairball', 'clog', 'false_tooth', 'still_water', 'go_lake']
senticnet['wastebasket'] = [0, -0.038, 0.054, -0.143, '#angry', '#disgusting', -0.053, 'trash', 'garbage_can', 'dustbin', 'inbox', 'trash_bin']
senticnet['waster'] = [-0.583, 0, 0.714, -0.612, '#angry', '#disgusting', -0.636, 'diversionist', 'sleeper', 'destroyer', 'ruiner', 'undoer']
senticnet['wasteyard'] = [-0.707, 0, 0.611, -0.695, '#sad', '#disgusting', -0.671, 'dump', 'garbage_dump', 'trash_dump', 'rubbish_dump', 'garbage_heap']
senticnet['wasting'] = [-0.937, 0, 0, -0.833, '#sad', '#disgusting', -0.59, 'infirmity', 'frailty', 'debility', 'frailness', 'valetudinarianism']
senticnet['wasting_away'] = [-0.869, 0, 0.738, -0.93, '#sad', '#disgusting', -0.846, 'amyotrophia', 'amyotrophy', 'tabes', 'kraurosis', 'symptom']
senticnet['watch'] = [0.788, 0.873, 0, 0, '#joyful', '#interesting', 0.554, 'watch_cartoon', 'watch_baseball_game', 'watch_comedy', 'watch_good_movie', 'watch_show']
senticnet['watch_advertisement'] = [-0.067, 0, 0.01, -0.079, '#sad', '#disgusting', -0.052, 'commercial', 'advertisement', 'watch_tv', 'watch_commercial', 'interruption_movie']
senticnet['watch_animal_documentary'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'read_book', 'explore_nature', 'study', 'read_science_book', 'study_animal']
senticnet['watch_art'] = [0.701, 0.786, 0, 0.594, '#joyful', '#interesting', 0.694, 'expand_mind', 'learn', 'gain_knowledge', 'take_up_time', 'gather_information']
senticnet['watch_baseball'] = [0.742, 0.78, 0, 0, '#joyful', '#interesting', 0.507, 'recreation', 'competition', 'funny_friend', 'fun', 'win_money']
senticnet['watch_baseball_game'] = [0.788, 0.873, 0, 0, '#joyful', '#interesting', 0.554, 'enjoy_challenge', 'skate_ice', 'win_money', 'victorious', 'watch_game']
senticnet['watch_bird'] = [-0.104, 0, -0.051, -0.046, '#sad', '#scared', -0.067, 'cut_grass', 'field_ball', 'like_play_game', 'laugh_clown', 'battle_illness']
senticnet['watch_carefully'] = [-0.09, 0, 0, 0, '#sad', '#sad', -0.03, 'look_carefully', 'watch_out', 'observe', 'look', 'stare']
senticnet['watch_cartoon'] = [0.784, 0.902, 0, 0, '#joyful', '#interesting', 0.562, 'watch', 'cartoon', 'watch_tv', 'entertainment', 'childhood']
senticnet['watch_clock'] = [-0.072, 0, 0, -0.034, '#sad', '#disgusting', -0.035, 'time_runner', 'escape_prison', 'measure_passage_time', 'measure_time', 'minute_second']
senticnet['watch_comedy'] = [0.784, 0.902, 0, 0, '#joyful', '#interesting', 0.562, 'big_home', 'find_interest', 'web_surf', 'family_activity', 'anarchy']
senticnet['watch_commercial'] = [-0.067, 0, 0.01, -0.079, '#sad', '#disgusting', -0.052, 'commercial', 'advertisement', 'watch_tv', 'watch_advertisement', 'interruption_movie']
senticnet['watch_concert'] = [0.784, 0.902, 0, 0, '#joyful', '#interesting', 0.562, 'watch', 'concert', 'watch_comedy', 'watch_show', 'watch_entertainment']
senticnet['watch_credit'] = [-0.067, 0, 0.01, -0.079, '#sad', '#disgusting', -0.052, 'read_credit', 'turn_off', 'scratch_itch', 'leave_theater', 'look_out_window']
senticnet['watch_crystal'] = [-0.587, 0, 0.992, -0.874, '#angry', '#disgusting', -0.818, 'mask', 'blind', 'protective_cover', 'cladding', 'thumbstall']
senticnet['watch_d'] = [-0.161, 0, -0.091, -0.037, '#sad', '#scared', -0.096, 'throw_fit', 'act_up', 'battle_illness', 'sun_oneself', 'honor_parent']
senticnet['watch_entertainment'] = [0.784, 0.902, 0, 0, '#joyful', '#interesting', 0.562, 'watch', 'entertainment', 'watch_concert', 'watch_show', 'watch_good_movie']
senticnet['watch_film'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'see_favorite_show', 'enjoy_film', 'watch_movie', 'see_movie', 'take_film']
senticnet['watch_football'] = [0.978, 0.99, 0, 0, '#joyful', '#interesting', 0.656, 'watch_television', 'listen_radio', 'watch_tv', 'view_video', 'watch_movie']
senticnet['watch_game'] = [0.784, 0.902, 0, 0, '#joyful', '#interesting', 0.562, 'watch_sport', 'watch_football', 'watch_baseball_game', 'watch_hockey_game', 'watch_tv']
senticnet['watch_good_movie'] = [0.169, 0.134, 0, 0.136, '#joyful', '#admirable', 0.146, 'rend_video', 'near_tv', 'turn_on_tv', 'go_cinema', 'able_see']
senticnet['watch_hockey_game'] = [0.749, 0.897, 0, 0, '#joyful', '#interesting', 0.549, 'eat_popcorn', 'entertain', 'kill_brain_cell', 'watch_game', 'enjoy_show']
senticnet['watch_movie'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'watch_news', 'record_movie', 'show_movie', 'enter_theater', 'see_film']
senticnet['watch_movie_together'] = [0.583, 0.585, 0, 0.766, '#interesting', '#admirable', 0.645, 'watch_show', 'mindless_entertainment', 'watch_news', 'enjoy_movie', 'idolize_actor']
senticnet['watch_much_tv'] = [-0.185, 0.111, -0.14, -0.094, '#sad', '#scared', -0.103, 'bigot', 'fail_exam', 'censorship', 'intolerance', 'fail_class']
senticnet['watch_musician_perform'] = [0, 0, 0, -0.072, '#disgusting', '#disgusting', -0.024, 'go_movie', 'attend_opus', 'go_concert', 'go_opus', 'turn_stereo']
senticnet['watch_news'] = [0.8, 0.737, 0, 0, '#joyful', '#interesting', 0.512, 'watch_show', 'watch_movie', 'record_movie', 'like_movie', 'zone_out']
senticnet['watch_other_person'] = [0, 0.76, 0, 0, '#interesting', '#interesting', 0.253, 'act_bored', 'become_impatient', 'get_front', 'think_dog', 'check_time']
senticnet['watch_others'] = [0.925, 0.749, 0, 0, '#joyful', '#interesting', 0.558, 'meditate', 'listen_sermon', 'conserve_energy', 'fall_asleep', 'work_pile_up']
senticnet['watch_out'] = [0.509, -0.93, 0, 0.75, '#surprising', '#admirable', 0.73, 'beware', 'look_after', 'keep_one_eyes_peeled', 'keep_one_eyes_skinned', 'keep_one_eyes_open']
senticnet['watch_over'] = [0, 0.916, 0, 0.881, '#interesting', '#admirable', 0.599, 'take_care', 'defend', 'look_after', 'type_of_bear', 'precaution']
senticnet['watch_parade'] = [0.837, 0, 0, 0.714, '#joyful', '#admirable', 0.517, 'enjoy_music', 'clear_mind_bad_thought', 'listen_pleasure', 'hear_live_music', 'get_entertain']
senticnet['watch_performance'] = [0.172, 0.236, -0.135, 0.287, '#interesting', '#admirable', 0.187, 'watch_play', 'sell_ticket', 'sit_at_theater', 'attend_concert', 'popcorn']
senticnet['watch_person'] = [-0.067, 0, 0.023, -0.137, '#sad', '#disgusting', -0.076, 'use_atm', 'impulse_shop', 'window_shop', 'walk_exercise', 'hang_out']
senticnet['watch_play'] = [0.712, 0, 0, 0.764, '#joyful', '#admirable', 0.492, 'sit_at_theater', 'opera', 'popcorn', 'watch_show', 'watch_entertainment']
senticnet['watch_porn'] = [0.983, 0, 0, 0, '#joyful', '#joyful', 0.328, 'sex', 'eat_pussy', 'spray_paint_grafitti', 'masturbation', 'beat_off']
senticnet['watch_sad_film'] = [-0.059, 0, -0.071, 0, '#sad', '#scared', -0.043, 'cry', 'sad_movie', 'chop_onion', 'see_sad_show', 'see_sad_movie']
senticnet['watch_show'] = [0.567, 0.855, 0, 0.894, '#interesting', '#admirable', 0.772, 'watch_news', 'zone_out', 'mindless_entertainment', 'like_movie', 'learn_news']
senticnet['watch_sport'] = [0.567, 0.855, 0, 0.894, '#interesting', '#admirable', 0.772, 'watch_game', 'watch_football', 'watch_baseball_game', 'watch_hockey_game', 'watch_tv']
senticnet['watch_sunset'] = [0.803, 0.745, 0, 0, '#joyful', '#interesting', 0.516, 'enjoy_sex', 'dance_music', 'need_companionship', 'eat_together', 'relax']
senticnet['watch_television'] = [0, 0.848, 0, 0.746, '#interesting', '#admirable', 0.531, 'record_film', 'proof_of_purchase', 'store_film', 'use_television', 'view_video']
senticnet['watch_television_show'] = [-0.047, 0.082, 0, 0.066, '#interesting', '#admirable', 0.034, 'record_television_show', 'turn_on_dvd_player', 'view_film_home', 'view_video', 'tape_television_show']
senticnet['watch_tv'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'buy_tv', 'buy_happiness', 'buy', 'turn_on_tv', 'buy_camera']
senticnet['watch_tv_show'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'view_video', 'view_film_home', 'watch_film', 'take_film', 'watch_movie']
senticnet['watcher'] = [0, 0.081, 0, 0, '#interesting', '#interesting', 0.027, 'favorite', 'guard', 'crowd', 'several_people', 'clique']
senticnet['watchful'] = [0.805, -0.671, 0, 0.901, '#joyful', '#admirable', 0.792, 'vigilant', 'wakeful', 'lidless', 'fly', 'sleepless']
senticnet['water'] = [-0.182, -0.078, 0, -0.203, '#sad', '#disgusting', -0.102, 'bad_drug_spill', 'bad_drug', 'atmosphere', 'cool_bad_drug', 'obtain_bad_drug']
senticnet['water_action'] = [0, 0.082, 0, 0.214, '#interesting', '#admirable', 0.099, 'water_motion', 'water_movement', 'arm_movement', 'water_relate', 'running_water']
senticnet['water_activity'] = [0, 0.815, 0, 0.766, '#interesting', '#admirable', 0.527, 'water_transport', 'travel_over_water', 'backstroke', 'water_sport', 'propulsion']
senticnet['water_air'] = [0.038, 0, 0.01, 0.059, '#joyful', '#admirable', 0.029, 'humid', 'water_molecule', 'water_vapor', 'water', 'water_mass']
senticnet['water_area'] = [-0.052, 0.077, 0, 0.112, '#interesting', '#admirable', 0.046, 'big_lake', 'water_feature', 'water_body', 'small_stream', 'water_beach']
senticnet['water_beach'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'aquarium', 'seashore', 'ocean_water', 'chowder', 'pacific']
senticnet['water_bird'] = [-0.03, -0.029, 0.027, -0.109, '#sad', '#disgusting', -0.046, 'crow', 'dove', 'bird_type', 'bird_prey', 'raven']
senticnet['water_biscuit'] = [-0.955, 0, 0.762, -0.648, '#sad', '#angry', -0.788, 'saltine', 'soda_cracker', 'oyster_cracker', 'cracker', 'graham_cracker']
senticnet['water_blister'] = [-0.784, 0, 0.855, -0.996, '#angry', '#disgusting', -0.878, 'blood_blister', 'pustule', 'bleb', 'vesicle', 'cyst']
senticnet['water_body'] = [0.057, 0.118, -0.049, 0.151, '#interesting', '#admirable', 0.092, 'small_river', 'panama', 'water_feature', 'fresh_water', 'large_body']
senticnet['water_bottle'] = [0, -0.026, 0.027, -0.092, '#angry', '#disgusting', -0.031, 'shoulder_bag', 'satchel', 'satchel_bag', 'tote_bag', 'vanity_case']
senticnet['water_bubble'] = [-0.222, -0.039, 0.026, -0.137, '#sad', '#disgusting', -0.115, 'burn_toast', 'bad_eyesight', 'blemish', 'dig_tunnel', 'vermin']
senticnet['water_bug'] = [-0.773, 0, 0.576, -0.922, '#sad', '#disgusting', -0.757, 'insect', 'firebug', 'heteropterous_insect', 'assassin_bug', 'reduviid']
senticnet['water_caltrop'] = [0.83, -0.802, 0, 0.969, '#joyful', '#admirable', 0.867, 'water_chestnut', 'ling', 'ling_ko', 'aquatic_plant', 'water_plant']
senticnet['water_carpet'] = [-0.839, 0, 0.768, -0.697, '#sad', '#angry', -0.768, 'golden_saxifrage', 'water_mat', 'aquatic_plant', 'water_plant', 'hydrophyte']
senticnet['water_chestnut'] = [0.83, -0.802, 0, 0.969, '#joyful', '#admirable', 0.867, 'water_caltrop', 'ling', 'ling_ko', 'aquatic_plant', 'water_plant']
senticnet['water_color'] = [0.833, 0.927, 0, 0, '#joyful', '#interesting', 0.587, 'no_color', 'transparency', 'sunny_weather', 'intelligent', 'clarity']
senticnet['water_container'] = [0.718, 0, 0, 0, '#joyful', '#joyful', 0.239, 'clean_water', 'still_water', 'dampness', 'water', 'cool_water']
senticnet['water_crop'] = [-0.055, 0.094, 0, 0.058, '#interesting', '#admirable', 0.032, 'farm_vegetable', 'cultivation', 'plant_field', 'grow_stuff', 'agricultural']
senticnet['water_drip'] = [-0.069, 0, 0.043, 0, '#sad', '#angry', -0.037, 'downward', 'angle', 'incline_plane', 'decline', 'mountain_side']
senticnet['water_drop'] = [0.962, 0.838, 0, 0, '#joyful', '#interesting', 0.6, 'sky', 'come_down', 'water_fall', 'cloud_sky', 'cloud_skylet']
senticnet['water_droplet'] = [0.792, 0.905, 0, 0, '#joyful', '#interesting', 0.566, 'sky', 'come_down', 'water_fall', 'water_drop', 'cloud_sky']
senticnet['water_dropwort'] = [-0.799, 0, 0.906, -0.671, '#sad', '#angry', -0.792, 'poisonous_plant', 'hemlock_poisonous_plant', 'water_hemlock', 'plant_life', 'poison_sumac']
senticnet['water_ear'] = [0.801, 0.897, 0, 0, '#joyful', '#interesting', 0.566, 'drown', 'get_wet', 'become_relaxed', 'wet_clothes', 'wrinkled_skin']
senticnet['water_eye'] = [-0.227, -0.011, -0.133, -0.075, '#sad', '#scared', -0.141, 'shed_tear', 'eye_tear', 'weep', 'bawl', 'sob']
senticnet['water_fall'] = [0.957, 0.934, 0, 0, '#joyful', '#interesting', 0.63, 'sky', 'come_down', 'cloud_sky', 'water_drop', 'water_droplet']
senticnet['water_faucet'] = [0.06, -0.029, 0, 0.051, '#joyful', '#admirable', 0.047, 'knock', 'pour_water', 'dance_well', 'scuba_gear', 'go_water']
senticnet['water_feature'] = [-0.031, 0.072, 0, 0.113, '#interesting', '#admirable', 0.051, 'water_body', 'water_area', 'small_stream', 'big_lake', 'water_mass']
senticnet['water_float'] = [-0.026, -0.013, 0.069, -0.05, '#angry', '#disgusting', -0.044, 'harbor', 'water_body', 'water_transport', 'ship_boat', 'cabin']
senticnet['water_flow'] = [0, 0.792, 0, 0.719, '#interesting', '#admirable', 0.504, 'flowing_water', 'water_stream', 'water_movement', 'ebb', 'fast_water']
senticnet['water_flower'] = [0.067, 0.153, -0.054, 0.111, '#interesting', '#admirable', 0.092, 'small_flower', 'plant_yard', 'like_flower', 'plant_tree', 'garden_plant']
senticnet['water_form'] = [0, 0.067, 0, 0.218, '#interesting', '#admirable', 0.095, 'water_formation', 'water_relate', 'arm_movement', 'water_action', 'hand_gesture']
senticnet['water_formation'] = [0, 0.074, 0, 0.195, '#interesting', '#admirable', 0.09, 'water_form', 'water_relate', 'wind_water', 'small_stream', 'big_lake']
senticnet['water_fountain'] = [0.06, 0.067, 0, -0.054, '#joyful', '#interesting', 0.024, 'flea_market', 'winery', 'brewery', 'load_dock', 'wish_well']
senticnet['water_freeze'] = [0, 0, 0, -0.096, '#disgusting', '#disgusting', -0.032, 'stand_queue', 'go_post_office', 'wait_line', 'stand_in_line', 'get_line']
senticnet['water_garden'] = [-0.091, 0, 0, 0, '#sad', '#sad', -0.03, 'adjust_water_temperature', 'water_lawn', 'heater', 'shower', 'cook']
senticnet['water_gun'] = [0.979, 0.806, 0, 0, '#joyful', '#interesting', 0.595, 'baseball_bat', 'hockey_stick', 'goalie', 'hockey_puck', 'bullseye']
senticnet['water_hemlock'] = [-0.799, 0, 0.906, -0.671, '#sad', '#angry', -0.792, 'water_dropwort', 'hemlock_water_dropwort', 'poisonous_plant', 'plant_life', 'poison_sumac']
senticnet['water_hole'] = [0.113, 0, 0, 0.118, '#joyful', '#admirable', 0.077, 'place_to_drink', 'metal_stick', 'drinking_place', 'hangout', 'meet_place']
senticnet['water_hose'] = [-0.038, -0.051, 0.06, -0.058, '#angry', '#disgusting', -0.035, 'prevent_conception', 'tired', 'lose', 'increase_price', 'gyroscope']
senticnet['water_inside'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'water_spray', 'liquid_water', 'rise_water', 'humid', 'water_relate']
senticnet['water_lawn'] = [-0.091, 0, 0, 0, '#sad', '#sad', -0.03, 'water_garden', 'adjust_water_temperature', 'water_rose', 'remove_clothes', 'learn_how_swim']
senticnet['water_locust'] = [-0.856, 0, 0.5, -0.709, '#sad', '#disgusting', -0.688, 'courbaril', 'locust_tree', 'swamp_locust', 'honey_locust', 'black_locust']
senticnet['water_mammal'] = [0, -0.101, 0, 0, '#surprising', '#surprising', 0.034, 'mammal', 'type_of_animal', 'animal', 'sea_mammal', 'baby_deer']
senticnet['water_mass'] = [-0.056, 0.068, 0, 0.102, '#interesting', '#admirable', 0.038, 'small_ocean', 'much_water', 'water_molecule', 'water_body', 'water_feature']
senticnet['water_mat'] = [-0.839, 0, 0.768, -0.697, '#sad', '#angry', -0.768, 'water_carpet', 'golden_saxifrage', 'aquatic_plant', 'water_plant', 'hydrophyte']
senticnet['water_moccasin'] = [-0.514, 0, 0.625, -0.984, '#angry', '#disgusting', -0.708, 'common_water_snake', 'banded_water_snake', 'water_snake', 'grass_snake', 'ring_snake']
senticnet['water_molecule'] = [0.038, 0, 0.01, 0.059, '#joyful', '#admirable', 0.029, 'humid', 'water_air', 'water_vapor', 'water', 'water_mass']
senticnet['water_motion'] = [0, 0.072, -0.062, 0.222, '#interesting', '#admirable', 0.077, 'water_movement', 'sea_movement', 'flowing_water', 'move_liquid', 'ebb']
senticnet['water_movement'] = [0, 0, 0, 0.162, '#admirable', '#admirable', 0.054, 'sea_movement', 'ebb', 'water_motion', 'water_flow', 'fast_water']
senticnet['water_particle'] = [-0.046, 0.078, 0, 0.174, '#interesting', '#admirable', 0.069, 'high_up', 'block_sun', 'crystal_clear', 'sun_cover', 'up_high']
senticnet['water_passage'] = [0, 0.074, 0, 0.139, '#interesting', '#admirable', 0.071, 'waterway', 'small_stream', 'flowing_water', 'water_flow', 'water_stream']
senticnet['water_plant'] = [-0.839, 0, 0.768, -0.697, '#sad', '#angry', -0.768, 'water_carpet', 'water_mat', 'aquatic_plant', 'golden_saxifrage', 'hydrophyte']
senticnet['water_relate'] = [0.026, 0.072, 0, 0.204, '#interesting', '#admirable', 0.101, 'water_action', 'water_form', 'arm_movement', 'water_motion', 'water_formation']
senticnet['water_resistance'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'tiles', 'hair', 'design', 'bathroom_wall', 'algae']
senticnet['water_rose'] = [0.701, 0.989, 0, 0, '#joyful', '#interesting', 0.563, 'seed_lawn', 'date_man', 'name_child', 'wear_skirt', 'voice_concern']
senticnet['water_sea'] = [-0.036, -0.009, 0.024, -0.052, '#sad', '#disgusting', -0.034, 'under_water', 'underwater', 'bottom_sea', 'ocean', 'sea']
senticnet['water_sky'] = [-0.037, 0, 0.048, 0, '#sad', '#angry', -0.028, 'crystal_clear', 'sun_cover', 'water_droplet', 'water', 'wet_air']
senticnet['water_snake'] = [-0.514, 0, 0.625, -0.984, '#angry', '#disgusting', -0.708, 'common_water_snake', 'banded_water_snake', 'water_moccasin', 'grass_snake', 'ring_snake']
senticnet['water_soap'] = [0, 0.095, 0, 0.074, '#interesting', '#admirable', 0.056, 'laundry_detergent', 'buy_wash_powder', 'clothes_dirty', 'laundry', 'use_water']
senticnet['water_source'] = [0, 0.097, 0, 0.16, '#interesting', '#admirable', 0.086, 'water_mass', 'water_body', 'much_water', 'small_ocean', 'water_feature']
senticnet['water_spill'] = [-0.182, -0.078, 0, -0.203, '#sad', '#disgusting', -0.102, 'bad_drug', 'water', 'atmosphere', 'cool_water', 'obtain_water']
senticnet['water_splash'] = [0, 0, 0, 0.169, '#admirable', '#admirable', 0.056, 'arm_movement', 'ocean_movement', 'hand_gesture', 'sea_movement', 'goodbye']
senticnet['water_sport'] = [0, 0.902, 0, 0.891, '#interesting', '#admirable', 0.598, 'swim', 'water_activity', 'movement_of_water', 'backstroke', 'swiming_pool']
senticnet['water_spot'] = [0.101, 0, 0, 0, '#joyful', '#joyful', 0.034, 'get_cold', 'wet_clothes', 'wetness', 'become_cold', 'filthy']
senticnet['water_spray'] = [0.095, 0, -0.045, 0.062, '#joyful', '#admirable', 0.037, 'liquid_water', 'photographer', 'moisture', 'rise_water', 'droplet']
senticnet['water_stream'] = [0, 0.752, 0, 0.732, '#interesting', '#admirable', 0.495, 'water_flow', 'flowing_water', 'small_stream', 'nile', 'big_lake']
senticnet['water_transport'] = [0.034, 0, 0, 0.128, '#joyful', '#admirable', 0.054, 'water_movement', 'movement_of_water', 'water_motion', 'move_water', 'fast_water']
senticnet['water_transportation'] = [0.153, 0, 0, 0.149, '#joyful', '#admirable', 0.101, 'paddle', 'raft', 'canoe', 'water_vehicle', 'ship']
senticnet['water_vapor'] = [0, 0.073, -0.052, 0.093, '#interesting', '#admirable', 0.038, 'vapor', 'condense_water', 'evaporate', 'gaseous', 'bubble']
senticnet['water_vehicle'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'ship', 'big_boat', 'boat', 'large_boat', 'yacht']
senticnet['watercraft'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'ship', 'yacht', 'military_ship', 'boat', 'lifeboat']
senticnet['watercress'] = [0.758, -0.975, 0, 0.851, '#surprising', '#admirable', 0.861, 'marsh_cress', 'yellow_watercress', 'mountain_watercress', 'common_watercress', 'great_yellowcress']
senticnet['waterfall'] = [0, 0, 0.015, -0.08, '#angry', '#disgusting', -0.032, 'riverbed', 'bottom_ocean', 'surface_earth', 'pond', 'arctic']
senticnet['waterlessness'] = [-0.926, 0, 0.974, -0.956, '#angry', '#disgusting', -0.952, 'aridness', 'thirstiness', 'xerostomia', 'dry_mouth', 'sereness']
senticnet['waterlogged'] = [0, 0, -0.769, -0.784, '#scared', '#disgusting', -0.518, 'miry', 'marshy', 'mucky', 'muddy', 'boggy']
senticnet['waterproof'] = [-0.104, -0.032, 0.057, -0.052, '#sad', '#angry', -0.06, 'animal_skin', 'striped', 'animal_pelt', 'animal_fur', 'animal_hide']
senticnet['waterproof_boot'] = [0.106, 0.162, 0.037, 0.32, '#interesting', '#admirable', 0.184, 'block_sun', 'waterproof_jacket', 'umbrella', 'rain_equipment', 'block_rain']
senticnet['waterproof_jacket'] = [0.106, 0.162, 0.037, 0.32, '#interesting', '#admirable', 0.184, 'block_sun', 'umbrella', 'waterproof_boot', 'rain_equipment', 'block_rain']
senticnet['watertight'] = [-0.633, 0, 0.745, -0.527, '#sad', '#angry', -0.635, 'incontestable', 'incontrovertible', 'unanswerable', 'bulletproof', 'unassailable']
senticnet['waterway'] = [0, 0.987, 0, 0.748, '#interesting', '#admirable', 0.578, 'water_passage', 'small_stream', 'water_flow', 'flowing_water', 'water_stream']
senticnet['watery'] = [0, 0.997, 0, 0.973, '#interesting', '#admirable', 0.657, 'wetness', 'water_spray', 'rain_water', 'wet_cold', 'essential_human_life']
senticnet['watt'] = [0, 0, -1, -1, '#scared', '#disgusting', -0.667, 'moon_gravity', 'force', 'volt', 'coercion', 'power_source']
senticnet['waul'] = [-0.502, 0, 0.611, -0.752, '#angry', '#disgusting', -0.622, 'howl', 'wail', 'ululate', 'roar', 'yawl']
senticnet['wave_arm'] = [0, 0.936, 0, 0.71, '#interesting', '#admirable', 0.549, 'greet', 'salute', 'greet_each_other', 'say_goodbye_to', 'attract_attention']
senticnet['wave_clip'] = [0, -0.07, 0.091, -0.077, '#angry', '#disgusting', -0.033, 'bobby_pin', 'telephone_index', 'hairpin', 'clip', 'telephone_book']
senticnet['wave_crowd'] = [0.887, 0, 0, 0.881, '#joyful', '#admirable', 0.589, 'hide_body', 'quicken', 'run_away', 'grab_ball', 'run_president']
senticnet['wave_flag'] = [0.842, 0.833, 0, 0, '#joyful', '#interesting', 0.558, 'age_gracefully', 'hurt_animal', 'kill_specific_group', 'wrong_another_person', 'lose_key']
senticnet['wave_friend'] = [0.706, 0.796, 0, 0, '#joyful', '#interesting', 0.501, 'naive', 'welcome_friend', 'laugh_oneself', 'needy', 'captain_boat']
senticnet['wave_goodbye'] = [-0.123, 0, -0.051, -0.028, '#sad', '#scared', -0.067, 'throw_fit', 'watch_d', 'sun_oneself', 'battle_illness', 'honor_parent']
senticnet['wave_hand'] = [0.895, 0.765, 0, 0, '#joyful', '#interesting', 0.553, 'position_furniture', 'speak_english', 'deal_card_player', 'forward_email', 'explain_everything']
senticnet['wave_hello'] = [0.834, 0.763, 0, 0, '#joyful', '#interesting', 0.532, 'position_furniture', 'deal_card_player', 'mind_store', 'rush_job', 'explain_everything']
senticnet['wave_off'] = [0.739, -0.764, 0, 0.977, '#surprising', '#admirable', 0.827, 'accent', 'stress', 'play_down', 'emphasize', 'punctuate']
senticnet['wave_wind'] = [0.037, 0.161, -0.154, 0.203, '#interesting', '#admirable', 0.082, 'wave', 'flow', 'salute', 'multiple_purposes', 'farewell']
senticnet['wavelength'] = [-0.044, 0.096, -0.046, 0.084, '#interesting', '#admirable', 0.03, 'meaning', 'green_orange', 'yellow_green', 'red_green', 'red_orange']
senticnet['waver'] = [-0.885, 0, 0.925, -0.556, '#sad', '#angry', -0.789, 'falter', 'hesitate', 'linger', 'boggle', 'dwell_on']
senticnet['wawl'] = [-0.878, 0, 0.591, -0.726, '#sad', '#disgusting', -0.732, 'howl', 'wail', 'ululate', 'roar', 'yawl']
senticnet['wax_bean'] = [0.861, -0.549, 0, 0.976, '#joyful', '#admirable', 0.795, 'kidney_bean', 'frijol', 'frijole', 'green_bean', 'common_bean']
senticnet['wax_dental_floss'] = [0.936, 0.853, 0, 0, '#joyful', '#interesting', 0.596, 'fluoride_toothpaste', 'tartar_control_toothpaste', 'dental_floss', 'gel_toothpaste', 'disposable_razor']
senticnet['wax_palm'] = [0.557, -0.534, 0, 0.704, '#joyful', '#admirable', 0.598, 'carnauba_palm', 'carnauba', 'fan_palm', 'palmetto', 'palmyra']
senticnet['way'] = [-0.04, 0.136, 0, 0.105, '#interesting', '#admirable', 0.067, 'street', 'path', 'long_road', 'small_street', 'road']
senticnet['waylay'] = [0, 0, -0.994, -0.726, '#scared', '#disgusting', -0.573, 'ambuscade', 'lurk', 'ambush', 'scupper', 'bushwhack']
senticnet['weak'] = [-0.743, 0, -0.503, -0.526, '#sad', '#disgusting', -0.591, 'sunday', 'religious_service', 'religious', 'church_service', 'catholic']
senticnet['weak_acid'] = [0, 0.869, 0, 0.787, '#interesting', '#admirable', 0.552, 'drinkable', 'artificial_intelligence', 'verbal_contract', 'pacifism', 'consumable']
senticnet['weak_body'] = [-0.856, 0, 0.949, -0.835, '#sad', '#angry', -0.88, 'disease', 'cancer', 'leukemia', 'death', 'feel_sick']
senticnet['weaken'] = [0.847, -0.808, 0, 0.711, '#joyful', '#surprising', 0.789, 'mollify', 'enervate', 'stultify', 'wash_out', 'cripple']
senticnet['weakened'] = [-0.978, 0, 0.584, -0.789, '#sad', '#disgusting', -0.784, 'remittent', 'diminished', 'decreased', 'faded', 'small']
senticnet['weakening'] = [-0.78, 0, 0.764, -0.886, '#sad', '#disgusting', -0.81, 'withering', 'downfall', 'atrophy', 'fading', 'attenuation']
senticnet['weakling'] = [-0.686, 0, 0.71, -0.879, '#angry', '#disgusting', -0.758, 'chicken', 'softy', 'softie', 'crybaby', 'wimp']
senticnet['weakness'] = [-0.95, 0, -0.73, -0.781, '#sad', '#disgusting', -0.82, 'nigh', 'belonging', 'solace', 'comfortably', 'comfortableness']
senticnet['wealth'] = [0.991, 0.945, 0, 0, '#joyful', '#interesting', 0.645, 'loan', 'extra_money', 'check', 'money_earn', 'cash_pay']
senticnet['wealthy'] = [0.973, 0.707, 0, 0, '#joyful', '#interesting', 0.56, 'money', 'down_payment', 'much_money', 'slogan', 'take_out_loan']
senticnet['wealthy_person'] = [0, 0.084, -0.052, 0.076, '#interesting', '#admirable', 0.036, 'manor', 'rich_house', 'aristocrat', 'wealthy', 'mansion']
senticnet['weapon'] = [-0.828, 0, 0, -0.952, '#sad', '#disgusting', -0.593, 'firearm', 'machine_gun', 'grenade', 'handgun', 'big_gun']
senticnet['weapon_war'] = [-0.888, 0, 0, -0.732, '#sad', '#disgusting', -0.54, 'tool_war', 'machine_gun', 'weapon', 'firearm', 'handgun']
senticnet['weaponless'] = [-0.574, 0, 0.654, -0.986, '#angry', '#disgusting', -0.738, 'defenseless', 'defenceless', 'barehanded', 'clean', 'unarmed']
senticnet['wear'] = [-0.976, 0, 0.54, -0.553, '#sad', '#disgusting', -0.69, 'ablate', 'ablate_off', 'ablate_out', 'ablate_down', 'ablate_thin']
senticnet['wear_apron'] = [-0.09, -0.006, 0, -0.078, '#sad', '#disgusting', -0.054, 'deflate', 'read_cover', 'read_direction', 'learn_read', 'spread_out']
senticnet['wear_around_neck'] = [0.956, 0, 0, 0.864, '#joyful', '#admirable', 0.607, 'dog_like', 'faithfulness', 'type_of_dog', 'future_robot', 'trust']
senticnet['wear_away'] = [-0.992, 0, 0.869, -0.604, '#sad', '#angry', -0.822, 'excoriate', 'chafe', 'rasp', 'abrade', 'wear_off']
senticnet['wear_bath_suit'] = [-0.073, 0, 0.009, 0, '#sad', '#angry', -0.027, 'put_swimsuit', 'go_pool', 'put_bath_suit', 'wear_swim_suit', 'go_lake']
senticnet['wear_boot'] = [0, -0.063, 0.113, -0.107, '#angry', '#disgusting', -0.052, 'run_fast', 'put_sneaker', 'bring_dog', 'good_physical_condition', 'expend_energy']
senticnet['wear_clean_clothes'] = [0, 0.842, 0, 0, '#interesting', '#interesting', 0.281, 'smell_nice', 'personal_hygiene', 'remove_dirt_body', 'clean_clothes', 'become_clean']
senticnet['wear_clean_underwear'] = [0.973, 0, 0, 0, '#joyful', '#joyful', 0.324, 'make_doctor_appointment', 'schedule_appointment_doctor', 'doctor_appointment', 'call_doctor', 'make_appointment_with_doctor']
senticnet['wear_clothes'] = [0.983, 0.934, 0, 0, '#joyful', '#interesting', 0.639, 'clothes', 'piece_of_clothing', 'wear_shirt', 'fabric_shop', 'item_clothes']
senticnet['wear_comfortable_clothes'] = [0.07, 0, 0.051, 0.091, '#joyful', '#admirable', 0.037, 'stretch_muscle', 'put_tennis_shoes', 'stretch_first', 'run_fast', 'run_quickly']
senticnet['wear_comfortable_shoes'] = [-0.059, -0.016, 0.06, -0.073, '#angry', '#disgusting', -0.059, 'obey_rule', 'look_map', 'leave_house', 'put_walking_shoes', 'decide_to_go']
senticnet['wear_down'] = [0.732, -0.675, 0, 0.749, '#joyful', '#admirable', 0.719, 'tucker', 'tucker_out', 'exhaust', 'beat', 'overtire']
senticnet['wear_dress'] = [0, 0.842, 0, 0, '#interesting', '#interesting', 0.281, 'wear_clothes', 'go_outside', 'fancy_dress', 'dress', 'wear_good_shoes']
senticnet['wear_glass'] = [0.837, 0, 0, 0, '#joyful', '#joyful', 0.279, 'ability_see', 'near_tv', 'open_eye', 'turn_on_tv', 'eyesight']
senticnet['wear_glasses'] = [-0.964, 0, 0, -0.715, '#sad', '#disgusting', -0.56, 'nerd', 'big_glasses', 'computer_lover', 'geek', 'blind']
senticnet['wear_glove'] = [-0.043, 0, -0.087, 0, '#sad', '#scared', -0.043, 'five_fingers', 'palm', 'arm_part', 'five_digits', 'ride_motorbike']
senticnet['wear_good_shoes'] = [-0.086, -0.014, 0.067, 0, '#sad', '#angry', -0.046, 'wear_running_shoes', 'put_running_shoes', 'put_shoes', 'find_ball', 'use_leg']
senticnet['wear_hat'] = [0.028, 0.149, -0.06, 0.121, '#interesting', '#admirable', 0.079, 'serve_beer', 'raise_hell', 'drink_tea', 'drink_juice', 'drink_much_beer']
senticnet['wear_helmet'] = [-0.112, 0, 0.012, -0.099, '#sad', '#disgusting', -0.074, 'lose_balance', 'fall_off', 'shift_gear', 'trip_over', 'peddle']
senticnet['wear_jacket'] = [0.069, 0, 0, 0, '#joyful', '#joyful', 0.023, 'knit_sweater', 'make_drape', 'weave', 'weave_cloth', 'cover_body']
senticnet['wear_makeup'] = [0.699, 0.622, -0.232, 0.322, '#joyful', '#interesting', 0.47, 'smoke_cigarette', 'feel_good', 'age_prematurely', 'sexy_woman', 'blow_smoke']
senticnet['wear_mask'] = [-0.911, 0, 0.429, -0.96, '#sad', '#disgusting', -0.767, 'hide_identity', 'hide_face', 'bad_person', 'thief', 'robbery']
senticnet['wear_necklace'] = [0.789, 0, 0, 0.878, '#joyful', '#admirable', 0.556, 'talk_oneself', 'world_peace', 'gain_respect', 'experience_life', 'strong_relationship']
senticnet['wear_nice_clothes'] = [0, 0.743, 0, 0.882, '#interesting', '#admirable', 0.542, 'little_hair', 'improve_look', 'short_hair', 'look_different', 'increase_self-confidence']
senticnet['wear_off'] = [-0.976, 0, 0.54, -0.553, '#sad', '#disgusting', -0.69, 'wear', 'ablate', 'wear_out', 'wear_down', 'wear_thin']
senticnet['wear_old_clothes'] = [0, 0.995, 0, 0, '#interesting', '#interesting', 0.332, 'use_soap', 'use_water', 'launder', 'sort_clothes', 'clean_product']
senticnet['wear_out'] = [-0.959, 0, 0, -0.87, '#sad', '#disgusting', -0.61, 'tucker', 'tucker_out', 'exhaust', 'beat', 'overtire']
senticnet['wear_out_shoes'] = [0, 0, 0, 0.968, '#admirable', '#admirable', 0.323, 'become_physically_fit', 'physical_exertion', 'exercise_dog', 'much_exercise', 'vigorous_exercise']
senticnet['wear_proper_clothes'] = [-0.085, -0.073, 0.116, -0.098, '#angry', '#disgusting', -0.075, 'stretch_muscle', 'put_sneaker', 'put_jogging_shoes', 'bring_dog', 'strain_muscle']
senticnet['wear_protection'] = [0, 0.141, 0, 0.05, '#interesting', '#admirable', 0.064, 'drive_home', 'sex', 'safe_sex', 'contraception', 'prevent_pregnancy']
senticnet['wear_pyjamas'] = [0, 0, 0, -0.089, '#disgusting', '#disgusting', -0.03, 'sleepwalk', 'close_eye', 'lay_down', 'wind_down', 'lie_down']
senticnet['wear_raincoat'] = [-0.07, 0, 0.019, 0, '#sad', '#angry', -0.03, 'carry_umbrella', 'rain_parade', 'turn_heat', 'turn_aircon_on', 'read_bedtime_story']
senticnet['wear_robe'] = [-0.031, 0.163, -0.057, 0.08, '#interesting', '#admirable', 0.052, 'fashion', 'become_judge', 'supreme_court', 'arbitrator', 'judge_jury']
senticnet['wear_running_shoes'] = [-0.096, -0.018, 0.062, 0, '#sad', '#angry', -0.047, 'put_running_shoes', 'wear_good_shoes', 'put_shoes', 'use_leg', 'put_jogging_shoes']
senticnet['wear_sandal'] = [-0.591, 0, 0.553, -0.768, '#sad', '#disgusting', -0.637, 'booted', 'slippered', 'roughshod', 'sandaled', 'shod']
senticnet['wear_shirt'] = [0.768, 0.856, 0, 0, '#joyful', '#interesting', 0.541, 'clothes', 'piece_of_clothing', 'wear_clothes', 'fabric_shop', 'item_clothes']
senticnet['wear_shoes'] = [0, 0.144, -0.079, 0.222, '#interesting', '#admirable', 0.096, 'put_shoes', 'put_walking_shoes', 'wear_good_shoes', 'wear_running_shoes', 'use_leg']
senticnet['wear_shorts'] = [0, 0.144, -0.079, 0.222, '#interesting', '#admirable', 0.096, 'hit_tree', 'perspire', 'enjoy_fresh_air', 'catch_ball', 'work_up_sweat']
senticnet['wear_silly_hat'] = [-0.203, -0.009, -0.081, -0.075, '#sad', '#scared', -0.117, 'promise_good', 'roll_ball', 'trade_baseball_card', 'follow_mother', 'bicycle_school']
senticnet['wear_skirt'] = [0.992, 0.734, 0, 0, '#joyful', '#interesting', 0.575, 'dig_grave', 'bicycle_across_town', 'service_car', 'mine_diamond', 'marry_man']
senticnet['wear_sock'] = [-0.082, 0, 0, 0, '#sad', '#sad', -0.027, 'camp_out', 'eat_dessert', 'wash_dog', 'floss_tooth', 'water_rose']
senticnet['wear_suit'] = [-0.035, -0.007, 0, -0.094, '#sad', '#disgusting', -0.041, 'hold_breath', 'underwater', 'turn_aircon_on', 'sit_in_shade', 'think_food']
senticnet['wear_sunglasses'] = [-0.1, 0, -0.11, 0, '#sad', '#scared', -0.07, 'change_tire', 'fix_flat_tire', 'play_rugby', 'wear_silly_hat', 'become_adult']
senticnet['wear_sunscreen'] = [0.943, 0.936, 0, 0, '#joyful', '#interesting', 0.626, 'sunscreen', 'sunblock', 'go_to_beach', 'sunny_day', 'summertime']
senticnet['wear_sweater'] = [0.337, 0, 0, 0.093, '#joyful', '#admirable', 0.143, 'feel_comfortable', 'put_coat', 'spread_germ', 'feel_warm', 'light_cigar']
senticnet['wear_swim_suit'] = [-0.073, 0, 0.009, 0, '#sad', '#angry', -0.027, 'put_swimsuit', 'go_pool', 'put_bath_suit', 'wear_bath_suit', 'go_lake']
senticnet['wear_swimsuit'] = [0.751, 0, 0, 0, '#joyful', '#joyful', 0.25, 'see_fish', 'swim_underwater', 'family_fun', 'take_leak', 'explore_underwater']
senticnet['wear_thin'] = [-0.976, 0, 0.54, -0.553, '#sad', '#disgusting', -0.69, 'wear', 'wear_off', 'wear_out', 'wear_down', 'ablate']
senticnet['wear_uniform'] = [-0.052, -0.034, 0.014, -0.079, '#sad', '#disgusting', -0.037, 'travel_work', 'fly_plane', 'push_limit', 'lock_up', 'carelessness']
senticnet['wear_upon'] = [0.589, -0.542, 0, 0.755, '#joyful', '#admirable', 0.629, 'tucker', 'tucker_out', 'exhaust', 'beat', 'overtire']
senticnet['wearable'] = [-0.741, 0, 0.722, -0.562, '#sad', '#angry', -0.675, 'trapping', 'furnishing', 'wear', 'accouterment', 'belt']
senticnet['weariness'] = [-0.732, 0, 0.596, -0.773, '#sad', '#disgusting', -0.7, 'exhaustion', 'loss_of_strength', 'logginess', 'eyestrain', 'asthenopia']
senticnet['wearing'] = [-0.88, 0, 0.907, -0.522, '#sad', '#angry', -0.77, 'corrasion', 'erosion', 'eroding', 'eating_away', 'corrasion_away']
senticnet['wearing_away'] = [-0.88, 0, 0.907, -0.522, '#sad', '#angry', -0.77, 'wearing', 'erosion', 'eroding', 'eating_away', 'corrasion']
senticnet['wearisome'] = [-0.661, 0, 0.594, -0.675, '#sad', '#disgusting', -0.643, 'boring', 'deadening', 'irksome', 'tiresome', 'uninteresting']
senticnet['weary'] = [0.981, -0.898, 0, 0.631, '#joyful', '#surprising', 0.837, 'tucker', 'tucker_out', 'exhaust', 'beat', 'overtire']
senticnet['wearying'] = [-0.825, 0, 0.58, -0.539, '#sad', '#angry', -0.648, 'tiring', 'wearing', 'effortful', 'hard', 'arduous']
senticnet['weather_condition'] = [0.025, -0.06, -0.056, 0.161, '#surprising', '#admirable', 0.063, 'cloudy', 'up_high', 'carry_water', 'dew', 'hazy']
senticnet['weather_deck'] = [0.831, -0.821, 0, 0.826, '#joyful', '#admirable', 0.826, 'deck', 'freeboard_deck', 'upper_deck', 'shelter_deck', 'boat_deck']
senticnet['weather_element'] = [0.116, 0.129, -0.058, 0.053, '#joyful', '#interesting', 0.08, 'blown', 'airy', 'move_air', 'unseen', 'breezy']
senticnet['weather_event'] = [-0.984, 0, 0.96, -0.923, '#sad', '#angry', -0.956, 'thunderstorm', 'storm', 'bad_weather', 'heavy_rain', 'hurricane']
senticnet['weather_forecast'] = [-0.036, 0, -0.05, 0, '#sad', '#scared', -0.029, 'crystal_clear', 'water_sky', 'weather_condition', 'weather_phenomenon', 'sun_cover']
senticnet['weather_outlook'] = [0.993, -0.654, 0, 0.743, '#joyful', '#admirable', 0.797, 'weather_forecast', 'prognosis', 'financial_forecast', 'prediction', 'foretelling']
senticnet['weather_phenomenon'] = [0.126, 0, 0, 0, '#joyful', '#joyful', 0.042, 'natural_phenomenon', 'rain_wind', 'rain_storm', 'stormy', 'weather_type']
senticnet['weather_prediction'] = [0, 0.086, -0.082, 0.197, '#interesting', '#admirable', 0.067, 'prediction', 'circumstance', 'tv_program', 'cnn', 'print_newspaper']
senticnet['weather_report'] = [0.102, -0.102, 0.009, -0.121, '#joyful', '#surprising', 0.025, 'freshness', 'bulletin', 'bird_fly', 'cnn', 'paper_write']
senticnet['weather_storm'] = [0.945, 0.941, 0, 0, '#joyful', '#interesting', 0.629, 'close_together', 'smoke_joint', 'rush_job', 'hang_picture_on_wall', 'gather_berry']
senticnet['weather_type'] = [-0.176, -0.073, 0, -0.159, '#sad', '#disgusting', -0.087, 'snow_storm', 'rain_snow', 'rainy', 'natural_phenomenon', 'cold_hot']
senticnet['weatherproof'] = [-0.898, 0, 0.627, -0.547, '#sad', '#angry', -0.691, 'shielded', 'protected', 'covert', 'stormproof', 'fortified']
senticnet['weatherstrip'] = [-0.57, 0, 0.855, -0.957, '#angry', '#disgusting', -0.794, 'soundproof', 'modify', 'alter', 'change', 'insulate']
senticnet['weave'] = [-0.051, 0, 0.039, -0.05, '#sad', '#disgusting', -0.047, 'clothes_repair', 'knit_sweater', 'make_cloth', 'weave_cloth', 'make_fabric']
senticnet['weave_cloth'] = [-0.029, -0.058, 0.106, -0.06, '#angry', '#disgusting', -0.046, 'make_cloth', 'make_clothes', 'weave', 'protect_body', 'wear']
senticnet['web'] = [0.061, 0.128, 0, 0.151, '#interesting', '#admirable', 0.113, 'spool', 'silk', 'velvet', 'cotton', 'satin']
senticnet['web_browser'] = [0.12, 0, 0.032, 0.08, '#joyful', '#admirable', 0.056, 'world_wide', 'web', 'internet', 'ass', 'www']
senticnet['web_site'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'internet', 'go_online', 'visit_web_site', 'find_information', 'choose_book']
senticnet['web_surf'] = [0.061, 0.128, 0, 0.151, '#interesting', '#admirable', 0.113, 'check_email', 'use_internet', 'surf_internet', 'use_technology', 'use_computer']
senticnet['webbed'] = [0, 0, -0.839, -0.759, '#scared', '#disgusting', -0.533, 'netted', 'net', 'lacy', 'netlike', 'weblike']
senticnet['webpage'] = [-0.025, 0, 0.077, 0, '#sad', '#angry', -0.034, 'record', 'file_bill', 'swat', 'store_record', 'ideal']
senticnet['wed'] = [-0.838, 0, 0.64, -0.536, '#sad', '#angry', -0.671, 'marry', 'get_married', 'mismarry', 'conjoin', 'hook_up_with']
senticnet['wedding'] = [0.768, 0.97, 0, 0.773, '#interesting', '#admirable', 0.837, 'celebrate_wedding', 'ceremony', 'religious_event', 'friend_wedding', 'happy_event']
senticnet['wedding_band'] = [0.025, 0, 0, 0.175, '#joyful', '#admirable', 0.067, 'piece_of_jewelry', 'bell_sound', 'gold', 'engagement', 'diamond_ring']
senticnet['wedding_cake'] = [0.78, 0.739, 0, 0.798, '#joyful', '#admirable', 0.772, 'friend_wedding', 'wedding', 'cake', 'celebrate_wedding', 'celebrate_special_occcasion']
senticnet['wedding_ceremony'] = [0.78, 0.739, 0, 0.798, '#joyful', '#admirable', 0.772, 'marriage_ceremony', 'jewelry_store', 'jewelry_box', 'strip_joint', 'decorate_oneself']
senticnet['wedding_chapel'] = [0.057, 0.13, 0, 0.119, '#interesting', '#admirable', 0.102, 'friend_wedding', 'circular_route', 'spanish_restaurant', 'altar', 'monastery']
senticnet['wedding_reception'] = [0.11, -0.079, 0.017, 0.057, '#joyful', '#surprising', 0.076, 'nightclub', 'cassette', 'band_play', 'ballroom', 'classical']
senticnet['wedding_ring'] = [0.048, 0, 0, 0.093, '#joyful', '#admirable', 0.047, 'ring', 'ring_loudly', 'diamond_ring', 'necklace', 'jewelry']
senticnet['wedding_vow'] = [0.97, 0.749, 0, 0.898, '#joyful', '#admirable', 0.872, 'distribute', 'hand_over', 'donate', 'take', 'retain']
senticnet['wedge'] = [0, 0, 0.061, -0.032, '#angry', '#disgusting', -0.031, 'garden_tool', 'straight_line', 'sharp', 'razor_blade', 'pointy_object']
senticnet['wedge_door'] = [-0.126, 0, -0.056, 0, '#sad', '#scared', -0.061, 'kiss_girl', 'fancy_girl', 'steal_store', 'part_of_hair', 'visit_grandmother']
senticnet['wedge_door_open'] = [-0.1, 0, 0, 0, '#sad', '#sad', -0.033, 'write_novel', 'draw_picture', 'write_word', 'sign_document', 'type_of_letter']
senticnet['wedge_shape'] = [0.763, -0.612, 0, 0.777, '#joyful', '#admirable', 0.717, 'acute_triangle', 'triangle', 'cuneus', 'wedge', 'oblique_triangle']
senticnet['wedlock'] = [-0.875, 0, 0.524, -0.762, '#sad', '#disgusting', -0.72, 'marriage', 'matrimony', 'union', 'spousal_relationship', 'bigamy']
senticnet['wee'] = [0.027, 0, 0.012, 0.063, '#joyful', '#admirable', 0.026, 'vegetation', 'tree_flower', 'green_growth', 'small', 'greenery']
senticnet['wee_small_voice'] = [0.714, -0.583, 0, 0.667, '#joyful', '#admirable', 0.655, 'morality', 'moral_sense', 'small_voice', 'voice_of_conscience', 'sense_of_shame']
senticnet['weed'] = [0, -0.012, 0.036, -0.05, '#angry', '#disgusting', -0.025, 'shamrock', 'flower_plant', 'fruit_plant', 'green_plant', 'star_anise']
senticnet['week'] = [0, 0, -0.116, 0, '#scared', '#scared', -0.039, 'year', 'reckon', 'century', 'month', 'november']
senticnet['weekend'] = [0, 0.734, 0, 0, '#interesting', '#interesting', 0.245, 'sleep', 'go_sleep', 'relax', 'go_out', 'sleep_night']
senticnet['weep'] = [-0.701, 0, 0, -0.903, '#sad', '#disgusting', -0.535, 'bawl', 'sob', 'shed_tear', 'cry_hard', 'wail']
senticnet['weeper'] = [-0.989, 0, 0.664, -0.524, '#sad', '#angry', -0.726, 'unfortunate', 'unfortunate_person', 'griever', 'pallbearer', 'bearer']
senticnet['weepiness'] = [-0.71, 0.312, -0.4, -0.08, '#sad', '#scared', -0.293, 'lachrymose', 'tearful', 'weeping', 'dolorous', 'tearfulness']
senticnet['weeping'] = [-0.71, 0.312, -0.4, -0.08, '#sad', '#scared', -0.293, 'lachrymose', 'tearful', 'dolorous', 'tearfulness', 'weepiness']
senticnet['weigh'] = [0.899, 0.939, 0, 0, '#joyful', '#interesting', 0.613, 'proportion', 'weight_measurement', 'weight', 'measurement_device', 'measure_pound']
senticnet['weigh_consequence'] = [-0.176, 0.111, -0.111, -0.141, '#sad', '#disgusting', -0.106, 'good_plan', 'overpower', 'commit_crime', 'fight_battle', 'get_revenge']
senticnet['weigh_much'] = [0, 0.085, 0.013, 0.212, '#interesting', '#admirable', 0.095, 'heavy', 'dense', 'smooth_surface', 'magnetic', 'precious']
senticnet['weight'] = [0.877, 0.778, 0, 0, '#joyful', '#interesting', 0.552, 'heavy_weight', 'weigh', 'weight_measurement', 'heaviness', 'proportion']
senticnet['weight_gain'] = [0.964, 0, 0, 0, '#joyful', '#joyful', 0.321, 'become_little_hungry', 'impress_girlfriend', 'eat_pizza', 'eat', 'satisfy_crave']
senticnet['weight_lift'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'increase_metabolism', 'feel_fit', 'become_healthy', 'exercise', 'big_muscle']
senticnet['weight_loss'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'increase_metabolism', 'big_muscle', 'feel_fit', 'diet', 'become_healthy']
senticnet['weight_machine'] = [0, 0.142, 0, 0.125, '#interesting', '#admirable', 0.089, 'pulley', 'tool', 'exercise_equipment', 'wrench', 'clamp']
senticnet['weight_measurement'] = [-0.033, 0.099, 0.056, 0.154, '#interesting', '#admirable', 0.055, 'heavy_weight', 'measure_pound', 'measurement_device', 'proportion', 'heaviness']
senticnet['weightlift'] = [-0.753, 0, 0.794, -0.585, '#sad', '#angry', -0.711, 'jerk', 'snatch', 'military_press', 'clean', 'bench_press']
senticnet['weightlifting'] = [-0.603, 0, 0.814, -0.89, '#angry', '#disgusting', -0.769, 'jerk', 'snatch', 'military_press', 'clean', 'bench_press']
senticnet['weighty'] = [0, 0, -0.859, -0.798, '#scared', '#disgusting', -0.552, 'grave', 'telling', 'heavy', 'cogent', 'grievous']
senticnet['weird'] = [-0.842, 0, -0.964, -0.82, '#sad', '#scared', -0.875, 'strange', 'uneducated', 'ignorant', 'precise', 'contrary']
senticnet['weird_behavior'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'antisocial', 'attitude', 'disorder', 'sociopathic', 'unfriendly']
senticnet['weirdo'] = [-0.648, 0, 0.781, -0.743, '#angry', '#disgusting', -0.724, 'lunatic', 'crazy', 'loony', 'looney', 'nutcase']
senticnet['welcher'] = [-0.524, 0, 0.506, -0.94, '#sad', '#disgusting', -0.657, 'gouger', 'swindler', 'defrauder', 'fraud', 'chiseler']
senticnet['welcome'] = [0, 0.779, 0, 0, '#interesting', '#interesting', 0.26, 'salutation', 'aye', 'please', 'nod', 'give']
senticnet['welcome_friend'] = [-0.108, 0.075, -0.08, 0, '#sad', '#scared', -0.038, 'captain_boat', 'laugh_oneself', 'needy', 'come_house', 'agree_disagree']
senticnet['welcome_guest'] = [0, 0.755, 0, 0, '#interesting', '#interesting', 0.252, 'eat_good_food', 'wipe_foot', 'meet_other_person', 'eat_well', 'eat_sushi']
senticnet['weld'] = [0, 0, 0, 0.114, '#admirable', '#admirable', 0.038, 'move_part', 'make_go', 'mode_transportation', 'form_of_transportation', 'car_steer']
senticnet['welfare'] = [0.915, 0, 0.705, 0.912, '#joyful', '#admirable', 0.374, 'reward', 'bribe', 'charity', 'profit', 'mastercard']
senticnet['well'] = [0.728, 0.713, 0, 0.715, '#joyful', '#admirable', 0.719, 'brook', 'stream', 'well_done', 'creek', 'pond']
senticnet['well-disposed'] = [0.58, 0.651, -0.264, 0.308, '#joyful', '#interesting', 0.425, 'friendliness', 'approving', 'approve', 'sanctioned', 'approved']
senticnet['well-to-do'] = [0.874, 0.907, 0, 0, '#joyful', '#interesting', 0.594, 'well-heeled', 'prosperous', 'well-fixed', 'comfortable', 'easy']
senticnet['well-worn'] = [0, 0, -0.929, -0.803, '#scared', '#disgusting', -0.577, 'banal', 'commonplace', 'old-hat', 'hackneyed', 'shopworn']
senticnet['well_deigned'] = [0.036, 0.232, -0.057, 0.192, '#interesting', '#admirable', 0.134, 'ergonomic_chair', 'comfortable', 'useful', 'prevent_stress', 'ergonomic_pillow']
senticnet['well_done'] = [0, 0.806, 0, 0.909, '#interesting', '#admirable', 0.572, 'high_quality', 'really_good', 'excellence', 'superlative', 'high_standard']
senticnet['well_dress'] = [0.855, 0.849, 0, 0.767, '#joyful', '#interesting', 0.824, 'keep_clothes_clean', 'smell_good', 'smell_nice', 'wash_hair', 'smell_clean']
senticnet['well_known'] = [0.983, 0.915, 0, 0.737, '#joyful', '#interesting', 0.878, 'famous', 'everyone_know', 'collection', 'favorite', 'clique']
senticnet['well_light'] = [0.05, 0.239, 0, 0.159, '#interesting', '#admirable', 0.149, 'hold_coin', 'money_collector', 'money_keeper', 'money_hold', 'save_money']
senticnet['well_off'] = [0.995, 0, 0, 0.835, '#joyful', '#admirable', 0.61, 'easy', 'well_fixed', 'prosperous', 'well-heeled', 'comfortable']
senticnet['well_test'] = [0.774, 0.728, 0, 0.932, '#joyful', '#admirable', 0.811, 'accumulate_knowledge', 'wish_learn', 'learn_history', 'become_knowledgeable', 'eye_strain']
senticnet['wellness'] = [0.252, 0.204, -0.138, 0.246, '#joyful', '#admirable', 0.188, 'medical_care', 'good_parent', 'health', 'keep_well', 'medical']
senticnet['wellspring'] = [-0.996, 0, 0.835, -0.582, '#sad', '#angry', -0.804, 'beginning', 'origin', 'root', 'rootage', 'source']
senticnet['welsher'] = [-0.663, 0, 0.602, -0.571, '#sad', '#angry', -0.612, 'gouger', 'swindler', 'defrauder', 'fraud', 'chiseler']
senticnet['welt'] = [-0.083, 0, -0.051, -0.069, '#sad', '#disgusting', -0.068, 'heal_wind', 'wind', 'cut', 'abrasion', 'ache']
senticnet['welter'] = [-0.855, 0, 0.583, -0.716, '#sad', '#disgusting', -0.718, 'muddle', 'fuddle', 'mare_nest', 'rummage', 'clutter']
senticnet['weltschmerz'] = [-0.77, 0.277, -0.449, -0.051, '#sad', '#scared', -0.331, 'heavyheartedness', 'bored', 'world-weariness', 'heavyhearted', 'world-weary']
senticnet['welwitschia'] = [-0.772, 0, 0.585, -0.835, '#sad', '#disgusting', -0.731, 'progymnosperm', 'gymnosperm', 'cycad', 'seed_fern', 'pteridosperm']
senticnet['wench'] = [0, 0.848, 0, 0.893, '#interesting', '#admirable', 0.58, 'lady', 'female', 'mother', 'pedophile', 'mom']
senticnet['western'] = [0.106, -0.018, 0, 0, '#joyful', '#surprising', 0.041, 'circus_act', 'sumo', 'rodeo', 'grand_canyon', 'have_fun']
senticnet['western_saxifrage'] = [-0.565, 0, 0.848, -0.801, '#angry', '#disgusting', -0.738, 'herb', 'yellow_mountain_saxifrage', 'meadow_saxifrage', 'mossy_saxifrage', 'breakstone']
senticnet['western_yellow_pine'] = [-0.698, 0, 0.725, -0.89, '#angry', '#disgusting', -0.771, 'ponderosa', 'ponderosa_pine', 'yellow_pine', 'bull_pine', 'longleaf_pine']
senticnet['wet'] = [-0.023, -0.024, 0.076, -0.054, '#angry', '#disgusting', -0.043, 'wear_raincoat', 'carry_umbrella', 'feel_cold', 'camp_out', 'splash_water']
senticnet['wet_air'] = [0.058, 0, 0.023, 0.058, '#joyful', '#admirable', 0.031, 'fluid', 'white_water', 'liquid', 'heavy_air', 'potable_liquid']
senticnet['wet_bed'] = [-0.144, -0.013, -0.05, -0.12, '#sad', '#disgusting', -0.1, 'quiet_mind', 'miss_appointment', 'sleep_bed', 'lower_standard', 'dress_doll']
senticnet['wet_blanket'] = [-0.513, 0, 0.906, -0.922, '#angry', '#disgusting', -0.78, 'worrier', 'fusspot', 'worrywart', 'unwelcome_person', 'killjoy']
senticnet['wet_clothes'] = [0.884, 0.784, 0, 0, '#joyful', '#interesting', 0.556, 'clothes_shrink', 'become_cleaner', 'dry_skin', 'become_wet', 'run_out_soap']
senticnet['wet_cold'] = [-0.182, -0.078, 0, -0.203, '#sad', '#disgusting', -0.102, 'uncomfortable', 'frozen_water', 'wetness', 'coldness', 'frozen']
senticnet['wet_floor'] = [-0.037, -0.008, 0.066, 0, '#sad', '#angry', -0.032, 'dirt', 'allergy', 'dust', 'dirt_floor', 'insect']
senticnet['wet_hair'] = [0, 0, 0, -0.807, '#disgusting', '#disgusting', -0.269, 'wet_clothes', 'get_cold', 'sunburned', 'hurt_back', 'sore_back']
senticnet['wet_lip'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'sexual_excitement', 'sexy', 'lip_stick', 'kiss', 'clean_up']
senticnet['wet_oneself'] = [-0.124, 0, -0.12, -0.07, '#sad', '#scared', -0.105, 'follow_mother', 'battle_illness', 'head_home', 'laugh_clown', 'trade_baseball_card']
senticnet['wet_paint'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'wall_decoration', 'renovation', 'painting', 'artwork', 'new_house']
senticnet['wet_pant'] = [0, 0, 0.742, -0.784, '#angry', '#disgusting', -0.509, 'listen_story', 'trade_stock', 'become_depressed', 'act_silly', 'correct_mistake']
senticnet['wet_tissue'] = [0.159, 0.068, -0.079, 0.118, '#joyful', '#admirable', 0.089, 'clean_mouth', 'wipe_mouth_napkin', 'refresh', 'wipe_dirty', 'paper_towel']
senticnet['wet_towel'] = [-0.068, 0, 0, 0, '#sad', '#sad', -0.023, 'bathroom_wall', 'fallen_tree', 'relax', 'under_rock', 'compost_pile']
senticnet['wetness'] = [-0.036, 0, 0.014, -0.031, '#sad', '#disgusting', -0.027, 'ice_crystal', 'frozen_water', 'wet_cold', 'coldness', 'frozen']
senticnet['wetter'] = [-0.531, 0, 0.508, -0.748, '#sad', '#disgusting', -0.596, 'bedpisser', 'bed_pisser', 'mortal', 'pisser', 'person']
senticnet['whack'] = [0.94, 0.726, 0, 0, '#joyful', '#interesting', 0.555, 'snap', 'fist', 'make_fist', 'rudeness', 'oppose']
senticnet['whacking'] = [-0.845, 0, 0.557, -0.796, '#sad', '#disgusting', -0.733, 'corporal_punishment', 'lashing', 'whipping', 'tanning', 'flogging']
senticnet['whale'] = [0, 0, -0.071, 0, '#scared', '#scared', -0.024, 'seal', 'walrus', 'mussel', 'alligator', 'otter']
senticnet['whale_louse'] = [0.96, -0.772, 0, 0.929, '#joyful', '#admirable', 0.887, 'amphipod', 'beach_flea', 'sand_hopper', 'sandhopper', 'sand_flea']
senticnet['whammy'] = [-0.976, 0, 0.597, -0.652, '#sad', '#disgusting', -0.742, 'blow', 'black_eye', 'setback', 'reversal', 'reverse']
senticnet['what_for'] = [0.539, -0.946, 0, 0.85, '#surprising', '#admirable', 0.778, 'rebuke', 'reproof', 'reproval', 'reprehension', 'reprimand']
senticnet['whatnot'] = [0.749, -0.859, 0, 0.709, '#joyful', '#surprising', 0.772, 'curio', 'oddity', 'curiosity', 'peculiarity', 'oddment']
senticnet['wheat'] = [0, 0.071, 0.027, 0.053, '#interesting', '#admirable', 0.032, 'grain', 'rye', 'corn', 'oat', 'white_rice']
senticnet['wheat_corn'] = [0, 0.072, 0.036, 0.059, '#interesting', '#admirable', 0.032, 'wheat', 'farm_plant', 'plant_food', 'wheat_rice', 'farm_vegetable']
senticnet['wheat_flour'] = [0.03, 0, 0, 0.076, '#joyful', '#admirable', 0.035, 'food_ingredient', 'rice', 'granulate', 'noodel', 'white_grain']
senticnet['wheat_rice'] = [0, 0.085, 0.045, 0.069, '#interesting', '#admirable', 0.036, 'farm_plant', 'wheat_corn', 'plant_food', 'wheat', 'farm_vegetable']
senticnet['wheel'] = [0, -0.097, 0.044, 0.055, '#surprising', '#admirable', 0.036, 'two_wheels', 'gear', 'axle', 'engine', 'steer_wheel']
senticnet['wheelchair'] = [-0.045, 0, -0.08, -0.078, '#scared', '#disgusting', -0.068, 'dirty_laundry', 'old_photograph', 'wife', 'hot_chick', 'mommy']
senticnet['wheeze'] = [-0.027, -0.05, 0.092, -0.065, '#angry', '#disgusting', -0.045, 'gasp', 'puff', 'pant', 'blow', 'heave']
senticnet['whine'] = [-0.261, 0, -0.216, 0, '#sad', '#scared', -0.159, 'shed_tear', 'bawl', 'eye_tear', 'say_prayer', 'show_emotion']
senticnet['whiner'] = [-0.747, 0, 0.68, -0.586, '#sad', '#angry', -0.671, 'kvetch', 'complainer', 'moaner', 'sniveller', 'crybaby']
senticnet['whiney'] = [-0.679, 0, 0.78, -0.816, '#angry', '#disgusting', -0.758, 'querulous', 'complaining', 'whiny', 'fretful', 'protestant']
senticnet['whiny'] = [-0.679, 0, 0.78, -0.816, '#angry', '#disgusting', -0.758, 'querulous', 'whiney', 'complaining', 'fretful', 'protestant']
senticnet['whip'] = [0.836, 0.775, 0, 0, '#joyful', '#interesting', 0.537, 'type_of_bow', 'chisel', 'baton', 'arrow', 'bow']
senticnet['whip_cream'] = [0.055, -0.015, 0, 0, '#joyful', '#surprising', 0.023, 'chocolate_pudding', 'green_bean', 'sweetness', 'side_dish', 'sushi']
senticnet['whip_hand'] = [0.761, -0.502, 0, 0.896, '#joyful', '#admirable', 0.72, 'advantage', 'vantage', 'upper_hand', 'favorable_position', 'edge']
senticnet['whipping'] = [-0.845, 0, 0.557, -0.796, '#sad', '#disgusting', -0.733, 'corporal_punishment', 'lashing', 'whacking', 'tanning', 'flogging']
senticnet['whisker'] = [0, -0.043, 0.085, -0.071, '#angry', '#disgusting', -0.038, 'claw', 'fur_keep_warm', 'tic', 'no_hair', 'muzzle']
senticnet['whiskered'] = [-0.945, 0, 0.84, -0.917, '#sad', '#disgusting', -0.901, 'bearded', 'barbate', 'beunshaved', 'unshaved', 'whiskery']
senticnet['whiskery'] = [-0.945, 0, 0.84, -0.917, '#sad', '#disgusting', -0.901, 'bearded', 'barbate', 'bewhiskered', 'whiskered', 'unshaved']
senticnet['whiskey'] = [0.711, 0, 0, 0.894, '#joyful', '#admirable', 0.535, 'bourbon', 'scotch', 'vodka', 'brandy', 'wine']
senticnet['whisper'] = [0, 0.921, 0, 0.854, '#interesting', '#admirable', 0.592, 'clear_throat', 'mouth_move', 'wake_morning', 'hear', 'mouth_noise']
senticnet['whispering_campaign'] = [-0.797, 0, 0.525, -0.635, '#sad', '#disgusting', -0.652, 'campaigning', 'candidacy', 'candidature', 'electioneering', 'political_campaign']
senticnet['whistle_happy_tune'] = [0.736, 0.719, 0, 0.794, '#joyful', '#admirable', 0.75, 'whistle', 'smoke_cigar', 'cross_bridge', 'deal_card', 'bounce_ball']
senticnet['white'] = [-0.556, 0, 0.561, -0.518, '#sad', '#angry', -0.545, 'whitey', 'honky', 'honkey', 'honkie', 'mortal']
senticnet['white-out'] = [0, -0.054, 0.065, -0.073, '#angry', '#disgusting', -0.028, 'tape_dispenser', 'letter_scale', 'intern', 'paper_punch', 'post_note']
senticnet['white_angel'] = [0.673, -0.64, 0, 0.669, '#joyful', '#admirable', 0.661, 'eudemon', 'guardian_angel', 'good_spirit', 'genius_loci', 'angel']
senticnet['white_animal'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'polar_bear', 'baji', 'arctic_fox', 'white_rabbit', 'fuzzy_animal']
senticnet['white_bird'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'glaucous_gull', 'dove', 'egret', 'white_swan', 'eismowe']
senticnet['white_blood_cell'] = [0.602, -0.736, 0, 0.942, '#surprising', '#admirable', 0.76, 'leukocyte', 'leucocyte', 'eosinophil', 'white_cell', 'white_blood_corpuscle']
senticnet['white_blood_corpuscle'] = [0.602, -0.736, 0, 0.942, '#surprising', '#admirable', 0.76, 'leukocyte', 'leucocyte', 'white_blood_cell', 'white_cell', 'eosinophil']
senticnet['white_brown'] = [0, 0.947, 0, 0.998, '#interesting', '#admirable', 0.648, 'tasty', 'flavor', 'sweetness', 'edible', 'a_lot_of_fat']
senticnet['white_cell'] = [0.602, -0.736, 0, 0.942, '#surprising', '#admirable', 0.76, 'leukocyte', 'leucocyte', 'white_blood_cell', 'eosinophil', 'white_blood_corpuscle']
senticnet['white_cinnamon'] = [-0.958, 0, 0.892, -0.777, '#sad', '#angry', -0.876, 'cork', 'cassia_bark', 'canella', 'canella_bark', 'bark']
senticnet['white_color'] = [0.044, 0, 0.04, 0.101, '#joyful', '#admirable', 0.035, 'tasty', 'white_stuff', 'fluid', 'flavor', 'crystalline_solid']
senticnet['white_cotton'] = [0, 0.081, 0.015, 0.052, '#interesting', '#admirable', 0.039, 'fabric', 'underwear', 'pajama', 'shirt', 'pants']
senticnet['white_face'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'afraid', 'scared', 'terrified', 'faint', 'sick']
senticnet['white_fox'] = [-0.662, 0, 0.992, -0.726, '#angry', '#disgusting', -0.793, 'vixen', 'red_fox', 'kit_fox', 'prairie_fox', 'fox']
senticnet['white_grain'] = [0.03, 0, 0, 0.076, '#joyful', '#admirable', 0.035, 'food_ingredient', 'rice', 'granulate', 'noodel', 'wheat_flour']
senticnet['white_house'] = [0, 0.994, 0, 0.73, '#interesting', '#admirable', 0.575, 'capitol', 'government_building', 'president', 'apartment_house', 'government']
senticnet['white_lead_ore'] = [0.555, -0.994, 0, 0.851, '#surprising', '#admirable', 0.8, 'quartz', 'cerussite', 'mineral', 'cobaltite', 'molybdenite']
senticnet['white_lie'] = [0.68, -0.861, 0, 0.72, '#surprising', '#admirable', 0.754, 'whopper', 'prevarication', 'jactitation', 'walloper', 'fib']
senticnet['white_light'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'water_sky', 'frozen_water', 'whiteness', 'water_drop', 'sun_cover']
senticnet['white_magic'] = [0.7, -0.628, 0, 0.58, '#joyful', '#surprising', 0.636, 'thaumaturgy', 'mojo', 'juju', 'conjuration', 'supernaturalism']
senticnet['white_mallee'] = [-0.605, 0, 0.787, -0.909, '#angry', '#disgusting', -0.767, 'mallee', 'congoo_mallee', 'black_mallee', 'black_sally', 'black_gum']
senticnet['white_paper'] = [0.993, 0.964, 0, 0, '#joyful', '#interesting', 0.652, 'phto_copy', 'writing_paper', 'printing_paper', 'note_book', 'color_paper']
senticnet['white_plague'] = [0.633, -0.634, 0, 0.507, '#joyful', '#surprising', 0.591, 'drug_addiction', 'dependance', 'physical_condition', 'physiological_state', 'physiological_condition']
senticnet['white_potato'] = [0.532, -0.682, 0, 0.984, '#surprising', '#admirable', 0.733, 'potato', 'chips', 'murphy', 'spud', 'tater']
senticnet['white_powder'] = [0, 0.879, 0, 0.702, '#interesting', '#admirable', 0.527, 'white_substance', 'food_ingredient', 'white_grain', 'make_up_powder', 'granulate']
senticnet['white_rabbit'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'polar_bear', 'baji', 'arctic_fox', 'white_animal', 'fuzzy_animal']
senticnet['white_rice'] = [-0.023, 0.083, 0.039, 0.049, '#interesting', '#admirable', 0.023, 'grain', 'wheat', 'oat', 'rye', 'rice']
senticnet['white_sheep'] = [-0.799, 0, 0.667, -0.668, '#sad', '#disgusting', -0.711, 'argali', 'argal', 'urial', 'wild_sheep', 'mountain_sheep']
senticnet['white_sheet'] = [0, -0.03, 0.079, -0.039, '#angry', '#disgusting', -0.029, 'make_tree', 'thin_wood', 'wood_product', 'sheet', 'peace']
senticnet['white_soft'] = [0.203, 0.077, 0, 0.189, '#joyful', '#admirable', 0.156, 'soft', 'skin', 'striped', 'waterproof', 'fuzzy']
senticnet['white_stuff'] = [0.044, 0, 0.04, 0.101, '#joyful', '#admirable', 0.035, 'tasty', 'white_color', 'fluid', 'flavor', 'crystalline_solid']
senticnet['white_substance'] = [0, 0.883, 0, 0.757, '#interesting', '#admirable', 0.547, 'white_powder', 'white', 'granulate', 'smelly', 'food_flavor']
senticnet['white_swan'] = [0.284, 0.208, -0.097, 0.196, '#joyful', '#interesting', 0.197, 'glaucous_gull', 'dove', 'egret', 'white_bird', 'eismowe']
senticnet['white_tooth'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'teeth_whitening', 'smile', 'clean_teeth', 'beautiful_smile', 'dentist']
senticnet['white_water'] = [0.055, 0, 0.036, 0.144, '#joyful', '#admirable', 0.054, 'white_stuff', 'wet_cold', 'white_color', 'ice_crystal', 'white']
senticnet['whiteboard'] = [0.044, -0.026, 0, 0, '#joyful', '#surprising', 0.023, 'sheet_paper', 'piece_of_paper', 'staple_remover', 'board', 'paperwork']
senticnet['whited_sepulcher'] = [0.978, -0.991, 0, 0.69, '#joyful', '#surprising', 0.886, 'pretender', 'phony', 'phoney', 'hypocrite', 'dissembler']
senticnet['whiteness'] = [0, 0, 0, 0.092, '#admirable', '#admirable', 0.031, 'sun_cover', 'crystal_clear', 'water_sky', 'block_sun', 'weather_forecast']
senticnet['whitey'] = [-0.934, 0, 0.77, -0.792, '#sad', '#disgusting', -0.832, 'caucasian', 'honky', 'honkey', 'honkie', 'mortal']
senticnet['whitlowwort'] = [-0.725, 0, 0.64, -0.585, '#sad', '#angry', -0.65, 'pearlwort', 'pearlweed', 'flora', 'rupturewort', 'groundcover']
senticnet['whittle'] = [0, -0.098, 0, 0, '#surprising', '#surprising', 0.033, 'price_product', 'fillet_fish', 'photography', 'demo', 'pottery']
senticnet['whole'] = [0.94, 0.835, 0, 0, '#joyful', '#interesting', 0.592, 'unhurt', 'unscathed', 'hale', 'unharmed', 'unit']
senticnet['whole_grain'] = [0.061, 0.093, 0.037, 0.114, '#interesting', '#admirable', 0.077, 'cereal_grain', 'food_ingredient', 'staple_food', 'starchy_food', 'food_grain']
senticnet['whole_kit_and_caboodle'] = [0.639, -0.827, 0, 0.997, '#surprising', '#admirable', 0.821, 'completeness', 'work', 'whole_shebang', 'entireness', 'kit_and_caboodle']
senticnet['whole_shebang'] = [0.639, -0.827, 0, 0.997, '#surprising', '#admirable', 0.821, 'completeness', 'work', 'entireness', 'whole_kit_and_caboodle', 'kit_and_caboodle']
senticnet['whole_step'] = [-0.652, 0, 0.681, -0.943, '#angry', '#disgusting', -0.759, 'tone', 'whole_tone', 'step', 'musical_interval', 'semitone']
senticnet['whole_tone'] = [-0.652, 0, 0.681, -0.943, '#angry', '#disgusting', -0.759, 'tone', 'musical_interval', 'step', 'whole_step', 'semitone']
senticnet['wholesale_price_index'] = [0.538, -0.802, 0, 0.517, '#joyful', '#surprising', 0.619, 'indicator', 'retail_price_index', 'producer_price_index', 'price_index', 'consumer_price_index']
senticnet['wholesome'] = [0.656, -0.731, 0, 0.736, '#surprising', '#admirable', 0.708, 'good_for_you', 'salubrious', 'healthy', 'solid', 'alimentary']
senticnet['whoop'] = [0.041, 0, 0, 0.064, '#joyful', '#admirable', 0.035, 'squeak', 'clang', 'musical_note', 'bad_music', 'roar']
senticnet['whoopee'] = [-0.702, 0, 0.704, -0.552, '#sad', '#angry', -0.653, 'revel', 'merrymaking', 'jollification', 'binge', 'riot']
senticnet['whopping'] = [0, 0, -0.976, -0.792, '#scared', '#disgusting', -0.589, 'sock', 'bop', 'whack', 'wham', 'wallop']
senticnet['whore'] = [-0.838, 0, 0.885, -0.52, '#sad', '#angry', -0.748, 'slattern', 'camp_follower', 'call_girl', 'comfort_woman', 'ianfu']
senticnet['whorehouse'] = [0.023, 0.085, 0, 0, '#joyful', '#interesting', 0.036, 'public_place', 'front_build', 'rest_area', 'memorial', 'nuclear_power_plant']
senticnet['wick'] = [0.994, 0.76, 0, 0, '#joyful', '#interesting', 0.585, 'cake', 'brownie', 'mousse', 'custard', 'birthday_cake']
senticnet['wicked'] = [0, 0, 0.916, -0.829, '#angry', '#disgusting', -0.582, 'loathsome', 'churn_up', 'loathly', 'distastefully', 'sickeningly']
senticnet['wickedness'] = [0.952, -0.78, 0, 0.56, '#joyful', '#surprising', 0.764, 'sexual_immorality', 'foul_play', 'irreverence', 'deviltry', 'devilry']
senticnet['wicker'] = [-0.119, 0, -0.162, 0.062, '#sad', '#scared', -0.073, 'tile_floor', 'cunt', 'miss', 'short_form', 'happy_together']
senticnet['wicket'] = [0, 0, 0, 0.19, '#admirable', '#admirable', 0.063, 'file_bill', 'record', 'webpage', 'note', 'store_record']
senticnet['wide'] = [0, 0.08, 0.068, 0.213, '#interesting', '#admirable', 0.075, 'large', 'big', 'really_big', 'huge', 'width']
senticnet['wide_of_mark'] = [-0.515, 0, 0.502, -0.58, '#sad', '#disgusting', -0.532, 'wrong', 'incorrect', 'inaccurate', 'unfaithful', 'faulty']
senticnet['wide_open'] = [0, 0.088, 0.022, 0.098, '#interesting', '#admirable', 0.055, 'open_area', 'outer', 'around_earth', 'star_planet', 'nothingness']
senticnet['wide_street'] = [0, 0.088, 0.022, 0.098, '#interesting', '#admirable', 0.055, 'street', 'wide', 'country_road', 'freeway', 'highway']
senticnet['widen'] = [-0.023, 0.167, -0.045, 0.259, '#interesting', '#admirable', 0.119, 'grow_long', 'elongate', 'rubbery', 'elasticity', 'make_big']
senticnet['widowed'] = [-0.73, 0, 0.729, -0.981, '#sad', '#disgusting', -0.813, 'unwed', 'unwedded', 'divorced', 'mateless', 'unmarried']
senticnet['widowhood'] = [-0.641, 0, 0.752, -0.681, '#angry', '#disgusting', -0.691, 'marital_status', 'marriage', 'matrimony', 'union', 'spousal_relationship']
senticnet['width'] = [0, 0.939, 0, 0.984, '#interesting', '#admirable', 0.641, 'dimension', 'size', 'mass_measure', 'length_dimension', 'gauge']
senticnet['wiener_dog'] = [-0.06, 0, -0.046, 0, '#sad', '#scared', -0.035, 'small_dog', 'red-bellied_black_snake', 'eastern_brown_snake', 'many_humans', 'puma']
senticnet['wife'] = [0.709, 0, 0, 0.939, '#joyful', '#admirable', 0.549, 'husband', 'mum', 'parent', 'mother', 'woman_child']
senticnet['wifi'] = [-0.096, -0.036, 0.061, 0, '#sad', '#angry', -0.04, 'bad_reception', 'bad_connection', 'internet', 'phone_call', 'underground']
senticnet['wig'] = [-0.848, 0, 0.633, -0.539, '#sad', '#angry', -0.673, 'grizzle', 'postiche', 'horsehair_wig', 'periwig', 'peruke']
senticnet['wigging'] = [-0.99, 0, 0.709, -0.602, '#sad', '#angry', -0.767, 'reprimand', 'chiding', 'rebuke', 'reproof', 'reproval']
senticnet['wiggle'] = [0, 0.703, 0, 0.887, '#interesting', '#admirable', 0.53, 'wrap_around', 'shrug', 'shake', 'rub', 'push']
senticnet['wiggly'] = [0, 0, -0.877, -0.723, '#scared', '#disgusting', -0.533, 'writhing', 'wriggly', 'sinuate', 'wriggling', 'sinuous']
senticnet['wild'] = [-0.808, 0, 0.856, -0.843, '#angry', '#disgusting', -0.836, 'primitiveness', 'crudeness', 'crudity', 'primitivism', 'rudeness']
senticnet['wild_animal'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'bear', 'need_protect', 'lion', 'nature', 'wild_life']
senticnet['wild_bird'] = [0, -0.06, 0.022, 0.054, '#surprising', '#admirable', 0.031, 'hold_egg', 'baby_bird', 'hatch', 'lay_egg', 'bird_home']
senticnet['wild_cat'] = [0, 0, 0.029, -0.052, '#angry', '#disgusting', -0.027, 'large_cat', 'big_cat', 'carnivore', 'feline', 'canine']
senticnet['wild_flower'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'tough', 'wild_plant', 'vitality', 'bionergy', 'nature']
senticnet['wild_ginger'] = [-0.524, 0, 0.527, -0.782, '#angry', '#disgusting', -0.611, 'herb', 'black_snakeroot', 'heartleaf', 'asarabacca', 'herbaceous_plant']
senticnet['wild_goat'] = [-0.51, 0, 0.845, -0.993, '#angry', '#disgusting', -0.783, 'bezoar_goat', 'pasang', 'markhor', 'goat', 'ibex']
senticnet['wild_horse'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'lost_pet', 'find_animal', 'animal', 'doghouse', 'find_dog']
senticnet['wild_licorice'] = [-0.943, 0, 0.608, -0.954, '#sad', '#disgusting', -0.835, 'milk_vetch', 'wild_liquorice', 'alpine_milk_vetch', 'purple_milk_vetch', 'woody_plant']
senticnet['wild_life'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'bear', 'need_protect', 'lion', 'nature', 'wild_animal']
senticnet['wild_liquorice'] = [-0.943, 0, 0.608, -0.954, '#sad', '#disgusting', -0.835, 'wild_licorice', 'milk_vetch', 'alpine_milk_vetch', 'purple_milk_vetch', 'woody_plant']
senticnet['wild_marjoram'] = [0.632, -0.933, 0, 0.928, '#surprising', '#admirable', 0.831, 'herb', 'oregano', 'marjoram', 'pot_marjoram', 'origanum']
senticnet['wild_nature'] = [0, 0.903, 0, 0.903, '#interesting', '#admirable', 0.602, 'plato', 'brown_hair', 'natural_world', 'feature', 'stick_out']
senticnet['wild_parsnip'] = [0.861, -0.879, 0, 0.597, '#joyful', '#surprising', 0.779, 'herb', 'cultivated_parsnip', 'pastinaca_sativa', 'madnep', 'herbaceous_plant']
senticnet['wild_plant'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'tough', 'wild_flower', 'vitality', 'bionergy', 'nature']
senticnet['wild_sheep'] = [-0.799, 0, 0.667, -0.668, '#sad', '#disgusting', -0.711, 'argali', 'argal', 'urial', 'white_sheep', 'mountain_sheep']
senticnet['wild_wolf'] = [0.731, 0, 0, 0.843, '#joyful', '#admirable', 0.525, 'breed', 'domestic_pet', 'smart_dog', 'big_dog', 'fierce']
senticnet['wildcat'] = [-0.904, 0, 0.569, -0.967, '#sad', '#disgusting', -0.813, 'unauthorized', 'unofficial', 'informal', 'loose', 'drumhead']
senticnet['wildcat_strike'] = [-0.772, 0, 0.505, -0.503, '#sad', '#angry', -0.593, 'work_stoppage', 'sympathy_strike', 'sympathetic_strike', 'walkout', 'job_action']
senticnet['wildflower'] = [-0.793, 0, 0.837, -0.886, '#angry', '#disgusting', -0.839, 'sunray', 'wilding', 'sagebrush_buttercup', 'pasqueflower', 'pasque_flower']
senticnet['wildfowl'] = [0.567, -0.935, 0, 0.659, '#surprising', '#admirable', 0.72, 'bird', 'grouse', 'quail', 'partridge', 'pheasant']
senticnet['wilding'] = [0.771, -0.638, 0, 0.875, '#joyful', '#admirable', 0.761, 'plant', 'flora', 'wildflower', 'wild_flower', 'plant_life']
senticnet['wildness'] = [-0.562, 0, 0.746, -0.627, '#angry', '#disgusting', -0.645, 'contrariness', 'fractiousness', 'intractability', 'intractableness', 'perversity']
senticnet['wile'] = [-0.97, 0, 0.713, -0.651, '#sad', '#angry', -0.778, 'humbug', 'deceit', 'deception', 'fraudulence', 'dissembling']
senticnet['will_power'] = [0.937, -0.799, 0, 0.634, '#joyful', '#surprising', 0.79, 'resoluteness', 'firmness_of_purpose', 'firmness', 'resolve', 'presence_of_mind']
senticnet['willful_neglect'] = [-0.936, 0, 0.624, -0.599, '#sad', '#angry', -0.72, 'carelessness', 'neglectfulness', 'laxness', 'laxity', 'remissness']
senticnet['willfulness'] = [-0.922, 0, 0.682, -0.632, '#sad', '#angry', -0.745, 'contrariness', 'wildness', 'intractability', 'intractableness', 'perversity']
senticnet['willing'] = [0.729, 0.974, 0, 0, '#joyful', '#interesting', 0.568, 'unforced', 'leave', 'bequeath', 'volition', 'uncoerced']
senticnet['willingness'] = [0.877, -0.513, 0, 0.624, '#joyful', '#admirable', 0.671, 'readiness', 'eagerness', 'zeal', 'disposition', 'openness']
senticnet['willpower'] = [0.804, -0.672, 0, 0.658, '#joyful', '#surprising', 0.711, 'resoluteness', 'firmness_of_purpose', 'firmness', 'resolve', 'presence_of_mind']
senticnet['wilt'] = [-0.087, 0, 0, 0, '#sad', '#sad', -0.029, 'step_aside', 'meander', 'step_out', 'open_mailbox', 'stay_still']
senticnet['wily'] = [0, -0.939, 0, 0.789, '#surprising', '#admirable', 0.576, 'dodgy', 'guileful', 'crafty', 'foxy', 'cunning']
senticnet['wimp'] = [-0.918, 0, 0.681, -0.818, '#sad', '#disgusting', -0.806, 'chicken', 'softy', 'softie', 'crybaby', 'doormat']
senticnet['win'] = [0.856, 0.928, 0, 0.828, '#joyful', '#interesting', 0.871, 'win_game', 'winner_loser', 'win_battle', 'lose_game', 'keep_score']
senticnet['win_award'] = [0.91, 0.939, 0, 0.883, '#joyful', '#interesting', 0.911, 'lend_hand', 'lower_expectation', 'receive_email', 'erase_blackboard', 'laugh_oneself']
senticnet['win_baseball_game'] = [0.742, 0.995, 0, 0.747, '#interesting', '#admirable', 0.828, 'score_homer', 'score_home_run', 'reach_advantage', 'jump_chance', 'compete_against']
senticnet['win_battle'] = [0.972, 0.975, 0, 0.901, '#joyful', '#interesting', 0.949, 'accomplish_mission', 'victory', 'win_enemy', 'win_war', 'score_point']
senticnet['win_bet'] = [0.821, 0.766, 0, 0.968, '#joyful', '#admirable', 0.852, 'enjoy_challenge', 'victorious', 'occupy_mind', 'like_challenge', 'win_money']
senticnet['win_case'] = [-0.19, 0, 0, -0.161, '#sad', '#disgusting', -0.117, 'hire_attorney', 'hire_lawyer', 'flip_coin', 'cancel', 'cost_fortune']
senticnet['win_championship'] = [0.05, -0.059, 0, 0.054, '#surprising', '#admirable', 0.054, 'happiness', 'win_game', 'skate_ice', 'win', 'pride']
senticnet['win_competition'] = [0.877, 0.832, 0, 0.791, '#joyful', '#interesting', 0.833, 'enjoy_challenge', 'engage_sport', 'enjoy_game', 'skate_ice', 'play_team_sport']
senticnet['win_contest'] = [0.992, 0.728, 0, 0.834, '#joyful', '#admirable', 0.851, 'smoke_pot', 'laugh_lot', 'experience_pleasure', 'go_date', 'enjoy_performance']
senticnet['win_election'] = [0, 0.794, 0, 0.791, '#interesting', '#admirable', 0.528, 'say_welcome', 'show_empathy', 'warm_feeling', 'certainty', 'show_love']
senticnet['win_enemy'] = [0.972, 0.975, 0, 0.901, '#joyful', '#interesting', 0.949, 'accomplish_mission', 'victory', 'win_battle', 'win_war', 'score_point']
senticnet['win_game'] = [0.742, 0.995, 0, 0.747, '#interesting', '#admirable', 0.828, 'excellent', 'win_match', 'prize', 'challenge', 'elation']
senticnet['win_hand'] = [0.087, 0.153, -0.089, 0.164, '#interesting', '#admirable', 0.105, 'choose_game', 'inflation', 'waffle', 'poker', 'get_hired']
senticnet['win_loose'] = [0.847, 0.806, 0, 0, '#joyful', '#interesting', 0.551, 'sore_butt', 'keep_score', 'roll_dice', 'win_game', 'play_game']
senticnet['win_lottery'] = [0.975, 0.994, 0, 0.74, '#joyful', '#interesting', 0.903, 'celebrate_anniversary', 'birthday', 'say_thank_you', 'new_baby', 'gift']
senticnet['win_marathon'] = [0.856, 0.928, 0, 0.828, '#joyful', '#interesting', 0.871, 'sport', 'endurance_exercise', 'champion', 'strong_endurance', 'competition']
senticnet['win_match'] = [0.742, 0.995, 0, 0.747, '#interesting', '#admirable', 0.828, 'excellent', 'win_game', 'prize', 'challenge', 'elation']
senticnet['win_medal'] = [0.878, 0.863, 0, 0.708, '#joyful', '#interesting', 0.816, 'tiredness', 'sore_knee', 'fatigue', 'run_out_breath', 'exhaustion']
senticnet['win_money'] = [0.096, -0.103, 0.138, -0.175, '#angry', '#disgusting', -0.038, 'gamble_money', 'funny_friend', 'winner_loser', 'like_compete', 'fun']
senticnet['win_prize'] = [0.743, 0.794, 0, 0.959, '#interesting', '#admirable', 0.832, 'perspiration', 'get_tired', 'burn_calorie', 'sweat_lot', 'extreme_elation']
senticnet['win_race'] = [0.856, 0.928, 0, 0.828, '#joyful', '#interesting', 0.871, 'champion', 'competition', 'motocyele_race', 'professional', 'award']
senticnet['win_sport'] = [0.896, 0.887, 0, 0.719, '#joyful', '#interesting', 0.834, 'exercise_dog', 'become_physically_fit', 'enjoy_outdoors', 'exercise', 'use_energy']
senticnet['win_sport_event'] = [0.896, 0.887, 0, 0.719, '#joyful', '#interesting', 0.834, 'play_team', 'bounce_up_down', 'win_game', 'go_game', 'delight_audience']
senticnet['win_trophy'] = [0.816, 0.756, 0, 0.747, '#joyful', '#interesting', 0.773, 'teamwork', 'bird_watch', 'win_hand', 'beat_opponent', 'roll_dice']
senticnet['win_videogame'] = [0.347, 0.348, -0.133, 0.394, '#interesting', '#admirable', 0.319, 'score_touchdown', 'score_goal', 'score_point', 'play_hard', 'athletic']
senticnet['win_war'] = [0.887, 0.877, 0, 0, '#joyful', '#interesting', 0.588, 'win', 'win_battle', 'ready_troop', 'high_skill', 'gain_territory']
senticnet['win_win_situation'] = [0.847, 0.806, 0, 0, '#joyful', '#interesting', 0.551, 'mutual_benefit', 'agreement', 'win_game', 'convenience', 'win']
senticnet['wind'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'breeze', 'windmill', 'wind_energy', 'wind_turbine', 'windy']
senticnet['wind_down'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'stop_work', 'take_nap', 'sit_back_relax', 'calm_down', 'breadeeply']
senticnet['wind_energy'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'breeze', 'windmill', 'wind', 'wind_turbine', 'windy']
senticnet['wind_generation'] = [-0.791, 0, 0.997, -0.687, '#sad', '#angry', -0.825, 'energy', 'solar_energy', 'solar_power', 'alternative_energy', 'wind_power']
senticnet['wind_power'] = [-0.791, 0, 0.997, -0.687, '#sad', '#angry', -0.825, 'energy', 'solar_energy', 'solar_power', 'wind_generation', 'alternative_energy']
senticnet['wind_scale'] = [-0.662, 0, 0.918, -0.96, '#angry', '#disgusting', -0.847, 'measure', 'standard', 'wage_scale', 'wage_schedule', 'graduated_table']
senticnet['wind_thread'] = [-0.067, 0, 0, -0.06, '#sad', '#disgusting', -0.042, 'sewn', 'clothes_repair', 'use_needle', 'sew_term', 'mend']
senticnet['wind_toy'] = [-0.11, -0.021, 0, -0.065, '#sad', '#disgusting', -0.051, 'drive_crazy', 'experience_pleasure', 'shut_down', 'experience_joy', 'visit_parent']
senticnet['wind_turbine'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'breeze', 'windmill', 'wind_energy', 'wind', 'windy']
senticnet['wind_up'] = [0.045, -0.067, 0.038, 0, '#joyful', '#surprising', 0.025, 'roll_away', 'enjoy_game', 'enjoy_challenge', 'win_competition', 'skate_ice']
senticnet['wind_watch'] = [-0.117, 0, -0.067, 0, '#sad', '#scared', -0.061, 'drink_espresso', 'bicycle_across_town', 'mine_diamond', 'age_gracefully', 'dig_grave']
senticnet['wind_water'] = [0, 0.118, -0.088, 0.186, '#interesting', '#admirable', 0.072, 'water_formation', 'water_relate', 'water_form', 'water_stream', 'water_splash']
senticnet['windburn'] = [-0.859, 0, 0.676, -0.827, '#sad', '#disgusting', -0.787, 'erythroderma', 'erythema_nodosum', 'erythema_multiforme', 'erythema', 'hickey']
senticnet['windfall_profit'] = [-0.938, 0, 0.771, -0.685, '#sad', '#angry', -0.798, 'profit', 'net_income', 'net', 'net_profit', 'lucre']
senticnet['windiness'] = [-0.699, 0, 0.835, -0.562, '#sad', '#angry', -0.699, 'roughness', 'inclemency', 'bad_weather', 'inclementness', 'storminess']
senticnet['winding'] = [0, 0, -0.872, -0.717, '#scared', '#disgusting', -0.53, 'twist', 'weave', 'wander', 'meander', 'thread']
senticnet['window_cover'] = [0, 0.087, 0, 0.132, '#interesting', '#admirable', 0.073, 'see_through', 'shutter', 'see_thru', 'look_through', 'contact_lens']
senticnet['window_door'] = [0.033, 0, 0, 0.081, '#joyful', '#admirable', 0.038, 'window', 'frame', 'door_lock', 'wall', 'doorway']
senticnet['window_shop'] = [-0.053, 0, 0.015, -0.043, '#sad', '#disgusting', -0.037, 'buy_goods', 'spend_much_money', 'buy_stuff', 'check_price', 'acquire_goods']
senticnet['window_treatment'] = [0.036, 0.072, 0, 0.097, '#interesting', '#admirable', 0.068, 'frame', 'ornamentation', 'mural', 'painting', 'artwork']
senticnet['windshield'] = [0, -0.033, 0, 0.064, '#surprising', '#admirable', 0.032, 'bumper', 'fan_belt', 'brake_pedal', 'emergency_brake', 'clutch']
senticnet['windsurf'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'go_sea', 'take_cruise', 'kayak', 'go_dive', 'sailboat']
senticnet['windy'] = [0, -0.019, 0.048, -0.058, '#angry', '#disgusting', -0.029, 'mild', 'breeze', 'tropical_storm', 'wind', 'air_movement']
senticnet['wine'] = [0.161, -0.146, 0.031, -0.104, '#joyful', '#surprising', 0.057, 'alcohol', 'reception', 'champagne', 'beer', 'case_beer']
senticnet['wine_bottle'] = [-0.032, 0.071, 0, 0.063, '#interesting', '#admirable', 0.034, 'wine_storage', 'drink_wine', 'wine_glass', 'wine_opener', 'water_bottle']
senticnet['wine_glass'] = [0.833, 0, 0, 0.899, '#joyful', '#admirable', 0.577, 'drink_wine', 'wine_opener', 'good_wine', 'made_of_glass', 'wine_bottle']
senticnet['wine_maker'] = [-0.96, 0, 0.651, -0.655, '#sad', '#disgusting', -0.755, 'still', 'plant', 'winery', 'mint', 'bottling_plant']
senticnet['wine_opener'] = [0.108, 0.145, -0.091, 0, '#joyful', '#interesting', 0.054, 'steak', 'dinner', 'special_occasion', 'decanter', 'drink_wine']
senticnet['wine_storage'] = [-0.032, 0.071, 0, 0.063, '#interesting', '#admirable', 0.034, 'wine_bottle', 'drink_wine', 'wine_glass', 'wine_opener', 'water_bottle']
senticnet['wing'] = [0.02, 0.078, 0, 0, '#joyful', '#interesting', 0.033, 'beak', 'bird_mouth', 'many_feathers_beak', 'many_feathers', 'water_bird']
senticnet['wing_animal'] = [-0.031, -0.02, 0.043, -0.042, '#angry', '#disgusting', -0.032, 'wing_insect', 'flap_wing', 'avian', 'aviation', 'wing_creature']
senticnet['wing_creature'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'wing_insect', 'flap_wing', 'bird', 'wing_animal', 'aviation']
senticnet['wing_insect'] = [-0.035, -0.042, 0.085, -0.046, '#angry', '#disgusting', -0.041, 'aviation', 'bothersome_insect', 'flap_wing', 'six_legs', 'soar']
senticnet['wink'] = [0, 0.971, 0, 0.759, '#interesting', '#admirable', 0.577, 'ask_name', 'point_finger', 'nod', 'sexual_attraction', 'unscrew']
senticnet['winner'] = [0.887, 0.711, 0, 0.806, '#joyful', '#admirable', 0.801, 'best', 'count', 'assurance', 'excess', 'ordinal']
senticnet['winner_loser'] = [0.111, -0.093, 0.143, -0.229, '#angry', '#disgusting', -0.056, 'win_money', 'win', 'silly', 'win_game', 'fun']
senticnet['wino'] = [0.797, -0.955, 0, 0.921, '#surprising', '#admirable', 0.891, 'lush', 'alcoholic', 'alky', 'dipsomaniac', 'boozer']
senticnet['winter'] = [0.082, -0.018, 0, 0, '#joyful', '#surprising', 0.033, 'snow_fall', 'snowy', 'cold_weather', 'winter_time', 'summer_winter']
senticnet['winter_boot'] = [0, 0.77, 0, 0.947, '#interesting', '#admirable', 0.572, 'foot', 'warm_foot', 'footwear', 'winter_sock', 'warm']
senticnet['winter_clothes'] = [0.053, -0.013, -0.052, 0.121, '#joyful', '#admirable', 0.045, 'coat', 'keep_warm', 'thick_jacket', 'sweater', 'winter_glove']
senticnet['winter_fall'] = [0.128, -0.031, 0.014, 0.103, '#joyful', '#admirable', 0.083, 'fall_spring', 'ice_rain', 'climate', 'cold', 'rain_wind']
senticnet['winter_glove'] = [0.053, -0.013, -0.052, 0.121, '#joyful', '#admirable', 0.045, 'coat', 'keep_warm', 'thick_jacket', 'sweater', 'winter_clothes']
senticnet['winter_savory'] = [0.91, -0.993, 0, 0.779, '#joyful', '#surprising', 0.894, 'herb', 'delicious', 'summer_savory', 'eat_well', 'savory']
senticnet['winter_sock'] = [0, 0.804, 0, 0.794, '#interesting', '#admirable', 0.533, 'foot', 'winter_boot', 'footwear', 'warm_foot', 'warm']
senticnet['winter_sport'] = [0.964, 0.852, 0, 0, '#joyful', '#interesting', 0.605, 'good_sport', 'recreational', 'recreational_activity', 'competitive', 'fun_exercise']
senticnet['winter_squash'] = [-0.562, 0, 0.696, -0.964, '#angry', '#disgusting', -0.741, 'squash', 'acorn_squash', 'hubbard_squash', 'turban_squash', 'butternut_squash']
senticnet['winter_squash_plant'] = [-0.759, 0, 0.934, -0.914, '#angry', '#disgusting', -0.869, 'squash', 'acorn_squash', 'hubbard_squash', 'turban_squash', 'butternut_squash']
senticnet['winter_time'] = [0.15, -0.025, 0, 0, '#joyful', '#surprising', 0.058, 'winter', 'cold_weather', 'fall_spring', 'season_year', 'snowy']
senticnet['wipe'] = [0.02, 0, 0, 0.104, '#joyful', '#admirable', 0.041, 'wipe_mouth', 'wipe_up_spill', 'sanitary', 'clean_mess', 'tidy_up']
senticnet['wipe_away_tear'] = [0.166, 0.123, -0.114, 0, '#joyful', '#interesting', 0.058, 'wet_oneself', 'laugh_out_loud', 'make_others_laugh', 'start_laugh', 'wave_hand']
senticnet['wipe_dirty'] = [0.159, 0.068, -0.079, 0.118, '#joyful', '#admirable', 0.089, 'clean_mouth', 'wet_tissue', 'refresh', 'wipe_mouth_napkin', 'paper_towel']
senticnet['wipe_eye'] = [0.835, 0.757, 0, 0, '#joyful', '#interesting', 0.531, 'rub_eye', 'open_window', 'wipe', 'buy_stock', 'reflect']
senticnet['wipe_foot'] = [-0.077, 0, 0, 0, '#sad', '#sad', -0.026, 'yoga', 'exercise_much', 'rest_tire', 'practice_yoga', 'use_body']
senticnet['wipe_mouth'] = [0.159, 0.068, -0.079, 0.118, '#joyful', '#admirable', 0.089, 'wipe', 'clean_mouth', 'napkin', 'clean_mess', 'tidy_up']
senticnet['wipe_mouth_napkin'] = [0.159, 0.068, -0.079, 0.118, '#joyful', '#admirable', 0.089, 'clean_mouth', 'wet_tissue', 'refresh', 'wipe_dirty', 'paper_towel']
senticnet['wipe_nose'] = [-0.151, 0.074, -0.159, -0.094, '#sad', '#scared', -0.11, 'cry_help', 'go_scuba_dive', 'end_life', 'blow_nose', 'take_aspirin']
senticnet['wipe_tear'] = [0, 0.101, 0.039, 0.054, '#interesting', '#admirable', 0.039, 'smear', 'cheer_up', 'use_tissue', 'push_button', 'scratch_back']
senticnet['wipe_up'] = [0.72, -0.764, 0, 0.695, '#joyful', '#surprising', 0.726, 'mop_up', 'blot', 'suck_up', 'mop', 'sponge_up']
senticnet['wipe_up_spill'] = [0, 0.935, 0, 0.898, '#interesting', '#admirable', 0.611, 'personal_cleanliness', 'cleanness', 'clean', 'look_bad', 'clean_carpet']
senticnet['wire'] = [0, -0.122, 0.011, 0.089, '#surprising', '#admirable', 0.067, 'cord', 'telegraph', 'cellular_phone', 'email', 'message']
senticnet['wiretap'] = [-0.536, 0, 0.884, -0.724, '#angry', '#disgusting', -0.715, 'bug', 'tap', 'eavesdrop', 'intercept', 'listen']
senticnet['wirework'] = [0.619, -0.774, 0, 0.834, '#surprising', '#admirable', 0.742, 'net', 'network', 'mesh', 'meshing', 'meshwork']
senticnet['wisdom'] = [0.798, 0.754, 0, 0.779, '#joyful', '#admirable', 0.777, 'know_world', 'find_out_truth', 'knowledge', 'know_how', 'experience']
senticnet['wise'] = [0.8, 0.891, 0, 0.827, '#interesting', '#admirable', 0.839, 'smartness', 'inventor', 'wisdom', 'intelligence', 'know_truth']
senticnet['wiseacre'] = [-0.955, 0, 0.772, -0.894, '#sad', '#disgusting', -0.874, 'smart_aleck', 'upstart', 'snob', 'snooty', 'unpleasant_person']
senticnet['wish'] = [0.868, 0.756, 0, 0, '#joyful', '#interesting', 0.541, 'demand', 'yearn', 'certainty', 'hope', 'give_help']
senticnet['wish_dead'] = [-0.972, 0, 0.787, -0.996, '#sad', '#disgusting', -0.918, 'kill_person', 'kill', 'weapon', 'hysteria', 'murder']
senticnet['wish_entertain'] = [0.786, 0.989, 0, 0, '#joyful', '#interesting', 0.592, 'idolize_actor', 'entertain_oneself', 'film_critic', 'enjoyment', 'enjoy_play']
senticnet['wish_learn'] = [0.97, 0, 0.773, 0.878, '#joyful', '#admirable', 0.358, 'get_knowledge', 'become_intelligent', 'expand_knowledge', 'gain_knowledge', 'learn_universe']
senticnet['wish_not'] = [-0.423, 0, -0.286, -0.084, '#sad', '#scared', -0.264, 'become_sad', 'investigate_fact', 'desire_travel', 'make_sad', 'think_logically']
senticnet['wish_success'] = [0.867, 0, 0, 0, '#joyful', '#joyful', 0.289, 'expectation', 'optimism', 'win_game', 'hope_win', 'dream_victory']
senticnet['wish_well'] = [0.891, 0.9, 0, 0.943, '#interesting', '#admirable', 0.911, 'candy_machine', 'load_dock', 'lock_box', 'incinerator', 'water_fountain']
senticnet['wishful'] = [0.783, -0.514, 0, 0.584, '#joyful', '#admirable', 0.627, 'appetent', 'avid', 'thirsty', 'devouring', 'envious']
senticnet['wishful_thinker'] = [-0.644, 0, 0.524, -0.598, '#sad', '#disgusting', -0.589, 'bum', 'dreamer', 'stargazer', 'escapist', 'daydreamer']
senticnet['wispy'] = [0, 0, -0.782, -0.753, '#scared', '#disgusting', -0.512, 'dim', 'vague', 'wisplike', 'shadowy', 'faint']
senticnet['wistful'] = [0, 0.859, 0, 0.773, '#interesting', '#admirable', 0.544, 'pondering', 'ruminative', 'broody', 'contemplative', 'meditative']
senticnet['wit'] = [0.58, 0.651, -0.264, 0.308, '#joyful', '#interesting', 0.425, 'act_out', 'laugh_loudly', 'say_love', 'sense_of_humor', 'listen_story']
senticnet['witch_brew'] = [-0.917, 0, 0.869, -0.777, '#sad', '#angry', -0.854, 'motley', 'mixture', 'variety', 'assortment', 'mixed_bag']
senticnet['witch_broth'] = [-0.992, 0, 0.766, -0.744, '#sad', '#angry', -0.834, 'motley', 'mixture', 'variety', 'assortment', 'mixed_bag']
senticnet['witch_doctor'] = [0.594, -0.549, 0, 0.518, '#joyful', '#surprising', 0.554, 'exorcist', 'enchanter', 'magus', 'sorceress', 'necromancer']
senticnet['witchcraft'] = [-0.845, 0, 0.833, -0.663, '#sad', '#angry', -0.78, 'magic', 'thaumaturgy', 'enchantment', 'black_art', 'witchery']
senticnet['witchery'] = [-0.845, 0, 0.833, -0.663, '#sad', '#angry', -0.78, 'magic', 'thaumaturgy', 'enchantment', 'witchcraft', 'black_art']
senticnet['with_person'] = [0, 0, 0, 0.924, '#admirable', '#admirable', 0.308, 'poker_hand', 'game_part', 'commence', 'together', 'group']
senticnet['withdraw'] = [-0.631, 0, 0.872, -0.883, '#angry', '#disgusting', -0.795, 'retreat', 'retrograde', 'back_up', 'move', 'give_up']
senticnet['withdrawal'] = [-0.93, 0, 0, -0.726, '#sad', '#disgusting', -0.552, 'aloofness', 'detachment', 'indifferently', 'indifferent', 'apathetic']
senticnet['withdrawn'] = [-0.981, 0, 0.582, -0.561, '#sad', '#angry', -0.708, 'asocial', 'antisocial', 'lonely', 'unsocial', 'solitary']
senticnet['wither'] = [-0.345, 0.092, -0.36, 0.079, '#sad', '#scared', -0.178, 'garden_plant', 'lifeless', 'undesirable', 'kill_self', 'need_water']
senticnet['withering'] = [-0.78, 0, 0.764, -0.886, '#sad', '#disgusting', -0.81, 'weakening', 'downfall', 'atrophy', 'fading', 'attenuation']
senticnet['without_end_product'] = [-0.973, 0, 0.009, -0.929, '#sad', '#disgusting', -0.637, 'come_to_nothing', 'waste_of_time', 'failure', 'unsuccessful', 'no_result']
senticnet['without_human_habitation'] = [-0.764, 0, 0, -0.768, '#sad', '#disgusting', -0.511, 'cold_weather', 'snow', 'ice', 'cold', 'arctic']
senticnet['without_light'] = [-0.722, 0, -0.894, 0, '#sad', '#scared', -0.539, 'dim', 'darkness', 'after_sundown', 'unseen', 'blurred_vision']
senticnet['without_money'] = [0.84, 0.729, 0, 0, '#joyful', '#interesting', 0.523, 'lose_credibility', 'broke', 'abuse', 'feel_stressed', 'go_bankrupt']
senticnet['without_notice'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'without_warning', 'unexpected', 'unpredicted', 'unanticipated', 'out_of_blue']
senticnet['without_space'] = [0, 0, -0.818, -0.716, '#scared', '#disgusting', -0.511, 'breathless', 'tight', 'narrow', 'immovale', 'small']
senticnet['without_support'] = [0, 0, -0.943, -0.77, '#scared', '#disgusting', -0.571, 'break', 'broken_shelf', 'damage', 'need_fix', 'destroy']
senticnet['without_warning'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'out_of_blue', 'unexpected', 'unpredicted', 'unanticipated', 'without_notice']
senticnet['withstand'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'brave_out', 'endure', 'weather', 'undamaged', 'stand_firm']
senticnet['witness'] = [-0.05, 0.173, -0.094, 0.111, '#interesting', '#admirable', 0.047, 'trial', 'call_witness', 'judgment', 'become_lawyer', 'justice']
senticnet['witting'] = [-0.067, -0.011, 0, -0.064, '#sad', '#disgusting', -0.04, 'make_paper_airplane', 'write_note', 'story', 'continue_story', 'make_mark_paper']
senticnet['witty_remark'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'banter', 'cross_talking', 'swordplay', 'wordplay', 'jester']
senticnet['wizard'] = [0, -0.004, 0, 0.097, '#surprising', '#admirable', 0.034, 'heavy_paper', 'lightweight_metal', 'rusty_metal', 'metal_type', 'soft_metal']
senticnet['woe'] = [-0.968, 0, -0.747, -0.913, '#sad', '#disgusting', -0.876, 'heartbreak', 'repent', 'repentance', 'guilty_conscience', 'penitentially']
senticnet['woebegone'] = [-0.906, 0.138, -0.63, 0.071, '#sad', '#scared', -0.442, 'woeful', 'execrable', 'deplorable', 'woefulness', 'plaintiveness']
senticnet['woeful'] = [-0.906, 0.138, -0.63, 0.071, '#sad', '#scared', -0.442, 'execrable', 'deplorable', 'woebegone', 'woefulness', 'plaintiveness']
senticnet['woefully'] = [-0.883, 0.174, -0.597, 0, '#sad', '#scared', -0.435, 'lamentably', 'deplorably', 'bereaved', 'bereft', 'grief-stricken']
senticnet['woefulness'] = [-0.906, 0.138, -0.63, 0.071, '#sad', '#scared', -0.442, 'woeful', 'execrable', 'deplorable', 'woebegone', 'plaintiveness']
senticnet['wolf'] = [-0.033, 0, -0.088, 0, '#sad', '#scared', -0.04, 'lion', 'leopard', 'mountain_lion', 'bobcat', 'craven']
senticnet['woman'] = [0.632, 0.645, -0.24, 0.295, '#joyful', '#interesting', 0.444, 'human_being', 'bloke', 'adult', 'male', 'sexy_woman']
senticnet['woman_breast'] = [-0.031, -0.013, 0.058, 0, '#sad', '#angry', -0.025, 'dartboard', 'loop', 'disk', 'puck', 'disc']
senticnet['woman_child'] = [0, 0.929, 0, 0.874, '#interesting', '#admirable', 0.601, 'care_giver', 'mom', 'family_relation', 'kin', 'female_parent']
senticnet['woman_closet'] = [-0.027, -0.071, 0.079, -0.08, '#angry', '#disgusting', -0.038, 'clothes_store', 'store_shoes', 'fabric_store', 'keep_clothes', 'fabric_shop']
senticnet['woman_cloth'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'formal_cloth', 'woman_garment', 'woman_suit', 'woman_pant', 'woman_shirt']
senticnet['woman_clothes'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'woman_dress', 'woman_garment', 'stocking', 'woman_culotte', 'tutu']
senticnet['woman_culotte'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'woman_dress', 'woman_garment', 'stocking', 'woman_clothes', 'tutu']
senticnet['woman_dress'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'woman_garment', 'skirt', 'female_cloth', 'frilly_design', 'robe']
senticnet['woman_garment'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'formal_cloth', 'woman_cloth', 'woman_suit', 'woman_pant', 'woman_shirt']
senticnet['woman_of_street'] = [-0.552, 0, 0.577, -0.891, '#angry', '#disgusting', -0.673, 'slattern', 'camp_follower', 'call_girl', 'comfort_woman', 'ianfu']
senticnet['woman_pant'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'formal_cloth', 'woman_cloth', 'woman_suit', 'woman_garment', 'woman_shirt']
senticnet['woman_purse'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'purse', 'pocket', 'wallet', 'man_purse', 'bag']
senticnet['woman_shirt'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'formal_cloth', 'woman_cloth', 'woman_suit', 'woman_pant', 'woman_garment']
senticnet['woman_suit'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'formal_cloth', 'woman_cloth', 'woman_garment', 'woman_pant', 'woman_shirt']
senticnet['womanish'] = [-0.63, 0, 0.986, -0.946, '#angry', '#disgusting', -0.854, 'unmanful', 'effeminate', 'emasculate', 'cissy', 'sissified']
senticnet['womb'] = [0.159, 0.068, -0.079, 0.118, '#joyful', '#admirable', 0.089, 'stomach', 'uterus', 'pregnant', 'lap', 'gravid']
senticnet['wonder'] = [0.957, 0.894, 0, 0.921, '#joyful', '#admirable', 0.924, 'awe', 'amazement', 'astonishment', 'perplex', 'marvel']
senticnet['wonder_child'] = [0.664, -0.661, 0, 0.987, '#joyful', '#admirable', 0.771, 'child', 'small_fry', 'tyke', 'tike', 'kid']
senticnet['wonderful'] = [0.722, 0.798, 0, 0.896, '#interesting', '#admirable', 0.805, 'fantastic', 'amaze', 'grand', 'pose', 'marvel']
senticnet['wonderful_feeling'] = [0.536, 0.44, -0.39, 0.41, '#joyful', '#interesting', 0.332, 'good_emotion', 'affection', 'pleasant_emotion', 'happy_emotion', 'ecstatic']
senticnet['wonderful_place_visit'] = [0.029, 0.1, 0.027, 0.054, '#interesting', '#admirable', 0.052, 'institution', 'bachelor_degree', 'place_learn', 'educational_facility', 'educational_institution']
senticnet['wonderfully'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'terrific', 'wondrously', 'tremendous', 'marvelous', 'wondrous']
senticnet['wonderland'] = [0.703, -0.579, 0, 0.918, '#joyful', '#admirable', 0.733, 'land', 'dry_land', 'earth', 'ground', 'solid_ground']
senticnet['wonderment'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'terrific', 'wondrously', 'tremendous', 'marvelous', 'wondrous']
senticnet['wondrous'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'terrific', 'wondrously', 'tremendous', 'amazing', 'marvelous']
senticnet['wondrously'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'terrific', 'tremendous', 'marvelous', 'wondrous', 'amazing']
senticnet['wood'] = [0, -0.026, 0.085, -0.094, '#angry', '#disgusting', -0.051, 'tree_dead_tree', 'forest', 'sideways', 'deforestation', 'dead_tree']
senticnet['wood_bird'] = [0.062, 0.072, 0, 0, '#joyful', '#interesting', 0.045, 'sculptor', 'carving', 'wood_duck', 'art_craft', 'wood_product']
senticnet['wood_board'] = [-0.062, -0.021, 0.049, 0, '#sad', '#angry', -0.03, 'wooden_board', 'hardwood', 'piece_of_wood', 'build_ground', 'cover_ground']
senticnet['wood_burn'] = [0, 0, -0.089, 0, '#scared', '#scared', -0.03, 'rapid_oxidation', 'heat_light', 'chemical_reaction', 'huge_fire', 'blow_out']
senticnet['wood_chopstick'] = [0, 0.928, 0, 0.969, '#interesting', '#admirable', 0.632, 'tree', 'rectangular', 'pencil', 'wooden_chair', 'wood_product']
senticnet['wood_duck'] = [0.062, 0.072, 0, 0, '#joyful', '#interesting', 0.045, 'sculptor', 'carving', 'wood_bird', 'art_craft', 'wood_product']
senticnet['wood_ibis'] = [0.797, -0.719, 0, 0.736, '#joyful', '#admirable', 0.751, 'ibis', 'wood_stork', 'sacred_ibis', 'wading_bird', 'wader']
senticnet['wood_material'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'comfortable', 'wooden_chair', 'tile_floor', 'wooden_bed', 'wooden_floor']
senticnet['wood_meadowgrass'] = [-0.766, 0, 0.513, -0.722, '#sad', '#disgusting', -0.667, 'foxtail', 'foxtail_grass', 'manna_grass', 'sweet_grass', 'meadow_grass']
senticnet['wood_panel'] = [0, 0.087, 0, 0.118, '#interesting', '#admirable', 0.068, 'wooden_structure', 'entrance_room', 'build_open', 'home_entrance', 'hinge']
senticnet['wood_plank'] = [0, 0.087, 0, 0.118, '#interesting', '#admirable', 0.068, 'wood_structure', 'wooden_house', 'wood_panel', 'plank', 'wood']
senticnet['wood_product'] = [0, 0.9, 0, 0.99, '#interesting', '#admirable', 0.63, 'tree', 'rectangular', 'pencil', 'wooden_chair', 'wood_chopstick']
senticnet['wood_pulp'] = [0.024, -0.046, 0, 0, '#joyful', '#surprising', 0.023, 'stump', 'plank', 'timber', 'paper', 'mahogany']
senticnet['wood_sage'] = [-0.565, 0, 0.91, -0.809, '#angry', '#disgusting', -0.761, 'subshrub', 'suffrutex', 'germander', 'wall_germander', 'cat_thyme']
senticnet['wood_stork'] = [0.797, -0.719, 0, 0.736, '#joyful', '#admirable', 0.751, 'wood_ibis', 'ibis', 'sacred_ibis', 'wading_bird', 'wader']
senticnet['wood_structure'] = [0, 0.132, 0, 0.09, '#interesting', '#admirable', 0.074, 'wooden_house', 'wooden', 'religious_significance', 'wood_panel', 'wood']
senticnet['wood_worktop'] = [0.025, 0.084, 0, 0.062, '#interesting', '#admirable', 0.057, 'kitchen_worktop', 'worktop', 'surface', 'work', 'work_surface']
senticnet['wooded'] = [-0.863, 0, 0.665, -0.616, '#sad', '#angry', -0.715, 'brambly', 'braky', 'rushy', 'scrubby', 'forested']
senticnet['wooden'] = [0, 0.927, 0, 0.945, '#interesting', '#admirable', 0.624, 'wooden_board', 'make_wood', 'wooden_box', 'wooden_floor', 'long_wood']
senticnet['wooden_bed'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'comfortable', 'wooden_chair', 'tile_floor', 'wooden_floor', 'wood_material']
senticnet['wooden_board'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'wooden_floor', 'plank', 'wooden_table', 'hardwood', 'cover_ground']
senticnet['wooden_box'] = [-0.121, 0.074, -0.125, -0.052, '#sad', '#scared', -0.075, 'bury_dead', 'in_person', 'death_place', 'corpse', 'morgue']
senticnet['wooden_chair'] = [0, -0.122, 0, 0, '#surprising', '#surprising', 0.041, 'rest', 'bench_sit', 'park', 'garden', 'outdoor']
senticnet['wooden_duck'] = [0.775, 0, 0, 0.879, '#joyful', '#admirable', 0.551, 'chainsaw', 'angle_grinder', 'sword', 'cannon', 'handgun']
senticnet['wooden_floor'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'comfortable', 'wooden_chair', 'tile_floor', 'wooden_bed', 'wood_material']
senticnet['wooden_house'] = [0, 0.087, 0, 0.118, '#interesting', '#admirable', 0.068, 'wood_structure', 'wood_plank', 'wood_panel', 'plank', 'wood']
senticnet['wooden_leg'] = [-0.189, -0.121, 0.049, -0.247, '#sad', '#disgusting', -0.121, 'tree_trunk', 'plank', 'artificial_leg', 'hardwood', 'tree_wood']
senticnet['wooden_rod'] = [0.86, 0.827, 0, 0, '#joyful', '#interesting', 0.562, 'adhere', 'hockey_equipment', 'cue', 'glue', 'brick']
senticnet['wooden_spoon'] = [0.763, 0.779, 0, 0, '#joyful', '#interesting', 0.514, 'teaspoon', 'kitchen_tool', 'spoon', 'wooden_tool', 'wood']
senticnet['wooden_stick'] = [0.071, -0.103, 0.063, 0.134, '#surprising', '#admirable', 0.082, 'big_stick', 'nocturnal', 'long_stick', 'tree_animal', 'same_again']
senticnet['wooden_structure'] = [0, 0.082, 0.013, 0.132, '#interesting', '#admirable', 0.067, 'wood_panel', 'entrance_room', 'threshold', 'house_open', 'rectangular_shape']
senticnet['wooden_table'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'wooden_floor', 'plank', 'wooden_board', 'hardwood', 'cover_ground']
senticnet['wooden_tool'] = [0.772, 0.838, 0, 0, '#joyful', '#interesting', 0.537, 'teaspoon', 'kitchen_tool', 'spoon', 'wooden_spoon', 'wood']
senticnet['woodland'] = [-0.739, 0, 0.59, -0.893, '#sad', '#disgusting', -0.741, 'desert', 'grassland', 'forest', 'biome', 'timberland']
senticnet['woodland_animal'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'life', 'bear', 'woodland_creature', 'deer', 'woodland_mushroom']
senticnet['woodland_creature'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'life', 'bear', 'woodland_animal', 'deer', 'woodland_mushroom']
senticnet['woodland_mushroom'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'life', 'bear', 'woodland_animal', 'deer', 'woodland_creature']
senticnet['woodman'] = [-0.232, -0.095, 0, -0.24, '#sad', '#disgusting', -0.126, 'fallen_tree', 'dangerous', 'kill_forest', 'wood', 'accident']
senticnet['woodwind_instrument'] = [0.821, -0.531, 0, 0.785, '#joyful', '#admirable', 0.712, 'fife', 'nose_flute', 'piccolo', 'woodwind', 'flute']
senticnet['woodworking'] = [0.035, 0.083, 0, 0.128, '#interesting', '#admirable', 0.082, 'build_boat', 'animation', 'bring_food', 'repair', 'clean_often']
senticnet['woodworking_tool'] = [-0.063, 0, 0.026, 0, '#sad', '#angry', -0.03, 'woodworking', 'tool', 'garden_tool', 'garden_implement', 'useful_tool']
senticnet['woody_plant'] = [-0.943, 0, 0.608, -0.954, '#sad', '#disgusting', -0.835, 'wild_licorice', 'wild_liquorice', 'alpine_milk_vetch', 'purple_milk_vetch', 'milk_vetch']
senticnet['wool'] = [-0.035, 0, 0, -0.045, '#sad', '#disgusting', -0.027, 'cotton', 'silk', 'asbestos', 'cotton_boll', 'velvet']
senticnet['woolgather'] = [-0.809, 0, 0.945, -0.639, '#sad', '#angry', -0.798, 'fancy', 'foresee', 'fantasy', 'daydream', 'conceive_of']
senticnet['woolgatherer'] = [-0.698, 0, 0.878, -0.628, '#sad', '#angry', -0.735, 'bum', 'dreamer', 'stargazer', 'escapist', 'wishful_thinker']
senticnet['woolly_animal'] = [-0.036, 0.11, 0, 0.177, '#interesting', '#admirable', 0.084, 'white_animal', 'graceful', 'animal_furry', 'hairy', 'fuzzy_animal']
senticnet['word'] = [0, 0.711, 0, 0.91, '#interesting', '#admirable', 0.54, 'part_of_speech', 'character', 'message', 'announcement', 'alphabet']
senticnet['word_deafness'] = [-0.82, 0, 0.953, -0.878, '#angry', '#disgusting', -0.884, 'auditory_aphasia', 'acoustic_aphasia', 'aphasia', 'nominal_aphasia', 'anomic_aphasia']
senticnet['word_frequently_misspell'] = [0, -0.022, 0.073, -0.088, '#angry', '#disgusting', -0.046, 'chop_wood', 'slash', 'cover_wound', 'cut', 'lacerate']
senticnet['word_of_advice'] = [-0.662, 0, 0.809, -0.655, '#sad', '#angry', -0.709, 'example', 'deterrent_example', 'lesson', 'object_lesson', 'advice']
senticnet['word_order'] = [0.888, -0.815, 0, 0.617, '#joyful', '#surprising', 0.773, 'bacteria_order', 'ordering', 'genetic_code', 'genome', 'series']
senticnet['word_process'] = [0, 0.764, 0, 0.96, '#interesting', '#admirable', 0.575, 'process_data', 'organize_information', 'surf_internet', 'learn_skill', 'write_email']
senticnet['word_salad'] = [0.813, -0.66, 0, 0.65, '#joyful', '#surprising', 0.708, 'nonsense', 'meaninglessness', 'unintelligibility', 'bunk', 'nonsensicality']
senticnet['wordiness'] = [-0.651, 0, 0.892, -0.773, '#angry', '#disgusting', -0.772, 'verboseness', 'verbosity', 'turgidity', 'turgidness', 'flatulence']
senticnet['wording'] = [-0.611, 0, 0.73, -0.858, '#angry', '#disgusting', -0.733, 'diction', 'phrasing', 'verbiage', 'verbalization', 'phraseology']
senticnet['wordplay'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'witty_remark', 'cross_talking', 'sbanter', 'banter', 'jester']
senticnet['work'] = [-0.782, 0, 0.585, -0.631, '#sad', '#disgusting', -0.666, 'still', 'wine_maker', 'winery', 'mint', 'bottling_plant']
senticnet['work_abroad'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'far_from_home', 'work_overseas', 'live_abroad', 'expat', 'abroad']
senticnet['work_area'] = [0, 0.975, 0, 0.805, '#interesting', '#admirable', 0.593, 'office_space', 'place_work', 'workplace', 'work_surface', 'office']
senticnet['work_box_office'] = [0.229, 0.127, 0, 0, '#joyful', '#interesting', 0.119, 'return_work', 'get_job', 'begin_work', 'get_salary', 'go_to_work']
senticnet['work_break'] = [0.158, 0.125, -0.045, 0.15, '#joyful', '#admirable', 0.129, 'coffee_break', 'inactivity', 'take_break', 'middle_day', 'rest_night']
senticnet['work_car'] = [0, 0, 0, 0.076, '#admirable', '#admirable', 0.025, 'work_oneself', 'public_transportation', 'stay_sober', 'find_job', 'settle']
senticnet['work_day'] = [-0.143, -0.101, 0.019, -0.151, '#sad', '#disgusting', -0.071, 'lack_energy', 'feel_tired', 'exhaustion', 'get_tired', 'sleep_pill']
senticnet['work_done'] = [-0.044, 0.15, -0.069, 0.077, '#interesting', '#admirable', 0.038, 'support_family', 'provide_service', 'earn_money', 'need_earn_money', 'get_job_done']
senticnet['work_for_money'] = [-0.052, 0.24, -0.084, 0.12, '#interesting', '#admirable', 0.075, 'give_money', 'receive_money', 'compensation', 'earn_income', 'job_pay']
senticnet['work_force'] = [0.814, -0.878, 0, 0.918, '#surprising', '#admirable', 0.87, 'ship_company', 'company', 'full_complement', 'workforce', 'manpower']
senticnet['work_group'] = [0.056, 0.107, 0, 0.156, '#interesting', '#admirable', 0.106, 'partnership', 'business_firm', 'business_group', 'large_business', 'business_organization']
senticnet['work_hard'] = [0.056, 0.107, 0, 0.156, '#interesting', '#admirable', 0.106, 'increase_efficiency', 'earn_paycheck', 'receive_paycheck', 'finish_work', 'earn_money']
senticnet['work_home'] = [-0.029, 0.127, -0.064, 0.092, '#interesting', '#admirable', 0.042, 'shoe_horse', 'speak_english', 'mine_diamond', 'bicycle_across_town', 'age_gracefully']
senticnet['work_in_garden'] = [-0.044, 0.15, -0.069, 0.077, '#interesting', '#admirable', 0.038, 'green_thumb', 'prune', 'water', 'sow', 'rake']
senticnet['work_much'] = [-0.247, -0.073, 0, -0.247, '#sad', '#disgusting', -0.14, 'stress', 'stressful_job', 'dig_ground', 'hate_boss', 'work_hard']
senticnet['work_office'] = [0.96, 0.8, 0, 0, '#joyful', '#interesting', 0.587, 'find_book_library', 'charge_credit_card', 'sell_car', 'price_goods', 'point_out']
senticnet['work_oneself'] = [0, 0.082, 0, 0, '#interesting', '#interesting', 0.027, 'find_job', 'job', 'work_out', 'settle', 'receive_paycheck']
senticnet['work_out'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'top_model', 'exercise', 'eat_properly', 'fitness', 'go_gym']
senticnet['work_overseas'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'far_from_home', 'work_abroad', 'live_abroad', 'expat', 'abroad']
senticnet['work_overtime'] = [-0.255, 0, -0.074, -0.2, '#sad', '#disgusting', -0.176, 'become_fatigued', 'muscle_ache', 'stress', 'feel_exhausted', 'get_done']
senticnet['work_person'] = [0, 0.092, 0, 0.096, '#interesting', '#admirable', 0.063, 'blue_collar', 'laborer', 'worker', 'occupation', 'employment']
senticnet['work_pile_up'] = [0.919, 0.779, 0, 0, '#joyful', '#interesting', 0.566, 'snowed_in', 'miss_work', 'restless', 'feel_little_tired', 'take_nap']
senticnet['work_restaurant'] = [0.025, 0.084, 0, 0.062, '#interesting', '#admirable', 0.057, 'seat_customer', 'serve', 'chore', 'cook_breakfast', 'take_order']
senticnet['work_stoppage'] = [-0.772, 0, 0.505, -0.503, '#sad', '#angry', -0.593, 'wildcat_strike', 'sympathy_strike', 'sympathetic_strike', 'walkout', 'job_action']
senticnet['work_surface'] = [0.025, 0.084, 0, 0.062, '#interesting', '#admirable', 0.057, 'kitchen_worktop', 'worktop', 'surface', 'work', 'wood_worktop']
senticnet['work_team'] = [-0.086, 0, 0, 0, '#sad', '#sad', -0.029, 'floss_tooth', 'dress_oneself', 'arrive_work', 'set_clock', 'market_product']
senticnet['work_time'] = [0.769, -0.614, 0, 0.746, '#joyful', '#admirable', 0.71, 'day', 'period', 'hours', 'face_time', 'workweek']
senticnet['work_to_earn_money'] = [0, 0.146, 0, 0, '#interesting', '#interesting', 0.049, 'life-long_mate', 'volume_control', 'belly_button', 'money_wallet', 'two_ears']
senticnet['work_together'] = [0.705, 0.805, 0, 0, '#joyful', '#interesting', 0.503, 'masturbation', 'intercourse', 'fuck', 'masturbate', 'anarchy']
senticnet['work_up_sweat'] = [0.806, 0.886, 0, 0, '#joyful', '#interesting', 0.564, 'stiffness', 'sweaty', 'get_tired', 'cramp', 'knee_injury']
senticnet['work_well'] = [0, -0.008, 0, 0.069, '#surprising', '#admirable', 0.026, 'machine_transportation', 'car_part', 'car_engine', 'motor_vehicle', 'mode_transportation']
senticnet['workaholic'] = [0.981, 0.707, 0, 0, '#joyful', '#interesting', 0.563, 'celebrate_anniversary', 'shed_tear', 'bring_happiness', 'say_thank_you', 'cat_purr']
senticnet['worker'] = [0.03, 0.09, -0.056, 0.062, '#interesting', '#admirable', 0.042, 'laborer', 'occupation', 'profession', 'work_person', 'career']
senticnet['workhouse'] = [0.051, 0.126, -0.074, 0.164, '#interesting', '#admirable', 0.089, 'edifice', 'palace', 'high_rise', 'current', 'bell_tower']
senticnet['working_girl'] = [-0.972, 0, 0.8, -0.844, '#sad', '#disgusting', -0.872, 'miss', 'girl', 'worker', 'missy', 'young_lady']
senticnet['workman'] = [0, 0, 0, -0.074, '#disgusting', '#disgusting', -0.025, 'army_man', 'army_person', 'sailor', 'man', 'fighter']
senticnet['workmanship'] = [0.876, -0.762, 0, 0.963, '#joyful', '#admirable', 0.867, 'housecraft', 'tradecraft', 'watercraft', 'acquirement', 'skill']
senticnet['workout'] = [-0.062, 0, -0.059, 0, '#sad', '#scared', -0.04, 'go_gym', 'join_gym', 'check_doctor', 'lift_weight', 'eat_balance_diet']
senticnet['workplace'] = [0.032, 0.11, 0, 0.105, '#interesting', '#admirable', 0.082, 'work', 'place_work', 'work_area', 'disorganize', 'employment']
senticnet['world'] = [-0.731, 0, 0.884, -0.601, '#sad', '#angry', -0.739, 'natural_order', 'universe', 'existence', 'creation', 'cosmos']
senticnet['world-weariness'] = [-0.778, 0.27, -0.457, -0.046, '#sad', '#scared', -0.337, 'world-weary', 'bored', 'weltschmerz', 'depressed', 'downcast']
senticnet['world-weary'] = [-0.778, 0.27, -0.457, -0.046, '#sad', '#scared', -0.337, 'bored', 'world-weariness', 'weltschmerz', 'depressed', 'downcast']
senticnet['world_domination'] = [-0.705, 0, 0.925, 0, '#sad', '#angry', -0.543, 'dictatorship', 'dictator', 'colony', 'world_war', 'oppression']
senticnet['world_event'] = [0.915, 0, 0.724, 0.952, '#joyful', '#admirable', 0.381, 'influence_worldwide', 'celebrate', 'olympic_game', 'international_affair', 'magnificent']
senticnet['world_hunger'] = [-0.079, -0.069, 0.013, -0.143, '#sad', '#disgusting', -0.055, 'weight_gain', 'clog_artery', 'salivate', 'no_long_hungry', 'taste_flavor']
senticnet['world_peace'] = [0.838, 0.707, 0, 0.904, '#joyful', '#admirable', 0.816, 'love_parent', 'strong_relationship', 'run_business', 'complement', 'good_fortune']
senticnet['world_religion'] = [0, 0.29, 0, 0.263, '#interesting', '#admirable', 0.184, 'religion', 'prayer', 'philosophy', 'religious_purpose', 'gospel']
senticnet['world_war'] = [-0.705, 0, 0.925, 0, '#sad', '#angry', -0.543, 'dictatorship', 'dictator', 'colony', 'world_domination', 'oppression']
senticnet['world_wide'] = [0.021, 0.067, 0, 0, '#joyful', '#interesting', 0.029, 'fish', 'urchin', 'bait', 'land_fish', 'mussel']
senticnet['worldly'] = [0.913, -0.635, 0, 0.961, '#joyful', '#admirable', 0.836, 'materialistic', 'mercenary', 'mundane', 'material', 'economic']
senticnet['worm'] = [0, -0.007, 0.038, -0.037, '#angry', '#disgusting', -0.023, 'earthworm', 'compost', 'fallen_leaf', 'detritus', 'mammoth_ice']
senticnet['worm_intestine'] = [-0.086, -0.06, 0.028, -0.124, '#sad', '#disgusting', -0.059, 'no_hair', 'fur_keep_warm', 'two_ears', 'two_eyes', 'claw']
senticnet['worm_snake'] = [-0.575, 0, 0.571, -0.975, '#sad', '#disgusting', -0.707, 'viper', 'elapid', 'elapid_snake', 'ophidian', 'blind_snake']
senticnet['wormwood'] = [-0.669, 0, 0.811, -0.781, '#angry', '#disgusting', -0.754, 'subshrub', 'suffrutex', 'old_woman', 'mugwort', 'southernwood']
senticnet['worn'] = [-0.843, 0, 0.653, -0.885, '#sad', '#disgusting', -0.794, 'battered', 'woebegone', 'tattered', 'derelict', 'raddled']
senticnet['worn_face'] = [-0.129, 0.082, 0.133, -0.059, '#sad', '#angry', -0.08, 'worn_improve_vision', 'worn_person', 'descriptive', 'cover_body', 'delicate']
senticnet['worn_foot'] = [-0.128, -0.037, 0.046, 0, '#sad', '#angry', -0.046, 'high_heel', 'footwear', 'shoe', 'foot', 'velcro']
senticnet['worn_head'] = [0.179, 0.164, -0.052, 0.163, '#joyful', '#interesting', 0.151, 'top_head', 'cover_hair', 'inside_head', 'head_wear', 'head']
senticnet['worn_improve_vision'] = [-0.115, 0, 0.146, -0.101, '#sad', '#angry', -0.121, 'worn_face', 'worn_person', 'cover_body', 'delicate', 'hang_up_clothes']
senticnet['worn_person'] = [-0.08, 0, 0.072, 0, '#sad', '#angry', -0.051, 'hang_hanger', 'make_out_cloth', 'worn_improve_vision', 'worn_face', 'protect_body']
senticnet['worn_spot'] = [-0.583, 0, 0.561, -0.622, '#sad', '#disgusting', -0.589, 'spot', 'speckle', 'dapple', 'patch', 'fleck']
senticnet['worried'] = [0.956, 0.953, 0, 0, '#joyful', '#interesting', 0.636, 'uneasily', 'anxiously', 'apprehensively', 'anxiousness', 'solicitous']
senticnet['worrier'] = [-0.827, 0, 0.556, -0.867, '#sad', '#disgusting', -0.75, 'killjoy', 'fusspot', 'worrywart', 'unwelcome_person', 'party_pooper']
senticnet['worriment'] = [-0.807, 0, 0.605, -0.764, '#sad', '#disgusting', -0.725, 'difficulty', 'awkwardness', 'flea_bite', 'difficultness', 'cumbersomeness']
senticnet['worrisome'] = [0.743, 0.773, 0, 0, '#joyful', '#interesting', 0.505, 'disquieted', 'distressing', 'disturbing', 'perturbing', 'troubling']
senticnet['worry'] = [-0.871, 0, 0.936, -0.985, '#angry', '#disgusting', -0.931, 'nervousness', 'shame', 'embarrassment', 'panic', 'upset']
senticnet['worry_about'] = [-0.925, 0, 0.116, -0.997, '#sad', '#disgusting', -0.679, 'care', 'anxiety', 'worry', 'fear', 'feel_terrible']
senticnet['worry_about_something'] = [-0.933, 0, 0.582, -0.996, '#sad', '#disgusting', -0.837, 'reply', 'answer', 'question', 'ask', 'response']
senticnet['worrying'] = [0.821, 0.748, 0, 0, '#joyful', '#interesting', 0.523, 'disquieted', 'distressing', 'disturbing', 'perturbing', 'troubling']
senticnet['worryingly'] = [0.756, 0.767, 0, 0, '#joyful', '#interesting', 0.508, 'disquieted', 'distressing', 'disturbing', 'perturbing', 'troubling']
senticnet['worrywart'] = [-0.827, 0, 0.556, -0.867, '#sad', '#disgusting', -0.75, 'worrier', 'fusspot', 'killjoy', 'unwelcome_person', 'party_pooper']
senticnet['worse'] = [-0.089, 0, -0.094, -0.051, '#sad', '#scared', -0.078, 'hard_find', 'bad_quality', 'bad', 'precise', 'awful']
senticnet['worse_economic_condition'] = [-0.975, 0, 0.936, -0.986, '#sad', '#disgusting', -0.966, 'worse', 'minus_sign', 'negative', 'worse_health_condition', 'get_worse']
senticnet['worse_health_condition'] = [-0.975, 0, 0.936, -0.986, '#sad', '#disgusting', -0.966, 'worse', 'minus_sign', 'negative', 'get_worse', 'worse_economic_condition']
senticnet['worsen'] = [-0.743, 0, 0.749, -0.828, '#angry', '#disgusting', -0.773, 'inflame', 'drop_away', 'lose', 'fall_away', 'deteriorate']
senticnet['worsening'] = [-0.699, 0, 0.941, -0.503, '#sad', '#angry', -0.714, 'decline', 'slack', 'slump', 'falloff', 'falling_off']
senticnet['worship'] = [0.265, 0.601, -0.207, 0.373, '#interesting', '#admirable', 0.344, 'hope', 'religious_purpose', 'trust', 'devotion', 'religious']
senticnet['worship_girl'] = [0.193, 0.298, -0.189, 0.369, '#interesting', '#admirable', 0.224, 'love_another_person', 'feel_love', 'care_deeply', 'find_woman', 'pregnant']
senticnet['worship_god'] = [0.817, 0, 0, 0.839, '#joyful', '#admirable', 0.552, 'religious_purpose', 'belief_god', 'prayer', 'pray_god', 'religious']
senticnet['worship_house'] = [0.798, 0.975, 0, 0.755, '#joyful', '#interesting', 0.843, 'church_part', 'worship_place', 'religious_build', 'holy_place', 'place_of_worship']
senticnet['worship_place'] = [0, 0.235, 0.027, 0.247, '#interesting', '#admirable', 0.152, 'worship_house', 'church_part', 'religious_build', 'holy_place', 'place_of_worship']
senticnet['worshiper'] = [0.037, 0.243, 0, 0.207, '#interesting', '#admirable', 0.162, 'believer', 'cleric', 'vicar', 'christian', 'fundamentalist']
senticnet['worshipful'] = [0.524, 0.681, -0.278, 0.281, '#joyful', '#interesting', 0.403, 'adoring', 'devotedness', 'devoted', 'amorousness', 'amorous']
senticnet['worst'] = [-0.125, -0.082, -0.05, -0.263, '#sad', '#disgusting', -0.119, 'car_race', 'mortuary', 'dry_cleaner', 'loose_end', 'death_row']
senticnet['worth'] = [0, 0.249, 0.012, 0.154, '#interesting', '#admirable', 0.13, 'like_cost', 'money_value', 'monetary_value', 'money_amount', 'sticker']
senticnet['worthiness'] = [0.76, -0.958, 0, 0.506, '#joyful', '#surprising', 0.741, 'goodness', 'praiseworthiness', 'laudability', 'laudableness', 'quotability']
senticnet['worthless'] = [-0.784, 0, 0.651, -0.564, '#sad', '#angry', -0.666, 'rubbishy', 'sorry', 'trashy', 'otiose', 'superfluous']
senticnet['worthlessness'] = [-0.771, 0, 0.599, -0.528, '#sad', '#angry', -0.633, 'vanity', 'trashiness', 'damn', 'shoddiness', 'shit']
senticnet['wound'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'gunshot', 'damage', 'vaccination', 'harm', 'fire_bullet']
senticnet['wounded'] = [-0.639, 0, 0.503, -0.736, '#sad', '#disgusting', -0.626, 'injured', 'mangled', 'torn', 'hurt', 'eviscerate']
senticnet['woven'] = [0, -0.043, 0.064, -0.098, '#angry', '#disgusting', -0.04, 'cut_fabric', 'cover_wind', 'braid', 'use_needle', 'seam']
senticnet['woven_cloth'] = [0, 0.081, 0.015, 0.052, '#interesting', '#admirable', 0.039, 'cotton', 'fabric_material', 'sheepskin', 'spin_silk', 'woven_fabric']
senticnet['woven_fabric'] = [0, 0.081, 0.015, 0.052, '#interesting', '#admirable', 0.039, 'cotton', 'fabric_material', 'sheepskin', 'spin_silk', 'woven_cloth']
senticnet['woven_sheepskin'] = [0, 0.081, 0.015, 0.052, '#interesting', '#admirable', 0.039, 'weave_cloth', 'sheepskin_material', 'woven_fabric', 'embroidery', 'cowhide']
senticnet['wow'] = [0, -0.758, 0, 0.934, '#surprising', '#admirable', 0.564, 'suddenly', 'unexpected', 'sudden', 'type_of_party', 'special']
senticnet['wraithlike'] = [-0.961, 0, 0.939, -0.605, '#sad', '#angry', -0.835, 'airy', 'shadowy', 'stringy', 'insubstantial', 'ethereal']
senticnet['wrangle'] = [-0.678, 0, 0.838, -0.735, '#angry', '#disgusting', -0.75, 'altercation', 'fracas', 'difference', 'affray', 'bickering']
senticnet['wrap'] = [0, 0.817, 0, 0.717, '#interesting', '#admirable', 0.511, 'give', 'gift_wrap', 'give_away', 'donate', 'wrap_gift']
senticnet['wrap_around'] = [0.067, 0.088, -0.078, 0.246, '#interesting', '#admirable', 0.108, 'multiple_purposes', 'revolve', 'start_run', 'wiggle', 'twist']
senticnet['wrap_gift'] = [0.915, 0, 0.724, 0.952, '#joyful', '#admirable', 0.381, 'festival', 'give_present', 'birthday', 'celebrate_event', 'wrap_present']
senticnet['wrap_present'] = [0, 0.737, 0, 0.794, '#interesting', '#admirable', 0.51, 'drive_home', 'gift_wrap', 'wrap_gift', 'carry_home', 'use_credit_card']
senticnet['wrap_up'] = [0, 0.106, -0.086, 0.115, '#interesting', '#admirable', 0.045, 'donate', 'gift_wrap', 'donate_charity', 'out_money', 'subscribe_magazine']
senticnet['wrapped_up'] = [0.737, 0.804, 0, 0, '#joyful', '#interesting', 0.514, 'ended', 'completed', 'finish_job', 'complete_job', 'complete_task']
senticnet['wrapper'] = [-0.952, 0, 0, -0.73, '#sad', '#disgusting', -0.561, 'hold_pencil', 'food_scrap', 'paper_product', 'waste_paper', 'tin_can']
senticnet['wrapping_paper'] = [-0.741, 0, 0.907, -0.865, '#angry', '#disgusting', -0.838, 'gift_wrap', 'kraft', 'kraft_paper', 'butcher_paper', 'paper']
senticnet['wrath'] = [-0.737, 0, 0.899, 0, '#sad', '#angry', -0.545, 'temper', 'madness', 'scorn', 'despise', 'disgust']
senticnet['wrathful'] = [-0.113, 0.112, 0.674, -0.66, '#angry', '#disgusting', -0.445, 'wrathfully', 'wrothful', 'wroth', 'lividly', 'lividity']
senticnet['wrathfully'] = [-0.113, 0.112, 0.674, -0.66, '#angry', '#disgusting', -0.445, 'wrathful', 'wrothful', 'wroth', 'lividly', 'lividity']
senticnet['wreck'] = [-0.103, -0.017, -0.091, -0.107, '#sad', '#disgusting', -0.095, 'broken_bone', 'tear_apart', 'smash', 'damage', 'painful_injury']
senticnet['wrecked'] = [-0.622, 0, 0.863, -0.991, '#angry', '#disgusting', -0.825, 'spoilt', 'destroyed', 'impoverished', 'blighted', 'extinguished']
senticnet['wrecker'] = [-0.846, 0, 0.96, -0.91, '#angry', '#disgusting', -0.905, 'housewrecker', 'housebreaker', 'knacker', 'laborer', 'manual_laborer']
senticnet['wren'] = [-0.109, 0, -0.09, 0, '#sad', '#scared', -0.066, 'quail', 'chicken_egg', 'sparrow', 'chicken', 'stork']
senticnet['wrench'] = [-0.837, 0, 0.509, -0.84, '#sad', '#disgusting', -0.729, 'sprain', 'injury', 'harm', 'hurt', 'trauma']
senticnet['wrestler'] = [0.848, 0.78, 0, 0, '#joyful', '#interesting', 0.543, 'several_types', 'put_mask', 'suspect', 'gas_stove', 'wrestling']
senticnet['wretch'] = [-0.515, 0, 0.571, -0.593, '#angry', '#disgusting', -0.56, 'scapegrace', 'black_sheep', 'degenerate', 'miscreant', 'pervert']
senticnet['wretched'] = [-0.841, 0.221, -0.542, 0, '#sad', '#scared', -0.387, 'dolefully', 'sorrowfully', 'doleful', 'sadly', 'ruefulness']
senticnet['wring_out'] = [-0.919, 0, 0.656, -0.813, '#sad', '#disgusting', -0.796, 'withdraw', 'squeeze_out', 'take', 'rip_out', 'demodulate']
senticnet['wringing'] = [-0.089, 0, -0.153, -0.206, '#scared', '#disgusting', -0.149, 'ask_money', 'exaction', 'extortion', 'intimidate', 'psychological_pressure']
senticnet['wrinkle'] = [-0.505, 0, 0.883, -0.683, '#angry', '#disgusting', -0.69, 'depression', 'impression', 'line_of_fate', 'line_of_destiny', 'line_of_heart']
senticnet['wrinkled_skin'] = [0, 0, 0.883, -0.767, '#angry', '#disgusting', -0.55, 'get_old', 'dry_skin', 'become_wet', 'clothes_shrink', 'wrinkle']
senticnet['wrist'] = [0, 0, -0.066, -0.071, '#scared', '#disgusting', -0.046, 'elbow', 'arm', 'bandit', 'five_fingers', 'bendable']
senticnet['wrist_bone'] = [-0.608, 0, 0.701, -0.723, '#angry', '#disgusting', -0.677, 'lunate_bone', 'semilunar_bone', 'carpal_bone', 'triquetral', 'triquetral_bone']
senticnet['wristwatch'] = [0.795, 0.89, 0, 0, '#joyful', '#interesting', 0.562, 'watch', 'wrist', 'clock', 'accessory', 'pocket_watch']
senticnet['write'] = [0.748, 0.847, 0, 0, '#joyful', '#interesting', 0.532, 'hold_document', 'bereavement_note', 'continue_story', 'make_paper_airplane', 'bereavement']
senticnet['write_assignment'] = [0.022, 0, 0.015, 0.096, '#joyful', '#admirable', 0.034, 'write_book', 'study', 'exam', 'write_paper', 'research']
senticnet['write_back'] = [0, 0.743, 0, 0, '#interesting', '#interesting', 0.248, 'retort', 'answer_back', 'response', 'send_back', 'question_answer']
senticnet['write_book'] = [0, 0.743, 0, 0, '#interesting', '#interesting', 0.248, 'write_novel', 'write_poem', 'write_story', 'write', 'sign_autograph']
senticnet['write_brush'] = [0.021, -0.049, 0.051, -0.094, '#angry', '#disgusting', -0.025, 'mechanical_pencil', 'marker', 'quill_brush', 'pen', 'write_instrument']
senticnet['write_check'] = [0.863, 0.878, 0, 0, '#joyful', '#interesting', 0.58, 'open_wallet', 'take_out_wallet', 'go_bank', 'save_money', 'money_bank']
senticnet['write_code'] = [0, 0.85, 0, 0.847, '#interesting', '#admirable', 0.566, 'learn_program_language', 'learn_computer_language', 'turn_computer_on', 'access_computer', 'a_lot_of_time']
senticnet['write_computer_program'] = [-0.109, 0, 0, -0.089, '#sad', '#disgusting', -0.066, 'master_skill', 'lose_key', 'erase_blackboard', 'wave_hello', 'wrong_another_person']
senticnet['write_date'] = [0.463, 0.561, -0.294, 0.281, '#joyful', '#interesting', 0.337, 'impress_date', 'digitate_date', 'use_computer', 'use_pen', 'date']
senticnet['write_device'] = [0.022, 0, 0.015, 0.096, '#joyful', '#admirable', 0.034, 'write_tool', 'write_implement', 'device', 'equipment', 'write_paper']
senticnet['write_down'] = [0, 0.952, 0, 0.812, '#interesting', '#admirable', 0.588, 'write_down_idea', 'record_story', 'take_note', 'write_word', 'use_pen']
senticnet['write_down_idea'] = [0.971, 0.942, 0, 0, '#joyful', '#interesting', 0.638, 'write_down', 'read_aloud', 'concentrate', 'visualize', 'misspell']
senticnet['write_email'] = [0, 0.783, 0, 0.758, '#interesting', '#admirable', 0.514, 'use_technology', 'use_computer', 'write', 'email', 'surf_internet']
senticnet['write_equipment'] = [0.022, 0, 0.015, 0.096, '#joyful', '#admirable', 0.034, 'write_tool', 'write_instrument', 'equipment', 'write_device', 'write_implement']
senticnet['write_essay'] = [0.832, 0.73, 0, 0, '#joyful', '#interesting', 0.521, 'chew_pencil', 'get_nervous', 'write_word', 'write_down', 'take_note_class']
senticnet['write_friend'] = [0.983, 0, 0, 0.945, '#joyful', '#admirable', 0.643, 'write_novel', 'book_reservation', 'wedge_door_open', 'receive_mail', 'draw_diagram']
senticnet['write_implement'] = [0.022, 0, 0.015, 0.096, '#joyful', '#admirable', 0.034, 'write_tool', 'write_instrument', 'equipment', 'write_device', 'write_equipment']
senticnet['write_instrument'] = [0.022, 0, 0.015, 0.096, '#joyful', '#admirable', 0.034, 'pencil', 'pen', 'highlighter', 'pencil_sharpener', 'marking_pen']
senticnet['write_law'] = [0, 0.794, 0, 0.971, '#interesting', '#admirable', 0.588, 'president', 'chief', 'respect', 'act_wisely', 'major']
senticnet['write_list'] = [-0.051, 0, 0.024, 0, '#sad', '#angry', -0.025, 'decide_buy', 'make_list', 'go_shopping', 'drive_to_store', 'look_price']
senticnet['write_lyric'] = [0.563, 0.781, 0, 0.787, '#interesting', '#admirable', 0.71, 'song_lyric', 'lyrics', 'rhyme', 'stanza', 'refrain']
senticnet['write_material'] = [0.098, 0.078, 0, 0.061, '#joyful', '#interesting', 0.079, 'book_page', 'thin_wood', 'paper', 'write_device', 'book_content']
senticnet['write_message'] = [-0.028, 0.094, 0, 0.097, '#interesting', '#admirable', 0.054, 'write_text', 'find_computer', 'body_language', 'check_spelling', 'put_envelope']
senticnet['write_note'] = [-0.028, 0.094, 0, 0.097, '#interesting', '#admirable', 0.054, 'make_note', 'write', 'take_note', 'note', 'notebook']
senticnet['write_novel'] = [0.022, 0, 0.015, 0.096, '#joyful', '#admirable', 0.034, 'write', 'novel', 'write_poem', 'write_word', 'write_book']
senticnet['write_number'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'use_phone', 'call_number', 'take_number', 'contact', 'add_number']
senticnet['write_on_notebook'] = [-0.028, 0.094, 0, 0.097, '#interesting', '#admirable', 0.054, 'remember_information', 'make_note', 'take_note', 'note', 'notebook']
senticnet['write_paper'] = [0.022, 0, 0.015, 0.096, '#joyful', '#admirable', 0.034, 'write_book', 'study', 'exam', 'write_assignment', 'research']
senticnet['write_poem'] = [0, 0.823, 0, 0.902, '#interesting', '#admirable', 0.575, 'write_book', 'write_story', 'poet', 'good_poem', 'witting']
senticnet['write_poetry'] = [0, 0, 0, 0.077, '#admirable', '#admirable', 0.026, 'write_novel', 'take_message', 'fact_right', 'body_language', 'draw_picture']
senticnet['write_program'] = [0.983, 0, 0, 0.945, '#joyful', '#admirable', 0.643, 'program_computer', 'design_software', 'fix_computer', 'add_up_column_number', 'program']
senticnet['write_report'] = [0, 0, 0, 0.881, '#admirable', '#admirable', 0.294, 'ask_question', 'know_subject', 'tell_information', 'share_opinion', 'research_subject']
senticnet['write_resume'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'look_job', 'change_work', 'certificate', 'go_interview', 'new_job']
senticnet['write_review'] = [0, 0.951, 0, 0.752, '#interesting', '#admirable', 0.568, 'review', 'book', 'read_book', 'review_book', 'analyze_book']
senticnet['write_story'] = [0, 0.96, 0, 0.855, '#interesting', '#admirable', 0.605, 'writer', 'write_book', 'write_poem', 'write_down_idea', 'witty']
senticnet['write_suicide_note'] = [-0.062, -0.02, 0, -0.051, '#sad', '#disgusting', -0.031, 'sign_document', 'make_mark_paper', 'make_paper_airplane', 'write_paper', 'wedge_door_open']
senticnet['write_term_paper'] = [-0.031, 0.086, 0.01, 0.091, '#interesting', '#admirable', 0.045, 'assignment', 'take_exam', 'write_thesis', 'school_test', 'study']
senticnet['write_text'] = [0.608, 0.7, 0, 0.637, '#interesting', '#admirable', 0.648, 'create_document', 'access_internet', 'enter_information', 'write_message', 'type']
senticnet['write_thesis'] = [-0.031, 0.086, 0.01, 0.091, '#interesting', '#admirable', 0.045, 'assignment', 'take_exam', 'write_term_paper', 'school_test', 'study']
senticnet['write_tool'] = [0.022, 0, 0.015, 0.096, '#joyful', '#admirable', 0.034, 'write_equipment', 'write_implement', 'tool', 'write_device', 'write_instrument']
senticnet['write_with_style'] = [0, 0.901, 0, 0.842, '#interesting', '#admirable', 0.581, 'write_book', 'artist', 'publish_book', 'life_style', 'fashion_style']
senticnet['write_word'] = [-0.084, 0, 0.023, -0.063, '#sad', '#disgusting', -0.057, 'draw_picture', 'make_note', 'wedge_door_open', 'write_novel', 'make_mark_paper']
senticnet['writer_cramp'] = [-0.241, 0.113, -0.185, 0, '#sad', '#scared', -0.104, 'hand_cramp', 'use_brain', 'think_story', 'use_mind', 'use_imagination']
senticnet['writhed'] = [-0.93, 0, 0.861, -0.504, '#sad', '#angry', -0.765, 'knotty', 'contorted', 'crooked', 'writhen', 'anfractuous']
senticnet['writhen'] = [-0.93, 0, 0.861, -0.504, '#sad', '#angry', -0.765, 'knotty', 'contorted', 'writhed', 'crooked', 'anfractuous']
senticnet['writhing'] = [0, 0, -0.945, -0.91, '#scared', '#disgusting', -0.618, 'wriggle', 'wrestle', 'squirm', 'worm', 'writhe']
senticnet['writing_paper'] = [0.867, 0.879, 0, 0, '#joyful', '#interesting', 0.582, 'photo_copy', 'color_paper', 'printing_paper', 'note_book', 'white_paper']
senticnet['writing_style'] = [-0.648, 0, 0.784, -0.722, '#angry', '#disgusting', -0.718, 'poetry', 'verse', 'drama', 'prose', 'form']
senticnet['written'] = [0, 0, 0, 0.077, '#admirable', '#admirable', 0.026, 'readable', 'print_medium', 'book_write', 'media', 'make_book']
senticnet['written_communication'] = [0.021, 0.107, 0, 0.156, '#interesting', '#admirable', 0.095, 'correspondence', 'note_down', 'document', 'handwritten', 'communication_method']
senticnet['written_down'] = [-0.072, 0.139, 0.042, 0.117, '#interesting', '#admirable', 0.047, 'documentation', 'paper_write', 'note_down', 'misspell', 'record_information']
senticnet['written_language'] = [0, 0, 0, 0.133, '#admirable', '#admirable', 0.044, 'information_source', 'grammar_part', 'give_info', 'communication_method', 'part_of_speech']
senticnet['written_message'] = [0, 0.098, 0.024, 0.162, '#interesting', '#admirable', 0.079, 'correspondence', 'handwritten', 'musical_symbol', 'written_note', 'written_communication']
senticnet['written_music'] = [0.852, 0.907, 0, 0.805, '#joyful', '#interesting', 0.855, 'tune', 'melody', 'lyric', 'harmony', 'music']
senticnet['written_note'] = [0.075, 0, 0.022, 0.134, '#joyful', '#admirable', 0.062, 'music_part', 'musical_symbol', 'musical_notation', 'correspondence', 'written_message']
senticnet['written_paper'] = [-0.169, 0, 0, 0, '#sad', '#sad', -0.056, 'print_paper', 'lack_of_sleep', 'lose', 'tired', 'tedium']
senticnet['written_programmer'] = [0, 0.889, 0, 0.957, '#interesting', '#admirable', 0.615, 'stuff_use_calculation', 'ridgeback', 'competitive_activity', 'low_blood_pressure', 'minor_planet']
senticnet['written_text'] = [-0.034, 0, -0.049, 0, '#sad', '#scared', -0.028, 'make_book', 'readable', 'essay', 'pencil_mark', 'read_material']
senticnet['written_word'] = [0.144, 0.134, -0.045, 0.238, '#joyful', '#admirable', 0.157, 'cat', 'tabby_cat', 'kitty', 'baby_dog', 'dog']
senticnet['wrong'] = [-0.722, 0, 0.752, -0.815, '#angry', '#disgusting', -0.763, 'wrongdoing', 'jail_time', 'bad_behavior', 'kidnap', 'reprimand']
senticnet['wrong_another_person'] = [-0.763, 0, 0.973, -0.927, '#angry', '#disgusting', -0.888, 'age_gracefully', 'position_furniture', 'speak_english', 'stand_alone', 'erase_blackboard']
senticnet['wrong_answer'] = [-0.941, -0.708, 0.726, 0, '#sad', '#angry', -0.32, 'excuse', 'result', 'problem', 'deliberate', 'get_answer']
senticnet['wrong_food'] = [-0.943, 0, 0.891, -0.939, '#sad', '#disgusting', -0.924, 'peanut', 'seafood', 'cause_allergy', 'sick', 'allergy_symptom']
senticnet['wrong_person'] = [-0.975, 0, 0.893, -0.993, '#sad', '#disgusting', -0.954, 'heart_broken', 'bad_couple', 'fake_love', 'bad_person', 'bad_marriage']
senticnet['wrong_place'] = [0, 0, -0.047, -0.049, '#scared', '#disgusting', -0.032, 'bad_luck', 'wrong', 'hockey_rink', 'cyberspace', 'deli_case']
senticnet['wrongdoing'] = [-0.848, 0, 0.882, -0.829, '#sad', '#angry', -0.853, 'bad_behavior', 'wrong', 'reprimand', 'jail_time', 'unsafe']
senticnet['wrongful_conduct'] = [-0.635, 0, 0.728, -0.588, '#sad', '#angry', -0.65, 'misconduct', 'inroad', 'wrongdoing', 'usurpation', 'actus_reus']
senticnet['wrongness'] = [-0.693, 0, 0.89, -0.988, '#angry', '#disgusting', -0.857, 'evil', 'immorality', 'putrefaction', 'wantonness', 'corruptibility']
senticnet['wroth'] = [-0.113, 0.112, 0.674, -0.66, '#angry', '#disgusting', -0.445, 'wrathfully', 'wrathful', 'wrothful', 'lividly', 'lividity']
senticnet['wrothful'] = [-0.125, 0.107, 0.668, -0.658, '#angry', '#disgusting', -0.448, 'lividity', 'livid', 'lividly', 'wrathfully', 'exasperate']
senticnet['wuss'] = [-0.798, 0, 0.744, -0.989, '#sad', '#disgusting', -0.844, 'chicken', 'softy', 'softie', 'crybaby', 'wimp']
senticnet['www'] = [0.12, 0, 0.032, 0.08, '#joyful', '#admirable', 0.056, 'world_wide', 'web', 'internet', 'ass', 'web_browser']
senticnet['x-ray'] = [0, 0, -0.074, -0.169, '#scared', '#disgusting', -0.081, 'radio_wave', 'sun', 'solar_cell', 'cosmic_ray', 'gamma_ray']
senticnet['x-ray_machine'] = [-0.031, 0, -0.106, -0.221, '#scared', '#disgusting', -0.119, 'syringe', 'latex_glove', 'check_body', 'wait_room', 'novocaine']
senticnet['x_ray'] = [-0.873, -0.794, 0.729, -0.976, '#sad', '#disgusting', -0.595, 'radiation', 'cancer', 'sickness', 'potential_danger', 'electromagnetic_radiation']
senticnet['xenon'] = [-0.575, 0, 0.954, -0.806, '#angry', '#disgusting', -0.778, 'nonmetal', 'transactinide', 'hydrogen', 'atomic_number_1', 'chemical_element']
senticnet['xenophobic'] = [-0.721, 0, -0.825, -0.841, '#scared', '#disgusting', -0.796, 'racism', 'intolerant', 'racist', 'antisemitism', 'nazism']
senticnet['xerostomia'] = [-0.738, 0, 0.931, -0.821, '#angry', '#disgusting', -0.83, 'aridness', 'thirstiness', 'dryness', 'dry_mouth', 'sereness']
senticnet['yacht'] = [-0.095, 0.192, -0.086, 0.106, '#interesting', '#admirable', 0.039, 'ship', 'speed_boat', 'water_vehicle', 'sailboat', 'boat']
senticnet['yardstick'] = [0, 0.851, 0, 0.953, '#interesting', '#admirable', 0.601, 'measure_inch', 'measure_tool', 'measurement_tool', 'measure', 'size_up']
senticnet['yawl'] = [-0.502, 0, 0.611, -0.752, '#angry', '#disgusting', -0.622, 'howl', 'wail', 'ululate', 'roar', 'waul']
senticnet['yawn'] = [-0.1, -0.065, 0, -0.122, '#sad', '#disgusting', -0.052, 'fall_out_bed', 'take_breath', 'shut_off_alarm_clock', 'wind_down', 'put_feet_up']
senticnet['yawning'] = [0, 0, -0.795, -0.773, '#scared', '#disgusting', -0.523, 'oscitancy', 'oscitance', 'gape', 'oscitant', 'drowsy']
senticnet['year'] = [0.037, -0.047, 0, 0, '#joyful', '#surprising', 0.028, 'many_years', 'old', 'teen', 'thirty', 'era']
senticnet['yearly'] = [0, 0, -0.967, -0.871, '#scared', '#disgusting', -0.613, 'every_year', 'yearbook', 'each_year', 'annually', 'annual']
senticnet['yearly_celebration'] = [0.877, 0.952, 0, 0.905, '#interesting', '#admirable', 0.911, 'special_day', 'annual_celebration', 'party_time', 'cake_candle', 'celebrate']
senticnet['yearn'] = [0, 0, 0, 0.864, '#admirable', '#admirable', 0.288, 'want_badly', 'strong_desire', 'ache', 'demand', 'need']
senticnet['yeast'] = [0, 0.823, 0, 0.748, '#interesting', '#admirable', 0.524, 'starchy_food', 'staple_food', 'whole_grain', 'crust', 'basic_food']
senticnet['yell'] = [-0.806, 0, 0, -0.782, '#sad', '#disgusting', -0.529, 'shout', 'yell_loudly', 'scream', 'loud_shout', 'loud_yell']
senticnet['yell_loudly'] = [-0.77, 0, 0, -0.728, '#sad', '#disgusting', -0.499, 'shout', 'yell', 'scream', 'high_volume', 'noise']
senticnet['yelling'] = [-0.96, 0, 0.533, -0.954, '#sad', '#disgusting', -0.816, 'outcry', 'call', 'cry', 'yell', 'shout']
senticnet['yellow'] = [0, 0.19, -0.097, 0.175, '#interesting', '#admirable', 0.089, 'red', 'green_black', 'green_red', 'peelable', 'precious_jewel']
senticnet['yellow_animal'] = [-0.856, 0, 0.749, -0.998, '#sad', '#disgusting', -0.868, 'bird', 'eat_worm', 'farm_bird', 'mistreat', 'biped']
senticnet['yellow_blue'] = [-0.054, 0, 0.031, 0, '#sad', '#angry', -0.028, 'blue_yellow', 'hue', 'violet', 'cool_color', 'tint']
senticnet['yellow_bone_marrow'] = [0.73, -0.726, 0, 0.653, '#joyful', '#surprising', 0.703, 'red_marrow', 'red_bone_marrow', 'yellow_marrow', 'bone_marrow', 'connective_tissue']
senticnet['yellow_card'] = [-0.983, 0, 0.334, -0.914, '#sad', '#disgusting', -0.744, 'punishment', 'fault', 'probabilty_of_losing', 'penalty_shoot', 'red_card']
senticnet['yellow_chestnut_oak'] = [0.776, -0.6, 0, 0.568, '#joyful', '#surprising', 0.648, 'swamp_chestnut_oak', 'chinquapin_oak', 'chinkapin_oak', 'chestnut_oak', 'basket_oak']
senticnet['yellow_color'] = [0, 0.121, 0.041, 0.12, '#interesting', '#admirable', 0.067, 'little_grain', 'nutritious', 'cereal_crop', 'small_grain', 'food_grain']
senticnet['yellow_flower'] = [0, 0.972, 0, 1.0, '#interesting', '#admirable', 0.657, 'flower', 'plant', 'flower_bloom', 'yellow_rose', 'good_smell']
senticnet['yellow_fruit'] = [0.057, 0, 0.038, 0.073, '#joyful', '#admirable', 0.031, 'delicious_fruit', 'small_fruit', 'tree_fruit', 'vine_fruit', 'domesticate_plant']
senticnet['yellow_green'] = [-0.062, 0.081, 0, 0.082, '#interesting', '#admirable', 0.034, 'green_yellow', 'red_orange', 'red_green', 'green_orange', 'red_blue']
senticnet['yellow_hornet'] = [-0.663, 0, 0.946, -0.554, '#sad', '#angry', -0.721, 'hornet', 'yellow_jacket', 'giant_hornet', 'vespid', 'vespid_wasp']
senticnet['yellow_jacket'] = [-0.663, 0, 0.946, -0.554, '#sad', '#angry', -0.721, 'yellow_hornet', 'hornet', 'giant_hornet', 'vespid', 'vespid_wasp']
senticnet['yellow_lady_slipper'] = [0.277, 0.161, 0, 0.337, '#joyful', '#admirable', 0.258, 'moccasin_flower', 'nerveroot', 'showy_lady_slipper', 'ladies_slipper', 'clustered_lady_slipper']
senticnet['yellow_line'] = [0, 0.786, 0, 0.718, '#interesting', '#admirable', 0.501, 'traffic_rule', 'develop_city', 'bicycle_riding', 'drive_car', 'control_road']
senticnet['yellow_marrow'] = [0.73, -0.726, 0, 0.653, '#joyful', '#surprising', 0.703, 'red_marrow', 'red_bone_marrow', 'bone_marrow', 'yellow_bone_marrow', 'connective_tissue']
senticnet['yellow_milkwort'] = [-0.706, 0, 0.769, -0.703, '#sad', '#angry', -0.726, 'subshrub', 'suffrutex', 'senega', 'orange_milkwort', 'milkwort']
senticnet['yellow_mountain_saxifrage'] = [-0.565, 0, 0.848, -0.801, '#angry', '#disgusting', -0.738, 'herb', 'breakstone', 'meadow_saxifrage', 'mossy_saxifrage', 'western_saxifrage']
senticnet['yellow_orange'] = [0, 0.123, -0.067, 0.11, '#interesting', '#admirable', 0.055, 'red_orange', 'reflect_light', 'blue_green', 'red_green', 'black_green']
senticnet['yellow_pine'] = [-0.698, 0, 0.725, -0.89, '#angry', '#disgusting', -0.771, 'ponderosa', 'ponderosa_pine', 'western_yellow_pine', 'bull_pine', 'longleaf_pine']
senticnet['yellow_ribbon'] = [0.065, -0.015, 0, 0, '#joyful', '#surprising', 0.027, 'oil_painting', 'tapestry', 'wall_art', 'use_oil_paint', 'artist_tool']
senticnet['yellow_rose'] = [0, 0.742, 0, 0.706, '#interesting', '#admirable', 0.483, 'flower', 'plant', 'flower_bloom', 'yellow_flower', 'good_smell']
senticnet['yellow_tooth'] = [-0.096, 0, 0, -0.111, '#sad', '#disgusting', -0.069, 'farm_crop', 'bad_taste', 'starch', 'meat', 'cereal_grain']
senticnet['yellow_watercress'] = [0.758, -0.975, 0, 0.851, '#surprising', '#admirable', 0.861, 'marsh_cress', 'watercress', 'mountain_watercress', 'common_watercress', 'great_yellowcress']
senticnet['yellowness'] = [-0.514, 0, 0.626, -0.544, '#angry', '#disgusting', -0.561, 'brownish_yellow', 'canary_yellow', 'old_gold', 'gold', 'canary']
senticnet['yellowstone'] = [-0.031, 0.224, -0.061, 0.067, '#interesting', '#admirable', 0.066, 'bill', 'invoice', 'expense', 'mastercard', 'payment']
senticnet['yeoman'] = [-0.993, 0, 0.877, -0.777, '#sad', '#angry', -0.882, 'bodyguard', 'outrider', 'bodyguard_of_guard', 'beefeater', 'defender']
senticnet['yeoman_of_guard'] = [-0.993, 0, 0.877, -0.777, '#sad', '#angry', -0.882, 'yeoman', 'outrider', 'bodyguard', 'beefeater', 'defender']
senticnet['yes_no'] = [-0.087, 0.188, -0.121, 0.279, '#interesting', '#admirable', 0.086, 'respond', 'interrogation', 'query', 'inquiry', 'inquire']
senticnet['yield'] = [-0.712, 0, 0, -0.809, '#sad', '#disgusting', -0.507, 'knuckle_under', 'buckle_under', 'succumb', 'give_up', 'give_in']
senticnet['yo-yo'] = [0.814, 0.989, 0, 0, '#joyful', '#interesting', 0.601, 'toy_soldier', 'toy', 'action_figure', 'toy_car', 'toy_marble']
senticnet['yob'] = [-0.777, 0, 0.692, -0.729, '#sad', '#disgusting', -0.733, 'bullyboy', 'muscleman', 'muscle', 'skinhead', 'skin']
senticnet['yobbo'] = [-0.69, 0, 0.876, -0.621, '#sad', '#angry', -0.729, 'bullyboy', 'muscleman', 'muscle', 'skinhead', 'skin']
senticnet['yobo'] = [-0.955, 0, 0.886, -0.515, '#sad', '#angry', -0.785, 'bullyboy', 'muscleman', 'muscle', 'skinhead', 'skin']
senticnet['yoga'] = [0, 0, 0, 0.93, '#admirable', '#admirable', 0.31, 'lift_weight', 'release_stress', 'move_body', 'take_hike', 'change_color']
senticnet['yogurt'] = [0, 0, 0, 0.93, '#admirable', '#admirable', 0.31, 'lunch_box', 'ferment_beverage', 'healthy_drink', 'ice_cream', 'healthy_snack']
senticnet['yokel'] = [-0.967, 0, 0.924, -0.865, '#sad', '#angry', -0.919, 'redneck', 'rustic', 'rube', 'hick', 'hayseed']
senticnet['yore'] = [0.798, 0.874, 0, 0, '#joyful', '#interesting', 0.557, 'reckon', 'yesterday', 'courtship', 'age', 'year']
senticnet['young'] = [0.895, 0, 0, 0.956, '#joyful', '#admirable', 0.617, 'new', 'untested', 'youthful', 'offspring', 'immature']
senticnet['young_age'] = [0.025, 0.073, -0.052, 0.1, '#interesting', '#admirable', 0.049, 'young_people', 'energy', 'hope', 'young_life', 'healthy']
senticnet['young_animal'] = [0.024, -0.046, 0, 0, '#joyful', '#surprising', 0.023, 'new_life', 'baby_dog', 'little', 'cute', 'baby_cat']
senticnet['young_child'] = [0.024, -0.046, 0, 0, '#joyful', '#surprising', 0.023, 'child', 'youth', 'child_smile', 'kid', 'childhood']
senticnet['young_girl'] = [0, 0.871, 0, 0.861, '#interesting', '#admirable', 0.577, 'female', 'lady', 'girl', 'alive', 'human_being']
senticnet['young_horse'] = [0.949, 0.91, 0, 0, '#joyful', '#interesting', 0.62, 'horse', 'sprinter', 'great_dane', 'mule', 'ride_horse']
senticnet['young_kid'] = [0.054, 0, 0, 0.061, '#joyful', '#admirable', 0.038, 'small_boy', 'small_adult', 'young_people', 'little_person', 'helpless']
senticnet['young_lady'] = [0, 0.911, 0, 0.851, '#interesting', '#admirable', 0.587, 'young_woman', 'sexy', 'beauty', 'human_being', 'miss']
senticnet['young_life'] = [0.025, 0.073, -0.052, 0.1, '#interesting', '#admirable', 0.049, 'young_age', 'energy', 'hope', 'young_people', 'healthy']
senticnet['young_man'] = [0, 0.076, 0, 0, '#interesting', '#interesting', 0.025, 'person', 'alive', 'investor', 'human_being', 'gardener']
senticnet['young_people'] = [0.025, 0.073, -0.052, 0.1, '#interesting', '#admirable', 0.049, 'young_age', 'energy', 'hope', 'young_life', 'healthy']
senticnet['young_woman'] = [0, 0.883, 0, 0.931, '#interesting', '#admirable', 0.605, 'sexy', 'young_lady', 'beauty', 'young_age', 'attractive']
senticnet['your_cloget_wet'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'bad_climate', 'heavy_rain', 'get_wet', 'snow', 'sickness']
senticnet['youth_subculture'] = [0.52, -0.911, 0, 0.65, '#surprising', '#admirable', 0.694, 'flower_people', 'hippies', 'hipsters', 'beat_generation', 'beats']
senticnet['yucky'] = [-0.089, 0.158, 0.659, -0.656, '#angry', '#disgusting', -0.415, 'disgustedly', 'revolting', 'disgusting', 'fed_up', 'sick_of']
senticnet['yum'] = [0.965, 0.936, 0, 0, '#joyful', '#interesting', 0.634, 'delicious_food', 'hot_meal', 'good_food', 'fresh_produce', 'tasty_food']
senticnet['yummy'] = [0.076, 0, 0, 0.113, '#joyful', '#admirable', 0.063, 'delicious', 'sweet_food', 'eatable', 'bake_product', 'bake_good']
senticnet['zany'] = [0.821, -0.994, 0, 0.572, '#joyful', '#surprising', 0.796, 'clown', 'buffoon', 'goof', 'goofball', 'merry_andrew']
senticnet['zeal'] = [0, 0.908, 0, 0.99, '#interesting', '#admirable', 0.633, 'beneficence', 'beneficially', 'beneficent', 'beneficed', 'benefic']
senticnet['zealous'] = [0.532, 0.657, -0.257, 0.268, '#joyful', '#interesting', 0.4, 'keenness', 'eagerly', 'eagerness', 'avidity', 'thirstily']
senticnet['zebra_crossing'] = [0.908, -0.562, 0, 0.878, '#joyful', '#admirable', 0.783, 'crosswalk', 'pelican_crossing', 'school_crossing', 'crossing', 'crossover']
senticnet['zeitgeist'] = [0.594, -0.949, 0, 0.834, '#surprising', '#admirable', 0.792, 'spirit', 'feel', 'look', 'flavor', 'tone']
senticnet['zenith'] = [0.044, 0.13, 0, 0.111, '#interesting', '#admirable', 0.095, 'top', 'brim', 'pinnacle', 'height', 'apex']
senticnet['zero'] = [-0.554, 0, 0.882, -0.735, '#angry', '#disgusting', -0.724, 'null', 'bugger_all', 'naught', 'zip', 'nothing']
senticnet['zest'] = [0.724, 0.755, 0, 0.853, '#interesting', '#admirable', 0.777, 'zestfulness', 'gusto', 'reassuringly', 'reassured', 'reassuring']
senticnet['zestfulness'] = [0.508, 0.659, -0.254, 0.253, '#joyful', '#interesting', 0.389, 'gusto', 'exuberantly', 'riotously', 'expansively', 'ebulliently']
senticnet['zesty'] = [0, 0, -0.984, -0.991, '#scared', '#disgusting', -0.658, 'savory', 'spicy', 'savoury', 'zestful', 'piquant']
senticnet['zeus'] = [0.04, 0.207, -0.061, 0.22, '#interesting', '#admirable', 0.135, 'bless', 'god', 'faith', 'pardon', 'dogma']
senticnet['zigzag'] = [0.036, 0.103, 0, 0.154, '#interesting', '#admirable', 0.098, 'upward', 'upwards', 'altitude', 'high', 'up_hill']
senticnet['zip'] = [-0.554, 0, 0.882, -0.735, '#angry', '#disgusting', -0.724, 'null', 'zero', 'naught', 'bugger_all', 'nothing']
senticnet['zip_code'] = [0, 0.849, 0, 0.841, '#interesting', '#admirable', 0.563, 'gps', 'house_location', 'location', 'small_group', 'address']
senticnet['zipper'] = [0, 0.813, 0, 0.737, '#interesting', '#admirable', 0.517, 'belt', 'leather_jacket', 'backpack', 'pouch', 'bag']
senticnet['zit'] = [-0.133, -0.05, 0, -0.119, '#sad', '#disgusting', -0.067, 'sloth', 'marmoset', 'snake', 'fungus', 'lemur']
senticnet['zombi'] = [-0.793, 0, 0.885, -0.768, '#sad', '#angry', -0.815, 'infernal', 'mortal', 'dead_soul', 'dead_soule', 'living_dead']
senticnet['zombie'] = [-0.03, -0.011, -0.166, -0.063, '#scared', '#disgusting', -0.083, 'sticky_floor', 'theater_box', 'projector', 'row_seat', 'theater_seat']
senticnet['zone'] = [0.025, 0.07, 0.016, 0.088, '#interesting', '#admirable', 0.056, 'region', 'area', 'place', 'territory', 'section']
senticnet['zone_out'] = [0.868, 0.99, 0, 0, '#joyful', '#interesting', 0.619, 'acculturation', 'enjoy_story', 'learn_news', 'cultural_experience', 'mindless_entertainment']
senticnet['zonk_out'] = [-0.608, 0, 0.541, -0.525, '#sad', '#angry', -0.558, 'swoon', 'pass_out', 'faint', 'conk', 'change_state']
senticnet['zoology'] = [0.1, 0.085, 0, 0.093, '#joyful', '#admirable', 0.093, 'study_person', 'subject_study', 'zoo', 'zoologist', 'geology']
senticnet['zoom_in'] = [0.791, -0.8, 0, 0.538, '#joyful', '#surprising', 0.71, 'focus', 'pore', 'rivet', 'concentrate', 'center']
senticnet['zoophobia'] = [-0.57, 0, 0.814, -0.936, '#angry', '#disgusting', -0.773, 'phobia', 'acarophobia', 'fear', 'arachnophobia', 'cynophobia']
senticnet['zymosis'] = [0.833, -0.507, 0, 0.519, '#joyful', '#admirable', 0.62, 'bottom_fermentation', 'top_fermentation', 'vinification', 'chemical_process', 'chemical_change']
senticnet['slothful'] = [0, 0, -0.869, -0.721, '#scared', '#disgusting', -0.53, 'otiose', 'indolent', 'faineant', 'lazy', 'work-shy']
senticnet['splendiferous'] = [0.919, 0, 0, 0.734, '#joyful', '#admirable', 0.551, 'splendid', 'glorious', 'excellent', 'resplendent', 'first-class']
senticnet['sooth'] = [0.76, -0.593, 0, 0.713, '#joyful', '#admirable', 0.689, 'truthfulness', 'sincerity', 'honestness', 'honesty', 'veracity']
senticnet['warmongering'] = [0.729, -0.561, 0, 0.785, '#joyful', '#admirable', 0.692, 'ideology', 'militarism', 'hawkishness', 'war_advocacy', 'political_orientation']
senticnet['hallucinating'] = [0, 0, -0.736, -0.83, '#scared', '#disgusting', -0.522, 'delirious', 'excited', 'frantic', 'mad', 'unrestrained']
senticnet['affiliated'] = [-0.792, 0, -0.834, 0, '#sad', '#scared', -0.542, 'bind', 'tie', 'attached', 'connected', 'committed']
senticnet['stern'] = [0, 0.993, 0, 0.87, '#interesting', '#admirable', 0.621, 'propeller', 'hull', 'cleat', 'gunwale', 'boat_part']
senticnet['ba_lot_of_out'] = [0, 0, -0.756, -0.811, '#scared', '#disgusting', -0.522, 'obliterate', 'kill', 'wipe_out', 'veil', 'obscure']
senticnet['simper'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'smirk', 'please', 'content', 'satisfy', 'gratify']
senticnet['copious'] = [0, 0.931, 0, 0.793, '#interesting', '#admirable', 0.575, 'ample', 'plenteous', 'plentiful', 'rich', 'sizable']
senticnet['junior-grade'] = [0, 0, 0.828, -0.805, '#angry', '#disgusting', -0.544, 'lowly', 'petty', 'secondary', 'subaltern', 'lower-ranking']
senticnet['stipulate'] = [0, 0, -0.777, -0.877, '#scared', '#disgusting', -0.551, 'qualified', 'qualify', 'measure_up', 'dispose', 'restrict']
senticnet['line_of_latitude'] = [0, 0, -0.9, -0.871, '#scared', '#disgusting', -0.59, 'analogue', 'analog', 'parallel', 'latitude', 'collimate']
senticnet['benign'] = [0.734, 0, 0, 0.936, '#joyful', '#admirable', 0.557, 'caring', 'benevolent', 'warmer', 'fatherly', 'motherly']
senticnet['toleration'] = [0.787, -0.885, 0, 0.858, '#surprising', '#admirable', 0.843, 'permissiveness', 'leniency', 'lenience', 'disposition', 'temperament']
senticnet['sinuate'] = [0, 0, -0.877, -0.723, '#scared', '#disgusting', -0.533, 'writhing', 'wriggly', 'wiggly', 'wriggling', 'sinuous']
senticnet['connive'] = [-0.819, 0, 0.823, 0, '#sad', '#angry', -0.547, 'conniving', 'collusive', 'intrigue', 'calculating', 'scheme']
senticnet['clamorous'] = [0, 0, -0.826, -0.934, '#scared', '#disgusting', -0.587, 'clamant', 'strident', 'conspicuous', 'blazing', 'blatant']
senticnet['service'] = [0.807, -0.92, 0, 0.796, '#joyful', '#surprising', 0.841, 'religious_ritual', 'confirmation', 'libation', 'rite', 'agape']
senticnet['withdrawnness'] = [0.72, -0.727, 0, 0.506, '#joyful', '#surprising', 0.651, 'standoffishness', 'unsociability', 'closeness', 'secretiveness', 'remoteness']
senticnet['miscellanea'] = [0, 0.839, 0, 0.912, '#interesting', '#admirable', 0.584, 'miscellany', 'assortment', 'mixture', 'smorgasbord', 'mixed_bag']
senticnet['uncouth'] = [0, 0, -0.972, -0.993, '#scared', '#disgusting', -0.655, 'harsh', 'common', 'rough-cut', 'coarse', 'vulgar']
senticnet['pixilated'] = [0, 0, -0.732, -0.857, '#scared', '#disgusting', -0.53, 'mischievous', 'prankish', 'implike', 'arch', 'impish']
senticnet['encomium'] = [0, 0, -0.857, -0.991, '#scared', '#disgusting', -0.616, 'paean', 'eulogium', 'eulogy', 'pean', 'panegyric']
senticnet['prevention'] = [0.06, 0.422, -0.177, 0.41, '#interesting', '#admirable', 0.238, 'safe_sex', 'meet_girl', 'use_condom', 'playboy', 'dirty_magazine']
senticnet['tower_rock_cress'] = [0.598, -0.721, 0, 0.941, '#surprising', '#admirable', 0.753, 'sicklepod', 'cress', 'tower_mustard', 'rock_cress', 'rock_cress_plant']
senticnet['rice'] = [0, 0.073, -0.093, -0.087, '#scared', '#disgusting', -0.036, 'cotton_boll', 'asbestos', 'corn', 'opium', 'cauliflower']
senticnet['plate'] = [0.022, 0.069, 0.027, 0.059, '#interesting', '#admirable', 0.041, 'perfect_surface', 'flat_land', 'flat_surface', 'flat_object', 'crockery']
senticnet['plato'] = [0, 0.722, 0, 0.975, '#interesting', '#admirable', 0.566, 'brown_hair', 'natural_world', 'hair', 'feature', 'stick_out']
senticnet['guileful'] = [0, -0.811, 0, 0.796, '#surprising', '#admirable', 0.536, 'cunning', 'dodgy', 'crafty', 'knavish', 'tricksy']
senticnet['eradicate'] = [0, 0, -0.819, -0.995, '#scared', '#disgusting', -0.605, 'annihilate', 'decimated', 'extinguish', 'eliminate', 'wipe_out']
senticnet['cerapteryx_graminis'] = [-0.103, -0.049, 0, -0.147, '#sad', '#disgusting', -0.067, 'armyworm', 'antler_moth', 'noctuid', 'heliothis_moth', 'moth']
senticnet['tooth_disease'] = [-0.605, 0, 0.787, -0.909, '#angry', '#disgusting', -0.767, 'pain', 'black_gum', 'need_dentist', 'discomfort', 'ugly_smile']
senticnet['spic'] = [0, 0, -0.866, -0.738, '#scared', '#disgusting', -0.535, 'spic-and-span', 'spick-and-span', 'spotless', 'immaculate', 'speckless']
senticnet['recollective'] = [0.905, 0.816, 0, 0, '#joyful', '#interesting', 0.574, 'retentive', 'long', 'dogged', 'dour', 'tenacious']
senticnet['workforce'] = [0.814, -0.878, 0, 0.918, '#surprising', '#admirable', 0.87, 'ship_company', 'company', 'work_force', 'full_complement', 'manpower']
senticnet['supper'] = [0.084, -0.054, 0, -0.044, '#joyful', '#surprising', 0.031, 'feast', 'mash_potato', 'satiation', 'breakfast', 'entree']
senticnet['prognosticate'] = [0.527, -0.984, 0, 0.847, '#surprising', '#admirable', 0.786, 'auspicate', 'prefigure', 'foreshow', 'portend', 'bode']
senticnet['portrayed'] = [0.716, -0.78, 0, 0.539, '#joyful', '#surprising', 0.678, 'depicted', 'pictured', 'delineated', 'described', 'diagrammatic']
senticnet['claudication'] = [-0.724, 0, 0, -0.915, '#sad', '#disgusting', -0.546, 'gimpiness', 'lameness', 'limping', 'gimp', 'gameness']
senticnet['studiousness'] = [0.799, -0.616, 0, 0.789, '#joyful', '#admirable', 0.735, 'sedulity', 'sedulousness', 'assiduity', 'assiduousness', 'industriousness']
senticnet['acidophilus_microflora'] = [-0.998, 0, 0.987, -0.965, '#sad', '#angry', -0.983, 'lactobacillus', 'acidophilus', 'acidophilus_bacterium', 'probiotic', 'acidophilus_flora']
senticnet['flux'] = [0, 0, -0.754, -0.924, '#scared', '#disgusting', -0.559, 'blend', 'conflate', 'mix', 'coalesce', 'commingle']
senticnet['starring'] = [0, -0.893, 0, 0.718, '#surprising', '#admirable', 0.537, 'conduce', 'precede', 'leadership', 'leading', 'guide']
senticnet['furcate'] = [0, 0, -0.789, -0.988, '#scared', '#disgusting', -0.592, 'disunite', 'divide', 'part', 'differentiate', 'separate']
senticnet['waistcoat'] = [0.939, -0.632, 0, 0.653, '#joyful', '#admirable', 0.741, 'vest', 'body_armor', 'bulletproof_vest', 'suit_of_armor', 'coat_of_mail']
senticnet['unanimous'] = [0.509, -0.626, 0, 0.786, '#surprising', '#admirable', 0.64, 'agreeable', 'consentaneous', 'consentient', 'accordant', 'according']
senticnet['stipendiary'] = [0.521, -0.859, 0, 0.727, '#surprising', '#admirable', 0.702, 'paid', 'remunerated', 'paying', 'compensated', 'remunerative']
senticnet['comely'] = [0.83, 0.727, 0, 0, '#joyful', '#interesting', 0.519, 'comme_il_faut', 'seemly', 'decorous', 'becoming', 'decent']
senticnet['smelling'] = [0, 0, -0.707, -0.801, '#scared', '#disgusting', -0.503, 'resonant', 'remindful', 'redolent', 'reminiscent', 'evocative']
senticnet['embark'] = [0, 0, 0.82, -0.963, '#angry', '#disgusting', -0.594, 'venturing', 'venture', 'guess', 'hazard', 'pretend']
senticnet['specked'] = [0, 0, -0.994, -0.915, '#scared', '#disgusting', -0.636, 'speckled', 'flecked', 'stipple', 'dotted', 'bespeckle']
senticnet['ill-fated'] = [0, 0, -0.909, -0.938, '#scared', '#disgusting', -0.616, 'luckless', 'ill-omened', 'ill-starred', 'doomed', 'unlucky']
senticnet['constraint'] = [-0.657, 0, 0.65, -0.981, '#sad', '#disgusting', -0.763, 'assumption', 'precondition', 'provision', 'boundary_condition', 'premiss']
senticnet['tile'] = [0.059, -0.047, 0.014, 0, '#joyful', '#surprising', 0.031, 'frame', 'artwork', 'mural', 'picture_frame', 'smoke_alarm']
senticnet['years'] = [0.074, -0.06, 0, 0, '#joyful', '#surprising', 0.045, 'age', 'annual', 'elderly', 'teen', 'time']
senticnet['wormlike'] = [0.679, -0.947, 0, 0.661, '#joyful', '#surprising', 0.762, 'submissive', 'cringing', 'groveling', 'sub', 'bowing']
senticnet['paper_octopod'] = [-0.523, 0, 0.728, -0.926, '#angry', '#disgusting', -0.726, 'octopod', 'cephalopod', 'cephalopod_mollusk', 'nautilus', 'octopus']
senticnet['workmanlike'] = [0.982, -0.67, 0, 0.682, '#joyful', '#admirable', 0.778, 'able', 'effective', 'efficient', 'competent', 'capcompetent']
senticnet['unlikelihood'] = [0.602, -0.728, 0, 0.892, '#surprising', '#admirable', 0.741, 'improbability', 'unlikeliness', 'uncertainty', 'precariousness', 'uncertainness']
senticnet['sponsor'] = [0, -0.751, 0, 0.847, '#surprising', '#admirable', 0.533, 'condescend', 'patronize', 'buy_at', 'support', 'patronise']
senticnet['matter-of-fact'] = [0, 0, -0.916, -0.763, '#scared', '#disgusting', -0.56, 'prosaic', 'commonplace', 'pedestrian', 'prosy', 'earthbound']
senticnet['wandering'] = [0, 0, -0.895, -0.942, '#scared', '#disgusting', -0.612, 'fickle', 'erratic', 'planetary', 'quicksilver', 'mercurial']
senticnet['proactive'] = [0, 0.717, 0, 0.765, '#interesting', '#admirable', 0.494, 'intelligent_agent', 'artificial_intelligence', 'goal_driven_active_entity', 'goal_driven', 'intelligent']
senticnet['emergency_brake_pedal'] = [0.771, 0.702, 0, 0, '#joyful', '#interesting', 0.491, 'safe_belt', 'brake', 'stop', 'avoid_accident', 'brake_pedal']
senticnet['turner'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'display', 'sharpen', 'paint_picture', 'letter_sign', 'display_information']
senticnet['zoo'] = [0.03, 0.068, -0.061, 0.062, '#interesting', '#admirable', 0.033, 'pacific_northwest', 'thermal', 'treetop', 'animals', 'american_forest']
senticnet['reconciled'] = [0.726, -0.888, 0, 0.529, '#joyful', '#surprising', 0.714, 'conformable', 'accordant', 'agreeable', 'consistent', 'pursuant']
senticnet['differential_derivative'] = [-0.716, 0, 0.871, -0.75, '#angry', '#disgusting', -0.779, 'differential', 'curvature', 'partial', 'calculation', 'computation']
senticnet['tike'] = [0.592, -0.931, 0, 0.935, '#surprising', '#admirable', 0.819, 'child', 'small_fry', 'tyke', 'child_prodigy', 'kid']
senticnet['postdoc'] = [0.846, -0.755, 0, 0.69, '#joyful', '#surprising', 0.764, 'experimenter', 'investigator', 'fieldworker', 'boffin', 'post_doc']
senticnet['refresher'] = [0.951, -0.97, 0, 0.639, '#joyful', '#surprising', 0.853, 'smoothie', 'drinking_water', 'nutrient', 'milk', 'beverage']
senticnet['refreshed'] = [0.078, 0, 0, 0, '#joyful', '#joyful', 0.026, 'glass_water', 'coke', 'smoothie', 'lemonade', 'cold_water']
senticnet['vender'] = [0.814, -0.582, 0, 0.646, '#joyful', '#admirable', 0.681, 'seller', 'marketer', 'cosmetician', 'vendor', 'trafficker']
senticnet['dealing_with_situation'] = [0, 0.828, 0, 0.896, '#interesting', '#admirable', 0.575, 'quick_look', 'approach', 'solution', 'proposal', 'proceed']
senticnet['glutinous'] = [0, 0, -0.841, -0.83, '#scared', '#disgusting', -0.557, 'gluey', 'pasty', 'sticky', 'mucilaginous', 'gummy']
senticnet['photon'] = [0.976, 0, 0, 0.741, '#joyful', '#admirable', 0.572, 'ray', 'light', 'electromagnetic_radiation', 'illumination', 'brightness']
senticnet['straighten'] = [0.971, -0.535, 0, 0.665, '#joyful', '#admirable', 0.724, 'tidy', 'tidy_up', 'clean_up', 'neaten', 'houseclean']
senticnet['dubious'] = [-0.926, 0, 0, -0.899, '#sad', '#disgusting', -0.608, 'implausible', 'unbelievable', 'cockamamie', 'farfetched', 'unlikely']
senticnet['wholeness'] = [0.898, -0.536, 0, 0.841, '#joyful', '#admirable', 0.758, 'integrity', 'completeness', 'fullness', 'comprehensiveness', 'unity']
senticnet['sumo'] = [0.106, -0.018, 0, 0, '#joyful', '#surprising', 0.041, 'western', 'circus_act', 'rodeo', 'grand_canyon', 'have_fun']
senticnet['seaman'] = [0.045, 0, 0, 0.088, '#joyful', '#admirable', 0.044, 'leader', 'captain', 'lieutenant', 'officer', 'traitor']
senticnet['pain_pill_hydrochloride'] = [-0.985, 0, 0.601, -0.695, '#sad', '#disgusting', -0.76, 'hydromorphone', 'pain_pill', 'acetaminophen', 'codeine', 'medicine']
senticnet['sedulity'] = [0.799, -0.616, 0, 0.789, '#joyful', '#admirable', 0.735, 'industriousness', 'sedulousness', 'assiduity', 'assiduousness', 'studiousness']
senticnet['rust'] = [0.057, 0, 0.012, 0.08, '#joyful', '#admirable', 0.042, 'aluminium', 'foil', 'tin', 'thin_metal', 'magnet']
senticnet['puppy'] = [0.144, 0.134, -0.045, 0.238, '#joyful', '#admirable', 0.157, 'baby_dog', 'vulnerable', 'need_care', 'young_animal', 'newborn']
senticnet['retral'] = [-0.801, 0, 0, -0.778, '#sad', '#disgusting', -0.526, 'reverse', 'retrograde', 'backward', 'primitive', 'benighted']
senticnet['roadway'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'suspension_bridge', 'under_bridge', 'bridge', 'county_highway', 'long_road']
senticnet['potentiation'] = [0.662, -0.793, 0, 0.919, '#surprising', '#admirable', 0.791, 'activity', 'natural_process', 'natural_action', 'synergism', 'action']
senticnet['adust'] = [0, 0, -0.923, -0.966, '#scared', '#disgusting', -0.63, 'parched', 'scorched', 'sear', 'sunbaked', 'baked']
senticnet['pliancy'] = [0.873, -0.943, 0, 0.74, '#joyful', '#surprising', 0.852, 'ability', 'flexibility', 'flexibleness', 'adaptability', 'pliantness']
senticnet['speedo'] = [0, 0.953, 0, 0.998, '#interesting', '#admirable', 0.65, 'stuff_use_calculation', 'complete_thesis', 'written_programmer', 'pour_hot_coffee_mug', 'voltage']
senticnet['tested'] = [0.947, -0.793, 0, 0.7, '#joyful', '#surprising', 0.813, 'dependable', 'tried', 'tried_and_true', 'sure', 'undeviating']
senticnet['seagull'] = [0.992, 0.915, 0, 0, '#joyful', '#interesting', 0.636, 'bird', 'colorful', 'pup', 'hummingbird', 'minnow']
senticnet['thickened'] = [-0.911, 0, 0.886, 0, '#sad', '#angry', -0.599, 'callous', 'tougheneded', 'heartless', 'unfeeling', 'uncaring']
senticnet['gastric_ranitidine'] = [-0.533, 0, 0.954, -0.541, '#angry', '#disgusting', -0.676, 'ranitidine', 'histamine_blocker', 'antacid', 'alkalizer', 'antiacid']
senticnet['twisting'] = [0, 0, -0.795, -0.772, '#scared', '#disgusting', -0.522, 'winding', 'tortuous', 'copious', 'voluminous', 'twisty']
senticnet['troglodyte'] = [0, 0, -0.728, -0.763, '#scared', '#disgusting', -0.497, 'solitary', 'recluse', 'hermit', 'reclusive', 'solitudinarian']
senticnet['trellis'] = [0.962, 0, 0, 0, '#joyful', '#joyful', 0.321, 'marijuana', 'pleasure_garden', 'cannabis', 'mushroom', 'cabbage']
senticnet['bigheaded'] = [0, 0, -0.764, -0.877, '#scared', '#disgusting', -0.547, 'snooty', 'uppish', 'too_big_for_ones_breeches', 'persnickety', 'stuck-up']
senticnet['weedy'] = [0, 0, 0.956, -0.963, '#angry', '#disgusting', -0.64, 'scraggy', 'boney', 'underweight', 'skinny', 'scrawny']
senticnet['solitariness'] = [0.929, -0.797, 0, 0.915, '#joyful', '#admirable', 0.88, 'privacy', 'seclusion', 'privateness', 'reclusiveness', 'loneliness']
senticnet['tummy'] = [0, 0, 0, 0.968, '#admirable', '#admirable', 0.323, 'digestive_system', 'nervous_system', 'human_body', 'stomach', 'belly']
senticnet['servitude'] = [-0.365, -0.082, 0, -0.327, '#sad', '#disgusting', -0.203, 'thrall', 'bonded_labor', 'serfdom', 'serfhood', 'vassalage']
senticnet['suppliant'] = [0, 0, -0.776, -0.821, '#scared', '#disgusting', -0.532, 'supplicant', 'requester', 'petitioner', 'supplicatory', 'prayer']
senticnet['exterminate'] = [0, 0, -0.963, -0.721, '#scared', '#disgusting', -0.561, 'eradicate', 'deracinate', 'root_out', 'extirpate', 'uproot']
senticnet['quotability'] = [0.76, -0.958, 0, 0.506, '#joyful', '#surprising', 0.741, 'goodness', 'praiseworthiness', 'worthiness', 'laudableness', 'laudability']
senticnet['civilized'] = [0, 0.969, 0, 0.759, '#interesting', '#admirable', 0.576, 'cultured', 'civilised', 'cultivated', 'genteel', 'polite']
senticnet['bareface'] = [0, 0, 0.936, -0.702, '#angry', '#disgusting', -0.546, 'undeferential', 'disrespectful', 'undutiful', 'insolent', 'brazen']
senticnet['analog'] = [0, 0, 0.94, -0.769, '#angry', '#disgusting', -0.57, 'linear', 'one-dimensional', 'elongate', 'additive', 'analogue']
senticnet['thrive'] = [0, 0, 0, 0.869, '#admirable', '#admirable', 0.29, 'prosper', 'succeed', 'realize', 'fly_high', 'enthusiam']
senticnet['deracinate'] = [0, 0, -0.963, -0.721, '#scared', '#disgusting', -0.561, 'eradicate', 'extirpate', 'root_out', 'exterminate', 'uproot']
senticnet['first_woman'] = [0.783, 0.708, 0, 0, '#joyful', '#interesting', 0.497, 'eden', 'first_man', 'adam_and_eve', 'religious', 'bible']
senticnet['sinuous'] = [0, 0, -0.877, -0.723, '#scared', '#disgusting', -0.533, 'writhing', 'wriggly', 'sinuate', 'wriggling', 'wiggly']
senticnet['brawny'] = [0.737, 0, 0, 0.957, '#joyful', '#admirable', 0.565, 'muscular', 'goodly', 'sinewy', 'powerful', 'hefty']
senticnet['yeti'] = [0, 0, 0.808, -0.779, '#angry', '#disgusting', -0.529, 'monster', 'wild_man', 'orang_pendek', 'abominable_snowman', 'abominable']
senticnet['unwearied'] = [0.516, -0.936, 0, 0.802, '#surprising', '#admirable', 0.751, 'rested', 'refreshed', 'rerested', 'untired', 'invigorated']
senticnet['technologic'] = [0.159, -0.005, 0.011, 0.079, '#joyful', '#admirable', 0.077, 'ceiling_fan', 'kitchenette', 'formula', 'ipod', 'music']
senticnet['seclusion'] = [0.929, -0.797, 0, 0.915, '#joyful', '#admirable', 0.88, 'privacy', 'reclusiveness', 'privateness', 'solitariness', 'loneliness']
senticnet['shoot_line'] = [0, 0, 0.807, -0.721, '#angry', '#disgusting', -0.509, 'touting', 'boast', 'swash', 'gas', 'brag']
senticnet['respite'] = [0.756, 0, 0, 0.748, '#joyful', '#admirable', 0.501, 'gasp', 'wind', 'breath', 'blow', 'whiff']
senticnet['schadenfreude'] = [-0.938, 0, 0, -0.842, '#sad', '#disgusting', -0.593, 'gloat', 'gloating', 'cheer', 'dwell', 'gloatingly']
senticnet['squirm'] = [0, 0, -0.945, -0.91, '#scared', '#disgusting', -0.618, 'wriggle', 'wrestle', 'writhing', 'worm', 'writhe']
senticnet['suppression'] = [0, 0, -0.896, -0.792, '#scared', '#disgusting', -0.563, 'crushing', 'quelling', 'stifling', 'oppress', 'squeeze']
senticnet['hot_coffee_roll'] = [-0.902, 0, 0, -0.89, '#sad', '#disgusting', -0.597, 'coffee_roll', 'cross_bun', 'bear_paw', 'bear_claw', 'bun']
senticnet['video'] = [0, 0.333, -0.219, 0.384, '#interesting', '#admirable', 0.166, 'take_picture', 'picture', 'take_photograph', 'use_camera', 'photograph']
senticnet['devil-may-care'] = [0, 0, -0.938, -0.932, '#scared', '#disgusting', -0.623, 'carefree', 'freewheeling', 'slaphappy', 'harum-scarum', 'happy-go-lucky']
senticnet['ultrapatriotic'] = [0.585, -0.7, 0, 0.586, '#surprising', '#admirable', 0.624, 'jingoistic', 'nationalistic', 'superpatriotic', 'patriotic', 'chauvinistic']
senticnet['thigh'] = [0.023, 0.085, -0.045, 0.088, '#interesting', '#admirable', 0.05, 'above_leg', 'femur', 'joint', 'hip', 'knee']
senticnet['far-famed'] = [0.971, 0.764, 0, 0, '#joyful', '#interesting', 0.578, 'notable', 'illustrious', 'famous', 'famed', 'celebrated']
senticnet['scorch'] = [0.606, -0.504, 0, 0.795, '#joyful', '#admirable', 0.635, 'plant_disease', 'pinkroot', 'disease', 'rust', 'cotton_ball']
senticnet['school_pedestrian_crossing'] = [0.508, -0.726, 0, 0.727, '#surprising', '#admirable', 0.654, 'crosswalk', 'pelican_pedestrian_crossing', 'crossing', 'pedestrian_crossing', 'crossover']
senticnet['temptingness'] = [0.817, -0.626, 0, 0.62, '#joyful', '#surprising', 0.688, 'quality', 'fascination', 'attractivenessment', 'attractiveness', 'allure']
senticnet['countermine'] = [0, 0, -0.913, -0.715, '#scared', '#disgusting', -0.543, 'undermined', 'counteract', 'sabotage', 'weaken', 'subvert']
senticnet['soundless'] = [0, 0, -0.94, -0.71, '#scared', '#disgusting', -0.55, 'tacit', 'silent', 'still', 'understood', 'mum']
senticnet['sergeant'] = [0, 0.121, 0, 0.068, '#interesting', '#admirable', 0.063, 'rank', 'military_rank', 'military_order', 'general', 'army_boss']
senticnet['symphonious'] = [0.826, -0.719, 0, 0.913, '#joyful', '#admirable', 0.819, 'true', 'pure', 'harmonical', 'harmonious', 'harmonized']
senticnet['dissociative_disorder_neurosis'] = [-0.583, 0, 0.722, -0.516, '#sad', '#angry', -0.607, 'disorder', 'depersonalization', 'dissociative_disorder', 'mental_disorder', 'mental_disturbance']
senticnet['unsparing'] = [0, -0.92, 0, 0.783, '#surprising', '#admirable', 0.568, 'shower', 'munificent', 'overgenerous', 'lavish', 'too-generous']
senticnet['terminal'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'train_station', 'government_office', 'cable_car', 'sport_stadium', 'baggage_compartment']
senticnet['untellable'] = [0, 0, -0.763, -0.862, '#scared', '#disgusting', -0.542, 'ineffable', 'unspeakable', 'indescribable', 'indefinable', 'unutterable']
senticnet['quickener'] = [0.962, -0.898, 0, 0.855, '#joyful', '#surprising', 0.905, 'infectious_agent', 'infective_agent', 'satisfier', 'agent', 'invigorator']
senticnet['vying'] = [0, 0.706, 0, 0.714, '#interesting', '#admirable', 0.473, 'ambitious', 'driven', 'competitive', 'combative', 'contentious']
senticnet['rear_flag_officer'] = [0.688, -0.908, 0, 0.877, '#surprising', '#admirable', 0.824, 'fleet_flag_officer', 'admiral', 'flag_officer', 'full_flag_officer', 'vice_flag_officer']
senticnet['nonintellectualed'] = [0.849, -0.897, 0, 0.924, '#surprising', '#admirable', 0.89, 'philistine', 'nonintellectual', 'lowbrow', 'mindless', 'uncultivated']
senticnet['thoughtlessness'] = [0.828, -0.675, 0, 0.811, '#joyful', '#admirable', 0.771, 'foolhardiness', 'brashness', 'adventurism', 'desperation', 'unthoughtfulness']
senticnet['venerability'] = [0.66, -0.842, 0, 0.712, '#surprising', '#admirable', 0.738, 'respectability', 'reputability', 'honorableness', 'venerableness', 'righteousness']
senticnet['hair_sculpt_gel'] = [-0.04, 0.069, 0, 0.075, '#interesting', '#admirable', 0.035, 'sculpt_gel', 'hairstyle', 'hairdresser', 'cosmetic', 'gel']
senticnet['unreflective'] = [-0.816, 0, 0, -0.994, '#sad', '#disgusting', -0.603, 'unthinking', 'thoughtless', 'inconsiderate', 'unthoughtful', 'selfish']
senticnet['torsion'] = [0.697, -0.507, 0, 0.792, '#joyful', '#admirable', 0.665, 'tortuousness', 'gnarl', 'warp', 'tortuosity', 'distorted_shape']
senticnet['prosiness'] = [0.741, -0.748, 0, 0.666, '#joyful', '#surprising', 0.718, 'mundaneness', 'mundanity', 'commonplaceness', 'prosaicness', 'ordinariness']
senticnet['stuffing'] = [0.87, -0.856, 0, 0.94, '#joyful', '#admirable', 0.889, 'mincemeat', 'concoction', 'dressing', 'roux', 'batter']
senticnet['footslog'] = [0, 0, -0.98, -0.801, '#scared', '#disgusting', -0.594, 'grind', 'plodding', 'donkeywork', 'slog', 'drudgery']
senticnet['soporiferous'] = [0, 0, -0.757, -0.88, '#scared', '#disgusting', -0.546, 'somnific', 'hypnotic', 'hypnogogic', 'somniferous', 'soporific']
senticnet['pietism'] = [0.674, -0.798, 0, 0.981, '#surprising', '#admirable', 0.818, 'piety', 'piousness', 'devoutness', 'religiosity', 'religionism']
senticnet['pier'] = [0.025, 0.136, 0, 0, '#joyful', '#interesting', 0.054, 'train_station', 'bus', 'subway_station', 'public_place', 'bus_station']
senticnet['mistrustful'] = [0, 0, -0.894, -0.941, '#scared', '#disgusting', -0.612, 'suspicious', 'untrusting', 'leery', 'fishy', 'wary']
senticnet['bad_drug_spill'] = [-0.182, -0.078, 0, -0.203, '#sad', '#disgusting', -0.102, 'water', 'bad_drug', 'atmosphere', 'cool_bad_drug', 'obtain_bad_drug']
senticnet['edacious'] = [0, 0, -0.857, -0.734, '#scared', '#disgusting', -0.53, 'wolfish', 'rapacious', 'esurient', 'ravenous', 'voracious']
senticnet['misbegot'] = [0, 0, -0.826, -0.903, '#scared', '#disgusting', -0.576, 'misbegotten', 'inauthentic', 'spurious', 'bastardly', 'specious']
senticnet['unsteadiness'] = [-0.897, 0, 0.972, -0.502, '#sad', '#angry', -0.79, 'fitfulness', 'haphazardness', 'stochasticity', 'variability', 'unregularity']
senticnet['progression'] = [0.501, -0.506, 0, 0.683, '#surprising', '#admirable', 0.563, 'forward_motion', 'onward_motion', 'clear_sailing', 'procession', 'progress']
senticnet['ratafia'] = [0.693, -0.945, 0, 0.713, '#surprising', '#admirable', 0.784, 'cordial', 'maraschino', 'anisette', 'pastis', 'ratafee']
senticnet['alloy_cast_cast_iron'] = [0.706, -0.941, 0, 0.622, '#joyful', '#surprising', 0.756, 'alloy_cast_iron', 'iron', 'pot_metal', 'cast_iron', 'atomic_number_26']
senticnet['uncertainness'] = [0.602, -0.728, 0, 0.892, '#surprising', '#admirable', 0.741, 'unlikelihood', 'unlikeliness', 'uncertainty', 'precariousness', 'improbability']
senticnet['spunky'] = [0, 0, -0.887, -0.891, '#scared', '#disgusting', -0.593, 'touchy', 'feisty', 'plucky', 'thin-skinned', 'huffy']
senticnet['sorceress'] = [0.594, -0.549, 0, 0.518, '#joyful', '#surprising', 0.554, 'exorcist', 'necromancer', 'magus', 'enchanter', 'witch_doctor']
senticnet['lonesome'] = [0, 0, -0.78, -0.719, '#scared', '#disgusting', -0.5, 'sole', 'solitary', 'single', 'only', 'alone']
senticnet['plop'] = [0, 0, -0.953, -0.711, '#scared', '#disgusting', -0.555, 'plank', 'plonk', 'flump', 'plump', 'plummet']
senticnet['sweater'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'coat', 'suit', 'leather', 'armor', 'belt']
senticnet['innovative'] = [0.795, 0.866, 0, 0, '#joyful', '#interesting', 0.554, 'progress', 'advanced', 'modern', 'sophisticated', 'ripe']
senticnet['roommate'] = [0, 0.754, 0, 0.804, '#interesting', '#admirable', 0.519, 'tenant', 'ceiling_fan', 'resident', 'stair_rail', 'citizien']
senticnet['scrumptious'] = [0.878, -0.765, 0, 0, '#joyful', '#surprising', 0.548, 'delicious', 'luscious', 'pleasant-tasting', 'delectable', 'toothsome']
senticnet['jest_at'] = [0, 0, -0.705, -0.871, '#scared', '#disgusting', -0.525, 'guy', 'blackguard', 'laugh_at', 'ridicule', 'roasted']
senticnet['transferability'] = [0.912, -0.757, 0, 0.512, '#joyful', '#surprising', 0.727, 'convertibility', 'exchangeability', 'changeableness', 'changeability', 'permutability']
senticnet['flawless'] = [0.855, 0, 0, 0.971, '#joyful', '#admirable', 0.609, 'inerrable', 'foolproof', 'unfailing', 'reliable', 'sure']
senticnet['another'] = [0, 0.945, 0, 0.723, '#interesting', '#admirable', 0.556, 'alternative', 'substitute', 'replacement', 'alternate', 'every_second']
senticnet['garble'] = [0, 0, -0.785, -0.786, '#scared', '#disgusting', -0.524, 'falsify', 'distorted', 'warp', 'twist', 'deform']
senticnet['sereneness'] = [0.621, 0.648, -0.252, 0.296, '#joyful', '#interesting', 0.438, 'pacifically', 'ataraxis', 'tranquility', 'harmony', 'peace']
senticnet['stateswoman'] = [0.838, -0.589, 0, 0.945, '#joyful', '#admirable', 0.791, 'national_leader', 'elder_statesman', 'politician', 'politico', 'pol']
senticnet['praising'] = [0.722, -0.981, 0, 0.832, '#surprising', '#admirable', 0.845, 'laudatory', 'praiseful', 'complimentary', 'encomiastic', 'eulogistic']
senticnet['put_on_shoes'] = [0, 0.144, -0.079, 0.222, '#interesting', '#admirable', 0.096, 'shoe', 'wear_shoes', 'put_shoes', 'jogging', 'sport']
senticnet['shower_cover_hair'] = [0.179, 0.164, -0.052, 0.163, '#joyful', '#interesting', 0.151, 'cap', 'hat', 'cover_hair', 'head_wear', 'scarf']
senticnet['ambasjoyfulor'] = [0, 0.952, 0, 0.878, '#interesting', '#admirable', 0.61, 'management', 'policeman', 'authority', 'duty', 'construction_worker']
senticnet['rung'] = [0.768, 0, 0, 0.881, '#joyful', '#admirable', 0.55, 'something_familiar', 'remember', 'amplitude', 'step', 'bell_ring']
senticnet['plainspoken'] = [0, 0.899, 0, 0.779, '#interesting', '#admirable', 0.559, 'free-spoken', 'forthright', 'outspoken', 'blunt', 'candid']
senticnet['secretary'] = [0.046, 0.099, -0.054, 0.067, '#interesting', '#admirable', 0.053, 'vocation', 'employee', 'public_servant', 'tradesman', 'worker']
senticnet['cow_droppings'] = [-0.838, 0, 0.521, -0.713, '#sad', '#disgusting', -0.691, 'stool', 'dejection', 'droppings', 'chip', 'cow_dung']
senticnet['latest_find_newspaper'] = [0.088, -0.003, 0, 0, '#joyful', '#surprising', 0.03, 'look_up_information', 'find_newspaper', 'headlines', 'enter_contest', 'news']
senticnet['meat_hand'] = [0.883, -0.593, 0, 0.533, '#joyful', '#surprising', 0.67, 'hand', 'hooks', 'maulers', 'right', 'left']
senticnet['tong'] = [0.064, 0, 0, 0.057, '#joyful', '#admirable', 0.04, 'keep_hand_warm', 'hand', 'human_hand', 'finger', 'grasper']
senticnet['perfervid'] = [0, 0, 0.959, -0.956, '#angry', '#disgusting', -0.638, 'impassioned', 'fervent', 'fervid', 'ardent', 'fiery']
senticnet['sculpt'] = [0.047, 0, 0, 0.067, '#joyful', '#admirable', 0.038, 'fillet_fish', 'clon', 'photography', 'price_product', 'demo']
senticnet['sabbatical'] = [0.787, 0.949, 0, 0.99, '#interesting', '#admirable', 0.909, 'holiday', 'day_off', 'vacation', 'time_off', 'time']
senticnet['briary'] = [0, 0, -0.827, -0.782, '#scared', '#disgusting', -0.536, 'barbellate', 'briery', 'bristled', 'thorny', 'barbed']
senticnet['sparing'] = [0.722, -0.744, 0, 0.554, '#joyful', '#surprising', 0.673, 'saving', 'thrifty', 'scotch', 'frugal', 'economical']
senticnet['atasteful'] = [0.737, -0.854, 0, 0.623, '#joyful', '#surprising', 0.738, 'understated', 'tasteful', 'esthetic', 'artistic', 'unostentatious']
senticnet['passing_pass'] = [-0.92, 0, 0.835, -0.682, '#sad', '#angry', -0.812, 'aerial', 'passing', 'forward_pass', 'lateral', 'spot_pass']
senticnet['biramous'] = [0, 0, -0.889, -0.783, '#scared', '#disgusting', -0.557, 'forficate', 'pronged', 'branched', 'bifurcate', 'forked']
senticnet['heavy_bad_climate'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'storm', 'rain', 'bad_climate', 'snow', 'become_sick']
senticnet['equable'] = [0.753, 0, 0, 0.911, '#joyful', '#admirable', 0.555, 'leisurely', 'unhurried', 'easy', 'easygoing', 'placid']
senticnet['pillow'] = [0, 0.943, 0, 0, '#interesting', '#interesting', 0.314, 'duvet_cover', 'bed_sheet', 'comforter', 'pillowcase', 'blanket']
senticnet['guttle'] = [0, 0, -0.9, -0.84, '#scared', '#disgusting', -0.58, 'consume', 'devoured', 'go_through', 'down', 'raven']
senticnet['purge'] = [0.799, -0.888, 0, 0.883, '#surprising', '#admirable', 0.857, 'pronounce', 'acquit', 'whitewash', 'vindicate', 'label']
senticnet['unworldlyal'] = [-0.948, 0, 0.779, -0.858, '#sad', '#disgusting', -0.862, 'unworldly', 'eremitic', 'cloistered', 'anchoritic', 'hermitic']
senticnet['varnished'] = [0, 0, -0.991, -0.925, '#scared', '#disgusting', -0.639, 'stained', 'tarnish', 'maculate', 'sully', 'defile']
senticnet['sweatshop'] = [0.049, 0.078, 0, 0.051, '#interesting', '#admirable', 0.059, 'work_in_garden', 'hold_up_office', 'workplace', 'courier', 'rendezvous']
senticnet['unimportantial'] = [0.978, -0.905, 0, 0.962, '#joyful', '#admirable', 0.948, 'potty', 'unimportant', 'inconsequent', 'trivial', 'lightweight']
senticnet['odoriferous'] = [0, -0.929, 0, 0.962, '#surprising', '#admirable', 0.63, 'aromatize', 'perfumed', 'sweet', 'scent', 'odorous']
senticnet['gaffe'] = [0, 0, 0.844, -0.94, '#angry', '#disgusting', -0.595, 'rusticity', 'slip', 'solecism', 'gaucherie', 'faux_pas']
senticnet['pliant'] = [0.808, -0.699, 0, 0.938, '#joyful', '#admirable', 0.815, 'spinnable', 'susceptible', 'easy', 'impressible', 'plastic']
senticnet['tomorrow'] = [0.936, -0.796, 0, 0.552, '#joyful', '#surprising', 0.761, 'today', 'day_of_month', 'date', 'day', 'yesterday']
senticnet['preponderate'] = [0.904, -0.695, 0, 0.758, '#joyful', '#admirable', 0.786, 'override', 'overarch', 'outweigh', 'predominate', 'overbalance']
senticnet['windsor'] = [0, 0, 0, 0.087, '#admirable', '#admirable', 0.029, 'bee_hive', 'lair', 'habitat', 'grassy_field', 'pet_store']
senticnet['many_almost_alwayss'] = [-0.046, 0, -0.116, 0, '#sad', '#scared', -0.054, 'almost_always', 'book', 'almost_always_genre', 'saga', 'almost_always_poetry']
senticnet['steady'] = [0.056, 0.123, -0.074, 0.263, '#interesting', '#admirable', 0.123, 'arrive', 'come', 'arrival', 'tow', 'permission']
senticnet['scoreboard'] = [0.952, -0.527, 0, 0.835, '#joyful', '#admirable', 0.771, 'billboard', 'signboard', 'sandwich_board', 'hoarding', 'shingle']
senticnet['pettifog'] = [0, 0, -0.794, -0.803, '#scared', '#disgusting', -0.532, 'niggle', 'quiddity', 'bicker', 'quibble', 'cavil']
senticnet['buy_car_object'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'car', 'buy_car_motorbike', 'buy_car', 'purchase_car', 'buy']
senticnet['ablate_off'] = [-0.976, 0, 0.54, -0.553, '#sad', '#disgusting', -0.69, 'ablate', 'wear', 'ablate_out', 'ablate_down', 'ablate_thin']
senticnet['hear_newsifact'] = [0, -0.121, 0, 0, '#surprising', '#surprising', 0.04, 'read_news', 'read_letter', 'see_exhibit', 'see_art', 'hear_news']
senticnet['unchangeability'] = [-0.834, 0, 0.696, -0.989, '#sad', '#disgusting', -0.84, 'unalterability', 'immutability', 'changelessness', 'agelessness', 'unchangeableness']
senticnet['vagueness'] = [0.906, -0.601, 0, 0.653, '#joyful', '#admirable', 0.72, 'opaqueness', 'faintness', 'dimness', 'opacity', 'blurriness']
senticnet['unlace'] = [0.507, -0.507, 0, 0.676, '#joyful', '#surprising', 0.563, 'undo', 'unfold', 'untie', 'unbrace', 'spread']
senticnet['teras'] = [-0.947, 0, 0, -0.85, '#sad', '#disgusting', -0.599, 'abortus', 'spontaneous_abortion', 'miscarriage', 'fetus', 'vertebrate']
senticnet['chat_up'] = [0, 0, 0.849, -0.952, '#angry', '#disgusting', -0.6, 'dawdle', 'dally', 'toy', 'play', 'flirt']
senticnet['gimpiness'] = [-0.724, 0, 0, -0.915, '#sad', '#disgusting', -0.546, 'limping', 'lameness', 'claudication', 'gimp', 'gameness']
senticnet['taxi'] = [-0.063, 0.122, -0.046, 0.113, '#interesting', '#admirable', 0.042, 'bus', 'motorcycle', 'tram', 'airplane', 'plane']
senticnet['come_forth'] = [0, 0, -0.96, -0.998, '#scared', '#disgusting', -0.653, 'egress', 'go_forth', 'issue', 'come_out', 'emerge']
senticnet['swim'] = [0.703, 0.836, 0, 0, '#joyful', '#interesting', 0.513, 'backstroke', 'water_activity', 'movement_of_water', 'water_sport', 'swiming_pool']
senticnet['annually'] = [0, 0, -0.967, -0.871, '#scared', '#disgusting', -0.613, 'every_year', 'yearbook', 'each_year', 'yearly', 'annual']
senticnet['uninitiated'] = [-0.759, 0, 0, -0.85, '#sad', '#disgusting', -0.536, 'unskilled', 'amateur', 'inexperienced', 'uninformed', 'inexpert']
senticnet['blur_vision'] = [-0.071, 0, 0, 0, '#sad', '#sad', -0.024, 'near_tv', 'wear_glass', 'switch_tv', 'turn_on_tv', 'eyesight']
senticnet['ill-starred'] = [0, 0, -0.909, -0.938, '#scared', '#disgusting', -0.616, 'luckless', 'ill-omened', 'unlucky', 'doomed', 'ill-fated']
senticnet['stockpile'] = [0.853, -0.504, 0, 0.708, '#joyful', '#admirable', 0.688, 'hold', 'have_got', 'hold_on', 'stock', 'bear']
senticnet['obnubilate'] = [0, 0, -0.83, -0.919, '#scared', '#disgusting', -0.583, 'befog', 'fog', 'becloud', 'haze_over', 'obscured']
senticnet['resounding'] = [-0.726, 0, -0.897, 0, '#sad', '#scared', -0.541, 'reverberative', 'reverberating', 'resonant', 'resonating', 'evocative']
senticnet['stalin'] = [0.042, 0, 0.033, 0.068, '#joyful', '#admirable', 0.026, 'hull', 'sail_sea', 'yacht', 'seagoing_vessel', 'water_vehicle']
senticnet['outdistance'] = [0.995, 0, 0, 0.825, '#joyful', '#admirable', 0.607, 'outsell', 'trounce', 'outrun', 'outstrip', 'outpace']
senticnet['revelation'] = [0, 0.933, 0, 0.953, '#interesting', '#admirable', 0.629, 'figure_out', 'gather_fact', 'cognition', 'arrive_conclusion', 'become_aware']
senticnet['rejuvenate'] = [0.997, 0.805, 0, 0.803, '#joyful', '#interesting', 0.868, 'relax', 'feel_relaxed', 'relax_muscle', 'become_relaxed', 'relieve_tension']
senticnet['stymie'] = [0.704, -0.557, 0, 0.96, '#joyful', '#admirable', 0.74, 'save', 'foil', 'spoil', 'frustrate', 'foreclose']
senticnet['utilize'] = [0, 0, -0.888, -0.984, '#scared', '#disgusting', -0.624, 'apply', 'employ', 'expend', 'used', 'habituate']
senticnet['susurration'] = [0.563, -0.592, 0, 0.612, '#surprising', '#admirable', 0.589, 'whispering', 'voicelessness', 'whisper', 'speaking', 'speech']
senticnet['rationality'] = [0.539, -0.771, 0, 0.657, '#surprising', '#admirable', 0.656, 'logicality', 'quality', 'rationalness', 'completeness', 'consistency']
senticnet['gray-haired'] = [0, 0, -0.86, -0.799, '#scared', '#disgusting', -0.553, 'hoary', 'gray', 'rusty', 'canescent', 'grizzly']
senticnet['logical_fallacy_principii'] = [0.623, -0.532, 0, 0.873, '#joyful', '#admirable', 0.676, 'petitio', 'logical_fallacy', 'hysteron_proteron', 'fallacy', 'false_belief']
senticnet['station'] = [0.052, 0.118, 0.03, 0, '#joyful', '#interesting', 0.047, 'circular_route', 'cemetery', 'memorial', 'coliseum', 'row_house']
senticnet['white_apartment_house'] = [0.82, 0.976, 0, 0, '#joyful', '#interesting', 0.599, 'capitol', 'government_building', 'apartment_house', 'house', 'government']
senticnet['barmy'] = [0, 0.908, 0, 0.765, '#interesting', '#admirable', 0.558, 'daft', 'balmy', 'kooky', 'bonkers', 'loony']
senticnet['physics'] = [-0.066, 0.255, -0.155, 0.202, '#interesting', '#admirable', 0.079, 'human_trait', 'quantity', 'movement_towards', 'physical_quantity', 'velocity']
senticnet['footling'] = [0, 0, -0.868, -0.863, '#scared', '#disgusting', -0.577, 'picayune', 'lilliputian', 'little', 'fiddling', 'niggling']
senticnet['thongs'] = [0.997, 0.814, 0, 0, '#joyful', '#interesting', 0.604, 'stove', 'pan', 'spoon', 'cook_tool', 'pot']
senticnet['vitalize'] = [0.669, -0.814, 0, 0.515, '#joyful', '#surprising', 0.666, 'undergird', 'secure', 'reenforce', 'strengthen', 'reinforce']
senticnet['pictured'] = [0.716, -0.78, 0, 0.539, '#joyful', '#surprising', 0.678, 'depicted', 'delineated', 'portrayed', 'described', 'diagrammatic']
senticnet['spray'] = [0.054, -0.057, 0, 0.098, '#surprising', '#admirable', 0.07, 'magnetism', 'boom', 'physical_phenomenon', 'boil', 'vapor']
senticnet['self_complacent'] = [-0.796, 0, 0, -0.738, '#sad', '#disgusting', -0.511, 'complacency', 'self-complacency', 'complacence', 'self_satisfaction', 'complacent']
senticnet['serfhood'] = [-0.365, -0.082, 0, -0.327, '#sad', '#disgusting', -0.203, 'thrall', 'servitude', 'serfdom', 'bonded_labor', 'vassalage']
senticnet['off-the-wall'] = [0, -0.949, 0, 0.938, '#surprising', '#admirable', 0.629, 'freaky', 'outlandish', 'flaky', 'bizarre', 'gonzo']
senticnet['misconceive'] = [0, 0, -0.921, -0.928, '#scared', '#disgusting', -0.616, 'misapprehend', 'amiss', 'misinterpret', 'misunderstand', 'misconstrue']
senticnet['fair_game'] = [0, 0, -0.903, -0.934, '#scared', '#disgusting', -0.612, 'quarry', 'pit', 'stone_pit', 'target', 'prey']
senticnet['unsusceptibility'] = [0.73, -0.569, 0, 0.621, '#joyful', '#admirable', 0.64, 'exemption', 'amnesty', 'diplomatic_immunity', 'indemnity', 'impunity']
senticnet['respect_rule'] = [0.722, 0.865, 0, 0.748, '#interesting', '#admirable', 0.778, 'safety', 'avoid_crash', 'drive_safe', 'safety_belt', 'traffic_light']
senticnet['disseminate'] = [0, 0, -0.779, -0.979, '#scared', '#disgusting', -0.586, 'propagate', 'disseminating', 'spread', 'circulate', 'distribute']
senticnet['shortcut'] = [-0.046, 0.127, -0.121, 0.223, '#interesting', '#admirable', 0.061, 'shorten', 'abridge', 'curtail', 'cut_short', 'abbreviate']
senticnet['seemliness'] = [0.85, -0.858, 0, 0.712, '#joyful', '#surprising', 0.807, 'decency', 'decorum', 'decorousness', 'correctness', 'correctitude']
senticnet['gamy'] = [0, -0.899, 0, 0.932, '#surprising', '#admirable', 0.61, 'granular', 'gritty', 'spirited', 'farinaceous', 'coarse-grained']
senticnet['old_city'] = [0.609, -0.744, 0, 0.716, '#surprising', '#admirable', 0.69, 'city', 'malaysian_city', 'asia', 'malacca', 'colony']
senticnet['invillager'] = [0.9, -0.513, 0, 0.836, '#joyful', '#admirable', 0.75, 'dweller', 'inhabitant', 'habitant', 'villager', 'denizen']
senticnet['telling'] = [0, 0, -0.859, -0.798, '#scared', '#disgusting', -0.552, 'grave', 'weighty', 'heavy', 'cogent', 'grievous']
senticnet['sportive'] = [0.582, -0.783, 0, 0.795, '#surprising', '#admirable', 0.72, 'playful', 'elvish', 'kittenish', 'frisky', 'elfish']
senticnet['authoring_language_program'] = [-0.849, 0, 0.689, -0.907, '#sad', '#disgusting', -0.815, 'authoring_language', 'software', 'computer_authoring_language', 'authoring_language_system', 'authoring_language_package']
senticnet['good_orientation'] = [0.7, -0.646, 0, 0.953, '#joyful', '#admirable', 0.766, 'travel', 'compass', 'find_way', 'compass_direction', 'use_compass']
senticnet['visibility'] = [0.685, -0.912, 0, 0.566, '#joyful', '#surprising', 0.721, 'perceptibility', 'audibleness', 'visibleness', 'audibility', 'physical_property']
senticnet['picturesque'] = [0.528, -0.685, 0, 0.798, '#surprising', '#admirable', 0.67, 'gay', 'showy', 'colourful', 'sporty', 'brave']
senticnet['high-flown'] = [0.964, 0.975, 0, 0, '#joyful', '#interesting', 0.646, 'sublime', 'exalted', 'elevated', 'lofty', 'grand']
senticnet['subtraction'] = [0, 0.145, 0.056, 0.197, '#interesting', '#admirable', 0.095, 'add', 'equal', 'mathematical_operation', 'math_action', 'factor']
senticnet['university'] = [0.739, 0.825, 0, 0.782, '#interesting', '#admirable', 0.782, 'school_session', 'freshman', 'lesson', 'academy', 'undergraduate']
senticnet['prevailing'] = [0, 0, -0.928, -0.774, '#scared', '#disgusting', -0.567, 'overabundant', 'rife', 'plethoric', 'predominant', 'dominant']
senticnet['eletronic'] = [0.721, -0.883, 0, 0, '#joyful', '#surprising', 0.535, 'automatic', 'robotic', 'pistol', 'firearm', 'shoot_weapon']
senticnet['plasticity'] = [0.64, -0.95, 0, 0.639, '#joyful', '#surprising', 0.743, 'pliability', 'whip', 'bendability', 'malleability', 'flexibleness']
senticnet['skunk'] = [0, -0.977, 0, 0, '#surprising', '#surprising', 0.326, 'mountain_lion', 'cougar', 'lion', 'tiger', 'lynx']
senticnet['seclude'] = [0, 0, -0.787, -0.828, '#scared', '#disgusting', -0.538, 'seize', 'sequester', 'attach', 'impound', 'confiscate']
senticnet['twinkle'] = [0.847, -0.659, 0, 0.955, '#joyful', '#admirable', 0.82, 'bright', 'sparkle', 'verve', 'spark', 'energy']
senticnet['dispense_with'] = [0, 0, -0.981, -0.82, '#scared', '#disgusting', -0.6, 'foreswear', 'relinquish', 'waive', 'forgo', 'throw_overboard']
senticnet['imperious'] = [0, 0, -0.749, -0.932, '#scared', '#disgusting', -0.56, 'supercilious', 'haughty', 'disdainful', 'lordly', 'overbearing']
senticnet['slimed'] = [0, 0, -0.878, -0.88, '#scared', '#disgusting', -0.586, 'unworthy', 'despicable', 'ugly', 'slimy', 'vile']
senticnet['widow'] = [0, 0.73, 0, 0.889, '#interesting', '#admirable', 0.54, 'doe', 'nickname', 'pretty_woman', 'sophisticated', 'woman']
senticnet['tent'] = [0.786, 0, 0, 0, '#joyful', '#joyful', 0.262, 'camping', 'outdoor', 'camp_out', 'bonfire', 'fresh_air']
senticnet['plenteous'] = [0, 0.931, 0, 0.793, '#interesting', '#admirable', 0.575, 'copious', 'ample', 'plentiful', 'rich', 'sizable']
senticnet['supernova'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'giant', 'variable', 'binary_star', 'supergiant', 'star']
senticnet['sniff'] = [0.718, 0.929, 0, 0, '#joyful', '#interesting', 0.549, 'aroma', 'scent', 'smell', 'odor', 'fragrance']
senticnet['revitalized'] = [0.673, -0.95, 0, 0.914, '#surprising', '#admirable', 0.846, 'renewed', 'revived', 'resurgent', 'renascent', 'resuscitated']
senticnet['superpatriotic'] = [0.585, -0.7, 0, 0.586, '#surprising', '#admirable', 0.624, 'jingoistic', 'ultranationalistic', 'chauvinistic', 'nationalistic', 'patriotic']
senticnet['surface'] = [0.745, -0.771, 0, 0.655, '#joyful', '#surprising', 0.724, 'light', 'open', 'general_knowledge', 'common_knowledge', 'cognition']
senticnet['trigger_off'] = [0.724, 0.806, 0, 0, '#joyful', '#interesting', 0.51, 'initiate', 'activate', 'get_going', 'do_it_yourself', 'operate']
senticnet['riverside'] = [-0.03, 0.085, 0, 0.127, '#interesting', '#admirable', 0.061, 'small_stream', 'big_lake', 'reservoir', 'dam', 'oceanside']
senticnet['la-di-da'] = [0, 0, -0.89, -0.833, '#scared', '#disgusting', -0.574, 'hifalutin', 'grandiose', 'highfaluting', 'highfalutin', 'hoity-toity']
senticnet['propeller'] = [0, 0.993, 0, 0.87, '#interesting', '#admirable', 0.621, 'boat_part', 'hull', 'cleat', 'gunwale', 'stern']
senticnet['leery'] = [0, 0, -0.894, -0.941, '#scared', '#disgusting', -0.612, 'mistrustful', 'untrusting', 'suspicious', 'fishy', 'wary']
senticnet['velcro_product'] = [0.04, 0.091, -0.065, 0.066, '#interesting', '#admirable', 0.044, 'velcro', 'nylon', 'clothes', 'shoe', 'pants']
senticnet['roguishness'] = [0.738, -0.895, 0, 0.634, '#joyful', '#surprising', 0.756, 'rascality', 'monkey_business', 'mischievousness', 'deviltry', 'devilry']
senticnet['windmill'] = [0.996, 0, 0, 0, '#joyful', '#joyful', 0.332, 'breeze', 'wind', 'wind_energy', 'wind_turbine', 'windy']
senticnet['triangular'] = [0.06, -0.036, 0.037, 0.075, '#joyful', '#admirable', 0.045, 'semicircle', 'trapezoid', 'circle', 'cone', 'facet']
senticnet['urging'] = [0, 0, 0.722, -0.768, '#angry', '#disgusting', -0.497, 'prod', 'spur', 'needle', 'goad', 'prick']
senticnet['traditionalism'] = [0.646, -0.924, 0, 0.816, '#surprising', '#admirable', 0.795, 'conventionality', 'conventionalism', 'orthodoxy', 'traditionality', 'unoriginality']
senticnet['atheism'] = [-0.919, 0, 0, -0.75, '#sad', '#disgusting', -0.556, 'irreverence', 'disrespect', 'apostasy', 'impiety', 'sacrilege']
senticnet['predestine'] = [0.716, -0.718, 0, 0.736, '#surprising', '#admirable', 0.723, 'predestinate', 'predetermine', 'foreordain', 'influence', 'preordain']
senticnet['knell'] = [-0.957, 0, -0.9, 0, '#sad', '#scared', -0.619, 'ringed', 'reverberate', 'resound', 'peal', 'echo']
senticnet['unfeeling'] = [-0.911, 0, 0.886, 0, '#sad', '#angry', -0.599, 'thickened', 'tougheneded', 'heartless', 'callous', 'uncaring']
senticnet['swan'] = [0, 0, -0.794, -0.752, '#scared', '#disgusting', -0.515, 'meander', 'jog', 'ramble', 'roll', 'wander']
senticnet['recycle'] = [0.071, 0, 0.031, 0.064, '#joyful', '#admirable', 0.035, 'organic_matter', 'decompose', 'compost_pile', 'soil', 'fertiliser']
senticnet['sway'] = [0.073, 0, 0, 0.231, '#joyful', '#admirable', 0.101, 'swirl', 'dance_move', 'motion', 'rotate_movement', 'rotate']
senticnet['wee_moral_sense'] = [0.714, -0.583, 0, 0.667, '#joyful', '#admirable', 0.655, 'morality', 'small_voice', 'moral_sense', 'voice_of_conscience', 'sense_of_shame']
senticnet['subordinate'] = [0, 0, -0.833, -0.923, '#scared', '#disgusting', -0.585, 'qualified', 'dependent', 'pendant', 'subject', 'hooked']
senticnet['arse_around'] = [0, 0, -0.943, -0.781, '#scared', '#disgusting', -0.575, 'bum', 'bum_about', 'loll', 'droop', 'bum_around']
senticnet['room'] = [0.84, 0.852, 0, 0, '#joyful', '#interesting', 0.564, 'a_lot_of_space', 'space', 'capacity', 'house', 'universe']
senticnet['roof'] = [0.152, 0, 0.046, 0.128, '#joyful', '#admirable', 0.078, 'exterior', 'foundation', 'find_outside', 'umbrella', 'vane']
senticnet['damsel_human'] = [0.863, 0, 0, 0.753, '#joyful', '#admirable', 0.539, 'female', 'damsel_person', 'niece', 'damsel', 'woman']
senticnet['root'] = [0.034, 0.065, 0, 0.07, '#interesting', '#admirable', 0.056, 'leafy', 'renewable_resource', 'part_of_plant', 'leafy_green', 'green_color']
senticnet['hypnogogic'] = [0, 0, -0.757, -0.88, '#scared', '#disgusting', -0.546, 'somnific', 'hypnotic', 'soporific', 'somniferous', 'soporiferous']
senticnet['fictitious'] = [0.075, 0.207, -0.061, 0.12, '#interesting', '#admirable', 0.114, 'false', 'unreal', 'non_existent', 'fictional', 'imaginary']
senticnet['ventilation'] = [0, -0.01, 0, 0.069, '#surprising', '#admirable', 0.026, 'air_vent', 'move_air', 'fan', 'spin', 'circulate_air']
senticnet['palaver'] = [0, 0, -0.925, -0.823, '#scared', '#disgusting', -0.583, 'wheedle', 'sweet-talk', 'blarney', 'cajole', 'coax']
senticnet['transitory'] = [0, 0, -0.849, -0.705, '#scared', '#disgusting', -0.518, 'transient', 'transeunt', 'ephemeral', 'passing', 'short-lived']
senticnet['duplicitous'] = [0, 0, -0.901, -0.703, '#scared', '#disgusting', -0.535, 'ambidextrous', 'deceitful', 'double-dealing', 'janus-faced', 'two-handed']
senticnet['rashness'] = [0.991, -0.75, 0, 0.815, '#joyful', '#admirable', 0.852, 'incaution', 'incautiousness', 'mindlessness', 'heedlessness', 'imprudence']
senticnet['asbestos_boll'] = [-0.035, 0, 0, -0.045, '#sad', '#disgusting', -0.027, 'asbestos', 'silk', 'wool', 'cotton', 'velvet']
senticnet['woodwind'] = [0.821, -0.531, 0, 0.785, '#joyful', '#admirable', 0.712, 'flute', 'nose_flute', 'piccolo', 'fife', 'woodwind_instrument']
senticnet['spotter'] = [0, 0, -0.77, -0.752, '#scared', '#disgusting', -0.507, 'watch', 'lookout', 'sentry', 'lookout_man', 'sentinel']
senticnet['quarterback'] = [0.053, -0.025, 0, 0, '#joyful', '#surprising', 0.026, 'football_player', 'manager', 'scrabble', 'card_type', 'contest']
senticnet['salubrious'] = [0.656, -0.731, 0, 0.736, '#surprising', '#admirable', 0.708, 'good_for_you', 'alimentary', 'healthy', 'solid', 'wholesome']
senticnet['blub'] = [0, 0, -0.957, -0.828, '#scared', '#disgusting', -0.595, 'whine', 'blubber', 'sniffle', 'snuffle', 'sniveling']
senticnet['slaughterous'] = [0, 0, -0.75, -0.932, '#scared', '#disgusting', -0.561, 'bloodthirsty', 'sanguinary', 'gory', 'butcherly', 'sanguineous']
senticnet['septuagenarian'] = [0.556, -0.641, 0, 0.64, '#surprising', '#admirable', 0.612, 'golden_ager', 'nonagenarian', 'octogenarian', 'centenarian', 'sexagenarian']
senticnet['oscitant'] = [0, 0, -0.795, -0.773, '#scared', '#disgusting', -0.523, 'oscitancy', 'oscitance', 'gape', 'yawning', 'drowsy']
senticnet['testing'] = [0.809, -0.719, 0, 0.708, '#joyful', '#surprising', 0.745, 'tally', 'numeration', 'tap', 'scrutiny', 'investigating']
senticnet['physicist'] = [0.711, 0, 0, 0, '#joyful', '#joyful', 0.237, 'chemist', 'expert', 'scientist', 'esaminatore', 'analyst']
senticnet['bombinate'] = [0, 0, -0.709, -0.913, '#scared', '#disgusting', -0.541, 'buzzing', 'bombilate', 'hum', 'seethe', 'abuzz']
senticnet['presumable'] = [0.878, -0.678, 0, 0.631, '#joyful', '#surprising', 0.729, 'ponderable', 'conceivable', 'supposable', 'surmisable', 'thinkable']
senticnet['tint'] = [0, 0.123, -0.067, 0.11, '#interesting', '#admirable', 0.055, 'visible', 'reflect_light', 'colorful', 'hue', 'blue_green']
senticnet['wheedle'] = [0, 0, -0.925, -0.823, '#scared', '#disgusting', -0.583, 'cajole', 'sweet-talk', 'blarney', 'palaver', 'coax']
senticnet['rollerblade'] = [0.05, -0.043, 0, 0, '#joyful', '#surprising', 0.031, 'skate', 'roller_skate', 'skateboard', 'ice_skate', 'skating']
senticnet['downplay'] = [0, 0, -0.868, -0.782, '#scared', '#disgusting', -0.55, 'minimize', 'minimise', 'unpretentious', 'unostentatious', 'understated']
senticnet['vendetta'] = [-0.866, 0, 0.668, -0.543, '#sad', '#angry', -0.692, 'conflict', 'struggle', 'battle', 'blood_feud', 'feud']
senticnet['rub_off'] = [0, 0, 0.862, -0.768, '#angry', '#disgusting', -0.543, 'scour', 'abrase', 'abraded', 'corrade', 'rub_down']
senticnet['undaunted'] = [0.518, -0.863, 0, 0.501, '#joyful', '#surprising', 0.627, 'undismayed', 'unshaken', 'resolute', 'firm', 'stout']
senticnet['unicorn'] = [0, 0.732, 0, 0.934, '#interesting', '#admirable', 0.555, 'mythical_monster', 'mythical_creature', 'legendary_creature', 'griffins', 'doppelganger']
senticnet['cool_bad_drug'] = [-0.182, -0.078, 0, -0.203, '#sad', '#disgusting', -0.102, 'bad_drug_spill', 'bad_drug', 'atmosphere', 'water', 'obtain_bad_drug']
senticnet['boaster'] = [0, 0, 0.765, -0.748, '#angry', '#disgusting', -0.504, 'blowhard', 'braggart', 'vaunter', 'line-shooter', 'bragger']
senticnet['squander'] = [0.52, -0.9, 0, 0.767, '#surprising', '#admirable', 0.729, 'occupy', 'waste', 'pervert', 'expend', 'take']
senticnet['immoderatenessiveness'] = [-0.501, 0, 0.89, -0.786, '#angry', '#disgusting', -0.726, 'immoderateness', 'degree', 'grade', 'level', 'excess']
senticnet['proexclamationation'] = [0, 0.158, -0.123, 0.359, '#interesting', '#admirable', 0.131, 'statement', 'affirmation', 'clam', 'exclamation', 'proposition']
senticnet['tennis'] = [0, 0.257, -0.133, 0.306, '#interesting', '#admirable', 0.143, 'sport', 'match_point', 'set_point', 'violent_action', 'tennis_term']
senticnet['strengthening'] = [0.556, -0.923, 0, 0.762, '#surprising', '#admirable', 0.747, 'degeneration', 'improvement', 'betterment', 'transformation', 'sea_change']
senticnet['pimples'] = [-0.745, 0, 0, -0.735, '#sad', '#disgusting', -0.493, 'skin_condition', 'adolescent', 'acne_medication', 'medical_treatment', 'prescription']
senticnet['swoop'] = [0.954, -0.87, 0, 0.583, '#joyful', '#surprising', 0.802, 'penetration', 'air_raid', 'foray', 'air_attack', 'incursion']
senticnet['sovereignty'] = [0.94, -0.636, 0, 0.772, '#joyful', '#admirable', 0.783, 'paramountcy', 'raj', 'reign', 'dominion', 'suzerainty']
senticnet['bombardment'] = [0, 0, -0.858, -0.913, '#scared', '#disgusting', -0.59, 'onslaught', 'battery', 'shelling', 'barrage', 'outpouring']
senticnet['sordid'] = [-0.786, 0, 0.837, 0, '#sad', '#angry', -0.541, 'flyblown', 'seamy', 'seedy', 'squalid', 'sleazy']
senticnet['mucilaginous'] = [0, 0, -0.841, -0.83, '#scared', '#disgusting', -0.557, 'gluey', 'pasty', 'sticky', 'gummy', 'glutinous']
senticnet['shakeable'] = [0.544, -0.693, 0, 0.658, '#surprising', '#admirable', 0.632, 'shakable', 'challengeable', 'contestable', 'disputable', 'debatable']
senticnet['abuzz'] = [0, 0, -0.709, -0.913, '#scared', '#disgusting', -0.541, 'bombinate', 'bombilate', 'hum', 'seethe', 'buzzing']
senticnet['foreswear'] = [0, 0, -0.981, -0.82, '#scared', '#disgusting', -0.6, 'waive', 'relinquish', 'dispense_with', 'forgo', 'throw_overboard']
senticnet['piousal'] = [0.889, -0.694, 0, 0.908, '#joyful', '#admirable', 0.83, 'pious', 'pharisaic', 'sanctimonious', 'reverent', 'worshipful']
senticnet['sterility'] = [0.617, -0.592, 0, 0.805, '#joyful', '#admirable', 0.671, 'sanitation', 'hygiene', 'asepsis', 'sanitary_condition', 'sanitariness']
senticnet['tucker'] = [0.84, -0.725, 0, 0.796, '#joyful', '#admirable', 0.787, 'fag_out', 'tucker_out', 'exhaust', 'beat', 'overtire']
senticnet['befog'] = [0, 0, -0.83, -0.919, '#scared', '#disgusting', -0.583, 'obscured', 'fog', 'becloud', 'haze_over', 'obnubilate']
senticnet['tougheneded'] = [-0.911, 0, 0.886, 0, '#sad', '#angry', -0.599, 'thickened', 'callous', 'heartless', 'unfeeling', 'uncaring']
senticnet['speckless'] = [0, 0, -0.866, -0.738, '#scared', '#disgusting', -0.535, 'spic-and-span', 'spick-and-span', 'spic', 'immaculate', 'spotless']
senticnet['patrioteer'] = [0, 0, -0.888, -0.702, '#scared', '#disgusting', -0.53, 'jingo', 'hundred-percenter', 'flag-waver', 'chauvinist', 'jingoist']
senticnet['waiter'] = [0.797, -0.782, 0, 0, '#joyful', '#surprising', 0.526, 'beverage_service', 'bar_service', 'lounge', 'concierge', 'minibar']
senticnet['gaudy'] = [0, 0, 0.952, -0.775, '#angry', '#disgusting', -0.576, 'meretricious', 'showy', 'flashy', 'tatty', 'brassy']
senticnet['capsize'] = [0, 0, 0.864, -0.951, '#angry', '#disgusting', -0.605, 'preponderate', 'outweigh', 'predominate', 'overbalance', 'upset']
senticnet['incisive'] = [0, 0, 0.96, -0.928, '#angry', '#disgusting', -0.629, 'discriminating', 'acute', 'lament', 'knifelike', 'keen']
senticnet['voodoo'] = [0.667, -0.869, 0, 0.884, '#surprising', '#admirable', 0.807, 'fetish', 'juju', 'object', 'fetich', 'good_luck_charm']
senticnet['disunite'] = [0, 0, -0.789, -0.988, '#scared', '#disgusting', -0.592, 'separate', 'divide', 'part', 'differentiate', 'furcate']
senticnet['bombilate'] = [0, 0, -0.709, -0.913, '#scared', '#disgusting', -0.541, 'bombinate', 'buzzing', 'hum', 'seethe', 'abuzz']
senticnet['sear'] = [0, 0, -0.923, -0.966, '#scared', '#disgusting', -0.63, 'adust', 'scorched', 'parched', 'sunbaked', 'baked']
senticnet['screen'] = [0.044, 0.08, 0, -0.03, '#joyful', '#interesting', 0.031, 'computer_monitor', 'pixel', 'visual_information', 'image', 'display']
senticnet['pedal_cycle'] = [0.954, 0.919, 0, 0, '#joyful', '#interesting', 0.624, 'cycle', 'bicycle_across_town', 'bike', 'transportation', 'city']
senticnet['restroom'] = [-0.043, 0.066, 0, 0.149, '#interesting', '#admirable', 0.057, 'first_aid_kit', 'floor', 'bathroom_floor', 'floorboard', 'fish_tackle']
senticnet['sketchy'] = [0.903, -0.935, 0, 0.996, '#surprising', '#admirable', 0.945, 'incomplete', 'unelaborated', 'partial', 'uncompleted', 'broken']
senticnet['self_pride'] = [0, 0, 0.875, -0.793, '#angry', '#disgusting', -0.556, 'self_love', 'amour_propre', 'conceit', 'egotism', 'self-importance']
senticnet['tuning'] = [0.667, -0.885, 0, 0.92, '#surprising', '#admirable', 0.824, 'adjustment', 'activity', 'calibration', 'registration', 'readjustment']
senticnet['sufferable'] = [0.525, -0.799, 0, 0.593, '#surprising', '#admirable', 0.639, 'tolerant', 'resistant', 'tolerable', 'endurable', 'bearable']
senticnet['dramatic'] = [0.7, 0.922, 0, 0, '#joyful', '#interesting', 0.541, 'prominent', 'vivid', 'striking', 'conspicuous', 'flagrant']
senticnet['workweek'] = [0.769, -0.614, 0, 0.746, '#joyful', '#admirable', 0.71, 'day', 'period', 'hours', 'work_time', 'face_time']
senticnet['promising'] = [0.997, -0.655, 0, 0.569, '#joyful', '#surprising', 0.74, 'fortunate', 'rosy', 'auspicious', 'bright', 'hopeful']
senticnet['shopworn'] = [0, 0, -0.924, -0.94, '#scared', '#disgusting', -0.621, 'hackneyed', 'banal', 'stock', 'old-hat', 'commonplace']
senticnet['uncomplicated'] = [0.769, 0.98, 0, 0, '#joyful', '#interesting', 0.583, 'simple', 'elementary', 'unproblematic', 'basic', 'primary']
senticnet['clueless'] = [-0.981, 0, 0, -0.966, '#sad', '#disgusting', -0.649, 'naive', 'unenlightened', 'unread', 'unknowing', 'uninformed']
senticnet['authoring_language_system'] = [-0.849, 0, 0.689, -0.907, '#sad', '#disgusting', -0.815, 'authoring_language', 'authoring_language_program', 'computer_authoring_language', 'software', 'authoring_language_package']
senticnet['wiseman'] = [0.813, 0.916, 0, 0.841, '#interesting', '#admirable', 0.857, 'text_book', 'freedom_think', 'librarian', 'professor', 'teacher']
senticnet['princely'] = [0.92, 0.879, 0, 0, '#joyful', '#interesting', 0.6, 'luxurious', 'opulent', 'gilded', 'grand', 'deluxe']
senticnet['rough-cut'] = [0, 0, -0.972, -0.993, '#scared', '#disgusting', -0.655, 'harsh', 'common', 'coarse', 'uncouth', 'vulgar']
senticnet['harness'] = [-0.884, 0, 0, -0.734, '#sad', '#disgusting', -0.539, 'avail', 'use', 'exploit', 'utilise', 'overexploit']
senticnet['motherly'] = [0.734, 0, 0, 0.936, '#joyful', '#admirable', 0.557, 'caring', 'benevolent', 'benign', 'fatherly', 'warmer']
senticnet['spice'] = [0, 0.158, -0.125, 0.138, '#interesting', '#admirable', 0.057, 'canella', 'sweet', 'sweetener', 'smell_good', 'white_cinnamon']
senticnet['annihilate'] = [0, 0, -0.819, -0.995, '#scared', '#disgusting', -0.605, 'decimated', 'eradicate', 'extinguish', 'eliminate', 'wipe_out']
senticnet['hand_baggage'] = [0.027, -0.033, 0.027, 0.105, '#surprising', '#admirable', 0.046, 'luggage', 'baggage', 'passenger_ticket', 'ticket_counter', 'baggage_trunk']
senticnet['achievment'] = [0.786, 0, 0, 0.821, '#joyful', '#admirable', 0.536, 'expiation', 'atonement', 'propitiation', 'rescue', 'redemption']
senticnet['toss'] = [0, 0.951, 0, 0.83, '#interesting', '#admirable', 0.594, 'bounce_up_down', 'throw', 'play_catch', 'play', 'make_move']
senticnet['forking'] = [0, 0, -0.983, -0.715, '#scared', '#disgusting', -0.566, 'fork', 'branching', 'branch', 'ramification', 'leg']
senticnet['constellate'] = [0, -0.714, 0, 0.984, '#surprising', '#admirable', 0.566, 'stud', 'doting', 'disperse', 'adoring', 'fond']
senticnet['revolutionist'] = [-0.789, 0, -0.751, 0, '#sad', '#scared', -0.513, 'subversive', 'subverter', 'insurgent', 'seditious', 'revolutionary']
senticnet['situation'] = [-0.954, 0, -0.799, 0, '#sad', '#scared', -0.584, 'sudden', 'suddenly', 'lovely', 'translucent', 'obvious']
senticnet['high-and-mighty'] = [0, 0, 0.92, -0.958, '#angry', '#disgusting', -0.626, 'autocratic', 'dominating', 'bossy', 'magisterial', 'peremptory']
senticnet['weblike'] = [0, 0, -0.839, -0.759, '#scared', '#disgusting', -0.533, 'netted', 'net', 'lacy', 'netlike', 'webbed']
senticnet['grisly'] = [0, 0, 0.808, -0.91, '#angry', '#disgusting', -0.573, 'grim', 'ghastly', 'macabre', 'sick', 'gruesome']
senticnet['onslaught'] = [0, 0, -0.858, -0.913, '#scared', '#disgusting', -0.59, 'barrage', 'battery', 'shelling', 'bombardment', 'outpouring']
senticnet['questioning'] = [0, 0, -0.791, -0.761, '#scared', '#disgusting', -0.517, 'unbelieving', 'sceptical', 'doubting', 'disbelieving', 'skeptical']
senticnet['toothy'] = [0.845, -0.716, 0, 0.775, '#joyful', '#admirable', 0.779, 'cogged', 'toothed', 'sabertoothed', 'toothlike', 'tusked']
senticnet['licit'] = [0, 0.767, 0, 0.842, '#interesting', '#admirable', 0.536, 'true', 'rule-governed', 'legitimate', 'lawful', 'rightful']
senticnet['accumulate_stress_city'] = [-0.983, 0, 0.058, -0.921, '#sad', '#disgusting', -0.654, 'traffic_jam', 'accumulate_stress', 'stress', 'crowd', 'bad_service']
senticnet['sibyl'] = [0.686, -0.514, 0, 0.829, '#joyful', '#admirable', 0.676, 'diviner', 'oracle', 'auspex', 'prophetess', 'augur']
senticnet['unemotionality'] = [-0.709, 0, 0, -0.927, '#sad', '#disgusting', -0.545, 'impassiveness', 'impassivity', 'emotionlessness', 'apathetically', 'stolidity']
senticnet['bad_camera_time'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'slow', 'bad_camera', 'focus_time', 'long_focus', 'low_quality_photo']
senticnet['read_buy_newspaper'] = [-0.058, 0.106, 0, 0.06, '#interesting', '#admirable', 0.036, 'buy', 'buy_newspaper', 'newspaper', 'buy_book', 'read_news']
senticnet['uncaring'] = [-0.911, 0, 0.886, 0, '#sad', '#angry', -0.599, 'thickened', 'tougheneded', 'heartless', 'unfeeling', 'callous']
senticnet['transmutable'] = [0.623, -0.566, 0, 0.974, '#joyful', '#admirable', 0.721, 'commutable', 'convertible', 'translatable', 'transformable', 'alterable']
senticnet['decorous'] = [0.83, 0.727, 0, 0, '#joyful', '#interesting', 0.519, 'comme_il_faut', 'comely', 'seemly', 'becoming', 'decent']
senticnet['disbelieving'] = [0, 0, -0.791, -0.761, '#scared', '#disgusting', -0.517, 'unbelieving', 'sceptical', 'doubting', 'skeptical', 'questioning']
senticnet['bristly'] = [0, 0, -0.858, -0.728, '#scared', '#disgusting', -0.529, 'barbed', 'splenetic', 'prickly', 'barbellate', 'waspish']
senticnet['lightweight_knight_protection'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'protective_gear', 'knight_protection_ore', 'metal', 'knight_protection', 'knight']
senticnet['timber'] = [0.048, -0.097, 0, 0.086, '#surprising', '#admirable', 0.077, 'elm', 'tree', 'willow', 'pine', 'cedar']
senticnet['common_landland'] = [-0.907, 0, 0.765, -0.98, '#sad', '#disgusting', -0.884, 'pasture', 'grazing_land', 'ley', 'common_land', 'lea']
senticnet['proficient'] = [0, 0.933, 0, 0.768, '#interesting', '#admirable', 0.567, 'virtuoso', 'genius', 'expert', 'adept', 'skillful']
senticnet['balmy'] = [0, 0.908, 0, 0.765, '#interesting', '#admirable', 0.558, 'daft', 'kooky', 'barmy', 'bonkers', 'loony']
senticnet['retailer'] = [0.028, 0.146, 0, 0.105, '#interesting', '#admirable', 0.093, 'association', 'merchant', 'organization', 'department', 'company']
senticnet['translate'] = [0, 0.202, -0.067, 0.291, '#interesting', '#admirable', 0.142, 'vocabulary', 'interpreter', 'dictionary', 'translation', 'thesaurus']
senticnet['planet'] = [0, 0, 0, 0.119, '#admirable', '#admirable', 0.04, 'hemisphere', 'earth', 'spherical', 'planet_solar_system', 'terrain']
senticnet['yearbook'] = [0, 0, -0.967, -0.871, '#scared', '#disgusting', -0.613, 'every_year', 'yearly', 'each_year', 'annually', 'annual']
senticnet['shmooze'] = [0.651, -0.929, 0, 0.657, '#surprising', '#admirable', 0.746, 'schmooze', 'schmoose', 'chew_fat', 'shmoose', 'jawbone']
senticnet['underweight'] = [0, 0, 0.956, -0.963, '#angry', '#disgusting', -0.64, 'scraggy', 'boney', 'scrawny', 'skinny', 'weedy']
senticnet['uterus'] = [0.159, 0.068, -0.079, 0.118, '#joyful', '#admirable', 0.089, 'stomach', 'gravid', 'pregnant', 'lap', 'womb']
senticnet['analogue'] = [0, 0, 0.94, -0.769, '#angry', '#disgusting', -0.57, 'analog', 'one-dimensional', 'elongate', 'additive', 'linear']
senticnet['need_dentist'] = [-0.605, 0, 0.787, -0.909, '#angry', '#disgusting', -0.767, 'pain', 'tooth_disease', 'black_gum', 'discomfort', 'ugly_smile']
senticnet['overexploit'] = [-0.884, 0, 0, -0.734, '#sad', '#disgusting', -0.539, 'avail', 'use', 'harness', 'utilise', 'exploit']
senticnet['voracity'] = [0.768, -0.723, 0, 0.838, '#joyful', '#admirable', 0.776, 'gluttony', 'esurience', 'edacity', 'voraciousness', 'rapaciousness']
senticnet['trenchancy'] = [0.632, -0.804, 0, 0.537, '#joyful', '#surprising', 0.658, 'incisiveness', 'effectiveness', 'efficacy', 'efficaciousness', 'power']
senticnet['chouse'] = [-0.836, 0, 0.76, 0, '#sad', '#angry', -0.532, 'cheat', 'jockeying', 'screw', 'shaft', 'chicane']
senticnet['no_emotion'] = [0, 0, 0.981, -0.96, '#angry', '#disgusting', -0.647, 'uninteresting', 'bland', 'boring', 'banal', 'tasteless']
senticnet['yard'] = [0.844, 0, 0, 0, '#joyful', '#joyful', 0.281, 'outside_house', 'garden', 'back_house', 'backyard', 'outdoor']
senticnet['sack'] = [0, 0.089, 0.01, 0.118, '#interesting', '#admirable', 0.066, 'crate', 'mom_house', 'carrier', 'poker_game', 'safekeep']
senticnet['scant'] = [0, -0.887, 0, 0.728, '#surprising', '#admirable', 0.538, 'scrimp', 'economical', 'stinting', 'frugal', 'skimp']
senticnet['flump'] = [0, 0, -0.953, -0.711, '#scared', '#disgusting', -0.555, 'plank', 'plonk', 'plump', 'plop', 'plummet']
senticnet['bristled'] = [0, 0, -0.827, -0.782, '#scared', '#disgusting', -0.536, 'barbellate', 'briery', 'thorny', 'briary', 'barbed']
senticnet['throat'] = [0.718, -0.882, 0, 0.83, '#surprising', '#admirable', 0.81, 'bodily_cavity', 'pharynx', 'cavity', 'tubular_cavity', 'cavum']
senticnet['voluptuary'] = [0.897, -0.961, 0, 0.785, '#joyful', '#surprising', 0.881, 'erotic', 'epicure', 'sensualist', 'gourmet', 'gastronome']
senticnet['thicken'] = [0, 0.073, -0.052, 0.093, '#interesting', '#admirable', 0.038, 'condensation', 'condense_water', 'condensed_milk', 'weather_condition', 'condense']
senticnet['pass_glass'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'further_goal', 'pass_ball', 'pass', 'help', 'pass_exam']
senticnet['starch'] = [0.037, 0, 0, 0.063, '#joyful', '#admirable', 0.033, 'food_type', 'food_group', 'lard', 'carbohydrate', 'staple_food']
senticnet['predict_future'] = [0, 0.25, -0.227, 0.281, '#interesting', '#admirable', 0.101, 'psychic_phenomenon', 'clairvoyance', 'parapsychology', 'precognition', 'foreknowledge']
senticnet['wanton_away'] = [0, 0, -0.846, -0.822, '#scared', '#disgusting', -0.556, 'dalliance', 'piddle', 'trifling', 'wanton', 'dawdling']
senticnet['seasoned'] = [0.822, -0.863, 0, 0.818, '#joyful', '#surprising', 0.834, 'practiced', 'veteran', 'older', 'experienced', 'knowledgeable']
senticnet['haddryad'] = [-0.023, -0.012, 0.045, -0.051, '#angry', '#disgusting', -0.036, 'dock', 'pier', 'ferry', 'dryad', 'shallow']
senticnet['bighearted'] = [0.757, 0.837, 0, 0, '#joyful', '#interesting', 0.531, 'big', 'well-favored', 'good-looking', 'better-looking', 'handsome']
senticnet['preconceive'] = [0.624, -0.811, 0, 0.773, '#surprising', '#admirable', 0.736, 'find', 'design', 'conceive', 'discover', 'create_by_mental_act']
senticnet['wish_luck'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'try', 'assay', 'enjoy_challenge', 'take_chance', 'go_for_it']
senticnet['crosspiece'] = [0, 0, -0.778, -0.778, '#scared', '#disgusting', -0.519, 'transom', 'track', 'traverse', 'crossbeam', 'traversal']
senticnet['redeemable'] = [0.779, -0.882, 0, 0.521, '#joyful', '#surprising', 0.727, 'corrigible', 'correctable', 'improvable', 'reformable', 'amendable']
senticnet['reintroduce'] = [0.649, -0.619, 0, 0.723, '#joyful', '#admirable', 0.664, 'bring_out', 'present', 'acquaint', 'introduce', 'inform']
senticnet['apostasy'] = [-0.919, 0, 0, -0.75, '#sad', '#disgusting', -0.556, 'irreverence', 'disrespect', 'impiety', 'atheism', 'sacrilege']
senticnet['wether'] = [0.656, -0.817, 0, 0.909, '#surprising', '#admirable', 0.794, 'black_sheep', 'ewe', 'ram', 'tup', 'sheep']
senticnet['pleasant-tasting'] = [0.878, -0.765, 0, 0, '#joyful', '#surprising', 0.548, 'delicious', 'luscious', 'delectable', 'scrumptious', 'toothsome']
senticnet['socks'] = [0.856, 0, 0, 0, '#joyful', '#joyful', 0.285, 'christmas_tree', 'jingles', 'star', 'tree', 'christmas_tree_item']
senticnet['detain'] = [0, 0, -0.804, -0.819, '#scared', '#disgusting', -0.541, 'delayed', 'hold_up', 'stay', 'check', 'retard']
senticnet['bodyguard_of_guard'] = [-0.993, 0, 0.877, -0.777, '#sad', '#angry', -0.882, 'bodyguard', 'outrider', 'yeoman', 'beefeater', 'defender']
senticnet['inexpert'] = [-0.759, 0, 0, -0.85, '#sad', '#disgusting', -0.536, 'unskilled', 'amateur', 'uninitiated', 'uninformed', 'inexperienced']
senticnet['school'] = [0, -0.131, -0.053, 0.08, '#surprising', '#admirable', 0.053, 'science', 'biology_book', 'student', 'study_material', 'study_of_life']
senticnet['drabness'] = [-0.703, 0, 0, -0.729, '#sad', '#disgusting', -0.477, 'tastelessness', 'sleaziness', 'coarseness', 'commonness', 'inelegance']
senticnet['hubbard_winter_squash'] = [-0.562, 0, 0.696, -0.964, '#angry', '#disgusting', -0.741, 'winter_squash', 'acorn_winter_squash', 'squash', 'turban_winter_squash', 'butternut_winter_squash']
senticnet['large_border'] = [0.042, 0.082, 0.026, 0, '#joyful', '#interesting', 0.033, 'boundary', 'border', 'territory', 'land_area', 'land_mass']
senticnet['salvage'] = [0.825, -0.636, 0, 0.781, '#joyful', '#admirable', 0.747, 'deliverance', 'lifesaving', 'redemption', 'salvation', 'recovery']
senticnet['defile'] = [0, 0, -0.788, -0.875, '#scared', '#disgusting', -0.554, 'foul', 'sully', 'maculated', 'tarnish', 'stain']
senticnet['deform'] = [0, 0, -0.785, -0.786, '#scared', '#disgusting', -0.524, 'falsify', 'garble', 'warp', 'twist', 'distorted']
senticnet['herald'] = [0, 0.845, 0, 0.787, '#interesting', '#admirable', 0.544, 'praise', 'hail', 'acclaimed', 'applaud', 'clap']
senticnet['luculent'] = [0, 0, -0.937, -0.991, '#scared', '#disgusting', -0.643, 'pellucid', 'crystal_clear', 'limpid', 'transparent', 'crystalline']
senticnet['pinstripe'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'adornment', 'stripe', 'hatband', 'neckband', 'cigar_band']
senticnet['separable'] = [0.998, -0.635, 0, 0.574, '#joyful', '#surprising', 0.736, 'divisible', 'dissociable', 'cleavable', 'severable', 'dissociative']
senticnet['sound_level'] = [0, 0, 0.831, -0.903, '#angry', '#disgusting', -0.578, 'adjust_volume', 'speakers', 'noisy', 'making_a_lot_of_noise', 'hear_song']
senticnet['prosaicness'] = [0.741, -0.748, 0, 0.666, '#joyful', '#surprising', 0.718, 'mundaneness', 'mundanity', 'prosiness', 'commonplaceness', 'ordinariness']
senticnet['almost_always_genre'] = [-0.046, 0, -0.116, 0, '#sad', '#scared', -0.054, 'almost_always', 'many_almost_alwayss', 'book', 'saga', 'almost_always_poetry']
senticnet['strength_of_character'] = [0, 0.729, 0, 0.769, '#interesting', '#admirable', 0.499, 'charm', 'presence', 'aura', 'personality', 'charisma']
senticnet['beach_shooting_brake'] = [-0.539, 0, 0.905, -0.586, '#angry', '#disgusting', -0.677, 'wagon', 'station_shooting_brake', 'shooting_brake', 'estate_car', 'beach_waggon']
senticnet['puritanical'] = [0.682, -0.559, 0, 0.985, '#joyful', '#admirable', 0.742, 'renunciant', 'renunciative', 'puritanic', 'nonindulgent', 'corrective']
senticnet['preordain'] = [0.716, -0.718, 0, 0.736, '#surprising', '#admirable', 0.723, 'predestinate', 'predetermine', 'predestine', 'influence', 'foreordain']
senticnet['lack_of_interest'] = [-0.959, 0, 0, -0.983, '#sad', '#disgusting', -0.647, 'become_bored', 'boredom', 'extreme_boredom', 'get_bored', 'kill_brain_cell']
senticnet['drowsy'] = [0, 0, -0.795, -0.773, '#scared', '#disgusting', -0.523, 'oscitancy', 'oscitance', 'gape', 'oscitant', 'yawning']
senticnet['stone_pit'] = [0, 0, -0.903, -0.934, '#scared', '#disgusting', -0.612, 'fair_game', 'pit', 'quarry', 'target', 'prey']
senticnet['unmatchable'] = [0.816, -0.599, 0, 0.947, '#joyful', '#admirable', 0.787, 'matchless', 'nonpareil', 'one_and_only', 'peerless', 'incomparable']
senticnet['moldable'] = [0, 0, -0.811, -1.0, '#scared', '#disgusting', -0.604, 'charge_plate', 'fictile', 'charge_card', 'credit_card', 'plastic']
senticnet['tress'] = [0.034, 0.111, -0.094, 0.148, '#interesting', '#admirable', 0.066, 'up_mountain', 'hike_trail', 'ant_hill', 'fallen_leaf', 'grass']
senticnet['made_up'] = [-0.757, 0, 0, -0.754, '#sad', '#disgusting', -0.504, 'fabled', 'fictitious', 'pretend', 'make_believe', 'unreal']
senticnet['punctuate'] = [0.739, -0.764, 0, 0.977, '#surprising', '#admirable', 0.827, 'accent', 'stress', 'wave_off', 'play_down', 'emphasize']
senticnet['possessed'] = [0.858, -0.933, 0, 0.58, '#joyful', '#surprising', 0.79, 'regimented', 'obsessed', 'controlled', 'disciplined', 'dominated']
senticnet['spanner'] = [0.137, -0.11, 0.036, -0.032, '#joyful', '#surprising', 0.06, 'wrench', 'metal_rod', 'nut_bolt', 'vise', 'golf_club']
senticnet['railbird'] = [0.703, -0.513, 0, 0.811, '#joyful', '#admirable', 0.676, 'enthusiast', 'partizan', 'partisan', 'rooter', 'aficionado']
senticnet['scattering'] = [0.849, -0.547, 0, 0.543, '#joyful', '#surprising', 0.646, 'diffusion', 'spread', 'dispersion', 'invasion', 'irradiation']
senticnet['propitiate'] = [-0.752, 0, 0, -0.769, '#sad', '#disgusting', -0.507, 'pacify', 'appease', 'placate', 'reconcile', 'resignedly']
senticnet['boat_upper_deck'] = [0.831, -0.821, 0, 0.826, '#joyful', '#admirable', 0.826, 'upper_deck', 'freeboard_upper_deck', 'weather_upper_deck', 'shelter_upper_deck', 'deck']
senticnet['undismayed'] = [0.518, -0.863, 0, 0.501, '#joyful', '#surprising', 0.627, 'resolute', 'unshaken', 'undaunted', 'firm', 'stout']
senticnet['sponge'] = [0.866, -0.917, 0, 0.893, '#surprising', '#admirable', 0.892, 'mooch', 'freeload', 'grub', 'cadge', 'bum']
senticnet['usher'] = [0.26, 0, 0, 0.089, '#joyful', '#admirable', 0.116, 'mosh_pit', 'movie_theater_seat', 'row_seat', 'balcony_rail', 'sticky_floor']
senticnet['rapidity'] = [0.548, -0.622, 0, 0.695, '#surprising', '#admirable', 0.622, 'quickness', 'instancy', 'celerity', 'rapidness', 'speediness']
senticnet['see_chop_onion'] = [-0.059, 0, -0.071, 0, '#sad', '#scared', -0.043, 'cry', 'chop_onion', 'watch_sad_film', 'see_sad_show', 'sad_movie']
senticnet['newcomer'] = [0, 0, -0.983, -0.891, '#scared', '#disgusting', -0.625, 'freshman', 'neophyte', 'starter', 'fledgeling', 'entrant']
senticnet['ensure'] = [0.847, 0, 0, 0.71, '#joyful', '#admirable', 0.519, 'guarantee', 'assured', 'insure', 'ascertain', 'promise']
senticnet['springtide'] = [0.632, -0.613, 0, 0.525, '#joyful', '#surprising', 0.59, 'neap_tide', 'neap', 'direct_tide', 'high_tide', 'tide']
senticnet['sunlight'] = [0.833, 0.995, 0, 0, '#joyful', '#interesting', 0.609, 'bright', 'ray', 'shine_sun', 'daylight', 'sun_down']
senticnet['plumber'] = [0, 0.142, 0, 0.125, '#interesting', '#admirable', 0.089, 'gym_equipment', 'weight_machine', 'pulley', 'dumbbell', 'exercise_equipment']
senticnet['ccheekiness'] = [-0.891, 0, -0.922, -0.813, '#sad', '#scared', -0.875, 'rudeness', 'discourtesy', 'insolence', 'hutzpah', 'cheekiness']
senticnet['ugly_smile'] = [-0.605, 0, 0.787, -0.909, '#angry', '#disgusting', -0.767, 'pain', 'tooth_disease', 'need_dentist', 'discomfort', 'black_gum']
senticnet['tie-dye'] = [0.936, 0.749, 0, 0.871, '#joyful', '#admirable', 0.852, 'paint_picture', 'create_art', 'paint_house', 'make_patchwork_quilt', 'letter_sign']
senticnet['flushed'] = [0.953, 0, 0, 0.865, '#joyful', '#admirable', 0.606, 'fortunate', 'rose_colored', 'rose_cheeked', 'blushful', 'rosy']
senticnet['self-effacing'] = [-0.896, 0, -0.864, 0, '#sad', '#scared', -0.587, 'retiring', 'restrained', 'unemotional', 'untalkative', 'reticent']
senticnet['extort'] = [0, 0, -0.842, -0.864, '#scared', '#disgusting', -0.569, 'ding', 'force_out', 'gouge', 'nick', 'dent']
senticnet['reputability'] = [0.66, -0.842, 0, 0.712, '#surprising', '#admirable', 0.738, 'respectability', 'honorableness', 'venerability', 'venerableness', 'righteousness']
senticnet['pork'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'beef', 'brisket', 'french_toast', 'steak', 'ham']
senticnet['unmarriedded'] = [-0.73, 0, 0.729, -0.981, '#sad', '#disgusting', -0.813, 'unmarried', 'unwed', 'divorced', 'mateless', 'widowed']
senticnet['positiveness'] = [0.776, -0.667, 0, 0.778, '#joyful', '#admirable', 0.74, 'indisputability', 'provability', 'positivity', 'demonstrability', 'certainty']
senticnet['today'] = [0.936, -0.796, 0, 0.552, '#joyful', '#surprising', 0.761, 'day', 'day_of_month', 'date', 'tomorrow', 'yesterday']
senticnet['homogot'] = [0.537, -0.514, 0, 0.807, '#joyful', '#admirable', 0.619, 'lesbian', 'fairy', 'homoot', 'fag', 'homo']
senticnet['sandbag'] = [-0.876, 0, 0, -0.937, '#sad', '#disgusting', -0.604, 'turn_up_heat', 'turn_up_pressure', 'steamroller', 'steamroll', 'coerce']
senticnet['disruptive'] = [0, 0, -0.727, -0.853, '#scared', '#disgusting', -0.527, 'turbulent', 'troubled', 'tumultuous', 'riotous', 'churning']
senticnet['tracle'] = [-0.089, 0.106, 0, 0.125, '#interesting', '#admirable', 0.047, 'sugar', 'black_treacle', 'molasses', 'add_sugar', 'sugar_substitute']
senticnet['platform'] = [0.215, 0.194, -0.204, 0.279, '#joyful', '#admirable', 0.161, 'launch', 'mast', 'gondola', 'launch_platform', 'ocean']
senticnet['unpleasant-smelling'] = [0, 0, 0.933, -0.965, '#angry', '#disgusting', -0.633, 'worm_intestine', 'fur_keep_warm', 'bad_breath', 'halitosis', 'asthama']
senticnet['bats'] = [0, -0.96, 0, 0.721, '#surprising', '#admirable', 0.56, 'nutlike', 'balmy', 'nutty', 'barmy', 'batty']
senticnet['busty'] = [0, 0, -0.749, -0.756, '#scared', '#disgusting', -0.502, 'bosomy', 'curvy', 'buxom', 'curvaceous', 'full-bosomed']
senticnet['tumultuous'] = [0, 0, -0.727, -0.853, '#scared', '#disgusting', -0.527, 'disruptive', 'troubled', 'turbulent', 'riotous', 'churning']
senticnet['precooked'] = [0.801, -0.575, 0, 0.947, '#joyful', '#admirable', 0.774, 'embattled', 'equipped', 'fitted_out', 'prepared', 'fortified']
senticnet['pandemic'] = [-0.857, 0, 0, -0.982, '#sad', '#disgusting', -0.613, 'infectious', 'communicable', 'epidemic', 'contagious', 'epizootic']
senticnet['oafish'] = [-0.9, 0, -0.997, 0, '#sad', '#scared', -0.632, 'neandertal', 'loutish', 'swinish', 'boorish', 'neanderthal']
senticnet['tell'] = [-0.081, 0.109, -0.077, 0.184, '#interesting', '#admirable', 0.045, 'write_back', 'elaborate', 'response', 'give_answer', 'explain_detail']
senticnet['prissy'] = [0.682, -0.525, 0, 0.613, '#joyful', '#admirable', 0.607, 'nice', 'meticulous', 'fastidious', 'dainty', 'pernickety']
senticnet['posit'] = [0.863, -0.947, 0, 0.986, '#surprising', '#admirable', 0.932, 'postulate', 'assume', 'presuppose', 'presume', 'take_for_granted']
senticnet['questionable'] = [0.906, -0.624, 0, 0.698, '#joyful', '#admirable', 0.743, 'disavowable', 'confutable', 'refutable', 'deniable', 'confutative']
senticnet['illiterateic'] = [-0.901, 0, 0.76, -0.871, '#sad', '#disgusting', -0.844, 'illiterate', 'analphabet', 'functional_illiterate', 'ignoramus', 'know_nothing']
senticnet['good_number'] = [0.277, 0.161, 0, 0.337, '#joyful', '#admirable', 0.258, 'many', 'plenty', 'big_amount', 'abundant', 'a_lot']
senticnet['sendup'] = [0, 0, 0.79, -0.834, '#angry', '#disgusting', -0.541, 'mockery', 'parody', 'spoof', 'lampoon', 'burlesque']
senticnet['fatherly'] = [0.734, 0, 0, 0.936, '#joyful', '#admirable', 0.557, 'caring', 'benevolent', 'benign', 'warmer', 'motherly']
senticnet['cautionary'] = [0, 0, -0.853, -0.928, '#scared', '#disgusting', -0.594, 'reproachful', 'admonishing', 'exemplary', 'warning', 'admonitory']
senticnet['dawdle'] = [0, 0, 0.849, -0.952, '#angry', '#disgusting', -0.6, 'dally', 'chat_up', 'toy', 'play', 'flirt']
senticnet['wild_man'] = [0, 0, 0.808, -0.779, '#angry', '#disgusting', -0.529, 'monster', 'abominable_snowman', 'orang_pendek', 'yeti', 'abominable']
senticnet['railway'] = [-0.042, 0.114, 0, 0.086, '#interesting', '#admirable', 0.053, 'street', 'road', 'track', 'racetrack', 'pathway']
senticnet['overeact'] = [0, 0, -0.998, -0.768, '#scared', '#disgusting', -0.589, 'animal_behavior', 'fixed_pattern_of_behavior', 'animal_instinct', 'instinct', 'impulse']
senticnet['confutation'] = [0.872, 0.997, 0, 0, '#joyful', '#interesting', 0.623, 'controvert', 'refute', 'confute', 'negate', 'rebut']
senticnet['pilot'] = [-0.048, 0.105, -0.061, 0.115, '#interesting', '#admirable', 0.037, 'airplane', 'aeroplane', 'air_traffic', 'sky', 'jet']
senticnet['pomaded'] = [0.888, -0.683, 0, 0.914, '#joyful', '#admirable', 0.828, 'tidy', 'kempt', 'sleek', 'brushed', 'groomed']
senticnet['ragout'] = [0.974, 0.844, 0, 0, '#joyful', '#interesting', 0.606, 'main_course', 'stew', 'soup', 'cream_soup', 'goulash']
senticnet['use_oil_cartoon_character'] = [-0.073, 0, 0, -0.074, '#sad', '#disgusting', -0.049, 'cartoon_character', 'use_tool', 'mould', 'paint', 'buy_cartoon_character']
senticnet['justify'] = [0.832, 0.87, 0, 0, '#joyful', '#interesting', 0.567, 'show', 'imply', 'smack', 'incriminate', 'inculpate']
senticnet['get_hitched_with'] = [0.715, 0, 0, 0.793, '#joyful', '#admirable', 0.503, 'marry', 'hook_up_with', 'wed', 'conjoin', 'married']
senticnet['arboriform'] = [0, 0, -0.756, -0.88, '#scared', '#disgusting', -0.545, 'tree-living', 'dendroidal', 'arborous', 'arboreal', 'arborary']
senticnet['rouse'] = [0.781, -0.588, 0, 0.721, '#joyful', '#admirable', 0.697, 'turn_on', 'electrify', 'charge', 'agitate', 'excite']
senticnet['ovoid'] = [0, 0, -0.929, -0.823, '#scared', '#disgusting', -0.584, 'egg-shaped', 'oval', 'ovate', 'elliptical', 'prolate']
senticnet['cockeyed'] = [-0.889, 0, -0.758, 0, '#sad', '#scared', -0.549, 'skew-whiff', 'awry', 'wonky', 'askew', 'lopsided']
senticnet['resonating'] = [-0.726, 0, -0.897, 0, '#sad', '#scared', -0.541, 'reverberative', 'reverberating', 'resounding', 'resonant', 'evocative']
senticnet['sibilation'] = [0.524, -0.751, 0, 0.932, '#surprising', '#admirable', 0.736, 'accent', 'pronunciation', 'assibilation', 'mispronunciation', 'homophony']
senticnet['treason'] = [0.847, -0.721, 0, 0.927, '#joyful', '#admirable', 0.832, 'wrongdoing', 'treachery', 'perfidy', 'knavery', 'charlatanism']
senticnet['platter'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'cheese_platter', 'cold_cuts', 'cottage_cheese_platter', 'cheese', 'appetizer']
senticnet['generalize'] = [0, 0, -0.913, -0.829, '#scared', '#disgusting', -0.581, 'infer', 'extrapolate', 'deduce', 'derive', 'guess']
senticnet['geometrical_asymmetry'] = [-0.596, 0, 0.672, -0.831, '#angry', '#disgusting', -0.7, 'irregularity', 'radial_asymmetry', 'lopsidedness', 'skewness', 'asymmetry']
senticnet['feticide'] = [-0.955, 0, -0.986, 0, '#sad', '#scared', -0.647, 'death', 'abortion', 'sickness', 'miscarriage', 'spontaneous_abortion']
senticnet['prognostication'] = [0.851, -0.657, 0, 0.66, '#joyful', '#admirable', 0.723, 'omen', 'portent', 'presage', 'prognostic', 'auspice']
senticnet['sub'] = [0.679, -0.947, 0, 0.661, '#joyful', '#surprising', 0.762, 'submissive', 'cringing', 'groveling', 'bowing', 'wormlike']
senticnet['sun'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'volleyball', 'game', 'beach_ball', 'sand', 'fun']
senticnet['version'] = [0, 0.701, 0, 0.832, '#interesting', '#admirable', 0.511, 'superhero', 'grizzly_bear', 'brown_bear', 'elf', 'book_poetry']
senticnet['misbegotten'] = [0, 0, -0.826, -0.903, '#scared', '#disgusting', -0.576, 'spurious', 'inauthentic', 'misbegot', 'bastardly', 'specious']
senticnet['outmoded'] = [0, 0, -0.841, -0.882, '#scared', '#disgusting', -0.574, 'old_hat', 'demode', 'old', 'old-fashioned', 'antique']
senticnet['freethinker'] = [0, 0.736, 0, 0.836, '#interesting', '#admirable', 0.524, 'non-believer', 'doubter', 'agnostic', 'atheist', 'sceptic']
senticnet['ablate_down'] = [-0.976, 0, 0.54, -0.553, '#sad', '#disgusting', -0.69, 'ablate', 'ablate_off', 'ablate_out', 'wear', 'ablate_thin']
senticnet['never-ending'] = [0, 0, -0.972, -0.95, '#scared', '#disgusting', -0.641, 'unceasing', 'incessant', 'constant', 'ceaseless', 'perpetual']
senticnet['self-motivation'] = [0.097, 0.166, -0.05, 0, '#joyful', '#interesting', 0.071, 'place_bet', 'competitive_spirit', 'deserve', 'need_job', 'down_payment']
senticnet['glitter'] = [0.799, 0, 0, 0.897, '#joyful', '#admirable', 0.565, 'brightness', 'blaze', 'brilliance', 'glare', 'glister']
senticnet['seahorse'] = [0, -0.987, 0, 0.859, '#surprising', '#admirable', 0.615, 'porpoise', 'many_fishes', 'horizon', 'sea_wee', 'mermaid']
senticnet['store'] = [0, 0.07, 0, 0.067, '#interesting', '#admirable', 0.046, 'boot', 'put_groceries', 'extra_tyre', 'car_trunk', 'storage_place']
senticnet['unrelenting'] = [-0.969, 0, 0.836, 0, '#sad', '#angry', -0.602, 'stern', 'relentless', 'implacable', 'grim', 'merciless']
senticnet['bum_about'] = [0, 0, -0.943, -0.781, '#scared', '#disgusting', -0.575, 'bum', 'loll', 'arse_around', 'droop', 'bum_around']
senticnet['scotch_whiskey'] = [0, -0.886, 0, 0.93, '#surprising', '#admirable', 0.605, 'score', 'economical', 'scotch', 'spoil', 'scottish']
senticnet['borecrucifer'] = [-0.569, 0, 0.892, -0.784, '#angry', '#disgusting', -0.748, 'cole', 'cruciferwort', 'kail', 'crucifer', 'kale']
senticnet['adam_and_eden'] = [0, 0.085, 0, 0.146, '#interesting', '#admirable', 0.077, 'eve', 'garden', 'apple', 'eden', 'outdoor']
senticnet['stately'] = [0.898, -0.562, 0, 0.513, '#joyful', '#surprising', 0.658, 'courtly', 'imposing', 'dignified', 'distinguished', 'grand']
senticnet['forerunner'] = [0, 0, -0.773, -0.981, '#scared', '#disgusting', -0.585, 'harbingers', 'announce', 'precursor', 'predecessor', 'herald']
senticnet['vaunter'] = [0, 0, 0.765, -0.748, '#angry', '#disgusting', -0.504, 'boaster', 'braggart', 'blowhard', 'line-shooter', 'bragger']
senticnet['relentless'] = [-0.969, 0, 0.836, 0, '#sad', '#angry', -0.602, 'stern', 'implacable', 'unrelenting', 'grim', 'merciless']
senticnet['witch'] = [0.521, -0.552, 0, 0.657, '#surprising', '#admirable', 0.577, 'bewitch', 'enchant', 'jinx', 'hex', 'becharm']
senticnet['village'] = [0, 0, 0, 0.073, '#admirable', '#admirable', 0.024, 'large_area_land', 'settle_down', 'urban', 'settlement', 'rural']
senticnet['unconquered'] = [0.914, -0.547, 0, 0.803, '#joyful', '#admirable', 0.755, 'victorious', 'triumphant', 'unbowed', 'unbeaten', 'undefeated']
senticnet['warrant'] = [0.969, -0.977, 0, 0.946, '#joyful', '#surprising', 0.964, 'okay', 'indorse', 'sanction', 'approve', 'champion']
senticnet['unseen'] = [0.116, 0.129, -0.058, 0.053, '#joyful', '#interesting', 0.08, 'blown', 'weather_element', 'move_air', 'airy', 'breezy']
senticnet['treacle'] = [0.825, -0.916, 0, 0.626, '#joyful', '#surprising', 0.789, 'formulation', 'glop', 'mush', 'slop', 'sentimentalism']
senticnet['resourcefulness'] = [0.909, -0.734, 0, 0.894, '#joyful', '#admirable', 0.846, 'creativity', 'creativeness', 'creative_thinking', 'imagination', 'cleverness']
senticnet['every_year'] = [0, 0, -0.967, -0.871, '#scared', '#disgusting', -0.613, 'yearly', 'yearbook', 'each_year', 'annually', 'annual']
senticnet['rectitude'] = [0.998, -0.893, 0, 0.667, '#joyful', '#surprising', 0.853, 'honorableness', 'honourableness', 'morality', 'righteousness', 'honor']
senticnet['youthful'] = [0.895, 0, 0, 0.956, '#joyful', '#admirable', 0.617, 'new', 'untested', 'young', 'offspring', 'immature']
senticnet['abrase'] = [0, 0, 0.862, -0.768, '#angry', '#disgusting', -0.543, 'scour', 'abraded', 'rub_off', 'corrade', 'rub_down']
senticnet['summertime'] = [0.896, 0.857, 0, 0, '#joyful', '#interesting', 0.584, 'sunscreen', 'wear_sunscreen', 'sunblock', 'sunny_day', 'go_to_beach']
senticnet['statuesque'] = [0.636, -0.954, 0, 0.664, '#surprising', '#admirable', 0.751, 'voluptuous', 'buxom', 'sculptured', 'shapely', 'sculptural']
senticnet['two_barbs'] = [0, 0, 0, 0.071, '#admirable', '#admirable', 0.024, 'horse', 'barb', 'mule', 'buddhist', 'ride_barb']
senticnet['remunerative'] = [0.521, -0.859, 0, 0.727, '#surprising', '#admirable', 0.702, 'paid', 'remunerated', 'paying', 'stipendiary', 'compensated']
senticnet['nick'] = [0, 0, -0.842, -0.864, '#scared', '#disgusting', -0.569, 'ding', 'force_out', 'extort', 'gouge', 'dent']
senticnet['supererogatory'] = [0, 0, -0.956, -0.817, '#scared', '#disgusting', -0.591, 'spare', 'redundant', 'extra', 'superfluous', 'excess']
senticnet['dandy'] = [0.706, 0, 0, 0.756, '#joyful', '#admirable', 0.487, 'beau', 'male_admirer', 'boyfriend', 'rich', 'young_man']
senticnet['writer'] = [0.331, 0.119, 0.022, 0.229, '#joyful', '#admirable', 0.219, 'finish', 'book', 'read_new_book', 'finish_book', 'finish_work']
senticnet['timetable'] = [0, -0.757, 0, 0.944, '#surprising', '#admirable', 0.567, 'diary', 'program', 'database', 'schedule', 'calendar_book']
senticnet['thirsty'] = [0.919, -0.717, 0, 0.569, '#joyful', '#surprising', 0.735, 'desirous', 'avid', 'appetent', 'devouring', 'envious']
senticnet['algebra_equation'] = [0, 0.725, 0, 0.779, '#interesting', '#admirable', 0.501, 'calculus', 'algebra', 'algebraematics', 'math', 'algebraematical_function']
senticnet['speak_write'] = [0, 0.87, 0, 0.96, '#interesting', '#admirable', 0.61, 'ask_name', 'unfold', 'know_language', 'linguistics', 'subscribe']
senticnet['sentiment'] = [0, 0.906, 0, 0.883, '#interesting', '#admirable', 0.596, 'energy', 'tai_chi', 'emotion', 'human_emotion', 'convert_energy']
senticnet['utensil'] = [0.03, -0.05, 0, 0.059, '#surprising', '#admirable', 0.046, 'grease_trap', 'glass_front_cupboard', 'fork', 'spoon', 'spoon_fork']
senticnet['tenant'] = [0, 0.754, 0, 0.804, '#interesting', '#admirable', 0.519, 'citizien', 'ceiling_fan', 'resident', 'stair_rail', 'roommate']
senticnet['god_creation_galaxy'] = [0.052, 0, 0, 0.094, '#joyful', '#admirable', 0.049, 'orbit_around_sun', 'enormous', 'god_creation', 'milky', 'nasa']
senticnet['priority'] = [0, 0.798, 0, 0.787, '#interesting', '#admirable', 0.528, 'ponder', 'prioritize', 'put_two_together', 'think_creatively', 'make_right_decision']
senticnet['potty'] = [0.978, -0.905, 0, 0.962, '#joyful', '#admirable', 0.948, 'inconsequent', 'unimportant', 'unimportantial', 'trivial', 'lightweight']
senticnet['right-down'] = [0, 0, -0.915, -0.718, '#scared', '#disgusting', -0.544, 'absolute', 'out-and-out', 'rank', 'downright', 'sheer']
senticnet['pipe'] = [0.939, -0.717, 0, 0.775, '#joyful', '#admirable', 0.81, 'vox_angelica', 'voix_celeste', 'dulciana', 'diapason', 'organ_stop']
senticnet['agreed'] = [0.858, -0.891, 0, 0.719, '#joyful', '#surprising', 0.823, 'sign_contract', 'agreement', 'arrangement', 'promise', 'agreed_upon']
senticnet['pleaser'] = [0.54, -0.64, 0, 0.566, '#surprising', '#admirable', 0.582, 'bombshell', 'entertainer', 'mortal', 'busker', 'drawing_card']
senticnet['hornet_wasp'] = [-0.663, 0, 0.946, -0.554, '#sad', '#angry', -0.721, 'yellow_hornet', 'yellow_jacket', 'giant_hornet', 'hornet', 'vespid']
senticnet['ascertain'] = [0.847, 0, 0, 0.71, '#joyful', '#admirable', 0.519, 'guarantee', 'ensure', 'insure', 'assured', 'promise']
senticnet['uncompleted'] = [0.903, -0.935, 0, 0.996, '#surprising', '#admirable', 0.945, 'sketchy', 'unelaborated', 'partial', 'incomplete', 'broken']
senticnet['jog'] = [0, 0, -0.794, -0.752, '#scared', '#disgusting', -0.515, 'meander', 'ramble', 'swan', 'roll', 'wander']
senticnet['retrograde'] = [-0.801, 0, 0, -0.778, '#sad', '#disgusting', -0.526, 'reverse', 'backward', 'retral', 'primitive', 'benighted']
senticnet['spoonfeed'] = [0.633, -0.799, 0, 0.935, '#surprising', '#admirable', 0.789, 'reward', 'mentor', 'reinforce', 'instruct', 'lecture']
senticnet['enchain'] = [-0.773, 0, 0.871, -0.64, '#sad', '#angry', -0.761, 'hold', 'prisoner', 'prison', 'tie_down', 'chain_up']
senticnet['rooster'] = [0.039, 0.089, -0.081, 0.143, '#interesting', '#admirable', 0.063, 'jay', 'nightingale', 'stork', 'bird', 'hen']
senticnet['untested'] = [0.895, 0, 0, 0.956, '#joyful', '#admirable', 0.617, 'new', 'young', 'youthful', 'offspring', 'immature']
senticnet['urbanity'] = [0.603, -0.987, 0, 0.648, '#surprising', '#admirable', 0.746, 'gallantry', 'niceness', 'politeness', 'good_manners', 'politesse']
senticnet['rose_colored'] = [0.953, 0, 0, 0.865, '#joyful', '#admirable', 0.606, 'fortunate', 'rosy', 'rose_cheeked', 'blushful', 'flushed']
senticnet['pasty'] = [0, 0, -0.841, -0.83, '#scared', '#disgusting', -0.557, 'gluey', 'gummy', 'sticky', 'mucilaginous', 'glutinous']
senticnet['ripped'] = [0.909, 0.983, 0, 0, '#joyful', '#interesting', 0.631, 'old', 'elderly', 'age_well', 'matured', 'mentality']
senticnet['ash_gray'] = [0, 0.793, 0, 0.815, '#interesting', '#admirable', 0.536, 'gold', 'metal', 'silver', 'fluent', 'eloquent']
senticnet['pietistic'] = [0, 0, -0.939, -0.766, '#scared', '#disgusting', -0.568, 'pietistical', 'sanctimonious', 'pharisaic', 'holier-than-thou', 'pharisaical']
senticnet['weather'] = [0, 0, -0.717, -0.904, '#scared', '#disgusting', -0.54, 'thunderstorm', 'snow_storm', 'storm', 'blizzard', 'rainy']
senticnet['suburbs'] = [0.701, 0.939, 0, 0.718, '#interesting', '#admirable', 0.786, 'book_story', 'bed', 'seduce', 'jewish_community', 'fond_memory']
senticnet['scintillating'] = [0.65, -0.614, 0, 0.711, '#joyful', '#admirable', 0.658, 'lively', 'bouncing', 'spirited', 'peppy', 'zippy']
senticnet['moa_bird'] = [-0.681, 0, 0.956, -0.909, '#angry', '#disgusting', -0.849, 'giant_moa', 'anomalopteryx', 'moa', 'ratite', 'flightless_bird']
senticnet['squeal'] = [0.691, -0.973, 0, 0.771, '#surprising', '#admirable', 0.812, 'blate', 'let_loose', 'churr', 'honk', 'sibilate']
senticnet['cussed'] = [0, 0, -0.909, -0.739, '#scared', '#disgusting', -0.549, 'unrepentant', 'obstinate', 'flint', 'flinty', 'obdurate']
senticnet['clothes_shrinkage'] = [-0.996, 0, 0.327, -0.913, '#sad', '#disgusting', -0.745, 'shrinkage', 'shrink', 'become_small', 'remove_stain', 'fight_fire']
senticnet['scoffer'] = [0.826, -0.655, 0, 0.587, '#joyful', '#surprising', 0.689, 'devourer', 'vegetarian', 'eater', 'diner', 'dunker']
senticnet['famed'] = [0, 0.939, 0, 0.75, '#interesting', '#admirable', 0.563, 'observe', 'keep', 'celebrated', 'notable', 'renowned']
senticnet['scourge'] = [0.946, -0.638, 0, 0.889, '#joyful', '#admirable', 0.824, 'flagellate', 'leather', 'birch', 'beat', 'trounce']
senticnet['cellulose_nitratee'] = [-0.886, 0, 0.87, -0.761, '#sad', '#angry', -0.839, 'cellulose_ester', 'cellulose_nitrate', 'pyroxylin', 'pyrocellulose', 'nitrate']
senticnet['urbane'] = [0, 0, -0.814, -0.979, '#scared', '#disgusting', -0.598, 'svelte', 'refined', 'slim', 'lithesome', 'polished']
senticnet['waddle'] = [-0.8, 0, -0.804, 0, '#sad', '#scared', -0.535, 'coggle', 'paddle', 'dodder', 'toddle', 'totter']
senticnet['sensory'] = [0.16, 0.067, 0, 0.083, '#joyful', '#admirable', 0.103, 'antenna', 'aerial', 'arthropods', 'insect', 'connection']
senticnet['fibrous'] = [0, -0.877, 0, 0.779, '#surprising', '#admirable', 0.552, 'sinewy', 'tendinous', 'stringy', 'unchewable', 'brawny']
senticnet['ambuscade'] = [0, 0, -0.994, -0.726, '#scared', '#disgusting', -0.573, 'waylay', 'lurk', 'ambush', 'scupper', 'bushwhack']
senticnet['asia'] = [0.609, -0.744, 0, 0.716, '#surprising', '#admirable', 0.69, 'city', 'malaysian_city', 'malacca', 'old_city', 'colony']
senticnet['wiliness'] = [0.784, -0.595, 0, 0.846, '#joyful', '#admirable', 0.742, 'foxiness', 'slyness', 'astuteness', 'craftiness', 'cunning']
senticnet['glitz'] = [0, 0, 0.865, -0.808, '#angry', '#disgusting', -0.558, 'foolhardiness', 'thoughtlessness', 'desperation', 'unthoughtfulness', 'brashness']
senticnet['profoundness'] = [0, 0, -0.722, -0.93, '#scared', '#disgusting', -0.551, 'abstrusity', 'reconditeness', 'astuteness', 'abstruseness', 'profundity']
senticnet['eulogium'] = [0, 0, -0.857, -0.991, '#scared', '#disgusting', -0.616, 'paean', 'eulogy', 'encomium', 'pean', 'panegyric']
senticnet['stealthy'] = [0, 0, -0.77, -0.712, '#scared', '#disgusting', -0.494, 'backstair', 'surreptitious', 'sneak', 'sneaky', 'furtive']
senticnet['overabundant'] = [0, 0, -0.928, -0.774, '#scared', '#disgusting', -0.567, 'rife', 'prevailing', 'plethoric', 'predominant', 'dominant']
senticnet['applaudable'] = [0.991, 0, 0, 0.751, '#joyful', '#admirable', 0.581, 'noteworthy', 'valuable', 'deserve', 'meritable', 'sacred']
senticnet['wild_sheepi'] = [-0.799, 0, 0.667, -0.668, '#sad', '#disgusting', -0.711, 'argal', 'wild_sheep', 'urial', 'white_sheep', 'mountain_sheep']
senticnet['thickening'] = [0.652, -0.649, 0, 0.953, '#joyful', '#admirable', 0.751, 'heightening', 'aggravating', 'intensifying', 'exacerbating', 'deepening']
senticnet['prologue'] = [0.08, 0.153, -0.125, 0.224, '#interesting', '#admirable', 0.111, 'begin', 'edition', 'introduction', 'start_end', 'false_statement']
senticnet['bonkers'] = [0, 0.908, 0, 0.765, '#interesting', '#admirable', 0.558, 'daft', 'balmy', 'barmy', 'kooky', 'loony']
senticnet['platyhelminth'] = [-0.866, 0, 0.668, -0.543, '#sad', '#angry', -0.692, 'flatworm', 'blood_fluke', 'liver_fluke', 'schistosome', 'trematode']
senticnet['macabre'] = [0, 0, 0.808, -0.91, '#angry', '#disgusting', -0.573, 'grim', 'ghastly', 'gruesome', 'sick', 'grisly']
senticnet['pinched'] = [0, 0, -0.767, -0.95, '#scared', '#disgusting', -0.572, 'cadaverous', 'gaunt', 'haggard', 'bony', 'skeletal']
senticnet['storeroom'] = [0, -0.075, 0, 0, '#surprising', '#surprising', 0.025, 'garage', 'bicycle_storage_area', 'trunks', 'motor_oil', 'bicycle']
senticnet['gauzy'] = [0, 0, -0.994, -0.974, '#scared', '#disgusting', -0.656, 'gauze-like', 'filmy', 'diaphanous', 'gossamer', 'see-through']
senticnet['better-looking'] = [0.757, 0.837, 0, 0, '#joyful', '#interesting', 0.531, 'big', 'well-favored', 'good-looking', 'handsome', 'bighearted']
senticnet['torturing'] = [-0.795, 0, 0.903, 0, '#sad', '#angry', -0.566, 'excruciating', 'harrowing', 'agonizing', 'worry', 'fret']
senticnet['liberal'] = [0, -0.772, 0, 0.795, '#surprising', '#admirable', 0.522, 'return', 'dedicate', 'yield', 'giving', 'sacrifice']
senticnet['dotted'] = [0, 0, -0.994, -0.915, '#scared', '#disgusting', -0.636, 'specked', 'flecked', 'stipple', 'speckled', 'bespeckle']
senticnet['republic'] = [0.044, 0.133, -0.086, 0.087, '#interesting', '#admirable', 0.059, 'democracy', 'nation', 'democratic_country', 'free_country', 'nation_state']
senticnet['rousing'] = [0.588, -0.759, 0, 0.574, '#joyful', '#surprising', 0.64, 'change_of_state', 'improvement', 'beautification', 'degradation', 'change_of_color']
senticnet['think_over'] = [0, 0, -0.782, -0.99, '#scared', '#disgusting', -0.591, 'goddess', 'muse', 'chew_over', 'ponder', 'meditate']
senticnet['pursuant'] = [0.726, -0.888, 0, 0.529, '#joyful', '#surprising', 0.714, 'reconciled', 'accordant', 'agreeable', 'consistent', 'conformable']
senticnet['team'] = [0.867, -0.846, 0, 0.876, '#joyful', '#admirable', 0.863, 'meet', 'aggroup', 'team_up', 'embed', 'gang']
senticnet['same_sex_attraction'] = [0.754, 0, 0, 0.717, '#joyful', '#admirable', 0.49, 'homosexual', 'gay_person', 'gay', 'unconventional', 'open_minded']
senticnet['reminiscent'] = [0, 0, -0.707, -0.801, '#scared', '#disgusting', -0.503, 'resonant', 'remindful', 'smelling', 'redolent', 'evocative']
senticnet['freaky'] = [0, -0.949, 0, 0.938, '#surprising', '#admirable', 0.629, 'flaky', 'outlandish', 'off-the-wall', 'bizarre', 'gonzo']
senticnet['old_hat'] = [0, 0, -0.841, -0.882, '#scared', '#disgusting', -0.574, 'old-fashioned', 'demode', 'old', 'outmoded', 'antique']
senticnet['bowl_alley_center'] = [0.101, 0.074, 0.03, 0, '#joyful', '#interesting', 0.048, 'bowl_alley', 'pins', 'sports', 'challenge', 'bowling']
senticnet['ablate_out'] = [-0.976, 0, 0.54, -0.553, '#sad', '#disgusting', -0.69, 'ablate', 'ablate_off', 'wear', 'ablate_down', 'ablate_thin']
senticnet['cavil'] = [0, 0, -0.794, -0.803, '#scared', '#disgusting', -0.532, 'niggle', 'quiddity', 'bicker', 'pettifog', 'quibble']
senticnet['broad_leaved_centaury'] = [-0.902, 0, 0.726, -0.534, '#sad', '#angry', -0.721, 'centaury', 'rosita', 'lesser_centaury', 'tufted_centaury', 'seaside_centaury']
senticnet['yielding'] = [0.625, -0.501, 0, 0.822, '#joyful', '#admirable', 0.649, 'meek', 'tame', 'docile', 'sheeplike', 'sheepish']
senticnet['self-collected'] = [0, 0, -0.821, -0.729, '#scared', '#disgusting', -0.517, 'balance', 'equanimous', 'brace', 'collected', 'poised']
senticnet['revery'] = [0.846, -0.928, 0, 0.504, '#joyful', '#surprising', 0.759, 'woolgathering', 'daydreaming', 'daydream', 'reverie', 'dreaming']
senticnet['sublimate'] = [0.969, -0.868, 0, 0.631, '#joyful', '#surprising', 0.823, 'assuage', 'perfect', 'make_look_better', 'relieve', 'fructify']
senticnet['emblematic'] = [0, 0, -0.828, -0.831, '#scared', '#disgusting', -0.553, 'model', 'exemplary', 'typic', 'admonitory', 'cautionary']
senticnet['chubby'] = [0, 0, 0.931, -0.749, '#angry', '#disgusting', -0.56, 'overweight', 'become_fat', 'large', 'heavy', 'get_fat']
senticnet['damsel_person'] = [0.863, 0, 0, 0.753, '#joyful', '#admirable', 0.539, 'damsel_human', 'female', 'niece', 'damsel', 'woman']
senticnet['future'] = [0, 0, -0.739, -0.968, '#scared', '#disgusting', -0.569, 'side_by_side', 'succeeding', 'following', 'adjacent', 'next']
senticnet['scuba'] = [-0.04, 0.069, 0, 0.075, '#interesting', '#admirable', 0.035, 'scuba_gear', 'go_to_swimming_pool', 'learn_swimming', 'jump_into_water', 'enjoy_nature']
senticnet['prospect'] = [0.554, -0.78, 0, 0.792, '#surprising', '#admirable', 0.709, 'latency', 'chance', 'possibility', 'possibleness', 'potentiality']
senticnet['needle_filament'] = [-0.036, -0.044, 0.079, -0.092, '#angry', '#disgusting', -0.054, 'string', 'bandage', 'suture', 'filament', 'thread']
senticnet['yammer'] = [0, 0, -0.918, -0.726, '#scared', '#disgusting', -0.548, 'brood', 'stew', 'whine', 'grizzled', 'yawp']
senticnet['liable'] = [0.819, 0.914, 0, 0, '#joyful', '#interesting', 0.578, 'appropriate', 'suitable', 'proper', 'apt', 'likely']
senticnet['scrutinise'] = [0, 0, -0.705, -0.763, '#scared', '#disgusting', -0.489, 'scrutinize', 'inspect', 'size_up', 'take_stock', 'audit']
senticnet['supermarket'] = [0.71, 0.815, 0, 0, '#joyful', '#interesting', 0.508, 'buy_meat', 'buy_grocery', 'compare_price', 'purchase_grocery', 'make_dinner']
senticnet['epigonr'] = [-0.627, 0, 0.667, -0.853, '#angry', '#disgusting', -0.716, 'copycat', 'emulator', 'ape', 'imitator', 'epigon']
senticnet['stalactite'] = [0.066, 0, -0.059, 0.066, '#joyful', '#admirable', 0.024, 'cyclist', 'smoker', 'homeowner', 'programmer', 'chauffeur']
senticnet['precariousness'] = [0.602, -0.728, 0, 0.892, '#surprising', '#admirable', 0.741, 'unlikelihood', 'unlikeliness', 'uncertainty', 'improbability', 'uncertainness']
senticnet['shanty'] = [0.846, -0.665, 0, 0.941, '#joyful', '#admirable', 0.817, 'hut', 'mudhif', 'hutch', 'shack', 'hovel']
senticnet['entangle'] = [0, 0, -0.979, -0.728, '#scared', '#disgusting', -0.569, 'snarling', 'tangle', 'snarl_up', 'snap', 'mat']
senticnet['high_school_choral'] = [0.023, 0.303, -0.087, 0.261, '#interesting', '#admirable', 0.167, 'band', 'drum_set', 'choral', 'string_quartet', 'school_choral']
senticnet['potentiate'] = [0.737, -0.808, 0, 0.611, '#joyful', '#surprising', 0.719, 'enhance', 'intensify', 'deepen', 'compound', 'heighten']
senticnet['knock_down'] = [-0.638, 0, 0.867, -0.57, '#sad', '#angry', -0.692, 'topple', 'flip', 'blow_over', 'fly_away', 'blow']
senticnet['reinvigorated'] = [0, 0.877, 0, 0, '#interesting', '#interesting', 0.292, 'cleaned', 'after_shower', 'shower', 'feel_refreshed', 'relax_time']
senticnet['fifty-fifty'] = [0, 0, -0.837, -0.998, '#scared', '#disgusting', -0.612, 'flush', 'level', 'even', 'regular', 'tied']
senticnet['vocabulary'] = [0, 0.846, 0, 0.798, '#interesting', '#admirable', 0.548, 'book_library', 'read_material', 'book_genre', 'many_words', 'definition']
senticnet['sparkly'] = [0, 0, 0.762, -0.835, '#angry', '#disgusting', -0.532, 'glisten', 'scintillating', 'fulgid', 'coruscant', 'glittering']
senticnet['roulotte'] = [0.027, 0, 0.026, 0.073, '#joyful', '#admirable', 0.025, 'large_automobile', 'expensive_car', 'limousine', 'means_of_transport', 'automatic_car']
senticnet['unostentatious'] = [0.737, -0.854, 0, 0.623, '#joyful', '#surprising', 0.738, 'understated', 'esthetic', 'tasteful', 'artistic', 'aesthetic']
senticnet['lout'] = [0, 0, -0.756, -0.851, '#scared', '#disgusting', -0.536, 'oaf', 'clod', 'goon', 'stumblebum', 'lummox']
senticnet['tapestry'] = [0.047, 0, 0, 0.055, '#joyful', '#admirable', 0.034, 'painting', 'sculpture', 'oil_painting', 'artwork', 'mural']
senticnet['equanimous'] = [0, 0, -0.821, -0.729, '#scared', '#disgusting', -0.517, 'balance', 'poised', 'brace', 'collected', 'self-collected']
senticnet['refutable'] = [0.906, -0.624, 0, 0.698, '#joyful', '#admirable', 0.743, 'disavowable', 'questionable', 'confutable', 'deniable', 'confutative']
senticnet['misapprehend'] = [0, 0, -0.921, -0.928, '#scared', '#disgusting', -0.616, 'misconstrue', 'amiss', 'misinterpret', 'misunderstand', 'misconceive']
senticnet['asthama'] = [0, 0, 0.933, -0.965, '#angry', '#disgusting', -0.633, 'worm_intestine', 'fur_keep_warm', 'unpleasant-smelling', 'halitosis', 'bad_breath']
senticnet['neanderthal'] = [-0.9, 0, -0.997, 0, '#sad', '#scared', -0.632, 'neandertal', 'loutish', 'swinish', 'oafish', 'boorish']
senticnet['psychology'] = [-0.049, 0.192, -0.079, 0.152, '#interesting', '#admirable', 0.072, 'hypothetical', 'supposition', 'scientific_statement', 'darwin', 'educate_guess']
senticnet['mountain_cougar'] = [0, -0.977, 0, 0, '#surprising', '#surprising', 0.326, 'lion', 'skunk', 'cougar', 'tiger', 'lynx']
senticnet['mawkish'] = [0, 0, -0.753, -0.986, '#scared', '#disgusting', -0.58, 'kitschy', 'maudlin', 'drippy', 'hokey', 'bathetic']
senticnet['high_choral'] = [0.023, 0.303, -0.087, 0.261, '#interesting', '#admirable', 0.167, 'school_band', 'drum_set', 'band', 'string_quartet', 'choral']
senticnet['yawp'] = [0, 0, -0.918, -0.726, '#scared', '#disgusting', -0.548, 'brood', 'stew', 'whine', 'yammer', 'grizzled']
senticnet['odorous'] = [0, -0.929, 0, 0.962, '#surprising', '#admirable', 0.63, 'aromatize', 'odoriferous', 'sweet', 'scent', 'perfumed']
senticnet['fulgid'] = [0, 0, 0.762, -0.835, '#angry', '#disgusting', -0.532, 'glisten', 'scintillating', 'glittering', 'coruscant', 'sparkly']
senticnet['sideboard'] = [0.054, -0.077, 0.025, 0, '#joyful', '#surprising', 0.035, 'table', 'glass_front_cupboard', 'gate_leg_table', 'dine_table', 'dine_room_table']
senticnet['fairy_candle'] = [-0.524, 0, 0.527, -0.782, '#angry', '#disgusting', -0.611, 'herb', 'black_snakeroot', 'actaea_racemosa', 'black_bugbane', 'black_cohosh']
senticnet['get_awake'] = [0, 0.08, 0, 0.179, '#interesting', '#admirable', 0.086, 'wake_up_morning', 'awake', 'up_early', 'gather_energy_tomorrow', 'sit_chair']
senticnet['jerry-built'] = [0, 0, 0.863, -0.745, '#angry', '#disgusting', -0.536, 'shoddy', 'tawdry', 'misleading', 'deceptive', 'cheapjack']
senticnet['vindicatory'] = [0.579, -0.541, 0, 0.784, '#joyful', '#admirable', 0.635, 'forgiving', 'absolvitory', 'exculpatory', 'exonerative', 'extenuating']
senticnet['sensitiveness'] = [0.698, -0.614, 0, 0.619, '#joyful', '#admirable', 0.644, 'sensitivity', 'excitability', 'irritability', 'sensibility', 'reactivity']
senticnet['sobriety'] = [0.916, -0.737, 0, 0.797, '#joyful', '#admirable', 0.817, 'natural_virtue', 'abstemiousness', 'dryness', 'temperance', 'restraint']
senticnet['elevated'] = [0.964, 0.975, 0, 0, '#joyful', '#interesting', 0.646, 'sublime', 'exalted', 'lofty', 'high-flown', 'grand']
senticnet['lithesome'] = [0, 0, -0.814, -0.979, '#scared', '#disgusting', -0.598, 'urbane', 'refined', 'slim', 'svelte', 'polished']
senticnet['sandman'] = [0.526, -0.997, 0, 0.673, '#surprising', '#admirable', 0.732, 'faery', 'faerie', 'fairy', 'leprechaun', 'imp']
senticnet['acute'] = [0, 0, 0.96, -0.928, '#angry', '#disgusting', -0.629, 'discriminating', 'keen', 'lament', 'knifelike', 'incisive']
senticnet['trueness'] = [0.553, -0.728, 0, 0.752, '#surprising', '#admirable', 0.678, 'jingoism', 'chauvinism', 'loyalty', 'nationalism', 'superpatriotism']
senticnet['sight'] = [0.959, -0.976, 0, 0.633, '#joyful', '#surprising', 0.856, 'oxyopia', 'acuity', 'top', 'vision', 'visual_sense']
senticnet['wrongful'] = [0, 0, -0.948, -0.78, '#scared', '#disgusting', -0.576, 'illegitimate', 'unconventional', 'illicit', 'unlawful', 'improper']
senticnet['wildlife'] = [0, -0.101, 0, 0, '#surprising', '#surprising', 0.034, 'mammal', 'cage', 'reptile', 'animal', 'zoo']
senticnet['byzantine'] = [0, 0, 0.968, -0.83, '#angry', '#disgusting', -0.599, 'convoluted', 'knotty', 'tangled', 'involved', 'tortuous']
senticnet['infirmaryto'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'infirmary', 'infirmaryte', 'lazar_house', 'pesthouse', 'lazaret']
senticnet['infirmaryte'] = [-0.962, 0, 0.261, -0.95, '#sad', '#disgusting', -0.724, 'infirmary', 'lazaret', 'lazar_house', 'pesthouse', 'infirmaryto']
senticnet['piddle'] = [0, 0, -0.846, -0.822, '#scared', '#disgusting', -0.556, 'dalliance', 'trifling', 'wanton_away', 'wanton', 'dawdling']
senticnet['unzip'] = [0.164, 0.13, 0.031, 0.209, '#joyful', '#admirable', 0.157, 'watch_good_movie', 'good_sense_of_humor', 'able_read', 'spare_time', 'strong_relationship']
senticnet['mental_amentia'] = [-0.602, 0, 0.827, -0.762, '#angry', '#disgusting', -0.73, 'slowness', 'retardation', 'backwardness', 'subnormality', 'amentia']
senticnet['snowshoe'] = [0.847, 0, 0, 0.858, '#joyful', '#admirable', 0.568, 'displace', 'swing', 'dodge', 'shuttle', 'bang']
senticnet['porter'] = [0.743, -0.814, 0, 0, '#joyful', '#surprising', 0.519, 'bar_service', 'beverage_service', 'luggage_trolley', 'concierge', 'minibar']
senticnet['word-painting'] = [0, 0, -0.999, -0.848, '#scared', '#disgusting', -0.616, 'word_picture', 'picture', 'delineation', 'depiction', 'characterization']
senticnet['cosset'] = [0, 0, -0.73, -0.945, '#scared', '#disgusting', -0.558, 'cocker', 'baby', 'coddle', 'featherbed', 'pamper']
senticnet['overgenerous'] = [0, -0.92, 0, 0.783, '#surprising', '#admirable', 0.568, 'shower', 'munificent', 'lavish', 'unsparing', 'too-generous']
senticnet['confiscate'] = [0, 0, -0.787, -0.828, '#scared', '#disgusting', -0.538, 'seize', 'seclude', 'attach', 'impound', 'sequester']
senticnet['trumpet'] = [0.063, 0.089, 0.036, 0.146, '#interesting', '#admirable', 0.087, 'horn', 'jew_harp', 'brass_instrument', 'antler', 'crash_cymbal']
senticnet['renascent'] = [0.673, -0.95, 0, 0.914, '#surprising', '#admirable', 0.846, 'renewed', 'revitalized', 'resurgent', 'revived', 'resuscitated']
senticnet['seatbelt'] = [0.802, 0.805, 0, 0, '#joyful', '#interesting', 0.536, 'dashboard', 'battery', 'car_stereo', 'spare_tire', 'brake_pedal']
senticnet['vacnat'] = [-0.614, 0, 0.738, -0.803, '#angry', '#disgusting', -0.718, 'empty_room', 'empty_space', 'empty', 'empty_house', 'aimless']
senticnet['steerable'] = [0.5, -0.9, 0, 0.525, '#surprising', '#admirable', 0.642, 'manageable', 'controllable', 'governable', 'administrable', 'dirigible']
senticnet['marrow'] = [0, 0, 0.861, -0.816, '#angry', '#disgusting', -0.559, 'pith', 'kernel', 'centre', 'core', 'substance']
senticnet['reference'] = [0.083, 0.179, -0.132, 0.256, '#interesting', '#admirable', 0.129, 'vocabulary', 'translation', 'sentence', 'narrative', 'refer']
senticnet['spaceship'] = [-0.045, 0.092, 0, 0.062, '#interesting', '#admirable', 0.036, 'hangar', 'blimp', 'hot_air_balloon', 'war_museum', 'aircraft_carrier']
senticnet['co-op'] = [0, 0, -0.764, -0.874, '#scared', '#disgusting', -0.546, 'cooperative', 'concerted', 'conjunct', 'conjunctive', 'accommodative']
senticnet['steel'] = [0.93, -0.78, 0, 0.873, '#joyful', '#admirable', 0.861, 'blade', 'brand', 'broadsword', 'claymore', 'sword']
senticnet['tortured'] = [0, 0, 0.704, -0.735, '#angry', '#disgusting', -0.48, 'pain', 'hurt', 'tormented', 'anguished', 'rage']
senticnet['studying'] = [0.572, -0.724, 0, 0.521, '#joyful', '#surprising', 0.606, 'browse', 'reading', 'perusing', 'poring_over', 'perusal']
senticnet['eucharist'] = [0.762, 0, 0, 0.894, '#joyful', '#admirable', 0.552, 'holy', 'liturgy', 'holy_eucharist', 'holy_sacrament', 'sacrament_of_eucharist']
senticnet['invalidityalness'] = [-0.551, 0, 0.741, -0.768, '#angry', '#disgusting', -0.687, 'invalidityality', 'illogic', 'invalidity', 'inconsequence', 'fallaciousness']
senticnet['tenableness'] = [0.943, -0.751, 0, 0.515, '#joyful', '#surprising', 0.736, 'reasonableness', 'tenability', 'plausibility', 'credibility', 'credibleness']
senticnet['algebraematical_function'] = [0, 0.725, 0, 0.779, '#interesting', '#admirable', 0.501, 'calculus', 'algebra', 'algebraematics', 'algebra_equation', 'math']
senticnet['run_along'] = [0, 0, 0.914, -0.975, '#angry', '#disgusting', -0.63, 'lined', 'delineate', 'describe', 'trace', 'draw']
senticnet['pronged'] = [0, 0, -0.889, -0.783, '#scared', '#disgusting', -0.557, 'forficate', 'forked', 'branched', 'bifurcate', 'biramous']
senticnet['profitableness'] = [0.854, -0.794, 0, 0.977, '#joyful', '#admirable', 0.875, 'advantageousness', 'favorableness', 'favourableness', 'auspiciousness', 'positivity']
senticnet['prophetess'] = [0.686, -0.514, 0, 0.829, '#joyful', '#admirable', 0.676, 'diviner', 'oracle', 'auspex', 'augur', 'sibyl']
senticnet['waspish'] = [0, 0, -0.858, -0.728, '#scared', '#disgusting', -0.529, 'barbed', 'splenetic', 'bristly', 'barbellate', 'prickly']
senticnet['robotic'] = [0.721, -0.883, 0, 0, '#joyful', '#surprising', 0.535, 'eletronic', 'automatic', 'pistol', 'firearm', 'shoot_weapon']
senticnet['ornithologist'] = [-0.982, 0, 0.937, -0.689, '#sad', '#angry', -0.869, 'ornithology', 'bird_watcher', 'hobby', 'naturalist', 'amateur']
senticnet['sister'] = [0.788, 0.739, 0, 0, '#joyful', '#interesting', 0.509, 'foster_kid', 'daughter', 'relation', 'adopt', 'cousin']
senticnet['seedy'] = [0.725, -0.886, 0, 0.508, '#joyful', '#surprising', 0.706, 'louche', 'discreditable', 'discredited', 'sleazy', 'disreputable']
senticnet['stamina'] = [0, 0, 0, 0.766, '#admirable', '#admirable', 0.255, 'effort', 'determination', 'discipline', 'good_condition', 'a_lot_of_energy']
senticnet['undutiful'] = [0.518, -0.635, 0, 0.529, '#surprising', '#admirable', 0.561, 'disrespectful', 'undeferential', 'devastating', 'insolent', 'annihilating']
senticnet['enbenign_tumor'] = [-0.704, 0, 0.639, -0.56, '#sad', '#angry', -0.634, 'fibroma', 'adenoma', 'benign_tumor', 'chondroma', 'myoma']
senticnet['cerebral_pathway'] = [-0.735, 0, 0.897, -0.774, '#angry', '#disgusting', -0.802, 'commissure', 'optic_radiation', 'radiatio_optica', 'pathway', 'peduncle']
senticnet['unswerving'] = [0.889, 0.727, 0, 0, '#joyful', '#interesting', 0.539, 'stanch', 'steadfast', 'staunch', 'stem', 'halt']
senticnet['go_for_it'] = [0.75, -0.887, 0, 0.989, '#surprising', '#admirable', 0.875, 'try', 'assay', 'enjoy_challenge', 'wish_luck', 'take_chance']
senticnet['depravation'] = [0, 0, -0.715, -0.7, '#scared', '#disgusting', -0.472, 'turpitude', 'putrefaction', 'corruption', 'depravity', 'degeneracy']
senticnet['rural'] = [0, 0, 0, 0.073, '#admirable', '#admirable', 0.024, 'large_area_land', 'settle_down', 'urban', 'village', 'settlement']
senticnet['blistering'] = [0, 0, -0.795, -0.823, '#scared', '#disgusting', -0.539, 'deadly', 'acerbic', 'virulent', 'acid', 'venomous']
senticnet['distort'] = [0, 0, -0.949, -0.865, '#scared', '#disgusting', -0.605, 'heave', 'falsify', 'buckle', 'warped', 'garble']
senticnet['capcompetent'] = [0.982, -0.67, 0, 0.682, '#joyful', '#admirable', 0.778, 'workmanlike', 'effective', 'efficient', 'competent', 'able']
senticnet['wanton'] = [0, 0, -0.846, -0.822, '#scared', '#disgusting', -0.556, 'dalliance', 'piddle', 'wanton_away', 'trifling', 'dawdling']
senticnet['sushi'] = [0.055, -0.015, 0, 0, '#joyful', '#surprising', 0.023, 'chocolate_pudding', 'green_bean', 'sweetness', 'whip_cream', 'side_dish']
senticnet['traceable'] = [0.511, -0.597, 0, 0.576, '#surprising', '#admirable', 0.561, 'due', 'ascribable', 'attributable', 'imputable', 'referable']
senticnet['spendthrift'] = [0.87, -0.937, 0, 0.831, '#joyful', '#surprising', 0.879, 'prodigal', 'waster', 'wastrel', 'spender', 'scattergood']
senticnet['ride_barb'] = [0, 0, 0, 0.071, '#admirable', '#admirable', 0.024, 'two_barbs', 'barb', 'mule', 'buddhist', 'horse']
senticnet['then'] = [0.916, -0.785, 0, 0.829, '#joyful', '#admirable', 0.843, 'second', 'point_in_time', 'outset', 'starting_time', 'showtime']
senticnet['flock'] = [0, 0, 0.869, -0.745, '#angry', '#disgusting', -0.538, 'great_deal', 'slew', 'batch', 'slide', 'deal']
senticnet['attractivenessment'] = [0.817, -0.626, 0, 0.62, '#joyful', '#surprising', 0.688, 'quality', 'fascination', 'allure', 'attractiveness', 'temptingness']
senticnet['play_magic_trick'] = [0.818, 0.913, 0, 0.825, '#interesting', '#admirable', 0.852, 'greeting', 'magic_trick', 'pass_card', 'credit', 'blackjack']
senticnet['food_delivery'] = [0, 0.975, 0, 0.857, '#interesting', '#admirable', 0.611, 'send', 'mail', 'delivery', 'postal_service', 'package']
senticnet['vigorous'] = [0, 0.741, 0, 0.828, '#interesting', '#admirable', 0.523, 'strong', 'powerful', 'energy', 'dynamic', 'forceful']
senticnet['sicklepod'] = [0.598, -0.721, 0, 0.941, '#surprising', '#admirable', 0.753, 'cress', 'tower_rock_cress', 'tower_mustard', 'rock_cress', 'rock_cress_plant']
senticnet['sound_power'] = [0.695, -0.856, 0, 0.501, '#joyful', '#surprising', 0.684, 'acoustic_power', 'light_intensity', 'intensity', 'sound_pressure_level', 'threshold_level']
senticnet['sentence'] = [0.021, 0, 0, 0.174, '#joyful', '#admirable', 0.065, 'grammar_part', 'grammatical_term', 'part_of_speech', 'word', 'written_language']
senticnet['roly-poly'] = [0, 0, 0.801, -0.702, '#angry', '#disgusting', -0.501, 'overweight', 'obese', 'gross', 'a_lot_of_fat', 'heavy']
senticnet['predecessor'] = [0, 0, -0.773, -0.981, '#scared', '#disgusting', -0.585, 'forerunner', 'announce', 'precursor', 'harbingers', 'herald']
senticnet['basketball_bounce'] = [0.787, 0.899, 0, 0, '#joyful', '#interesting', 0.562, 'ball_bounce', 'bounce', 'football_bounce', 'soccer', 'ball']
senticnet['wham'] = [0, 0, -0.976, -0.792, '#scared', '#disgusting', -0.589, 'sock', 'bop', 'whack', 'whopping', 'wallop']
senticnet['props'] = [0.781, -0.732, 0, 0.786, '#joyful', '#admirable', 0.766, 'deference', 'politeness', 'homage', 'civility', 'court']
senticnet['proclivity'] = [0.976, -0.873, 0, 0.706, '#joyful', '#surprising', 0.852, 'understanding', 'propensity', 'leaning', 'favor', 'inclination']
senticnet['zooflagellate'] = [0.807, -0.868, 0, 0.611, '#joyful', '#surprising', 0.762, 'flagellate', 'zoomastigote', 'costia', 'dinoflagellate', 'hypermastigote']
senticnet['taint'] = [0, 0, 0.894, -0.744, '#angry', '#disgusting', -0.546, 'debasement', 'dirtiness', 'pollution', 'adulteration', 'impureness']
senticnet['enask_for'] = [0.722, -0.764, 0, 0.946, '#surprising', '#admirable', 0.811, 'arouse', 'elicit', 'kindle', 'ask_for', 'evoke']
senticnet['halloo'] = [0, 0, 0.982, -0.822, '#angry', '#disgusting', -0.601, 'cry', 'acting_out', 'explosion', 'outburst', 'yell']
senticnet['alchemy'] = [0, 0.795, 0, 0.796, '#interesting', '#admirable', 0.53, 'servant', 'art_of_transmuting_metal', 'stone', 'alchemist', 'philosopher']
senticnet['transformed'] = [0.78, -0.799, 0, 0.954, '#surprising', '#admirable', 0.844, 'changed', 'varied', 'exchanged', 'denatured', 'denaturized']
senticnet['jumping_thysanuran_insect'] = [-0.703, 0, 0.994, -0.99, '#angry', '#disgusting', -0.896, 'insect', 'thysanuran_insect', 'silverfish', 'bristletail', 'machilid']
senticnet['violinist'] = [0.882, 0.901, 0, 0, '#joyful', '#interesting', 0.594, 'songwriter', 'vip', 'rock_group', 'guitar_player', 'singer']
senticnet['corking'] = [0.876, 0.733, 0, 0, '#joyful', '#interesting', 0.536, 'bang-up', 'dandy', 'nifty', 'cracking', 'bully']
senticnet['air_traffic_jam'] = [-0.987, 0, 0.989, -0.933, '#sad', '#angry', -0.97, 'flight_accident', 'dangerous', 'danger', 'air_traffic', 'traffic']
senticnet['lewd'] = [0, 0, -0.916, -0.861, '#scared', '#disgusting', -0.592, 'lubricious', 'salacious', 'lustful', 'obscene', 'prurient']
senticnet['statistic'] = [0.076, 0.096, -0.089, 0.167, '#interesting', '#admirable', 0.083, 'arithmetic', 'mathematical_function', 'calculation', 'list_number', 'calculate']
senticnet['sexual_gayness'] = [0.807, -0.88, 0, 0.718, '#joyful', '#surprising', 0.802, 'sex', 'gayness', 'inversion', 'lesbianism', 'sapphism']
senticnet['interested'] = [0.997, 0, 0, 0.716, '#joyful', '#admirable', 0.571, 'concerned', 'caring', 'attentive', 'mindful', 'solicitous']
senticnet['miry'] = [0, 0, -0.796, -0.935, '#scared', '#disgusting', -0.577, 'marshy', 'mucky', 'muddy', 'boggy', 'soggy']
senticnet['wakeful'] = [0.805, -0.671, 0, 0.901, '#joyful', '#admirable', 0.792, 'vigilant', 'lidless', 'watchful', 'fly', 'sleepless']
senticnet['supporting'] = [0.9, -0.742, 0, 0.721, '#joyful', '#surprising', 0.788, 'supportive', 'demonstrative_of', 'encouraging', 'certificatory', 'accessary']
senticnet['chicane'] = [-0.836, 0, 0.76, 0, '#sad', '#angry', -0.532, 'cheat', 'chouse', 'screw', 'shaft', 'jockeying']
senticnet['fictious'] = [0, 0.951, 0, 0, '#interesting', '#interesting', 0.317, 'genre', 'movie_genre', 'action_movie', 'cinderella', 'fictional']
senticnet['snowboard'] = [0.107, 0.098, 0, 0.135, '#joyful', '#admirable', 0.113, 'snow', 'ball', 'ski', 'snowball', 'have_fun']
senticnet['plaything'] = [0, -0.918, 0, 0.756, '#surprising', '#admirable', 0.558, 'child_plaything', 'kid_play', 'play_object', 'child_play', 'play_device']
senticnet['bang-up'] = [0.876, 0.733, 0, 0, '#joyful', '#interesting', 0.536, 'nifty', 'dandy', 'corking', 'cracking', 'bully']
senticnet['unrealistical'] = [-0.93, 0, 0.94, -0.772, '#sad', '#angry', -0.881, 'delusive', 'unrealistic', 'phantasmagoric', 'surrealistic', 'wild']
senticnet['skydiving'] = [0, 0.109, -0.102, 0.235, '#interesting', '#admirable', 0.081, 'sport', 'sports_expert', 'adrenaline', 'extreme', 'extreme_sport']
senticnet['distinguishable'] = [0.891, 0.987, 0, 0, '#joyful', '#interesting', 0.626, 'distinct', 'discrete', 'decided', 'clear-cut', 'trenchant']
senticnet['brazen'] = [0, 0, 0.936, -0.702, '#angry', '#disgusting', -0.546, 'undeferential', 'disrespectful', 'undutiful', 'bareface', 'insolent']
senticnet['dock_worker'] = [0, 0, -0.952, -0.844, '#scared', '#disgusting', -0.599, 'docker', 'lumper', 'loader', 'longshoreman', 'stevedore']
senticnet['recap'] = [0, 0.175, 0.084, 0.133, '#interesting', '#admirable', 0.075, 'brief', 'abridgement', 'summary', 'resume', 'report']
senticnet['goosy'] = [0, 0, 0.746, -0.914, '#angry', '#disgusting', -0.553, 'anserine', 'dopy', 'foolish', 'dopey', 'jerky']
senticnet['space'] = [0.84, 0.852, 0, 0, '#joyful', '#interesting', 0.564, 'room', 'a_lot_of_space', 'capacity', 'house', 'universe']
senticnet['saltshaker'] = [0.03, -0.05, 0, 0.059, '#surprising', '#admirable', 0.046, 'fork', 'hot_table', 'chopstick', 'bowl', 'spoon']
senticnet['buy_car_motorbike'] = [0.06, -0.126, 0, 0, '#joyful', '#surprising', 0.062, 'car', 'buy', 'buy_car', 'purchase_car', 'buy_car_object']
senticnet['striking'] = [0.7, 0.922, 0, 0, '#joyful', '#interesting', 0.541, 'prominent', 'vivid', 'conspicuous', 'dramatic', 'flagrant']
senticnet['harum-scarum'] = [0, 0, -0.938, -0.932, '#scared', '#disgusting', -0.623, 'carefree', 'freewheeling', 'slaphappy', 'happy-go-lucky', 'devil-may-care']
senticnet['sheer'] = [0.026, -0.166, -0.05, 0.076, '#surprising', '#admirable', 0.073, 'monocle', 'eyeglass', 'spectacle', 'lens', 'contact_lens']
senticnet['sheet'] = [0.024, 0, 0, 0.074, '#joyful', '#admirable', 0.033, 'bedsheet', 'cover', 'quilt', 'comforter', 'modesty']
senticnet['larder'] = [0, 0, -0.868, -0.782, '#scared', '#disgusting', -0.55, 'pantry', 'buttery', 'fulsome', 'oily', 'oleaginous']
senticnet['sublime'] = [0.964, 0.975, 0, 0, '#joyful', '#interesting', 0.646, 'lofty', 'exalted', 'elevated', 'high-flown', 'grand']
senticnet['veteran'] = [0.822, -0.863, 0, 0.818, '#joyful', '#surprising', 0.834, 'practiced', 'experienced', 'older', 'seasoned', 'knowledgeable']
senticnet['ratio'] = [-0.04, 0.097, 0.06, 0.146, '#interesting', '#admirable', 0.048, 'vector', 'maths', 'length_measurement', 'measurement_unit', 'unit_of_measurement']
senticnet['proportion'] = [0, 0.125, 0.074, 0.097, '#interesting', '#admirable', 0.049, 'weigh', 'measurement_device', 'balance', 'measure_pound', 'weight_measurement']
senticnet['subservientness'] = [0.875, -0.724, 0, 0.584, '#joyful', '#surprising', 0.728, 'subordinateness', 'subservience', 'servant', 'handmaid', 'handmaiden']
senticnet['raunchy'] = [0, 0, -0.925, -0.825, '#scared', '#disgusting', -0.583, 'grubby', 'begrimed', 'dingy', 'grimy', 'dirty']
senticnet['whitewash'] = [0.799, -0.888, 0, 0.883, '#surprising', '#admirable', 0.857, 'pronounce', 'purge', 'acquit', 'vindicate', 'label']
senticnet['pliantness'] = [0.873, -0.943, 0, 0.74, '#joyful', '#surprising', 0.852, 'ability', 'flexibility', 'flexibleness', 'pliancy', 'adaptability']
senticnet['vice_flag_officer'] = [0.688, -0.908, 0, 0.877, '#surprising', '#admirable', 0.824, 'fleet_flag_officer', 'rear_flag_officer', 'flag_officer', 'full_flag_officer', 'admiral']
senticnet['ambo'] = [-0.711, 0, -0.794, 0, '#sad', '#scared', -0.502, 'pulpit', 'stump', 'dais', 'podium', 'rostrum']
senticnet['spitfire'] = [0.853, -0.876, 0, 0.973, '#surprising', '#admirable', 0.901, 'captive', 'mortal', 'emotional_person', 'person', 'individual']
senticnet['talented'] = [0.777, 0.948, 0, 0, '#joyful', '#interesting', 0.575, 'empower', 'present', 'give', 'invest', 'gifted']
senticnet['chance_eventpy_chance'] = [-0.912, 0, 0.769, -0.841, '#sad', '#disgusting', -0.841, 'break', 'good_luck', 'hap', 'chance_event', 'coincidence']
senticnet['unable_to_focus'] = [-0.702, 0, 0.811, 0, '#sad', '#angry', -0.504, 'become_distracted', 'preoccupied', 'inattentive', 'brain_storm', 'new_idea']
senticnet['hatchway'] = [0, 0, -0.911, -0.998, '#scared', '#disgusting', -0.636, 'skitter', 'scuttle', 'scamper', 'opening', 'scurry']
senticnet['soil'] = [-0.71, 0, 0.704, -0.891, '#sad', '#disgusting', -0.768, 'bleaching_clay', 'mire', 'dirt', 'mud', 'bleaching_earth']
senticnet['somebody'] = [0.55, -0.981, 0, 0.794, '#surprising', '#admirable', 0.775, 'mortal', 'person', 'individual', 'someone', 'agnostic']
senticnet['underground_neighborhood_map'] = [0.087, 0.08, 0.013, 0, '#joyful', '#interesting', 0.051, 'neighborhood_map', 'billboard', 'map', 'advertise_panel', 'restaurant_entrance']
senticnet['home_made'] = [0.809, -0.868, 0, 0, '#joyful', '#surprising', 0.559, 'big_breadbox', 'bread', 'container', 'baked_goods', 'eat_bread']
senticnet['struck'] = [0.854, -0.845, 0, 0.679, '#joyful', '#surprising', 0.793, 'taken', 'subject', 'stricken', 'impressed', 'affected']
senticnet['unbowed'] = [0.914, -0.547, 0, 0.803, '#joyful', '#admirable', 0.755, 'victorious', 'triumphant', 'undefeated', 'unbeaten', 'unconquered']
senticnet['smell_out'] = [0, 0, -0.951, -0.891, '#scared', '#disgusting', -0.614, 'smell', 'reek', 'smack', 'smelt', 'sense']
senticnet['sedimentation'] = [0.614, -0.956, 0, 0.584, '#joyful', '#surprising', 0.718, 'mother_lode', 'champion_lode', 'deposit', 'alluviation', 'lode']
senticnet['black_bugbane'] = [-0.524, 0, 0.527, -0.782, '#angry', '#disgusting', -0.611, 'herb', 'fairy_candle', 'actaea_racemosa', 'black_snakeroot', 'black_cohosh']
senticnet['propanone'] = [0.843, -0.958, 0, 0.648, '#joyful', '#surprising', 0.816, 'medium', 'dissolvent', 'acetone', 'dimethyl_ketone', 'chlorobenzene']
senticnet['renovate'] = [0.599, -0.973, 0, 0.869, '#surprising', '#admirable', 0.814, 'reanimate', 'revivify', 'reinvigorate', 'recreate', 'energize']
senticnet['radiology'] = [0.701, -0.633, 0, 0.929, '#joyful', '#admirable', 0.754, 'pathology', 'medicine', 'medical_specialty', 'medical_science', 'serology']
senticnet['immaculate'] = [0, 0, -0.866, -0.738, '#scared', '#disgusting', -0.535, 'spic-and-span', 'spick-and-span', 'spic', 'spotless', 'speckless']
senticnet['shed_light_on'] = [0, 0.889, 0, 0.754, '#interesting', '#admirable', 0.548, 'sort_out', 'illuminate', 'light_up', 'elucidate', 'clear']
senticnet['tessellated'] = [0.613, -0.532, 0, 0.932, '#joyful', '#admirable', 0.692, 'buttony', 'ruffled', 'fringed', 'adorned', 'mounted']
senticnet['sense_audition'] = [0.785, -0.995, 0, 0.981, '#surprising', '#admirable', 0.92, 'ear', 'absolute_pitch', 'perfect_pitch', 'audition', 'modality']
senticnet['sales'] = [0.956, 0.713, 0, 0, '#joyful', '#interesting', 0.556, 'marketing', 'advertisement', 'announcement', 'billboard', 'promotion']
senticnet['polar'] = [0.626, -0.603, 0, 0.769, '#joyful', '#admirable', 0.666, 'positive', 'electropositive', 'positively_charged', 'live', 'charged']
senticnet['regenarate'] = [0, 0.763, 0, 0.932, '#interesting', '#admirable', 0.565, 'alleviate', 'cure_illness', 'recovery', 'heal', 'cure']
senticnet['bequeath'] = [0.729, 0.974, 0, 0, '#joyful', '#interesting', 0.568, 'unforced', 'leave', 'willing', 'volition', 'uncoerced']
senticnet['washroom'] = [0.758, 0, 0, 0.903, '#joyful', '#admirable', 0.554, 'bath_robe', 'bathroom', 'toilet', 'hotel_bathroom', 'bathroom_drawer']
senticnet['slavish'] = [-0.655, 0, 0.804, -0.945, '#angry', '#disgusting', -0.801, 'cold', 'unoriginal', 'dusty', 'cliched', 'banal']
senticnet['enoverclothe'] = [-0.635, 0, 0.694, -0.997, '#angry', '#disgusting', -0.775, 'raiment', 'garb', 'dress', 'overclothe', 'clothe']
senticnet['radiotherapy'] = [0.789, -0.817, 0, 0.591, '#joyful', '#surprising', 0.732, 'actinotherapy', 'radiation_therapy', 'radiation', 'phototherapy', 'irradiation']
senticnet['weather_control_weather'] = [0.814, 0.773, 0, 0, '#joyful', '#interesting', 0.529, 'rain_check', 'check_weather', 'forecast', 'control_weather', 'weather']
senticnet['prognostic'] = [0.851, -0.657, 0, 0.66, '#joyful', '#admirable', 0.723, 'omen', 'portent', 'presage', 'auspice', 'prognostication']
senticnet['access_quickly'] = [0.825, 0, 0, 0.703, '#joyful', '#admirable', 0.509, 'pay_toll', 'get_fast', 'access', 'fast_travel', 'drive']
senticnet['ding'] = [0, 0, -0.842, -0.864, '#scared', '#disgusting', -0.569, 'gouge', 'force_out', 'extort', 'nick', 'dent']
senticnet['shakedown'] = [0.735, -0.714, 0, 0.566, '#joyful', '#surprising', 0.672, 'improvement', 'betterment', 'habituation', 'domestication', 'adjustment']
senticnet['sweeping'] = [0.732, -0.829, 0, 0, '#joyful', '#surprising', 0.52, 'extensive', 'expansive', 'rolling', 'spacious', 'open']
senticnet['inhale_oxygen'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'respiration', 'external_respiration', 'exhale_oxygen', 'inhaler_technique', 'ventilation']
senticnet['word_picture'] = [0, 0, -0.999, -0.848, '#scared', '#disgusting', -0.616, 'delineation', 'picture', 'word-painting', 'depiction', 'characterization']
senticnet['put'] = [0.619, -0.628, 0, 0.693, '#surprising', '#admirable', 0.647, 'set', 'pose', 'lay', 'emplace', 'place']
senticnet['old-hat'] = [0, 0, -0.924, -0.94, '#scared', '#disgusting', -0.621, 'shopworn', 'banal', 'stock', 'hackneyed', 'commonplace']
senticnet['quarreler'] = [0.644, -0.864, 0, 0.58, '#joyful', '#surprising', 0.696, 'hairsplitter', 'disputant', 'fight', 'obstructor', 'obstructer']
senticnet['horse_animal_fancier'] = [0.967, 0, 0, 0.776, '#joyful', '#admirable', 0.581, 'enthusiast', 'horseman', 'fancier', 'animal_fancier', 'lover']
senticnet['form_of_punishmentment'] = [-0.146, -0.042, 0, -0.102, '#sad', '#disgusting', -0.069, 'form_of_punishment', 'inflict_pain', 'death_penalty', 'kill', 'punish']
senticnet['well_fixed'] = [0.995, 0, 0, 0.835, '#joyful', '#admirable', 0.61, 'easy', 'well_off', 'prosperous', 'well-heeled', 'comfortable']
senticnet['quota'] = [0.732, -0.833, 0, 0.566, '#joyful', '#surprising', 0.71, 'share', 'reallocation', 'allocation', 'portion', 'part']
senticnet['acerbic'] = [-0.977, 0, -0.86, 0, '#sad', '#scared', -0.612, 'acid', 'pungent', 'acerb', 'acrid', 'bitter']
senticnet['upstanding'] = [0.666, -0.831, 0, 0.896, '#surprising', '#admirable', 0.798, 'nice', 'respectable', 'solid', 'presentable', 'decent']
senticnet['woo'] = [0.857, 0, 0, 0, '#joyful', '#joyful', 0.286, 'date', 'accuracy', 'sexy_woman', 'seduction', 'enjoy_person']
senticnet['useable'] = [0.834, -0.764, 0, 0, '#joyful', '#surprising', 0.533, 'operational', 'functional', 'operable', 'available', 'usable']
senticnet['unknowing'] = [-0.981, 0, 0, -0.966, '#sad', '#disgusting', -0.649, 'naive', 'unenlightened', 'unread', 'uninformed', 'clueless']
senticnet['utmost'] = [0, 0.075, 0, 0.159, '#interesting', '#admirable', 0.078, 'maximum', 'max', 'highest', 'top', 'most']
senticnet['knight_protection_ore'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'protective_gear', 'metal', 'lightweight_knight_protection', 'knight_protection', 'knight']
senticnet['user'] = [0, 0.777, 0, 0.775, '#interesting', '#admirable', 0.517, 'computer', 'engineer', 'computer_user', 'internet_user', 'computer_software']
senticnet['forefend'] = [-0.869, 0, -0.721, 0, '#sad', '#scared', -0.53, 'debar', 'rid_of', 'eliminate', 'forfend', 'obviate']
senticnet['intertoll_highway'] = [0, 0, 0.024, -0.051, '#angry', '#disgusting', -0.025, 'toll_road', 'toll_highway', 'superhighway', 'national_highway', 'motorway']
senticnet['sprinter'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'jockey', 'lead_ropes', 'horse', 'control_horse', 'saddle']
senticnet['habituate'] = [0, 0, -0.888, -0.984, '#scared', '#disgusting', -0.624, 'apply', 'employ', 'expend', 'utilize', 'used']
senticnet['march'] = [0, 0, -0.898, -0.961, '#scared', '#disgusting', -0.62, 'abut', 'butt', 'edge', 'border', 'adjoin']
senticnet['regeneration'] = [0.866, 0.817, 0, 0, '#joyful', '#interesting', 0.561, 'patriotism', 'uprise', 'revolutionary', 'renovation', 'revolution']
senticnet['keep_cool_cream'] = [0.793, 0, 0, 0.778, '#joyful', '#admirable', 0.524, 'cool_car_engine', 'keep_cold', 'cool_food', 'keep_cool', 'store_ice']
senticnet['exceeding'] = [0.873, 0.793, 0, 0, '#joyful', '#interesting', 0.555, 'exceptional', 'colossal', 'portentous', 'prodigious', 'stupendous']
senticnet['run'] = [0.11, 0, 0, 0.095, '#joyful', '#admirable', 0.068, 'play_fetch', 'ride_car', 'dog', 'play_human', 'chew_bone']
senticnet['article_make_clothes'] = [0, -0.04, 0.126, -0.054, '#angry', '#disgusting', -0.047, 'make_shirt', 'make_make_clothes', 'make_cloth', 'cloth', 'apparel']
senticnet['marcelfure'] = [-0.974, 0, 0.567, -0.598, '#sad', '#disgusting', -0.713, 'marcel', 'coif', 'hairdo', 'hairstyle', 'hair_style']
senticnet['mordacious'] = [0, 0, -0.915, -0.823, '#scared', '#disgusting', -0.579, 'barbed', 'biting', 'acrid', 'pungent', 'nipping']
senticnet['mechanical_complex_machine'] = [0.028, 0, 0, 0.131, '#joyful', '#admirable', 0.053, 'device', 'mechanism', 'human_invention', 'machine', 'complex_machine']
senticnet['tastelessness'] = [0.989, -0.997, 0, 0.728, '#joyful', '#surprising', 0.905, 'quality', 'coarseness', 'sleaziness', 'inelegance', 'commonness']
senticnet['seethe'] = [-0.908, 0, 0.965, 0, '#sad', '#angry', -0.624, 'stewing', 'simmering', 'churn', 'moil', 'boiling']
senticnet['lantern_jawr_bone'] = [0.886, -0.997, 0, 0.542, '#joyful', '#surprising', 0.808, 'jowl', 'lower_jaw', 'mandible', 'lantern_jaw', 'mandibula']
senticnet['forgo'] = [0, 0, -0.981, -0.82, '#scared', '#disgusting', -0.6, 'foreswear', 'relinquish', 'dispense_with', 'waive', 'throw_overboard']
senticnet['above_all'] = [0.75, 0, 0, 0.971, '#joyful', '#admirable', 0.574, 'high', 'superior', 'aloft', 'above', 'atop']
senticnet['earthbound'] = [0, 0, -0.916, -0.763, '#scared', '#disgusting', -0.56, 'matter-of-fact', 'commonplace', 'pedestrian', 'prosy', 'prosaic']
senticnet['excite_someone_sexually'] = [0.888, 0.803, 0, 0, '#joyful', '#interesting', 0.564, 'evoke_feeling', 'wake_up', 'become_aroused', 'love_back', 'love_oneself']
senticnet['rationalness'] = [0.539, -0.771, 0, 0.657, '#surprising', '#admirable', 0.656, 'rationality', 'quality', 'logicality', 'completeness', 'consistency']
senticnet['valet'] = [0, 0.081, 0, 0.071, '#interesting', '#admirable', 0.051, 'go_bar', 'designate_driver', 'drink_a_lot_of_beer', 'go_party', 'drink_alcohol']
senticnet['stanch'] = [0.889, 0.727, 0, 0, '#joyful', '#interesting', 0.539, 'staunch', 'steadfast', 'unswerving', 'stem', 'halt']
senticnet['vaunt'] = [0.838, 0.936, 0, 0, '#joyful', '#interesting', 0.591, 'proud', 'glory', 'brag', 'boast', 'pride']
senticnet['ambivalence'] = [0, 0, 0.801, -0.933, '#angry', '#disgusting', -0.578, 'amphibology', 'amphiboly', 'parisology', 'ambiguity', 'equivocation']
senticnet['tactical_feint'] = [-0.825, 0, 0.739, -0.509, '#sad', '#angry', -0.691, 'fake', 'juke', 'feint', 'manoeuvre', 'maneuver']
senticnet['spelling'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'review', 'double_check', 'check_spelling', 'correct_homework', 'mark_exam']
senticnet['unbreakable'] = [0.132, 0.212, 0, 0.242, '#interesting', '#admirable', 0.195, 'good_quality', 'premium', 'last_long', 'steel', 'strong']
senticnet['pine'] = [0.048, -0.097, 0, 0.086, '#surprising', '#admirable', 0.077, 'elm', 'tree', 'willow', 'cedar', 'timber']
senticnet['youngster'] = [0.029, 0.076, 0, 0, '#joyful', '#interesting', 0.035, 'adolescent', 'teenager', 'junior', 'lad', 'maturity']
senticnet['pixel'] = [0.044, 0.08, 0, -0.03, '#joyful', '#interesting', 0.031, 'screen', 'computer_monitor', 'visual_information', 'image', 'display']
senticnet['allicrocodilian'] = [-0.853, 0, 0.685, -0.838, '#sad', '#disgusting', -0.792, 'gator', 'crocodile', 'false_gavial', 'crocodilian', 'caiman']
senticnet['sandy'] = [0.047, 0.11, 0, 0, '#joyful', '#interesting', 0.052, 'near_sea', 'cover_sand', 'sand_rock', 'near_beach', 'beach']
senticnet['route'] = [0.021, 0, 0, 0.058, '#joyful', '#admirable', 0.026, 'architecture', 'infrastructure', 'structure', 'car_path', 'building']
senticnet['student'] = [0.134, 0.1, -0.112, 0.246, '#joyful', '#admirable', 0.123, 'hard_worker', 'pupil', 'apprentice', 'serious_student', 'much_information']
senticnet['evoke_feeling'] = [0.888, 0.803, 0, 0, '#joyful', '#interesting', 0.564, 'become_aroused', 'wake_up', 'excite_someone_sexually', 'love_back', 'love_oneself']
senticnet['butcherly'] = [0, 0, -0.75, -0.932, '#scared', '#disgusting', -0.561, 'bloodthirsty', 'slaughterous', 'gory', 'sanguinary', 'sanguineous']
senticnet['patronise'] = [0, -0.751, 0, 0.847, '#surprising', '#admirable', 0.533, 'condescend', 'sponsor', 'buy_at', 'support', 'patronize']
senticnet['resplendent'] = [0.919, 0, 0, 0.734, '#joyful', '#admirable', 0.551, 'splendiferous', 'glorious', 'excellent', 'splendid', 'first-class']
senticnet['demise'] = [0, 0, -0.922, -0.988, '#scared', '#disgusting', -0.637, 'loss', 'deprivation', 'dispossession', 'privation', 'bereavement']
senticnet['bloodthirsty'] = [0, 0, -0.75, -0.932, '#scared', '#disgusting', -0.561, 'sanguinary', 'slaughterous', 'gory', 'butcherly', 'sanguineous']
senticnet['remunerated'] = [0.521, -0.859, 0, 0.727, '#surprising', '#admirable', 0.702, 'paid', 'compensated', 'paying', 'stipendiary', 'remunerative']
senticnet['worktop'] = [0.025, 0.084, 0, 0.062, '#interesting', '#admirable', 0.057, 'work_surface', 'kitchen_worktop', 'surface', 'work', 'wood_worktop']
senticnet['shrillness'] = [0.509, -0.678, 0, 0.707, '#surprising', '#admirable', 0.631, 'color', 'newsworthiness', 'interestingness', 'vividness', 'charisma']
senticnet['marshy'] = [0, 0, -0.796, -0.935, '#scared', '#disgusting', -0.577, 'soggy', 'mucky', 'muddy', 'boggy', 'miry']
senticnet['crystalline'] = [0, 0, -0.715, -0.892, '#scared', '#disgusting', -0.536, 'liquid', 'crystal_clear', 'pellucid', 'limpid', 'lucid']
senticnet['minimise'] = [0, 0, -0.868, -0.782, '#scared', '#disgusting', -0.55, 'minimize', 'understated', 'unpretentious', 'unostentatious', 'downplay']
senticnet['ripen'] = [0.7, -0.646, 0, 0.953, '#joyful', '#admirable', 0.766, 'find', 'find_oneself', 'maturate', 'grow_up', 'develop']
senticnet['juicy_fruit'] = [0.779, -0.76, 0, 0, '#joyful', '#surprising', 0.513, 'berry', 'fruit', 'prune', 'fig', 'sweet_fruit']
senticnet['under_back_sofa'] = [-0.023, 0, 0, -0.058, '#sad', '#disgusting', -0.027, 'sock_drawer', 'under_carpet', 'back_sofa', 'closet', 'under_bed']
senticnet['vaticination'] = [0.677, -0.551, 0, 0.831, '#joyful', '#admirable', 0.686, 'vaticinate', 'call', 'enlighten', 'irradiate', 'predict']
senticnet['get_going'] = [0.724, 0.806, 0, 0, '#joyful', '#interesting', 0.51, 'initiate', 'trigger_off', 'activate', 'do_it_yourself', 'operate']
senticnet['recognized'] = [0.683, -0.553, 0, 0.552, '#joyful', '#surprising', 0.596, 'acknowledged', 'accepted', 'declarable', 'given', 'putative']
senticnet['zoologist'] = [0.1, 0.085, 0, 0.093, '#joyful', '#admirable', 0.093, 'study_person', 'subject_study', 'zoo', 'zoology', 'geology']
senticnet['flinty'] = [0, 0, -0.909, -0.739, '#scared', '#disgusting', -0.549, 'unrepentant', 'obstinate', 'flint', 'obdurate', 'cussed']
senticnet['tensile'] = [0, 0, -0.806, -0.896, '#scared', '#disgusting', -0.567, 'fictile', 'malleable', 'pliable', 'ductile', 'pliant']
senticnet['vociferous'] = [0, 0, -0.933, -0.947, '#scared', '#disgusting', -0.627, 'fricative', 'clamant', 'clamorous', 'blatant', 'strident']
senticnet['naturalist'] = [-0.982, 0, 0.937, -0.689, '#sad', '#angry', -0.869, 'ornithology', 'ornithologist', 'hobby', 'bird_watcher', 'amateur']
senticnet['pander'] = [0.812, 0, 0, 0.813, '#joyful', '#admirable', 0.542, 'indulge', 'gratify', 'humor', 'luxuriate', 'spend']
senticnet['extrospective'] = [0, 0, -0.852, -0.891, '#scared', '#disgusting', -0.581, 'extroverted', 'forthcoming', 'outgoing', 'extravert', 'extrovertive']
senticnet['verdancy'] = [0.581, -0.656, 0, 0.959, '#surprising', '#admirable', 0.732, 'wilderness', 'overgrowth', 'greenness', 'profuseness', 'verdure']
senticnet['type'] = [0.702, -0.862, 0, 0, '#joyful', '#surprising', 0.521, 'special_event', 'bachelor_party', 'birthday_party', 'event', 'event_type']
senticnet['water_chestnut_ko'] = [0.83, -0.802, 0, 0.969, '#joyful', '#admirable', 0.867, 'water_caltrop', 'water_chestnut', 'ling', 'aquatic_plant', 'water_plant']
senticnet['suggestive'] = [0.734, -0.56, 0, 0.64, '#joyful', '#admirable', 0.645, 'inferential', 'connotational', 'implicative', 'connotative', 'connotative_of']
senticnet['tatty'] = [0, 0, 0.952, -0.775, '#angry', '#disgusting', -0.576, 'meretricious', 'showy', 'gaudy', 'flashy', 'brassy']
senticnet['highfaluting'] = [0, 0, -0.89, -0.833, '#scared', '#disgusting', -0.574, 'hifalutin', 'la-di-da', 'grandiose', 'highfalutin', 'hoity-toity']
senticnet['sluggish'] = [-0.963, 0, -0.848, 0, '#sad', '#scared', -0.604, 'soggy', 'dormant', 'inert', 'torpid', 'hibernating']
senticnet['shriveled'] = [0, 0, -0.932, -0.818, '#scared', '#disgusting', -0.583, 'sear', 'withered', 'dried-up', 'shrivelled', 'sere']
senticnet['great_deal'] = [0, 0, 0.869, -0.745, '#angry', '#disgusting', -0.538, 'slew', 'flock', 'batch', 'slide', 'deal']
senticnet['virility_drug_citrate'] = [-0.595, 0, 0.537, -0.577, '#sad', '#disgusting', -0.57, 'phentolamine', 'virility_drug', 'sildenafil', 'tadalafil', 'vardenafil']
senticnet['unbrace'] = [0.507, -0.507, 0, 0.676, '#joyful', '#surprising', 0.563, 'unlace', 'unfold', 'untie', 'undo', 'spread']
senticnet['sulfisoxazole'] = [0.551, -0.753, 0, 0.817, '#surprising', '#admirable', 0.707, 'antibacterial', 'sulfamethoxazole', 'sulfa', 'sulfadiazine', 'sulfacetamide']
senticnet['hypooxyacid'] = [-0.814, 0, 0.774, -0.776, '#sad', '#disgusting', -0.788, 'acid', 'hypophosphoric_acid', 'periodic_acid', 'phosphorous_acid', 'oxyacid']
senticnet['pietistical'] = [0, 0, -0.939, -0.766, '#scared', '#disgusting', -0.568, 'sanctimonious', 'pietistic', 'pharisaic', 'holier-than-thou', 'pharisaical']
senticnet['one-dimensional'] = [0, 0, 0.94, -0.769, '#angry', '#disgusting', -0.57, 'analog', 'linear', 'elongate', 'additive', 'analogue']
senticnet['brilliance'] = [0.799, 0, 0, 0.897, '#joyful', '#admirable', 0.565, 'brightness', 'blaze', 'glare', 'glitter', 'glister']
senticnet['tyke'] = [0, 0, -0.758, -0.906, '#scared', '#disgusting', -0.555, 'boor', 'barbarian', 'peasant', 'churl', 'goth']
senticnet['stinking_composite_plant'] = [0.782, -0.695, 0, 0.684, '#joyful', '#surprising', 0.72, 'composite_plant', 'mayweed', 'stinking_chamomile', 'dog_fennel', 'oxeye_daisy']
senticnet['mucky'] = [0, 0, -0.796, -0.935, '#scared', '#disgusting', -0.577, 'marshy', 'soggy', 'muddy', 'boggy', 'miry']
senticnet['prudential'] = [0.625, -0.88, 0, 0.782, '#surprising', '#admirable', 0.762, 'judicious', 'discreet', 'circumspect', 'heady', 'prudent']
senticnet['spick-and-span'] = [0, 0, -0.866, -0.738, '#scared', '#disgusting', -0.535, 'spic-and-span', 'spotless', 'spic', 'immaculate', 'speckless']
senticnet['brassy'] = [0, 0, 0.952, -0.775, '#angry', '#disgusting', -0.576, 'meretricious', 'showy', 'gaudy', 'tatty', 'flashy']
senticnet['anchor'] = [0, 0, -0.907, -0.969, '#scared', '#disgusting', -0.625, 'grounded', 'base', 'establish', 'strand', 'undercoat']
senticnet['derisory'] = [0, 0, 0.817, -0.789, '#angry', '#disgusting', -0.535, 'ridiculous', 'cockeyed', 'ludicrous', 'absurd', 'farcical']
senticnet['reproducibility'] = [0.512, -0.52, 0, 0.874, '#surprising', '#admirable', 0.635, 'responsibleness', 'dependability', 'duplicability', 'solidness', 'responsibility']
senticnet['malaysian_city'] = [0.609, -0.744, 0, 0.716, '#surprising', '#admirable', 0.69, 'city', 'malacca', 'asia', 'old_city', 'colony']
senticnet['surmisal'] = [0.861, -0.559, 0, 0.578, '#joyful', '#admirable', 0.666, 'conjecture', 'speculation', 'guess', 'divination', 'supposition']
senticnet['open_minded'] = [0.754, 0, 0, 0.717, '#joyful', '#admirable', 0.49, 'homosexual', 'same_sex_attraction', 'gay', 'unconventional', 'gay_person']
senticnet['practiced'] = [0.822, -0.863, 0, 0.818, '#joyful', '#surprising', 0.834, 'experienced', 'veteran', 'older', 'seasoned', 'knowledgeable']
senticnet['romp'] = [0.525, -0.857, 0, 0.599, '#surprising', '#admirable', 0.66, 'frolic', 'gambol', 'coquetry', 'play', 'caper']
senticnet['rome'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'newyork', 'london', 'big_city', 'beijing', 'tokyo']
senticnet['tombstone'] = [0, 0.702, 0, 0.864, '#interesting', '#admirable', 0.522, 'graveyard', 'funeral', 'funeral_home', 'cemetery', 'die']
senticnet['wrongfulness'] = [0.871, -0.748, 0, 0.981, '#joyful', '#admirable', 0.867, 'unrighteousness', 'unjustness', 'unfairness', 'wrong', 'inequity']
senticnet['tastebud'] = [0.961, 0, 0, 0.802, '#joyful', '#admirable', 0.588, 'food', 'put_mouth', 'taste', 'sour_taste', 'tongue']
senticnet['beget'] = [0, 0, -0.839, -0.829, '#scared', '#disgusting', -0.556, 'breed', 'engender', 'get', 'father', 'spawn']
senticnet['sort_out'] = [0, 0.889, 0, 0.754, '#interesting', '#admirable', 0.548, 'illuminate', 'shed_light_on', 'light_up', 'elucidate', 'clear']
senticnet['something_familiar'] = [0.768, 0, 0, 0.881, '#joyful', '#admirable', 0.55, 'bell_ring', 'remember', 'amplitude', 'step', 'rung']
senticnet['quivering'] = [0.748, -0.907, 0, 0.99, '#surprising', '#admirable', 0.882, 'shakiness', 'tremolo', 'shaking', 'vibration', 'quiver']
senticnet['holy_sacrament'] = [0.762, 0, 0, 0.894, '#joyful', '#admirable', 0.552, 'holy', 'eucharist', 'holy_eucharist', 'liturgy', 'sacrament_of_eucharist']
senticnet['rathole'] = [-0.528, 0, 0.785, -0.617, '#angry', '#disgusting', -0.643, 'gap', 'bullet_hole', 'aperture', 'hole', 'cranny']
senticnet['sundae'] = [0, -0.023, 0, 0.07, '#surprising', '#admirable', 0.031, 'pastry', 'christmas_stock', 'breadbox', 'bakery', 'freezer']
senticnet['pins'] = [0.101, 0.074, 0.03, 0, '#joyful', '#interesting', 0.048, 'bowling', 'bowl_alley', 'sports', 'challenge', 'bowling_center']
senticnet['unqualifiedal'] = [-0.669, 0, 0.721, -0.539, '#sad', '#angry', -0.643, 'unlimited', 'outright', 'unconditional', 'unqualified', 'categoric']
senticnet['recovery'] = [0.825, -0.636, 0, 0.781, '#joyful', '#admirable', 0.747, 'salvage', 'lifesaving', 'redemption', 'salvation', 'deliverance']
senticnet['tapas'] = [0.039, 0.089, 0.023, 0, '#joyful', '#interesting', 0.035, 'steak_house', 'paella', 'french_restaurant', 'spanish_restaurant', 'restaurant_diner']
senticnet['fluent'] = [0, 0, -0.712, -0.751, '#scared', '#disgusting', -0.488, 'facile', 'silver', 'smooth-spoken', 'eloquent', 'silver-tongued']
senticnet['terrace'] = [0, 0.105, 0, 0.076, '#interesting', '#admirable', 0.06, 'palace', 'mansion', 'castle', 'bungalow', 'big_house']
senticnet['rastafarian'] = [0.024, 0.211, 0, 0.209, '#interesting', '#admirable', 0.148, 'pulpit', 'choir_stall', 'fundamentalist', 'pew', 'altar']
senticnet['interdict'] = [0, 0, -0.917, -0.908, '#scared', '#disgusting', -0.608, 'forbid', 'prohibit', 'veto', 'disallow', 'proscribe']
senticnet['slyness'] = [0.784, -0.595, 0, 0.846, '#joyful', '#admirable', 0.742, 'foxiness', 'astuteness', 'wiliness', 'craftiness', 'cunning']
senticnet['steadfast'] = [0.889, 0.727, 0, 0, '#joyful', '#interesting', 0.539, 'stanch', 'staunch', 'unswerving', 'stem', 'halt']
senticnet['bathetic'] = [0, 0, -0.753, -0.986, '#scared', '#disgusting', -0.58, 'kitschy', 'mawkish', 'drippy', 'hokey', 'maudlin']
senticnet['tup'] = [0.656, -0.817, 0, 0.909, '#surprising', '#admirable', 0.794, 'black_sheep', 'ewe', 'ram', 'sheep', 'wether']
senticnet['pillared'] = [0.897, -0.985, 0, 0.692, '#joyful', '#surprising', 0.858, 'amphistylar', 'columned', 'colonnaded', 'columnar', 'columniform']
senticnet['tub'] = [0.041, 0.086, 0.016, 0, '#joyful', '#interesting', 0.037, 'separate_shower', 'shower_head', 'shampoo_conditioner', 'plunger', 'bath_shower']
senticnet['rugby'] = [0.059, -0.049, 0.014, 0, '#joyful', '#surprising', 0.031, 'table_tennis', 'golf', 'soccer', 'football', 'play_golf']
senticnet['saratoga'] = [0.565, -0.697, 0, 0.787, '#surprising', '#admirable', 0.683, 'species', 'fish_species', 'spotted_barramundi', 'spotted_bonytongue', 'northern_barramundi']
senticnet['indelicate'] = [0, 0, -0.72, -0.838, '#scared', '#disgusting', -0.519, 'uncomely', 'unseemly', 'indecent', 'unbecoming', 'indecorous']
senticnet['solitudinarian'] = [0, 0, -0.728, -0.763, '#scared', '#disgusting', -0.497, 'solitary', 'troglodyte', 'hermit', 'reclusive', 'recluse']
senticnet['give_voice'] = [0, 0, -0.74, -0.769, '#scared', '#disgusting', -0.503, 'word', 'joint', 'formulate', 'articulate', 'phrase']
senticnet['dirty_dish_overflow'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'faucet', 'hot_dirty_dish', 'hot_tap', 'dirty_dish', 'washcloth']
senticnet['same'] = [0, 0.213, -0.073, 0.308, '#interesting', '#admirable', 0.149, 'alike', 'identical', 'similar', 'compare', 'comparison']
senticnet['presentable'] = [0.666, -0.831, 0, 0.896, '#surprising', '#admirable', 0.798, 'nice', 'respectable', 'solid', 'decent', 'upstanding']
senticnet['substitutable'] = [0.552, -0.585, 0, 0.762, '#surprising', '#admirable', 0.633, 'transposable', 'permutable', 'fungible', 'commutable', 'exchangeable']
senticnet['rightful'] = [0, 0.767, 0, 0.842, '#interesting', '#admirable', 0.536, 'true', 'rule-governed', 'legitimate', 'licit', 'lawful']
senticnet['supposable'] = [0.878, -0.678, 0, 0.631, '#joyful', '#surprising', 0.729, 'ponderable', 'presumable', 'conceivable', 'surmisable', 'thinkable']
senticnet['strawberry'] = [0.842, 0, 0, 0.813, '#joyful', '#admirable', 0.552, 'fruit_tree', 'baby_flower', 'fig', 'carpel', 'star_anise']
senticnet['measure_up'] = [0, 0, -0.777, -0.877, '#scared', '#disgusting', -0.551, 'stipulate', 'qualify', 'qualified', 'dispose', 'restrict']
senticnet['fly-by-night'] = [0, 0, -0.786, -0.966, '#scared', '#disgusting', -0.584, 'suspect', 'fishy', 'funny', 'louche', 'shady']
senticnet['talky'] = [0.949, -0.694, 0, 0.992, '#joyful', '#admirable', 0.878, 'voluble', 'gabby', 'garrulous', 'loquacious', 'chatty']
senticnet['misadvise'] = [0, 0, -0.803, -0.83, '#scared', '#disgusting', -0.544, 'misdirect', 'lead_astray', 'mislead', 'misguided', 'ill-conceived']
senticnet['red-hot'] = [0.962, -0.898, 0, 0, '#joyful', '#surprising', 0.62, 'toothsome', 'delectable', 'juicy', 'luscious', 'voluptuous']
senticnet['delicious_meal_bun'] = [0.028, -0.073, 0, 0, '#joyful', '#surprising', 0.034, 'casserole', 'meatloaf', 'hot_dog', 'hamburger', 'delicious_meal']
senticnet['scour'] = [0, 0, 0.862, -0.768, '#angry', '#disgusting', -0.543, 'abraded', 'abrase', 'rub_off', 'corrade', 'rub_down']
senticnet['go_hell'] = [-0.231, -0.018, -0.137, -0.07, '#sad', '#scared', -0.14, 'scold', 'diseased', 'restrain', 'tragedy', 'put_in_jail']
senticnet['supergiant'] = [0.509, -0.721, 0, 0.657, '#surprising', '#admirable', 0.629, 'giant', 'variable', 'supernova', 'binary_star', 'star']
senticnet['whopper'] = [0.68, -0.861, 0, 0.72, '#surprising', '#admirable', 0.754, 'prevarication', 'white_lie', 'jactitation', 'walloper', 'fib']
senticnet['sheeplike'] = [0.625, -0.501, 0, 0.822, '#joyful', '#admirable', 0.649, 'meek', 'tame', 'yielding', 'docile', 'sheepish']
senticnet['coax'] = [0, 0, -0.925, -0.823, '#scared', '#disgusting', -0.583, 'wheedle', 'sweet-talk', 'blarney', 'palaver', 'cajole']
senticnet['spontaneous_abortion'] = [-0.955, 0, -0.986, 0, '#sad', '#scared', -0.647, 'death', 'feticide', 'sickness', 'miscarriage', 'abortion']
senticnet['unthoughtful'] = [-0.816, 0, 0, -0.994, '#sad', '#disgusting', -0.603, 'unthinking', 'thoughtless', 'unreflective', 'inconsiderate', 'selfish']
senticnet['omit'] = [-0.774, 0, -0.93, 0, '#sad', '#scared', -0.568, 'pretermit', 'neglected', 'drop', 'leave_out', 'miss']
senticnet['sitcom'] = [0, -0.036, 0, 0.094, '#surprising', '#admirable', 0.043, 'commercial', 'make_other_person_laugh', 'presentation', 'satire', 'funny']
senticnet['netted'] = [0, 0, -0.839, -0.759, '#scared', '#disgusting', -0.533, 'webbed', 'net', 'lacy', 'netlike', 'weblike']
senticnet['approximately'] = [0, 0, -0.725, -0.873, '#scared', '#disgusting', -0.533, 'close_to', 'some', 'just_about', 'roughly', 'about']
senticnet['prehend'] = [0.981, -0.727, 0, 0.638, '#joyful', '#surprising', 0.782, 'swoop', 'swoop_up', 'seize', 'snatch_up', 'clutch']
senticnet['better_others_person'] = [0, 0.852, 0, 0.958, '#interesting', '#admirable', 0.603, 'better_others', 'medical', 'trustworthy', 'doctor_patient', 'treat_illness']
senticnet['restart'] = [0, 0.201, 0.018, 0.077, '#interesting', '#admirable', 0.087, 'boot_up_computer', 'start_up', 'connect_internet', 'buy_computer', 'shut_down']
senticnet['whitening'] = [0.995, -0.533, 0, 0.977, '#joyful', '#admirable', 0.835, 'change_of_state', 'discoloration', 'discolouration', 'change_of_color', 'lightening']
senticnet['positivity'] = [0.854, -0.794, 0, 0.977, '#joyful', '#admirable', 0.875, 'profitableness', 'favorableness', 'favourableness', 'auspiciousness', 'advantageousness']
senticnet['care_for'] = [0.732, 0, 0, 0.907, '#joyful', '#admirable', 0.546, 'cherish', 'prize', 'appreciate', 'value', 'treasured']
senticnet['supple'] = [0, 0, -0.926, -0.837, '#scared', '#disgusting', -0.588, 'sylphlike', 'lithe', 'lissom', 'slender', 'svelte']
senticnet['toddle'] = [-0.8, 0, -0.804, 0, '#sad', '#scared', -0.535, 'coggle', 'paddle', 'dodder', 'totter', 'waddle']
senticnet['platinum'] = [0.102, 0.078, 0, 0.087, '#joyful', '#admirable', 0.089, 'gold', 'adjustable', 'iron_ore', 'silver', 'magnetic']
senticnet['first_man'] = [0.783, 0.708, 0, 0, '#joyful', '#interesting', 0.497, 'eden', 'adam_and_eve', 'first_woman', 'religious', 'bible']
senticnet['unify'] = [0, 0, -0.832, -0.845, '#scared', '#disgusting', -0.559, 'mingle', 'coalesced', 'commix', 'mix', 'amalgamate']
senticnet['moistureity'] = [0, -0.037, 0.05, -0.142, '#angry', '#disgusting', -0.052, 'humid', 'wetness', 'damp', 'moisture', 'dank']
senticnet['regimented'] = [0.858, -0.933, 0, 0.58, '#joyful', '#surprising', 0.79, 'controlled', 'obsessed', 'possessed', 'disciplined', 'dominated']
senticnet['receive_earn_paycheck'] = [0.832, 0, 0, 0, '#joyful', '#joyful', 0.277, 'earn_money', 'paycheck', 'earn', 'earn_paycheck', 'finish_work']
senticnet['rebound'] = [0.715, 0, 0, 0.783, '#joyful', '#admirable', 0.499, 'reply', 'response', 'comeback', 'backtalk', 'revival']
senticnet['grandness'] = [0, 0.967, 0, 0.824, '#interesting', '#admirable', 0.597, 'stateliness', 'excellence', 'impressiveness', 'richness', 'expansivity']
senticnet['vasoconstrictive'] = [0.887, -0.9, 0, 0.852, '#joyful', '#surprising', 0.88, 'pressor', 'phenylephrine', 'phenylpropanolamine', 'vasoconstrictor', 'adrenergic']
senticnet['skittish'] = [0.963, -0.987, 0, 0.514, '#joyful', '#surprising', 0.821, 'warm', 'flighty', 'nervous', 'excitable', 'spooky']
senticnet['subservient'] = [0.981, -0.887, 0, 0.939, '#joyful', '#admirable', 0.936, 'slavelike', 'submissive', 'servile', 'obsequious', 'slavish']
senticnet['respectful'] = [0.958, 0, 0, 0.968, '#joyful', '#admirable', 0.642, 'kind', 'nice', 'at_your_service', 'humble', 'red_carpet']
senticnet['suzerainty'] = [0.94, -0.636, 0, 0.772, '#joyful', '#admirable', 0.783, 'paramountcy', 'raj', 'reign', 'sovereignty', 'dominion']
senticnet['resurrect'] = [0.658, -0.605, 0, 0.691, '#joyful', '#admirable', 0.651, 'bring_up', 'revive', 'bring_around', 'boot', 'reboot']
senticnet['unread'] = [-0.981, 0, 0, -0.966, '#sad', '#disgusting', -0.649, 'naive', 'unenlightened', 'uninformed', 'unknowing', 'clueless']
senticnet['serviceability'] = [0.513, -0.874, 0, 0.924, '#surprising', '#admirable', 0.77, 'quality', 'usefulness', 'serviceableness', 'usableness', 'user_friendly']
senticnet['thin-skinned'] = [0, 0, -0.887, -0.891, '#scared', '#disgusting', -0.593, 'touchy', 'spunky', 'plucky', 'feisty', 'huffy']
senticnet['haze_over'] = [0, 0, -0.83, -0.919, '#scared', '#disgusting', -0.583, 'befog', 'fog', 'becloud', 'obscured', 'obnubilate']
senticnet['resurgent'] = [0.673, -0.95, 0, 0.914, '#surprising', '#admirable', 0.846, 'renewed', 'revitalized', 'revived', 'renascent', 'resuscitated']
senticnet['unstained'] = [0.513, -0.585, 0, 0.919, '#surprising', '#admirable', 0.672, 'stainless', 'untainted', 'untarnished', 'unsullied', 'unblemished']
senticnet['latitude'] = [0, 0, -0.9, -0.871, '#scared', '#disgusting', -0.59, 'analogue', 'analog', 'line_of_latitude', 'parallel', 'collimate']
senticnet['programmer'] = [0.066, 0, -0.059, 0.066, '#joyful', '#admirable', 0.024, 'cyclist', 'smoker', 'homeowner', 'chauffeur', 'stalactite']
senticnet['tell_on'] = [0, 0, -0.721, -0.707, '#scared', '#disgusting', -0.476, 'betray', 'stigmatize', 'denounce', 'brand', 'mark']
senticnet['salami'] = [0.662, -0.636, 0, 0.628, '#joyful', '#surprising', 0.642, 'knackwurst', 'knockwurst', 'hotdog', 'frank', 'sausage']
senticnet['retriever'] = [0.034, 0.074, 0, 0, '#joyful', '#interesting', 0.036, 'pet', 'pag', 'most_cats', 'dog', 'poodle']
senticnet['overweening'] = [0, 0, 0.845, -0.919, '#angry', '#disgusting', -0.588, 'extravagant', 'excessive', 'wasteful', 'exuberant', 'prodigal']
senticnet['frazzle'] = [-0.783, 0, -0.837, 0, '#sad', '#scared', -0.54, 'fret', 'rub', 'scratch', 'frayed', 'chafe']
senticnet['pallgriever'] = [-0.989, 0, 0.664, -0.524, '#sad', '#angry', -0.726, 'unfortunate', 'unfortunate_person', 'weeper', 'bearer', 'griever']
senticnet['vulgar'] = [0, 0, -0.972, -0.993, '#scared', '#disgusting', -0.655, 'harsh', 'common', 'rough-cut', 'uncouth', 'coarse']
senticnet['writhe'] = [0, 0, -0.945, -0.91, '#scared', '#disgusting', -0.618, 'wriggle', 'wrestle', 'squirm', 'worm', 'writhing']
senticnet['tide'] = [0.632, -0.613, 0, 0.525, '#joyful', '#surprising', 0.59, 'neap_tide', 'neap', 'springtide', 'high_tide', 'direct_tide']
senticnet['walkway'] = [0.029, 0.087, 0.065, 0.137, '#interesting', '#admirable', 0.063, 'archway', 'arch', 'mat', 'passageway', 'aisle']
senticnet['supporter'] = [0.814, -0.508, 0, 0.622, '#joyful', '#admirable', 0.648, 'friend', 'champion', 'admirer', 'protagonist', 'endorser']
senticnet['particolohorse_chestnut'] = [-0.579, 0, 0.582, -0.65, '#angry', '#disgusting', -0.604, 'sweet_buckeye', 'dwarf_buckeye', 'bottlebrush_buckeye', 'horse_chestnut', 'red_buckeye']
senticnet['unprejudiced'] = [-0.955, 0, 0.961, 0, '#sad', '#angry', -0.639, 'dispassionate', 'indifferent', 'unbiased', 'disinterested', 'neutral']
senticnet['virginal'] = [0.839, -0.704, 0, 0.93, '#joyful', '#admirable', 0.824, 'virtuous', 'chaste', 'pure', 'continent', 'celibate']
senticnet['brown_rot_brown_rot'] = [-0.833, 0, 0.754, -0.979, '#sad', '#disgusting', -0.855, 'gummosis', 'ring_rot', 'ring_disease', 'tobacco_wilt', 'brown_rot']
senticnet['blank_spaceation'] = [-0.982, 0, 0.959, -0.685, '#sad', '#angry', -0.875, 'expanse', 'margin', 'indent', 'blank_spaceion', 'blank_space']
senticnet['untrue'] = [-0.669, 0, 0.709, -0.881, '#angry', '#disgusting', -0.753, 'apostate', 'unfaithful', 'treacherous', 'perfidious', 'punic']
senticnet['yearning'] = [0.885, -0.676, 0, 0.645, '#joyful', '#surprising', 0.735, 'dissatisfaction', 'disgruntlement', 'dysphoria', 'longing', 'discontentedness']
senticnet['vivacious'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'lively', 'buoyant', 'joyful', 'cheerful', 'happy']
senticnet['ornithology'] = [-0.982, 0, 0.937, -0.689, '#sad', '#angry', -0.869, 'bird_watcher', 'ornithologist', 'hobby', 'naturalist', 'amateur']
senticnet['respected'] = [0.991, -0.989, 0, 0.588, '#joyful', '#surprising', 0.856, 'estimable', 'esteemed', 'reputable', 'honored', 'prestigious']
senticnet['shuttle'] = [0.847, 0, 0, 0.858, '#joyful', '#admirable', 0.568, 'displace', 'swing', 'snowshoe', 'dodge', 'bang']
senticnet['gauze-like'] = [0, 0, -0.994, -0.974, '#scared', '#disgusting', -0.656, 'diaphanous', 'filmy', 'gauzy', 'gossamer', 'see-through']
senticnet['black_teeth'] = [-0.74, 0, 0, -0.983, '#sad', '#disgusting', -0.574, 'ethnicity', 'paint_nail', 'black_stuff', 'burnt', 'racism']
senticnet['retiring'] = [-0.896, 0, -0.864, 0, '#sad', '#scared', -0.587, 'reticent', 'restrained', 'unemotional', 'untalkative', 'self-effacing']
senticnet['humdrum'] = [-0.793, 0, 0, -0.992, '#sad', '#disgusting', -0.595, 'cliche', 'banality', 'prosaic', 'unexciting', 'commonplace']
senticnet['windflower'] = [0, 0.068, -0.065, 0.081, '#interesting', '#admirable', 0.028, 'flower', 'anemone', 'leaves', 'plant', 'bright_petals']
senticnet['combative'] = [0, 0.706, 0, 0.714, '#interesting', '#admirable', 0.473, 'ambitious', 'driven', 'vying', 'competitive', 'contentious']
senticnet['deluxe'] = [0.92, 0.879, 0, 0, '#joyful', '#interesting', 0.6, 'luxurious', 'princely', 'gilded', 'grand', 'opulent']
senticnet['baked'] = [0, 0, -0.923, -0.966, '#scared', '#disgusting', -0.63, 'adust', 'scorched', 'sear', 'sunbaked', 'parched']
senticnet['undergird'] = [0.669, -0.814, 0, 0.515, '#joyful', '#surprising', 0.666, 'strengthen', 'secure', 'reenforce', 'vitalize', 'reinforce']
senticnet['derogate'] = [0, 0, -0.83, -0.954, '#scared', '#disgusting', -0.595, 'minimize', 'slander', 'defame', 'denigrate', 'belittle']
senticnet['rabidness'] = [0.609, -0.615, 0, 0.592, '#joyful', '#surprising', 0.605, 'spirit', 'rabidity', 'ebullience', 'sprightliness', 'lyricism']
senticnet['softened'] = [0, 0, -0.935, -0.886, '#scared', '#disgusting', -0.607, 'dull', 'muffle', 'tone_down', 'hushed', 'muted']
senticnet['degeneracy'] = [0, 0, -0.715, -0.7, '#scared', '#disgusting', -0.472, 'turpitude', 'putrefaction', 'corruption', 'depravation', 'depravity']
senticnet['shining'] = [0.577, -0.696, 0, 0.645, '#surprising', '#admirable', 0.639, 'burnished', 'lustrous', 'shiny', 'bright', 'polished']
senticnet['mischievous'] = [0, 0, -0.732, -0.857, '#scared', '#disgusting', -0.53, 'impish', 'prankish', 'implike', 'arch', 'pixilated']
senticnet['verdure'] = [0.581, -0.656, 0, 0.959, '#surprising', '#admirable', 0.732, 'wilderness', 'overgrowth', 'greenness', 'verdancy', 'profuseness']
senticnet['fixed_pattern_of_behavior'] = [0, 0, -0.998, -0.768, '#scared', '#disgusting', -0.589, 'animal_behavior', 'animal_instinct', 'overeact', 'instinct', 'impulse']
senticnet['moil'] = [-0.908, 0, 0.965, 0, '#sad', '#angry', -0.624, 'stewing', 'simmering', 'churn', 'boiling', 'seethe']
senticnet['taxiway'] = [0.745, 0.898, 0, 0, '#joyful', '#interesting', 0.548, 'highway', 'aircraft_roadway', 'runway', 'flight_terminal', 'ticket_counter']
senticnet['biting'] = [0, 0, -0.915, -0.823, '#scared', '#disgusting', -0.579, 'barbed', 'pungent', 'acrid', 'mordacious', 'nipping']
senticnet['spout'] = [0.584, -0.938, 0, 0.927, '#surprising', '#admirable', 0.816, 'elocute', 'perorate', 'perform', 'orate', 'declaim']
senticnet['thesis'] = [0, 0.921, 0, 0.853, '#interesting', '#admirable', 0.591, 'royal_flush', 'volume_control', 'book_genre', 'myth', 'classic']
senticnet['eatage'] = [0, 0, -0.903, -0.99, '#scared', '#disgusting', -0.631, 'foraging', 'pasture', 'grass', 'forage', 'scrounge']
senticnet['medical_treatment'] = [-0.745, 0, 0, -0.735, '#sad', '#disgusting', -0.493, 'skin_condition', 'adolescent', 'pimples', 'acne_medication', 'prescription']
senticnet['washer'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'purse', 'pocket', 'clothes_washer', 'wallet_purse', 'woman_purse']
senticnet['sinning'] = [0.69, -0.644, 0, 0.825, '#joyful', '#admirable', 0.72, 'lust', 'mortal_sin', 'luxuria', 'pride', 'superbia']
senticnet['time_waster_class'] = [-0.883, 0, 0, -0.863, '#sad', '#disgusting', -0.582, 'school', 'school_system', 'class', 'time_waster', 'college']
senticnet['toon'] = [0.789, -0.518, 0, 0.947, '#joyful', '#admirable', 0.751, 'flick', 'cartoon', 'short_subject', 'animated_cartoon', 'newsreel']
senticnet['regulate'] = [0.933, -0.836, 0, 0.826, '#joyful', '#surprising', 0.865, 'influence', 'determine', 'shape', 'mold', 'carry_weight']
senticnet['stargazing'] = [0.056, -0.035, 0, 0.054, '#joyful', '#admirable', 0.048, 'analyze', 'examine', 'influence_public_decision', 'question_everything', 'see_artifact']
senticnet['coarse-grained'] = [0, -0.899, 0, 0.932, '#surprising', '#admirable', 0.61, 'granular', 'gamy', 'spirited', 'farinaceous', 'gritty']
senticnet['high_jollification'] = [-0.85, 0, 0.691, -0.821, '#sad', '#disgusting', -0.787, 'jollification', 'jinks', 'hijollification', 'high_jinx', 'revel']
senticnet['treats'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'dog_food', 'toy', 'lure', 'attract_dog', 'whistle']
senticnet['short-lived'] = [0, 0, -0.849, -0.705, '#scared', '#disgusting', -0.518, 'transitory', 'transeunt', 'ephemeral', 'passing', 'transient']
senticnet['unbelievable_of'] = [-0.542, 0, 0.646, -0.62, '#angry', '#disgusting', -0.603, 'improbable', 'unbelievable', 'undreamed', 'undreamt', 'undreamt_of']
senticnet['flog'] = [0, 0, -0.789, -0.923, '#scared', '#disgusting', -0.571, 'rebuke', 'take_to_task', 'lambaste', 'call_on_carpet', 'cane']
senticnet['structure_support'] = [0.994, 0, 0, 0.772, '#joyful', '#admirable', 0.589, 'large_architectural_structure', 'architectural_structure', 'home_architectural_structure', 'architect', 'build']
senticnet['saliency'] = [0.55, -0.742, 0, 0.81, '#surprising', '#admirable', 0.701, 'strikingness', 'glare', 'salience', 'prominence', 'standing']
senticnet['salience'] = [0.55, -0.742, 0, 0.81, '#surprising', '#admirable', 0.701, 'strikingness', 'glare', 'prominence', 'saliency', 'standing']
senticnet['arborous'] = [0, 0, -0.756, -0.88, '#scared', '#disgusting', -0.545, 'tree-living', 'dendroidal', 'arboreal', 'arboriform', 'arborary']
senticnet['resist'] = [-0.054, 0.08, -0.054, 0.158, '#interesting', '#admirable', 0.043, 'hold_out', 'hold_match', 'strike_against', 'put_effort', 'change_plan']
senticnet['coalesced'] = [0, 0, -0.832, -0.845, '#scared', '#disgusting', -0.559, 'mingle', 'amalgamate', 'commix', 'mix', 'unify']
senticnet['faltering'] = [0, 0, 0.793, -0.837, '#angry', '#disgusting', -0.543, 'stumble', 'waver', 'hesitation', 'bumble', 'falters']
senticnet['specifiable'] = [0.935, -0.958, 0, 0.949, '#surprising', '#admirable', 0.947, 'identifiable', 'acknowledgeable', 'recognizable', 'diagnosable', 'classifiable']
senticnet['pull_together'] = [0, 0, -0.7, -0.912, '#scared', '#disgusting', -0.537, 'earn', 'garner', 'gather', 'collect', 'granary']
senticnet['utilitarian'] = [0.922, -0.949, 0, 0.965, '#surprising', '#admirable', 0.945, 'elitist', 'egalitarian', 'equalitarian', 'moralist', 'philosopher']
senticnet['cut_tool_edge'] = [-0.054, -0.029, 0.05, -0.133, '#sad', '#disgusting', -0.069, 'dagger', 'machete', 'cut_tool', 'sharp', 'use_knife']
senticnet['cruciferwort'] = [-0.569, 0, 0.892, -0.784, '#angry', '#disgusting', -0.748, 'borecrucifer', 'cole', 'kail', 'crucifer', 'kale']
senticnet['playtime'] = [-0.066, 0.19, 0.039, 0.103, '#interesting', '#admirable', 0.063, 'young_child', 'child', 'baby', 'small_child', 'childhood']
senticnet['unvoiced'] = [0.531, -0.769, 0, 0.603, '#surprising', '#admirable', 0.634, 'tacit', 'understood', 'implicit', 'silent', 'unspoken']
senticnet['specific'] = [0, 0, 0, 0.865, '#admirable', '#admirable', 0.288, 'animal', 'kind_pet', 'pet', 'disarray', 'face_other']
senticnet['spic-and-span'] = [0, 0, -0.866, -0.738, '#scared', '#disgusting', -0.535, 'spotless', 'spick-and-span', 'spic', 'immaculate', 'speckless']
senticnet['subordination'] = [0.809, -0.588, 0, 0.702, '#joyful', '#admirable', 0.7, 'state', 'reliance', 'contingency', 'helplessness', 'dependence']
senticnet['misleading'] = [0, 0, 0.863, -0.745, '#angry', '#disgusting', -0.536, 'jerry-built', 'tawdry', 'shoddy', 'deceptive', 'cheapjack']
senticnet['landing_airstrip'] = [-0.975, 0, 0.737, -0.979, '#sad', '#disgusting', -0.897, 'flare_path', 'airairstrip', 'field', 'flying_airstrip', 'airstrip']
senticnet['scamper'] = [0, 0, -0.911, -0.998, '#scared', '#disgusting', -0.636, 'skitter', 'hatchway', 'scuttle', 'opening', 'scurry']
senticnet['unpretentious'] = [0, 0, -0.868, -0.782, '#scared', '#disgusting', -0.55, 'minimize', 'minimise', 'understated', 'unostentatious', 'downplay']
senticnet['kitschy'] = [0, 0, -0.753, -0.986, '#scared', '#disgusting', -0.58, 'maudlin', 'mawkish', 'drippy', 'hokey', 'bathetic']
senticnet['ungracious'] = [0.584, -0.592, 0, 0.753, '#surprising', '#admirable', 0.643, 'brattish', 'discourteous', 'bratty', 'impolite', 'unparliamentary']
senticnet['rose_cheeked'] = [0.953, 0, 0, 0.865, '#joyful', '#admirable', 0.606, 'fortunate', 'rose_colored', 'rosy', 'blushful', 'flushed']
senticnet['ghastly'] = [0, 0, 0.808, -0.91, '#angry', '#disgusting', -0.573, 'grim', 'gruesome', 'macabre', 'sick', 'grisly']
senticnet['takeoff'] = [-0.899, 0, -0.802, 0, '#sad', '#scared', -0.567, 'mockery', 'spoof', 'sendup', 'lampoon', 'parody']
senticnet['whisk'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'address_book', 'get_rich', 'ladle', 'swiss_army_knife', 'blank_check']
senticnet['eruditeness'] = [0.758, 0, 0, 0.939, '#joyful', '#admirable', 0.566, 'encyclopedism', 'learning', 'scholarship', 'learnedness', 'erudition']
senticnet['subjugable'] = [0.702, -0.944, 0, 0.582, '#joyful', '#surprising', 0.743, 'conquerable', 'vanquishable', 'vincible', 'subduable', 'beatable']
senticnet['faineant'] = [0, 0, -0.869, -0.721, '#scared', '#disgusting', -0.53, 'otiose', 'slothful', 'indolent', 'lazy', 'work-shy']
senticnet['scrimshaw'] = [0.969, -0.686, 0, 0.756, '#joyful', '#admirable', 0.804, 'vermiculation', 'cinquefoil', 'glyptic_art', 'glyptography', 'carving']
senticnet['skimp'] = [0, -0.887, 0, 0.728, '#surprising', '#admirable', 0.538, 'scrimp', 'economical', 'scant', 'frugal', 'stinting']
senticnet['unutterable'] = [0, 0, -0.763, -0.862, '#scared', '#disgusting', -0.542, 'untellable', 'unspeakable', 'indescribable', 'indefinable', 'ineffable']
senticnet['business_leader'] = [0, 0, -0.747, -0.893, '#scared', '#disgusting', -0.547, 'king', 'baron', 'magnate', 'mogul', 'big_businessman']
senticnet['refund'] = [-0.065, 0.097, 0, 0.076, '#interesting', '#admirable', 0.036, 'buy_stuff', 'return_goods', 'buy_goods', 'buy_item', 'buy_cheap_item']
senticnet['forficate'] = [0, 0, -0.889, -0.783, '#scared', '#disgusting', -0.557, 'forked', 'pronged', 'branched', 'bifurcate', 'biramous']
senticnet['varicolored'] = [0.767, 0, 0, 0.844, '#joyful', '#admirable', 0.537, 'calico', 'multi-color', 'pied', 'motley', 'painted']
senticnet['higlorious'] = [-0.838, 0, 0.896, -0.959, '#angry', '#disgusting', -0.898, 'glorious', 'incandescent', 'storied', 'divine', 'empyreal']
senticnet['realism'] = [0.99, -0.88, 0, 0.831, '#joyful', '#surprising', 0.9, 'practicality', 'sensibleness', 'viability', 'usefulness', 'functionality']
senticnet['splashy'] = [0, -1.0, 0, 0.766, '#surprising', '#admirable', 0.589, 'flamboyant', 'royal_poinciana', 'florid', 'showy', 'aureate']
senticnet['male_admirer'] = [0.706, 0, 0, 0.756, '#joyful', '#admirable', 0.487, 'dandy', 'beau', 'boyfriend', 'rich', 'young_man']
senticnet['pelican_pedestrian_crossing'] = [0.508, -0.726, 0, 0.727, '#surprising', '#admirable', 0.654, 'crosswalk', 'crossing', 'school_pedestrian_crossing', 'pedestrian_crossing', 'crossover']
senticnet['cloak-and-dagger'] = [0, 0, -0.806, -0.738, '#scared', '#disgusting', -0.515, 'secret', 'hush-hush', 'hugger-mugger', 'clandestine', 'hole-and-corner']
senticnet['royal_poinciana'] = [0, -1.0, 0, 0.766, '#surprising', '#admirable', 0.589, 'splashy', 'flamboyant', 'florid', 'showy', 'aureate']
senticnet['dust_matter'] = [-0.955, 0, 0.738, -0.584, '#sad', '#angry', -0.759, 'fallout', 'chalk_dust', 'radioactive_dust', 'dust', 'particulate']
senticnet['simmering'] = [-0.908, 0, 0.965, 0, '#sad', '#angry', -0.624, 'stewing', 'boiling', 'churn', 'moil', 'seethe']
senticnet['good-looking'] = [0.757, 0.837, 0, 0, '#joyful', '#interesting', 0.531, 'big', 'well-favored', 'handsome', 'better-looking', 'bighearted']
senticnet['crossbeam'] = [0, 0, -0.778, -0.778, '#scared', '#disgusting', -0.519, 'transom', 'track', 'crosspiece', 'traverse', 'traversal']
senticnet['polo'] = [-0.024, -0.051, 0, 0.069, '#surprising', '#admirable', 0.032, 'equestrian_sport', 'soccer', 'game', 'type_of_sport', 'expensive_sport']
senticnet['medical_scrutiny'] = [0.934, -0.884, 0, 0.797, '#joyful', '#surprising', 0.872, 'scan', 'scrutiny', 'checkup', 'medical_examination', 'medical_exam']
senticnet['imcapableness'] = [0.946, -0.641, 0, 0.602, '#joyful', '#surprising', 0.73, 'grasp', 'capableness', 'perfectibility', 'reach', 'aptitude']
senticnet['trackless'] = [0, 0, 0.737, -0.897, '#angry', '#disgusting', -0.545, 'outback', 'inaccessible', 'pathless', 'roadless', 'untracked']
senticnet['volition'] = [0.729, 0.974, 0, 0, '#joyful', '#interesting', 0.568, 'unforced', 'leave', 'bequeath', 'willing', 'uncoerced']
senticnet['vantage'] = [0.761, -0.502, 0, 0.896, '#joyful', '#admirable', 0.72, 'advantage', 'favorable_position', 'upper_hand', 'whip_hand', 'edge']
senticnet['oversensitive'] = [0, 0, 0.826, -0.703, '#angry', '#disgusting', -0.51, 'sensitivity', 'touchy', 'huffy', 'feisty', 'hard']
senticnet['rubeola'] = [0.925, -0.561, 0, 0.626, '#joyful', '#admirable', 0.704, 'influenza', 'flu', 'grippe', 'measles', 'contagion']
senticnet['recital'] = [0, 0, 0.704, -0.77, '#angry', '#disgusting', -0.491, 'explanation', 'check', 'record', 'report', 'disquisition']
senticnet['clod'] = [0, 0, -0.756, -0.851, '#scared', '#disgusting', -0.536, 'oaf', 'lummox', 'goon', 'stumblebum', 'lout']
senticnet['perilous'] = [0, 0, -0.842, -0.92, '#scared', '#disgusting', -0.587, 'unstable', 'parlous', 'precarious', 'touch-and-go', 'shaky']
senticnet['unceremonious'] = [0.694, -0.554, 0, 0.894, '#joyful', '#admirable', 0.714, 'curt', 'brusque', 'discourteous', 'abrupt', 'brusk']
senticnet['ill-timed'] = [0, 0, -0.906, -0.995, '#scared', '#disgusting', -0.634, 'wrong', 'prematurely', 'unseasonable', 'premature', 'untimely']
senticnet['unelaborated'] = [0.903, -0.935, 0, 0.996, '#surprising', '#admirable', 0.945, 'sketchy', 'incomplete', 'partial', 'uncompleted', 'broken']
senticnet['veracity'] = [0.76, -0.593, 0, 0.713, '#joyful', '#admirable', 0.689, 'sooth', 'sincerity', 'honestness', 'honesty', 'truthfulness']
senticnet['prolific'] = [0.851, -0.671, 0, 0.854, '#joyful', '#admirable', 0.792, 'fertile', 'breeding', 'bountiful', 'fruitful', 'productive']
senticnet['undervaluation'] = [0.798, -0.527, 0, 0.693, '#joyful', '#admirable', 0.673, 'overvaluation', 'grade', 'rating', 'pricing', 'reevaluation']
senticnet['wader'] = [0.797, -0.719, 0, 0.736, '#joyful', '#admirable', 0.751, 'wood_ibis', 'wood_stork', 'sacred_ibis', 'wading_bird', 'ibis']
senticnet['tributary'] = [0.59, -0.599, 0, 0.527, '#joyful', '#surprising', 0.572, 'responsible', 'inducive', 'activating', 'causative', 'motivative']
senticnet['politico'] = [0.838, -0.589, 0, 0.945, '#joyful', '#admirable', 0.791, 'national_leader', 'stateswoman', 'politician', 'elder_statesman', 'pol']
senticnet['plonk'] = [0, 0, -0.953, -0.711, '#scared', '#disgusting', -0.555, 'plank', 'plump', 'flump', 'plop', 'plummet']
senticnet['unproblematic'] = [0.769, 0.98, 0, 0, '#joyful', '#interesting', 0.583, 'simple', 'uncomplicated', 'elementary', 'basic', 'primary']
senticnet['communicable'] = [-0.857, 0, 0, -0.982, '#sad', '#disgusting', -0.613, 'infectious', 'contagious', 'epidemic', 'pandemic', 'epizootic']
senticnet['misinterpret'] = [0, 0, -0.921, -0.928, '#scared', '#disgusting', -0.616, 'misapprehend', 'amiss', 'misconstrue', 'misunderstand', 'misconceive']
senticnet['precipitant'] = [-0.848, 0, 0.908, 0, '#sad', '#angry', -0.585, 'hasty', 'come_down', 'fall', 'overhasty', 'precipitate']
senticnet['sculptural'] = [0.636, -0.954, 0, 0.664, '#surprising', '#admirable', 0.751, 'voluptuous', 'statuesque', 'sculptured', 'shapely', 'buxom']
senticnet['sentry'] = [0, 0, -0.77, -0.752, '#scared', '#disgusting', -0.507, 'watch', 'lookout', 'sentinel', 'lookout_man', 'spotter']
senticnet['excursion'] = [0, 0, 0.904, -0.804, '#angry', '#disgusting', -0.569, 'outing', 'junket', 'pleasure_trip', 'jaunt', 'expedition']
senticnet['stemma'] = [0.753, -0.647, 0, 0.556, '#joyful', '#surprising', 0.652, 'oculus_dexter', 'eye', 'naked_eye', 'peeper', 'oculus_sinister']
senticnet['maculate'] = [0, 0, -0.991, -0.925, '#scared', '#disgusting', -0.639, 'varnished', 'tarnish', 'stained', 'sully', 'defile']
senticnet['untainted'] = [0.513, -0.585, 0, 0.919, '#surprising', '#admirable', 0.672, 'stainless', 'unblemished', 'untarnished', 'unsullied', 'unstained']
senticnet['seditious'] = [-0.789, 0, -0.751, 0, '#sad', '#scared', -0.513, 'revolutionist', 'subverter', 'insurgent', 'subversive', 'revolutionary']
senticnet['discrete'] = [0.891, 0.987, 0, 0, '#joyful', '#interesting', 0.626, 'distinguishable', 'distinct', 'decided', 'clear-cut', 'trenchant']
senticnet['double-dealing'] = [0, 0, -0.901, -0.703, '#scared', '#disgusting', -0.535, 'duplicitous', 'deceitful', 'ambidextrous', 'janus-faced', 'two-handed']
senticnet['sexual_paraphilia'] = [-0.622, 0, 0.515, -0.638, '#sad', '#disgusting', -0.592, 'immodesty', 'paraphilia', 'exhibitionism', 'perversion', 'fetishism']
senticnet['sulfadiazine'] = [0.551, -0.753, 0, 0.817, '#surprising', '#admirable', 0.707, 'antibacterial', 'sulfamethoxazole', 'sulfisoxazole', 'sulfa', 'sulfacetamide']
senticnet['aureate'] = [0, -1.0, 0, 0.766, '#surprising', '#admirable', 0.589, 'splashy', 'royal_poinciana', 'florid', 'showy', 'flamboyant']
senticnet['cosh'] = [0, 0, -0.94, -0.948, '#scared', '#disgusting', -0.629, 'tomfool', 'fool', 'sap', 'blackjack', 'muggins']
senticnet['semiliterate'] = [0.786, -0.527, 0, 0.848, '#joyful', '#admirable', 0.72, 'learned', 'educated', 'knowledgeable', 'lettered', 'literate']
senticnet['line-shooter'] = [0, 0, 0.765, -0.748, '#angry', '#disgusting', -0.504, 'boaster', 'braggart', 'vaunter', 'blowhard', 'bragger']
senticnet['point_weapon'] = [0.717, 0.935, 0, 0, '#joyful', '#interesting', 0.551, 'intention', 'aim', 'life_goal', 'objective', 'target']
senticnet['dead_tired'] = [0, 0, 0.933, -0.863, '#angry', '#disgusting', -0.599, 'tired', 'energy_exhaustion', 'need_rest', 'exhausted', 'lack_of_rest']
senticnet['feeling_no_interestunconcerned'] = [-0.849, 0, -0.829, 0, '#sad', '#scared', -0.559, 'unconcern', 'apathetic', 'unconcernedly', 'apathetically', 'indifferently']
senticnet['plethoric'] = [0, 0, -0.928, -0.774, '#scared', '#disgusting', -0.567, 'overabundant', 'prevailing', 'rife', 'predominant', 'dominant']
senticnet['whelm'] = [0.627, -0.651, 0, 0.968, '#surprising', '#admirable', 0.749, 'overwhelm', 'overpower', 'sweep_over', 'benight', 'overcome']
senticnet['varnish'] = [0.031, 0.103, 0, 0.06, '#interesting', '#admirable', 0.065, 'graphical_representation', 'photo', 'artwork', 'photograph', 'crayon']
senticnet['goodly'] = [0.737, 0, 0, 0.957, '#joyful', '#admirable', 0.565, 'muscular', 'hefty', 'sinewy', 'powerful', 'brawny']
senticnet['batch'] = [0, 0, 0.869, -0.745, '#angry', '#disgusting', -0.538, 'great_deal', 'flock', 'slew', 'slide', 'deal']
senticnet['quail'] = [0.026, 0.069, 0, 0, '#joyful', '#interesting', 0.032, 'chicken_egg', 'chicken_soup', 'chick', 'male_chicken', 'chicken']
senticnet['riffle'] = [0.969, -0.575, 0, 0.851, '#joyful', '#admirable', 0.798, 'thumb', 'flick', 'flip', 'peruse', 'leaf']
senticnet['vindicate'] = [0.799, -0.888, 0, 0.883, '#surprising', '#admirable', 0.857, 'pronounce', 'purge', 'whitewash', 'acquit', 'label']
senticnet['movie_action_movie'] = [0, 0.951, 0, 0, '#interesting', '#interesting', 0.317, 'part_of_history', 'genre', 'action_movie', 'fictional', 'horror_movie']
senticnet['characterization'] = [0, 0, -0.999, -0.848, '#scared', '#disgusting', -0.616, 'word_picture', 'picture', 'word-painting', 'depiction', 'delineation']
senticnet['cute_big_cat'] = [0.028, 0, 0.013, 0.061, '#joyful', '#admirable', 0.025, 'cat', 'domestibig_cate_animal', 'big_cat', 'big_animal', 'big']
senticnet['stricken'] = [0.854, -0.845, 0, 0.679, '#joyful', '#surprising', 0.793, 'taken', 'subject', 'impressed', 'struck', 'affected']
senticnet['vagabond'] = [-0.817, 0, 0.747, -0.886, '#sad', '#disgusting', -0.817, 'vagrant', 'drifter', 'floater', 'dosser', 'hobo']
senticnet['playlet'] = [0.734, -0.604, 0, 0.612, '#joyful', '#admirable', 0.65, 'theater_of_absurd', 'drama', 'miracle_play', 'morality_play', 'mystery_play']
senticnet['fingerblotk'] = [-0.879, 0, 0.881, -0.731, '#sad', '#angry', -0.83, 'mar', 'blemish', 'blot', 'defect', 'blotch']
senticnet['potassium'] = [0.021, 0, 0, 0.054, '#joyful', '#admirable', 0.025, 'gold', 'gem', 'manganese', 'diamond', 'silver']
senticnet['forbidding'] = [0, 0, 0.882, -0.991, '#angry', '#disgusting', -0.624, 'formidable', 'redoubtable', 'daunting', 'alarming', 'frightening']
senticnet['quantification'] = [-0.938, 0, 0, -0.859, '#sad', '#disgusting', -0.599, 'narrowness', 'limitation', 'regulation', 'restraint', 'limit']
senticnet['pleasure_trip'] = [0, 0, 0.904, -0.804, '#angry', '#disgusting', -0.569, 'outing', 'junket', 'jaunt', 'excursion', 'expedition']
senticnet['severable'] = [0.998, -0.635, 0, 0.574, '#joyful', '#surprising', 0.736, 'divisible', 'dissociable', 'separable', 'cleavable', 'dissociative']
senticnet['desired'] = [0.733, 0, 0, 0.728, '#joyful', '#admirable', 0.487, 'enviousness', 'enviably', 'preferred', 'lovable', 'enviable']
senticnet['vividness'] = [0.509, -0.678, 0, 0.707, '#surprising', '#admirable', 0.631, 'color', 'newsworthiness', 'shrillness', 'interestingness', 'charisma']
senticnet['rede'] = [0.506, -0.599, 0, 0.896, '#surprising', '#admirable', 0.667, 'naturalize', 'clarify', 'clear_up', 'elucidate', 'explicate']
senticnet['droopy'] = [-0.83, 0, 0, -0.713, '#sad', '#disgusting', -0.514, 'limp', 'crooked', 'inclined', 'bent', 'arciform']
senticnet['usa'] = [0.08, 0, -0.071, 0.133, '#joyful', '#admirable', 0.047, 'state_america', 'state', 'name_state', 'united_states', 'large_state']
senticnet['sculptor'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'art_craft', 'carving', 'art', 'craft', 'wood_product']
senticnet['topic'] = [0.072, 0.269, -0.192, 0.29, '#interesting', '#admirable', 0.146, 'obedience', 'demand', 'affirmation', 'proof', 'indeed']
senticnet['halitosis'] = [0, 0, 0.933, -0.965, '#angry', '#disgusting', -0.633, 'worm_intestine', 'fur_keep_warm', 'unpleasant-smelling', 'bad_breath', 'asthama']
senticnet['spying'] = [0.774, -0.634, 0, 0.567, '#joyful', '#surprising', 0.658, 'catching', 'discovery', 'breakthrough', 'determination', 'tracing']
senticnet['tastefulness'] = [0.639, -0.701, 0, 0.507, '#joyful', '#surprising', 0.616, 'breeding', 'daintiness', 'eclat', 'elegance', 'genteelness']
senticnet['tone_down'] = [0, 0, -0.935, -0.886, '#scared', '#disgusting', -0.607, 'dull', 'muffle', 'muted', 'hushed', 'softened']
senticnet['wilderness'] = [0.581, -0.656, 0, 0.959, '#surprising', '#admirable', 0.732, 'profuseness', 'overgrowth', 'greenness', 'verdancy', 'verdure']
senticnet['trenchant'] = [0.891, 0.987, 0, 0, '#joyful', '#interesting', 0.626, 'distinguishable', 'discrete', 'decided', 'clear-cut', 'distinct']
senticnet['untouchable'] = [0, 0, 0, 0.816, '#admirable', '#admirable', 0.272, 'resitence', 'protection', 'immunity', 'invunerable', 'sacrosanct']
senticnet['extrovertive'] = [0, 0, -0.852, -0.891, '#scared', '#disgusting', -0.581, 'extrospective', 'forthcoming', 'outgoing', 'extravert', 'extroverted']
senticnet['unshaken'] = [0.518, -0.863, 0, 0.501, '#joyful', '#surprising', 0.627, 'undismayed', 'resolute', 'undaunted', 'firm', 'stout']
senticnet['ratiocination'] = [0.725, -0.76, 0, 0.51, '#joyful', '#surprising', 0.665, 'abstract_thought', 'logical_argument', 'line_of_reasoning', 'thinking', 'thought']
senticnet['swimming_costume'] = [0.819, -0.782, 0, 0, '#joyful', '#surprising', 0.534, 'bikini', 'storage_item', 'jeans', 'pair_of_pants', 'dirty_magazine']
senticnet['illicit'] = [0, 0, -0.948, -0.78, '#scared', '#disgusting', -0.576, 'illegitimate', 'unconventional', 'unlawful', 'wrongful', 'improper']
senticnet['uproot'] = [0, 0, -0.963, -0.721, '#scared', '#disgusting', -0.561, 'eradicate', 'deracinate', 'root_out', 'exterminate', 'extirpate']
senticnet['infectious'] = [-0.857, 0, 0, -0.982, '#sad', '#disgusting', -0.613, 'contagious', 'communicable', 'epidemic', 'pandemic', 'epizootic']
senticnet['lilliputian'] = [0, 0, -0.868, -0.863, '#scared', '#disgusting', -0.577, 'footling', 'picayune', 'little', 'fiddling', 'niggling']
senticnet['stipple'] = [0, 0, -0.994, -0.915, '#scared', '#disgusting', -0.636, 'specked', 'flecked', 'speckled', 'dotted', 'bespeckle']
senticnet['mogul'] = [0, 0, -0.747, -0.893, '#scared', '#disgusting', -0.547, 'king', 'baron', 'business_leader', 'magnate', 'big_businessman']
senticnet['roux'] = [0.87, -0.856, 0, 0.94, '#joyful', '#admirable', 0.889, 'mincemeat', 'stuffing', 'dressing', 'concoction', 'batter']
senticnet['towboats'] = [0, 0, 0, 0.135, '#admirable', '#admirable', 0.045, 'kayak', 'ferries', 'canoes', 'boat_type', 'yachts']
senticnet['vegetation'] = [0, 0.141, 0, 0.096, '#interesting', '#admirable', 0.079, 'leafy_green', 'usual_green', 'green_stuff', 'greenery', 'cow_food']
senticnet['refreshing'] = [0.843, -0.818, 0, 0.624, '#joyful', '#surprising', 0.762, 'exhilarating', 'invigorating', 'enlivening', 'animating', 'restorative']
senticnet['unflustered'] = [0.68, -0.799, 0, 0.661, '#joyful', '#surprising', 0.713, 'unflurried', 'composed', 'unperturbed', 'unruffled', 'coolheaded']
senticnet['unimpeded'] = [0.924, -0.834, 0, 0.807, '#joyful', '#surprising', 0.855, 'unclogged', 'clear', 'patent', 'open', 'unobstructed']
senticnet['sunhyperpigmentation'] = [-0.969, 0, 0.636, -0.646, '#sad', '#disgusting', -0.75, 'burn', 'hyperpigmentation', 'tan', 'sunburn', 'physical_condition']
senticnet['spud'] = [0.532, -0.682, 0, 0.984, '#surprising', '#admirable', 0.733, 'potato', 'white_potato', 'murphy', 'chips', 'tater']
senticnet['roam_around'] = [0.895, 0.982, 0, 0, '#joyful', '#interesting', 0.626, 'commute_work', 'get_place', 'sightsee', 'get_school', 'get_around_town']
senticnet['spur'] = [-0.846, 0, 0.762, 0, '#sad', '#angry', -0.536, 'motive', 'need', 'abience', 'impulse', 'adience']
senticnet['coggle'] = [-0.8, 0, -0.804, 0, '#sad', '#scared', -0.535, 'totter', 'paddle', 'dodder', 'toddle', 'waddle']
senticnet['voicelessness'] = [0.563, -0.592, 0, 0.612, '#surprising', '#admirable', 0.589, 'whispering', 'speaking', 'whisper', 'susurration', 'speech']
senticnet['smooth-spoken'] = [0, 0, -0.712, -0.751, '#scared', '#disgusting', -0.488, 'facile', 'silver', 'eloquent', 'fluent', 'silver-tongued']
senticnet['willow'] = [0.043, -0.04, 0, 0, '#joyful', '#surprising', 0.028, 'birch', 'cedar', 'oak', 'elm', 'lumber']
senticnet['subscribe'] = [0, 0.87, 0, 0.96, '#interesting', '#admirable', 0.61, 'ask_name', 'unfold', 'know_language', 'speak_write', 'linguistics']
senticnet['predestinate'] = [0.716, -0.718, 0, 0.736, '#surprising', '#admirable', 0.723, 'foreordain', 'predetermine', 'predestine', 'influence', 'preordain']
senticnet['untrusting'] = [0, 0, -0.894, -0.941, '#scared', '#disgusting', -0.612, 'mistrustful', 'suspicious', 'leery', 'fishy', 'wary']
senticnet['unspoken'] = [0.531, -0.769, 0, 0.603, '#surprising', '#admirable', 0.634, 'tacit', 'understood', 'unvoiced', 'silent', 'implicit']
senticnet['painted'] = [0.767, 0, 0, 0.844, '#joyful', '#admirable', 0.537, 'calico', 'multi-color', 'varicolored', 'motley', 'pied']
senticnet['home_architectural_structure'] = [0.994, 0, 0, 0.772, '#joyful', '#admirable', 0.589, 'large_architectural_structure', 'architectural_structure', 'build', 'architect', 'structure_support']
senticnet['propensity'] = [0.976, -0.873, 0, 0.706, '#joyful', '#surprising', 0.852, 'understanding', 'inclination', 'leaning', 'favor', 'proclivity']
senticnet['presume'] = [0.863, -0.947, 0, 0.986, '#surprising', '#admirable', 0.932, 'postulate', 'posit', 'presuppose', 'assume', 'take_for_granted']
senticnet['raffish'] = [0, 0, -0.733, -0.706, '#scared', '#disgusting', -0.48, 'dashing', 'jaunty', 'natty', 'dapper', 'spiffy']
senticnet['religiosity'] = [0.674, -0.798, 0, 0.981, '#surprising', '#admirable', 0.818, 'piety', 'piousness', 'pietism', 'devoutness', 'religionism']
senticnet['unflurried'] = [0.68, -0.799, 0, 0.661, '#joyful', '#surprising', 0.713, 'composed', 'unflustered', 'unperturbed', 'unruffled', 'coolheaded']
senticnet['common_beane'] = [0.861, -0.549, 0, 0.976, '#joyful', '#admirable', 0.795, 'kidney_bean', 'common_bean', 'frijol', 'green_bean', 'wax_bean']
senticnet['saddle'] = [0.093, -0.021, 0, 0.056, '#joyful', '#admirable', 0.057, 'jockey', 'lead_ropes', 'horse', 'sprinter', 'control_horse']
senticnet['transposable'] = [0.552, -0.585, 0, 0.762, '#surprising', '#admirable', 0.633, 'exchangeable', 'permutable', 'fungible', 'commutable', 'substitutable']
senticnet['chew_over'] = [0, 0, -0.782, -0.99, '#scared', '#disgusting', -0.591, 'goddess', 'think_over', 'muse', 'ponder', 'meditate']
senticnet['bed_pisser'] = [-0.531, 0, 0.508, -0.748, '#sad', '#disgusting', -0.596, 'bedpisser', 'wetter', 'mortal', 'pisser', 'person']
senticnet['coiledd'] = [0.612, -0.536, 0, 0.532, '#joyful', '#surprising', 0.56, 'convolute', 'coiled', 'involute', 'rolled', 'wound']
senticnet['record'] = [0, 0.846, 0, 0.782, '#interesting', '#admirable', 0.543, 'keep_record', 'list_item', 'check_balance', 'strive', 'cross_room']
senticnet['stuck-up'] = [0, 0, -0.764, -0.877, '#scared', '#disgusting', -0.547, 'snooty', 'uppish', 'too_big_for_ones_breeches', 'bigheaded', 'persnickety']
senticnet['tamable'] = [0.841, -0.576, 0, 0.891, '#joyful', '#admirable', 0.769, 'ductile', 'tameable', 'manipulable', 'malleable', 'docile']
senticnet['unlikeliness'] = [0.602, -0.728, 0, 0.892, '#surprising', '#admirable', 0.741, 'unlikelihood', 'improbability', 'uncertainty', 'precariousness', 'uncertainness']
senticnet['jingoist'] = [0, 0, -0.888, -0.702, '#scared', '#disgusting', -0.53, 'jingo', 'hundred-percenter', 'flag-waver', 'patrioteer', 'chauvinist']
senticnet['outwit'] = [0, 0, -0.719, -0.783, '#scared', '#disgusting', -0.501, 'beleaguer', 'besiege', 'circumvent', 'surround', 'hem_in']
senticnet['wild_origanum'] = [0.632, -0.933, 0, 0.928, '#surprising', '#admirable', 0.831, 'herb', 'oregano', 'origanum', 'pot_origanum', 'marjoram']
senticnet['butternut_winter_squash'] = [-0.562, 0, 0.696, -0.964, '#angry', '#disgusting', -0.741, 'winter_squash', 'acorn_winter_squash', 'hubbard_winter_squash', 'turban_winter_squash', 'squash']
senticnet['resilient'] = [0, 0.739, 0, 0.775, '#interesting', '#admirable', 0.505, 'hardy', 'sturdy', 'stalwart', 'durable', 'robust']
senticnet['soya_bean'] = [-0.705, 0, 0.606, -0.723, '#sad', '#disgusting', -0.678, 'common_bean', 'soya', 'goa_bean', 'mung', 'bean']
senticnet['reversible'] = [0.896, -0.663, 0, 0.667, '#joyful', '#admirable', 0.742, 'mutable', 'distortable', 'changeful', 'adjustable', 'unstable']
senticnet['portentous'] = [0.596, -0.815, 0, 0.767, '#surprising', '#admirable', 0.726, 'inflated', 'pretentious', 'snooty', 'highfalutin', 'hifalutin']
senticnet['scrupulousness'] = [0.512, -0.945, 0, 0.5, '#joyful', '#surprising', 0.652, 'carefulness', 'painstakingness', 'diligence', 'meticulousness', 'meticulosity']
senticnet['utilise'] = [-0.884, 0, 0, -0.734, '#sad', '#disgusting', -0.539, 'avail', 'use', 'harness', 'exploit', 'overexploit']
senticnet['provability'] = [0.776, -0.667, 0, 0.778, '#joyful', '#admirable', 0.74, 'indisputability', 'demonstrability', 'positivity', 'positiveness', 'certainty']
senticnet['seduce'] = [0, 0.171, -0.056, 0.102, '#interesting', '#admirable', 0.072, 'bed', 'mattress', 'linen_cupboard', 'bed_cover', 'bead']
senticnet['unworthiness'] = [0.605, -0.836, 0, 0.935, '#surprising', '#admirable', 0.792, 'quality', 'unfitness', 'inappropriateness', 'inconvenience', 'unsuitability']
senticnet['hibernating'] = [-0.963, 0, -0.848, 0, '#sad', '#scared', -0.604, 'soggy', 'dormant', 'inert', 'sluggish', 'torpid']
senticnet['contuse'] = [0, 0, -0.903, -0.745, '#scared', '#disgusting', -0.549, 'bruised', 'hurt', 'wound', 'injure', 'offend']
senticnet['unforeseen'] = [0, -1, 0, 0, '#surprising', '#surprising', 0.333, 'surprise', 'amazement', 'astonishment', 'unexpected', 'unanticipated']
senticnet['series'] = [0.888, -0.815, 0, 0.617, '#joyful', '#surprising', 0.773, 'ordering', 'word_order', 'genetic_code', 'genome', 'bacteria_order']
senticnet['tricksy'] = [0, -0.811, 0, 0.796, '#surprising', '#admirable', 0.536, 'cunning', 'dodgy', 'guileful', 'knavish', 'crafty']
senticnet['arciform'] = [-0.83, 0, 0, -0.713, '#sad', '#disgusting', -0.514, 'limp', 'crooked', 'inclined', 'droopy', 'bent']
senticnet['malevolent_program_horse'] = [-0.867, 0, 0.769, -0.888, '#sad', '#disgusting', -0.841, 'malevolent_program', 'trojan', 'virus', 'worm', 'computer_virus']
senticnet['switchblade'] = [-0.711, 0, 0.954, -0.563, '#sad', '#angry', -0.743, 'jackknife', 'pocket_knife', 'penknife', 'clasp_knife', 'switchblade_knife']
senticnet['sulfurous'] = [-0.877, 0, -0.965, 0, '#sad', '#scared', -0.614, 'corrosive', 'vitriolic', 'acid', 'acerbic', 'bitter']
senticnet['benighted'] = [-0.801, 0, 0, -0.778, '#sad', '#disgusting', -0.526, 'reverse', 'retrograde', 'retral', 'primitive', 'backward']
senticnet['knifelike'] = [0, 0, 0.96, -0.928, '#angry', '#disgusting', -0.629, 'discriminating', 'acute', 'lament', 'keen', 'incisive']
senticnet['rerested'] = [0.516, -0.936, 0, 0.802, '#surprising', '#admirable', 0.751, 'rested', 'refreshed', 'invigorated', 'untired', 'unwearied']
senticnet['in_straitened_circumstances'] = [0, 0, -0.736, -0.741, '#scared', '#disgusting', -0.492, 'pinched', 'impecunious', 'hard_up', 'penniless', 'penurious']
senticnet['recruit'] = [0.824, -0.973, 0, 0.833, '#surprising', '#admirable', 0.877, 'enlistee', 'fledgeling', 'novice', 'beginner', 'tyro']
senticnet['respectability'] = [0.66, -0.842, 0, 0.712, '#surprising', '#admirable', 0.738, 'honorableness', 'reputability', 'venerability', 'venerableness', 'righteousness']
senticnet['privilege'] = [0.621, -0.603, 0, 0.545, '#joyful', '#surprising', 0.59, 'easement', 'perquisite', 'public_easement', 'right_of_way', 'prerogative']
senticnet['full-bosomed'] = [0, 0, -0.749, -0.756, '#scared', '#disgusting', -0.502, 'bosomy', 'busty', 'buxom', 'curvaceous', 'curvy']
senticnet['violin'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'instrumental', 'symphony', 'concert', 'music', 'sound_beautiful']
senticnet['haggard'] = [0, 0, -0.767, -0.95, '#scared', '#disgusting', -0.572, 'cadaverous', 'gaunt', 'bony', 'pinched', 'skeletal']
senticnet['sheeny'] = [0, 0, 0.963, -0.871, '#angry', '#disgusting', -0.611, 'shining', 'glistening', 'gleam', 'glossy', 'lustrous']
senticnet['secretin'] = [0.685, -0.898, 0, 0.765, '#surprising', '#admirable', 0.783, 'motilin', 'gastrin', 'gastrointestinal_hormone', 'cholecystokinin', 'ghrelin']
senticnet['son'] = [0, 0.08, 0.016, 0.103, '#interesting', '#admirable', 0.056, 'father', 'mother', 'daughter', 'grandfather', 'part_of_family']
senticnet['cosmetic_surgery'] = [0, -0.738, 0, 0.957, '#surprising', '#admirable', 0.565, 'looking_old', 'aging', 'looking_good', 'accepting_changes', 'age_gracefully']
senticnet['farinaceous'] = [0, -0.899, 0, 0.932, '#surprising', '#admirable', 0.61, 'granular', 'gamy', 'spirited', 'gritty', 'coarse-grained']
senticnet['llama_mammal'] = [-0.535, 0, 0.751, -0.971, '#angry', '#disgusting', -0.752, 'guanaco', 'domestic_llama', 'alpaca', 'llama', 'artiodactyl']
senticnet['speculation'] = [0.937, -0.939, 0, 0.933, '#joyful', '#surprising', 0.936, 'consideration', 'introspection', 'rumination', 'study', 'cogitation']
senticnet['tailpiece'] = [0, 0.103, 0, 0.111, '#interesting', '#admirable', 0.071, 'body_extremity', 'projection', 'limb', 'organ', 'appendage']
senticnet['vice_addiction'] = [-0.887, 0, 0, -0.902, '#sad', '#disgusting', -0.596, 'bad_habit', 'smoke_cigarette', 'drink_alcohol', 'gambling', 'vice']
senticnet['understanding'] = [0.577, -0.596, 0, 0.675, '#surprising', '#admirable', 0.616, 'faculty', 'intellect', 'ability', 'retentiveness', 'retentivity']
senticnet['witticism'] = [0.867, 0.949, 0, 0, '#joyful', '#interesting', 0.605, 'tell_funny_joke', 'tell_joke', 'funny_joke', 'jest', 'joke']
senticnet['acidophilus_bacterium'] = [-0.998, 0, 0.987, -0.965, '#sad', '#angry', -0.983, 'lactobacillus', 'acidophilus', 'probiotic', 'acidophilus_microflora', 'acidophilus_flora']
senticnet['forfend'] = [-0.869, 0, -0.721, 0, '#sad', '#scared', -0.53, 'debar', 'rid_of', 'eliminate', 'obviate', 'forefend']
senticnet['black_cohosh'] = [-0.524, 0, 0.527, -0.782, '#angry', '#disgusting', -0.611, 'herb', 'fairy_candle', 'actaea_racemosa', 'black_bugbane', 'black_snakeroot']
senticnet['barbellate'] = [0, 0, -0.858, -0.728, '#scared', '#disgusting', -0.529, 'barbed', 'splenetic', 'bristly', 'prickly', 'waspish']
senticnet['scope'] = [0.989, -0.905, 0, 0.876, '#joyful', '#surprising', 0.923, 'reach', 'range', 'compass', 'confines', 'orbit']
senticnet['unanticipated'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'without_warning', 'unexpected', 'unpredicted', 'out_of_blue', 'without_notice']
senticnet['clearing_of_land'] = [-0.538, 0, 0.771, -0.696, '#angry', '#disgusting', -0.668, 'tract', 'piece_of_land', 'piece_of_ground', 'parcel', 'clearing']
senticnet['privation'] = [0, 0, -0.922, -0.988, '#scared', '#disgusting', -0.637, 'loss', 'deprivation', 'dispossession', 'bereavement', 'demise']
senticnet['sacrosanct'] = [0, 0, 0, 0.816, '#admirable', '#admirable', 0.272, 'resitence', 'protection', 'untouchable', 'invunerable', 'immunity']
senticnet['spiritualism'] = [0.995, -0.731, 0, 0.83, '#joyful', '#admirable', 0.852, 'spiritism', 'otherworldliness', 'spirituality', 'internality', 'introversion']
senticnet['government_accommodation'] = [0, 0.119, 0, 0.095, '#interesting', '#admirable', 0.071, 'accommodation', 'government', 'govern_city', 'building', 'large_accommodation']
senticnet['uncultivated'] = [0.849, -0.897, 0, 0.924, '#surprising', '#admirable', 0.89, 'philistine', 'nonintellectual', 'nonintellectualed', 'mindless', 'lowbrow']
senticnet['terpsichore'] = [0.584, -0.783, 0, 0.546, '#joyful', '#surprising', 0.638, 'acting', 'musical_performance', 'performing_art', 'dance', 'dancing']
senticnet['profanation'] = [-0.832, 0, 0, -0.931, '#sad', '#disgusting', -0.588, 'popularization', 'degradation', 'demoralization', 'corruption', 'humiliation']
senticnet['russia'] = [0.039, 0, 0, 0.053, '#joyful', '#admirable', 0.031, 'china', 'democratic_country', 'free_country', 'unite', 'big_country']
senticnet['spender'] = [0.87, -0.937, 0, 0.831, '#joyful', '#surprising', 0.879, 'spendthrift', 'waster', 'wastrel', 'prodigal', 'scattergood']
senticnet['blinding'] = [0, 0, 0.709, -0.957, '#angry', '#disgusting', -0.555, 'fulgent', 'dazzling', 'egregious', 'glaring', 'glower']
senticnet['splenetic'] = [0, 0, -0.858, -0.728, '#scared', '#disgusting', -0.529, 'barbed', 'prickly', 'bristly', 'barbellate', 'waspish']
senticnet['big_businessman'] = [0, 0, -0.747, -0.893, '#scared', '#disgusting', -0.547, 'king', 'baron', 'business_leader', 'mogul', 'magnate']
senticnet['touch-and-go'] = [0, 0, -0.842, -0.92, '#scared', '#disgusting', -0.587, 'unstable', 'parlous', 'perilous', 'precarious', 'shaky']
senticnet['saliva'] = [0.066, 0.083, -0.064, 0.09, '#interesting', '#admirable', 0.058, 'aroma', 'perfume', 'fragrance', 'bad_odor', 'female_perfume']
senticnet['uncover'] = [0, 0, 0.701, -0.779, '#angry', '#disgusting', -0.493, 'color', 'treat', 'bear_upon', 'influence', 'expose']
senticnet['recent_epoch'] = [0.842, 0.898, 0, 0, '#joyful', '#interesting', 0.58, 'holocene', 'recent', 'holocene_epoch', 'late', 'new']
senticnet['bitter_cathartic'] = [0.722, -0.606, 0, 0.596, '#joyful', '#surprising', 0.641, 'medicament', 'medicinal_drug', 'medication', 'cathartic', 'aloe']
senticnet['haughty'] = [0, 0, -0.749, -0.932, '#scared', '#disgusting', -0.56, 'imperious', 'supercilious', 'disdainful', 'lordly', 'overbearing']
senticnet['spartan'] = [0.555, -0.914, 0, 0.601, '#surprising', '#admirable', 0.69, 'ascetic', 'ascetical', 'abstemious', 'austere', 'abstinent']
senticnet['many'] = [0.277, 0.161, 0, 0.337, '#joyful', '#admirable', 0.258, 'a_lot', 'plenty', 'big_amount', 'abundant', 'good_number']
senticnet['senesce'] = [0.568, -0.796, 0, 0.804, '#surprising', '#admirable', 0.723, 'age', 'get_on', 'dote', 'mature', 'maturate']
senticnet['riddle'] = [0, 0.827, 0, 0.903, '#interesting', '#admirable', 0.577, 'article', 'obituary', 'editorial', 'news_story', 'mystery']
senticnet['spotlight'] = [-0.034, 0.133, -0.071, 0.214, '#interesting', '#admirable', 0.081, 'projector', 'floodlight', 'headlight', 'light', 'teach_lesson']
senticnet['purse'] = [0, 0.092, 0, 0, '#interesting', '#interesting', 0.031, 'man_pocket', 'pant_pocket', 'pocket', 'back_pocket', 'clothes_washer']
senticnet['barbed'] = [0, 0, -0.858, -0.728, '#scared', '#disgusting', -0.529, 'prickly', 'splenetic', 'bristly', 'barbellate', 'waspish']
senticnet['hypothetical_creature_being'] = [-0.654, 0, 0.859, -0.639, '#sad', '#angry', -0.717, 'alien', 'extraterrestrial', 'hypothetical_creature', 'imaginary_being', 'imaginary_creature']
senticnet['booster'] = [0, 0, -0.737, -0.922, '#scared', '#disgusting', -0.553, 'champion', 'admirer', 'protagonist', 'friend', 'supporter']
senticnet['veal'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'animal_flesh', 'beef', 'food_group', 'cereal', 'curry']
senticnet['supplicatory'] = [0, 0, -0.776, -0.821, '#scared', '#disgusting', -0.532, 'suppliant', 'requester', 'petitioner', 'supplicant', 'prayer']
senticnet['vacuum'] = [0, 0.733, 0, 0.784, '#interesting', '#admirable', 0.506, 'clean_floor', 'clean_carpet', 'keep_house_clean', 'expect_guest', 'clean_bathroom']
senticnet['snarf'] = [0, 0, -0.811, -0.95, '#scared', '#disgusting', -0.587, 'cabbage', 'pinch', 'pilfer', 'abstract', 'purloin']
senticnet['multi-color'] = [0.767, 0, 0, 0.844, '#joyful', '#admirable', 0.537, 'calico', 'pied', 'varicolored', 'motley', 'painted']
senticnet['corrosive'] = [-0.877, 0, -0.965, 0, '#sad', '#scared', -0.614, 'vitriolic', 'sulfurous', 'acid', 'acerbic', 'bitter']
senticnet['holy_eucharist'] = [0.762, 0, 0, 0.894, '#joyful', '#admirable', 0.552, 'holy', 'eucharist', 'liturgy', 'holy_sacrament', 'sacrament_of_eucharist']
senticnet['unseasonable'] = [0, 0, -0.906, -0.995, '#scared', '#disgusting', -0.634, 'wrong', 'prematurely', 'untimely', 'premature', 'ill-timed']
senticnet['throw_overboard'] = [0, 0, -0.981, -0.82, '#scared', '#disgusting', -0.6, 'foreswear', 'relinquish', 'dispense_with', 'forgo', 'waive']
senticnet['treetop'] = [0.03, 0.068, -0.061, 0.062, '#interesting', '#admirable', 0.033, 'pacific_northwest', 'thermal', 'american_forest', 'animals', 'zoo']
senticnet['spinnable'] = [0.808, -0.699, 0, 0.938, '#joyful', '#admirable', 0.815, 'impressible', 'susceptible', 'easy', 'pliant', 'plastic']
senticnet['make_oppose'] = [-0.066, 0.068, -0.089, -0.074, '#scared', '#disgusting', -0.054, 'oppose', 'whack', 'rudeness', 'fist', 'hand']
senticnet['rostrum'] = [-0.711, 0, -0.794, 0, '#sad', '#scared', -0.502, 'pulpit', 'stump', 'dais', 'ambo', 'podium']
senticnet['sensibility'] = [0.96, -0.907, 0, 0, '#joyful', '#surprising', 0.622, 'go_rock_concert', 'attend_concert', 'able_hear', 'audible', 'turn_radio']
senticnet['abstemiousal'] = [0.555, -0.914, 0, 0.601, '#surprising', '#admirable', 0.69, 'abstemious', 'ascetic', 'spartan', 'austere', 'abstinent']
senticnet['hundred-percenter'] = [0, 0, -0.888, -0.702, '#scared', '#disgusting', -0.53, 'jingo', 'chauvinist', 'flag-waver', 'patrioteer', 'jingoist']
senticnet['ill-omened'] = [0, 0, -0.909, -0.938, '#scared', '#disgusting', -0.616, 'luckless', 'unlucky', 'ill-starred', 'doomed', 'ill-fated']
senticnet['unbiased'] = [-0.955, 0, 0.961, 0, '#sad', '#angry', -0.639, 'dispassionate', 'indifferent', 'disinterested', 'unprejudiced', 'neutral']
senticnet['schoolgirl'] = [0.738, -0.537, 0, 0.856, '#joyful', '#admirable', 0.71, 'little_girl', 'flower_girl', 'moppet', 'farm_girl', 'female']
senticnet['rusticity'] = [0, 0, 0.844, -0.94, '#angry', '#disgusting', -0.595, 'gaucherie', 'slip', 'solecism', 'gaffe', 'faux_pas']
senticnet['referent'] = [0.904, -0.588, 0, 0.736, '#joyful', '#admirable', 0.743, 'naming', 'denotative', 'designative', 'extensional', 'appellative']
senticnet['waves'] = [0.053, 0.073, -0.065, 0.104, '#interesting', '#admirable', 0.055, 'coral', 'small_fish', 'horizon', 'ocean', 'aquatic_life']
senticnet['register'] = [0, 0.175, 0, 0.231, '#interesting', '#admirable', 0.135, 'list', 'schedule', 'index', 'agenda', 'directory']
senticnet['volleyball'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'beach_ball', 'game', 'sun', 'sand', 'fun']
senticnet['saccharin'] = [0.53, -0.64, 0, 0.934, '#surprising', '#admirable', 0.701, 'sweetener', 'honey', 'aspartame', 'sugar', 'refined_sugar']
senticnet['televise'] = [0.055, -0.054, 0.013, 0, '#joyful', '#surprising', 0.032, 'radio-control_helicopter', 'football', 'spray_paint_grafitti', 'marijuana', 'fricative']
senticnet['zippy'] = [0.65, -0.614, 0, 0.711, '#joyful', '#admirable', 0.658, 'lively', 'scintillating', 'spirited', 'peppy', 'bouncing']
senticnet['salute'] = [0.037, 0.161, -0.154, 0.203, '#interesting', '#admirable', 0.082, 'wave', 'flow', 'farewell', 'multiple_purposes', 'wave_wind']
senticnet['canescent'] = [0, 0, -0.86, -0.799, '#scared', '#disgusting', -0.553, 'gray-haired', 'gray', 'rusty', 'hoary', 'grizzly']
senticnet['every_second'] = [0, 0.945, 0, 0.723, '#interesting', '#admirable', 0.556, 'alternative', 'substitute', 'replacement', 'another', 'alternate']
senticnet['renunciant'] = [0.682, -0.559, 0, 0.985, '#joyful', '#admirable', 0.742, 'nonindulgent', 'renunciative', 'puritanic', 'puritanical', 'corrective']
senticnet['seafarer'] = [0.587, -0.67, 0, 0.729, '#surprising', '#admirable', 0.662, 'sea_lawyer', 'seaman', 'tar', 'old_salt', 'mariner']
senticnet['beforehand'] = [-0.996, 0, 0, -0.817, '#sad', '#disgusting', -0.604, 'primal', 'archaic', 'archaean', 'previous', 'untimely']
senticnet['pedestrian'] = [0, 0, -0.916, -0.763, '#scared', '#disgusting', -0.56, 'matter-of-fact', 'commonplace', 'prosaic', 'prosy', 'earthbound']
senticnet['reliance'] = [0.809, -0.588, 0, 0.702, '#joyful', '#admirable', 0.7, 'state', 'contingency', 'subordination', 'helplessness', 'dependence']
senticnet['torus'] = [-0.043, 0.077, 0.073, 0.118, '#interesting', '#admirable', 0.026, 'round_figure', 'orb', 'great_invention', 'circle_shape', 'ball_shape']
senticnet['vermiculation'] = [0.969, -0.686, 0, 0.756, '#joyful', '#admirable', 0.804, 'carving', 'cinquefoil', 'glyptic_art', 'glyptography', 'scrimshaw']
senticnet['hush-hush'] = [0, 0, -0.806, -0.738, '#scared', '#disgusting', -0.515, 'secret', 'clandestine', 'hugger-mugger', 'cloak-and-dagger', 'hole-and-corner']
senticnet['potent'] = [0.923, -0.546, 0, 0.633, '#joyful', '#admirable', 0.701, 'important', 'prestigious', 'powerful', 'influential', 'authoritative']
senticnet['spirits'] = [0.679, -0.512, 0, 0.502, '#joyful', '#surprising', 0.564, 'liquor', 'firewater', 'booze', 'hard_drink', 'hard_liquor']
senticnet['renewed'] = [0.673, -0.95, 0, 0.914, '#surprising', '#admirable', 0.846, 'revived', 'revitalized', 'resurgent', 'renascent', 'resuscitated']
senticnet['bedpisser'] = [-0.531, 0, 0.508, -0.748, '#sad', '#disgusting', -0.596, 'wetter', 'bed_pisser', 'mortal', 'pisser', 'person']
senticnet['nasal_nasality'] = [-0.719, 0, 0.998, -0.647, '#sad', '#angry', -0.788, 'tone', 'quality', 'nasality', 'twang', 'timber']
senticnet['rifleman'] = [0.801, -0.874, 0, 0.916, '#surprising', '#admirable', 0.864, 'crack_shot', 'deadeye', 'sniper', 'shot', 'shooter']
senticnet['shitty'] = [0, 0, -0.877, -0.998, '#scared', '#disgusting', -0.625, 'crappy', 'rotten', 'lousy', 'stinking', 'icky']
senticnet['spring'] = [0.21, 0.131, -0.051, 0.084, '#joyful', '#interesting', 0.125, 'weather', 'sunny', 'climate', 'snow', 'four_seasons']
senticnet['sprint'] = [0, 0, 0, 0.108, '#admirable', '#admirable', 0.036, 'fast', 'flee', 'good_form_exercise', 'race', 'marathon']
senticnet['ratafee'] = [0.693, -0.945, 0, 0.713, '#surprising', '#admirable', 0.784, 'cordial', 'maraschino', 'ratafia', 'pastis', 'anisette']
senticnet['sanguineous'] = [0, 0, -0.75, -0.932, '#scared', '#disgusting', -0.561, 'bloodthirsty', 'slaughterous', 'gory', 'butcherly', 'sanguinary']
senticnet['unoriginality'] = [0.646, -0.924, 0, 0.816, '#surprising', '#admirable', 0.795, 'conventionality', 'traditionalism', 'orthodoxy', 'traditionality', 'conventionalism']
senticnet['suit'] = [0, 0.069, 0, 0, '#interesting', '#interesting', 0.023, 'coat', 'armor', 'leather', 'sweater', 'belt']
senticnet['revetment'] = [0.937, -0.799, 0, 0.634, '#joyful', '#surprising', 0.79, 'protective_cover', 'protective_covering', 'protection', 'cladding', 'cover']
senticnet['tameable'] = [0.841, -0.576, 0, 0.891, '#joyful', '#admirable', 0.769, 'tamable', 'ductile', 'manipulable', 'malleable', 'docile']
senticnet['spectroscope'] = [0.954, -0.668, 0, 0.958, '#joyful', '#admirable', 0.86, 'instrument', 'field_glasses', 'prism_spectroscope', 'binoculars', 'optical_instrument']
senticnet['retrace'] = [0.615, -0.899, 0, 0.714, '#surprising', '#admirable', 0.743, 'reconstruct', 'hypothesize', 'explicate', 'expect', 'formulate']
senticnet['retract'] = [0.92, -0.883, 0, 0.695, '#joyful', '#surprising', 0.833, 'get', 'catch', 'arrest', 'tug', 'attract']
senticnet['quodlibet'] = [0.648, -0.873, 0, 0.597, '#joyful', '#surprising', 0.706, 'issue', 'content', 'paramount_issue', 'pocketbook_issue', 'gut_issue']
senticnet['uniqueness'] = [0.618, -0.75, 0, 0.628, '#surprising', '#admirable', 0.665, 'individualism', 'singularity', 'specialty', 'special', 'distinctiveness']
senticnet['stodgy'] = [0.84, -0.646, 0, 0.912, '#joyful', '#admirable', 0.799, 'received', 'customary', 'formulaic', 'stuffy', 'conventional']
senticnet['corrasion_away'] = [-0.88, 0, 0.907, -0.522, '#sad', '#angry', -0.77, 'corrasion', 'erosion', 'eroding', 'eating_away', 'wearing']
senticnet['casino'] = [0, 0, -0.79, -0.818, '#scared', '#disgusting', -0.536, 'gamble', 'bet', 'hazard', 'poker_chip', 'risk']
senticnet['fellow_conspirator'] = [0, 0, -0.863, -0.752, '#scared', '#disgusting', -0.538, 'crime', 'murder', 'accomplice', 'partner_in_crime', 'offence']
senticnet['slip'] = [0, 0, 0.844, -0.94, '#angry', '#disgusting', -0.595, 'rusticity', 'gaucherie', 'solecism', 'gaffe', 'faux_pas']
senticnet['tomato'] = [0, 0.102, 0.016, 0.076, '#interesting', '#admirable', 0.054, 'cherry', 'apricot', 'plum', 'cranberry', 'pineapple']
senticnet['eagerlyness'] = [0.911, 0, 0, 0.978, '#joyful', '#admirable', 0.63, 'eagerly', 'eager', 'avidity', 'thirstily', 'avidness']
senticnet['amphiapteral'] = [-0.659, 0, 0.878, -0.868, '#angry', '#disgusting', -0.802, 'amphistylar', 'amphiprostylar', 'prostyle', 'porticoed', 'apteral']
senticnet['urethroscope'] = [0.255, 0.182, -0.06, 0.314, '#joyful', '#admirable', 0.23, 'doctor_office', 'colposcope', 'sigmoidoscope', 'hospital', 'check_health']
senticnet['deceptive'] = [0, 0, 0.863, -0.745, '#angry', '#disgusting', -0.536, 'jerry-built', 'tawdry', 'misleading', 'shoddy', 'cheapjack']
senticnet['unexpended'] = [0.921, -0.825, 0, 0.868, '#joyful', '#admirable', 0.871, 'odd', 'left', 'unspent', 'unexhausted', 'leftover']
senticnet['reproduction'] = [0.848, 0, 0, 0.813, '#joyful', '#admirable', 0.554, 'breed', 'survival', 'host_party', 'part_of_meal', 'put_ice']
senticnet['anneal'] = [0, 0, 0.751, -0.818, '#angry', '#disgusting', -0.523, 'mood', 'humor', 'irritation', 'chasten', 'temper']
senticnet['suaveness'] = [0.753, -0.898, 0, 0.652, '#joyful', '#surprising', 0.768, 'good_manners', 'suavity', 'graciousness', 'courtesy', 'smoothness']
senticnet['shaping'] = [0.678, -0.897, 0, 0.804, '#surprising', '#admirable', 0.793, 'reconstructive', 'formative', 'constructive', 'creative', 'inferential']
senticnet['reverberative'] = [-0.726, 0, -0.897, 0, '#sad', '#scared', -0.541, 'resonant', 'reverberating', 'resounding', 'resonating', 'evocative']
senticnet['ratability'] = [0, 0, 0.967, -0.749, '#angry', '#disgusting', -0.572, 'liability', 'susceptibility', 'susceptibleness', 'taxability', 'rateability']
senticnet['whispering'] = [0.563, -0.592, 0, 0.612, '#surprising', '#admirable', 0.589, 'speaking', 'voicelessness', 'whisper', 'susurration', 'speech']
senticnet['runway'] = [0.745, 0.898, 0, 0, '#joyful', '#interesting', 0.548, 'highway', 'taxiway', 'aircraft_roadway', 'flight_terminal', 'ticket_counter']
senticnet['concerted'] = [0, 0, -0.764, -0.874, '#scared', '#disgusting', -0.546, 'co-op', 'cooperative', 'conjunct', 'conjunctive', 'accommodative']
senticnet['rooms'] = [0, -0.069, 0, 0, '#surprising', '#surprising', 0.023, 'apartment', 'home', 'furnitures', 'kitchen', 'flats']
senticnet['undeferential'] = [0.518, -0.635, 0, 0.529, '#surprising', '#admirable', 0.561, 'disrespectful', 'annihilating', 'devastating', 'insolent', 'undutiful']
senticnet['voluptuous'] = [0.636, -0.954, 0, 0.664, '#surprising', '#admirable', 0.751, 'buxom', 'statuesque', 'sculptured', 'shapely', 'sculptural']
senticnet['tenability'] = [0.943, -0.751, 0, 0.515, '#joyful', '#surprising', 0.736, 'reasonableness', 'plausibility', 'tenableness', 'credibility', 'credibleness']
senticnet['pinkroot'] = [0.606, -0.504, 0, 0.795, '#joyful', '#admirable', 0.635, 'plant_disease', 'cotton_ball', 'disease', 'rust', 'scorch']
senticnet['sibling'] = [0.986, 0.931, 0, 0, '#joyful', '#interesting', 0.639, 'relative', 'familial_relationship', 'family_member', 'mother_brother', 'female_relative']
senticnet['renowned'] = [0, 0.939, 0, 0.75, '#interesting', '#admirable', 0.563, 'observe', 'keep', 'famed', 'notable', 'celebrated']
senticnet['predominant'] = [0, 0, -0.928, -0.774, '#scared', '#disgusting', -0.567, 'overabundant', 'prevailing', 'plethoric', 'rife', 'dominant']
senticnet['straightforwardness'] = [0.772, -0.953, 0, 0.89, '#surprising', '#admirable', 0.872, 'downrightness', 'directness', 'characteristic', 'immediacy', 'immediateness']
senticnet['silica'] = [0.037, 0.073, 0.027, 0.072, '#interesting', '#admirable', 0.052, 'transistor', 'grain_sand', 'sand', 'computer_chip', 'amethyst']
senticnet['unspeakable'] = [0, 0, -0.763, -0.862, '#scared', '#disgusting', -0.542, 'untellable', 'ineffable', 'indescribable', 'indefinable', 'unutterable']
senticnet['productiveness'] = [0.643, -0.803, 0, 0.681, '#surprising', '#admirable', 0.709, 'quality', 'richness', 'fruitfulness', 'prolificacy', 'fertility']
senticnet['traitorousness'] = [-0.792, 0, 0, -0.848, '#sad', '#disgusting', -0.547, 'perfidiousness', 'disloyalty', 'perfidy', 'treachery', 'betrayal']
senticnet['monotonous'] = [-0.79, 0, 0, -0.731, '#sad', '#disgusting', -0.507, 'dull', 'boring', 'tedious', 'mundane', 'tiresome']
senticnet['subaltern'] = [0, 0, 0.828, -0.805, '#angry', '#disgusting', -0.544, 'lowly', 'petty', 'junior-grade', 'secondary', 'lower-ranking']
senticnet['conjunctive'] = [0, 0, -0.764, -0.874, '#scared', '#disgusting', -0.546, 'co-op', 'concerted', 'conjunct', 'cooperative', 'accommodative']
senticnet['prehigh_status'] = [0.594, -0.688, 0, 0.957, '#surprising', '#admirable', 0.746, 'eminence', 'high_status', 'senior_status', 'higher_status', 'higher_rank']
senticnet['unretentive'] = [0, 0, -0.868, -0.895, '#scared', '#disgusting', -0.588, 'short', 'poor', 'inadequate', 'little', 'forgetful']
senticnet['subversiveness'] = [0.927, -0.564, 0, 0.8, '#joyful', '#admirable', 0.764, 'disloyalty', 'perfidiousness', 'traitorousness', 'perfidy', 'treachery']
senticnet['fictile'] = [0, 0, -0.811, -1.0, '#scared', '#disgusting', -0.604, 'charge_plate', 'plastic', 'charge_card', 'credit_card', 'moldable']
senticnet['transparence'] = [0.818, -0.672, 0, 0.906, '#joyful', '#admirable', 0.799, 'quality', 'transparentness', 'distinctness', 'transparency', 'uncloudedness']
senticnet['validated'] = [0.622, -0.721, 0, 0.799, '#surprising', '#admirable', 0.714, 'sound', 'logical', 'effectual', 'valid', 'legitimate']
senticnet['farce'] = [0, 0, -0.905, -0.973, '#scared', '#disgusting', -0.626, 'parody', 'travesty', 'lampoon', 'farce_comedy', 'spoof']
senticnet['spiritism'] = [0.995, -0.731, 0, 0.83, '#joyful', '#admirable', 0.852, 'internality', 'otherworldliness', 'spirituality', 'spiritualism', 'introversion']
senticnet['hasty'] = [-0.848, 0, 0.908, 0, '#sad', '#angry', -0.585, 'precipitate', 'come_down', 'fall', 'overhasty', 'precipitant']
senticnet['junket'] = [0, 0, 0.904, -0.804, '#angry', '#disgusting', -0.569, 'outing', 'jaunt', 'pleasure_trip', 'excursion', 'expedition']
senticnet['ceaseless'] = [0, 0, -0.972, -0.95, '#scared', '#disgusting', -0.641, 'unceasing', 'never-ending', 'constant', 'incessant', 'perpetual']
senticnet['goldbowl'] = [-0.519, 0, 0.562, -0.699, '#angry', '#disgusting', -0.593, 'fishbowl', 'bowl', 'fish_bowl', 'jorum', 'mazer']
senticnet['hooked'] = [0, 0, -0.833, -0.923, '#scared', '#disgusting', -0.585, 'qualified', 'subordinate', 'pendant', 'subject', 'dependent']
senticnet['daunting'] = [0, 0, 0.882, -0.991, '#angry', '#disgusting', -0.624, 'forbidding', 'redoubtable', 'formidable', 'alarming', 'frightening']
senticnet['postoffice'] = [0, -0.124, 0, 0.105, '#surprising', '#admirable', 0.076, 'mail_package', 'hang_wall', 'stationery_store', 'desk', 'desk_drawer']
senticnet['prolificacy'] = [0.643, -0.803, 0, 0.681, '#surprising', '#admirable', 0.709, 'quality', 'richness', 'fruitfulness', 'fertility', 'productiveness']
senticnet['stupendous'] = [0.873, 0.793, 0, 0, '#joyful', '#interesting', 0.555, 'exceptional', 'colossal', 'portentous', 'exceeding', 'prodigious']
senticnet['realm'] = [0, 0.173, -0.067, 0.126, '#interesting', '#admirable', 0.077, 'democracy', 'empire', 'amendment', 'unite', 'international']
senticnet['anxiouslyly'] = [-0.944, 0, -0.716, 0, '#sad', '#scared', -0.553, 'uneasily', 'apprehensive', 'anxiously', 'worried', 'solicitousness']
senticnet['foraging'] = [0, 0, -0.903, -0.99, '#scared', '#disgusting', -0.631, 'forage', 'pasture', 'grass', 'eatage', 'scrounge']
senticnet['gaud'] = [0, 0, -0.955, -0.711, '#scared', '#disgusting', -0.555, 'trinket', 'novelty', 'gewgaw', 'bangle', 'bauble']
senticnet['hot_dirty_dish'] = [0, 0, 0.865, -0.953, '#angry', '#disgusting', -0.606, 'dirty_dish_overflow', 'faucet', 'hot_tap', 'dirty_dish', 'washcloth']
senticnet['lack_originality'] = [-0.811, 0, 0, -0.777, '#sad', '#disgusting', -0.529, 'dull', 'ordinary', 'unoriginal', 'murky', 'banal']
senticnet['inspired'] = [0.724, 0, 0, 0.783, '#joyful', '#admirable', 0.502, 'idealist', 'visionary', 'imaginative', 'creative', 'inventive']
senticnet['fibroma_tumor'] = [-0.882, 0, 0.774, -0.993, '#sad', '#disgusting', -0.883, 'fibroid', 'fibroma', 'benign_tumor', 'nonmalignant_tumor', 'nonmalignant_neoplasm']
senticnet['sweet-talk'] = [0, 0, -0.925, -0.823, '#scared', '#disgusting', -0.583, 'wheedle', 'cajole', 'blarney', 'palaver', 'coax']
senticnet['singleness'] = [0.927, -0.922, 0, 0.76, '#joyful', '#surprising', 0.87, 'diligence', 'industriousness', 'assiduity', 'intentness', 'engrossment']
senticnet['shakiness'] = [0.748, -0.907, 0, 0.99, '#surprising', '#admirable', 0.882, 'tremolo', 'quivering', 'shaking', 'vibration', 'quiver']
senticnet['emphasis'] = [0, 0, -0.925, -0.934, '#scared', '#disgusting', -0.62, 'fury', 'vehemence', 'fierceness', 'wildness', 'ferocity']
senticnet['two-handed'] = [0, 0, -0.901, -0.703, '#scared', '#disgusting', -0.535, 'duplicitous', 'deceitful', 'double-dealing', 'janus-faced', 'ambidextrous']
senticnet['clamant'] = [0, 0, -0.826, -0.934, '#scared', '#disgusting', -0.587, 'blatant', 'strident', 'conspicuous', 'blazing', 'clamorous']
senticnet['wal'] = [-0.043, 0.086, 0.036, 0.166, '#interesting', '#admirable', 0.058, 'limp', 'stand_upon', 'walk_device', 'walk_part', 'foot_action']
senticnet['wax'] = [0.101, -0.248, -0.049, 0.212, '#surprising', '#admirable', 0.171, 'pleasant_experience', 'stick', 'rod', 'find_jar', 'mantle']
senticnet['serviceableness'] = [0.513, -0.874, 0, 0.924, '#surprising', '#admirable', 0.77, 'quality', 'serviceability', 'usefulness', 'usableness', 'user_friendly']
senticnet['becoming'] = [0.83, 0.727, 0, 0, '#joyful', '#interesting', 0.519, 'comme_il_faut', 'comely', 'decorous', 'seemly', 'decent']
senticnet['winery'] = [0.728, -0.517, 0, 0.811, '#joyful', '#admirable', 0.685, 'still', 'wine_maker', 'bottling_plant', 'mint', 'plant']
senticnet['abstrusity'] = [0, 0, -0.722, -0.93, '#scared', '#disgusting', -0.551, 'profundity', 'reconditeness', 'astuteness', 'abstruseness', 'profoundness']
senticnet['lumper'] = [0, 0, -0.952, -0.844, '#scared', '#disgusting', -0.599, 'docker', 'stevedore', 'loader', 'longshoreman', 'dock_worker']
senticnet['longshoreman'] = [0, 0, -0.952, -0.844, '#scared', '#disgusting', -0.599, 'docker', 'lumper', 'loader', 'stevedore', 'dock_worker']
senticnet['witty'] = [0, 0.96, 0, 0.855, '#interesting', '#admirable', 0.605, 'writer', 'write_book', 'write_poem', 'write_down_idea', 'write_story']
senticnet['predicate'] = [0.565, -0.738, 0, 0.542, '#joyful', '#surprising', 0.615, 'say', 'aver', 'asseverate', 'insist', 'take_firm_stand']
senticnet['corpulent'] = [-0.958, 0, -0.93, 0, '#sad', '#scared', -0.629, 'weighty', 'pear-shaped', 'rotund', 'obese', 'round']
senticnet['propellent'] = [0.74, -0.755, 0, 0.815, '#surprising', '#admirable', 0.77, 'propellant', 'changing', 'propelling', 'dynamical', 'propulsive']
senticnet['presenter'] = [0.883, -0.664, 0, 0.732, '#joyful', '#admirable', 0.76, 'giver', 'donor', 'bestower', 'subsidizer', 'conferrer']
senticnet['punkah'] = [0.628, -0.967, 0, 0.682, '#surprising', '#admirable', 0.759, 'electric_fan', 'fan', 'exhaust_fan', 'blower', 'device']
senticnet['movingback'] = [0.535, -0.586, 0, 0.748, '#surprising', '#admirable', 0.623, 'kinetic', 'restless', 'afoot', 'moving', 'ahorse']
senticnet['pictorial'] = [0.927, 0, 0, 0.855, '#joyful', '#admirable', 0.594, 'lifelike', 'graphic', 'vivid', 'bright', 'brilliant']
senticnet['pot_origanum'] = [0.632, -0.933, 0, 0.928, '#surprising', '#admirable', 0.831, 'herb', 'oregano', 'origanum', 'marjoram', 'wild_origanum']
senticnet['indescribable'] = [0, 0, -0.763, -0.862, '#scared', '#disgusting', -0.542, 'untellable', 'unspeakable', 'ineffable', 'indefinable', 'unutterable']
senticnet['countermand'] = [0, 0, -0.734, -0.887, '#scared', '#disgusting', -0.54, 'lift', 'rescind', 'revoke', 'reverse', 'annul']
senticnet['conjunct'] = [0, 0, -0.764, -0.874, '#scared', '#disgusting', -0.546, 'co-op', 'concerted', 'cooperative', 'conjunctive', 'accommodative']
senticnet['bauble'] = [0, 0, -0.955, -0.711, '#scared', '#disgusting', -0.555, 'gaud', 'novelty', 'gewgaw', 'bangle', 'trinket']
senticnet['truly'] = [0.77, 0, 0, 0.996, '#joyful', '#admirable', 0.589, 'bind_agreement', 'need_money', 'completely', 'earn_wage', 'absolutely']
senticnet['get_accomplish_done'] = [0.907, 0, 0, 0.79, '#joyful', '#admirable', 0.566, 'job', 'task', 'hard_work', 'accomplish', 'find_accomplish']
senticnet['proceedwards'] = [0, 0.29, -0.149, 0.418, '#interesting', '#admirable', 0.186, 'proceed', 'take', 'bring_up', 'go_on', 'permission']
senticnet['sport'] = [0.836, -0.913, 0, 0, '#joyful', '#surprising', 0.583, 'sport_play', 'excite_game', 'athletic_event', 'rough_game', 'verbosity']
senticnet['reasonableness'] = [0.554, -0.726, 0, 0.651, '#surprising', '#admirable', 0.644, 'cut_price', 'modestness', 'cost', 'cut_rate', 'inexpensiveness']
senticnet['aura'] = [0, 0.729, 0, 0.769, '#interesting', '#admirable', 0.499, 'charm', 'presence', 'charisma', 'personality', 'strength_of_character']
senticnet['kilodistance_measurement'] = [0, 0.951, 0, 0.721, '#interesting', '#admirable', 0.557, 'distance_measure', 'length_measurement', 'distance_measurement', 'meter', 'imperial_measurement']
senticnet['blushful'] = [0.953, 0, 0, 0.865, '#joyful', '#admirable', 0.606, 'fortunate', 'rose_colored', 'rose_cheeked', 'rosy', 'flushed']
senticnet['prurient'] = [0, 0, -0.916, -0.861, '#scared', '#disgusting', -0.592, 'lubricious', 'lewd', 'lustful', 'obscene', 'salacious']
senticnet['dalliance'] = [0, 0, -0.846, -0.822, '#scared', '#disgusting', -0.556, 'trifling', 'piddle', 'wanton_away', 'wanton', 'dawdling']
senticnet['ruby'] = [0.418, 0.103, 0, 0.373, '#joyful', '#admirable', 0.298, 'bloodstone', 'turquoise', 'sapphire', 'emerald', 'jade']
senticnet['large_architectural_structure'] = [0.994, 0, 0, 0.772, '#joyful', '#admirable', 0.589, 'build', 'architectural_structure', 'home_architectural_structure', 'architect', 'structure_support']
senticnet['unshakable'] = [0.893, 0.908, 0, 0, '#joyful', '#interesting', 0.6, 'incontrovertible', 'bulletproof', 'incontestable', 'armored', 'unassailable']
senticnet['plectognathfish'] = [-0.545, 0, 0.829, -0.725, '#angry', '#disgusting', -0.7, 'plectognath', 'puffer', 'blowfish', 'triggerfish', 'filefish']
senticnet['ruler'] = [0.039, 0, 0.038, 0.099, '#joyful', '#admirable', 0.033, 'imperial', 'kingly', 'nobleman', 'blue_blood', 'nobility']
senticnet['bad_read'] = [-0.062, -0.019, 0, -0.044, '#sad', '#disgusting', -0.029, 'choose_book', 'purchase_book', 'store_book', 'sell_book', 'hold_book']
senticnet['proponent'] = [0.677, -0.529, 0, 0.714, '#joyful', '#admirable', 0.64, 'economic_libertarian', 'civil_libertarian', 'libertarian', 'advocator', 'advocate']
senticnet['reverberating'] = [-0.726, 0, -0.897, 0, '#sad', '#scared', -0.541, 'reverberative', 'resonant', 'resounding', 'resonating', 'evocative']
senticnet['throw'] = [0.987, 0, 0, 0.868, '#joyful', '#admirable', 0.618, 'bounce', 'bounce_up_down', 'play_catch', 'ball_game', 'game']
senticnet['stratagem'] = [0.681, -0.851, 0, 0.605, '#joyful', '#surprising', 0.712, 'contrivance', 'bubble', 'strategy', 'house_of_cards', 'waiting_game']
senticnet['wigwam'] = [0.038, 0, 0, 0.097, '#joyful', '#admirable', 0.045, 'place', 'address', 'abide', 'post', 'property']
senticnet['drift'] = [0, 0, 0.708, -0.747, '#angry', '#disgusting', -0.485, 'diverge', 'digress', 'deviate', 'stray', 'slew']
senticnet['faux_pas'] = [0, 0, 0.844, -0.94, '#angry', '#disgusting', -0.595, 'rusticity', 'slip', 'solecism', 'gaffe', 'gaucherie']
senticnet['pean'] = [0, 0, -0.857, -0.991, '#scared', '#disgusting', -0.616, 'paean', 'eulogium', 'encomium', 'eulogy', 'panegyric']
senticnet['amount_waterment'] = [0.884, 0.877, 0, 0, '#joyful', '#interesting', 0.587, 'liquid_unit', 'amount_water', 'small_size', 'liquid_measure', 'small_amount']
senticnet['midsection'] = [0.902, 0.772, 0, 0, '#joyful', '#interesting', 0.558, 'body', 'two_ears', 'dog_pet', 'living_thing', 'abdomen']
senticnet['talkativeness'] = [0.916, -0.877, 0, 0.79, '#joyful', '#surprising', 0.861, 'garrulity', 'garrulousness', 'loquaciousness', 'loquacity', 'leresis']
senticnet['colossal'] = [0.873, 0.793, 0, 0, '#joyful', '#interesting', 0.555, 'exceptional', 'prodigious', 'portentous', 'exceeding', 'stupendous']
senticnet['unblinking'] = [-0.893, 0, 0.797, -0.958, '#sad', '#disgusting', -0.883, 'unemotional', 'unemotionalal', 'phlegmatic', 'stoic', 'chilly']
senticnet['selective'] = [0.902, -0.855, 0, 0.898, '#joyful', '#admirable', 0.885, 'discerning', 'discriminating', 'discriminatingal', 'discriminative', 'diacritic']
senticnet['vegetarian'] = [0.826, -0.655, 0, 0.587, '#joyful', '#surprising', 0.689, 'scoffer', 'devourer', 'eater', 'diner', 'dunker']
senticnet['toys'] = [0.754, 0, 0, 0.729, '#joyful', '#admirable', 0.494, 'food', 'biodegradable', 'pet', 'organic', 'animal_product']
senticnet['prosy'] = [0, 0, -0.916, -0.763, '#scared', '#disgusting', -0.56, 'matter-of-fact', 'commonplace', 'pedestrian', 'prosaic', 'earthbound']
senticnet['holier-than-thou'] = [0, 0, -0.939, -0.766, '#scared', '#disgusting', -0.568, 'pietistical', 'pietistic', 'pharisaic', 'sanctimonious', 'pharisaical']
senticnet['reallocation'] = [0.732, -0.833, 0, 0.566, '#joyful', '#surprising', 0.71, 'share', 'allocation', 'quota', 'portion', 'part']
senticnet['trustworthiness'] = [0.881, -0.51, 0, 0.76, '#joyful', '#admirable', 0.717, 'responsibleness', 'trustiness', 'dependability', 'dependableness', 'reliability']
senticnet['slicker'] = [0.969, -0.885, 0, 0.736, '#joyful', '#surprising', 0.863, 'charlatan', 'beguiler', 'quack', 'phrenologist', 'craniologist']
senticnet['effortless'] = [0.857, 0, 0, 0.997, '#joyful', '#admirable', 0.618, 'straightforward', 'easy', 'uncomplicated', 'uninvolved', 'simple']
senticnet['outrun'] = [0.995, 0, 0, 0.825, '#joyful', '#admirable', 0.607, 'outsell', 'trounce', 'outstrip', 'outdistance', 'outpace']
senticnet['dominating'] = [0, 0, 0.92, -0.958, '#angry', '#disgusting', -0.626, 'autocratic', 'bossy', 'high-and-mighty', 'magisterial', 'peremptory']
senticnet['withered'] = [0, 0, -0.932, -0.818, '#scared', '#disgusting', -0.583, 'sear', 'sere', 'dried-up', 'shrivelled', 'shriveled']
senticnet['plunder'] = [0, 0, -0.749, -0.89, '#scared', '#disgusting', -0.546, 'booty', 'loot', 'pillage', 'swag', 'prize']
senticnet['pushful'] = [0.913, -0.833, 0, 0.739, '#joyful', '#surprising', 0.828, 'ambitious', 'pushy', 'aspirant', 'aspiring', 'wishful']
senticnet['wriggly'] = [0, 0, -0.877, -0.723, '#scared', '#disgusting', -0.533, 'writhing', 'wiggly', 'sinuate', 'wriggling', 'sinuous']
senticnet['scooter'] = [0.05, -0.043, 0, 0, '#joyful', '#surprising', 0.031, 'have_fun', 'motorcycle', 'roller_coaster', 'sports_car', 'bike']
senticnet['striptease'] = [0.993, -0.967, 0, 0.917, '#joyful', '#surprising', 0.959, 'strip', 'fan_dance', 'bubble_dance', 'strip_show', 'nude_dancing']
senticnet['becloud'] = [0, 0, -0.83, -0.919, '#scared', '#disgusting', -0.583, 'befog', 'fog', 'obscured', 'haze_over', 'obnubilate']
senticnet['bifurcate'] = [0, 0, -0.889, -0.783, '#scared', '#disgusting', -0.557, 'forficate', 'pronged', 'branched', 'forked', 'biramous']
senticnet['stamp'] = [0.927, 0.742, 0, 0.879, '#joyful', '#admirable', 0.849, 'letter', 'postman', 'arrive_mail', 'letterhead', 'envelope']
senticnet['collected'] = [0, 0, -0.821, -0.729, '#scared', '#disgusting', -0.517, 'balance', 'equanimous', 'brace', 'poised', 'self-collected']
senticnet['docker'] = [0, 0, -0.952, -0.844, '#scared', '#disgusting', -0.599, 'stevedore', 'lumper', 'loader', 'longshoreman', 'dock_worker']
senticnet['unceasing'] = [0, 0, -0.972, -0.95, '#scared', '#disgusting', -0.641, 'incessant', 'never-ending', 'constant', 'ceaseless', 'perpetual']
senticnet['wings'] = [0.042, 0.088, 0, 0, '#joyful', '#interesting', 0.043, 'jump_over_obstacle', 'chick', 'aircraft', 'pilot', 'attempt_fly']
senticnet['venturesome'] = [0.706, -0.87, 0, 0.968, '#surprising', '#admirable', 0.848, 'audacious', 'swaggering', 'daring', 'adventuresome', 'venturous']
senticnet['providence'] = [0, 0.91, 0, 0.874, '#interesting', '#admirable', 0.595, 'discretion', 'frugality', 'frugalness', 'prudence', 'judgement']
senticnet['stem'] = [0.945, -0.849, 0, 0, '#joyful', '#surprising', 0.598, 'evergreen', 'leaf', 'moss', 'branch', 'leaf_tree']
senticnet['scraggy'] = [0, 0, 0.956, -0.963, '#angry', '#disgusting', -0.64, 'scrawny', 'boney', 'underweight', 'skinny', 'weedy']
senticnet['smelly'] = [-0.031, 0.152, -0.107, 0.188, '#interesting', '#admirable', 0.067, 'mouth_action', 'bad_odor', 'five_senses', 'human_sense', 'exhalation']
senticnet['specialty'] = [0.618, -0.75, 0, 0.628, '#surprising', '#admirable', 0.665, 'uniqueness', 'singularity', 'individualism', 'special', 'distinctiveness']
senticnet['fishy'] = [0, 0, -0.786, -0.966, '#scared', '#disgusting', -0.584, 'suspect', 'shady', 'funny', 'louche', 'fly-by-night']
senticnet['enjoyousured'] = [0.79, 0, 0, 0.71, '#joyful', '#admirable', 0.5, 'joyful', 'ecstatic', 'rapt', 'joyousurous', 'joyous']
senticnet['vassalage'] = [-0.365, -0.082, 0, -0.327, '#sad', '#disgusting', -0.203, 'thrall', 'servitude', 'serfdom', 'serfhood', 'bonded_labor']
senticnet['work-shy'] = [0, 0, -0.869, -0.721, '#scared', '#disgusting', -0.53, 'otiose', 'slothful', 'faineant', 'lazy', 'indolent']
senticnet['abstruseness'] = [0, 0, -0.722, -0.93, '#scared', '#disgusting', -0.551, 'abstrusity', 'reconditeness', 'astuteness', 'profundity', 'profoundness']
senticnet['pretended'] = [0, 0, 0.891, -0.836, '#angry', '#disgusting', -0.576, 'affected', 'feigned', 'false', 'fake', 'sham']
senticnet['sslosh_around'] = [-0.879, 0, 0.682, -0.533, '#sad', '#angry', -0.698, 'swash', 'spatter', 'splatter', 'slosh_around', 'plash']
senticnet['pretender'] = [0.85, -0.716, 0, 0.617, '#joyful', '#surprising', 0.728, 'charmer', 'phony', 'phoney', 'hypocrite', 'dissembler']
senticnet['wellbeing'] = [0.971, -0.717, 0, 0.656, '#joyful', '#surprising', 0.781, 'eudaimonia', 'human_flourishing', 'successfulness', 'upbeat', 'strength']
senticnet['turn_out'] = [0, 0, 0.855, -0.738, '#angry', '#disgusting', -0.531, 'circumvolve', 'rotating', 'revolve', 'rotate', 'go_around']
senticnet['take_off_clotheses'] = [0.714, -0.583, 0, 0.667, '#joyful', '#admirable', 0.655, 'take_clothes_off', 'fill_bathtub_water', 'turn_water', 'remove_cloth', 'take_off_clothes']
senticnet['collusive'] = [-0.819, 0, 0.823, 0, '#sad', '#angry', -0.547, 'connive', 'conniving', 'intrigue', 'calculating', 'scheme']
senticnet['virtuous'] = [0.839, -0.704, 0, 0.93, '#joyful', '#admirable', 0.824, 'celibate', 'chaste', 'pure', 'continent', 'virginal']
senticnet['scorched'] = [0, 0, -0.923, -0.966, '#scared', '#disgusting', -0.63, 'adust', 'parched', 'sear', 'sunbaked', 'baked']
senticnet['quelling'] = [0, 0, -0.896, -0.792, '#scared', '#disgusting', -0.563, 'suppression', 'crushing', 'stifling', 'oppress', 'squeeze']
senticnet['excruciating'] = [-0.795, 0, 0.903, 0, '#sad', '#angry', -0.566, 'agonizing', 'harrowing', 'torturing', 'worry', 'fret']
senticnet['mercurial'] = [0, 0, -0.895, -0.942, '#scared', '#disgusting', -0.612, 'fickle', 'wandering', 'planetary', 'quicksilver', 'erratic']
senticnet['referable'] = [0.511, -0.597, 0, 0.576, '#surprising', '#admirable', 0.561, 'due', 'traceable', 'attributable', 'imputable', 'ascribable']
senticnet['worthy'] = [0.866, -0.528, 0, 0.529, '#joyful', '#admirable', 0.641, 'bailable', 'desirable', 'suitable', 'eligible', 'entitled']
senticnet['lower-ranking'] = [0, 0, 0.828, -0.805, '#angry', '#disgusting', -0.544, 'lowly', 'petty', 'junior-grade', 'subaltern', 'secondary']
senticnet['degenerateer'] = [0.789, -0.733, 0, 0.857, '#joyful', '#admirable', 0.793, 'fetishist', 'lech', 'degenerate', 'letch', 'satyr']
senticnet['cabalistic'] = [-0.77, 0, -0.991, 0, '#sad', '#scared', -0.587, 'inscrutable', 'cryptic', 'deep', 'mysterious', 'mystifying']
senticnet['starter'] = [0, 0, -0.983, -0.891, '#scared', '#disgusting', -0.625, 'freshman', 'newcomer', 'neophyte', 'fledgeling', 'entrant']
senticnet['skirt'] = [0.1, -0.12, 0.05, -0.032, '#joyful', '#surprising', 0.046, 'fancy_dress', 'frill', 'fashion', 'dress', 'blouse']
senticnet['magisterial'] = [0, 0, 0.92, -0.958, '#angry', '#disgusting', -0.626, 'autocratic', 'dominating', 'high-and-mighty', 'bossy', 'peremptory']
senticnet['lordly'] = [0, 0, -0.749, -0.932, '#scared', '#disgusting', -0.56, 'imperious', 'haughty', 'disdainful', 'supercilious', 'overbearing']
senticnet['grillworking'] = [0.5, -0.762, 0, 0.814, '#surprising', '#admirable', 0.692, 'net', 'network', 'grillwork', 'mesh', 'grillworkwork']
senticnet['religionism'] = [0.674, -0.798, 0, 0.981, '#surprising', '#admirable', 0.818, 'piety', 'piousness', 'pietism', 'religiosity', 'devoutness']
senticnet['shaking'] = [0.748, -0.907, 0, 0.99, '#surprising', '#admirable', 0.882, 'shakiness', 'quivering', 'tremolo', 'vibration', 'quiver']
senticnet['obsess'] = [0, -0.862, 0, 0.987, '#surprising', '#admirable', 0.616, 'ghost', 'stalk', 'haunting', 'frequent', 'persistent']
senticnet['stride'] = [0, 0.84, 0, 0.786, '#interesting', '#admirable', 0.542, 'foot_motion', 'foot_action', 'foot_movement', 'anagram', 'pace']
senticnet['seasonable'] = [0.915, -0.99, 0, 0.673, '#joyful', '#surprising', 0.859, 'ripe', 'good', 'right', 'timely', 'opportune']
senticnet['well-favored'] = [0.757, 0.837, 0, 0, '#joyful', '#interesting', 0.531, 'big', 'handsome', 'good-looking', 'better-looking', 'bighearted']
senticnet['just_about'] = [0, 0, -0.725, -0.873, '#scared', '#disgusting', -0.533, 'close_to', 'approximately', 'some', 'roughly', 'about']
senticnet['ungodliness'] = [0.905, -0.802, 0, 0.583, '#joyful', '#surprising', 0.763, 'unrighteousness', 'undutifulness', 'impiety', 'godlessness', 'irreligiousness']
senticnet['serfdom'] = [-0.365, -0.082, 0, -0.327, '#sad', '#disgusting', -0.203, 'thrall', 'servitude', 'bonded_labor', 'serfhood', 'vassalage']
senticnet['plaster_saint'] = [-0.734, 0, 0, -0.961, '#sad', '#disgusting', -0.565, 'hypocrite', 'humbug', 'pretender', 'phoney', 'imposter']
senticnet['rigor'] = [0.529, -0.755, 0, 0.578, '#surprising', '#admirable', 0.621, 'sternness', 'grimness', 'asperity', 'hardship', 'rigorousness']
senticnet['tendinous'] = [0, -0.877, 0, 0.779, '#surprising', '#admirable', 0.552, 'fibrous', 'sinewy', 'stringy', 'unchewable', 'brawny']
senticnet['weather_upper_deck'] = [0.831, -0.821, 0, 0.826, '#joyful', '#admirable', 0.826, 'upper_deck', 'freeboard_upper_deck', 'deck', 'shelter_upper_deck', 'boat_upper_deck']
senticnet['tire'] = [0, -0.075, 0, 0, '#surprising', '#surprising', 0.025, 'gyroscope', 'air_pump', 'ball_bounce', 'motor_oil', 'bicycle_tire']
senticnet['north_pole'] = [0, 0, 0.701, -0.824, '#angry', '#disgusting', -0.508, 'arctic', 'cold_weather', 'snow', 'ice', 'cold']
senticnet['timeliness'] = [-0.059, 0.161, -0.126, 0.181, '#interesting', '#admirable', 0.052, 'usable', 'redo', 'available', 'question_starter', 'replay']
senticnet['sabotage'] = [0, 0, 0.773, -0.95, '#angry', '#disgusting', -0.574, 'counteract', 'cave', 'undermine', 'subvert', 'weaken']
senticnet['thumb'] = [0, -0.857, 0, 0.746, '#surprising', '#admirable', 0.534, 'finger', 'cylindric', 'cylindrical_shape', 'five_digits', 'cylinder']
senticnet['decrease_music'] = [-0.129, -0.058, 0, -0.134, '#sad', '#disgusting', -0.068, 'diminish', 'reduce', 'decrease', 'lower', 'low_level']
senticnet['quiz'] = [-0.057, 0.141, -0.098, 0.132, '#interesting', '#admirable', 0.039, 'multiple_choices', 'pop_quiz', 'final', 'final_exam', 'evaluation']
senticnet['unconventional'] = [0.754, 0, 0, 0.717, '#joyful', '#admirable', 0.49, 'homosexual', 'same_sex_attraction', 'gay', 'gay_person', 'open_minded']
senticnet['usableness'] = [0.513, -0.874, 0, 0.924, '#surprising', '#admirable', 0.77, 'quality', 'serviceability', 'serviceableness', 'usefulness', 'user_friendly']
senticnet['very_tired'] = [-0.727, 0, 0, -0.78, '#sad', '#disgusting', -0.502, 'increased_heart_rate', 'become_exhausted', 'sore_muscle', 'breathlessness', 'pull_muscle']
senticnet['homoot'] = [0.537, -0.514, 0, 0.807, '#joyful', '#admirable', 0.619, 'lesbian', 'fairy', 'fag', 'homogot', 'homo']
senticnet['proton'] = [0, 0, 0, 0.101, '#admirable', '#admirable', 0.034, 'elementary_particle', 'neutron', 'proton_neutron', 'subatomic_particle', 'electron']
senticnet['stimulant'] = [0.95, -0.951, 0, 0.769, '#joyful', '#surprising', 0.89, 'adrenocorticotropic', 'stimulative', 'adrenocorticotrophic', 'stimulating', 'excitant']
senticnet['venturous'] = [0.706, -0.87, 0, 0.968, '#surprising', '#admirable', 0.848, 'audacious', 'swaggering', 'daring', 'venturesome', 'adventuresome']
senticnet['unchain'] = [0.714, -0.571, 0, 0.873, '#joyful', '#admirable', 0.719, 'bail_out', 'unspell', 'bail', 'unloose', 'run']
senticnet['particle_scientific_instrument'] = [0.562, -0.777, 0, 0.962, '#surprising', '#admirable', 0.767, 'console', 'instrument', 'scientific_instrument', 'accelerator', 'atom_smasher']
senticnet['lissom'] = [0, 0, -0.926, -0.837, '#scared', '#disgusting', -0.588, 'sylphlike', 'supple', 'lithe', 'slender', 'svelte']
senticnet['breast_infant_feeding'] = [-0.802, 0, 0.724, -0.706, '#sad', '#angry', -0.744, 'nursing', 'schedule_infant_feeding', 'demand_infant_feeding', 'feeding', 'infant_feeding']
senticnet['blurryred'] = [-0.093, 0, 0, 0, '#sad', '#sad', -0.031, 'hazy', 'blurry', 'bleary', 'blur', 'foggy']
senticnet['sacrament_of_eucharist'] = [0.762, 0, 0, 0.894, '#joyful', '#admirable', 0.552, 'holy', 'eucharist', 'holy_eucharist', 'holy_sacrament', 'liturgy']
senticnet['tongue'] = [0.04, 0, 0, 0.067, '#joyful', '#admirable', 0.036, 'cook', 'food', 'taste', 'ingredient', 'add_flavor']
senticnet['sedume'] = [-0.592, 0, 0.942, -0.758, '#angry', '#disgusting', -0.764, 'livelong', 'herb', 'stonecrop', 'orpin', 'sedum']
senticnet['paean'] = [0, 0, -0.857, -0.991, '#scared', '#disgusting', -0.616, 'eulogy', 'eulogium', 'encomium', 'pean', 'panegyric']
senticnet['accommodative'] = [0, 0, -0.764, -0.874, '#scared', '#disgusting', -0.546, 'co-op', 'concerted', 'conjunct', 'conjunctive', 'cooperative']
senticnet['flecked'] = [0, 0, -0.994, -0.915, '#scared', '#disgusting', -0.636, 'specked', 'speckled', 'stipple', 'dotted', 'bespeckle']
senticnet['get_tan'] = [0.759, 0, 0, 0, '#joyful', '#joyful', 0.253, 'sit_on_beach', 'enjoy_sun', 'summer', 'sunshine', 'dry_clothes']
senticnet['unparliamentary'] = [0.584, -0.592, 0, 0.753, '#surprising', '#admirable', 0.643, 'ungracious', 'discourteous', 'bratty', 'impolite', 'brattish']
senticnet['animal_behavior'] = [0, 0, -0.998, -0.768, '#scared', '#disgusting', -0.589, 'animal_instinct', 'fixed_pattern_of_behavior', 'overeact', 'instinct', 'impulse']
senticnet['suitable'] = [0.819, 0.914, 0, 0, '#joyful', '#interesting', 0.578, 'appropriate', 'apt', 'proper', 'liable', 'likely']
senticnet['soybean'] = [0.901, 0, 0, 0, '#joyful', '#joyful', 0.3, 'french_toast', 'gnocchi', 'fondue', 'result_cook', 'lasagna']
senticnet['well-heeled'] = [0.874, 0.907, 0, 0, '#joyful', '#interesting', 0.594, 'well-to-do', 'prosperous', 'well-fixed', 'comfortable', 'easy']
senticnet['aging'] = [0, -0.738, 0, 0.957, '#surprising', '#admirable', 0.565, 'looking_old', 'age_gracefully', 'looking_good', 'accepting_changes', 'cosmetic_surgery']
senticnet['waterfront'] = [0.03, 0.117, 0, 0.084, '#interesting', '#admirable', 0.077, 'ocean_beach', 'beach', 'ocean', 'coast', 'sea']
senticnet['unsullied'] = [0.513, -0.585, 0, 0.919, '#surprising', '#admirable', 0.672, 'stainless', 'untainted', 'untarnished', 'unblemished', 'unstained']
senticnet['first-class'] = [0.919, 0, 0, 0.734, '#joyful', '#admirable', 0.551, 'splendiferous', 'glorious', 'excellent', 'resplendent', 'splendid']
senticnet['whiff'] = [0.957, -0.576, 0, 0.857, '#joyful', '#admirable', 0.797, 'gust', 'puff', 'sandblast', 'puff_of_air', 'bluster']
senticnet['dodder'] = [-0.8, 0, -0.804, 0, '#sad', '#scared', -0.535, 'coggle', 'paddle', 'totter', 'toddle', 'waddle']
senticnet['scrounge'] = [0, 0, -0.903, -0.99, '#scared', '#disgusting', -0.631, 'foraging', 'pasture', 'grass', 'eatage', 'forage']
senticnet['big_amount'] = [0.277, 0.161, 0, 0.337, '#joyful', '#admirable', 0.258, 'many', 'plenty', 'a_lot', 'abundant', 'good_number']
senticnet['dwell'] = [-0.938, 0, 0, -0.842, '#sad', '#disgusting', -0.593, 'gloat', 'gloating', 'cheer', 'gloatingly', 'schadenfreude']
senticnet['stoic'] = [-0.893, 0, 0.797, -0.958, '#sad', '#disgusting', -0.883, 'unemotional', 'unemotionalal', 'unblinking', 'phlegmatic', 'chilly']
senticnet['seer'] = [0.849, 0.856, 0, 0, '#joyful', '#interesting', 0.568, 'observer', 'peek', 'appearance', 'peer', 'glimpse']
senticnet['buy_at'] = [0, -0.751, 0, 0.847, '#surprising', '#admirable', 0.533, 'condescend', 'sponsor', 'patronize', 'support', 'patronise']
senticnet['quench'] = [0, 0, 0.932, -0.9, '#angry', '#disgusting', -0.611, 'slake', 'abate', 'allay', 'assuage', 'slack']
senticnet['yachts'] = [0, 0, 0, 0.135, '#admirable', '#admirable', 0.045, 'kayak', 'ferries', 'canoes', 'towboats', 'boat_type']
senticnet['planetary'] = [0.829, 0, 0, 0.81, '#joyful', '#admirable', 0.546, 'galaxy', 'universe', 'dwarf_planet', 'sun', 'moon']
senticnet['whole_entireness'] = [0.639, -0.827, 0, 0.997, '#surprising', '#admirable', 0.821, 'completeness', 'work', 'whole_shebang', 'kit_and_caboodle', 'entireness']
senticnet['ovarian_ectopic_gestation'] = [-0.752, 0, 0.715, -0.725, '#sad', '#disgusting', -0.731, 'abdominal_ectopic_gestation', 'pregnancy', 'tubal_ectopic_gestation', 'ectopic_gestation', 'gestation']
senticnet['sugar'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'add_sugar', 'drink_tea', 'drink_coffee', 'cake', 'sweet']
senticnet['wrestling'] = [0.848, 0.78, 0, 0, '#joyful', '#interesting', 0.543, 'several_types', 'put_mask', 'suspect', 'gas_stove', 'wrestler']
senticnet['tiles'] = [0, 0.952, 0, 0, '#interesting', '#interesting', 0.317, 'bathroom_wall', 'hair', 'design', 'water_resistance', 'algae']
senticnet['decided'] = [0.891, 0.987, 0, 0, '#joyful', '#interesting', 0.626, 'distinguishable', 'discrete', 'distinct', 'clear-cut', 'trenchant']
senticnet['stealthiness'] = [0.742, -0.839, 0, 0.889, '#surprising', '#admirable', 0.823, 'secretiveness', 'sneakiness', 'furtiveness', 'unsociability', 'unsociableness']
senticnet['japanese_animation'] = [0.743, 0, 0, 0.999, '#joyful', '#admirable', 0.581, 'manga', 'cartoon', 'anime', 'movie', 'film']
senticnet['device_measure_timeer'] = [-0.022, -0.01, 0.058, 0, '#sad', '#angry', -0.023, 'time_tracker', 'show_time', 'timekeep', 'device_measure_time', 'tell_time']
senticnet['wasteful'] = [0, 0, 0.845, -0.919, '#angry', '#disgusting', -0.588, 'overweening', 'excessive', 'extravagant', 'exuberant', 'prodigal']
senticnet['soccer'] = [0.787, 0.899, 0, 0, '#joyful', '#interesting', 0.562, 'ball_bounce', 'bounce', 'football_bounce', 'ball', 'basketball_bounce']
senticnet['taxability'] = [0, 0, 0.967, -0.749, '#angry', '#disgusting', -0.572, 'ratability', 'susceptibility', 'susceptibleness', 'liability', 'rateability']
senticnet['victorious'] = [0.995, 0.722, 0, 0.773, '#joyful', '#admirable', 0.83, 'score', 'make_goal', 'lift_car', 'silly', 'win']
senticnet['unstinted'] = [0, 0, -0.819, -0.888, '#scared', '#disgusting', -0.569, 'unsparing', 'overgenerous', 'lavish', 'too-generous', 'munificent']
senticnet['clear-cut'] = [0.891, 0.987, 0, 0, '#joyful', '#interesting', 0.626, 'distinguishable', 'discrete', 'decided', 'distinct', 'trenchant']
senticnet['sensuous'] = [0.596, -0.64, 0, 0.945, '#surprising', '#admirable', 0.727, 'cosmetic', 'painterly', 'aesthetical', 'artistic', 'enhancive']
senticnet['punctilio'] = [0.559, -0.839, 0, 0.593, '#surprising', '#admirable', 0.664, 'abidance', 'compliance', 'conformation', 'conformity', 'honoring']
senticnet['potato'] = [0.532, -0.682, 0, 0.984, '#surprising', '#admirable', 0.733, 'chips', 'white_potato', 'murphy', 'spud', 'tater']
senticnet['teeth'] = [0.854, 0.659, 0, 0.545, '#joyful', '#interesting', 0.686, 'bite_food', 'obtain_food', 'find_restaurant', 'order_lunch', 'decide_eat']
senticnet['undeviating'] = [0.947, -0.793, 0, 0.7, '#joyful', '#surprising', 0.813, 'tested', 'tried', 'tried_and_true', 'sure', 'dependable']
senticnet['too-generous'] = [0, -0.92, 0, 0.783, '#surprising', '#admirable', 0.568, 'shower', 'munificent', 'overgenerous', 'unsparing', 'lavish']
senticnet['adamance_of_purpose'] = [-0.975, 0, 0.549, -0.978, '#sad', '#disgusting', -0.834, 'adamance', 'resolve', 'resoluteness', 'firmness', 'resolution']
senticnet['nutlike'] = [0, -0.96, 0, 0.721, '#surprising', '#admirable', 0.56, 'nutty', 'balmy', 'bats', 'barmy', 'batty']
senticnet['ill-conceived'] = [0, 0, -0.803, -0.83, '#scared', '#disgusting', -0.544, 'misdirect', 'lead_astray', 'mislead', 'misadvise', 'misguided']
senticnet['tusked'] = [0.845, -0.716, 0, 0.775, '#joyful', '#admirable', 0.779, 'toothy', 'toothed', 'sabertoothed', 'toothlike', 'cogged']
senticnet['shift'] = [0.719, -0.572, 0, 0.651, '#joyful', '#admirable', 0.647, 'chap', 'break', 'slit', 'gap', 'scissure']
senticnet['gewgaw'] = [0, 0, -0.955, -0.711, '#scared', '#disgusting', -0.555, 'gaud', 'novelty', 'trinket', 'bangle', 'bauble']
senticnet['gonzo'] = [0, -0.949, 0, 0.938, '#surprising', '#admirable', 0.629, 'freaky', 'outlandish', 'off-the-wall', 'bizarre', 'flaky']
senticnet['slog'] = [0, 0, -0.98, -0.801, '#scared', '#disgusting', -0.594, 'grind', 'footslog', 'donkeywork', 'plodding', 'drudgery']
senticnet['tradecraft'] = [0.921, -0.615, 0, 0.91, '#joyful', '#admirable', 0.815, 'housecraft', 'craftsmanship', 'watercraft', 'acquirement', 'skill']
senticnet['unhelpfulness'] = [0.814, -0.95, 0, 0.918, '#surprising', '#admirable', 0.894, 'inconsideration', 'unkindness', 'thoughtlessness', 'inconsiderateness', 'insensitivity']
senticnet['thiabendazole'] = [0.621, -0.767, 0, 0.947, '#surprising', '#admirable', 0.778, 'helminthic', 'medicament', 'medicinal_drug', 'medication', 'medicine']
senticnet['shaky'] = [0, 0, -0.842, -0.92, '#scared', '#disgusting', -0.587, 'unstable', 'parlous', 'perilous', 'touch-and-go', 'precarious']
senticnet['satyr'] = [0.789, -0.733, 0, 0.857, '#joyful', '#admirable', 0.793, 'fetishist', 'lecher', 'lech', 'letch', 'degenerate']
senticnet['rock'] = [0.129, 0, 0, 0, '#joyful', '#joyful', 0.043, 'incline_plane', 'boulder', 'ramp', 'hill_mountain', 'slide']
senticnet['goth'] = [0, 0, -0.758, -0.906, '#scared', '#disgusting', -0.555, 'tyke', 'barbarian', 'peasant', 'churl', 'boor']
senticnet['smudge'] = [0.707, -0.527, 0, 0.634, '#joyful', '#admirable', 0.623, 'spot', 'smirch', 'daub', 'blotch', 'blot']
senticnet['thing'] = [0.052, 0.129, 0, 0.16, '#interesting', '#admirable', 0.114, 'general_term', 'generic', 'generic_term', 'general_name', 'name']
senticnet['sailing'] = [0.035, 0.083, 0, 0.128, '#interesting', '#admirable', 0.082, 'woodworking', 'build_boat', 'workshop', 'repair', 'expensive']
senticnet['speakers'] = [0, 0, 0.831, -0.903, '#angry', '#disgusting', -0.578, 'sound_level', 'adjust_volume', 'noisy', 'making_a_lot_of_noise', 'hear_song']
senticnet['comme_il_faut'] = [0.83, 0.727, 0, 0, '#joyful', '#interesting', 0.519, 'seemly', 'comely', 'decorous', 'becoming', 'decent']
senticnet['bereavement_note'] = [0.748, 0.847, 0, 0, '#joyful', '#interesting', 0.532, 'hold_document', 'write', 'continue_story', 'make_paper_airplane', 'bereavement']
senticnet['viewable'] = [0.654, -0.715, 0, 0.624, '#joyful', '#surprising', 0.664, 'panoptic', 'gross', 'telescopic', 'seeable', 'visual']
senticnet['stockings'] = [0.742, 0, 0, 0.905, '#joyful', '#admirable', 0.549, 'cover_leg', 'intimate', 'robe', 'make_fashion_statement', 'leg']
senticnet['shot'] = [0.695, -0.525, 0, 0.957, '#joyful', '#admirable', 0.726, 'jibe', 'slam', 'gibe', 'cheap_shot', 'shaft']
senticnet['uppish'] = [0, 0, -0.764, -0.877, '#scared', '#disgusting', -0.547, 'snooty', 'persnickety', 'too_big_for_ones_breeches', 'bigheaded', 'stuck-up']
senticnet['hijollification'] = [-0.85, 0, 0.691, -0.821, '#sad', '#disgusting', -0.787, 'jollification', 'high_jollification', 'jinks', 'high_jinx', 'revel']
senticnet['reevaluation'] = [0.798, -0.527, 0, 0.693, '#joyful', '#admirable', 0.673, 'overvaluation', 'grade', 'undervaluation', 'pricing', 'rating']
senticnet['rapacious'] = [0, 0, -0.857, -0.734, '#scared', '#disgusting', -0.53, 'wolfish', 'voracious', 'esurient', 'ravenous', 'edacious']
senticnet['luckless'] = [0, 0, -0.909, -0.938, '#scared', '#disgusting', -0.616, 'unlucky', 'ill-omened', 'ill-starred', 'doomed', 'ill-fated']
senticnet['workshop'] = [0.035, 0.083, 0, 0.128, '#interesting', '#admirable', 0.082, 'woodworking', 'sailing', 'build_boat', 'repair', 'expensive']
senticnet['traversal'] = [0, 0, -0.778, -0.778, '#scared', '#disgusting', -0.519, 'transom', 'track', 'crosspiece', 'crossbeam', 'traverse']
senticnet['roughly'] = [0, 0, -0.725, -0.873, '#scared', '#disgusting', -0.533, 'close_to', 'approximately', 'just_about', 'some', 'about']
senticnet['substantive'] = [0.738, -0.525, 0, 0.775, '#joyful', '#admirable', 0.679, 'significant', 'meaning', 'purposeful', 'meaningful', 'pregnant']
senticnet['parody'] = [0, 0, 0.79, -0.834, '#angry', '#disgusting', -0.541, 'mockery', 'burlesque', 'spoof', 'lampoon', 'sendup']
senticnet['seek_information'] = [0, 0.84, 0, 0.887, '#interesting', '#admirable', 0.576, 'curious', 'inquisitive', 'ask_question', 'question', 'question_knowledge']
senticnet['undamaged'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'brave_out', 'endure', 'weather', 'withstand', 'stand_firm']
senticnet['vincible'] = [0.702, -0.944, 0, 0.582, '#joyful', '#surprising', 0.743, 'conquerable', 'vanquishable', 'beatable', 'subduable', 'subjugable']
senticnet['wastrel'] = [0.87, -0.937, 0, 0.831, '#joyful', '#surprising', 0.879, 'spendthrift', 'waster', 'prodigal', 'spender', 'scattergood']
senticnet['self_love'] = [0, 0, 0.875, -0.793, '#angry', '#disgusting', -0.556, 'conceit', 'amour_propre', 'self_pride', 'egotism', 'self-importance']
senticnet['surgical_knifet'] = [0.932, -0.521, 0, 0.534, '#joyful', '#admirable', 0.662, 'lance', 'catling', 'surgical_knife', 'scalpel', 'knife']
senticnet['slavelike'] = [0.981, -0.887, 0, 0.939, '#joyful', '#admirable', 0.936, 'obsequious', 'submissive', 'servile', 'subservient', 'slavish']
senticnet['epileptic_seizure'] = [-0.782, 0, 0, -0.826, '#sad', '#disgusting', -0.536, 'attack', 'raptus', 'absence_seizure', 'absence', 'ictus']
senticnet['preposterous'] = [0, 0, 0.911, -0.867, '#angry', '#disgusting', -0.593, 'illogical', 'nonrational', 'absurd', 'ridiculous', 'ludicrous']
senticnet['fulgent'] = [0, 0, 0.709, -0.957, '#angry', '#disgusting', -0.555, 'glaring', 'dazzling', 'egregious', 'blinding', 'glower']
senticnet['suite'] = [0.039, 0.081, -0.05, 0.053, '#interesting', '#admirable', 0.041, 'park_space', 'empty_space', 'soda_machine', 'washroom', 'place_to_sit']
senticnet['sphere'] = [0, 0.077, 0.039, 0.154, '#interesting', '#admirable', 0.064, 'marbles', 'round_figure', 'almond', 'round_ball', 'dome']
senticnet['triathlon'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'land_fish', 'fish', 'catch_fish', 'communication_system', 'bait']
senticnet['wave'] = [0.037, 0.161, -0.154, 0.203, '#interesting', '#admirable', 0.082, 'farewell', 'flow', 'salute', 'multiple_purposes', 'wave_wind']
senticnet['square-toed'] = [0, 0, 0.929, -0.876, '#angry', '#disgusting', -0.602, 'prissy', 'puritanical', 'priggish', 'prim', 'prudish']
senticnet['someone'] = [0.55, -0.981, 0, 0.794, '#surprising', '#admirable', 0.775, 'mortal', 'person', 'individual', 'agnostic', 'somebody']
senticnet['orient'] = [0.766, 0, 0, 0.727, '#joyful', '#admirable', 0.498, 'charge', 'pointed', 'indicate', 'designate', 'show']
senticnet['subduable'] = [0.702, -0.944, 0, 0.582, '#joyful', '#surprising', 0.743, 'conquerable', 'vanquishable', 'vincible', 'beatable', 'subjugable']
senticnet['print'] = [-0.042, 0.131, -0.055, 0.186, '#interesting', '#admirable', 0.073, 'print_word', 'paragraph', 'typeface', 'hold_information', 'document_type']
senticnet['rock_cress_plant'] = [0.598, -0.721, 0, 0.941, '#surprising', '#admirable', 0.753, 'sicklepod', 'tower_rock_cress', 'tower_mustard', 'rock_cress', 'cress']
senticnet['tortuousness'] = [0.697, -0.507, 0, 0.792, '#joyful', '#admirable', 0.665, 'distorted_shape', 'gnarl', 'warp', 'tortuosity', 'torsion']
senticnet['tree-living'] = [0, 0, -0.756, -0.88, '#scared', '#disgusting', -0.545, 'arboreal', 'dendroidal', 'arborous', 'arboriform', 'arborary']
senticnet['bragger'] = [0, 0, 0.765, -0.748, '#angry', '#disgusting', -0.504, 'boaster', 'braggart', 'vaunter', 'line-shooter', 'blowhard']
senticnet['melt_off'] = [0, 0, 0.752, -0.914, '#angry', '#disgusting', -0.555, 'dilute', 'reduce', 'thin', 'cut', 'lose_weight']
senticnet['flitter'] = [0, 0, 0.78, -0.831, '#angry', '#disgusting', -0.537, 'aflicker', 'quiver', 'flickering', 'flutter', 'waver']
senticnet['building_block'] = [0.962, -0.703, 0, 0.522, '#joyful', '#surprising', 0.729, 'adobe', 'adobe_brick', 'brick', 'clinker', 'firebrick']
senticnet['branching'] = [0, 0, -0.983, -0.715, '#scared', '#disgusting', -0.566, 'fork', 'ramification', 'branch', 'forking', 'leg']
senticnet['find_tv_set'] = [0.787, -0.55, 0, 0.784, '#joyful', '#admirable', 0.707, 'turn_television', 'find_tv', 'switch_tv', 'near_tv', 'buy_tv']
senticnet['wonky'] = [-0.889, 0, -0.758, 0, '#sad', '#scared', -0.549, 'skew-whiff', 'awry', 'lopsided', 'askew', 'cockeyed']
senticnet['disperse'] = [0, -0.714, 0, 0.984, '#surprising', '#admirable', 0.566, 'stud', 'constellate', 'doting', 'adoring', 'fond']
senticnet['niggling'] = [0, 0, -0.868, -0.863, '#scared', '#disgusting', -0.577, 'footling', 'lilliputian', 'little', 'fiddling', 'picayune']
senticnet['reconditeness'] = [0, 0, -0.722, -0.93, '#scared', '#disgusting', -0.551, 'abstrusity', 'profundity', 'astuteness', 'abstruseness', 'profoundness']
senticnet['forthcoming'] = [0, 0, -0.852, -0.891, '#scared', '#disgusting', -0.581, 'extrospective', 'extroverted', 'outgoing', 'extravert', 'extrovertive']
senticnet['reverse'] = [-0.801, 0, 0, -0.778, '#sad', '#disgusting', -0.526, 'backward', 'retrograde', 'retral', 'primitive', 'benighted']
senticnet['abdominal_ectopic_gestation'] = [-0.752, 0, 0.715, -0.725, '#sad', '#disgusting', -0.731, 'pregnancy', 'ovarian_ectopic_gestation', 'tubal_ectopic_gestation', 'ectopic_gestation', 'gestation']
senticnet['vertebrate'] = [-0.947, 0, 0, -0.85, '#sad', '#disgusting', -0.599, 'teras', 'spontaneous_abortion', 'miscarriage', 'fetus', 'abortus']
senticnet['vane'] = [0.152, 0, 0.046, 0.128, '#joyful', '#admirable', 0.078, 'roof', 'foundation', 'find_outside', 'umbrella', 'exterior']
senticnet['chatter'] = [0, 0, -0.869, -0.97, '#scared', '#disgusting', -0.613, 'prate', 'tittle-tattle', 'palaver', 'piffle', 'gibbering']
senticnet['remindful'] = [0, 0, -0.707, -0.801, '#scared', '#disgusting', -0.503, 'resonant', 'redolent', 'smelling', 'reminiscent', 'evocative']
senticnet['transom'] = [0, 0, -0.778, -0.778, '#scared', '#disgusting', -0.519, 'traverse', 'track', 'crosspiece', 'crossbeam', 'traversal']
senticnet['judgement'] = [0, 0.91, 0, 0.874, '#interesting', '#admirable', 0.595, 'discretion', 'frugality', 'frugalness', 'providence', 'prudence']
senticnet['pricing'] = [0.798, -0.527, 0, 0.693, '#joyful', '#admirable', 0.673, 'overvaluation', 'grade', 'undervaluation', 'rating', 'reevaluation']
senticnet['looking_good'] = [0, -0.738, 0, 0.957, '#surprising', '#admirable', 0.565, 'looking_old', 'aging', 'age_gracefully', 'accepting_changes', 'cosmetic_surgery']
senticnet['subconscious'] = [0.914, -0.56, 0, 0.869, '#joyful', '#admirable', 0.781, 'tabula_rasa', 'ego', 'noddle', 'unconscious', 'psyche']
senticnet['zoomastigote'] = [0.807, -0.868, 0, 0.611, '#joyful', '#surprising', 0.762, 'flagellate', 'costia', 'zooflagellate', 'dinoflagellate', 'hypermastigote']
senticnet['sniffle'] = [0, 0, -0.957, -0.828, '#scared', '#disgusting', -0.595, 'whine', 'blubber', 'sniveling', 'snuffle', 'blub']
senticnet['remembrance'] = [0.685, -0.896, 0, 0.609, '#joyful', '#surprising', 0.73, 'mental_faculty', 'faculty', 'module', 'anamnesis', 'retentiveness']
senticnet['transformable'] = [0.623, -0.566, 0, 0.974, '#joyful', '#admirable', 0.721, 'commutable', 'convertible', 'translatable', 'alterable', 'transmutable']
senticnet['sulfamethoxazole'] = [0.551, -0.753, 0, 0.817, '#surprising', '#admirable', 0.707, 'antibacterial', 'sulfa', 'sulfisoxazole', 'sulfadiazine', 'sulfacetamide']
senticnet['located'] = [0, 0, -0.786, -0.872, '#scared', '#disgusting', -0.553, 'spy', 'recognise', 'spotted', 'recognize', 'descry']
senticnet['unthinking'] = [-0.816, 0, 0, -0.994, '#sad', '#disgusting', -0.603, 'inconsiderate', 'thoughtless', 'unreflective', 'unthoughtful', 'selfish']
senticnet['privately'] = [0, 0.091, -0.053, 0.073, '#interesting', '#admirable', 0.037, 'brew', 'hold_liquid', 'make_wish', 'rinse_dish', 'find_toilet']
senticnet['train'] = [0.069, 0.14, -0.064, 0.108, '#interesting', '#admirable', 0.084, 'trainer', 'instructor', 'personal_trainer', 'fit_person', 'coach']
senticnet['unbelieving'] = [0, 0, -0.791, -0.761, '#scared', '#disgusting', -0.517, 'skeptical', 'sceptical', 'doubting', 'disbelieving', 'questioning']
senticnet['reserved'] = [0, 0.084, 0, 0, '#interesting', '#interesting', 0.028, 'enquiries', 'reservation', 'reserve', 'dinner', 'call_restaurant']
senticnet['salving'] = [0, 0, -0.79, -0.951, '#scared', '#disgusting', -0.58, 'ointment', 'demulcent', 'softening', 'emollient', 'cream']
senticnet['terrier'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'video_recorder', 'ice_skater', 'vertebrate', 'elf', 'live_human']
senticnet['sneakiness'] = [0.742, -0.839, 0, 0.889, '#surprising', '#admirable', 0.823, 'secretiveness', 'furtiveness', 'stealthiness', 'unsociability', 'unsociableness']
senticnet['rigorousness'] = [0.529, -0.755, 0, 0.578, '#surprising', '#admirable', 0.621, 'sternness', 'grimness', 'rigor', 'hardship', 'asperity']
senticnet['skin_condition'] = [-0.745, 0, 0, -0.735, '#sad', '#disgusting', -0.493, 'acne_medication', 'adolescent', 'pimples', 'medical_treatment', 'prescription']
senticnet['blazing'] = [0, 0, -0.826, -0.934, '#scared', '#disgusting', -0.587, 'clamant', 'strident', 'conspicuous', 'blatant', 'clamorous']
senticnet['stub'] = [-0.953, 0, -0.926, 0, '#sad', '#scared', -0.626, 'anus', 'inside_brain', 'nervous_system', 'nape', 'under_head']
senticnet['stud'] = [0, -0.714, 0, 0.984, '#surprising', '#admirable', 0.566, 'doting', 'constellate', 'disperse', 'adoring', 'fond']
senticnet['unspent'] = [0.921, -0.825, 0, 0.868, '#joyful', '#admirable', 0.871, 'odd', 'left', 'unexhausted', 'unexpended', 'leftover']
senticnet['yellowness_yellow'] = [-0.514, 0, 0.626, -0.544, '#angry', '#disgusting', -0.561, 'brownish_yellow', 'canary', 'old_gold', 'gold', 'yellowness']
senticnet['sting_operation_game'] = [0.931, -0.714, 0, 0.63, '#joyful', '#surprising', 0.758, 'hustle', 'con', 'sting_operation', 'sting', 'bunco']
senticnet['unlikely'] = [0.764, -0.667, 0, 0.898, '#joyful', '#admirable', 0.776, 'farfetched', 'unbelievable', 'implausible', 'cockamamy', 'cockamamie']
senticnet['scoop'] = [0.699, -0.699, 0, 0.587, '#joyful', '#surprising', 0.662, 'best', 'outmaneuver', 'trump', 'outflank', 'outdo']
senticnet['skillful'] = [0, 0.933, 0, 0.768, '#interesting', '#admirable', 0.567, 'virtuoso', 'genius', 'expert', 'proficient', 'adept']
senticnet['autocratic'] = [0, 0, 0.92, -0.958, '#angry', '#disgusting', -0.626, 'bossy', 'dominating', 'high-and-mighty', 'magisterial', 'peremptory']
senticnet['sensibleness'] = [0.99, -0.88, 0, 0.831, '#joyful', '#surprising', 0.9, 'practicality', 'functionality', 'viability', 'usefulness', 'realism']
senticnet['propagate'] = [0, 0, -0.779, -0.979, '#scared', '#disgusting', -0.586, 'disseminating', 'disseminate', 'spread', 'circulate', 'distribute']
senticnet['sally'] = [0.59, -0.757, 0, 0.543, '#joyful', '#surprising', 0.63, 'venture', 'joint_venture', 'labor', 'cause', 'risk']
senticnet['quattrocento'] = [0.978, -0.601, 0, 0.895, '#joyful', '#admirable', 0.825, 'period', 'century', 'twentieth_century', 'time_period', 'period_of_time']
senticnet['sidetrack'] = [0, 0, -0.734, -0.873, '#scared', '#disgusting', -0.536, 'digress', 'depart', 'wander', 'divagate', 'stray']
senticnet['loutish'] = [-0.9, 0, -0.997, 0, '#sad', '#scared', -0.632, 'neandertal', 'boorish', 'swinish', 'oafish', 'neanderthal']
senticnet['shelling'] = [0, 0, -0.858, -0.913, '#scared', '#disgusting', -0.59, 'onslaught', 'battery', 'barrage', 'bombardment', 'outpouring']
senticnet['aromatize'] = [0, -0.929, 0, 0.962, '#surprising', '#admirable', 0.63, 'perfumed', 'odoriferous', 'sweet', 'scent', 'odorous']
senticnet['psychical'] = [0.034, 0.161, -0.05, 0.172, '#interesting', '#admirable', 0.106, 'mental', 'mind_power', 'psychologist', 'psychic', 'mind']
senticnet['torso'] = [0.087, -0.041, 0, 0, '#joyful', '#surprising', 0.043, 'hoist', 'control_room', 'utility_case', 'platform_rail', 'forklift']
senticnet['tater'] = [0.532, -0.682, 0, 0.984, '#surprising', '#admirable', 0.733, 'potato', 'white_potato', 'murphy', 'spud', 'chips']
senticnet['knavish'] = [0, -0.811, 0, 0.796, '#surprising', '#admirable', 0.536, 'cunning', 'dodgy', 'guileful', 'crafty', 'tricksy']
senticnet['foxy'] = [0, -0.939, 0, 0.789, '#surprising', '#admirable', 0.576, 'dodgy', 'guileful', 'crafty', 'wily', 'cunning']
senticnet['slaphappy'] = [0.951, -0.895, 0, 0.52, '#joyful', '#surprising', 0.789, 'irresponsible', 'carefree', 'freewheeling', 'unaccountable', 'loose']
senticnet['necessitate'] = [0, 0, 0.813, -0.789, '#angry', '#disgusting', -0.534, 'postulate', 'required', 'take', 'ask', 'need']
senticnet['wipe_out'] = [0, 0, -0.819, -0.995, '#scared', '#disgusting', -0.605, 'annihilate', 'eradicate', 'extinguish', 'eliminate', 'decimated']
senticnet['eye_popping'] = [-0.743, 0, 0, -0.739, '#sad', '#disgusting', -0.494, 'scared', 'fulgurant', 'daze', 'fulgurous', 'dazzling']
senticnet['shrub'] = [0.938, -0.773, 0, 0.944, '#joyful', '#admirable', 0.885, 'bush', 'scarlet_bush', 'scarlet_hamelia', 'hamelia', 'coloradillo']
senticnet['rattlesnake'] = [0, 0.11, 0, 0.077, '#interesting', '#admirable', 0.062, 'snake', 'python', 'reptile', 'animal', 'cobra']
senticnet['utmax'] = [0, 0.075, 0, 0.159, '#interesting', '#admirable', 0.078, 'maximum', 'highest', 'most', 'top', 'max']
senticnet['about'] = [0, 0, -0.725, -0.873, '#scared', '#disgusting', -0.533, 'close_to', 'approximately', 'just_about', 'roughly', 'some']
senticnet['relativity_theory'] = [0.708, -0.934, 0, 0.764, '#surprising', '#admirable', 0.802, 'relativity', 'general_theory_of_relativity', 'general_relativity', 'special_relativity', 'special_theory_of_relativity']
senticnet['roper'] = [0.527, -0.582, 0, 0.784, '#surprising', '#admirable', 0.631, 'slicker', 'beguiler', 'deceiver', 'shill', 'decoy']
senticnet['epizootic'] = [-0.857, 0, 0, -0.982, '#sad', '#disgusting', -0.613, 'infectious', 'communicable', 'epidemic', 'pandemic', 'contagious']
senticnet['stainless'] = [0.513, -0.585, 0, 0.919, '#surprising', '#admirable', 0.672, 'unblemished', 'untainted', 'untarnished', 'unsullied', 'unstained']
senticnet['skating'] = [0.05, -0.043, 0, 0, '#joyful', '#surprising', 0.031, 'skate', 'rollerblade', 'skateboard', 'ice_skate', 'roller_skate']
senticnet['catch_fish_rod'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'fishing', 'catch_fish', 'patience', 'fish_lake', 'bait']
senticnet['oaf'] = [0, 0, -0.756, -0.851, '#scared', '#disgusting', -0.536, 'lummox', 'clod', 'goon', 'stumblebum', 'lout']
senticnet['pine_away'] = [-0.876, 0, -0.955, 0, '#sad', '#scared', -0.61, 'waste', 'ache', 'yearn', 'yen', 'languish']
senticnet['backstair'] = [0, 0, -0.77, -0.712, '#scared', '#disgusting', -0.494, 'furtive', 'surreptitious', 'sneak', 'sneaky', 'stealthy']
senticnet['remoteness'] = [0.72, -0.727, 0, 0.506, '#joyful', '#surprising', 0.651, 'standoffishness', 'withdrawnness', 'closeness', 'secretiveness', 'unsociability']
senticnet['resitence'] = [0, 0, 0, 0.816, '#admirable', '#admirable', 0.272, 'immunity', 'protection', 'untouchable', 'invunerable', 'sacrosanct']
senticnet['preview'] = [0.681, -0.572, 0, 0.632, '#joyful', '#admirable', 0.628, 'movie_star', 'actor', 'entertainer', 'performer', 'actress']
senticnet['outshine'] = [0, 0.95, 0, 0.725, '#interesting', '#admirable', 0.558, 'exceed', 'outshout', 'outstrip', 'outperform', 'outsail']
senticnet['quintessence'] = [0.645, -0.766, 0, 0.961, '#surprising', '#admirable', 0.791, 'content', 'bare_bones', 'stuff', 'essence', 'hypostasis']
senticnet['destitute'] = [-0.915, 0, 0.724, 0, '#sad', '#angry', -0.546, 'impoverished', 'needy', 'necessitous', 'poverty-stricken', 'indigent']
senticnet['snot'] = [0.965, 0.775, 0, 0.968, '#joyful', '#admirable', 0.903, '32_teeth', 'good_taste', 'mouth_part', 'gum', 'near_mouth']
senticnet['extravert'] = [0, 0, -0.852, -0.891, '#scared', '#disgusting', -0.581, 'extrospective', 'forthcoming', 'outgoing', 'extroverted', 'extrovertive']
senticnet['scupper'] = [0, 0, -0.994, -0.726, '#scared', '#disgusting', -0.573, 'ambuscade', 'lurk', 'ambush', 'waylay', 'bushwhack']
senticnet['football_bounce'] = [0.787, 0.899, 0, 0, '#joyful', '#interesting', 0.562, 'ball_bounce', 'bounce', 'ball', 'soccer', 'basketball_bounce']
senticnet['pineapple'] = [0, 0.102, 0.016, 0.076, '#interesting', '#admirable', 0.054, 'cherry', 'tomato', 'plum', 'cranberry', 'apricot']
senticnet['skitter'] = [0, 0, -0.911, -0.998, '#scared', '#disgusting', -0.636, 'scuttle', 'hatchway', 'scamper', 'opening', 'scurry']
senticnet['refreshment'] = [0.789, -0.68, 0, 0.729, '#joyful', '#admirable', 0.733, 'collation', 'nosh', 'coffee_break', 'tea_break', 'meal']
senticnet['bead_cover'] = [0, 0.171, -0.056, 0.102, '#interesting', '#admirable', 0.072, 'bead', 'mattress', 'linen_cupboard', 'bed', 'seduce']
senticnet['overbearing'] = [0, 0, -0.749, -0.932, '#scared', '#disgusting', -0.56, 'imperious', 'haughty', 'disdainful', 'lordly', 'supercilious']
senticnet['subservience'] = [0.875, -0.724, 0, 0.584, '#joyful', '#surprising', 0.728, 'subservientness', 'subordinateness', 'servant', 'handmaid', 'handmaiden']
senticnet['wrest'] = [0.045, 0, 0, 0.051, '#joyful', '#admirable', 0.032, 'perfect_sphere', 'pour_hot_coffee_mug', 'planet_earth', 'alkaline', 'name_planet']
senticnet['accede'] = [0, 0, -0.763, -0.879, '#scared', '#disgusting', -0.547, 'bow_down', 'submit', 'bowed', 'give_in', 'bend']
senticnet['gamey'] = [0, -0.795, 0, 1.0, '#surprising', '#admirable', 0.598, 'spirited', 'mettlesome', 'game', 'gritty', 'gamy']
senticnet['hotel_bathroom_drawerroom'] = [0.042, -0.056, 0, 0, '#joyful', '#surprising', 0.033, 'toilet', 'bathroom_drawerroom', 'beauty_parlor', 'bath', 'bathroom_drawer']
senticnet['steamroller'] = [-0.876, 0, 0, -0.937, '#sad', '#disgusting', -0.604, 'turn_up_heat', 'turn_up_pressure', 'coerce', 'steamroll', 'sandbag']
senticnet['proselytize'] = [0.741, 0.898, 0, 0.734, '#joyful', '#interesting', 0.791, 'plan_trip', 'desire_social_interaction', 'see_different', 'buy_airline_ticket', 'improve_knowledge']
senticnet['prolate'] = [0.969, -0.542, 0, 0.806, '#joyful', '#admirable', 0.772, 'rounded', 'roundedal', 'aspheric', 'auriform', 'crescent']
senticnet['workfighter'] = [0, 0, 0, -0.074, '#disgusting', '#disgusting', -0.025, 'army_fighter', 'army_person', 'sailor', 'fighter', 'man']
senticnet['feel_powerful'] = [0.792, 0, 0, 0.763, '#joyful', '#admirable', 0.518, 'exercise_regularly', 'eat_healthy_diet', 'exercise_much', 'healthy_lifestyle', 'exercise_often']
senticnet['teenager'] = [0.029, 0.076, 0, 0, '#joyful', '#interesting', 0.035, 'youngster', 'adolescent', 'junior', 'lad', 'maturity']
senticnet['smarmy'] = [0, 0, -0.746, -0.795, '#scared', '#disgusting', -0.514, 'buttery', 'oleaginous', 'fulsome', 'unctuous', 'oily']
senticnet['piquant'] = [0, 0, -0.984, -0.991, '#scared', '#disgusting', -0.658, 'savory', 'spicy', 'savoury', 'zestful', 'zesty']
senticnet['glowering'] = [0, 0, -0.835, -0.703, '#scared', '#disgusting', -0.513, 'moody', 'dour', 'glum', 'dark', 'morose']
senticnet['trafficker'] = [0.814, -0.582, 0, 0.646, '#joyful', '#admirable', 0.681, 'seller', 'marketer', 'vender', 'vendor', 'cosmetician']
senticnet['transform'] = [0.033, 0.234, -0.084, 0.274, '#interesting', '#admirable', 0.152, 'change', 'adjust', 'modifier', 'precise', 'versatile']
senticnet['virgin'] = [0.798, -0.519, 0, 0.973, '#joyful', '#admirable', 0.763, 'naif', 'inexperienced_person', 'dear', 'boy_scout', 'mortal']
senticnet['wavering'] = [0.928, -0.834, 0, 0.656, '#joyful', '#surprising', 0.806, 'indecisiveness', 'doubt', 'incertitude', 'dubiety', 'doubtfulness']
senticnet['wireless'] = [0, -0.122, 0.011, 0.089, '#surprising', '#admirable', 0.067, 'cordless', 'telephone', 'cellular_phone', 'connect', 'message']
senticnet['quicksilver'] = [0, 0, -0.895, -0.942, '#scared', '#disgusting', -0.612, 'fickle', 'wandering', 'planetary', 'erratic', 'mercurial']
senticnet['praiseworthiness'] = [0.76, -0.958, 0, 0.506, '#joyful', '#surprising', 0.741, 'goodness', 'laudability', 'worthiness', 'laudableness', 'quotability']
senticnet['sexagenarian'] = [0.556, -0.641, 0, 0.64, '#surprising', '#admirable', 0.612, 'golden_ager', 'nonagenarian', 'octogenarian', 'septuagenarian', 'centenarian']
senticnet['inhaler_technique'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'respiration', 'inhale_oxygen', 'exhale_oxygen', 'external_respiration', 'ventilation']
senticnet['vanquisher'] = [0.556, -0.688, 0, 0.978, '#surprising', '#admirable', 0.741, 'victor', 'conqueror', 'combatant', 'battler', 'belligerent']
senticnet['ablate_thin'] = [-0.976, 0, 0.54, -0.553, '#sad', '#disgusting', -0.69, 'ablate', 'ablate_off', 'ablate_out', 'ablate_down', 'wear']
senticnet['roadless'] = [0, 0, 0.737, -0.897, '#angry', '#disgusting', -0.545, 'outback', 'trackless', 'pathless', 'inaccessible', 'untracked']
senticnet['ice_athletic_game'] = [0.7, -0.798, 0, 0.873, '#surprising', '#admirable', 0.79, 'sport', 'game', 'hockey', 'athletic_game', 'winter_sport']
senticnet['invidious'] = [-0.949, 0, 0, -0.753, '#sad', '#disgusting', -0.567, 'homophobic', 'racist', 'jaundiced', 'antiblack', 'discriminatory']
senticnet['propellant'] = [0.74, -0.755, 0, 0.815, '#surprising', '#admirable', 0.77, 'changing', 'propellent', 'propelling', 'dynamical', 'propulsive']
senticnet['core'] = [0, 0, 0.861, -0.816, '#angry', '#disgusting', -0.559, 'marrow', 'kernel', 'centre', 'pith', 'substance']
senticnet['another_country'] = [0, 0.766, 0, 0, '#interesting', '#interesting', 0.255, 'overseas', 'abroad', 'study_abroad', 'elsewhere', 'live_abroad']
senticnet['tittle-tattle'] = [0, 0, -0.869, -0.97, '#scared', '#disgusting', -0.613, 'prate', 'gibbering', 'palaver', 'piffle', 'chatter']
senticnet['discriminatingal'] = [0.902, -0.855, 0, 0.898, '#joyful', '#admirable', 0.885, 'discerning', 'discriminating', 'diacritic', 'discriminative', 'selective']
senticnet['stated'] = [0.501, -0.996, 0, 0.68, '#surprising', '#admirable', 0.726, 'definitive', 'hardcore', 'declared', 'explicit', 'graphic']
senticnet['sports'] = [0.98, 0, 0, 0.936, '#joyful', '#admirable', 0.639, 'team', 'ball_player', 'player', 'competition', 'teamwork']
senticnet['necessitous'] = [-0.915, 0, 0.724, 0, '#sad', '#angry', -0.546, 'impoverished', 'needy', 'indigent', 'poverty-stricken', 'destitute']
senticnet['tranfer'] = [0.979, 0.93, 0, 0.723, '#joyful', '#interesting', 0.877, 'information_transfer', 'collaborate', 'inform_person', 'inform_others', 'information']
senticnet['airairstrip'] = [-0.975, 0, 0.737, -0.979, '#sad', '#disgusting', -0.897, 'flare_path', 'field', 'landing_airstrip', 'flying_airstrip', 'airstrip']
senticnet['estuary'] = [0.939, -0.877, 0, 0, '#joyful', '#surprising', 0.605, 'bay', 'harpoon', 'gulf', 'lake', 'river']
senticnet['plausive'] = [0.585, 0.652, -0.268, 0.313, '#joyful', '#interesting', 0.427, 'approbative', 'approve', 'approbatory', 'affirmative', 'approved']
senticnet['lustful'] = [0, 0, -0.916, -0.861, '#scared', '#disgusting', -0.592, 'lubricious', 'lewd', 'salacious', 'obscene', 'prurient']
senticnet['transposition'] = [0.898, -0.874, 0, 0.929, '#joyful', '#admirable', 0.9, 'make', 'permutation', 'reversal', 'passing', 'reordering']
senticnet['trunks'] = [0, -0.075, 0, 0, '#surprising', '#surprising', 0.025, 'garage', 'storeroom', 'bicycle_storage_area', 'motor_oil', 'bicycle']
senticnet['puritanic'] = [0.682, -0.559, 0, 0.985, '#joyful', '#admirable', 0.742, 'renunciant', 'renunciative', 'nonindulgent', 'puritanical', 'corrective']
senticnet['swing'] = [0.754, 0, 0, 0.861, '#joyful', '#admirable', 0.538, 'clown', 'juggler', 'acrobat', 'halloween', 'dare']
senticnet['tendon'] = [0.042, 0.146, 0, 0, '#joyful', '#interesting', 0.063, 'skeletal_system', 'main_artery', 'nape', 'artery', 'soul']
senticnet['attentiveness'] = [0, 0, -0.984, -0.838, '#scared', '#disgusting', -0.607, 'heed', 'listen', 'mind', 'paying_attention', 'regard']
senticnet['translatable'] = [0.623, -0.566, 0, 0.974, '#joyful', '#admirable', 0.721, 'commutable', 'convertible', 'alterable', 'transformable', 'transmutable']
senticnet['spinach'] = [0.062, 0.115, 0, 0, '#joyful', '#interesting', 0.059, 'lettuce', 'herb', 'mint', 'baby_flower', 'cabbage']
senticnet['pot'] = [0.997, 0.814, 0, 0, '#joyful', '#interesting', 0.604, 'stove', 'pan', 'spoon', 'thongs', 'cook_tool']
senticnet['pol'] = [0.838, -0.589, 0, 0.945, '#joyful', '#admirable', 0.791, 'national_leader', 'stateswoman', 'politician', 'politico', 'elder_statesman']
senticnet['each_year'] = [0, 0, -0.967, -0.871, '#scared', '#disgusting', -0.613, 'every_year', 'yearbook', 'yearly', 'annually', 'annual']
senticnet['tiger'] = [0, -0.977, 0, 0, '#surprising', '#surprising', 0.326, 'mountain_lion', 'skunk', 'lion', 'cougar', 'lynx']
senticnet['well-fixed'] = [0.874, 0.907, 0, 0, '#joyful', '#interesting', 0.594, 'well-heeled', 'prosperous', 'well-to-do', 'comfortable', 'easy']
senticnet['premature'] = [0, 0, -0.906, -0.995, '#scared', '#disgusting', -0.634, 'wrong', 'prematurely', 'unseasonable', 'untimely', 'ill-timed']
senticnet['shingle'] = [0.952, -0.527, 0, 0.835, '#joyful', '#admirable', 0.771, 'billboard', 'signboard', 'sandwich_board', 'scoreboard', 'hoarding']
senticnet['lamisil_agent'] = [0.932, -0.56, 0, 0.617, '#joyful', '#admirable', 0.703, 'lamisil', 'antifungal', 'fungicide', 'antimycotic', 'antimycotic_agent']
senticnet['ranch'] = [0.037, 0, 0, 0.067, '#joyful', '#admirable', 0.035, 'veal', 'milk_product', 'salad_dress', 'dairy', 'food_group']
senticnet['thermodynamic_process'] = [-0.643, 0, 0.938, -0.521, '#sad', '#angry', -0.701, 'extinction', 'adiabatic_process', 'hardening', 'decay', 'absorption']
senticnet['satin'] = [0.061, 0.128, 0, 0.151, '#interesting', '#admirable', 0.113, 'spool', 'silk', 'velvet', 'cotton', 'web']
senticnet['rose'] = [0.027, 0.093, 0.025, 0.071, '#interesting', '#admirable', 0.055, 'flower', 'love', 'show_love', 'a_lot_of_flowers', 'give_flower']
senticnet['impound'] = [0, 0, -0.787, -0.828, '#scared', '#disgusting', -0.538, 'seize', 'seclude', 'attach', 'sequester', 'confiscate']
senticnet['stand'] = [0.731, 0.729, 0, 0.866, '#joyful', '#admirable', 0.775, 'stand_behind', 'start_move', 'conform', 'able_run', 'go_end']
senticnet['breakwater'] = [0, 0, -0.801, -0.777, '#scared', '#disgusting', -0.526, 'wall', 'mole', 'groin', 'rampart', 'bulwark']
senticnet['serologist'] = [0.904, -0.93, 0, 0.639, '#joyful', '#surprising', 0.824, 'toxicologist', 'medical_scientist', 'immunologist', 'epidemiologist', 'scientist']
senticnet['biochemistry'] = [0, 0.9, 0, 0.719, '#interesting', '#admirable', 0.54, 'adenosine', 'water', 'make_up_water', 'large_body', 'water_spill']
senticnet['coruscant'] = [0, 0, 0.762, -0.835, '#angry', '#disgusting', -0.532, 'glisten', 'scintillating', 'fulgid', 'glittering', 'sparkly']
senticnet['sully'] = [0, 0, -0.788, -0.875, '#scared', '#disgusting', -0.554, 'foul', 'maculated', 'defile', 'tarnish', 'stain']
senticnet['recognise'] = [0, 0, -0.786, -0.872, '#scared', '#disgusting', -0.553, 'spy', 'spotted', 'located', 'recognize', 'descry']
senticnet['trattoria'] = [0.068, 0.066, 0.011, -0.034, '#joyful', '#interesting', 0.03, 'italian_restaurant', 'eat_pizza', 'pizzeria', 'restaurant_diner', 'eatery']
senticnet['non-believer'] = [0, 0.736, 0, 0.836, '#interesting', '#admirable', 0.524, 'atheist', 'doubter', 'agnostic', 'freethinker', 'sceptic']
senticnet['pumpernickel'] = [0.52, -0.693, 0, 0.639, '#surprising', '#admirable', 0.617, 'rye_bread', 'black_bread', 'limpa', 'bread', 'breadstuff']
senticnet['sedulousness'] = [0.799, -0.616, 0, 0.789, '#joyful', '#admirable', 0.735, 'sedulity', 'industriousness', 'assiduity', 'assiduousness', 'studiousness']
senticnet['life_goal'] = [0.717, 0.935, 0, 0, '#joyful', '#interesting', 0.551, 'intention', 'point_weapon', 'aim', 'objective', 'target']
senticnet['unfairness'] = [0.871, -0.748, 0, 0.981, '#joyful', '#admirable', 0.867, 'unrighteousness', 'unjustness', 'inequity', 'wrong', 'wrongfulness']
senticnet['pond'] = [0, 0.087, 0, 0.071, '#interesting', '#admirable', 0.053, 'atlantic_ocean', 'lake', 'pacific_ocean', 'small_lake', 'mere']
senticnet['dentist_chair_bed'] = [0.897, 0, 0, 0.737, '#joyful', '#admirable', 0.545, 'magazine_rack', 'dentist_chair', 'couch', 'sofa', 'mattress']
senticnet['shade'] = [0.946, 0, 0, 0.77, '#joyful', '#admirable', 0.572, 'aviator', 'drive_quickly', 'drive', 'drive_somewhere', 'fast_travel']
senticnet['resorb'] = [0.869, -0.598, 0, 0.66, '#joyful', '#admirable', 0.709, 'assimilate', 'take_up', 'reabsorb', 'absorb', 'imbibe']
senticnet['snarl_up'] = [0, 0, -0.979, -0.728, '#scared', '#disgusting', -0.569, 'entangle', 'tangle', 'snarling', 'snap', 'mat']
senticnet['shipment'] = [0.887, 0.976, 0, 0, '#joyful', '#interesting', 0.621, 'mission', 'expedition', 'delivery', 'consignment', 'dispatch']
senticnet['platitude'] = [0.524, -0.641, 0, 0.675, '#surprising', '#admirable', 0.613, 'truth', 'banality', 'cliche', 'truism', 'commonplace']
senticnet['soapy'] = [0.035, 0, 0, 0.057, '#joyful', '#admirable', 0.031, 'clean_hand', 'clean_product', 'remove_dirt', 'clean_skin', 'cleaner']
senticnet['somniferous'] = [0, 0, -0.757, -0.88, '#scared', '#disgusting', -0.546, 'somnific', 'hypnotic', 'hypnogogic', 'soporific', 'soporiferous']
senticnet['grimy'] = [0, 0, -0.925, -0.825, '#scared', '#disgusting', -0.583, 'raunchy', 'begrimed', 'dingy', 'grubby', 'dirty']
senticnet['hard_up'] = [0, 0, -0.736, -0.741, '#scared', '#disgusting', -0.492, 'pinched', 'in_straitened_circumstances', 'impecunious', 'penniless', 'penurious']
senticnet['hoity-toity'] = [0, 0, -0.89, -0.833, '#scared', '#disgusting', -0.574, 'hifalutin', 'la-di-da', 'highfaluting', 'highfalutin', 'grandiose']
senticnet['egg-shaped'] = [0, 0, -0.929, -0.823, '#scared', '#disgusting', -0.584, 'elliptical', 'oval', 'ovate', 'ovoid', 'prolate']
senticnet['unremarkable'] = [0, 0, -0.85, -0.823, '#scared', '#disgusting', -0.558, 'workaday', 'quotidian', 'routine', 'everyday', 'mundane']
senticnet['stack_brick'] = [0.962, -0.703, 0, 0.522, '#joyful', '#surprising', 0.729, 'brick', 'adobe', 'clinker', 'clinker_brick', 'firebrick']
senticnet['leaf_tree'] = [0.945, -0.849, 0, 0, '#joyful', '#surprising', 0.598, 'stem', 'leaf', 'moss', 'branch', 'evergreen']
senticnet['readjustment'] = [0.667, -0.885, 0, 0.92, '#surprising', '#admirable', 0.824, 'adjustment', 'activity', 'tuning', 'registration', 'calibration']
senticnet['gilded'] = [0.92, 0.879, 0, 0, '#joyful', '#interesting', 0.6, 'luxurious', 'princely', 'opulent', 'grand', 'deluxe']
senticnet['publicity'] = [-0.025, 0.233, -0.076, 0.284, '#interesting', '#admirable', 0.139, 'make', 'creation', 'creationism', 'fabricate', 'create_form']
senticnet['knee_trunk_hose'] = [-0.589, 0, 0.757, -0.679, '#angry', '#disgusting', -0.675, 'trunk_hose', 'breeches', 'knee_pants', 'knickerbockers', 'knickers']
senticnet['costless'] = [0, -0.854, 0, 0.991, '#surprising', '#admirable', 0.615, 'free', 'gratis', 'gratuitous', 'for_free', 'complimentary']
senticnet['somnific'] = [0, 0, -0.757, -0.88, '#scared', '#disgusting', -0.546, 'soporific', 'hypnotic', 'hypnogogic', 'somniferous', 'soporiferous']
senticnet['greater_chickweed'] = [-0.642, 0, 0.555, -0.627, '#sad', '#disgusting', -0.608, 'herb', 'common_chickweed', 'chickweed', 'stitchwort', 'starwort']
senticnet['holocene_epoch'] = [0.842, 0.898, 0, 0, '#joyful', '#interesting', 0.58, 'holocene', 'recent_epoch', 'recent', 'late', 'new']
senticnet['nipping'] = [0, 0, -0.915, -0.823, '#scared', '#disgusting', -0.579, 'barbed', 'biting', 'acrid', 'mordacious', 'pungent']
senticnet['referee'] = [0.032, -0.009, 0, 0.09, '#joyful', '#admirable', 0.044, 'umpire', 'croquet', 'equestrian_sport', 'backgammon', 'traffic_control']
senticnet['frantic'] = [0, 0, -0.736, -0.83, '#scared', '#disgusting', -0.522, 'hallucinating', 'excited', 'delirious', 'mad', 'unrestrained']
senticnet['seize'] = [0, 0, -0.787, -0.828, '#scared', '#disgusting', -0.538, 'sequester', 'seclude', 'attach', 'impound', 'confiscate']
senticnet['resuscitated'] = [0.673, -0.95, 0, 0.914, '#surprising', '#admirable', 0.846, 'renewed', 'revitalized', 'resurgent', 'renascent', 'revived']
senticnet['autographion'] = [0, 0, 0, 0.082, '#admirable', '#admirable', 0.027, 'autograph', 'communication', 'communicate_person', 'talk_another_person', 'discuss']
senticnet['love_affair'] = [-0.777, 0, 0.965, 0, '#sad', '#angry', -0.581, 'intrigue', 'affair', 'divorce', 'betrayal', 'adultery']
senticnet['pollen'] = [0.081, -0.032, 0, 0, '#joyful', '#surprising', 0.038, 'blossom', 'bloom', 'bouquet', 'poppy', 'many_plants']
senticnet['politesse'] = [0.603, -0.987, 0, 0.648, '#surprising', '#admirable', 0.746, 'urbanity', 'niceness', 'politeness', 'good_manners', 'gallantry']
senticnet['sandhopper'] = [0.96, -0.772, 0, 0.929, '#joyful', '#admirable', 0.887, 'whale_louse', 'beach_flea', 'sand_hopper', 'amphipod', 'sand_flea']
senticnet['vendor'] = [0.025, -0.062, 0, 0.135, '#surprising', '#admirable', 0.074, 'grocery', 'groceries', 'fresh_vegetable', 'cold_drink', 'goods']
senticnet['moody'] = [0, 0, -0.835, -0.703, '#scared', '#disgusting', -0.513, 'morose', 'dour', 'glum', 'dark', 'glowering']
senticnet['vasoconstrictor'] = [0.887, -0.9, 0, 0.852, '#joyful', '#surprising', 0.88, 'pressor', 'phenylephrine', 'phenylpropanolamine', 'adrenergic', 'vasoconstrictive']
senticnet['porridge'] = [0.062, 0, 0.027, 0.055, '#joyful', '#admirable', 0.03, 'appetizer', 'meal', 'broth', 'hamburger', 'hearty']
senticnet['aloft'] = [0.75, 0, 0, 0.971, '#joyful', '#admirable', 0.574, 'high', 'superior', 'above', 'above_all', 'atop']
senticnet['dormant'] = [-0.963, 0, -0.848, 0, '#sad', '#scared', -0.604, 'soggy', 'torpid', 'inert', 'sluggish', 'hibernating']
senticnet['remit'] = [0, 0, 0.728, -0.861, '#angry', '#disgusting', -0.53, 'diminish', 'taper', 'drop_off', 'contract', 'break']
senticnet['wrestle'] = [0, 0, -0.945, -0.91, '#scared', '#disgusting', -0.618, 'wriggle', 'writhing', 'squirm', 'worm', 'writhe']
senticnet['free-spoken'] = [0, 0.899, 0, 0.779, '#interesting', '#admirable', 0.559, 'forthright', 'plainspoken', 'outspoken', 'blunt', 'candid']
senticnet['breathing'] = [0.898, 0.88, 0, 0, '#joyful', '#interesting', 0.593, 'exercise', 'catch_breath', 'relax', 'rest_up', 'regain_energy']
senticnet['spool'] = [0.061, 0.128, 0, 0.151, '#interesting', '#admirable', 0.113, 'web', 'silk', 'velvet', 'cotton', 'satin']
senticnet['spoof'] = [0, 0, 0.79, -0.834, '#angry', '#disgusting', -0.541, 'mockery', 'parody', 'burlesque', 'lampoon', 'sendup']
senticnet['pleat'] = [0.688, -0.733, 0, 0.955, '#surprising', '#admirable', 0.792, 'angular_shape', 'angularity', 'ruck', 'pucker', 'crimp']
senticnet['abominable'] = [0, 0, 0.808, -0.779, '#angry', '#disgusting', -0.529, 'monster', 'wild_man', 'orang_pendek', 'yeti', 'abominable_snowman']
senticnet['batty'] = [0, -0.96, 0, 0.721, '#surprising', '#admirable', 0.56, 'nutlike', 'balmy', 'bats', 'barmy', 'nutty']
senticnet['rhombus'] = [0, 0.917, 0, 0.901, '#interesting', '#admirable', 0.606, 'square', 'four_sides', 'rectangle', 'four_corners', 'cube']
senticnet['vinification'] = [0.833, -0.507, 0, 0.519, '#joyful', '#admirable', 0.62, 'zymosis', 'top_fermentation', 'bottom_fermentation', 'chemical_process', 'chemical_change']
senticnet['parlous'] = [0, 0, -0.842, -0.92, '#scared', '#disgusting', -0.587, 'unstable', 'precarious', 'perilous', 'touch-and-go', 'shaky']
senticnet['announce'] = [0, 0, -0.773, -0.981, '#scared', '#disgusting', -0.585, 'forerunner', 'harbingers', 'precursor', 'predecessor', 'herald']
senticnet['supplication'] = [0.638, -0.838, 0, 0.852, '#surprising', '#admirable', 0.776, 'blessing', 'grace', 'commination', 'orison', 'benediction']
senticnet['bad_egg_food'] = [-0.931, 0, 0.238, -0.904, '#sad', '#disgusting', -0.691, 'bad_egg', 'poisoning', 'bad_taste', 'spoil', 'expired']
senticnet['buy_cartoon_character'] = [-0.073, 0, 0, -0.074, '#sad', '#disgusting', -0.049, 'cartoon_character', 'use_tool', 'mould', 'use_oil_cartoon_character', 'paint']
senticnet['glisten'] = [0, 0, 0.762, -0.835, '#angry', '#disgusting', -0.532, 'glittering', 'scintillating', 'fulgid', 'coruscant', 'sparkly']
senticnet['glister'] = [0.799, 0, 0, 0.897, '#joyful', '#admirable', 0.565, 'brightness', 'blaze', 'brilliance', 'glitter', 'glare']
senticnet['shell'] = [0.203, 0.077, 0, 0.189, '#joyful', '#admirable', 0.156, 'sea_shell', 'coast', 'seaside', 'sediment', 'sane']
senticnet['unemotionalal'] = [-0.893, 0, 0.797, -0.958, '#sad', '#disgusting', -0.883, 'unemotional', 'phlegmatic', 'unblinking', 'stoic', 'chilly']
senticnet['see'] = [0.862, -0.611, 0, 0.549, '#joyful', '#surprising', 0.674, 'consider', 'view', 'regard', 'reckon', 'deem']
senticnet['find_library_human'] = [-0.051, -0.034, -0.051, 0, '#sad', '#scared', -0.023, 'read', 'find_library', 'make_paper', 'pick_tooth', 'illuminate_area']
senticnet['cracking'] = [0.876, 0.733, 0, 0, '#joyful', '#interesting', 0.536, 'bang-up', 'dandy', 'corking', 'nifty', 'bully']
senticnet['sceptical'] = [0, 0, -0.969, -0.908, '#scared', '#disgusting', -0.626, 'doubting', 'wary', 'distrustful', 'skeptical', 'overjealous']
senticnet['stove'] = [0.997, 0.814, 0, 0, '#joyful', '#interesting', 0.604, 'cook_tool', 'pan', 'spoon', 'thongs', 'pot']
senticnet['encyclopedism'] = [0.758, 0, 0, 0.939, '#joyful', '#admirable', 0.566, 'erudition', 'learning', 'scholarship', 'learnedness', 'eruditeness']
senticnet['miscellany'] = [0, 0.839, 0, 0.912, '#interesting', '#admirable', 0.584, 'smorgasbord', 'assortment', 'mixture', 'miscellanea', 'mixed_bag']
senticnet['inventive'] = [0.724, 0, 0, 0.783, '#joyful', '#admirable', 0.502, 'idealist', 'inspired', 'imaginative', 'creative', 'visionary']
senticnet['enamour'] = [0.708, 0.862, 0, 0, '#joyful', '#interesting', 0.523, 'capture', 'charming', 'trance', 'catch', 'becharm']
senticnet['postponement'] = [0.976, -0.719, 0, 0.863, '#joyful', '#admirable', 0.853, 'hold', 'delay', 'wait', 'time_lag', 'moratorium']
senticnet['wall'] = [0, -0.916, 0, 0.984, '#surprising', '#admirable', 0.633, 'finite', 'limited', 'finite_state_machine', 'bounded', 'boundary']
senticnet['walk'] = [0.759, -0.767, 0, 0.878, '#surprising', '#admirable', 0.801, 'remember_oneself', 'move', 'assert_oneself', 'comport', 'act']
senticnet['rusty'] = [0, 0, -0.86, -0.799, '#scared', '#disgusting', -0.553, 'gray-haired', 'gray', 'hoary', 'canescent', 'grizzly']
senticnet['crappy'] = [0, 0, -0.877, -0.998, '#scared', '#disgusting', -0.625, 'icky', 'rotten', 'lousy', 'stinking', 'shitty']
senticnet['value_for_money'] = [0, 0.219, -0.05, 0.144, '#interesting', '#admirable', 0.104, 'price', 'value', 'amount_charge', 'amount', 'item_worth']
senticnet['gimpy'] = [0, 0, 0.868, -0.708, '#angry', '#disgusting', -0.525, 'lame', 'feeble', 'crippled', 'square', 'halt']
senticnet['smith'] = [0, 0.115, 0, 0.105, '#interesting', '#admirable', 0.073, 'farrier', 'miner', 'horseshoer', 'locksmith', 'blacksmith']
senticnet['putative'] = [0.683, -0.553, 0, 0.552, '#joyful', '#surprising', 0.596, 'acknowledged', 'recognized', 'declarable', 'given', 'accepted']
senticnet['universe'] = [0.84, 0.852, 0, 0, '#joyful', '#interesting', 0.564, 'room', 'space', 'capacity', 'house', 'a_lot_of_space']
senticnet['boggy'] = [0, 0, -0.796, -0.935, '#scared', '#disgusting', -0.577, 'marshy', 'mucky', 'muddy', 'soggy', 'miry']
senticnet['cocker'] = [0, 0, -0.73, -0.945, '#scared', '#disgusting', -0.558, 'coddle', 'baby', 'cosset', 'featherbed', 'pamper']
senticnet['woolgathering'] = [0.846, -0.928, 0, 0.504, '#joyful', '#surprising', 0.759, 'daydreaming', 'revery', 'daydream', 'reverie', 'dreaming']
senticnet['learnedness'] = [0.758, 0, 0, 0.939, '#joyful', '#admirable', 0.566, 'encyclopedism', 'learning', 'scholarship', 'erudition', 'eruditeness']
senticnet['unchewable'] = [0, -0.877, 0, 0.779, '#surprising', '#admirable', 0.552, 'fibrous', 'tendinous', 'stringy', 'sinewy', 'brawny']
senticnet['art_of_transmuting_metal'] = [0, 0.795, 0, 0.796, '#interesting', '#admirable', 0.53, 'servant', 'alchemist', 'stone', 'alchemy', 'philosopher']
senticnet['wizardry'] = [0.703, -0.593, 0, 0.739, '#joyful', '#admirable', 0.678, 'fruitfulness', 'genius', 'fecundity', 'ability', 'creative_thinking']
senticnet['turpitude'] = [0, 0, -0.715, -0.7, '#scared', '#disgusting', -0.472, 'depravity', 'putrefaction', 'corruption', 'depravation', 'degeneracy']
senticnet['swag'] = [0, 0, -0.749, -0.89, '#scared', '#disgusting', -0.546, 'booty', 'loot', 'plunder', 'pillage', 'prize']
senticnet['untie'] = [0.507, -0.507, 0, 0.676, '#joyful', '#surprising', 0.563, 'unlace', 'unfold', 'undo', 'unbrace', 'spread']
senticnet['playboy'] = [0.06, 0.422, -0.177, 0.41, '#interesting', '#admirable', 0.238, 'safe_sex', 'meet_girl', 'prevention', 'use_condom', 'dirty_magazine']
senticnet['sandblast'] = [0.957, -0.576, 0, 0.857, '#joyful', '#admirable', 0.797, 'gust', 'puff', 'bluster', 'puff_of_air', 'whiff']
senticnet['traditionality'] = [0.646, -0.924, 0, 0.816, '#surprising', '#admirable', 0.795, 'conventionality', 'traditionalism', 'orthodoxy', 'conventionalism', 'unoriginality']
senticnet['gameness'] = [-0.724, 0, 0, -0.915, '#sad', '#disgusting', -0.546, 'gimpiness', 'lameness', 'claudication', 'gimp', 'limping']
senticnet['walmart'] = [0, 0.092, 0.016, 0.074, '#interesting', '#admirable', 0.05, 'beach_bag', 'drugstore', 'own_bathroom', 'pharmacy', 'car_trunk']
senticnet['partner_in_crime'] = [0, 0, -0.863, -0.752, '#scared', '#disgusting', -0.538, 'crime', 'murder', 'fellow_conspirator', 'accomplice', 'offence']
senticnet['walloper'] = [0.68, -0.861, 0, 0.72, '#surprising', '#admirable', 0.754, 'whopper', 'white_lie', 'jactitation', 'prevarication', 'fib']
senticnet['prim'] = [0, 0, 0.929, -0.876, '#angry', '#disgusting', -0.602, 'prissy', 'puritanical', 'priggish', 'prudish', 'square-toed']
senticnet['twee'] = [0.614, -0.959, 0, 0.537, '#joyful', '#surprising', 0.703, 'mincing', 'gentlemanlike', 'refined', 'gentlemanly', 'ladylike']
senticnet['sapphism'] = [0.807, -0.88, 0, 0.718, '#joyful', '#surprising', 0.802, 'sex', 'inversion', 'sexual_inversion', 'lesbianism', 'gayness']
senticnet['rolled'] = [0.612, -0.536, 0, 0.532, '#joyful', '#surprising', 0.56, 'convoluted', 'convolute', 'involute', 'coiled', 'wound']
senticnet['askew'] = [-0.889, 0, -0.758, 0, '#sad', '#scared', -0.549, 'skew-whiff', 'awry', 'wonky', 'lopsided', 'cockeyed']
senticnet['take_stock'] = [0, 0, -0.705, -0.763, '#scared', '#disgusting', -0.489, 'scrutinise', 'inspect', 'size_up', 'scrutinize', 'audit']
senticnet['swinish'] = [-0.9, 0, -0.997, 0, '#sad', '#scared', -0.632, 'neandertal', 'loutish', 'boorish', 'oafish', 'neanderthal']
senticnet['zestful'] = [0, 0, -0.984, -0.991, '#scared', '#disgusting', -0.658, 'savory', 'spicy', 'savoury', 'zesty', 'piquant']
senticnet['player'] = [0.98, 0, 0, 0.936, '#joyful', '#admirable', 0.639, 'team', 'sports', 'ball_player', 'competition', 'teamwork']
senticnet['hokey'] = [0, 0, -0.753, -0.986, '#scared', '#disgusting', -0.58, 'kitschy', 'mawkish', 'drippy', 'maudlin', 'bathetic']
senticnet['remedial'] = [0.618, -0.604, 0, 0.747, '#joyful', '#admirable', 0.656, 'corrective', 'ameliorating', 'bettering', 'ameliorative', 'amelioratory']
senticnet['ruffled'] = [0.613, -0.532, 0, 0.932, '#joyful', '#admirable', 0.692, 'buttony', 'adorned', 'fringed', 'tessellated', 'mounted']
senticnet['preeminence'] = [0.594, -0.688, 0, 0.957, '#surprising', '#admirable', 0.746, 'high_status', 'eminence', 'senior_status', 'higher_status', 'higher_rank']
senticnet['shrivelled'] = [0, 0, -0.932, -0.818, '#scared', '#disgusting', -0.583, 'sear', 'withered', 'dried-up', 'sere', 'shriveled']
senticnet['nonhumanal'] = [-0.939, 0, 0.508, -0.582, '#sad', '#disgusting', -0.676, 'inhuman', 'bloodless', 'apelike', 'nonhuman', 'anthropoid']
senticnet['curvaceous'] = [0, 0, -0.749, -0.756, '#scared', '#disgusting', -0.502, 'bosomy', 'busty', 'buxom', 'curvy', 'full-bosomed']
senticnet['yen'] = [-0.876, 0, -0.955, 0, '#sad', '#scared', -0.61, 'waste', 'ache', 'yearn', 'languish', 'pine_away']
senticnet['demode'] = [0, 0, -0.841, -0.882, '#scared', '#disgusting', -0.574, 'old_hat', 'old-fashioned', 'old', 'outmoded', 'antique']
senticnet['dead_soule'] = [-0.793, 0, 0.885, -0.768, '#sad', '#angry', -0.815, 'infernal', 'mortal', 'dead_soul', 'zombi', 'living_dead']
senticnet['telepathist'] = [0.9, -0.882, 0, 0.687, '#joyful', '#surprising', 0.823, 'escapologist', 'escape_expert', 'mind_reader', 'conjurer', 'performer']
senticnet['utterer'] = [0.727, -0.622, 0, 0.57, '#joyful', '#surprising', 0.64, 'conversational_partner', 'deipnosophist', 'interlocutor', 'conversationalist', 'speaker']
senticnet['make_make_clothes'] = [0, -0.04, 0.126, -0.054, '#angry', '#disgusting', -0.047, 'make_shirt', 'cloth', 'make_cloth', 'article_make_clothes', 'apparel']
senticnet['rolling'] = [0.732, -0.829, 0, 0, '#joyful', '#surprising', 0.52, 'extensive', 'sweeping', 'expansive', 'spacious', 'open']
senticnet['netlike'] = [0, 0, -0.839, -0.759, '#scared', '#disgusting', -0.533, 'netted', 'net', 'lacy', 'webbed', 'weblike']
senticnet['slope'] = [0.037, 0.096, 0, 0.063, '#interesting', '#admirable', 0.065, 'house_roof', 'incline', 'slant', 'ramp', 'mountain_side']
senticnet['shmoose'] = [0.651, -0.929, 0, 0.657, '#surprising', '#admirable', 0.746, 'schmooze', 'schmoose', 'shmooze', 'chew_fat', 'jawbone']
senticnet['reclusive'] = [0, 0, -0.728, -0.763, '#scared', '#disgusting', -0.497, 'solitary', 'troglodyte', 'hermit', 'recluse', 'solitudinarian']
senticnet['wriggle'] = [0, 0, -0.945, -0.91, '#scared', '#disgusting', -0.618, 'writhing', 'wrestle', 'squirm', 'worm', 'writhe']
senticnet['radish'] = [0.065, 0, 0.011, 0.051, '#joyful', '#admirable', 0.035, 'fruit_vegetable', 'fruit', 'fresh_fruit', 'turnip', 'fresh_vegetable']
senticnet['purblind'] = [-0.949, 0, -0.808, 0, '#sad', '#scared', -0.586, 'dense', 'obtuse', 'dull', 'dumb', 'dim']
senticnet['filmy'] = [0, 0, -0.994, -0.974, '#scared', '#disgusting', -0.656, 'gauze-like', 'diaphanous', 'gauzy', 'gossamer', 'see-through']
senticnet['refrain'] = [0.93, 0, 0, 0, '#joyful', '#joyful', 0.31, 'like_poetry', 'rhyme', 'song_lyric', 'greet_card', 'musical_notation']
senticnet['typicality'] = [0.798, -0.517, 0, 0.519, '#joyful', '#admirable', 0.611, 'normalcy', 'commonness', 'expectedness', 'averageness', 'condition']
senticnet['noteworthy'] = [0.991, 0, 0, 0.751, '#joyful', '#admirable', 0.581, 'deserve', 'valuable', 'applaudable', 'meritable', 'sacred']
senticnet['derive'] = [0, 0, -0.913, -0.829, '#scared', '#disgusting', -0.581, 'generalize', 'extrapolate', 'deduce', 'infer', 'guess']
senticnet['seventy'] = [0, -0.974, 0, 0.813, '#surprising', '#admirable', 0.596, 'compact_disc', 'music_storage', 'store_music', 'cd-rom', 'cassette']
senticnet['domestibig_cate_animal'] = [0.028, 0, 0.013, 0.061, '#joyful', '#admirable', 0.025, 'cute_big_cat', 'cat', 'big_cat', 'big_animal', 'big']
senticnet['spanish'] = [0.045, 0, 0.033, 0.089, '#joyful', '#admirable', 0.034, 'composition', 'vocalization', 'verbal_communication', 'vocal', 'mouth_noise']
senticnet['mindfulness'] = [0.781, 0, 0, 0.767, '#joyful', '#admirable', 0.516, 'solicitousness', 'solicitous', 'solicitously', 'solicitude', 'consideration']
senticnet['polemic'] = [-0.856, 0, 0.749, -0.998, '#sad', '#disgusting', -0.868, 'controversial', 'contentious', 'disputable', 'disputed', 'arguable']
senticnet['prestigious'] = [0.923, -0.546, 0, 0.633, '#joyful', '#admirable', 0.701, 'important', 'authoritative', 'powerful', 'influential', 'potent']
senticnet['say'] = [0.565, -0.738, 0, 0.542, '#joyful', '#surprising', 0.615, 'asseverate', 'aver', 'predicate', 'insist', 'take_firm_stand']
senticnet['uncontrolledal'] = [-0.891, 0, 0.678, -0.62, '#sad', '#angry', -0.73, 'undisciplined', 'uncontrolled', 'anarchic', 'irrepressible', 'uncontrollable']
senticnet['janus-faced'] = [0, 0, -0.901, -0.703, '#scared', '#disgusting', -0.535, 'duplicitous', 'deceitful', 'double-dealing', 'ambidextrous', 'two-handed']
senticnet['roadside'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'path', 'car_path', 'trail', 'intersection', 'under_bridge']
senticnet['salt'] = [0.64, -0.579, 0, 0.838, '#joyful', '#admirable', 0.686, 'sand', 'find_treasure', 'grain_sand', 'silica', 'sand_rock']
senticnet['slot'] = [0, 0.083, 0, 0, '#interesting', '#interesting', 0.028, 'diskette', 'box', 'load_dock', 'safe_deposit_box', 'emporium']
senticnet['slop'] = [0.825, -0.916, 0, 0.626, '#joyful', '#surprising', 0.789, 'treacle', 'glop', 'mush', 'formulation', 'sentimentalism']
senticnet['towboat'] = [0, 0, 0, 0.069, '#admirable', '#admirable', 0.023, 'trailer', 'trail_car', 'camion', 'wagon', 'tow_truck']
senticnet['ultranationalistic'] = [0.585, -0.7, 0, 0.586, '#surprising', '#admirable', 0.624, 'jingoistic', 'chauvinistic', 'superpatriotic', 'nationalistic', 'patriotic']
senticnet['farcical'] = [0, 0, 0.817, -0.789, '#angry', '#disgusting', -0.535, 'ridiculous', 'cockeyed', 'derisory', 'absurd', 'ludicrous']
senticnet['testimonial'] = [0.561, -0.793, 0, 0.89, '#surprising', '#admirable', 0.748, 'superlative', 'compliment', 'congratulations', 'good_word', 'approval']
senticnet['ethical'] = [0.739, 0.995, 0, 0, '#joyful', '#interesting', 0.578, 'honorable', 'honest', 'good', 'estimable', 'fair']
senticnet['twisty'] = [0, 0, -0.795, -0.772, '#scared', '#disgusting', -0.522, 'winding', 'tortuous', 'copious', 'twisting', 'voluminous']
senticnet['joyousurous'] = [0.79, 0, 0, 0.71, '#joyful', '#admirable', 0.5, 'joyful', 'ecstatic', 'enjoyousured', 'rapt', 'joyous']
senticnet['excogitate'] = [0, 0, -0.895, -0.944, '#scared', '#disgusting', -0.613, 'meditate', 'reflecting', 'ponder', 'think_over', 'chew_over']
senticnet['summer'] = [0.759, 0, 0, 0, '#joyful', '#joyful', 0.253, 'get_tan', 'enjoy_sun', 'sit_on_beach', 'sunshine', 'dry_clothes']
senticnet['rake'] = [-0.044, 0.15, -0.069, 0.077, '#interesting', '#admirable', 0.038, 'green_thumb', 'prune', 'water', 'sow', 'work_in_garden']
senticnet['sleepless'] = [0.805, -0.671, 0, 0.901, '#joyful', '#admirable', 0.792, 'vigilant', 'wakeful', 'watchful', 'fly', 'lidless']
senticnet['pushy'] = [0.913, -0.833, 0, 0.739, '#joyful', '#surprising', 0.828, 'pushful', 'ambitious', 'aspirant', 'aspiring', 'wishful']
senticnet['stone'] = [0, 0.795, 0, 0.796, '#interesting', '#admirable', 0.53, 'servant', 'art_of_transmuting_metal', 'alchemist', 'alchemy', 'philosopher']
senticnet['slender'] = [0, 0, -0.926, -0.837, '#scared', '#disgusting', -0.588, 'sylphlike', 'supple', 'lissom', 'lithe', 'svelte']
senticnet['wade'] = [0.817, 0, 0, 0.764, '#joyful', '#admirable', 0.527, 'splash', 'traveling_water', 'drown', 'catch_shark', 'catch_catfish']
senticnet['racquet'] = [0.028, -0.006, 0, 0.096, '#joyful', '#admirable', 0.043, 'action_figure', 'toy_car', 'game_card', 'toy_marble', 'yo-yo']
senticnet['plucky'] = [0, 0, -0.887, -0.891, '#scared', '#disgusting', -0.593, 'touchy', 'spunky', 'feisty', 'thin-skinned', 'huffy']
senticnet['unfearing'] = [0.468, 0.661, -0.252, 0.231, '#joyful', '#interesting', 0.369, 'gratefully', 'gratefulness', 'appreciativeness', 'thankfulness', 'appreciatively']
senticnet['awry'] = [-0.889, 0, -0.758, 0, '#sad', '#scared', -0.549, 'skew-whiff', 'lopsided', 'wonky', 'askew', 'cockeyed']
senticnet['absolute_vodka'] = [0, 0, 0.722, -0.9, '#angry', '#disgusting', -0.541, 'ethyl_alcohol', 'spirits_of_wine', 'absolute_alcohol', 'fermentation_alcohol', 'grain_alcohol']
senticnet['rescuer'] = [0.88, 0, 0, 0.883, '#joyful', '#admirable', 0.588, 'succorer', 'saver', 'salvager', 'salvor', 'reedemer']
senticnet['odourise'] = [0, -0.79, 0, 0.889, '#surprising', '#admirable', 0.56, 'nose', 'scented', 'perfume', 'wind', 'odorize']
senticnet['scattergood'] = [0.87, -0.937, 0, 0.831, '#joyful', '#surprising', 0.879, 'spendthrift', 'waster', 'wastrel', 'spender', 'prodigal']
senticnet['almost_always_poetry'] = [-0.046, 0, -0.116, 0, '#sad', '#scared', -0.054, 'almost_always', 'many_almost_alwayss', 'almost_always_genre', 'saga', 'book']
senticnet['undecided'] = [0.778, -0.502, 0, 0.517, '#joyful', '#admirable', 0.599, 'on_fence', 'suspensive', 'hesitant', 'indecisive', 'hesitating']
senticnet['revealing'] = [0.795, -0.977, 0, 0.679, '#joyful', '#surprising', 0.817, 'informatory', 'consultative', 'consultatory', 'consultive', 'advisory']
senticnet['rootbound'] = [0.59, -0.967, 0, 0.785, '#surprising', '#admirable', 0.781, 'tangled', 'intermeshed', 'enmeshed', 'matted', 'knotty']
senticnet['vip'] = [0, 0, 0, 0.861, '#admirable', '#admirable', 0.287, 'come_out', 'debut', 'become_famous', 'become_known', 'admit']
senticnet['take_asleep'] = [0.929, -0.928, 0, 0, '#joyful', '#surprising', 0.619, 'lie_back', 'feel_little_tired', 'asleep', 'laze', 'nap']
senticnet['blarney'] = [0, 0, -0.925, -0.823, '#scared', '#disgusting', -0.583, 'wheedle', 'sweet-talk', 'cajole', 'palaver', 'coax']
senticnet['uncoerced'] = [0.729, 0.974, 0, 0, '#joyful', '#interesting', 0.568, 'unforced', 'leave', 'bequeath', 'volition', 'willing']
senticnet['flutter'] = [0, 0, 0.78, -0.831, '#angry', '#disgusting', -0.537, 'aflicker', 'quiver', 'flitter', 'flickering', 'waver']
senticnet['army_fighter'] = [0, 0, 0, -0.074, '#disgusting', '#disgusting', -0.025, 'man', 'army_person', 'sailor', 'fighter', 'workfighter']
senticnet['tranquilizer_drug'] = [-0.866, 0, 0.646, -0.888, '#sad', '#disgusting', -0.8, 'minor_tranquilizer', 'put_to_sleep', 'antianxiety_drug', 'tranquilizer', 'anxiolytic']
senticnet['pear-shaped'] = [-0.958, 0, -0.93, 0, '#sad', '#scared', -0.629, 'weighty', 'rotund', 'corpulent', 'obese', 'round']
senticnet['respire'] = [0.822, -0.88, 0, 0.591, '#joyful', '#surprising', 0.764, 'expire', 'inspire', 'breathe', 'yawn', 'hyperventilate']
senticnet['theodicy'] = [0.664, -0.577, 0, 0.981, '#joyful', '#admirable', 0.741, 'theology', 'homiletics', 'discipline', 'study', 'subject']
senticnet['demand_infant_feeding'] = [-0.802, 0, 0.724, -0.706, '#sad', '#angry', -0.744, 'nursing', 'schedule_infant_feeding', 'feeding', 'breast_infant_feeding', 'infant_feeding']
senticnet['inauthentic'] = [0, 0, -0.826, -0.903, '#scared', '#disgusting', -0.576, 'misbegotten', 'spurious', 'misbegot', 'bastardly', 'specious']
senticnet['sybaritic'] = [0.558, -0.905, 0, 0.736, '#surprising', '#admirable', 0.733, 'luxurious', 'luxuriant', 'indulgent', 'voluptuary', 'gay']
senticnet['purposeful'] = [0.738, -0.525, 0, 0.775, '#joyful', '#admirable', 0.679, 'significant', 'meaning', 'meaningful', 'substantive', 'pregnant']
senticnet['exhale_oxygen'] = [0.686, 0.526, 0, 0.812, '#joyful', '#admirable', 0.675, 'respiration', 'inhale_oxygen', 'external_respiration', 'inhaler_technique', 'ventilation']
senticnet['preciousness'] = [0.902, -0.726, 0, 0.919, '#joyful', '#admirable', 0.849, 'costliness', 'expensiveness', 'dearness', 'cost', 'lavishness']
senticnet['bespeckle'] = [0, 0, -0.994, -0.915, '#scared', '#disgusting', -0.636, 'specked', 'flecked', 'stipple', 'dotted', 'speckled']
senticnet['sacrilege'] = [-0.919, 0, 0, -0.75, '#sad', '#disgusting', -0.556, 'irreverence', 'disrespect', 'apostasy', 'atheism', 'impiety']
senticnet['proclaim'] = [0.79, -0.973, 0, 0.689, '#joyful', '#surprising', 0.817, 'laud', 'extol', 'exalt', 'glorify', 'ensky']
senticnet['rivet'] = [0.619, -0.828, 0, 0.854, '#surprising', '#admirable', 0.767, 'focus', 'pore', 'engross', 'concentrate', 'center']
senticnet['disallow'] = [0, 0, -0.917, -0.908, '#scared', '#disgusting', -0.608, 'forbid', 'prohibit', 'veto', 'proscribe', 'interdict']
senticnet['scottish'] = [0, -0.886, 0, 0.93, '#surprising', '#admirable', 0.605, 'score', 'economical', 'scotch_whiskey', 'spoil', 'scotch']
senticnet['full_flag_officer'] = [0.688, -0.908, 0, 0.877, '#surprising', '#admirable', 0.824, 'fleet_flag_officer', 'rear_flag_officer', 'flag_officer', 'admiral', 'vice_flag_officer']
senticnet['pound'] = [0, 0.108, 0.029, 0.09, '#interesting', '#admirable', 0.056, 'quantity', 'amount', 'rate', 'a_lot', 'allotment']
senticnet['reachable'] = [0.859, -0.81, 0, 0.615, '#joyful', '#surprising', 0.761, 'get_table', 'approachable', 'accessible', 'handy', 'ready_to_hand']
senticnet['standoffishness'] = [0.72, -0.727, 0, 0.506, '#joyful', '#surprising', 0.651, 'unsociability', 'withdrawnness', 'closeness', 'secretiveness', 'remoteness']
senticnet['strikingness'] = [0.55, -0.742, 0, 0.81, '#surprising', '#admirable', 0.701, 'prominence', 'glare', 'salience', 'saliency', 'standing']
senticnet['unto'] = [0, 0.21, -0.113, 0.345, '#interesting', '#admirable', 0.147, 'direction', 'go_toward', 'forehead', 'upon', 'toward']
senticnet['crying'] = [0, 0, 0.88, -0.916, '#angry', '#disgusting', -0.599, 'flagrant', 'egregious', 'glaring', 'gross', 'rank']
senticnet['out-and-out'] = [0, 0, -0.915, -0.718, '#scared', '#disgusting', -0.544, 'absolute', 'downright', 'rank', 'right-down', 'sheer']
senticnet['sbanter'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'witty_remark', 'cross_talking', 'wordplay', 'banter', 'jester']
senticnet['repair'] = [0.035, 0.083, 0, 0.128, '#interesting', '#admirable', 0.082, 'woodworking', 'sailing', 'workshop', 'build_boat', 'expensive']
senticnet['paraprofessionalal'] = [-0.697, 0, 0.659, -0.696, '#sad', '#disgusting', -0.684, 'help', 'paralegal', 'legal_assistant', 'paraprofessional', 'paramedic']
senticnet['spending'] = [0.753, 0.979, 0, 0, '#joyful', '#interesting', 0.577, 'first_class', 'shopping', 'travel_across_world', 'cost_money', 'run_out_fuel']
senticnet['atop'] = [0.75, 0, 0, 0.971, '#joyful', '#admirable', 0.574, 'high', 'superior', 'aloft', 'above_all', 'above']
senticnet['betrayerer'] = [-0.672, 0, 0.546, -0.633, '#sad', '#disgusting', -0.617, 'fink', 'betrayer', 'snitch', 'sneak', 'stoolpigeon']
senticnet['small_govern_city'] = [0, 0, 0, 0.104, '#admirable', '#admirable', 0.035, 'downtown', 'govern_city', 'large_town', 'govern', 'city']
senticnet['root_out'] = [0, 0, -0.963, -0.721, '#scared', '#disgusting', -0.561, 'eradicate', 'deracinate', 'extirpate', 'exterminate', 'uproot']
senticnet['acidophilus_flora'] = [-0.998, 0, 0.987, -0.965, '#sad', '#angry', -0.983, 'lactobacillus', 'acidophilus', 'acidophilus_bacterium', 'acidophilus_microflora', 'probiotic']
senticnet['workaday'] = [0, 0, -0.85, -0.823, '#scared', '#disgusting', -0.558, 'quotidian', 'unremarkable', 'routine', 'everyday', 'mundane']
senticnet['shelter_upper_deck'] = [0.831, -0.821, 0, 0.826, '#joyful', '#admirable', 0.826, 'upper_deck', 'freeboard_upper_deck', 'weather_upper_deck', 'deck', 'boat_upper_deck']
senticnet['involved'] = [0, 0, 0.968, -0.83, '#angry', '#disgusting', -0.599, 'convoluted', 'knotty', 'tangled', 'tortuous', 'byzantine']
senticnet['peripety'] = [0.736, 0, 0, 0.768, '#joyful', '#admirable', 0.501, 'astonishingly', 'amazingly', 'alteration', 'surprisingly', 'bombshell']
senticnet['public_slayer'] = [-0.628, 0, 0.94, -0.998, '#angry', '#disgusting', -0.855, 'poisoner', 'choker', 'mortal', 'slayer', 'executioner']
senticnet['depiction'] = [0, 0, -0.999, -0.848, '#scared', '#disgusting', -0.616, 'word_picture', 'picture', 'word-painting', 'delineation', 'characterization']
senticnet['portability'] = [0.664, -0.883, 0, 0.732, '#surprising', '#admirable', 0.76, 'mobility', 'looseness', 'movability', 'play', 'unsteadiness']
senticnet['tied'] = [0, 0, -0.837, -0.998, '#scared', '#disgusting', -0.612, 'flush', 'level', 'fifty-fifty', 'regular', 'even']
senticnet['progeny'] = [-0.062, 0.2, -0.1, 0.168, '#interesting', '#admirable', 0.069, 'orphan', 'take_child', 'offspring', 'become_parent', 'much_child']
senticnet['undertaking'] = [0.746, -0.678, 0, 0.529, '#joyful', '#surprising', 0.651, 'labor', 'doddle', 'cinch', 'project', 'task']
senticnet['rateability'] = [0, 0, 0.967, -0.749, '#angry', '#disgusting', -0.572, 'ratability', 'susceptibility', 'susceptibleness', 'taxability', 'liability']
senticnet['wallpaper'] = [0, 0.239, 0, 0.129, '#interesting', '#admirable', 0.123, 'paper_clip', 'decorate_wall', 'intern', 'glue', 'paper_fastener']
senticnet['reflexive'] = [0.506, -0.567, 0, 0.788, '#surprising', '#admirable', 0.62, 'backward', 'reverse', 'retrograde', 'inverse', 'retral']
senticnet['theosophy'] = [0.661, -0.666, 0, 0.685, '#surprising', '#admirable', 0.671, 'ethical_code', 'anthroposophy', 'system_of_rules', 'logic', 'method']
senticnet['bad_airette'] = [-0.999, 0, 0.056, -0.982, '#sad', '#disgusting', -0.679, 'smoke', 'cigar', 'tobacco', 'pollution', 'bad_air']
senticnet['vise'] = [0.137, -0.11, 0.036, -0.032, '#joyful', '#surprising', 0.06, 'wrench', 'metal_rod', 'nut_bolt', 'golf_club', 'spanner']
senticnet['rosebush'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'apple_tree', 'ferret', 'snake', 'fox', 'mormon']
senticnet['side_by_side'] = [0, 0, -0.739, -0.968, '#scared', '#disgusting', -0.569, 'next', 'succeeding', 'following', 'adjacent', 'future']
senticnet['retentive'] = [0.905, 0.816, 0, 0, '#joyful', '#interesting', 0.574, 'tenacious', 'long', 'dogged', 'dour', 'recollective']
senticnet['ramp'] = [0.037, 0.096, 0, 0.063, '#interesting', '#admirable', 0.065, 'slope', 'incline', 'slant', 'house_roof', 'mountain_side']
senticnet['puff'] = [0.957, -0.576, 0, 0.857, '#joyful', '#admirable', 0.797, 'gust', 'bluster', 'sandblast', 'puff_of_air', 'whiff']
senticnet['civilised'] = [0, 0.969, 0, 0.759, '#interesting', '#admirable', 0.576, 'civilized', 'cultured', 'cultivated', 'genteel', 'polite']
senticnet['upon'] = [0, 0.21, -0.113, 0.345, '#interesting', '#admirable', 0.147, 'direction', 'unto', 'forehead', 'go_toward', 'toward']
senticnet['prospering'] = [0.98, -0.746, 0, 0.984, '#joyful', '#admirable', 0.903, 'prosperous', 'successful', 'palmy', 'flourishing', 'thriving']
senticnet['softening'] = [0, 0, -0.79, -0.951, '#scared', '#disgusting', -0.58, 'ointment', 'demulcent', 'emollient', 'salving', 'cream']
senticnet['buy_bedroom_sheet'] = [0.281, 0.203, -0.079, 0.184, '#joyful', '#interesting', 0.196, 'home_renovation', 'buy_pillow', 'buy_home_appliance', 'buy_bed', 'buy_bedroom']
senticnet['loader'] = [0, 0, -0.952, -0.844, '#scared', '#disgusting', -0.599, 'docker', 'lumper', 'stevedore', 'longshoreman', 'dock_worker']
senticnet['mountain_climb_mountain'] = [0, 0.166, -0.134, 0.275, '#interesting', '#admirable', 0.102, 'climb', 'climb_mountain', 'chop_down_tree', 'reflect_water', 'store_garage']
senticnet['pilfer'] = [0, 0, -0.811, -0.95, '#scared', '#disgusting', -0.587, 'cabbage', 'pinch', 'purloin', 'abstract', 'snarf']
senticnet['cadaverous'] = [0, 0, -0.767, -0.95, '#scared', '#disgusting', -0.572, 'bony', 'gaunt', 'haggard', 'pinched', 'skeletal']
senticnet['question_knowledge'] = [0, 0.84, 0, 0.887, '#interesting', '#admirable', 0.576, 'curious', 'seek_information', 'ask_question', 'question', 'inquisitive']
senticnet['reedmace'] = [0.656, -0.632, 0, 0.844, '#joyful', '#admirable', 0.711, 'cattail', 'bulrush', 'nailrod', 'reed_mace', 'bullrush']
senticnet['paying_attention'] = [0, 0, -0.984, -0.838, '#scared', '#disgusting', -0.607, 'attentiveness', 'listen', 'mind', 'heed', 'regard']
senticnet['poppy'] = [0.088, 0, 0, 0.072, '#joyful', '#admirable', 0.053, 'wee', 'baby_flower', 'yellow_flower', 'rose', 'green_plant']
senticnet['phoney'] = [0.85, -0.716, 0, 0.617, '#joyful', '#surprising', 0.728, 'pretender', 'phony', 'charmer', 'hypocrite', 'dissembler']
senticnet['miscarriage'] = [-0.955, 0, -0.986, 0, '#sad', '#scared', -0.647, 'death', 'feticide', 'sickness', 'abortion', 'spontaneous_abortion']
senticnet['cogent'] = [0, 0, -0.859, -0.798, '#scared', '#disgusting', -0.552, 'grave', 'telling', 'heavy', 'weighty', 'grievous']
senticnet['hole-and-corner'] = [0, 0, -0.806, -0.738, '#scared', '#disgusting', -0.515, 'secret', 'hush-hush', 'hugger-mugger', 'cloak-and-dagger', 'clandestine']
senticnet['siblings'] = [0, 0.269, -0.17, 0.182, '#interesting', '#admirable', 0.094, 'kinship', 'big_brother', 'elder', 'family', 'best_friend']
senticnet['reabsorb'] = [0.869, -0.598, 0, 0.66, '#joyful', '#admirable', 0.709, 'assimilate', 'take_up', 'absorb', 'resorb', 'imbibe']
senticnet['non_existent'] = [0.075, 0.207, -0.061, 0.12, '#interesting', '#admirable', 0.114, 'false', 'unreal', 'imaginary', 'fictional', 'fictitious']
senticnet['wriggling'] = [0, 0, -0.877, -0.723, '#scared', '#disgusting', -0.533, 'writhing', 'wriggly', 'sinuate', 'wiggly', 'sinuous']
senticnet['proportionate'] = [0.814, -0.658, 0, 0.782, '#joyful', '#admirable', 0.751, 'harmonious', 'stable', 'symmetrical', 'counterbalanced', 'balanced']
senticnet['satisfier'] = [0.962, -0.898, 0, 0.855, '#joyful', '#surprising', 0.905, 'infectious_agent', 'infective_agent', 'agent', 'quickener', 'invigorator']
senticnet['deconsecrate'] = [0, 0, -0.701, -0.792, '#scared', '#disgusting', -0.498, 'profane', 'desecrate', 'outrage', 'unhallow', 'violate']
senticnet['recognizable'] = [0.935, -0.958, 0, 0.949, '#surprising', '#admirable', 0.947, 'identifiable', 'specifiable', 'acknowledgeable', 'diagnosable', 'classifiable']
senticnet['pressor'] = [0.672, -0.552, 0, 0.992, '#joyful', '#admirable', 0.739, 'adrenalin', 'hormone', 'endocrine', 'internal_secretion', 'catecholamine']
senticnet['tangle'] = [0, 0, -0.979, -0.728, '#scared', '#disgusting', -0.569, 'entangle', 'snarling', 'snarl_up', 'snap', 'mat']
senticnet['poker_countenance'] = [0.719, -0.58, 0, 0.739, '#joyful', '#admirable', 0.679, 'face', 'look', 'countenance', 'expression', 'aspect']
senticnet['mother_daddy'] = [0, 0.836, 0, 0.943, '#interesting', '#admirable', 0.593, 'family_member', 'dad', 'daddy', 'brother', 'uncle']
senticnet['griffins'] = [0, 0.732, 0, 0.934, '#interesting', '#admirable', 0.555, 'mythical_monster', 'mythical_creature', 'unicorn', 'legendary_creature', 'doppelganger']
senticnet['peevish'] = [0, 0, -0.897, -0.952, '#scared', '#disgusting', -0.616, 'nettlesome', 'fractious', 'petulant', 'irritable', 'cranky']
senticnet['lacuna'] = [0, -0.997, 0, 0.856, '#surprising', '#admirable', 0.618, 'space', 'blank', 'dummy', 'clean', 'vacuous']
senticnet['timorousation'] = [0.992, 0.719, 0, 0, '#joyful', '#interesting', 0.57, 'timorously', 'timorous', 'fear', 'trepid', 'presentiment']
senticnet['preferred'] = [0.59, -0.815, 0, 0.571, '#joyful', '#surprising', 0.659, 'admired', 'wanted', 'loved', 'darling', 'precious']
senticnet['steak'] = [0, 0.08, 0, 0, '#interesting', '#interesting', 0.027, 'beef', 'pork', 'french_toast', 'brisket', 'ham']
senticnet['sylphlike'] = [0, 0, -0.926, -0.837, '#scared', '#disgusting', -0.588, 'lithe', 'supple', 'lissom', 'slender', 'svelte']
senticnet['unfold'] = [0.58, -0.821, 0, 0.77, '#surprising', '#admirable', 0.724, 'show', 'expose', 'trot_out', 'bring_out', 'disclose']
senticnet['received'] = [0.84, -0.646, 0, 0.912, '#joyful', '#admirable', 0.799, 'conventional', 'customary', 'formulaic', 'stuffy', 'stodgy']
senticnet['spear'] = [0.059, 0, 0, 0.049, '#joyful', '#admirable', 0.036, 'bayonet', 'arrow', 'shotgun', 'bullet', 'hydrogen_bomb']
senticnet['untarnished'] = [0.513, -0.585, 0, 0.919, '#surprising', '#admirable', 0.672, 'stainless', 'untainted', 'unblemished', 'unsullied', 'unstained']
senticnet['suavity'] = [0.753, -0.898, 0, 0.652, '#joyful', '#surprising', 0.768, 'good_manners', 'graciousness', 'suaveness', 'courtesy', 'smoothness']
senticnet['descry'] = [0, 0, -0.786, -0.872, '#scared', '#disgusting', -0.553, 'spy', 'recognise', 'located', 'recognize', 'spotted']
senticnet['aflicker'] = [0, 0, 0.78, -0.831, '#angry', '#disgusting', -0.537, 'flickering', 'quiver', 'flitter', 'flutter', 'waver']
senticnet['mingle'] = [0, 0, -0.832, -0.845, '#scared', '#disgusting', -0.559, 'amalgamate', 'coalesced', 'commix', 'mix', 'unify']
senticnet['soap'] = [0.159, 0, 0.041, 0.174, '#joyful', '#admirable', 0.097, 'clean_hand', 'use_clean', 'clean_cloth', 'cleanse', 'clean_supply']
senticnet['upsize'] = [0.799, -0.927, 0, 0.896, '#surprising', '#admirable', 0.874, 'size_up', 'big_meal', 'big_size', 'big', 'quantity']
senticnet['marketing'] = [0.956, 0.713, 0, 0, '#joyful', '#interesting', 0.556, 'advertisement', 'sales', 'announcement', 'billboard', 'promotion']
senticnet['treble'] = [0, 0, 0.713, -0.99, '#angry', '#disgusting', -0.568, 'double', 'twofold', 'dual', 'threefold', 'three-fold']
senticnet['snowy'] = [0.851, 0.768, 0, 0, '#joyful', '#interesting', 0.54, 'chilly', 'cool_temperature', 'coldness', 'ice_rain', 'season_year']
senticnet['bathroom_drawerroom'] = [0.042, -0.056, 0, 0, '#joyful', '#surprising', 0.033, 'toilet', 'bath', 'beauty_parlor', 'hotel_bathroom_drawerroom', 'bathroom_drawer']
senticnet['too_big_for_ones_breeches'] = [0, 0, -0.764, -0.877, '#scared', '#disgusting', -0.547, 'snooty', 'uppish', 'persnickety', 'bigheaded', 'stuck-up']
senticnet['corrade'] = [0, 0, 0.862, -0.768, '#angry', '#disgusting', -0.543, 'scour', 'abrase', 'rub_off', 'abraded', 'rub_down']
senticnet['umpire'] = [0.032, -0.009, 0, 0.09, '#joyful', '#admirable', 0.044, 'croquet', 'referee', 'equestrian_sport', 'backgammon', 'traffic_control']
senticnet['wintry'] = [0, 0, -0.986, -0.746, '#scared', '#disgusting', -0.577, 'frosty', 'glacial', 'icy', 'frigid', 'frozen']
senticnet['telescopic'] = [0.545, -0.599, 0, 0.865, '#surprising', '#admirable', 0.67, 'farsighted', 'longsighted', 'farseeing', 'hyperopic', 'hypermetropic']
senticnet['disdainful'] = [0, 0, -0.749, -0.932, '#scared', '#disgusting', -0.56, 'imperious', 'haughty', 'supercilious', 'lordly', 'overbearing']
senticnet['flag-waver'] = [0, 0, -0.888, -0.702, '#scared', '#disgusting', -0.53, 'jingo', 'hundred-percenter', 'chauvinist', 'patrioteer', 'jingoist']
senticnet['petitioner'] = [0, 0, -0.776, -0.821, '#scared', '#disgusting', -0.532, 'suppliant', 'requester', 'supplicant', 'supplicatory', 'prayer']
senticnet['pony'] = [0, -0.114, 0.022, 0.06, '#surprising', '#admirable', 0.051, 'donkey', 'small_horse', 'male_cow', 'hoof_animal', 'little_horse']
senticnet['beanbag_airline_seat'] = [0, 0, 0.763, -0.999, '#angry', '#disgusting', -0.587, 'sofa_bed', 'small_seat', 'chair', 'hide-a-bed_sofa', 'airline_seat']
senticnet['turban_winter_squash'] = [-0.562, 0, 0.696, -0.964, '#angry', '#disgusting', -0.741, 'winter_squash', 'acorn_winter_squash', 'hubbard_winter_squash', 'squash', 'butternut_winter_squash']
senticnet['genteel'] = [0, 0.969, 0, 0.759, '#interesting', '#admirable', 0.576, 'civilized', 'civilised', 'cultivated', 'cultured', 'polite']
senticnet['trifle'] = [0.777, -0.852, 0, 0.615, '#joyful', '#surprising', 0.748, 'think_about', 'play', 'look_at', 'abstract', 'warm_to']
senticnet['tending'] = [0.946, -0.728, 0, 0.843, '#joyful', '#admirable', 0.839, 'fond', 'disposed', 'inclined', 'partial', 'given']
senticnet['counteract'] = [0, 0, 0.773, -0.95, '#angry', '#disgusting', -0.574, 'undermine', 'cave', 'sabotage', 'subvert', 'weaken']
senticnet['untold'] = [0, 0.789, 0, 0.705, '#interesting', '#admirable', 0.498, 'secret', 'secret_agent', 'secret_organization', 'mysterious', 'mystic']
senticnet['recover'] = [0.855, 0.741, 0, 0.862, '#joyful', '#admirable', 0.819, 'feel_rejuvenated', 'feel_fresher', 'feel_more_lively', 'become_younger', 'feel_regenerate']
senticnet['professional'] = [0.811, -0.63, 0, 0.959, '#joyful', '#admirable', 0.8, 'drama_critic', 'theater_critic', 'art_critic', 'critic', 'literary_critic']
senticnet['see-through'] = [0, 0, -0.994, -0.974, '#scared', '#disgusting', -0.656, 'gauze-like', 'filmy', 'gauzy', 'gossamer', 'diaphanous']
senticnet['bum_around'] = [0, 0, -0.943, -0.781, '#scared', '#disgusting', -0.575, 'bum', 'bum_about', 'arse_around', 'droop', 'loll']
senticnet['overhasty'] = [-0.848, 0, 0.908, 0, '#sad', '#angry', -0.585, 'hasty', 'come_down', 'fall', 'precipitate', 'precipitant']
senticnet['threefold'] = [0, 0, 0.713, -0.99, '#angry', '#disgusting', -0.568, 'double', 'twofold', 'treble', 'dual', 'three-fold']
senticnet['rapidness'] = [0.548, -0.622, 0, 0.695, '#surprising', '#admirable', 0.622, 'quickness', 'instancy', 'rapidity', 'celerity', 'speediness']
senticnet['conflate'] = [0, 0, -0.754, -0.924, '#scared', '#disgusting', -0.559, 'blend', 'coalesce', 'mix', 'flux', 'commingle']
senticnet['renunciative'] = [0.682, -0.559, 0, 0.985, '#joyful', '#admirable', 0.742, 'renunciant', 'nonindulgent', 'puritanic', 'puritanical', 'corrective']
senticnet['sweeper'] = [0.159, 0, 0.041, 0.174, '#joyful', '#admirable', 0.097, 'clean_hand', 'use_clean', 'clean_supply', 'cleanse', 'clean_cloth']
senticnet['valued'] = [0, 0.761, 0, 0.834, '#interesting', '#admirable', 0.532, 'valuable', 'costly', 'expensive', 'precious', 'special']
senticnet['outshout'] = [0, 0.95, 0, 0.725, '#interesting', '#admirable', 0.558, 'exceed', 'outperform', 'outstrip', 'outshine', 'outsail']
senticnet['refurbish'] = [0.857, -0.688, 0, 0.971, '#joyful', '#admirable', 0.839, 'revitalize', 'freshen_up', 'reconstruct', 'renovate', 'renew']
senticnet['subversion'] = [-0.848, 0, 0.744, -0.581, '#sad', '#angry', -0.724, 'ending', 'subversive_activity', 'termination', 'overthrow', 'conclusion']
senticnet['offence'] = [0, 0, -0.863, -0.752, '#scared', '#disgusting', -0.538, 'crime', 'murder', 'fellow_conspirator', 'partner_in_crime', 'accomplice']
senticnet['seamy'] = [-0.786, 0, 0.837, 0, '#sad', '#angry', -0.541, 'flyblown', 'squalid', 'seedy', 'sordid', 'sleazy']
senticnet['polyuria'] = [0.576, -0.572, 0, 0.768, '#joyful', '#admirable', 0.639, 'uropathy', 'kidney_disease', 'polycystic_kidney_disease', 'renal_failure', 'kidney_failure']
senticnet['squirt'] = [-0.726, 0, 0.778, -0.98, '#angry', '#disgusting', -0.828, 'dirty_water', 'puddle', 'mud', 'slosh', 'sludge']
senticnet['processor'] = [0, 0.94, 0, 0.774, '#interesting', '#admirable', 0.571, 'computer_type', 'browse_web', 'laptop', 'desktop', 'language']
senticnet['roundedal'] = [0.969, -0.542, 0, 0.806, '#joyful', '#admirable', 0.772, 'rounded', 'aspheric', 'prolate', 'auriform', 'crescent']
senticnet['unpredicted'] = [0.046, -0.66, 0, 0.365, '#surprising', '#admirable', 0.357, 'without_warning', 'unexpected', 'out_of_blue', 'unanticipated', 'without_notice']
senticnet['sporty'] = [0.528, -0.685, 0, 0.798, '#surprising', '#admirable', 0.67, 'gay', 'showy', 'picturesque', 'colourful', 'brave']
senticnet['accepting_changes'] = [0, -0.738, 0, 0.957, '#surprising', '#admirable', 0.565, 'looking_old', 'aging', 'looking_good', 'age_gracefully', 'cosmetic_surgery']
senticnet['revoke'] = [0, 0, -0.734, -0.887, '#scared', '#disgusting', -0.54, 'lift', 'countermand', 'rescind', 'reverse', 'annul']
senticnet['bow_down'] = [0, 0, -0.763, -0.879, '#scared', '#disgusting', -0.547, 'bowed', 'submit', 'accede', 'give_in', 'bend']
senticnet['reformable'] = [0.779, -0.882, 0, 0.521, '#joyful', '#surprising', 0.727, 'corrigible', 'correctable', 'improvable', 'amendable', 'redeemable']
senticnet['acerb'] = [-0.977, 0, -0.86, 0, '#sad', '#scared', -0.612, 'acid', 'pungent', 'acrid', 'acerbic', 'bitter']
senticnet['stigmatize'] = [0, 0, -0.721, -0.707, '#scared', '#disgusting', -0.476, 'betray', 'denounce', 'tell_on', 'brand', 'mark']
senticnet['resound'] = [-0.957, 0, -0.9, 0, '#sad', '#scared', -0.619, 'knell', 'reverberate', 'ringed', 'peal', 'echo']
senticnet['snappish'] = [0, -0.858, 0, 0.876, '#surprising', '#admirable', 0.578, 'nipping', 'whipping', 'snappy', 'crisp', 'frosty']
senticnet['curly_salad_green'] = [0.636, -0.796, 0, 0.552, '#joyful', '#surprising', 0.661, 'lettuce', 'salad_green', 'green', 'endive', 'food']
senticnet['authoring_language_package'] = [-0.849, 0, 0.689, -0.907, '#sad', '#disgusting', -0.815, 'authoring_language', 'authoring_language_program', 'computer_authoring_language', 'authoring_language_system', 'software']
senticnet['tried'] = [0.947, -0.793, 0, 0.7, '#joyful', '#surprising', 0.813, 'tested', 'dependable', 'tried_and_true', 'sure', 'undeviating']
senticnet['reservoir'] = [-0.03, 0.085, 0, 0.127, '#interesting', '#admirable', 0.061, 'small_stream', 'riverside', 'big_lake', 'dam', 'oceanside']
senticnet['committed'] = [-0.792, 0, -0.834, 0, '#sad', '#scared', -0.542, 'bind', 'tie', 'affiliated', 'connected', 'attached']
senticnet['viability'] = [0.99, -0.88, 0, 0.831, '#joyful', '#surprising', 0.9, 'practicality', 'sensibleness', 'functionality', 'usefulness', 'realism']
senticnet['sustain'] = [0, 0.991, 0, 0.804, '#interesting', '#admirable', 0.598, 'pillar', 'back_bone', 'solid_basis', 'structure', 'help_people']
senticnet['transcendency'] = [0.516, -0.837, 0, 0.985, '#surprising', '#admirable', 0.779, 'superiority', 'transcendence', 'supremacy', 'dominance', 'ascendance']
senticnet['transcendence'] = [0.516, -0.837, 0, 0.985, '#surprising', '#admirable', 0.779, 'superiority', 'supremacy', 'transcendency', 'dominance', 'ascendance']
senticnet['large_outdoor_board'] = [0.704, 0.815, 0, 0, '#joyful', '#interesting', 0.506, 'advertisement', 'billboard', 'motorway', 'expressway', 'train_track']
senticnet['skew-whiff'] = [-0.889, 0, -0.758, 0, '#sad', '#scared', -0.549, 'lopsided', 'awry', 'wonky', 'askew', 'cockeyed']
senticnet['tenet'] = [0, 0.274, -0.066, 0.282, '#interesting', '#admirable', 0.163, 'principle', 'axiom', 'govern', 'confirmation', 'supreme']
senticnet['screech'] = [0, 0, 0.799, -0.887, '#angry', '#disgusting', -0.562, 'shriek', 'screaming', 'yell', 'howl', 'shout']
senticnet['probable'] = [0, 0.988, 0, 0.733, '#interesting', '#admirable', 0.574, 'hopeful', 'hopefully', 'look_forward', 'anticipate', 'optimism']
senticnet['propulsive'] = [0.74, -0.755, 0, 0.815, '#surprising', '#admirable', 0.77, 'propellant', 'propellent', 'propelling', 'dynamical', 'changing']
senticnet['manners'] = [0, 0.815, 0, 0.735, '#interesting', '#admirable', 0.517, 'way_of_acting', 'good_etiquette', 'behavior', 'niceness', 'good_behavior']
senticnet['whatever'] = [0, 0.961, 0, 0.931, '#interesting', '#admirable', 0.631, 'prosper', 'desirable', 'cherish', 'a_lot_of_sex', 'diversity']
senticnet['bop'] = [0, 0, -0.976, -0.792, '#scared', '#disgusting', -0.589, 'sock', 'whopping', 'whack', 'wham', 'wallop']
senticnet['riotous'] = [0, 0, -0.727, -0.853, '#scared', '#disgusting', -0.527, 'disruptive', 'troubled', 'tumultuous', 'turbulent', 'churning']
senticnet['gimp'] = [-0.724, 0, 0, -0.915, '#sad', '#disgusting', -0.546, 'gimpiness', 'lameness', 'claudication', 'limping', 'gameness']
senticnet['indefinable'] = [0, 0, -0.763, -0.862, '#scared', '#disgusting', -0.542, 'untellable', 'unspeakable', 'indescribable', 'ineffable', 'unutterable']
senticnet['serology'] = [0.701, -0.633, 0, 0.929, '#joyful', '#admirable', 0.754, 'pathology', 'medicine', 'medical_specialty', 'radiology', 'medical_science']
senticnet['lookout_man'] = [0, 0, -0.77, -0.752, '#scared', '#disgusting', -0.507, 'watch', 'lookout', 'sentry', 'sentinel', 'spotter']
senticnet['unperturbed'] = [0.68, -0.799, 0, 0.661, '#joyful', '#surprising', 0.713, 'unflurried', 'unflustered', 'composed', 'unruffled', 'coolheaded']
senticnet['urgent'] = [-0.891, 0.168, -0.609, 0.05, '#sad', '#scared', -0.427, 'emergency', 'urgency', 'emergency_situation', 'needful', 'alarm']
senticnet['lifelike'] = [0.927, 0, 0, 0.855, '#joyful', '#admirable', 0.594, 'vivid', 'graphic', 'pictorial', 'bright', 'brilliant']
senticnet['slapstick'] = [0.995, 0, 0, 0.718, '#joyful', '#admirable', 0.571, 'lift_spirit', 'embarrass_oneself', 'act_silly', 'experience_joy', 'become_happy']
senticnet['jazzy'] = [0, 0, -0.919, -0.952, '#scared', '#disgusting', -0.624, 'showy', 'flashy', 'splashy', 'flamboyant', 'gaudy']
senticnet['tracing'] = [0.774, -0.634, 0, 0.567, '#joyful', '#surprising', 0.658, 'catching', 'discovery', 'spying', 'determination', 'breakthrough']
senticnet['holocene'] = [0.842, 0.898, 0, 0, '#joyful', '#interesting', 0.58, 'recent', 'recent_epoch', 'holocene_epoch', 'late', 'new']
senticnet['sports_equipment'] = [0.52, -0.972, 0, 0.916, '#surprising', '#admirable', 0.803, 'sporting_goods', 'weight', 'mat', 'free_weight', 'exercising_weight']
senticnet['syllabus'] = [0.731, -0.97, 0, 0.957, '#surprising', '#admirable', 0.886, 'reading_program', 'program', 'programme', 'curriculum', 'course_of_study']
senticnet['skull'] = [0, 0.895, 0, 0.984, '#interesting', '#admirable', 0.626, 'hold_brain', 'inside_head', 'cranium', 'brain', 'mind']
senticnet['lubricious'] = [0, 0, -0.916, -0.861, '#scared', '#disgusting', -0.592, 'salacious', 'lewd', 'lustful', 'obscene', 'prurient']
senticnet['nab'] = [0.972, 0.943, 0, 0, '#joyful', '#interesting', 0.638, 'impressive', 'nail', 'arresting', 'pick_up', 'apprehend']
senticnet['begrimed'] = [0, 0, -0.925, -0.825, '#scared', '#disgusting', -0.583, 'raunchy', 'grubby', 'dingy', 'grimy', 'dirty']
senticnet['prerogative'] = [0.621, -0.603, 0, 0.545, '#joyful', '#surprising', 0.59, 'privilege', 'perquisite', 'public_easement', 'right_of_way', 'easement']
senticnet['rub_down'] = [0, 0, 0.862, -0.768, '#angry', '#disgusting', -0.543, 'scour', 'abrase', 'rub_off', 'corrade', 'abraded']
senticnet['restrained'] = [-0.896, 0, -0.864, 0, '#sad', '#scared', -0.587, 'retiring', 'reticent', 'unemotional', 'untalkative', 'self-effacing']
senticnet['outing'] = [0, 0, 0.904, -0.804, '#angry', '#disgusting', -0.569, 'jaunt', 'junket', 'pleasure_trip', 'excursion', 'expedition']
senticnet['rakish'] = [0, 0, -0.815, -0.768, '#scared', '#disgusting', -0.528, 'dashing', 'raffish', 'jaunty', 'natty', 'dapper']
senticnet['algebraematics'] = [0, 0.725, 0, 0.779, '#interesting', '#admirable', 0.501, 'calculus', 'algebra', 'math', 'algebra_equation', 'algebraematical_function']
senticnet['ardent'] = [0, 0, 0.959, -0.956, '#angry', '#disgusting', -0.638, 'impassioned', 'perfervid', 'fervid', 'fervent', 'fiery']
senticnet['volatile'] = [0, 0, 0.853, -0.777, '#angry', '#disgusting', -0.543, 'mutable', 'false', 'fickle', 'untrue', 'inconstant']
senticnet['close_to'] = [0, 0, -0.725, -0.873, '#scared', '#disgusting', -0.533, 'some', 'approximately', 'just_about', 'roughly', 'about']
senticnet['singing'] = [0.034, 0, 0.01, 0.087, '#joyful', '#admirable', 0.037, 'music', 'voice', 'bell', 'alto', 'highest_pitch']
senticnet['whisky'] = [-0.884, 0, 0, -0.705, '#sad', '#disgusting', -0.53, 'drunkard', 'drunk_person', 'alcoholic', 'beer', 'alcohol']
senticnet['salad'] = [0.041, -0.045, 0, 0, '#joyful', '#surprising', 0.029, 'meatloaf', 'casserole', 'delicious_meal', 'garden_salad', 'apple_pie']
senticnet['coatinging'] = [-0.944, 0, 0.569, -0.721, '#sad', '#disgusting', -0.745, 'bitumastic', 'coating', 'veneer', 'lacquer', 'seal']
senticnet['primate'] = [0, 0.072, 0, 0.09, '#interesting', '#admirable', 0.054, 'equine', 'wild_animal', 'rodent', 'high_animal', 'mustang']
senticnet['playground'] = [0, 0, 0, 0.09, '#admirable', '#admirable', 0.03, 'play_area', 'military_installation', 'kid_activity', 'location', 'play_place']
senticnet['thriving'] = [0.98, -0.746, 0, 0.984, '#joyful', '#admirable', 0.903, 'prosperous', 'successful', 'palmy', 'prospering', 'flourishing']
senticnet['hold_cold_beer'] = [0.186, -0.104, 0.046, 0, '#joyful', '#surprising', 0.081, 'liquor', 'whisky', 'alcohol', 'adult_drink', 'cold_beer']
senticnet['phrenologist'] = [0.969, -0.885, 0, 0.736, '#joyful', '#surprising', 0.863, 'slicker', 'beguiler', 'quack', 'charlatan', 'craniologist']
senticnet['shill'] = [0.527, -0.582, 0, 0.784, '#surprising', '#admirable', 0.631, 'slicker', 'beguiler', 'roper', 'deceiver', 'decoy']
senticnet['selectman'] = [0.984, -0.933, 0, 0.927, '#joyful', '#surprising', 0.948, 'lame_duck', 'lieutenant_governor', 'elected_official', 'selectwoman', 'official']
senticnet['connected'] = [-0.792, 0, -0.834, 0, '#sad', '#scared', -0.542, 'bind', 'tie', 'affiliated', 'attached', 'committed']
senticnet['bastardly'] = [0, 0, -0.826, -0.903, '#scared', '#disgusting', -0.576, 'misbegotten', 'inauthentic', 'misbegot', 'spurious', 'specious']
senticnet['dodgy'] = [0, -0.811, 0, 0.796, '#surprising', '#admirable', 0.536, 'cunning', 'crafty', 'guileful', 'knavish', 'tricksy']
senticnet['powder'] = [0.904, -0.892, 0, 0, '#joyful', '#surprising', 0.599, 'make_curry', 'cook_dinner', 'cook_meal', 'cook_curry', 'curry_powder']
senticnet['dendroidal'] = [0, 0, -0.756, -0.88, '#scared', '#disgusting', -0.545, 'tree-living', 'arboreal', 'arborous', 'arboriform', 'arborary']
senticnet['tread'] = [0.035, 0.115, 0, 0.209, '#interesting', '#admirable', 0.12, 'dance_move', 'anagram', 'pace', 'backwards', 'foot_action']
senticnet['undercoat'] = [0, 0, -0.907, -0.969, '#scared', '#disgusting', -0.625, 'anchor', 'base', 'establish', 'strand', 'grounded']
senticnet['donkeywork'] = [0, 0, -0.98, -0.801, '#scared', '#disgusting', -0.594, 'grind', 'footslog', 'plodding', 'slog', 'drudgery']
senticnet['familiarity_uncle'] = [0.02, 0.209, -0.148, 0.202, '#interesting', '#admirable', 0.094, 'familiar', 'mum', 'aunt', 'care_giver', 'familiarity']
senticnet['three-fold'] = [0, 0, 0.713, -0.99, '#angry', '#disgusting', -0.568, 'double', 'twofold', 'treble', 'threefold', 'dual']
senticnet['sustenance'] = [0.728, 0.921, 0, 0, '#joyful', '#interesting', 0.55, 'munch', 'satisfy_appetite', 'nourishment', 'replenish_energy', 'able_eat']
senticnet['glower'] = [0, 0, 0.709, -0.957, '#angry', '#disgusting', -0.555, 'fulgent', 'dazzling', 'egregious', 'blinding', 'glaring']
senticnet['grillworkwork'] = [0.5, -0.762, 0, 0.814, '#surprising', '#admirable', 0.692, 'net', 'network', 'grillwork', 'grillworking', 'mesh']
senticnet['unforced'] = [0.729, 0.974, 0, 0, '#joyful', '#interesting', 0.568, 'willing', 'leave', 'bequeath', 'volition', 'uncoerced']
senticnet['illeness'] = [-0.87, 0, -0.959, 0, '#sad', '#scared', -0.61, 'medicine', 'get_cured', 'kill_specific_group', 'cure', 'avoid_pain']
senticnet['sleight'] = [0.703, -0.8, 0, 0.691, '#joyful', '#surprising', 0.731, 'skillfulness', 'touch', 'dexterity', 'manual_dexterity', 'adeptness']
senticnet['dcalculable'] = [0.983, -0.807, 0, 0.966, '#joyful', '#admirable', 0.919, 'estimable', 'computable', 'countable', 'enumerable', 'calculable']
senticnet['shakable'] = [0.544, -0.693, 0, 0.658, '#surprising', '#admirable', 0.632, 'challengeable', 'shakeable', 'contestable', 'disputable', 'debatable']
senticnet['superpatriotism'] = [0.553, -0.728, 0, 0.752, '#surprising', '#admirable', 0.678, 'jingoism', 'trueness', 'loyalty', 'nationalism', 'chauvinism']
senticnet['primal'] = [-0.996, 0, 0, -0.817, '#sad', '#disgusting', -0.604, 'archaic', 'beforehand', 'archaean', 'previous', 'untimely']
senticnet['technician'] = [0.119, 0, 0, 0, '#joyful', '#joyful', 0.04, 'control', 'control_room', 'indoor_object', 'room', 'tape_player']
senticnet['piece'] = [0.54, -0.575, 0, 0.678, '#surprising', '#admirable', 0.598, 'musical_composition', 'opus', 'composition', 'adagio', 'piece_of_music']
senticnet['portion'] = [0.732, -0.833, 0, 0.566, '#joyful', '#surprising', 0.71, 'share', 'reallocation', 'quota', 'allocation', 'part']
senticnet['hemlock_poisonous_plant'] = [-0.799, 0, 0.906, -0.671, '#sad', '#angry', -0.792, 'poisonous_plant', 'water_dropwort', 'water_hemlock', 'plant_life', 'poison_sumac']
senticnet['rampart'] = [0, 0, -0.801, -0.777, '#scared', '#disgusting', -0.526, 'wall', 'mole', 'groin', 'bulwark', 'breakwater']
senticnet['roundness'] = [-0.943, 0, 0.65, -0.578, '#sad', '#angry', -0.724, 'manner_of_speaking', 'undertone', 'note', 'rotundity', 'tone_of_voice']
senticnet['sabertoothed'] = [0.845, -0.716, 0, 0.775, '#joyful', '#admirable', 0.779, 'toothy', 'toothed', 'cogged', 'toothlike', 'tusked']
senticnet['quilt'] = [0.024, 0, 0, 0.074, '#joyful', '#admirable', 0.033, 'sheet', 'cover', 'bedsheet', 'comforter', 'modesty']
senticnet['orang_pendek'] = [0, 0, 0.808, -0.779, '#angry', '#disgusting', -0.529, 'monster', 'wild_man', 'abominable_snowman', 'yeti', 'abominable']
senticnet['refinement'] = [0.783, -0.606, 0, 0.512, '#joyful', '#surprising', 0.634, 'blowing', 'processing', 'data_processing', 'development', 'developing']
senticnet['taper'] = [0, 0, 0.728, -0.861, '#angry', '#disgusting', -0.53, 'remit', 'diminish', 'drop_off', 'contract', 'break']
senticnet['immix'] = [0, 0, 0.977, -0.775, '#angry', '#disgusting', -0.584, 'flux', 'mix', 'blend', 'conflate', 'commingle']
senticnet['defer'] = [-0.77, 0, -0.855, 0, '#sad', '#scared', -0.542, 'give_in', 'submit', 'accept', 'succumb', 'yield']
senticnet['salivate'] = [0, 0, 0, 0.098, '#admirable', '#admirable', 0.033, 'salivation', 'world_hunger', 'buy_steak', 'weight_gain', 'loss_ofmoney']
senticnet['hugger-mugger'] = [0, 0, -0.806, -0.738, '#scared', '#disgusting', -0.515, 'secret', 'hush-hush', 'clandestine', 'cloak-and-dagger', 'hole-and-corner']
senticnet['droll'] = [0.881, 0, 0, 0.976, '#joyful', '#admirable', 0.619, 'fun', 'guffaw', 'make_laugh', 'amuse', 'funny']
senticnet['dour'] = [0, 0, -0.835, -0.703, '#scared', '#disgusting', -0.513, 'moody', 'morose', 'glum', 'dark', 'glowering']
senticnet['hushed'] = [0, 0, -0.935, -0.886, '#scared', '#disgusting', -0.607, 'dull', 'muffle', 'tone_down', 'muted', 'softened']
senticnet['rare'] = [0.05, 0, 0, 0.115, '#joyful', '#admirable', 0.055, 'poisonous_human', 'poisonous', 'fauna', 'generic_name', 'hard_material']
senticnet['shorebird'] = [0.786, -0.82, 0, 0.776, '#joyful', '#surprising', 0.794, 'red_phalarope', 'northern_phalarope', 'limicoline_bird', 'shore_bird', 'phalarope']
senticnet['untalkative'] = [-0.896, 0, -0.864, 0, '#sad', '#scared', -0.587, 'retiring', 'restrained', 'unemotional', 'reticent', 'self-effacing']
senticnet['leech_worm'] = [-0.716, 0, 0.605, -0.623, '#sad', '#disgusting', -0.648, 'medicinal_leech', 'horseleech', 'leech', 'annelid', 'segmented_worm']
senticnet['toothsome'] = [0.878, -0.765, 0, 0, '#joyful', '#surprising', 0.548, 'delicious', 'luscious', 'pleasant-tasting', 'scrumptious', 'delectable']
senticnet['piquance'] = [0.743, -0.508, 0, 0.959, '#joyful', '#admirable', 0.737, 'zest', 'sharpness', 'hotness', 'spiciness', 'piquancy']
senticnet['piquancy'] = [0.743, -0.508, 0, 0.959, '#joyful', '#admirable', 0.737, 'zest', 'sharpness', 'hotness', 'piquance', 'spiciness']
senticnet['toothlike'] = [0.845, -0.716, 0, 0.775, '#joyful', '#admirable', 0.779, 'toothy', 'toothed', 'sabertoothed', 'cogged', 'tusked']
senticnet['churn'] = [-0.908, 0, 0.965, 0, '#sad', '#angry', -0.624, 'stewing', 'simmering', 'boiling', 'moil', 'seethe']
senticnet['wolfish'] = [0, 0, -0.857, -0.734, '#scared', '#disgusting', -0.53, 'voracious', 'rapacious', 'esurient', 'ravenous', 'edacious']
senticnet['illegitimate'] = [0, 0, -0.948, -0.78, '#scared', '#disgusting', -0.576, 'unlawful', 'unconventional', 'illicit', 'wrongful', 'improper']
senticnet['ban'] = [-0.703, 0, 0.791, 0, '#sad', '#angry', -0.498, 'bar', 'debar', 'criminalize', 'outlaw', 'forbid']
senticnet['unworthy'] = [0, 0, -0.878, -0.88, '#scared', '#disgusting', -0.586, 'slimy', 'despicable', 'ugly', 'slimed', 'vile']
senticnet['sail'] = [0.055, 0, 0.038, 0.119, '#joyful', '#admirable', 0.045, 'cross_river', 'travel_over_water', 'cross_water', 'water_activity', 'cross_bridge']
senticnet['eat_up'] = [0, 0, -0.921, -0.824, '#scared', '#disgusting', -0.582, 'consume', 'eat', 'use_up', 'deplete', 'exhaust']
senticnet['prosperous'] = [0.98, -0.746, 0, 0.984, '#joyful', '#admirable', 0.903, 'flourishing', 'successful', 'palmy', 'prospering', 'thriving']
senticnet['reddish'] = [0, 0, -0.926, -0.963, '#scared', '#disgusting', -0.63, 'ruddy', 'florid', 'sanguine', 'red', 'rubicund']
senticnet['spawn'] = [0, 0, -0.839, -0.829, '#scared', '#disgusting', -0.556, 'breed', 'beget', 'get', 'father', 'engender']
senticnet['computer_authoring_language'] = [-0.849, 0, 0.689, -0.907, '#sad', '#disgusting', -0.815, 'authoring_language', 'authoring_language_program', 'software', 'authoring_language_system', 'authoring_language_package']
senticnet['vegetable'] = [0.035, 0.104, 0, 0.12, '#interesting', '#admirable', 0.086, 'fruit_vegetable', 'leafy_vegetable', 'vegetable_fruit', 'fresh_vegetable', 'vegetarian_food']
senticnet['actaea_racemosa'] = [-0.524, 0, 0.527, -0.782, '#angry', '#disgusting', -0.611, 'herb', 'fairy_candle', 'black_snakeroot', 'black_bugbane', 'black_cohosh']
senticnet['smoker'] = [0.066, 0, -0.059, 0.066, '#joyful', '#admirable', 0.024, 'cyclist', 'chauffeur', 'homeowner', 'programmer', 'stalactite']
senticnet['octopod_mollusk'] = [-0.523, 0, 0.728, -0.926, '#angry', '#disgusting', -0.726, 'nautilus', 'octopod', 'cephalopod', 'paper_nautilus', 'octopus']
senticnet['potential'] = [-0.968, 0, 0.603, -0.915, '#sad', '#disgusting', -0.829, 'achievability', 'potency', 'conceivableness', 'conceivability', 'possibleness']
senticnet['spooky'] = [0.963, -0.987, 0, 0.514, '#joyful', '#surprising', 0.821, 'warm', 'flighty', 'nervous', 'skittish', 'excitable']
senticnet['undutifulness'] = [0.905, -0.802, 0, 0.583, '#joyful', '#surprising', 0.763, 'unrighteousness', 'godlessness', 'impiety', 'ungodliness', 'irreligiousness']
senticnet['making_a_lot_of_noise'] = [0, 0, 0.831, -0.903, '#angry', '#disgusting', -0.578, 'sound_level', 'speakers', 'noisy', 'adjust_volume', 'hear_song']
senticnet['demulcent'] = [0, 0, -0.79, -0.951, '#scared', '#disgusting', -0.58, 'ointment', 'emollient', 'softening', 'salving', 'cream']
senticnet['freeboard_upper_deck'] = [0.831, -0.821, 0, 0.826, '#joyful', '#admirable', 0.826, 'upper_deck', 'deck', 'weather_upper_deck', 'shelter_upper_deck', 'boat_upper_deck']
senticnet['commix'] = [0, 0, -0.832, -0.845, '#scared', '#disgusting', -0.559, 'mingle', 'coalesced', 'amalgamate', 'mix', 'unify']
senticnet['meritable'] = [0.991, 0, 0, 0.751, '#joyful', '#admirable', 0.581, 'noteworthy', 'valuable', 'applaudable', 'deserve', 'sacred']
senticnet['focalise'] = [-0.762, 0, -0.733, 0, '#sad', '#scared', -0.498, 'concentrate', 'centre', 'focused', 'sharpen', 'pore']
senticnet['unenlightened'] = [-0.981, 0, 0, -0.966, '#sad', '#disgusting', -0.649, 'naive', 'uninformed', 'unread', 'unknowing', 'clueless']
senticnet['way_of_acting'] = [0, 0.815, 0, 0.735, '#interesting', '#admirable', 0.517, 'behavior', 'good_etiquette', 'manners', 'niceness', 'good_behavior']
senticnet['baked_goods'] = [0.809, -0.868, 0, 0, '#joyful', '#surprising', 0.559, 'home_made', 'bread', 'container', 'big_breadbox', 'eat_bread']
senticnet['villa'] = [0.903, 0.684, 0, 0.791, '#joyful', '#admirable', 0.793, 'house', 'expensive_house', 'fabulous', 'fancy_house', 'vip']
senticnet['bacteriae'] = [0.905, -0.659, 0, 0.851, '#joyful', '#admirable', 0.805, 'gonococcus', 'bacteria', 'acidophil', 'probiotic', 'probiotic_bacterium']
senticnet['rule-governed'] = [0, 0.767, 0, 0.842, '#interesting', '#admirable', 0.536, 'true', 'lawful', 'legitimate', 'licit', 'rightful']
senticnet['vintner'] = [0.824, 0.743, 0, 0, '#joyful', '#interesting', 0.522, 'shopper', 'customer', 'patron', 'clerk', 'hairdresser']
senticnet['subverter'] = [-0.789, 0, -0.751, 0, '#sad', '#scared', -0.513, 'revolutionist', 'subversive', 'insurgent', 'seditious', 'revolutionary']
senticnet['cloud_skylet'] = [0.962, 0.838, 0, 0, '#joyful', '#interesting', 0.6, 'sky', 'come_down', 'water_fall', 'cloud_sky', 'water_drop']
senticnet['additive'] = [0, 0, 0.94, -0.769, '#angry', '#disgusting', -0.57, 'analog', 'one-dimensional', 'elongate', 'linear', 'analogue']
senticnet['retinopathy'] = [0.621, -0.68, 0, 0.63, '#surprising', '#admirable', 0.644, 'eye_problem', 'bad_eyesight', 'macular_degeneration', 'eye_disease', 'disease']
senticnet['like_price'] = [0, 0.219, -0.05, 0.144, '#interesting', '#admirable', 0.104, 'information', 'a_lot_of_information', 'amount_charge', 'amount', 'item_worth']
senticnet['tokyo'] = [0, 0, 0, 0.081, '#admirable', '#admirable', 0.027, 'newyork', 'london', 'big_city', 'rome', 'beijing']
senticnet['unexciting'] = [-0.793, 0, 0, -0.992, '#sad', '#disgusting', -0.595, 'cliche', 'banality', 'prosaic', 'commonplace', 'humdrum']
senticnet['granary'] = [0, 0, -0.7, -0.912, '#scared', '#disgusting', -0.537, 'earn', 'pull_together', 'gather', 'collect', 'garner']
senticnet['stringed_use_jazz_music'] = [-0.036, -0.009, 0.018, -0.082, '#sad', '#disgusting', -0.042, 'reed_instrument', 'musical_instrument', 'instrument_music', 'use_jazz_music', 'listen_music']
senticnet['spoonfeeding'] = [0.548, -0.982, 0, 0.769, '#surprising', '#admirable', 0.766, 'education', 'teaching_reading', 'catechesis', 'lecture', 'teaching']
senticnet['rakishness'] = [0.853, -0.764, 0, 0.966, '#joyful', '#admirable', 0.861, 'elegance', 'jauntiness', 'chicness', 'nattiness', 'dapperness']
senticnet['sufferance'] = [0.989, -0.806, 0, 0.569, '#joyful', '#surprising', 0.788, 'strength', 'tolerance', 'stamina', 'staying_power', 'endurance']
senticnet['piccolo'] = [0.821, -0.531, 0, 0.785, '#joyful', '#admirable', 0.712, 'flute', 'nose_flute', 'fife', 'woodwind', 'woodwind_instrument']
senticnet['implike'] = [0, 0, -0.732, -0.857, '#scared', '#disgusting', -0.53, 'mischievous', 'prankish', 'impish', 'arch', 'pixilated']
senticnet['ranking'] = [0.829, -0.826, 0, 0.986, '#joyful', '#admirable', 0.88, 'standing', 'importance', 'honor', 'laurels', 'prominence']
senticnet['uninvolved'] = [0.857, 0, 0, 0.997, '#joyful', '#admirable', 0.618, 'straightforward', 'easy', 'uncomplicated', 'simple', 'effortless']
senticnet['station_shooting_brake'] = [-0.539, 0, 0.905, -0.586, '#angry', '#disgusting', -0.677, 'beach_shooting_brake', 'wagon', 'shooting_brake', 'estate_car', 'beach_waggon']
senticnet['reedemer'] = [0.88, 0, 0, 0.883, '#joyful', '#admirable', 0.588, 'succorer', 'rescuer', 'salvager', 'salvor', 'saver']
senticnet['gas_guzzlermobile'] = [-0.512, 0, 0.552, -0.659, '#angry', '#disgusting', -0.574, 'car', 'gas_guzzler', 'auto', 'machine', 'motorcar']
senticnet['tacit'] = [0.531, -0.769, 0, 0.603, '#surprising', '#admirable', 0.634, 'implicit', 'understood', 'unvoiced', 'silent', 'unspoken']
senticnet['shopping'] = [0.719, 0.988, 0, 0, '#joyful', '#interesting', 0.569, 'go_to_shopping_mall', 'bring_a_lot_of_money', 'drive_to_store', 'go_department_store', 'find_merchant']
senticnet['stepper'] = [0.67, -0.912, 0, 0.805, '#surprising', '#admirable', 0.796, 'motor', 'engine', 'electric_motor', 'stepping_motor', 'machine']
senticnet['prankish'] = [0, 0, -0.732, -0.857, '#scared', '#disgusting', -0.53, 'mischievous', 'impish', 'implike', 'arch', 'pixilated']
senticnet['extensive'] = [0.732, -0.829, 0, 0, '#joyful', '#surprising', 0.52, 'expansive', 'sweeping', 'rolling', 'spacious', 'open']
senticnet['notable'] = [0, 0.939, 0, 0.75, '#interesting', '#admirable', 0.563, 'observe', 'keep', 'famed', 'celebrated', 'renowned']
senticnet['despicable'] = [0, 0, -0.878, -0.88, '#scared', '#disgusting', -0.586, 'unworthy', 'slimy', 'ugly', 'slimed', 'vile']
senticnet['preoccupied'] = [-0.702, 0, 0.811, 0, '#sad', '#angry', -0.504, 'unable_to_focus', 'become_distracted', 'inattentive', 'brain_storm', 'new_idea']
senticnet['cottage_cheese_platter'] = [0.044, -0.661, 0, 0.361, '#surprising', '#admirable', 0.355, 'cheese_platter', 'cold_cuts', 'cheese', 'platter', 'appetizer']
senticnet['road'] = [0.749, 0, 0, 0, '#joyful', '#joyful', 0.25, 'dark', 'alley', 'street', 'direction', 'alleyway']
senticnet['vaporize'] = [-0.909, 0, 0, -0.966, '#sad', '#disgusting', -0.625, 'wear_out', 'wear_off', 'melt', 'ablate', 'wear_thin']
senticnet['name_australia'] = [0, 0.917, 0, 0.868, '#interesting', '#admirable', 0.595, 'name', 'native', 'royal', 'title', 'alias']
senticnet['gory'] = [0, 0, -0.75, -0.932, '#scared', '#disgusting', -0.561, 'bloodthirsty', 'slaughterous', 'sanguinary', 'butcherly', 'sanguineous']
senticnet['surmisable'] = [0.878, -0.678, 0, 0.631, '#joyful', '#surprising', 0.729, 'ponderable', 'presumable', 'supposable', 'conceivable', 'thinkable']
senticnet['delineate'] = [0, 0, 0.914, -0.975, '#angry', '#disgusting', -0.63, 'run_along', 'lined', 'describe', 'trace', 'draw']
senticnet['bosomy'] = [0, 0, -0.749, -0.756, '#scared', '#disgusting', -0.502, 'curvy', 'busty', 'buxom', 'curvaceous', 'full-bosomed']
senticnet['swallow'] = [0.097, 0, 0, 0, '#joyful', '#joyful', 0.032, 'serve_liquid', 'eat_food', 'consume_food', 'fill_up', 'drink_soup']
senticnet['premium'] = [0.791, 0.934, 0, 0.85, '#interesting', '#admirable', 0.858, 'top', 'top_class', 'top_notch', 'first_rate', 'high_class']
senticnet['trustful'] = [0.772, 0, 0, 0.75, '#joyful', '#admirable', 0.507, 'naive', 'innocent', 'childlike', 'guileless', 'ingenuous']
senticnet['stretching'] = [0.777, -0.895, 0, 0.508, '#joyful', '#surprising', 0.727, 'dilatation', 'enlarge', 'enlargement', 'get_bigger', 'distension']
senticnet['scurry'] = [0, 0, -0.911, -0.998, '#scared', '#disgusting', -0.636, 'skitter', 'hatchway', 'scamper', 'opening', 'scuttle']
senticnet['maven'] = [0.867, 0.726, 0, 0, '#joyful', '#interesting', 0.531, 'sensation', 'champion', 'adept', 'ace', 'virtuoso']
senticnet['beunshaved'] = [-0.945, 0, 0.84, -0.917, '#sad', '#disgusting', -0.901, 'bearded', 'barbate', 'whiskered', 'unshaved', 'whiskery']
senticnet['reconstructive'] = [0.678, -0.897, 0, 0.804, '#surprising', '#admirable', 0.793, 'constructive', 'formative', 'shaping', 'creative', 'inferential']
senticnet['share'] = [0.732, -0.833, 0, 0.566, '#joyful', '#surprising', 0.71, 'allocation', 'reallocation', 'quota', 'portion', 'part']
senticnet['rye'] = [0, 0.065, 0.031, 0.052, '#interesting', '#admirable', 0.029, 'wheat', 'white_rice', 'corn', 'grain', 'oat']
senticnet['redoubtable'] = [0, 0, 0.882, -0.991, '#angry', '#disgusting', -0.624, 'forbidding', 'formidable', 'daunting', 'alarming', 'frightening']
senticnet['turnpike'] = [0.579, -0.891, 0, 0.878, '#surprising', '#admirable', 0.783, 'autobahn', 'expressway', 'autostrada', 'toll_road', 'highway']
senticnet['tutu'] = [0.053, -0.068, 0.047, 0.087, '#surprising', '#admirable', 0.054, 'woman_dress', 'woman_garment', 'stocking', 'woman_culotte', 'woman_clothes']
senticnet['jingo'] = [0, 0, -0.888, -0.702, '#scared', '#disgusting', -0.53, 'chauvinist', 'hundred-percenter', 'flag-waver', 'patrioteer', 'jingoist']
senticnet['popularization'] = [-0.832, 0, 0, -0.931, '#sad', '#disgusting', -0.588, 'degradation', 'profanation', 'demoralization', 'corruption', 'humiliation']
senticnet['bumble'] = [0, 0, 0.793, -0.837, '#angry', '#disgusting', -0.543, 'stumble', 'waver', 'hesitation', 'falters', 'faltering']
senticnet['sizable'] = [0, 0.931, 0, 0.793, '#interesting', '#admirable', 0.575, 'copious', 'plenteous', 'plentiful', 'rich', 'ample']
senticnet['oscillate'] = [0, 0, -0.834, -0.905, '#scared', '#disgusting', -0.58, 'vibrate', 'vacillate', 'hover', 'waver', 'fluctuate']
senticnet['youth'] = [0, 0.788, 0, 0.86, '#interesting', '#admirable', 0.549, 'child', 'enjoy_time', 'adolescence', 'smile_child', 'open_mind']
senticnet['prefigure'] = [0.527, -0.984, 0, 0.847, '#surprising', '#admirable', 0.786, 'auspicate', 'bode', 'foreshow', 'portend', 'prognosticate']
senticnet['fluctuate'] = [0, 0, -0.834, -0.905, '#scared', '#disgusting', -0.58, 'vibrate', 'oscillate', 'hover', 'waver', 'vacillate']
senticnet['refrigerator'] = [0.045, -0.053, 0, -0.029, '#joyful', '#surprising', 0.023, 'cold_storage', 'store_refrigerator', 'icebox', 'restaurant_storage_area', 'icy']
senticnet['ovate'] = [0, 0, -0.929, -0.823, '#scared', '#disgusting', -0.584, 'egg-shaped', 'oval', 'elliptical', 'ovoid', 'prolate']
senticnet['transeunt'] = [0, 0, -0.849, -0.705, '#scared', '#disgusting', -0.518, 'transitory', 'transient', 'ephemeral', 'passing', 'short-lived']
senticnet['vindicated'] = [0.913, -0.745, 0, 0.703, '#joyful', '#surprising', 0.787, 'guiltless', 'exculpated', 'exonerated', 'absolved', 'clear']
senticnet['selectwoman'] = [0.984, -0.933, 0, 0.927, '#joyful', '#surprising', 0.948, 'lame_duck', 'lieutenant_governor', 'selectman', 'elected_official', 'official']
senticnet['a_little_specific'] = [0.092, 0.14, -0.098, 0.128, '#interesting', '#admirable', 0.087, 'clan', 'happy_together', 'many_people', 'aunt_uncle', 'human_group']
senticnet['everlasting_flower_plant'] = [-0.934, 0, 0.691, -0.971, '#sad', '#disgusting', -0.865, 'cudweed', 'strawflower', 'everlasting_flower', 'composite', 'pink_paper_daisy']
senticnet['pyjamas'] = [0, 0.184, -0.065, 0.22, '#interesting', '#admirable', 0.113, 'sleep_under', 'bed_cover', 'cover_furniture', 'keep_warm_night', 'cover']
senticnet['yesterday'] = [0, 0.75, 0, 0.984, '#interesting', '#admirable', 0.578, 'instance', 'year', 'rendezvous', 'years', 'appointment']
senticnet['retrenchment'] = [0.953, -0.65, 0, 0.866, '#joyful', '#admirable', 0.823, 'economy_of_scale', 'curtailment', 'saving', 'downsizing', 'action']
senticnet['staycation'] = [0, 0.084, 0, 0, '#interesting', '#interesting', 0.028, 'reservation', 'online_booking', 'book_hotel', 'rate', 'currency']
senticnet['looking_old'] = [0, -0.738, 0, 0.957, '#surprising', '#admirable', 0.565, 'age_gracefully', 'aging', 'looking_good', 'accepting_changes', 'cosmetic_surgery']
senticnet['snag'] = [0, 0, -0.78, -0.876, '#scared', '#disgusting', -0.552, 'split', 'rip', 'lease', 'rent', 'tear']
senticnet['account_indebtedness'] = [0.628, -0.607, 0, 0.532, '#joyful', '#surprising', 0.589, 'payable', 'indebtedness', 'limited_liability', 'debt', 'arrears']
senticnet['divagate'] = [0, 0, -0.734, -0.873, '#scared', '#disgusting', -0.536, 'sidetrack', 'depart', 'wander', 'digress', 'stray']
senticnet['tubal_ectopic_gestation'] = [-0.752, 0, 0.715, -0.725, '#sad', '#disgusting', -0.731, 'abdominal_ectopic_gestation', 'ovarian_ectopic_gestation', 'pregnancy', 'ectopic_gestation', 'gestation']
senticnet['seabed'] = [0, 0.068, 0, 0, '#interesting', '#interesting', 0.023, 'ocean_edge', 'ocean_floor', 'sea_floor', 'surface_earth', 'bottom_ocean']
senticnet['calico'] = [0.767, 0, 0, 0.844, '#joyful', '#admirable', 0.537, 'pied', 'multi-color', 'varicolored', 'motley', 'painted']
senticnet['priggish'] = [0, 0, 0.929, -0.876, '#angry', '#disgusting', -0.602, 'prissy', 'puritanical', 'prudish', 'prim', 'square-toed']
senticnet['fleet_flag_officer'] = [0.688, -0.908, 0, 0.877, '#surprising', '#admirable', 0.824, 'admiral', 'rear_flag_officer', 'flag_officer', 'full_flag_officer', 'vice_flag_officer']
senticnet['macerate'] = [0, 0, -0.733, -0.729, '#scared', '#disgusting', -0.487, 'bony', 'gaunt', 'waste', 'emaciated', 'cadaverous']
senticnet['tree_dead_tree'] = [0, -0.026, 0.085, -0.094, '#angry', '#disgusting', -0.051, 'wood', 'forest', 'sideways', 'deforestation', 'dead_tree']
senticnet['rinse'] = [0.116, 0.108, -0.091, 0.12, '#joyful', '#admirable', 0.084, 'fresh', 'timely', 'update', 'new', 'feel_refreshed']
senticnet['blaze'] = [0.799, 0, 0, 0.897, '#joyful', '#admirable', 0.565, 'brightness', 'glare', 'brilliance', 'glitter', 'glister']
senticnet['unbeaten'] = [0.914, -0.547, 0, 0.803, '#joyful', '#admirable', 0.755, 'victorious', 'triumphant', 'unbowed', 'undefeated', 'unconquered']
senticnet['shock'] = [-0.569, 0, 0.897, -0.651, '#angry', '#disgusting', -0.706, 'ball_over', 'floor', 'galvanize', 'blow_out_of_water', 'take_aback']
senticnet['rain_buckets_down'] = [-0.771, 0, 0.583, -0.609, '#sad', '#disgusting', -0.654, 'rain', 'rain_down', 'sheet', 'rain_bucket', 'sluice']
senticnet['visored'] = [0.84, -0.973, 0, 0.517, '#joyful', '#surprising', 0.777, 'prepared', 'equipped', 'armored', 'outfitted', 'helmeted']
senticnet['sacrilegious'] = [0.615, -0.572, 0, 0.502, '#joyful', '#surprising', 0.563, 'irreverent', 'awless', 'disrespectful', 'aweless', 'blasphemous']
senticnet['harrowing'] = [-0.795, 0, 0.903, 0, '#sad', '#angry', -0.566, 'excruciating', 'agonizing', 'torturing', 'worry', 'fret']
senticnet['reanimated'] = [0.689, -0.544, 0, 0.511, '#joyful', '#surprising', 0.581, 'lively', 'enlivened', 'spirited', 'animated', 'vital']
senticnet['boney'] = [0, 0, 0.956, -0.963, '#angry', '#disgusting', -0.64, 'scraggy', 'scrawny', 'underweight', 'skinny', 'weedy']
senticnet['tortuosity'] = [0.697, -0.507, 0, 0.792, '#joyful', '#admirable', 0.665, 'tortuousness', 'gnarl', 'warp', 'distorted_shape', 'torsion']
senticnet['occlude'] = [-0.904, 0, 0.922, 0, '#sad', '#angry', -0.609, 'obturate', 'impeding', 'hinder', 'impede', 'obstruct']
senticnet['twofer'] = [0.921, -0.571, 0, 0.962, '#joyful', '#admirable', 0.818, 'coupon', 'meal_ticket', 'luncheon_voucher', 'book_token', 'commercial_document']
senticnet['arborary'] = [0, 0, -0.756, -0.88, '#scared', '#disgusting', -0.545, 'tree-living', 'dendroidal', 'arborous', 'arboriform', 'arboreal']
senticnet['chicken_bushel'] = [0, 0.067, 0, 0.07, '#interesting', '#admirable', 0.046, 'peck', 'embryo', 'egg', 'ovum', 'bushel']
senticnet['gurk'] = [0, 0, -0.802, -0.809, '#scared', '#disgusting', -0.537, 'acid_indigestion', 'burp', 'belch', 'hunger_go_away', 'choke']
senticnet['sebaceous'] = [0, 0, -0.903, -0.951, '#scared', '#disgusting', -0.618, 'oily', 'greasy', 'fulsome', 'oleaginous', 'buttery']
senticnet['steal'] = [0, 0, 0.762, -0.82, '#angry', '#disgusting', -0.527, 'arm_man', 'commit_crime', 'storm_fortress', 'even_odds', 'go_after']
senticnet['waitress'] = [0, 0.873, 0, 0.74, '#interesting', '#admirable', 0.538, 'wait_staff', 'manager', 'server', 'public_servant', 'waiter']
senticnet['puppet'] = [0.033, 0.076, 0, 0.066, '#interesting', '#admirable', 0.058, 'baby_dog', 'most_dogs', 'boyfriend', 'dog', 'dog_like']
senticnet['archaean'] = [-0.996, 0, 0, -0.817, '#sad', '#disgusting', -0.604, 'primal', 'beforehand', 'archaic', 'previous', 'untimely']
senticnet['circumvolve'] = [0, 0, 0.855, -0.738, '#angry', '#disgusting', -0.531, 'rotating', 'turn_out', 'revolve', 'rotate', 'go_around']
senticnet['vanquishable'] = [0.702, -0.944, 0, 0.582, '#joyful', '#surprising', 0.743, 'conquerable', 'beatable', 'vincible', 'subduable', 'subjugable']
senticnet['poverty-stricken'] = [-0.915, 0, 0.724, 0, '#sad', '#angry', -0.546, 'impoverished', 'needy', 'necessitous', 'indigent', 'destitute']
senticnet['snuffle'] = [0, 0, -0.957, -0.828, '#scared', '#disgusting', -0.595, 'whine', 'blubber', 'sniffle', 'sniveling', 'blub']
senticnet['text'] = [0.036, 0.219, 0, 0.19, '#interesting', '#admirable', 0.148, 'long_story', 'novel', 'fiction', 'book', 'classic']
senticnet['photography'] = [0.047, 0, 0, 0.067, '#joyful', '#admirable', 0.038, 'fillet_fish', 'clon', 'price_product', 'sculpt', 'demo']
senticnet['comebacking'] = [-0.958, 0, 0.941, -0.577, '#sad', '#angry', -0.825, 'reply', 'response', 'comeback', 'sass', 'backtalk']
senticnet['for_free'] = [0, -0.854, 0, 0.991, '#surprising', '#admirable', 0.615, 'free', 'costless', 'gratuitous', 'gratis', 'complimentary']
senticnet['small_picaninny'] = [-0.83, 0, 0.987, -0.535, '#sad', '#angry', -0.784, 'picaninny', 'kid', 'minor', 'tike', 'fry']
senticnet['vena'] = [0.614, -0.89, 0, 0.51, '#joyful', '#surprising', 0.671, 'jugular', 'external_jugular_vein', 'internal_jugular_vein', 'vein', 'anterior_jugular_vein']
senticnet['protoplasm'] = [0.611, -0.829, 0, 0.737, '#surprising', '#admirable', 0.726, 'plasma', 'cytoplasm', 'germplasm', 'nucleoplasm', 'blood_plasma']
senticnet['upbeat'] = [0.971, -0.717, 0, 0.656, '#joyful', '#surprising', 0.781, 'wellbeing', 'human_flourishing', 'successfulness', 'eudaimonia', 'strength']
senticnet['long_bad_camera'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'slow', 'long_focus', 'bad_camera', 'focus_time', 'low_quality_photo']
senticnet['untired'] = [0.516, -0.936, 0, 0.802, '#surprising', '#admirable', 0.751, 'rested', 'refreshed', 'rerested', 'invigorated', 'unwearied']
senticnet['rosiness'] = [0.939, -0.745, 0, 0.57, '#joyful', '#surprising', 0.751, 'healthiness', 'wholeness', 'haleness', 'health', 'vitality']
senticnet['scrimp'] = [0, -0.887, 0, 0.728, '#surprising', '#admirable', 0.538, 'stinting', 'economical', 'scant', 'frugal', 'skimp']
senticnet['quiddity'] = [0, 0, -0.794, -0.803, '#scared', '#disgusting', -0.532, 'niggle', 'quibble', 'bicker', 'pettifog', 'cavil']
senticnet['ostracise'] = [-0.812, 0, 0.775, 0, '#sad', '#angry', -0.529, 'move', 'displace', 'fire', 'chase_away', 'banish']
senticnet['stuffy'] = [0.84, -0.646, 0, 0.912, '#joyful', '#admirable', 0.799, 'received', 'customary', 'formulaic', 'conventional', 'stodgy']
senticnet['plutonium'] = [0, 0, 0, 0.1, '#admirable', '#admirable', 0.033, 'find_earth', 'wax', 'polish', 'worn_person', 'melt']
senticnet['supremo'] = [0.979, -0.692, 0, 0.576, '#joyful', '#surprising', 0.749, 'knocker', 'big_cheese', 'important_person', 'influential_person', 'personage']
senticnet['invalidityality'] = [-0.551, 0, 0.741, -0.768, '#angry', '#disgusting', -0.687, 'illogic', 'invalidityalness', 'invalidity', 'inconsequence', 'fallaciousness']
senticnet['pip'] = [0, 0.141, 0.01, 0.115, '#interesting', '#admirable', 0.082, 'fruit', 'rind', 'funiculus', 'seed', 'achene']
senticnet['pit'] = [0, 0, -0.903, -0.934, '#scared', '#disgusting', -0.612, 'fair_game', 'quarry', 'stone_pit', 'target', 'prey']
senticnet['sleek'] = [0.888, -0.683, 0, 0.914, '#joyful', '#admirable', 0.828, 'tidy', 'kempt', 'brushed', 'pomaded', 'groomed']
senticnet['sleet'] = [0.923, 0.994, 0, 0, '#joyful', '#interesting', 0.639, 'dew', 'fog', 'spray', 'cold_air', 'cloudy']
senticnet['sleep'] = [0.069, 0, 0, 0, '#joyful', '#joyful', 0.023, 'keep_warm_night', 'sleep_under', 'keep_warm_bed', 'cover_bed', 'use_bed']
senticnet['lurk'] = [0, 0, -0.994, -0.726, '#scared', '#disgusting', -0.573, 'ambuscade', 'waylay', 'ambush', 'scupper', 'bushwhack']
senticnet['venue'] = [0.12, -0.061, 0, 0, '#joyful', '#surprising', 0.06, 'ballroom', 'perform_art', 'nightclub', 'ballerina', 'ballet']
senticnet['socialize'] = [0.75, -0.978, 0, 0, '#joyful', '#surprising', 0.576, 'business_card', 'formal_introduction', 'database', 'professional', 'introduce_oneself']
senticnet['outpace'] = [0.995, 0, 0, 0.825, '#joyful', '#admirable', 0.607, 'outsell', 'trounce', 'outrun', 'outdistance', 'outstrip']
senticnet['schistosome'] = [-0.866, 0, 0.668, -0.543, '#sad', '#angry', -0.692, 'flatworm', 'platyhelminth', 'liver_fluke', 'blood_fluke', 'trematode']
senticnet['adjacent'] = [0, 0, -0.739, -0.968, '#scared', '#disgusting', -0.569, 'side_by_side', 'succeeding', 'following', 'next', 'future']
senticnet['poker'] = [-0.035, 0.085, -0.077, 0.114, '#interesting', '#admirable', 0.029, 'many_games', 'billiards', 'form_of_gambling', 'card_game', 'backgammon']
senticnet['stifling'] = [0, 0, -0.896, -0.792, '#scared', '#disgusting', -0.563, 'suppression', 'quelling', 'crushing', 'oppress', 'squeeze']
senticnet['acorn_winter_squash'] = [-0.562, 0, 0.696, -0.964, '#angry', '#disgusting', -0.741, 'winter_squash', 'squash', 'hubbard_winter_squash', 'turban_winter_squash', 'butternut_winter_squash']
senticnet['wanted'] = [0.59, -0.815, 0, 0.571, '#joyful', '#surprising', 0.659, 'preferred', 'admired', 'loved', 'darling', 'precious']
senticnet['fret'] = [-0.795, 0, 0.903, 0, '#sad', '#angry', -0.566, 'excruciating', 'harrowing', 'torturing', 'worry', 'agonizing']
senticnet['recite'] = [-0.066, 0.101, 0, 0.157, '#interesting', '#admirable', 0.064, 'use_memory', 'commemorate_event', 'contemplation', 'provide_answer', 'problem_solve']
senticnet['bushwhack'] = [0, 0, -0.994, -0.726, '#scared', '#disgusting', -0.573, 'ambuscade', 'lurk', 'ambush', 'scupper', 'waylay']
senticnet['revival'] = [0.715, 0, 0, 0.783, '#joyful', '#admirable', 0.499, 'reply', 'response', 'rebound', 'backtalk', 'comeback']
senticnet['ram'] = [-0.914, 0, -0.728, -0.99, '#sad', '#disgusting', -0.877, 'push', 'barge', 'shove_around', 'bang', 'jostle']
senticnet['raj'] = [0.94, -0.636, 0, 0.772, '#joyful', '#admirable', 0.783, 'paramountcy', 'dominion', 'reign', 'sovereignty', 'suzerainty']
senticnet['get_stuck_traffic'] = [0, 0, -0.811, -0.832, '#scared', '#disgusting', -0.548, 'accident_happen', 'traffic_congestion', 'piss_off', 'overwhelm', 'work_much']
senticnet['drum_out'] = [0, 0, -0.799, -0.771, '#scared', '#disgusting', -0.523, 'throw_out', 'oust', 'kick_out', 'boot_out', 'expel']
senticnet['transistor'] = [0.037, 0.073, 0.027, 0.072, '#interesting', '#admirable', 0.052, 'computer_chip', 'grain_sand', 'sand', 'silica', 'amethyst']
senticnet['receive_phone_call'] = [0, 0.85, 0, 0.933, '#interesting', '#admirable', 0.594, 'learn_listen', 'answer_phone', 'receive_letter', 'call_mom', 'answer_telephone']
senticnet['subjugate'] = [0, -0.925, 0, 0.704, '#surprising', '#admirable', 0.543, 'quash', 'keep_down', 'subdued', 'repress', 'reduce']
senticnet['precede'] = [0, -0.893, 0, 0.718, '#surprising', '#admirable', 0.537, 'conduce', 'leading', 'leadership', 'starring', 'guide']
senticnet['charge_plate'] = [0, 0, -0.811, -1.0, '#scared', '#disgusting', -0.604, 'plastic', 'fictile', 'charge_card', 'credit_card', 'moldable']
senticnet['rabidity'] = [0.609, -0.615, 0, 0.592, '#joyful', '#surprising', 0.605, 'spirit', 'ebullience', 'rabidness', 'sprightliness', 'lyricism']
senticnet['schedule_infant_feeding'] = [-0.802, 0, 0.724, -0.706, '#sad', '#angry', -0.744, 'nursing', 'feeding', 'demand_infant_feeding', 'breast_infant_feeding', 'infant_feeding']
senticnet['puppetry'] = [0.607, -0.997, 0, 0.847, '#surprising', '#admirable', 0.817, 'eristic', 'airmanship', 'homiletics', 'aviation', 'artistry']
senticnet['rubicund'] = [0, 0, -0.926, -0.963, '#scared', '#disgusting', -0.63, 'reddish', 'florid', 'sanguine', 'red', 'ruddy']
senticnet['vulture'] = [0, -0.076, 0, 0.081, '#surprising', '#admirable', 0.052, 'wing', 'most_birds', 'air_traffic_controller', 'bird', 'pigeon']
senticnet['tigerish'] = [0.971, -0.926, 0, 0.617, '#joyful', '#surprising', 0.838, 'mortal', 'cutthroat', 'merciless', 'bowelless', 'pitiless']
senticnet['willowy'] = [0.734, -0.531, 0, 0.914, '#joyful', '#admirable', 0.726, 'graceful', 'gracile', 'gainly', 'elegant', 'smooth']
senticnet['jejune'] = [0, 0, -0.947, -0.897, '#scared', '#disgusting', -0.615, 'flavorless', 'bland', 'insipid', 'vapid', 'flat']
senticnet['uncle'] = [0, 0.836, 0, 0.943, '#interesting', '#admirable', 0.593, 'family_member', 'dad', 'daddy', 'mother_daddy', 'brother']
senticnet['solar'] = [0.061, 0, 0, 0.067, '#joyful', '#admirable', 0.043, 'star', 'celestial_body', 'sun', 'celestial_object', 'sol']
senticnet['raft'] = [0.153, 0, 0, 0.149, '#joyful', '#admirable', 0.101, 'water_transportation', 'paddle', 'canoe', 'water_vehicle', 'ship']
senticnet['prematurely'] = [0, 0, -0.906, -0.995, '#scared', '#disgusting', -0.634, 'wrong', 'untimely', 'unseasonable', 'premature', 'ill-timed']
senticnet['tie'] = [-0.792, 0, -0.834, 0, '#sad', '#scared', -0.542, 'bind', 'attached', 'affiliated', 'connected', 'committed']
senticnet['propelling'] = [0.74, -0.755, 0, 0.815, '#surprising', '#admirable', 0.77, 'propellant', 'propellent', 'changing', 'dynamical', 'propulsive']
senticnet['younger'] = [0.032, 0.109, -0.079, 0.085, '#interesting', '#admirable', 0.049, 'plural', 'kin', 'relate_person', 'calve', 'young_people']
senticnet['snip'] = [0.636, -0.796, 0, 0.552, '#joyful', '#surprising', 0.661, 'dress', 'trim', 'disbud', 'prune', 'cut_back']
senticnet['poetess'] = [0.836, -0.602, 0, 0.845, '#joyful', '#admirable', 0.761, 'bard', 'poet', 'elegist', 'odist', 'poet_laureate']
senticnet['policeman'] = [0.954, 0.996, 0, 0.781, '#joyful', '#interesting', 0.91, 'officer', 'command', 'authority', 'military_order', 'supervisor']
senticnet['crippled'] = [0, 0, 0.868, -0.708, '#angry', '#disgusting', -0.525, 'gimpy', 'feeble', 'lame', 'square', 'halt']
senticnet['rededicate'] = [0.693, -0.699, 0, 0.714, '#surprising', '#admirable', 0.702, 'vow', 'dedicate', 'apply', 'consecrate', 'use']
senticnet['tweak'] = [0.71, -0.577, 0, 0.721, '#joyful', '#admirable', 0.669, 'tune_up', 'correct', 'adjust', 'set', 'service']
senticnet['trump'] = [0.974, 0, 0, 0.977, '#joyful', '#admirable', 0.65, 'top', 'cap', 'outdo', 'beat', 'better']
senticnet['stream'] = [0.728, 0.713, 0, 0.715, '#joyful', '#admirable', 0.719, 'brook', 'creek', 'river', 'well', 'pond']
senticnet['silver-tongued'] = [0, 0, -0.712, -0.751, '#scared', '#disgusting', -0.488, 'facile', 'silver', 'smooth-spoken', 'fluent', 'eloquent']
senticnet['renovation'] = [0.101, 0.099, 0, 0.169, '#joyful', '#admirable', 0.123, 'family_home', 'apartment', 'appliance_store', 'kitchen', 'electronics']
senticnet['branched'] = [0, 0, -0.889, -0.783, '#scared', '#disgusting', -0.557, 'forficate', 'pronged', 'forked', 'bifurcate', 'biramous']
senticnet['sugarcoat'] = [0.744, -0.77, 0, 0.661, '#joyful', '#surprising', 0.725, 'dulcify', 'honey', 'glaze', 'change_taste', 'sugar']
senticnet['threepenny'] = [0.753, -0.945, 0, 0.965, '#surprising', '#admirable', 0.888, 'eightpenny', 'size', 'sized', 'fourpenny', 'ninepenny']
senticnet['ruck'] = [0.688, -0.733, 0, 0.955, '#surprising', '#admirable', 0.792, 'angular_shape', 'angularity', 'crimp', 'pucker', 'pleat']
senticnet['extrapolate'] = [0, 0, -0.913, -0.829, '#scared', '#disgusting', -0.581, 'generalize', 'infer', 'deduce', 'derive', 'guess']
senticnet['venerableness'] = [0.66, -0.842, 0, 0.712, '#surprising', '#admirable', 0.738, 'respectability', 'reputability', 'venerability', 'honorableness', 'righteousness']
senticnet['reverie'] = [0.846, -0.928, 0, 0.504, '#joyful', '#surprising', 0.759, 'woolgathering', 'revery', 'daydream', 'daydreaming', 'dreaming']
senticnet['season'] = [0, 0.257, -0.133, 0.306, '#interesting', '#admirable', 0.143, 'word', 'notion', 'section', 'term', 'date']
senticnet['farce_comedy'] = [0, 0, -0.905, -0.973, '#scared', '#disgusting', -0.626, 'parody', 'farce', 'lampoon', 'travesty', 'spoof']
senticnet['neandertal'] = [-0.9, 0, -0.997, 0, '#sad', '#scared', -0.632, 'boorish', 'loutish', 'swinish', 'oafish', 'neanderthal']
senticnet['collimate'] = [0, 0, -0.9, -0.871, '#scared', '#disgusting', -0.59, 'analogue', 'analog', 'line_of_latitude', 'latitude', 'parallel']
senticnet['speediness'] = [0.548, -0.622, 0, 0.695, '#surprising', '#admirable', 0.622, 'quickness', 'instancy', 'rapidity', 'rapidness', 'celerity']
senticnet['dried-up'] = [0, 0, -0.932, -0.818, '#scared', '#disgusting', -0.583, 'sear', 'withered', 'sere', 'shrivelled', 'shriveled']
senticnet['rascality'] = [0.738, -0.895, 0, 0.634, '#joyful', '#surprising', 0.756, 'mischievousness', 'monkey_business', 'roguishness', 'deviltry', 'devilry']
senticnet['featherbed'] = [0, 0, -0.73, -0.945, '#scared', '#disgusting', -0.558, 'cocker', 'baby', 'cosset', 'coddle', 'pamper']
senticnet['savoury'] = [0, 0, -0.984, -0.991, '#scared', '#disgusting', -0.658, 'savory', 'spicy', 'zesty', 'zestful', 'piquant']
senticnet['torpedo'] = [0.086, 0.095, -0.065, 0.066, '#joyful', '#interesting', 0.061, 'married_couple', 'presidential_election', 'intelligent_person', 'use_binoculars', 'grown_up']
senticnet['professed'] = [0.843, -0.935, 0, 0.952, '#surprising', '#admirable', 0.91, 'asserted', 'avowed', 'alleged', 'declared', 'announced']
senticnet['visceral'] = [-0.91, 0, 0, -0.844, '#sad', '#disgusting', -0.585, 'absurd', 'inconsequential', 'illogical', 'nonrational', 'groundless']
senticnet['review'] = [0, 0.848, 0, 0.971, '#interesting', '#admirable', 0.606, 'analyze_book', 'book', 'read_book', 'write_review', 'review_book']
senticnet['bemuddy'] = [-0.93, 0, 0.897, -0.923, '#sad', '#disgusting', -0.917, 'dirty', 'soil', 'grime', 'muddy', 'colly']
senticnet['fiddling'] = [0, 0, -0.868, -0.863, '#scared', '#disgusting', -0.577, 'footling', 'lilliputian', 'little', 'picayune', 'niggling']
senticnet['reaction'] = [0.97, 0, 0, 0, '#joyful', '#joyful', 0.323, 'eye_tear', 'baby_action', 'shed_tear', 'bawl', 'body_action']
senticnet['superstar'] = [0, 0.793, 0, 0.91, '#interesting', '#admirable', 0.568, 'stardom', 'vip', 'accomplishment', 'performance', 'concert']
senticnet['swaggering'] = [0.706, -0.87, 0, 0.968, '#surprising', '#admirable', 0.848, 'audacious', 'adventuresome', 'daring', 'venturesome', 'venturous']
senticnet['bizarre'] = [0, -0.949, 0, 0.938, '#surprising', '#admirable', 0.629, 'freaky', 'outlandish', 'off-the-wall', 'flaky', 'gonzo']
senticnet['palliate'] = [0, -0.816, 0, 0.902, '#surprising', '#admirable', 0.573, 'alleviate', 'assuage', 'relieved', 'take_over', 'exempt']
senticnet['telephone'] = [0.035, -0.01, 0.027, 0.085, '#joyful', '#admirable', 0.034, 'cellphone', 'find_phone_number', 'telephone_room', 'phone', 'use_telephone']
senticnet['mockery'] = [0, 0, 0.79, -0.834, '#angry', '#disgusting', -0.541, 'burlesque', 'parody', 'spoof', 'lampoon', 'sendup']
senticnet['minimize'] = [0, 0, -0.83, -0.954, '#scared', '#disgusting', -0.595, 'denigrate', 'slander', 'defame', 'derogate', 'belittle']
senticnet['large_accommodation'] = [0, 0.119, 0, 0.095, '#interesting', '#admirable', 0.071, 'accommodation', 'government', 'govern_city', 'government_accommodation', 'building']
senticnet['slick'] = [0.072, 0.065, -0.068, 0.144, '#joyful', '#admirable', 0.071, 'gooey', 'paraffin', 'bee_product', 'goo', 'fuel_source']
senticnet['sleazy'] = [0.725, -0.886, 0, 0.508, '#joyful', '#surprising', 0.706, 'louche', 'seedy', 'discredited', 'discreditable', 'disreputable']
senticnet['toilet'] = [0.042, -0.056, 0, 0, '#joyful', '#surprising', 0.033, 'bath', 'bathroom_drawerroom', 'beauty_parlor', 'hotel_bathroom_drawerroom', 'bathroom_drawer']
senticnet['requester'] = [0, 0, -0.776, -0.821, '#scared', '#disgusting', -0.532, 'suppliant', 'supplicant', 'petitioner', 'supplicatory', 'prayer']
senticnet['lacy'] = [0, 0, -0.839, -0.759, '#scared', '#disgusting', -0.533, 'netted', 'net', 'webbed', 'netlike', 'weblike']
senticnet['ticket'] = [0, 0.074, 0.051, 0.105, '#interesting', '#admirable', 0.043, 'purchase_ticket', 'buy_ticket', 'pay_ticket', 'go_to_theater', 'go_movie_theater']
senticnet['sulfacetamide'] = [0.551, -0.753, 0, 0.817, '#surprising', '#admirable', 0.707, 'antibacterial', 'sulfamethoxazole', 'sulfisoxazole', 'sulfadiazine', 'sulfa']
senticnet['bride_groomsmaid'] = [0.151, 0, -0.148, 0.157, '#joyful', '#admirable', 0.053, 'bride_groom', 'wedding_cake', 'flower_girl', 'bride', 'alcohol']
senticnet['thrift'] = [0.533, -0.558, 0, 0.912, '#surprising', '#admirable', 0.668, 'parsimony', 'parsimoniousness', 'frugality', 'economy', 'prudence']
senticnet['reverberate'] = [-0.957, 0, -0.9, 0, '#sad', '#scared', -0.619, 'knell', 'ringed', 'resound', 'peal', 'echo']
senticnet['unclogged'] = [0.924, -0.834, 0, 0.807, '#joyful', '#surprising', 0.855, 'unobstructed', 'clear', 'patent', 'open', 'unimpeded']
senticnet['oleaginous'] = [0, 0, -0.868, -0.782, '#scared', '#disgusting', -0.55, 'pantry', 'larder', 'fulsome', 'oily', 'buttery']
senticnet['sunscreen'] = [0.896, 0.857, 0, 0, '#joyful', '#interesting', 0.584, 'go_to_beach', 'wear_sunscreen', 'sunblock', 'sunny_day', 'summertime']
senticnet['obtain_bad_drug'] = [-0.182, -0.078, 0, -0.203, '#sad', '#disgusting', -0.102, 'bad_drug_spill', 'bad_drug', 'atmosphere', 'cool_bad_drug', 'water']
senticnet['toxicologist'] = [0.904, -0.93, 0, 0.639, '#joyful', '#surprising', 0.824, 'epidemiologist', 'medical_scientist', 'immunologist', 'serologist', 'scientist']
senticnet['rapaciousness'] = [0.768, -0.723, 0, 0.838, '#joyful', '#admirable', 0.776, 'gluttony', 'esurience', 'voracity', 'voraciousness', 'edacity']
senticnet['prodigy'] = [-0.75, 0, -0.718, 0, '#sad', '#scared', -0.489, 'prognostication', 'prognostic', 'presage', 'omen', 'portent']
senticnet['churning'] = [0, 0, -0.727, -0.853, '#scared', '#disgusting', -0.527, 'disruptive', 'troubled', 'tumultuous', 'riotous', 'turbulent']
senticnet['plummet'] = [0, 0, -0.953, -0.711, '#scared', '#disgusting', -0.555, 'plank', 'plonk', 'flump', 'plop', 'plump']
senticnet['predementedness'] = [-0.947, 0, 0.821, -0.756, '#sad', '#angry', -0.841, 'senile_dementia', 'insanity', 'dementedness', 'senile_psychosis', 'alcoholic_dementia']
senticnet['dawdling'] = [0, 0, -0.846, -0.822, '#scared', '#disgusting', -0.556, 'dalliance', 'piddle', 'wanton_away', 'wanton', 'trifling']
senticnet['pianism'] = [0.558, -0.602, 0, 0.779, '#surprising', '#admirable', 0.646, 'benefit', 'histrionics', 'song_and_dance', 'routine', 'performance']
senticnet['voraciousness'] = [0.768, -0.723, 0, 0.838, '#joyful', '#admirable', 0.776, 'gluttony', 'esurience', 'voracity', 'edacity', 'rapaciousness']
senticnet['react'] = [-0.042, 0.131, -0.055, 0.186, '#interesting', '#admirable', 0.073, 'do_something', 'posture', 'take_action', 'behave', 'take_initiative']
senticnet['enjoy_sun'] = [0.759, 0, 0, 0, '#joyful', '#joyful', 0.253, 'get_tan', 'sit_on_beach', 'summer', 'sunshine', 'dry_clothes']
senticnet['sure'] = [0.947, -0.793, 0, 0.7, '#joyful', '#surprising', 0.813, 'tested', 'tried', 'tried_and_true', 'dependable', 'undeviating']
senticnet['unconsidered'] = [0.561, -0.912, 0, 0.563, '#surprising', '#admirable', 0.679, 'unthinking', 'inconsiderate', 'unreflective', 'unthoughtful', 'thoughtless']
senticnet['whistle'] = [0.076, 0, 0, 0, '#joyful', '#joyful', 0.025, 'dog_food', 'toy', 'lure', 'treats', 'attract_dog']
senticnet['stump'] = [0.935, 0.842, 0, 0, '#joyful', '#interesting', 0.592, 'plank', 'lumber', 'mahogany', 'hardwood', 'board']
senticnet['wisplike'] = [0, 0, -0.782, -0.753, '#scared', '#disgusting', -0.512, 'dim', 'vague', 'wispy', 'shadowy', 'faint']
senticnet['recording'] = [0, 0.108, 0, 0.202, '#interesting', '#admirable', 0.103, 'source_electricity', 'read_instruction_manual', 'switch', 'turn_television_set', 'find_tape']
senticnet['shtik'] = [0.931, -0.847, 0, 0.829, '#joyful', '#surprising', 0.869, 'folly', 'lunacy', 'craziness', 'indulgence', 'buffoonery']
senticnet['untracked'] = [0, 0, 0.737, -0.897, '#angry', '#disgusting', -0.545, 'outback', 'trackless', 'pathless', 'roadless', 'inaccessible']
senticnet['precursor'] = [0, 0, -0.773, -0.981, '#scared', '#disgusting', -0.585, 'forerunner', 'announce', 'harbingers', 'predecessor', 'herald']
senticnet['twofold'] = [0, 0, 0.713, -0.99, '#angry', '#disgusting', -0.568, 'double', 'dual', 'treble', 'threefold', 'three-fold']
senticnet['stumblebum'] = [0, 0, -0.756, -0.851, '#scared', '#disgusting', -0.536, 'oaf', 'clod', 'goon', 'lummox', 'lout']
senticnet['vigilant'] = [0.805, -0.671, 0, 0.901, '#joyful', '#admirable', 0.792, 'lidless', 'wakeful', 'watchful', 'fly', 'sleepless']
senticnet['find_accomplish'] = [0.907, 0, 0, 0.79, '#joyful', '#admirable', 0.566, 'get_accomplish_done', 'task', 'hard_work', 'accomplish', 'job']
senticnet['prod'] = [0, 0, 0.722, -0.768, '#angry', '#disgusting', -0.497, 'goad', 'spur', 'needle', 'urging', 'prick']
senticnet['solecism'] = [0, 0, 0.844, -0.94, '#angry', '#disgusting', -0.595, 'rusticity', 'slip', 'gaucherie', 'gaffe', 'faux_pas']
senticnet['repeatedly'] = [0, 0.338, -0.162, 0.355, '#interesting', '#admirable', 0.177, 'redo', 'inclusion', 'again_and_again', 'never_stop', 'repeat']
senticnet['anserine'] = [0, 0, 0.746, -0.914, '#angry', '#disgusting', -0.553, 'dopey', 'dopy', 'foolish', 'goosy', 'jerky']
senticnet['sniper'] = [0.801, -0.874, 0, 0.916, '#surprising', '#admirable', 0.864, 'rifleman', 'deadeye', 'crack_shot', 'shot', 'shooter']
senticnet['unhallow'] = [0, 0, -0.701, -0.792, '#scared', '#disgusting', -0.498, 'profane', 'deconsecrate', 'outrage', 'desecrate', 'violate']
senticnet['sunbright_light'] = [0.085, 0.107, -0.081, 0, '#joyful', '#interesting', 0.037, 'hot_sun', 'light', 'hot', 'hot_day', 'bright_light']
senticnet['scrapper'] = [0.833, -0.974, 0, 0.91, '#surprising', '#admirable', 0.906, 'combatant', 'fencer', 'belligerent', 'fighter', 'battler']
senticnet['pleseant'] = [0, 0.96, 0, 0.823, '#interesting', '#admirable', 0.594, 'mythical_creature', 'hero', 'mythical_being', 'calm', 'halcyon']
senticnet['typic'] = [0, 0, -0.828, -0.831, '#scared', '#disgusting', -0.553, 'model', 'emblematic', 'exemplary', 'admonitory', 'cautionary']
senticnet['briery'] = [0, 0, -0.827, -0.782, '#scared', '#disgusting', -0.536, 'barbellate', 'thorny', 'bristled', 'briary', 'barbed']
senticnet['steganography'] = [0.634, -0.738, 0, 0.974, '#surprising', '#admirable', 0.782, 'decompression', 'cryptography', 'decipherment', 'secret_writing', 'coding']
senticnet['tar'] = [0, 0.127, -0.046, 0.194, '#interesting', '#admirable', 0.092, 'concrete', 'cement', 'pavement', 'big_city_life', 'popular_building_material']
senticnet['condescend'] = [0, -0.751, 0, 0.847, '#surprising', '#admirable', 0.533, 'patronize', 'sponsor', 'buy_at', 'support', 'patronise']
senticnet['sculptured'] = [0.636, -0.954, 0, 0.664, '#surprising', '#admirable', 0.751, 'voluptuous', 'statuesque', 'buxom', 'shapely', 'sculptural']
senticnet['choosy'] = [0.682, -0.525, 0, 0.613, '#joyful', '#admirable', 0.607, 'meticulous', 'pernickety', 'fastidious', 'fussy', 'dainty']
senticnet['trap'] = [0.02, 0.162, 0, 0.062, '#interesting', '#admirable', 0.081, 'catch', 'ambush', 'bait_trap', 'lure', 'decoy']
senticnet['praiseful'] = [0.722, -0.981, 0, 0.832, '#surprising', '#admirable', 0.845, 'laudatory', 'complimentary', 'praising', 'encomiastic', 'eulogistic']
senticnet['semen'] = [0, 0.104, 0, 0.185, '#interesting', '#admirable', 0.096, 'seed_lawn', 'seed', 'pip', 'kernel', 'pit']
senticnet['sunbaked'] = [0, 0, -0.923, -0.966, '#scared', '#disgusting', -0.63, 'adust', 'scorched', 'sear', 'parched', 'baked']
senticnet['flying_airstrip'] = [-0.975, 0, 0.737, -0.979, '#sad', '#disgusting', -0.897, 'flare_path', 'airairstrip', 'landing_airstrip', 'field', 'airstrip']
senticnet['salient'] = [0.998, 0, 0, 0.848, '#joyful', '#admirable', 0.615, 'outstanding', 'prominent', 'big', 'spectacular', 'striking']
senticnet['droop'] = [0, 0, -0.943, -0.781, '#scared', '#disgusting', -0.575, 'bum', 'bum_about', 'arse_around', 'loll', 'bum_around']
senticnet['inert_coal'] = [0, 0.76, 0, 0.817, '#interesting', '#admirable', 0.526, 'diesel', 'fuel', 'kerosene', 'coal', 'gas']
senticnet['doomed'] = [0, 0, -0.909, -0.938, '#scared', '#disgusting', -0.616, 'luckless', 'ill-omened', 'ill-starred', 'unlucky', 'ill-fated']
senticnet['florid'] = [0, -1.0, 0, 0.766, '#surprising', '#admirable', 0.589, 'splashy', 'royal_poinciana', 'flamboyant', 'showy', 'aureate']
senticnet['ponderable'] = [0.878, -0.678, 0, 0.631, '#joyful', '#surprising', 0.729, 'conceivable', 'presumable', 'supposable', 'surmisable', 'thinkable']
senticnet['centre'] = [-0.762, 0, -0.733, 0, '#sad', '#scared', -0.498, 'concentrate', 'focused', 'focalise', 'sharpen', 'pore']
senticnet['trustiness'] = [0.881, -0.51, 0, 0.76, '#joyful', '#admirable', 0.717, 'trustworthiness', 'responsibleness', 'dependability', 'dependableness', 'reliability']
senticnet['plummy'] = [0.816, 0, 0, 0.872, '#joyful', '#admirable', 0.563, 'delectable', 'preferred', 'lovable', 'desired', 'enviably']
senticnet['dopy'] = [0, 0, 0.746, -0.914, '#angry', '#disgusting', -0.553, 'anserine', 'dopey', 'foolish', 'goosy', 'jerky']
senticnet['sediment'] = [0.203, 0.077, 0, 0.189, '#joyful', '#admirable', 0.156, 'sea_shell', 'coast', 'seaside', 'sane', 'shell']
senticnet['view'] = [0.862, -0.611, 0, 0.549, '#joyful', '#surprising', 0.674, 'consider', 'deem', 'regard', 'reckon', 'see']
senticnet['blank_spaceion'] = [-0.982, 0, 0.959, -0.685, '#sad', '#angry', -0.875, 'expanse', 'margin', 'blank_spaceation', 'indent', 'blank_space']
senticnet['entrant'] = [0, 0, -0.983, -0.891, '#scared', '#disgusting', -0.625, 'freshman', 'newcomer', 'starter', 'fledgeling', 'neophyte']
senticnet['window'] = [0, 0.073, 0, 0.079, '#interesting', '#admirable', 0.051, 'shutter', 'drape', 'window_cover', 'hang', 'drop']
senticnet['bladder_rockweed'] = [-0.896, 0, 0.556, -0.726, '#sad', '#disgusting', -0.726, 'rockweed', 'bladderwrack', 'black_rockweed', 'fucus', 'tang']
senticnet['spironolactone_drug'] = [-0.763, 0, 0.681, -0.578, '#sad', '#angry', -0.674, 'corticosteroid', 'corticoid', 'adrenal_cortical_steroid', 'spironolactone', 'antihypertensive']
senticnet['vintage'] = [0.086, -0.107, 0.064, 0, '#joyful', '#surprising', 0.043, 'art_piece', 'lifetime', 'museum', 'ancient_artifact', 'collectibles']
senticnet['flint'] = [0, 0, -0.909, -0.739, '#scared', '#disgusting', -0.549, 'unrepentant', 'obstinate', 'obdurate', 'flinty', 'cussed']
senticnet['temerity'] = [0.775, -0.978, 0, 0.731, '#joyful', '#surprising', 0.828, 'daredevilry', 'daredeviltry', 'audaciousness', 'audacity', 'boldness']
senticnet['sky'] = [-0.048, 0.105, -0.061, 0.115, '#interesting', '#admirable', 0.037, 'airplane', 'pilot', 'air_traffic', 'aeroplane', 'jet']
senticnet['saturation'] = [0.789, -0.925, 0, 0.964, '#surprising', '#admirable', 0.893, 'permeation', 'carbonation', 'impregnation', 'ammonification', 'diffusion']
senticnet['visibleness'] = [0.685, -0.912, 0, 0.566, '#joyful', '#surprising', 0.721, 'perceptibility', 'audibleness', 'audibility', 'visibility', 'physical_property']
senticnet['flash_cardination'] = [-0.031, 0.086, 0.01, 0.091, '#interesting', '#admirable', 0.045, 'write_term_paper', 'flash_card', 'take_final', 'take_exam', 'take_midterm']
senticnet['shock_therapy_treatment'] = [-0.724, 0, 0.732, -0.595, '#sad', '#angry', -0.684, 'shock_therapy', 'shock', 'insulin_shock', 'metrazol_shock', 'metrazol_shock_therapy']
senticnet['theatrical_baddie'] = [-0.829, 0, 0.958, -0.557, '#sad', '#angry', -0.781, 'character', 'baddie', 'role', 'part', 'persona']
senticnet['registration'] = [0.667, -0.885, 0, 0.92, '#surprising', '#admirable', 0.824, 'adjustment', 'activity', 'tuning', 'calibration', 'readjustment']
senticnet['hardiness'] = [0.973, 0.74, 0, 0, '#joyful', '#interesting', 0.571, 'courage', 'grit', 'resolve', 'determination', 'resolution']
senticnet['self_satisfied'] = [-0.872, 0, 0, -0.915, '#sad', '#disgusting', -0.596, 'smugness', 'proudly', 'smug', 'preen', 'complacence']
senticnet['give_a_lot_of_flowers'] = [0.027, 0.093, 0.025, 0.071, '#interesting', '#admirable', 0.055, 'a_lot_of_flowers', 'love', 'show_love', 'rose', 'flower']
